(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1175704,      29130]*)
(*NotebookOutlinePosition[   1176478,      29157]*)
(*  CellTagsIndexPosition[   1176434,      29153]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[
"Detekcja cz\:0119stotliwo\.9cci podstawowej przy pomocy funkcji \
autokorelacji"], "Title"],

Cell[TextData["\[CapitalSHacek] 1999, 2000, Marek Szczerba"], "Subsubsection"],

Cell[CellGroupData[{

Cell["Inicjalizacja", "Section"],

Cell[CellGroupData[{

Cell["Wczytanie bibliotek", "Subsection"],

Cell[TextData["Biblioteka obs\[LSlash]ugi d\.9fwi\:0119ku"], "MathCaption"],

Cell[BoxData[
    \(<< Miscellaneous`Audio`\)], "Input",
  CellLabel->"In[1]:="],

Cell["Biblioteki statystyczne", "MathCaption"],

Cell[BoxData[
    \(<< Statistics`DescriptiveStatistics`\)], "Input",
  CellLabel->"In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Akwizycja sygna\[LSlash]u"], "Subsection"],

Cell[BoxData[
    \(\(SetDirectory["\<D:\\Mathematica\\Data\\\>"]; \)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(snd = ReadSoundfile["\<oboe1.wav\>"]; \nAKFName = "\<AutoK.dat\>"; \)], 
  "Input",
  CellLabel->"In[4]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Parametry definiowane przez u\:017cytkownika"], "Subsection"],

Cell[TextData[
"Odst\:0119p w pr\[OAcute]bkach pomi\:0119dzy poszczeg\[OAcute]lnymi punktami \
analizy"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Skok", "=", 
        StyleBox["100",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[
"Cz\:0119stotliwo\.9c\[CAcute] pr\[OAcute]bkowania"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CzP", "=", 
        StyleBox["22050",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[6]:="],

Cell["Granice pasma analizy", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CzMin", "=", 
        StyleBox["100",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"CzMax", "=", 
        StyleBox["2000",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[7]:="],

Cell[TextData[
"Warto\.9c\[CAcute] parametru t\[LSlash]umienia niskich \
cz\:0119stotliwo\.9cci"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"T\[LSlash]umik", "=", 
        StyleBox["0.8",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[8]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parametry obliczane automatycznie", "Subsection"],

Cell["Konwersja pasma analizy", "MathCaption"],

Cell[BoxData[
    \(OkrMin = 1;  (*Ceiling[CzP\/CzMax]; *) \nOkrMax = Floor[CzP\/CzMin]; 
    \)], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[
"Rzeczywista cz\:0119stotliwo\.9c\[CAcute] podstawowa d\.9fwi\:0119ku"], 
  "MathCaption"],

Cell[BoxData[
    \(\(RzCzPodst = N[444 \@\( 2\^Wys\)\%12]; \)\)], "Input",
  CellLabel->"In[10]:="],

Cell["Liczba punkt\[OAcute]w analizy", "MathCaption"],

Cell[BoxData[
    \(LRamek = 0; \n
    For[j = 1, j <= Length[snd] - 4  OkrMax, j += Skok, \(LRamek++\)]; \)], 
  "Input",
  CellLabel->"In[11]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Definicje funkcji przetwarzania sygna\[LSlash]u"], "Section"],

Cell["Definicja funkcji autokorelacji", "MathCaption"],

Cell[BoxData[
    \(\(AutoCorr = \n\t
      Function[dane, \n\t\tfL = Length[dane]\  - \ OkrMax; \n\t\t
        Wynik = Table[0, \ {fi, OkrMax}]; \n\t\t
        init = \[Sum]\+\(fn = 1\)\%fL Abs[
              dane\[LeftDoubleBracket]fn\[RightDoubleBracket]]; \n\t\t
        For[fi = OkrMin, \ fi\  <= \ OkrMax, \ \(fi++\), \n\t\t\t
          \[Rho] = 
            \[Sum]\+\(fn = 1\)\%fL\((
                dane\[LeftDoubleBracket]fn\[RightDoubleBracket] 
                  dane\[LeftDoubleBracket]fn\  + \ fi\[RightDoubleBracket])
                \); \n\t\t\t
          Wynik\[LeftDoubleBracket]fi\[RightDoubleBracket] = 
            N[\[Rho]\/init]]; \n\ \ \ \ \ \ \ \ Wynik]; \)\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData["P\:0119tla funkcji autokorelacji"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(OblAutoK = \n\t
      Function[{dzw, lr}, \n\t\tstream = OpenWrite[AKFName]; \n\t\tNumer = 0; 
        \n\t\tFor[fk = 1, fk <= lr*Skok, fk += Skok, \n\t\t\t\(Numer++\); \n
          \t\t\tRamka = 
            Table[dzw\[LeftDoubleBracket]fj\[RightDoubleBracket], {fj, fk, 
                fk + 2\ OkrMax - 1}]; \n\t\t\tAKRamka\  = \ AutoCorr[Ramka]; 
          \n\t\t\tFor[fm = 1, fm < OkrMin, \(fm++\), \n\t\t\t\t
            AKRamka\[LeftDoubleBracket]fm\[RightDoubleBracket] = 0]; \n\t\t\t
          Write[stream, AKRamka]]; \n\t\tClose[stream]; ]; \)\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`Numer\\)\\\" is similar to existing symbol \
\\\"\\!\\(TraditionalForm\\`Number\\)\\\".\"\>"}], TraditionalForm]], 
  "Message"]
}, Open  ]],

Cell["Odczytanie warto\.9cci funkcji autokorelacji z pliku", "MathCaption"],

Cell[BoxData[
    \(\(ReadAK = 
      Function[lr, \n\t\tstream = OpenRead[AKFName]; \n\t\tWyP = {}; \n\t\t
        For[fk = 1, fk <= lr\ Skok, fk += Skok, \n\t\t\t\t
          AppendTo[WyP, Read[stream, Expression]]]; \n\t\tClose[stream]; \n
        \t\tWyP]; \)\)], "Input",
  CellLabel->"In[14]:="],

Cell["Poszukiwanie maksimum funkcji autokorelacji", "MathCaption"],

Cell[BoxData[
    \(\(MaksAutoK = \n\t
      Function[dane, \n\t\tWynik = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \ \n\t\t\tMaks = 0; \n\t\t\t
          Lok = 0; \n\t\t\t
          For[fj = 1, 
            fj <= Length[dane\[LeftDoubleBracket]fi\[RightDoubleBracket]], 
            \(fj++\), \n\t\t\t\t
            \(If[dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] > Maks, 
              \n\t\t\t\t\t
              Maks = dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket]; \n
              \t\t\t\t\tLok = fj; ]; \)]; \n\t\t\t
          AppendTo[Wynik, {Lok, Maks}]; ]; \n\t\tWynik]; \)\)], "Input",
  CellLabel->"In[15]:="],

Cell[TextData[
"Funkcja t\[LSlash]umienia sk\[LSlash]adowych o niskiej \
cz\:0119stotliwo\.9cci"], "MathCaption"],

Cell[BoxData[
    \(\(T\[LSlash]umienie = 
      Function[{dane, k}, \n\t\tWynik = dane; \n\t\tM = OkrMax - OkrMin; \n
        \t\tFor[fn = 1, fn <= Length[dane], \(fn++\), \n\t\t\t
          For[fm = 1, 
            fm <= Length[dane\[LeftDoubleBracket]fn\[RightDoubleBracket]], 
            \(fm++\), \n\t\t\t\t
            \(Wynik\[LeftDoubleBracket]fn, fm\[RightDoubleBracket] = 
              dane\[LeftDoubleBracket]fn, fm\[RightDoubleBracket]*
                \((1 - \(k\ fm\)\/M)\); \)]]; \n\t\tWynik]; \)\)], "Input",
  CellLabel->"In[16]:="],

Cell[TextData[StyleBox[
"Wyznaczenie pasm p\[OAcute]\[LSlash]tonowych"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GetBands = 
      Function[{fin, fmin, fmax}, \n\t\tWy = {fin}; \n\t\tfx = fin; \n\t\t
        While[fx > fmin, \n\t\t\tfx *= \@\(2\^\(-1\)\)\%12; \n\t\t\t
          AppendTo[Wy, N[fx]]]; \n\t\tfx = fin; \n\t\t
        While[fx < fmax, \n\t\t\tfx *= \@2\%12; \n\t\t\tAppendTo[Wy, N[fx]]]; 
        \n\t\tSort[Wy]]; \)\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`fmin\\)\\\" is similar to existing symbol \\\"\\!\
\\(TraditionalForm\\`fin\\)\\\".\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell[TextData[StyleBox[
"Wyznaczenie maksymalnych warto\.9cci funkcji autokorelacji w pasmach"]], 
  "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GetMaksBands = 
      Function[{fdata, fbands}, \n\t\t
        Wy = Table[Table[0, {Length[fbands]}], {Length[fdata]}]; \n\t\t
        For[fi = 1, fi <= Length[fdata], \(fi++\), \n\t\t\t
          For[fj = 1, fj <= Length[fbands], \(fj++\), \n\t\t\t\t
            TmpTable = {}; \n\t\t\t\t
            fkmax = Ceiling[
                CzP\/\(fbands\[LeftDoubleBracket]fj\[RightDoubleBracket] 
                    \@\(2\^\(-1\)\)\%24\)]; \n\t\t\t\t
            If[fkmax > OkrMax, fkmax = OkrMax]; \n\t\t\t\t
            For[fk = 
                Floor[CzP
                    \/\(fbands\[LeftDoubleBracket]fj\[RightDoubleBracket] 
                      \@2\%24\)], fk <= fkmax, \(fk++\), \n\t\t\t\t\t
              AppendTo[TmpTable, 
                fdata\[LeftDoubleBracket]fi, fk\[RightDoubleBracket]]]; \n
            \t\t\t\tWy\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] = 
              Max[TmpTable]]]; \n\t\tWy]; \)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`fkmax\\)\\\" is similar to existing symbol \
\\\"\\!\\(TraditionalForm\\`fmax\\)\\\".\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell["Pomiar poprawno\.9cci detekcji", "MathCaption"],

Cell[BoxData[
    \(\(B\[LSlash]\[SHacek]dProc = 
      Function[dane, \n\t\tOK = 0; \n\t\tfj = 1; \n\t\t
        B\[LSlash]\:0119dzik = {}; \n\t\t
        For[fi = 1, fi < Length[dane], \(fi++\), \n\t\t\t\t
          While[\(fi\ Skok\)\/CzP > 
                Fraza\[LeftDoubleBracket]fj, 2\[RightDoubleBracket] && 
              fj < Length[Fraza], \(\(fj++\); \)]; \n\t\t\t
          GrDolna = 
            Fraza\[LeftDoubleBracket]fj, 1\[RightDoubleBracket] 
              \@\(2\^\(-2\)\)\%12; \n\t\t\t
          GrG\[OAcute]rna = 
            Fraza\[LeftDoubleBracket]fj, 1\[RightDoubleBracket] 
              \@\(2\^2\)\%12; \n\t\t\t
          AppendTo[B\[LSlash]\:0119dzik, 
            Fraza\[LeftDoubleBracket]fj, 1\[RightDoubleBracket] - 
              dane\[LeftDoubleBracket]fi\[RightDoubleBracket]]; \n\t\t\t
          If[GrDolna < dane\[LeftDoubleBracket]fi\[RightDoubleBracket] && 
              dane\[LeftDoubleBracket]fi\[RightDoubleBracket] < 
                GrG\[OAcute]rna, \(OK++\)]]; \n100  OK\/Length[dane] // N]; 
    \)\)], "Input",
  CellLabel->"In[19]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obliczenia", "Section"],

Cell[TextData[
"Obliczenie funkcji autokorelacji dla poszczeg\[OAcute]lnych ramek sygna\
\[LSlash]u"], "MathCaption"],

Cell[BoxData[
    \(\(OblAutoK[snd, LRamek]; \)\)], "Input",
  CellLabel->"In[292]:="],

Cell["Odczytanie warto\.9cci funkcji autokorelacji z pliku", "MathCaption"],

Cell[BoxData[
    \(\(AutoK = ReadAK[LRamek]; \)\)], "Input",
  CellLabel->"In[20]:="],

Cell[TextData[
"T\[LSlash]umienie warto\.9cci funkcji autokorelacji dla ni\:017cszych cz\
\:0119stotliwo\.9cci"], "MathCaption"],

Cell[BoxData[
    \(\(T\[LSlash]AutoK = T\[LSlash]umienie[AutoK, T\[LSlash]umik]/10000; 
    \)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(\(For[i = 1, i <= Length[snd], \(i++\), \n\t
      If[snd\[LeftDoubleBracket]i\[RightDoubleBracket] == 0, 
        snd\[LeftDoubleBracket]i\[RightDoubleBracket] = 1]]; \)\)], "Input",
  CellLabel->"In[22]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Segmentacja sygna\[LSlash]u"], "Section"],

Cell[BoxData[
    \(\(sft = 
      Table[Max[T\[LSlash]AutoK\[LeftDoubleBracket]j\[RightDoubleBracket]]*
          \((1 + \(1\/\(10  OkrMax\)\) 
                \(\[Sum]\+\(k = 1\)\%OkrMax Log[
                    Abs[snd\[LeftDoubleBracket]k + 
                          \((j - 1)\) Skok\[RightDoubleBracket]]]\))\), {j, 
          Length[T\[LSlash]AutoK]}]; \)\)], "Input",
  CellLabel->"In[23]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[sft, PlotJoined -> True, PlotRange -> All, 
      PlotStyle -> RGBColor[0, 0, 1], Frame -> True]; \)\)], "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0233132 0.00049629 0.0144769 0.244921 [
[.02331 -0.0125 -3 -9 ]
[.02331 -0.0125 3 0 ]
[.27146 -0.0125 -9 -9 ]
[.27146 -0.0125 9 0 ]
[.5196 -0.0125 -12 -9 ]
[.5196 -0.0125 12 0 ]
[.76775 -0.0125 -12 -9 ]
[.76775 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01448 -6 -4.5 ]
[-0.0125 .01448 0 4.5 ]
[-0.0125 .13694 -18 -4.5 ]
[-0.0125 .13694 0 4.5 ]
[-0.0125 .2594 -6 -4.5 ]
[-0.0125 .2594 0 4.5 ]
[-0.0125 .38186 -18 -4.5 ]
[-0.0125 .38186 0 4.5 ]
[-0.0125 .50432 -6 -4.5 ]
[-0.0125 .50432 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02331 0 m
.02331 .00625 L
s
[(0)] .02331 -0.0125 0 1 Mshowa
.27146 0 m
.27146 .00625 L
s
[(500)] .27146 -0.0125 0 1 Mshowa
.5196 0 m
.5196 .00625 L
s
[(1000)] .5196 -0.0125 0 1 Mshowa
.76775 0 m
.76775 .00625 L
s
[(1500)] .76775 -0.0125 0 1 Mshowa
.125 Mabswid
.07294 0 m
.07294 .00375 L
s
.12257 0 m
.12257 .00375 L
s
.1722 0 m
.1722 .00375 L
s
.22183 0 m
.22183 .00375 L
s
.32109 0 m
.32109 .00375 L
s
.37072 0 m
.37072 .00375 L
s
.42035 0 m
.42035 .00375 L
s
.46997 0 m
.46997 .00375 L
s
.56923 0 m
.56923 .00375 L
s
.61886 0 m
.61886 .00375 L
s
.66849 0 m
.66849 .00375 L
s
.71812 0 m
.71812 .00375 L
s
.81738 0 m
.81738 .00375 L
s
.86701 0 m
.86701 .00375 L
s
.91664 0 m
.91664 .00375 L
s
.96626 0 m
.96626 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01448 m
.00625 .01448 L
s
[(0)] -0.0125 .01448 1 0 Mshowa
0 .13694 m
.00625 .13694 L
s
[(0.5)] -0.0125 .13694 1 0 Mshowa
0 .2594 m
.00625 .2594 L
s
[(1)] -0.0125 .2594 1 0 Mshowa
0 .38186 m
.00625 .38186 L
s
[(1.5)] -0.0125 .38186 1 0 Mshowa
0 .50432 m
.00625 .50432 L
s
[(2)] -0.0125 .50432 1 0 Mshowa
.125 Mabswid
0 .03897 m
.00375 .03897 L
s
0 .06346 m
.00375 .06346 L
s
0 .08795 m
.00375 .08795 L
s
0 .11245 m
.00375 .11245 L
s
0 .16143 m
.00375 .16143 L
s
0 .18592 m
.00375 .18592 L
s
0 .21041 m
.00375 .21041 L
s
0 .23491 m
.00375 .23491 L
s
0 .28389 m
.00375 .28389 L
s
0 .30838 m
.00375 .30838 L
s
0 .33287 m
.00375 .33287 L
s
0 .35737 m
.00375 .35737 L
s
0 .40635 m
.00375 .40635 L
s
0 .43084 m
.00375 .43084 L
s
0 .45533 m
.00375 .45533 L
s
0 .47983 m
.00375 .47983 L
s
0 .52881 m
.00375 .52881 L
s
0 .5533 m
.00375 .5533 L
s
0 .57779 m
.00375 .57779 L
s
0 .60229 m
.00375 .60229 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02331 .61178 m
.02331 .61803 L
s
.27146 .61178 m
.27146 .61803 L
s
.5196 .61178 m
.5196 .61803 L
s
.76775 .61178 m
.76775 .61803 L
s
.125 Mabswid
.07294 .61428 m
.07294 .61803 L
s
.12257 .61428 m
.12257 .61803 L
s
.1722 .61428 m
.1722 .61803 L
s
.22183 .61428 m
.22183 .61803 L
s
.32109 .61428 m
.32109 .61803 L
s
.37072 .61428 m
.37072 .61803 L
s
.42035 .61428 m
.42035 .61803 L
s
.46997 .61428 m
.46997 .61803 L
s
.56923 .61428 m
.56923 .61803 L
s
.61886 .61428 m
.61886 .61803 L
s
.66849 .61428 m
.66849 .61803 L
s
.71812 .61428 m
.71812 .61803 L
s
.81738 .61428 m
.81738 .61803 L
s
.86701 .61428 m
.86701 .61803 L
s
.91664 .61428 m
.91664 .61803 L
s
.96626 .61428 m
.96626 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01448 m
1 .01448 L
s
.99375 .13694 m
1 .13694 L
s
.99375 .2594 m
1 .2594 L
s
.99375 .38186 m
1 .38186 L
s
.99375 .50432 m
1 .50432 L
s
.125 Mabswid
.99625 .03897 m
1 .03897 L
s
.99625 .06346 m
1 .06346 L
s
.99625 .08795 m
1 .08795 L
s
.99625 .11245 m
1 .11245 L
s
.99625 .16143 m
1 .16143 L
s
.99625 .18592 m
1 .18592 L
s
.99625 .21041 m
1 .21041 L
s
.99625 .23491 m
1 .23491 L
s
.99625 .28389 m
1 .28389 L
s
.99625 .30838 m
1 .30838 L
s
.99625 .33287 m
1 .33287 L
s
.99625 .35737 m
1 .35737 L
s
.99625 .40635 m
1 .40635 L
s
.99625 .43084 m
1 .43084 L
s
.99625 .45533 m
1 .45533 L
s
.99625 .47983 m
1 .47983 L
s
.99625 .52881 m
1 .52881 L
s
.99625 .5533 m
1 .5533 L
s
.99625 .57779 m
1 .57779 L
s
.99625 .60229 m
1 .60229 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01482 m
.02431 .01472 L
.0248 .01535 L
.0253 .01613 L
.02579 .01619 L
.02629 .01567 L
.02679 .01502 L
.02728 .01518 L
.02778 .01569 L
.02828 .01708 L
.02877 .01714 L
.02927 .01614 L
.02977 .03853 L
.03026 .07714 L
.03076 .24206 L
.03125 .36131 L
.03175 .38139 L
.03225 .35605 L
.03274 .33707 L
.03324 .32116 L
.03374 .31334 L
.03423 .30642 L
.03473 .29821 L
.03522 .29612 L
.03572 .31852 L
.03622 .33326 L
.03671 .33064 L
.03721 .33565 L
.03771 .34084 L
.0382 .33259 L
.0387 .32414 L
.03919 .32319 L
.03969 .3237 L
.04019 .32446 L
.04068 .33185 L
.04118 .35133 L
.04168 .37869 L
.04217 .40487 L
.04267 .42209 L
.04316 .43713 L
.04366 .45053 L
.04416 .45798 L
.04465 .46782 L
.04515 .46986 L
.04565 .453 L
.04614 .4214 L
.04664 .38758 L
.04714 .35446 L
.04763 .31555 L
.04813 .27451 L
Mistroke
.04862 .2386 L
.04912 .21893 L
.04962 .21888 L
.05011 .2432 L
.05061 .28329 L
.05111 .33575 L
.0516 .37899 L
.0521 .39935 L
.05259 .40244 L
.05309 .40341 L
.05359 .41052 L
.05408 .40932 L
.05458 .394 L
.05508 .37011 L
.05557 .34131 L
.05607 .30361 L
.05656 .2679 L
.05706 .25434 L
.05756 .29227 L
.05805 .35913 L
.05855 .40419 L
.05905 .40399 L
.05954 .36571 L
.06004 .32704 L
.06054 .35749 L
.06103 .45423 L
.06153 .54058 L
.06202 .57995 L
.06252 .58714 L
.06302 .57619 L
.06351 .55417 L
.06401 .52624 L
.06451 .48618 L
.065 .43205 L
.0655 .36196 L
.06599 .29421 L
.06649 .26995 L
.06699 .29398 L
.06748 .32612 L
.06798 .36024 L
.06848 .37756 L
.06897 .3537 L
.06947 .31649 L
.06996 .31612 L
.07046 .34842 L
.07096 .34683 L
.07145 .31998 L
.07195 .30853 L
.07245 .31247 L
.07294 .30667 L
Mistroke
.07344 .27664 L
.07393 .22585 L
.07443 .17833 L
.07493 .16945 L
.07542 .22215 L
.07592 .30844 L
.07642 .37086 L
.07691 .39643 L
.07741 .38415 L
.07791 .33372 L
.0784 .2799 L
.0789 .26451 L
.07939 .29695 L
.07989 .34115 L
.08039 .38601 L
.08088 .43311 L
.08138 .47683 L
.08188 .50106 L
.08237 .48523 L
.08287 .42136 L
.08336 .3275 L
.08386 .24507 L
.08436 .19901 L
.08485 .21226 L
.08535 .2588 L
.08585 .30726 L
.08634 .33213 L
.08684 .32239 L
.08733 .31271 L
.08783 .32247 L
.08833 .32866 L
.08882 .30929 L
.08932 .2788 L
.08982 .26735 L
.09031 .2735 L
.09081 .26635 L
.0913 .24102 L
.0918 .20942 L
.0923 .18529 L
.09279 .18402 L
.09329 .22242 L
.09379 .28659 L
.09428 .33628 L
.09478 .36676 L
.09528 .37269 L
.09577 .35358 L
.09627 .32258 L
.09676 .29743 L
.09726 .29335 L
.09776 .31376 L
Mistroke
.09825 .34663 L
.09875 .38698 L
.09925 .4281 L
.09974 .45621 L
.10024 .45076 L
.10073 .40372 L
.10123 .32713 L
.10173 .24547 L
.10222 .17891 L
.10272 .15398 L
.10322 .18841 L
.10371 .23848 L
.10421 .27592 L
.1047 .29605 L
.1052 .30349 L
.1057 .31643 L
.10619 .32643 L
.10669 .30148 L
.10719 .25286 L
.10768 .23259 L
.10818 .24503 L
.10868 .24166 L
.10917 .22374 L
.10967 .21256 L
.11016 .21199 L
.11066 .2146 L
.11116 .22911 L
.11165 .24932 L
.11215 .26415 L
.11265 .27037 L
.11314 .2579 L
.11364 .2315 L
.11413 .20262 L
.11463 .18074 L
.11513 .1666 L
.11562 .16606 L
.11612 .18707 L
.11662 .22885 L
.11711 .26839 L
.11761 .28412 L
.1181 .27732 L
.1186 .24456 L
.1191 .20019 L
.11959 .16741 L
.12009 .15894 L
.12059 .15602 L
.12108 .15317 L
.12158 .15573 L
.12207 .15671 L
.12257 .14942 L
Mistroke
.12307 .13651 L
.12356 .12445 L
.12406 .11047 L
.12456 .09163 L
.12505 .07479 L
.12555 .066 L
.12605 .06847 L
.12654 .07836 L
.12704 .08603 L
.12753 .0768 L
.12803 .23661 L
.12853 .35554 L
.12902 .37018 L
.12952 .3641 L
.13002 .35862 L
.13051 .37712 L
.13101 .4198 L
.1315 .45505 L
.132 .44715 L
.1325 .41991 L
.13299 .39526 L
.13349 .38895 L
.13399 .34896 L
.13448 .3128 L
.13498 .29287 L
.13547 .29892 L
.13597 .24956 L
.13647 .21728 L
.13696 .19548 L
.13746 .1777 L
.13796 .15643 L
.13845 .13993 L
.13895 .12185 L
.13945 .11572 L
.13994 .12008 L
.14044 .12033 L
.14093 .1129 L
.14143 .1003 L
.14193 .09168 L
.14242 .08355 L
.14292 .08671 L
.14342 .08236 L
.14391 .07568 L
.14441 .06889 L
.1449 .08391 L
.1454 .1848 L
.1459 .23527 L
.14639 .22122 L
.14689 .22245 L
.14739 .23304 L
Mistroke
.14788 .24528 L
.14838 .24145 L
.14887 .23041 L
.14937 .21598 L
.14987 .2188 L
.15036 .22424 L
.15086 .22934 L
.15136 .21788 L
.15185 .20441 L
.15235 .20709 L
.15284 .21299 L
.15334 .19977 L
.15384 .17237 L
.15433 .15271 L
.15483 .14801 L
.15533 .15441 L
.15582 .15348 L
.15632 .14544 L
.15682 .13288 L
.15731 .13749 L
.15781 .13714 L
.1583 .12658 L
.1588 .12015 L
.1593 .11455 L
.15979 .16627 L
.16029 .3238 L
.16079 .38741 L
.16128 .43301 L
.16178 .44229 L
.16227 .45158 L
.16277 .4269 L
.16327 .39469 L
.16376 .37152 L
.16426 .36122 L
.16476 .36987 L
.16525 .33568 L
.16575 .33876 L
.16624 .31922 L
.16674 .29866 L
.16724 .2561 L
.16773 .25704 L
.16823 .23356 L
.16873 .1675 L
.16922 .10796 L
.16972 .10328 L
.17022 .15323 L
.17071 .15901 L
.17121 .15749 L
.1717 .14494 L
.1722 .13758 L
Mistroke
.1727 .13848 L
.17319 .15502 L
.17369 .16596 L
.17419 .1375 L
.17468 .18378 L
.17518 .19345 L
.17567 .21796 L
.17617 .22176 L
.17667 .23599 L
.17716 .23785 L
.17766 .24922 L
.17816 .26024 L
.17865 .26215 L
.17915 .25976 L
.17964 .2335 L
.18014 .20896 L
.18064 .17356 L
.18113 .14494 L
.18163 .1249 L
.18213 .12848 L
.18262 .13644 L
.18312 .14006 L
.18361 .12904 L
.18411 .11241 L
.18461 .09223 L
.1851 .07791 L
.1856 .07695 L
.1861 .07512 L
.18659 .08953 L
.18709 .09577 L
.18759 .10105 L
.18808 .08217 L
.18858 .09261 L
.18907 .20944 L
.18957 .29343 L
.19007 .34885 L
.19056 .38091 L
.19106 .39347 L
.19156 .35686 L
.19205 .34746 L
.19255 .31278 L
.19304 .29015 L
.19354 .25692 L
.19404 .2544 L
.19453 .21987 L
.19503 .20696 L
.19553 .18517 L
.19602 .17969 L
.19652 .13671 L
.19701 .095 L
Mistroke
.19751 .07463 L
.19801 .07444 L
.1985 .06678 L
.199 .07051 L
.1995 .07235 L
.19999 .07688 L
.20049 .09108 L
.20099 .08546 L
.20148 .0812 L
.20198 .08028 L
.20247 .11455 L
.20297 .1538 L
.20347 .19556 L
.20396 .22255 L
.20446 .22632 L
.20496 .23109 L
.20545 .22303 L
.20595 .2188 L
.20644 .23535 L
.20694 .23844 L
.20744 .24072 L
.20793 .22558 L
.20843 .19485 L
.20893 .15772 L
.20942 .11264 L
.20992 .06818 L
.21041 .0881 L
.21091 .0983 L
.21141 .0969 L
.2119 .09376 L
.2124 .09779 L
.2129 .09772 L
.21339 .11045 L
.21389 .11964 L
.21438 .12078 L
.21488 .10873 L
.21538 .1044 L
.21587 .1275 L
.21637 .16533 L
.21687 .24907 L
.21736 .26978 L
.21786 .28936 L
.21836 .27836 L
.21885 .27865 L
.21935 .2672 L
.21984 .26835 L
.22034 .23222 L
.22084 .23281 L
.22133 .20802 L
.22183 .2044 L
Mistroke
.22233 .1701 L
.22282 .16677 L
.22332 .14863 L
.22381 .13429 L
.22431 .11224 L
.22481 .09805 L
.2253 .0893 L
.2258 .08792 L
.2263 .08293 L
.22679 .07744 L
.22729 .08376 L
.22778 .09069 L
.22828 .09592 L
.22878 .09667 L
.22927 .08215 L
.22977 .1387 L
.23027 .21497 L
.23076 .24602 L
.23126 .25571 L
.23176 .27132 L
.23225 .27347 L
.23275 .2811 L
.23324 .28796 L
.23374 .29569 L
.23424 .28135 L
.23473 .26583 L
.23523 .23612 L
.23573 .19079 L
.23622 .14746 L
.23672 .10591 L
.23721 .07903 L
.23771 .11778 L
.23821 .12811 L
.2387 .11405 L
.2392 .09734 L
.2397 .07933 L
.24019 .06719 L
.24069 .07385 L
.24118 .0753 L
.24168 .07384 L
.24218 .08212 L
.24267 .08818 L
.24317 .16621 L
.24367 .27533 L
.24416 .33158 L
.24466 .32474 L
.24515 .30245 L
.24565 .26905 L
.24615 .27212 L
.24664 .28016 L
Mistroke
.24714 .29199 L
.24764 .29815 L
.24813 .31966 L
.24863 .33237 L
.24913 .31995 L
.24962 .26333 L
.25012 .20832 L
.25061 .1926 L
.25111 .18981 L
.25161 .17488 L
.2521 .17507 L
.2526 .14111 L
.2531 .10775 L
.25359 .10313 L
.25409 .10779 L
.25458 .09632 L
.25508 .09393 L
.25558 .0784 L
.25607 .08508 L
.25657 .12795 L
.25707 .17085 L
.25756 .19547 L
.25806 .20004 L
.25855 .21713 L
.25905 .22509 L
.25955 .22153 L
.26004 .21483 L
.26054 .21183 L
.26104 .20804 L
.26153 .21121 L
.26203 .20801 L
.26253 .19454 L
.26302 .15633 L
.26352 .09924 L
.26401 .07055 L
.26451 .08685 L
.26501 .103 L
.2655 .0939 L
.266 .08925 L
.2665 .08995 L
.26699 .09381 L
.26749 .08465 L
.26798 .07447 L
.26848 .0675 L
.26898 .05432 L
.26947 .04773 L
.26997 .06139 L
.27047 .09108 L
.27096 .13463 L
.27146 .17465 L
Mistroke
.27195 .19189 L
.27245 .19659 L
.27295 .19484 L
.27344 .20872 L
.27394 .20059 L
.27444 .18499 L
.27493 .17472 L
.27543 .1815 L
.27592 .18164 L
.27642 .15988 L
.27692 .15101 L
.27741 .13114 L
.27791 .12811 L
.27841 .14126 L
.2789 .12792 L
.2794 .12205 L
.2799 .10203 L
.28039 .08277 L
.28089 .06958 L
.28138 .08365 L
.28188 .0978 L
.28238 .09405 L
.28287 .15406 L
.28337 .23893 L
.28387 .29751 L
.28436 .31578 L
.28486 .31634 L
.28535 .30779 L
.28585 .29898 L
.28635 .27554 L
.28684 .25713 L
.28734 .2442 L
.28784 .22925 L
.28833 .20527 L
.28883 .18014 L
.28932 .15375 L
.28982 .11596 L
.29032 .09414 L
.29081 .09567 L
.29131 .10713 L
.29181 .10076 L
.2923 .09865 L
.2928 .09435 L
.2933 .09256 L
.29379 .0854 L
.29429 .08679 L
.29478 .0761 L
.29528 .06774 L
.29578 .05326 L
.29627 .06033 L
Mistroke
.29677 .1802 L
.29727 .28359 L
.29776 .36511 L
.29826 .37305 L
.29875 .38876 L
.29925 .33925 L
.29975 .33531 L
.30024 .2977 L
.30074 .27247 L
.30124 .25195 L
.30173 .24279 L
.30223 .2156 L
.30272 .20638 L
.30322 .18222 L
.30372 .14697 L
.30421 .12004 L
.30471 .10759 L
.30521 .09619 L
.3057 .09856 L
.3062 .09047 L
.30669 .08731 L
.30719 .0775 L
.30769 .07893 L
.30818 .07944 L
.30868 .07477 L
.30918 .08357 L
.30967 .12716 L
.31017 .15019 L
.31067 .15457 L
.31116 .15913 L
.31166 .17277 L
.31215 .18735 L
.31265 .21764 L
.31315 .23236 L
.31364 .23928 L
.31414 .24868 L
.31464 .26198 L
.31513 .25744 L
.31563 .24576 L
.31612 .20898 L
.31662 .15924 L
.31712 .11686 L
.31761 .09177 L
.31811 .09028 L
.31861 .10395 L
.3191 .10721 L
.3196 .08288 L
.32009 .07894 L
.32059 .09286 L
.32109 .11048 L
Mistroke
.32158 .11222 L
.32208 .09855 L
.32258 .09662 L
.32307 .0857 L
.32357 .0649 L
.32407 .05247 L
.32456 .06843 L
.32506 .13787 L
.32555 .18187 L
.32605 .18871 L
.32655 .17036 L
.32704 .16127 L
.32754 .14879 L
.32804 .15883 L
.32853 .13413 L
.32903 .1357 L
.32952 .12518 L
.33002 .12666 L
.33052 .11618 L
.33101 .11552 L
.33151 .09948 L
.33201 .11801 L
.3325 .13639 L
.333 .14418 L
.33349 .13319 L
.33399 .11692 L
.33449 .10766 L
.33498 .10255 L
.33548 .1105 L
.33598 .10264 L
.33647 .08718 L
.33697 .06624 L
.33746 .16322 L
.33796 .22106 L
.33846 .2581 L
.33895 .27075 L
.33945 .26136 L
.33995 .26283 L
.34044 .25622 L
.34094 .25638 L
.34144 .26823 L
.34193 .27146 L
.34243 .26171 L
.34292 .23478 L
.34342 .18646 L
.34392 .14426 L
.34441 .11386 L
.34491 .13549 L
.34541 .14217 L
.3459 .13489 L
Mistroke
.3464 .11596 L
.34689 .09456 L
.34739 .06532 L
.34789 .04782 L
.34838 .04256 L
.34888 .03921 L
.34938 .04785 L
.34987 .05619 L
.35037 .06245 L
.35086 .06891 L
.35136 .08662 L
.35186 .15834 L
.35235 .2887 L
.35285 .36729 L
.35335 .38046 L
.35384 .34586 L
.35434 .30538 L
.35484 .27625 L
.35533 .24924 L
.35583 .21952 L
.35632 .19854 L
.35682 .17336 L
.35732 .18148 L
.35781 .19372 L
.35831 .18261 L
.35881 .20133 L
.3593 .21383 L
.3598 .18351 L
.36029 .1245 L
.36079 .07544 L
.36129 .07742 L
.36178 .08031 L
.36228 .07774 L
.36278 .07764 L
.36327 .09278 L
.36377 .09027 L
.36426 .10437 L
.36476 .18609 L
.36526 .23754 L
.36575 .24701 L
.36625 .25361 L
.36675 .26203 L
.36724 .26308 L
.36774 .25966 L
.36823 .25904 L
.36873 .26771 L
.36923 .26976 L
.36972 .26711 L
.37022 .25745 L
.37072 .23436 L
Mistroke
.37121 .1891 L
.37171 .1356 L
.37221 .09481 L
.3727 .09174 L
.3732 .1033 L
.37369 .10758 L
.37419 .09194 L
.37469 .07057 L
.37518 .06214 L
.37568 .07905 L
.37618 .09395 L
.37667 .08937 L
.37717 .07542 L
.37766 .07445 L
.37816 .08212 L
.37866 .08438 L
.37915 .11172 L
.37965 .18063 L
.38015 .19573 L
.38064 .21365 L
.38114 .19485 L
.38163 .19726 L
.38213 .17628 L
.38263 .18416 L
.38312 .1972 L
.38362 .21144 L
.38412 .20064 L
.38461 .21627 L
.38511 .2098 L
.38561 .21916 L
.3861 .18913 L
.3866 .17205 L
.38709 .13656 L
.38759 .13203 L
.38809 .1391 L
.38858 .14131 L
.38908 .12496 L
.38958 .10859 L
.39007 .09307 L
.39057 .08232 L
.39106 .07643 L
.39156 .12313 L
.39206 .16518 L
.39255 .21395 L
.39305 .22729 L
.39355 .22206 L
.39404 .22916 L
.39454 .233 L
.39503 .23608 L
.39553 .2354 L
Mistroke
.39603 .23631 L
.39652 .23248 L
.39702 .22851 L
.39752 .20759 L
.39801 .1813 L
.39851 .15398 L
.399 .11913 L
.3995 .11225 L
.4 .12653 L
.40049 .11964 L
.40099 .11019 L
.40149 .10761 L
.40198 .08305 L
.40248 .06348 L
.40298 .04465 L
.40347 .0372 L
.40397 .0406 L
.40446 .05076 L
.40496 .04555 L
.40546 .04826 L
.40595 .10051 L
.40645 .13038 L
.40695 .20212 L
.40744 .32724 L
.40794 .41135 L
.40843 .42188 L
.40893 .40157 L
.40943 .40417 L
.40992 .40604 L
.41042 .36646 L
.41092 .31482 L
.41141 .26688 L
.41191 .22579 L
.4124 .18086 L
.4129 .14238 L
.4134 .15758 L
.41389 .2222 L
.41439 .23844 L
.41489 .20124 L
.41538 .15229 L
.41588 .17649 L
.41638 .2061 L
.41687 .20854 L
.41737 .19206 L
.41786 .15158 L
.41836 .11422 L
.41886 .09978 L
.41935 .13101 L
.41985 .17909 L
.42035 .30409 L
Mistroke
.42084 .30965 L
.42134 .30605 L
.42183 .28565 L
.42233 .26557 L
.42283 .2601 L
.42332 .26138 L
.42382 .29009 L
.42432 .28441 L
.42481 .24423 L
.42531 .26015 L
.4258 .25214 L
.4263 .22338 L
.4268 .18361 L
.42729 .13912 L
.42779 .12445 L
.42829 .19795 L
.42878 .23425 L
.42928 .21943 L
.42977 .2008 L
.43027 .18221 L
.43077 .17004 L
.43126 .16322 L
.43176 .18729 L
.43226 .20873 L
.43275 .19972 L
.43325 .20469 L
.43375 .21381 L
.43424 .21439 L
.43474 .1673 L
.43523 .14425 L
.43573 .20886 L
.43623 .32833 L
.43672 .34228 L
.43722 .36315 L
.43772 .31921 L
.43821 .28653 L
.43871 .2894 L
.4392 .26675 L
.4397 .21897 L
.4402 .19951 L
.44069 .14907 L
.44119 .15852 L
.44169 .15432 L
.44218 .16238 L
.44268 .12674 L
.44317 .08494 L
.44367 .09078 L
.44417 .11478 L
.44466 .10126 L
.44516 .07535 L
Mistroke
.44566 .07175 L
.44615 .11126 L
.44665 .12645 L
.44715 .14352 L
.44764 .20847 L
.44814 .27752 L
.44863 .27653 L
.44913 .23394 L
.44963 .26999 L
.45012 .31252 L
.45062 .34207 L
.45112 .39226 L
.45161 .38628 L
.45211 .39418 L
.4526 .37811 L
.4531 .34543 L
.4536 .34147 L
.45409 .30639 L
.45459 .24601 L
.45509 .17965 L
.45558 .19334 L
.45608 .25269 L
.45657 .24538 L
.45707 .21399 L
.45757 .17021 L
.45806 .14158 L
.45856 .13078 L
.45906 .14792 L
.45955 .17388 L
.46005 .17538 L
.46054 .16736 L
.46104 .17458 L
.46154 .1574 L
.46203 .15277 L
.46253 .1636 L
.46303 .16266 L
.46352 .16292 L
.46402 .17882 L
.46452 .18097 L
.46501 .18434 L
.46551 .15958 L
.466 .15053 L
.4665 .14947 L
.467 .15266 L
.46749 .17386 L
.46799 .15807 L
.46849 .15781 L
.46898 .13897 L
.46948 .12224 L
.46997 .09221 L
Mistroke
.47047 .08887 L
.47097 .08944 L
.47146 .11116 L
.47196 .12459 L
.47246 .10622 L
.47295 .07959 L
.47345 .07953 L
.47394 .07376 L
.47444 .08378 L
.47494 .15004 L
.47543 .31299 L
.47593 .37262 L
.47643 .39885 L
.47692 .42815 L
.47742 .40518 L
.47792 .37222 L
.47841 .40736 L
.47891 .41657 L
.4794 .37942 L
.4799 .33653 L
.4804 .34207 L
.48089 .32803 L
.48139 .25791 L
.48189 .17501 L
.48238 .19579 L
.48288 .23047 L
.48337 .24803 L
.48387 .22537 L
.48437 .17856 L
.48486 .14653 L
.48536 .10782 L
.48586 .1027 L
.48635 .14952 L
.48685 .14893 L
.48734 .14802 L
.48784 .12039 L
.48834 .12811 L
.48883 .14297 L
.48933 .15923 L
.48983 .13809 L
.49032 .15774 L
.49082 .21644 L
.49131 .25047 L
.49181 .26206 L
.49231 .27958 L
.4928 .2706 L
.4933 .26328 L
.4938 .26421 L
.49429 .25559 L
.49479 .23868 L
Mistroke
.49529 .19254 L
.49578 .14184 L
.49628 .12252 L
.49677 .12931 L
.49727 .12102 L
.49777 .10744 L
.49826 .07744 L
.49876 .08949 L
.49926 .11419 L
.49975 .13053 L
.50025 .12711 L
.50074 .12012 L
.50124 .10578 L
.50174 .13701 L
.50223 .18522 L
.50273 .20661 L
.50323 .21156 L
.50372 .19426 L
.50422 .19662 L
.50471 .17855 L
.50521 .13995 L
.50571 .14139 L
.5062 .14251 L
.5067 .12257 L
.5072 .10575 L
.50769 .10903 L
.50819 .11943 L
.50869 .1012 L
.50918 .09401 L
.50968 .10052 L
.51017 .0924 L
.51067 .08651 L
.51117 .08478 L
.51166 .07514 L
.51216 .06292 L
.51266 .06341 L
.51315 .04592 L
.51365 .0559 L
.51414 .064 L
.51464 .06299 L
.51514 .05565 L
.51563 .09042 L
.51613 .08875 L
.51663 .10366 L
.51712 .13842 L
.51762 .14662 L
.51811 .1413 L
.51861 .1489 L
.51911 .18207 L
.5196 .20856 L
Mistroke
.5201 .22845 L
.5206 .2387 L
.52109 .24322 L
.52159 .22164 L
.52208 .23927 L
.52258 .24832 L
.52308 .21848 L
.52357 .18196 L
.52407 .18917 L
.52457 .19148 L
.52506 .17711 L
.52556 .18226 L
.52606 .19235 L
.52655 .18297 L
.52705 .18147 L
.52754 .17017 L
.52804 .15876 L
.52854 .13727 L
.52903 .19294 L
.52953 .27764 L
.53003 .27149 L
.53052 .27232 L
.53102 .29102 L
.53151 .2348 L
.53201 .20327 L
.53251 .20246 L
.533 .21571 L
.5335 .21596 L
.534 .18225 L
.53449 .17723 L
.53499 .1839 L
.53548 .16273 L
.53598 .17073 L
.53648 .18112 L
.53697 .15532 L
.53747 .18463 L
.53797 .20295 L
.53846 .18617 L
.53896 .18076 L
.53946 .18107 L
.53995 .15709 L
.54045 .11991 L
.54094 .12982 L
.54144 .12532 L
.54194 .10687 L
.54243 .1088 L
.54293 .11625 L
.54343 .12626 L
.54392 .11071 L
.54442 .13206 L
Mistroke
.54491 .13226 L
.54541 .08833 L
.54591 .10536 L
.5464 .1498 L
.5469 .14823 L
.5474 .16401 L
.54789 .20959 L
.54839 .20611 L
.54888 .1866 L
.54938 .20853 L
.54988 .22464 L
.55037 .17104 L
.55087 .14834 L
.55137 .12896 L
.55186 .12294 L
.55236 .11718 L
.55285 .124 L
.55335 .09541 L
.55385 .07663 L
.55434 .06753 L
.55484 .06799 L
.55534 .07874 L
.55583 .11128 L
.55633 .10423 L
.55683 .11848 L
.55732 .11491 L
.55782 .08504 L
.55831 .07906 L
.55881 .07443 L
.55931 .10352 L
.5598 .09247 L
.5603 .06867 L
.5608 .1038 L
.56129 .10986 L
.56179 .11385 L
.56228 .13447 L
.56278 .11808 L
.56328 .12281 L
.56377 .12639 L
.56427 .11884 L
.56477 .14426 L
.56526 .14119 L
.56576 .12286 L
.56625 .1041 L
.56675 .09144 L
.56725 .10194 L
.56774 .08952 L
.56824 .06507 L
.56874 .06828 L
.56923 .06028 L
Mistroke
.56973 .06774 L
.57023 .08241 L
.57072 .10181 L
.57122 .09164 L
.57171 .09913 L
.57221 .09348 L
.57271 .10126 L
.5732 .08613 L
.5737 .09081 L
.5742 .08626 L
.57469 .09975 L
.57519 .11165 L
.57568 .10601 L
.57618 .10141 L
.57668 .0966 L
.57717 .09087 L
.57767 .08084 L
.57817 .06346 L
.57866 .0529 L
.57916 .07231 L
.57965 .06474 L
.58015 .06496 L
.58065 .07007 L
.58114 .05562 L
.58164 .10117 L
.58214 .19136 L
.58263 .2533 L
.58313 .30497 L
.58362 .31001 L
.58412 .29297 L
.58462 .25644 L
.58511 .24662 L
.58561 .27534 L
.58611 .28428 L
.5866 .27919 L
.5871 .3011 L
.5876 .28969 L
.58809 .25981 L
.58859 .26864 L
.58908 .26293 L
.58958 .26754 L
.59008 .27223 L
.59057 .22762 L
.59107 .16886 L
.59157 .15946 L
.59206 .15549 L
.59256 .16979 L
.59305 .19169 L
.59355 .18748 L
.59405 .1411 L
Mistroke
.59454 .1089 L
.59504 .10857 L
.59554 .10773 L
.59603 .12265 L
.59653 .12824 L
.59702 .12232 L
.59752 .11767 L
.59802 .11826 L
.59851 .118 L
.59901 .11346 L
.59951 .12792 L
.6 .14379 L
.6005 .13324 L
.601 .13846 L
.60149 .14717 L
.60199 .1396 L
.60248 .11371 L
.60298 .07116 L
.60348 .05071 L
.60397 .05216 L
.60447 .05067 L
.60497 .05312 L
.60546 .05381 L
.60596 .05584 L
.60645 .06602 L
.60695 .079 L
.60745 .08948 L
.60794 .066 L
.60844 .10331 L
.60894 .14861 L
.60943 .15682 L
.60993 .14873 L
.61042 .14517 L
.61092 .15223 L
.61142 .13366 L
.61191 .1203 L
.61241 .11934 L
.61291 .11631 L
.6134 .10125 L
.6139 .10817 L
.61439 .11606 L
.61489 .09287 L
.61539 .07261 L
.61588 .08286 L
.61638 .08127 L
.61688 .06297 L
.61737 .06197 L
.61787 .07674 L
.61837 .06735 L
.61886 .05342 L
Mistroke
.61936 .04462 L
.61985 .04011 L
.62035 .04216 L
.62085 .04728 L
.62134 .04305 L
.62184 .05409 L
.62234 .06745 L
.62283 .08416 L
.62333 .13599 L
.62382 .18144 L
.62432 .19684 L
.62482 .19393 L
.62531 .17208 L
.62581 .17078 L
.62631 .18874 L
.6268 .18225 L
.6273 .17589 L
.62779 .19033 L
.62829 .19079 L
.62879 .16536 L
.62928 .11906 L
.62978 .08646 L
.63028 .06898 L
.63077 .07141 L
.63127 .09012 L
.63177 .09022 L
.63226 .09173 L
.63276 .08608 L
.63325 .07011 L
.63375 .05448 L
.63425 .05056 L
.63474 .05634 L
.63524 .05709 L
.63574 .10749 L
.63623 .14822 L
.63673 .16465 L
.63722 .1729 L
.63772 .18459 L
.63822 .19245 L
.63871 .18908 L
.63921 .2019 L
.63971 .21693 L
.6402 .23287 L
.6407 .24049 L
.64119 .23906 L
.64169 .23093 L
.64219 .19271 L
.64268 .15177 L
.64318 .11006 L
.64368 .10009 L
Mistroke
.64417 .12124 L
.64467 .12606 L
.64516 .11886 L
.64566 .10266 L
.64616 .10093 L
.64665 .11335 L
.64715 .12084 L
.64765 .11633 L
.64814 .10989 L
.64864 .12261 L
.64914 .14782 L
.64963 .17808 L
.65013 .19519 L
.65062 .21451 L
.65112 .20934 L
.65162 .2084 L
.65211 .20416 L
.65261 .18248 L
.65311 .17616 L
.6536 .16947 L
.6541 .15327 L
.65459 .14952 L
.65509 .15472 L
.65559 .1435 L
.65608 .14285 L
.65658 .13439 L
.65708 .11817 L
.65757 .10717 L
.65807 .10542 L
.65856 .09829 L
.65906 .08923 L
.65956 .08235 L
.66005 .08002 L
.66055 .07842 L
.66105 .08271 L
.66154 .07385 L
.66204 .07803 L
.66254 .08937 L
.66303 .12618 L
.66353 .25864 L
.66402 .31923 L
.66452 .30198 L
.66502 .31282 L
.66551 .30472 L
.66601 .2593 L
.66651 .25062 L
.667 .25331 L
.6675 .20516 L
.66799 .18307 L
.66849 .20498 L
Mistroke
.66899 .20375 L
.66948 .19556 L
.66998 .17746 L
.67048 .16659 L
.67097 .18086 L
.67147 .18044 L
.67196 .1491 L
.67246 .09734 L
.67296 .08978 L
.67345 .09944 L
.67395 .11546 L
.67445 .09672 L
.67494 .10035 L
.67544 .09956 L
.67593 .1088 L
.67643 .11752 L
.67693 .12532 L
.67742 .16077 L
.67792 .2323 L
.67842 .22983 L
.67891 .18716 L
.67941 .21149 L
.67991 .21926 L
.6804 .2316 L
.6809 .22298 L
.68139 .19196 L
.68189 .18774 L
.68239 .19318 L
.68288 .27619 L
.68338 .30546 L
.68388 .2451 L
.68437 .19058 L
.68487 .23197 L
.68536 .20899 L
.68586 .142 L
.68636 .09715 L
.68685 .09394 L
.68735 .13186 L
.68785 .16995 L
.68834 .20945 L
.68884 .22539 L
.68933 .22526 L
.68983 .26876 L
.69033 .29999 L
.69082 .27625 L
.69132 .26904 L
.69182 .26607 L
.69231 .25216 L
.69281 .24529 L
.69331 .26363 L
Mistroke
.6938 .24963 L
.6943 .21764 L
.69479 .21373 L
.69529 .1977 L
.69579 .19753 L
.69628 .171 L
.69678 .101 L
.69728 .11596 L
.69777 .14625 L
.69827 .18903 L
.69876 .20532 L
.69926 .17039 L
.69976 .16572 L
.70025 .17895 L
.70075 .16267 L
.70125 .14386 L
.70174 .12571 L
.70224 .12343 L
.70273 .13673 L
.70323 .15109 L
.70373 .22304 L
.70422 .30269 L
.70472 .29772 L
.70522 .2736 L
.70571 .27618 L
.70621 .26086 L
.7067 .24316 L
.7072 .2458 L
.7077 .27434 L
.70819 .2853 L
.70869 .28109 L
.70919 .31091 L
.70968 .28539 L
.71018 .23167 L
.71068 .19974 L
.71117 .16761 L
.71167 .1986 L
.71216 .20011 L
.71266 .18983 L
.71316 .16114 L
.71365 .10944 L
.71415 .104 L
.71465 .08961 L
.71514 .09091 L
.71564 .07403 L
.71613 .11128 L
.71663 .24502 L
.71713 .38026 L
.71762 .46775 L
.71812 .49159 L
Mistroke
.71862 .48129 L
.71911 .46489 L
.71961 .4587 L
.7201 .5314 L
.7206 .60332 L
.7211 .5873 L
.72159 .54671 L
.72209 .57554 L
.72259 .55362 L
.72308 .49046 L
.72358 .42268 L
.72408 .37868 L
.72457 .29751 L
.72507 .23353 L
.72556 .19904 L
.72606 .20576 L
.72656 .17503 L
.72705 .11184 L
.72755 .09443 L
.72805 .05935 L
.72854 .06656 L
.72904 .08018 L
.72953 .10615 L
.73003 .12674 L
.73053 .11855 L
.73102 .10853 L
.73152 .09762 L
.73202 .15382 L
.73251 .26279 L
.73301 .3113 L
.7335 .30106 L
.734 .29952 L
.7345 .29212 L
.73499 .27046 L
.73549 .21676 L
.73599 .16868 L
.73648 .11254 L
.73698 .07417 L
.73747 .0611 L
.73797 .10359 L
.73847 .18407 L
.73896 .21905 L
.73946 .2038 L
.73996 .16502 L
.74045 .14798 L
.74095 .15591 L
.74145 .18043 L
.74194 .20442 L
.74244 .19928 L
.74293 .19591 L
Mistroke
.74343 .19204 L
.74393 .17763 L
.74442 .15203 L
.74492 .11183 L
.74542 .16275 L
.74591 .1978 L
.74641 .21362 L
.7469 .17961 L
.7474 .17378 L
.7479 .16472 L
.74839 .16172 L
.74889 .15532 L
.74939 .14753 L
.74988 .13515 L
.75038 .12459 L
.75087 .12579 L
.75137 .12144 L
.75187 .12974 L
.75236 .11594 L
.75286 .10293 L
.75336 .08717 L
.75385 .09433 L
.75435 .0854 L
.75485 .07732 L
.75534 .07344 L
.75584 .07049 L
.75633 .06351 L
.75683 .04986 L
.75733 .05847 L
.75782 .07472 L
.75832 .06213 L
.75882 .11291 L
.75931 .16817 L
.75981 .19626 L
.7603 .19792 L
.7608 .19591 L
.7613 .19908 L
.76179 .21338 L
.76229 .23052 L
.76279 .237 L
.76328 .24507 L
.76378 .24821 L
.76427 .24237 L
.76477 .22587 L
.76527 .18675 L
.76576 .13954 L
.76626 .13383 L
.76676 .15259 L
.76725 .14884 L
.76775 .13861 L
Mistroke
.76824 .10783 L
.76874 .07912 L
.76924 .04995 L
.76973 .04474 L
.77023 .05912 L
.77073 .08182 L
.77122 .08945 L
.77172 .09022 L
.77222 .08754 L
.77271 .09974 L
.77321 .16537 L
.7737 .26441 L
.7742 .31183 L
.7747 .32016 L
.77519 .33439 L
.77569 .34355 L
.77619 .37088 L
.77668 .39465 L
.77718 .39637 L
.77767 .39417 L
.77817 .35109 L
.77867 .26644 L
.77916 .14858 L
.77966 .12768 L
.78016 .15216 L
.78065 .15967 L
.78115 .14355 L
.78164 .11853 L
.78214 .09914 L
.78264 .07925 L
.78313 .08881 L
.78363 .0966 L
.78413 .0971 L
.78462 .11733 L
.78512 .13701 L
.78562 .13451 L
.78611 .12155 L
.78661 .10578 L
.7871 .09187 L
.7876 .0937 L
.7881 .14766 L
.78859 .19844 L
.78909 .22582 L
.78959 .22318 L
.79008 .21718 L
.79058 .20709 L
.79107 .1755 L
.79157 .14001 L
.79207 .11086 L
.79256 .09407 L
Mistroke
.79306 .08398 L
.79356 .07803 L
.79405 .09711 L
.79455 .15335 L
.79504 .17763 L
.79554 .16305 L
.79604 .13575 L
.79653 .11365 L
.79703 .11926 L
.79753 .12873 L
.79802 .129 L
.79852 .12146 L
.79901 .11744 L
.79951 .11107 L
.80001 .10447 L
.8005 .10075 L
.801 .10385 L
.8015 .12405 L
.80199 .15375 L
.80249 .16422 L
.80299 .13655 L
.80348 .12779 L
.80398 .11077 L
.80447 .1174 L
.80497 .10713 L
.80547 .11446 L
.80596 .09785 L
.80646 .09592 L
.80696 .08953 L
.80745 .10764 L
.80795 .0891 L
.80844 .08352 L
.80894 .06694 L
.80944 .07444 L
.80993 .07031 L
.81043 .06652 L
.81093 .05153 L
.81142 .04463 L
.81192 .04971 L
.81241 .05426 L
.81291 .04808 L
.81341 .04962 L
.8139 .05447 L
.8144 .04692 L
.8149 .05087 L
.81539 .06598 L
.81589 .11065 L
.81639 .15048 L
.81688 .1803 L
.81738 .2063 L
Mistroke
.81787 .2158 L
.81837 .22123 L
.81887 .21511 L
.81936 .22084 L
.81986 .21804 L
.82036 .20241 L
.82085 .18037 L
.82135 .15806 L
.82184 .13114 L
.82234 .11835 L
.82284 .12228 L
.82333 .14011 L
.82383 .14235 L
.82433 .12464 L
.82482 .09774 L
.82532 .07571 L
.82581 .06435 L
.82631 .07419 L
.82681 .07615 L
.8273 .07039 L
.8278 .07474 L
.8283 .08316 L
.82879 .0916 L
.82929 .09053 L
.82978 .08456 L
.83028 .07624 L
.83078 .06749 L
.83127 .06022 L
.83177 .05578 L
.83227 .05573 L
.83276 .1779 L
.83326 .29219 L
.83376 .34441 L
.83425 .35124 L
.83475 .34804 L
.83524 .36232 L
.83574 .38218 L
.83624 .40541 L
.83673 .42359 L
.83723 .42644 L
.83773 .39924 L
.83822 .34703 L
.83872 .28012 L
.83921 .22578 L
.83971 .17631 L
.84021 .14149 L
.8407 .13835 L
.8412 .12603 L
.8417 .0994 L
.84219 .0896 L
Mistroke
.84269 .10808 L
.84318 .1247 L
.84368 .11859 L
.84418 .10435 L
.84467 .09957 L
.84517 .08913 L
.84567 .07352 L
.84616 .0659 L
.84666 .06753 L
.84716 .06908 L
.84765 .06656 L
.84815 .07685 L
.84864 .09804 L
.84914 .1075 L
.84964 .10578 L
.85013 .09921 L
.85063 .09066 L
.85113 .08159 L
.85162 .06595 L
.85212 .04951 L
.85261 .05677 L
.85311 .06546 L
.85361 .06488 L
.8541 .06165 L
.8546 .06526 L
.8551 .07228 L
.85559 .07224 L
.85609 .0657 L
.85658 .05715 L
.85708 .05496 L
.85758 .05418 L
.85807 .05496 L
.85857 .06439 L
.85907 .07312 L
.85956 .07517 L
.86006 .06989 L
.86055 .06484 L
.86105 .05912 L
.86155 .05283 L
.86204 .04664 L
.86254 .04582 L
.86304 .04468 L
.86353 .04048 L
.86403 .04474 L
.86453 .05446 L
.86502 .06121 L
.86552 .06169 L
.86601 .05845 L
.86651 .0568 L
.86701 .05434 L
Mistroke
.8675 .04869 L
.868 .04004 L
.8685 .05173 L
.86899 .07149 L
.86949 .11074 L
.86998 .1608 L
.87048 .20148 L
.87098 .22083 L
.87147 .22069 L
.87197 .21294 L
.87247 .20162 L
.87296 .19469 L
.87346 .19133 L
.87395 .18344 L
.87445 .1718 L
.87495 .15705 L
.87544 .14163 L
.87594 .13218 L
.87644 .13009 L
.87693 .1321 L
.87743 .12724 L
.87793 .11707 L
.87842 .11152 L
.87892 .10712 L
.87941 .09697 L
.87991 .08697 L
.88041 .0865 L
.8809 .09017 L
.8814 .09336 L
.8819 .09419 L
.88239 .08963 L
.88289 .08126 L
.88338 .06916 L
.88388 .0558 L
.88438 .0492 L
.88487 .05424 L
.88537 .05782 L
.88587 .05937 L
.88636 .06591 L
.88686 .07157 L
.88735 .07152 L
.88785 .06852 L
.88835 .06415 L
.88884 .05963 L
.88934 .05782 L
.88984 .05784 L
.89033 .05718 L
.89083 .05554 L
.89132 .05346 L
.89182 .0502 L
Mistroke
.89232 .04674 L
.89281 .04642 L
.89331 .04821 L
.89381 .0505 L
.8943 .05134 L
.8948 .05427 L
.8953 .05794 L
.89579 .05841 L
.89629 .05518 L
.89678 .05031 L
.89728 .04493 L
.89778 .04172 L
.89827 .04226 L
.89877 .04502 L
.89927 .0464 L
.89976 .04557 L
.90026 .04221 L
.90075 .03766 L
.90125 .03582 L
.90175 .03674 L
.90224 .03631 L
.90274 .03418 L
.90324 .03066 L
.90373 .02779 L
.90423 .02558 L
.90472 .02488 L
.90522 .02581 L
.90572 .02571 L
.90621 .02829 L
.90671 .03302 L
.90721 .0341 L
.9077 .03217 L
.9082 .03018 L
.9087 .03062 L
.90919 .03117 L
.90969 .03132 L
.91018 .03078 L
.91068 .03022 L
.91118 .03013 L
.91167 .0308 L
.91217 .03151 L
.91267 .03214 L
.91316 .03166 L
.91366 .03146 L
.91415 .031 L
.91465 .03001 L
.91515 .02866 L
.91564 .02708 L
.91614 .02628 L
.91664 .02746 L
Mistroke
.91713 .02734 L
.91763 .0254 L
.91812 .02352 L
.91862 .02161 L
.91912 .02203 L
.91961 .0242 L
.92011 .0264 L
.92061 .02731 L
.9211 .0268 L
.9216 .02562 L
.92209 .0248 L
.92259 .02429 L
.92309 .02428 L
.92358 .02379 L
.92408 .02341 L
.92458 .02402 L
.92507 .02426 L
.92557 .02512 L
.92607 .02763 L
.92656 .02924 L
.92706 .0291 L
.92755 .02863 L
.92805 .02782 L
.92855 .02718 L
.92904 .02586 L
.92954 .02474 L
.93004 .02312 L
.93053 .0229 L
.93103 .02317 L
.93152 .02203 L
.93202 .02122 L
.93252 .02256 L
.93301 .02304 L
.93351 .02158 L
.93401 .01923 L
.9345 .02019 L
.935 .02176 L
.93549 .02177 L
.93599 .02087 L
.93649 .02054 L
.93698 .02181 L
.93748 .02315 L
.93798 .024 L
.93847 .02487 L
.93897 .02469 L
.93946 .02323 L
.93996 .02251 L
.94046 .02218 L
.94095 .02102 L
.94145 .01907 L
Mistroke
.94195 .01909 L
.94244 .02001 L
.94294 .02015 L
.94344 .01969 L
.94393 .01954 L
.94443 .01977 L
.94492 .02012 L
.94542 .01989 L
.94592 .01949 L
.94641 .01989 L
.94691 .02054 L
.94741 .01972 L
.9479 .01887 L
.9484 .01925 L
.94889 .01853 L
.94939 .01792 L
.94989 .01807 L
.95038 .01804 L
.95088 .0182 L
.95138 .01849 L
.95187 .01954 L
.95237 .02077 L
.95286 .02009 L
.95336 .01898 L
.95386 .02018 L
.95435 .02024 L
.95485 .01991 L
.95535 .01873 L
.95584 .01733 L
.95634 .01731 L
.95684 .0181 L
.95733 .01828 L
.95783 .01799 L
.95832 .01751 L
.95882 .01731 L
.95932 .01822 L
.95981 .02037 L
.96031 .01967 L
.96081 .01849 L
.9613 .01772 L
.9618 .01745 L
.96229 .01751 L
.96279 .01931 L
.96329 .01959 L
.96378 .01844 L
.96428 .01842 L
.96478 .02003 L
.96527 .02039 L
.96577 .02068 L
.96626 .02003 L
Mistroke
.96676 .02018 L
.96726 .02021 L
.96775 .01906 L
.96825 .01913 L
.96875 .01847 L
.96924 .0186 L
.96974 .01851 L
.97023 .01787 L
.97073 .01667 L
.97123 .01662 L
.97172 .01651 L
.97222 .01675 L
.97272 .0166 L
.97321 .01636 L
.97371 .01596 L
.97421 .01661 L
.9747 .01676 L
.9752 .01779 L
.97569 .01844 L
.97619 .01834 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{433, 267.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a00012aP00`40o`000?l0003ooooook;oool0
023oool00`000?ooooooo`1Moooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Doooo1@0000;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
057oool500000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0Eooo
o`007oooo`030000oooo000005goool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Ooool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Coool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Soool001ooool00`000?ooo`00001Ooooo00H0003oooooool0003oool00002oooo00<0
003oool00000Eoooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0
003oool00000E?ooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`0000;oool00`000?oo
o`00001Hoooo000Ooooo00<0003oool00000GOooo`800003oooo00<0003oool000000_ooo`030000
oooo000005Ooool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Coool010000?ooooooooooo`800003oooo00<0003oool000000_ooo`030000oooo0000
05Soool001ooool00`000?ooo`00001Moooo00<0003oooooool00_ooo`030000oooo000000;oool0
0`000?ooo`00001Goooo00L0003oooooooooool0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`00001Doooo00D0003oooooooooool000001?ooo`030000oooo000000;oool00`000?oo
o`00001Hoooo000Poooo00<0003oooooool0G?ooo`<00003oooo00<0003oooooool00_ooo`030000
oooooooo05Goool200001?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool0D_ooo`800003oooo0`0000?oool00`000?ooooooo`02oooo00<0003oooooool0Eoooo`00oooo
ok;oool00?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooo
ok;oool001Oooooo0000VP00007oool001Ooool00`000?ooooooo`06oooo00<0003oooooool04_oo
o`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo
01;oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?oo
ooooo`0Boooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Boooo00<0
003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04_oo
o`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo
00_oool100000Oooo`005oooo`030000oooooooo00Koool00`000?ooooooo`0Boooo00<0003ooooo
ool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04_ooo`030000
oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo01;oool00`000?ooooooo`0A
oooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Boooo00<0003ooooo
ool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool02oooo`400001
oooo000Goooo00<0003oooooool01_ooo`030000oooooooo06?oool00`000?ooooooo`1Roooo00<0
003oooooool0H_ooo`030000oooooooo05coool100000Oooo`003oooo`030000oooooooo00Goool0
0`000?ooooooo`3oooooU_ooo`400001oooo000>oooo00<0003oool000001_ooo`030000oooooooo
0?oooonFoooo0@00007oool000koool00`000?ooo`000006oooo0`0000Ooool2003ooooooh_oool3
00000Oooo`003_ooo`030000oooo000000Koool00`000?ooooooo`07oooo0`00oooooomhoooo00<0
0?ooool00?l00`00o`;oool3003o2Oooo`400001oooo000>oooo00<0003oool000001_ooo`030000
oooooooo00Woool00`00ooooooooo`3oooooKoooo`800?l00oooo`00o`00o`0;003o00?oool00?oo
ool02?ooo`400001oooo000?oooo00<0003oooooool01Oooo`030000oooooooo00Woool00`00oooo
ooooo`3oooooJOooo`03003ooooooooo00;oool3003o00?oool00?ooool00oooo`03003ooooooooo
00;oool00`00ooooooooo`0;oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?oooooo
ool0ooooof?oool00`00ooooooooo`03oooo1`00o`03oooo003ooooo01Ooool100000Oooo`005ooo
o`030000oooooooo00Woool00`00ooooooooo`3oooooHoooo`800?l3oooo00@00?ooool00?ooool2
003o7?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo0?oooomSoooo1P00
o`?oool2003o7?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo0?oooomS
oooo1@00ob;oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`3oooooH_oo
o`03003ooooo003o02Goool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`2F
oooo00<00?ooooooool0b?ooo`03003ooooooooo02Goool100000Oooo`005oooo`80000:oooo00<0
0?ooooooool0Ooooo`03003ooooooooo01Coool00`00ooooooooo`1Eoooo00<00?ooooooool0H_oo
o`03003ooooooooo00[oool00`00ooooooooo`0Uoooo0P00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool0Ooooo`03003ooooooooo01?oool2003oEoooo`03003ooooooooo063oool0
0`00ooooo`00o`0;oooo0P00obSoool100000Oooo`005oooo`030000oooooooo00Woool00`00oooo
ooooo`1ooooo00<00?ooooooool04oooo`800?mGoooo0P00oc_oool00`00ooooooooo`0>oooo00<0
0?ooooooool04_ooo`<00?l;oooo0P00obSoool100000Oooo`005oooo`030000oooooooo00Woool0
0`00ooooooooo`1ooooo00<00?ooooooool04oooo`800?l[oooo00<00?ooooooool0:Oooo`800?lk
oooo00<00?ooooooool03_ooo`800?lCoooo0`00o`Woool01000ooooo`00o`00obSoool100000Ooo
o`005oooo`030000oooooooo00Woool00`00ooooooooo`1Ooooo00<00?ooooooool07Oooo`03003o
oooooooo01?oool2003o:oooo`03003ooooooooo02Woool2003o=_ooo`03003ooooooooo00;oool0
0`00ooooooooo`0>oooo0`00o`koool01000ooooooooooooo`<00?l6oooo00<00?ooooooool00`00
obWoool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`1Ooooo00<00?oooooo
ool07Oooo`03003ooooooooo01?oool2003o:oooo`800?lSoooo0P00o`Goool2003o1?ooo`03003o
oooooooo02ooool00`00ooooooooo`02oooo00<00?ooooooool03_ooo`<00?l>oooo00@00?oooooo
ooooool3003o1_ooo`03003ooooooooo00<00?lYoooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool0Goooo`03003ooooooooo00Soool00`00ooooooooo`08oooo00<00?oooooo
ool01oooo`800?lDoooo0P00ob_oool2003o6Oooo`03003ooooooooo00Ooool2003o1Oooo`800?l4
oooo00<00?ooooooool0;oooo`03003ooooooooo00;oool00`00ooooooooo`0>oooo0`00o`koool0
1000ooooo`00ooooo`<00?l6oooo00<00?ooooooool00`00obWoool100000Oooo`005oooo`030000
oooooooo00Woool00`00ooooooooo`1Ooooo00<00?ooooooool02?ooo`03003ooooooooo00Soool0
0`00ooooooooo`07oooo0P00oaCoool2003o:oooo`800?lIoooo0P00o`Soool2003o1Oooo`800?l4
oooo00<00?ooooooool0;oooo`03003ooooooooo00;oool00`00ooooooooo`0>oooo00<00?ooool0
0?l01Oooo`800?l7oooo00D00?ooool00?l00?ooool00P00o`Koool00`00ooooo`00o`03003o:Ooo
o`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo05ooool00`00ooooooooo`08
oooo00<00?ooooooool02?ooo`03003ooooooooo00Ooool2003o5?ooo`800?l[oooo0P00oaWoool2
003o2?ooo`800?l5oooo0P00o`Coool00`00ooooooooo`0Soooo00<00?ooooooool02Oooo`03003o
oooooooo00;oool00`00ooooooooo`0>oooo00<00?ooool00?l01Oooo`800?l7oooo00D00?ooool0
0?l00?ooool00P00o`Koool3003o00?oool00?l00?l0:Oooo`400001oooo000Goooo00<0003ooooo
ool02Oooo`03003ooooooooo05koool2003o2Oooo`800?l:oooo00<00?ooooooool01oooo`800?l9
oooo00<00?ooooooool02?ooo`800?l[oooo0P00oaGoool01000ooooooooooooo`800?l8oooo0P00
o`Coool00`00ooooo`00o`04oooo00<00?ooooooool08oooo`05003ooooooooooooo003o00Ooool0
0`00ooooooooo`02oooo00<00?ooooooool03_ooo`03003ooooo003o00Goool2003o1oooo`@00?l0
1?ooo`00ooooo`00o`Goool3003o;?ooo`400001oooo000Goooo0P0000[oool00`00ooooooooo`1N
oooo0P00o`Woool2003o2_ooo`03003ooooooooo00Ooool2003o2Oooo`03003ooooooooo00Soool2
003o:oooo`800?lEoooo00@00?ooooooooooool2003o2?ooo`800?l4oooo00<00?ooool00?l00ooo
o`800?lUoooo00D00?ooooooooooool00?l01oooo`03003ooooooooo00;oool00`00ooooooooo`0>
oooo00<00?ooool00?l00oooo`04003ooooo003o003o1oooo`@00?l3oooo00<00?ooooooool00ooo
o`<00?l[oooo0P00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool09?ooo`03003o
oooooooo01_oool00`00ooooooooo`0Ioooo0P00o`Woool2003o2_ooo`03003ooooooooo00;oool0
0`00ooooooooo`02oooo0P00o`Woool00`00ooooooooo`08oooo0P00ob_oool2003o5Oooo`04003o
oooooooooooo0P00o`Soool3003o0oooo`03003ooooo003o00?oool2003o9Oooo`05003ooooooooo
oooo003o00Ooool00`00ooooooooo`02oooo00<00?ooooooool03Oooo`800?l00oooo`00ooooo`02
oooo00@00?ooool00?l00?l4oooo0P00o`03oooo003o003o00800?l3oooo00<00?ooooooool00ooo
o`800?l]oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool09?ooo`03003o
oooooooo00Goool00`00ooooooooo`0Coooo00<00?ooooooool00_ooo`03003ooooooooo00Woool0
0`00ooooooooo`08oooo0P00o`Woool2003o2_ooo`03003ooooooooo00;oool00`00ooooooooo`02
oooo0P00o`Woool00`00ooooooooo`08oooo0P00ob_oool2003o3oooo`04003ooooooooo003o0_oo
o`04003ooooooooooooo0P00o`Soool3003o0oooo`03003ooooo003o00;oool3003o9Oooo`05003o
oooooooooooo003o00Koool2003o1?ooo`03003ooooooooo00goool2003o00?oool00?ooool00_oo
o`04003ooooo003o003o1?ooo`800?l01Oooo`00o`00ooooo`00o`03oooo00<00?ooooooool00ooo
o`800?l]oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool09?ooo`03003o
oooooooo00Goool00`00ooooooooo`0Coooo00<00?ooooooool00_ooo`03003ooooooooo00Woool0
0`00ooooooooo`07oooo0`00o`Coool00`00ooooooooo`02oooo0P00o`[oool00`00ooooooooo`02
oooo00<00?ooooooool00_ooo`800?l9oooo00<00?ooooooool02?ooo`800?l@oooo00<00?oooooo
ool06?ooo`800?l?oooo00@00?ooooooool00?l2oooo00@00?ooooooooooool2003o2?ooo`<00?l3
oooo00<00?ooool00?l00_ooo`<00?lUoooo00D00?ooooooooooool00?l01_ooo`800?l4oooo0P00
o`koool2003o00?oool00?ooool00_ooo`@00?l4oooo0P00o`05oooo003o003ooooo003o00?oool0
0`00ooooooooo`03oooo0P00obgoool100000Oooo`005oooo`030000oooooooo00Woool00`00oooo
ooooo`0Toooo00<00?ooooooool01Oooo`03003ooooooooo01?oool00`00ooooooooo`02oooo00<0
0?ooooooool02Oooo`03003ooooooooo00Ooool3003o1?ooo`03003ooooooooo00;oool2003o2_oo
o`03003ooooooooo00;oool00`00ooooooooo`02oooo0P00o`Woool00`00ooooooooo`08oooo0P00
oa3oool00`00ooooooooo`08oooo00<00?ooooooool03Oooo`800?l?oooo0P00o`05oooo003ooooo
oooo003o00?oool2003o2?ooo`03003ooooo003o00;oool2003o00Coool00?ooooooool3003o2_oo
o`03003ooooooooo01?oool00`00ooooooooo`02oooo0P00o`;oool00`00ooooooooo`04oooo0P00
o`Coool2003o3_ooo`04003ooooooooo003o0oooo`@00?l4oooo0`00o`04oooo003ooooo003o0ooo
o`03003ooooooooo00?oool00`00ooooooooo`0/oooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool09?ooo`800?l6oooo00<00?ooooooool03_ooo`04003ooooooooooooo0P00
o`Coool00`00ooooooooo`09oooo00<00?ooooooool01oooo`<00?l4oooo00<00?ooooooool00_oo
o`800?l4oooo00<00?ooooooool00oooo`03003ooooooooo00;oool00`00ooooooooo`02oooo0P00
o`?oool00`00ooooooooo`03oooo0P00o`Goool01`00ooooooooooooo`00ooooo`00o`0?oooo00<0
0?ooooooool02?ooo`03003ooooooooo00goool2003o3oooo`@00?l2oooo0P00o`;oool2003o2?oo
o`03003ooooo003o00;oool2003o00Coool00?ooooooool3003o2_ooo`03003ooooooooo01?oool0
0`00ooooooooo`02oooo0P00o`;oool00`00ooooooooo`04oooo0P00o`Coool2003o3_ooo`04003o
oooooooo003o0oooo`@00?l4oooo0`00o`?oool01@00ooooooooooooo`00o`04oooo00<00?oooooo
ool0;Oooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1_oo
o`03003ooooooooo00goool2003o0oooo`800?l4oooo00<00?ooooooool00oooo`03003ooooooooo
00;oool3003o1?ooo`04003ooooooooooooo0`00o`?oool2003o1?ooo`800?l3oooo0P00o`Coool2
003o1?ooo`03003ooooooooo00;oool2003o0oooo`800?l4oooo0P00o`Goool01`00oooooooooooo
o`00ooooo`00o`0?oooo00<00?ooooooool02?ooo`800?l8oooo00<00?ooooooool00oooo`800?l?
oooo1000o`;oool2003o0_ooo`800?l8oooo00<00?ooool00?l00_ooo`800?l01?ooo`00oooooooo
o`<00?l:oooo00<00?ooooooool04oooo`03003ooooooooo00;oool2003o0_ooo`03003ooooooooo
00Coool2003o1?ooo`800?l3oooo00<00?ooooooool00_ooo`03003ooooooooo00?oool01000oooo
ooooo`00o`?oool4003o1?ooo`<00?l7oooo00<00?ooooooool00_ooo`03003ooooooooo02goool1
00000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0Toooo0P00o`Goool2003o3ooo
o`800?l3oooo0`00o`?oool00`00ooooooooo`03oooo0P00o`?oool3003o1?ooo`04003ooooooooo
oooo0`00o`?oool2003o1?ooo`800?l3oooo0P00o`?oool3003o1?ooo`07003ooooooooooooo003o
oooo003o00?oool2003o1?ooo`800?l4oooo0P00o`?oool00`00ooooo`00o`0?oooo00<00?oooooo
ool02?ooo`800?l8oooo00<00?ooooooool00oooo`800?l?oooo1000o`;oool2003o0_ooo`800?l8
oooo00<00?ooool00?l00_ooo`800?l01?ooo`00ooooooooo`<00?l9oooo0P00oaGoool00`00oooo
ooooo`02oooo0P00o`;oool00`00ooooooooo`04oooo0P00o`Coool2003o0oooo`03003ooooooooo
00;oool00`00ooooooooo`03oooo00@00?ooooooool00?l3oooo1000o`Coool3003o1oooo`03003o
oooooooo00;oool00`00ooooooooo`0]oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<0
0?ooooooool09?ooo`800?l5oooo0P00o`ooool3003o0_ooo`<00?l3oooo00<00?ooooooool00ooo
o`800?l3oooo0`00o`Coool01000ooooooooooooo`<00?l3oooo0P00o`Coool2003o0oooo`800?l3
oooo0`00o`Coool01`00ooooooooooooo`00ooooo`00o`03oooo0P00o`Coool2003o1?ooo`800?l3
oooo00<00?ooool00?l03oooo`03003ooooooooo00Soool2003o2?ooo`03003ooooooooo00?oool2
003o3oooo`@00?l2oooo0P00o`;oool2003o2?ooo`03003ooooo003o00;oool01000ooooooooo`00
o`;oool3003o2Oooo`800?lEoooo00<00?ooooooool00_ooo`800?l2oooo00<00?ooooooool01?oo
o`800?l4oooo0P00o`?oool2003o0oooo`03003ooooooooo00?oool01000ooooooooo`00o`?oool4
003o1?ooo`<00?l7oooo00<00?ooooooool00_ooo`03003ooooooooo02goool100000Oooo`005ooo
o`030000oooooooo00Woool00`00ooooooooo`0Toooo0P00o`Goool2003o3oooo`<00?l2oooo00<0
0?ooool00?l00oooo`03003ooooooooo00?oool2003o0oooo`<00?l4oooo00<00?ooooooool01000
o`?oool2003o1?ooo`800?l3oooo0P00o`?oool3003o1?ooo`07003ooooooooooooo003ooooo003o
00?oool2003o1?ooo`800?l4oooo0P00o`?oool00`00ooooo`00o`0>oooo0P00o`[oool2003o2?oo
o`03003ooooooooo00;oool3003o3oooo`@00?l2oooo0`00o`03oooo003o003o00Soool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo0`00o`Woool2003o5Oooo`03003ooooooooo00;oool2
003o0_ooo`03003ooooooooo00Coool2003o1?ooo`800?l3oooo0P00o`?oool00`00ooooooooo`03
oooo00@00?ooooooool00?l3oooo1000o`Coool3003o1oooo`04003ooooooooooooo0P00obooool1
00000Oooo`005oooo`80000:oooo00<00?ooooooool09?ooo`800?l5oooo0P00o`ooool3003o0_oo
o`03003ooooo003o00?oool00`00ooooooooo`03oooo0P00o`?oool3003o1?ooo`03003ooooooooo
00@00?l3oooo0P00o`Coool2003o0oooo`800?l3oooo0`00o`Coool01`00ooooooooooooo`00oooo
o`00o`03oooo0P00o`Coool2003o1?ooo`800?l3oooo00<00?ooool00?l03_ooo`800?l9oooo0`00
o`Soool00`00ooooooooo`02oooo00@00?ooool00?l00?l;oooo00<00?ooooooool01000o`;oool3
003o00?oool00?l00?l02?ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool3003o2Ooo
o`800?lEoooo00<00?ooooooool00_ooo`800?l2oooo00<00?ooooooool00oooo`800?l00oooo`00
ooooo`02oooo0P00o`?oool2003o0oooo`03003ooooooooo00?oool01000ooooooooo`00o`?oool2
003o00?oool00?ooool00oooo`<00?l7oooo00@00?ooooooooooool2003o;_ooo`800001oooo000G
oooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1Oooo`800?l?oooo0`00o`;oool0
0`00ooooo`00o`02oooo0P00o`Goool2003o0oooo`03003ooooo003o00Coool00`00ooooooooo`04
003o0oooo`800?l4oooo0P00o`?oool2003o0oooo`<00?l4oooo00L00?ooooooooooool00?ooool0
0?l00oooo`800?l4oooo0P00o`Coool2003o0oooo`03003ooooo003o00koool2003o2Oooo`<00?l8
oooo00<00?ooooooool00_ooo`04003ooooo003o003o2oooo`03003ooooooooo00@00?l00oooo`00
o`00o`02003o00?oool00?l00?l02?ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool3
003o2Oooo`800?l4oooo00<00?ooooooool03_ooo`03003ooooooooo00;oool2003o0_ooo`03003o
oooooooo00?oool2003o00?oool00?ooool00_ooo`800?l3oooo0P00o`;oool2003o1?ooo`800?l2
oooo00@00?ooooooooooool2003o00?oool00?ooool00_ooo`@00?l7oooo00@00?ooooooooooool2
003o;oooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1Ooo
o`800?l?oooo0`00o`;oool00`00ooooo`00o`02oooo0P00o`Goool2003o0_ooo`800?l00oooo`00
ooooo`03oooo00<00?ooooooool01000o`?oool2003o1?ooo`800?l3oooo0P00o`?oool3003o1?oo
o`07003ooooooooooooo003ooooo003o00?oool2003o0oooo`<00?l4oooo0P00o`?oool00`00oooo
o`00o`0>oooo0P00o`Woool3003o2?ooo`03003ooooooooo00;oool01000ooooooooo`00o`_oool0
0`00ooooooooo`04003o00?oool00?l00?l00P00o`03oooo003o003o00Soool00`00ooooo`00o`02
oooo00@00?ooooooool00?l2oooo0`00o`Woool2003o1?ooo`03003ooooooooo00;oool00`00oooo
ooooo`09oooo00<00?ooooooool00_ooo`800?l2oooo00<00?ooooooool00oooo`800?l00oooo`00
ooooo`02oooo0P00o`?oool3003o00?oool00?l00?l01?ooo`800?l2oooo00@00?ooooooooooool2
003o00?oool00?ooool00_ooo`@00?l7oooo00@00?ooooooooooool2003o;oooo`400001oooo000G
oooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1Oooo`800?l?oooo0`00o`;oool0
0`00ooooo`00o`02oooo0`00o`Coool2003o0_ooo`800?l00oooo`00ooooo`03oooo00<00?oooooo
ool00P00o`03oooo003ooooo00;oool2003o0_ooo`800?l01?ooo`00ooooooooo`<00?l3oooo0`00
o`Coool01`00ooooooooooooo`00ooooo`00o`03oooo0P00o`?oool3003o1?ooo`800?l3oooo00<0
0?ooool00?l03_ooo`800?l9oooo0`00o`Soool00`00ooooooooo`02oooo00@00?ooooooool00?l;
oooo00<00?ooooooool01000o`03oooo003o003o00<00?l00oooo`00ooooo`07oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00Woool2003o0oooo`800?l4oooo00<0
0?ooooooool02Oooo`03003ooooooooo00;oool2003o0_ooo`03003ooooooooo00?oool2003o00?o
ool00?ooool00_ooo`800?l3oooo0`00o`03oooo003o003o00Coool2003o0_ooo`05003ooooooooo
oooo003o00;oool01000ooooooooooooo`@00?l7oooo00@00?ooooooooooool2003o;oooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1Oooo`800?l?oooo0`00
o`;oool00`00ooooo`00o`02oooo0`00o`Coool2003o0_ooo`800?l00oooo`00ooooo`03oooo00<0
0?ooooooool00P00o`03oooo003ooooo00;oool2003o0_ooo`800?l01?ooo`00ooooooooo`<00?l3
oooo0`00o`Coool01`00ooooooooooooo`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`<00?l4
oooo0P00o`?oool00`00ooooo`00o`0>oooo0P00o`Woool3003o2?ooo`03003ooooooooo00;oool0
1000ooooooooo`00o`_oool00`00ooooooooo`04003o00?oool00?ooool00`00o`03oooo003ooooo
00Ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooool00?l02Oooo`800?l3
oooo0P00o`Coool00`00ooooooooo`08oooo0P00o`Coool3003o00?oool00?ooool01?ooo`04003o
oooooooo003o0oooo`800?l3oooo0`00o`03oooo003o003o00Coool2003o0_ooo`05003ooooooooo
oooo003o00;oool01000ooooooooooooo`@00?l7oooo00D00?ooooooooooool00?l0<?ooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02Coool2003o1Oooo`800?l?oooo0`00
o`;oool00`00ooooo`00o`02oooo00<00?ooool00?l01?ooo`800?l2oooo0P00o`03oooo003ooooo
00?oool00`00ooooooooo`02003o00?oool00?ooool00_ooo`800?l2oooo0P00o`07oooo003ooooo
oooo003ooooo003o00?oool3003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`03oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0oooo`800?l3oooo00<00?ooool00?l01?ooo`03003o
oooooooo00Ooool2003o2Oooo`<00?l8oooo00<00?ooooooool00_ooo`04003ooooooooo003o2ooo
o`03003ooooooooo00@00?l00oooo`00ooooo`03003o00?oool00?ooool01oooo`04003ooooo003o
oooo0P00o`;oool01P00ooooooooo`00ooooo`00o`?oool2003o1?ooo`800?l3oooo0`00o`?oool0
1@00ooooooooooooo`00o`06oooo0P00o`Coool3003o00?oool00?ooool01?ooo`04003ooooooooo
003o0oooo`800?l3oooo0`00o`03oooo003o003o00;oool01000ooooo`00o`00o`;oool01@00oooo
ooooooooo`00o`02oooo00@00?ooooooooooool4003o1oooo`05003ooooooooooooo003o033oool1
00000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0Soooo00<00?ooool00?l01Ooo
o`800?l9oooo00<00?ooooooool00oooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00<0
0?ooool00?l01?ooo`800?l2oooo0P00o`03oooo003ooooo00;oool2003o0_ooo`800?l00oooo`00
ooooo`02oooo0P00o`;oool2003o00Ooool00?ooooooool00?ooool00?l00oooo`800?l01_ooo`00
ooooo`00ooooo`00o`?oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0oooo`800?l3oooo00<00?ooool00?l01?ooo`03003ooooooooo00Ooool2003o2Oooo`<00?l3
oooo00<00?ooooooool00_ooo`800?l3oooo00@00?ooooooool00?l;oooo00<00?ooooooool01000
o`03oooo003ooooo00<00?l00oooo`00ooooo`07oooo00@00?ooool00?ooool2003o0_ooo`06003o
oooooooo003ooooo003o0oooo`800?l4oooo0P00o`?oool3003o0oooo`05003ooooooooooooo003o
00Koool2003o1?ooo`<00?l00oooo`00ooooo`04oooo00@00?ooooooool00?l3oooo0P00o`?oool3
003o00?oool00?l00?l00_ooo`04003ooooo003o003o0_ooo`05003ooooooooooooo003o00;oool0
1000ooooooooooooo`800?l00oooo`00ooooo`06oooo00D00?ooooooooooool00?l0<?ooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02?oool00`00ooooo`00o`05oooo0P00
o`Woool00`00ooooooooo`03oooo00<00?ooool00?l00_ooo`03003ooooo003o00;oool01000oooo
o`00o`00o`;oool00`00ooooo`00o`02oooo0P00o`03oooo003ooooo00;oool2003o0_ooo`04003o
oooooooo003o0oooo`800?l2oooo0P00o`07oooo003ooooooooo003ooooo003o00;oool3003o00?o
ool00?ooool00`00o`?oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0oooo`800?l3oooo00<00?ooool00?l01?ooo`03003ooooooooo00Ooool2003o2Oooo`<00?l3
oooo00<00?ooooooool00_ooo`800?l2oooo0P00o`;oool00`00ooooooooo`09oooo00<00?oooooo
ool00P00o`04oooo003ooooo003o0_ooo`800?l00oooo`00ooooo`07oooo00@00?ooool00?ooool2
003o0_ooo`06003ooooooooo003ooooo003o0_ooo`<00?l4oooo0P00o`?oool3003o0oooo`05003o
oooooooooooo003o00Koool2003o1?ooo`<00?l00oooo`00ooooo`04oooo00@00?ooooooool00?l3
oooo0P00o`?oool3003o00?oool00?l00?l00_ooo`04003ooooo003o003o0_ooo`05003ooooooooo
oooo003o00;oool01000ooooooooooooo`800?l00oooo`00ooooo`06oooo00D00?ooooooooooool0
0?l0<?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02?oool00`00oooo
o`00o`04oooo00<00?ooool00?l02Oooo`03003ooooooooo00?oool00`00ooooo`00o`02oooo00<0
0?ooool00?l00_ooo`04003ooooo003o003o0_ooo`03003ooooo003o00;oool2003o00?oool00?oo
ool00_ooo`<00?l01Oooo`00ooooooooo`00o`03oooo0P00o`;oool2003o00Ooool00?ooooooool0
0?ooool00?l00_ooo`<00?l00oooo`00ooooo`03003o0oooo`03003ooooo003o00?oool00`00oooo
o`00o`02oooo00@00?ooooooool00?l3oooo0P00o`?oool00`00ooooo`00o`04oooo00<00?oooooo
ool01oooo`800?l9oooo0`00o`?oool00`00ooooooooo`02oooo0P00o`;oool2003o0_ooo`03003o
oooooooo00Ooool00`00ooooo`00o`02oooo0P00o`04oooo003ooooo003o0oooo`03003ooooo003o
00Goool01`00ooooooooo`00ooooo`00ooooo`02003o0_ooo`06003ooooooooo003ooooo003o0_oo
o`<00?l3oooo00<00?ooool00?l00oooo`<00?l3oooo00@00?ooooooooooool2003o1Oooo`800?l4
oooo0`00o`03oooo003ooooo00Coool01000ooooooooo`00o`?oool2003o0oooo`<00?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`02oooo00D00?ooooooooooool00?l00_ooo`04003ooooooooo
oooo0P00o`03oooo003ooooo00Koool01@00ooooooooooooo`00o`0`oooo0@00007oool001Ooool0
0`000?ooooooo`09oooo00<00?ooooooool08oooo`03003ooooo003o00Coool00`00ooooo`00o`09
oooo00<00?ooooooool00oooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00@00?ooool0
0?l00?l2oooo00<00?ooool00?l00_ooo`800?l00oooo`00ooooo`02oooo00D00?ooool00?ooool0
0?l00_ooo`04003ooooooooooooo0P00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02
oooo00H00?ooool00?ooool00?ooool3003o0oooo`03003ooooo003o00?oool00`00ooooo`00o`02
oooo00@00?ooooooool00?l3oooo0P00o`?oool00`00ooooo`00o`04oooo00<00?ooooooool01ooo
o`800?l9oooo0`00o`?oool00`00ooooooooo`02oooo0P00o`;oool01@00ooooooooooooo`00o`09
oooo0`00o`;oool2003o00Coool00?ooool00?l3oooo00<00?ooool00?l01Oooo`07003ooooooooo
003ooooo003ooooo00800?l2oooo00H00?ooooooool00?ooool00?l2oooo0`00o`?oool01000oooo
ooooo`00o`;oool3003o0oooo`04003ooooooooooooo0P00o`Goool2003o1?ooo`<00?l00oooo`00
ooooo`04oooo00@00?ooooooool00?l3oooo0P00o`?oool3003o00Coool00?l00?ooool4003o0ooo
o`05003ooooooooooooo003o00;oool01000ooooooooooooo`800?l9oooo00D00?ooooooooooool0
0?l0<?ooo`400001oooo000Goooo0P0000[oool00`00ooooooooo`0Soooo00<00?ooool00?l01?oo
o`03003ooooo003o00Woool00`00ooooooooo`03oooo00<00?ooool00?l00_ooo`03003ooooo003o
00;oool01000ooooo`00o`00o`;oool01@00ooooooooo`00ooooo`02003o00?oool00?ooool00_oo
o`05003ooooo003ooooo003o00;oool01000ooooooooooooo`800?l2oooo00@00?ooooooool00?l2
oooo00<00?ooool00?l00_ooo`06003ooooo003ooooo003ooooo0`00o`?oool00`00ooooo`00o`03
oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0oooo`800?l2oooo0P00o`03oooo003ooooo
00?oool00`00ooooooooo`07oooo0P00o`Woool3003o0oooo`03003ooooooooo00;oool2003o0_oo
o`05003ooooooooooooo003o00Woool3003o0_ooo`800?l01?ooo`00ooooo`00o`?oool00`00oooo
o`00o`05oooo0P00o`05oooo003ooooo003ooooo00800?l2oooo00H00?ooooooool00?ooool00?l2
oooo0`00o`?oool01000ooooooooo`00o`;oool3003o0oooo`800?l2oooo0P00o`Goool2003o1?oo
o`<00?l01Oooo`00ooooooooo`00o`02oooo00@00?ooooooool00?l3oooo0P00o`?oool3003o00Co
ool00?l00?ooool4003o0oooo`04003ooooooooo003o0oooo`05003ooooooooooooo003o00[oool0
1@00ooooooooooooo`00o`0_oooo0P00007oool001Ooool00`000?ooooooo`09oooo00<00?oooooo
ool08oooo`03003ooooo003o00Coool00`00ooooo`00o`05oooo00D00?ooooooooooool00?l01Ooo
o`03003ooooo003o00;oool00`00ooooo`00o`02oooo00@00?ooool00?l00?l2oooo00D00?oooooo
ool00?ooool00P00o`03oooo003ooooo00;oool01@00ooooo`00ooooo`00o`02oooo00@00?oooooo
ooooool2003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01P00oooooooooooo
o`00ooooo`800?l00oooo`00ooooo`02003o00?oool00?ooool00_ooo`03003ooooo003o00;oool0
1000ooooooooo`00o`?oool2003o0_ooo`04003ooooooooo003o1?ooo`03003ooooooooo00Ooool2
003o2Oooo`<00?l3oooo00<00?ooooooool00_ooo`800?l2oooo00D00?ooooooooooool00?l02Ooo
o`<00?l2oooo0P00o`04oooo003ooooo003o1Oooo`03003ooooooooo00?oool2003o00Goool00?oo
ool00?ooool00P00o`;oool01P00ooooooooo`00ooooo`00o`;oool3003o0oooo`04003ooooooooo
003o0_ooo`<00?l3oooo0P00o`;oool2003o1Oooo`800?l4oooo0`00o`05oooo003ooooooooo003o
00;oool01000ooooooooo`00o`?oool2003o0oooo`<00?l00oooo`00o`00o`05003o0oooo`04003o
oooooooo003o0oooo`03003ooooooooo00800?l:oooo00@00?ooooooool00?laoooo0@00007oool0
01Ooool00`000?ooooooo`09oooo00<00?ooooooool08oooo`03003ooooo003o00Coool00`00oooo
o`00o`05oooo00D00?ooooooooooool00?l01Oooo`03003ooooo003o00;oool00`00ooooo`00o`02
oooo00@00?ooool00?l00?l2oooo00D00?ooooooool00?ooool00P00o`03oooo003ooooo00;oool0
1@00ooooo`00ooooo`00o`02oooo00@00?ooooooooooool2003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00;oool01P00ooooooooooooo`00ooooo`800?l00oooo`00ooooo`02003o00?o
ool00?ooool00_ooo`03003ooooo003o00;oool01000ooooooooo`00o`?oool2003o0_ooo`04003o
oooooooo003o1?ooo`03003ooooooooo00Ooool2003o2Oooo`<00?l3oooo00<00?ooooooool00_oo
o`800?l2oooo00D00?ooooooooooool00?l02Oooo`<00?l01Oooo`00o`00o`00ooooo`03003o1Ooo
o`03003ooooooooo00?oool2003o00Goool00?ooool00?ooool00P00o`;oool01P00ooooooooo`00
ooooo`00o`;oool4003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00?oool2003o0_oo
o`800?l5oooo0P00o`Coool3003o00Goool00?ooooooool00?l00_ooo`04003ooooooooo003o0ooo
o`800?l3oooo0`00o`03oooo003o003o00@00?l4oooo00@00?ooooooool00?l3oooo00<00?oooooo
ool00P00o`[oool01000ooooooooo`00oc7oool100000Oooo`005oooo`030000oooooooo00Woool0
0`00ooooooooo`0Soooo00<00?ooool00?l01?ooo`03003ooooo003o00Goool01@00oooooooooooo
o`00o`05oooo00<00?ooool00?l00_ooo`03003ooooo003o00;oool01000ooooo`00o`00o`;oool0
1@00ooooooooo`00ooooo`02003o00?oool00?ooool00_ooo`05003ooooo003ooooo003o00;oool0
1000ooooooooooooo`800?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`06003o
oooooooooooo003ooooo0P00o`03oooo003ooooo00800?l00oooo`00ooooo`02oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0oooo`800?l2oooo00@00?ooooooool00?l4oooo00<00?oooooo
ool01oooo`800?l9oooo0`00o`?oool2003o0oooo`800?l2oooo00D00?ooooooooooool00?l02Ooo
o`<00?l00oooo`00o`00o`02oooo0`00o`Goool00`00ooooooooo`03oooo1000o`04oooo003ooooo
003o0oooo`06003ooooooooo003ooooo003o0_ooo`@00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooool00?l00oooo`800?l2oooo0P00o`Goool2003o1?ooo`<00?l01Oooo`00ooooooooo`00o`02
oooo00@00?ooooooool00?l3oooo0P00o`?oool:003o1?ooo`04003ooooooooo003o0oooo`03003o
oooooooo00800?l:oooo00@00?ooooooool00?laoooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool08oooo`03003ooooo003o00Coool00`00ooooo`00o`05oooo00D00?oooooo
ooooool00?l01Oooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2
oooo00D00?ooooooool00?ooool00P00o`03oooo003ooooo00;oool01@00ooooo`00ooooo`00o`02
oooo00@00?ooooooooooool2003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
1P00ooooooooooooo`00ooooo`800?l00oooo`00ooooo`02003o00?oool00?ooool00_ooo`03003o
oooo003o00;oool01000ooooooooo`00o`?oool2003o0_ooo`04003ooooooooo003o1?ooo`03003o
oooooooo00Ooool2003o2Oooo`<00?l3oooo0P00o`;oool4003o00?oool00?ooool00_ooo`03003o
oooooooo00Ooool3003o00?oool00?l00?l00_ooo`<00?l5oooo00<00?ooooooool00oooo`@00?l0
1?ooo`00ooooo`00o`?oool01P00ooooooooo`00ooooo`00o`;oool2003o00Goool00?ooooooool0
0?l00_ooo`06003ooooooooo003ooooo003o0oooo`800?l2oooo0P00o`Goool2003o1?ooo`<00?l0
1Oooo`00ooooooooo`00o`02oooo00@00?ooooooool00?l3oooo0P00o`?oool:003o1?ooo`04003o
oooooooo003o0oooo`03003ooooooooo00800?l:oooo00@00?ooooooool00?laoooo0@00007oool0
01Ooool00`000?ooooooo`09oooo00<00?ooooooool08oooo`03003ooooo003o00Coool00`00oooo
o`00o`04oooo0P00o`?oool00`00ooooooooo`02oooo0P00o`07oooo003ooooooooo003ooooo003o
00;oool01000ooooooooo`00o`;oool01@00ooooooooo`00ooooo`02003o00?oool00?ooool00_oo
o`05003ooooo003ooooo003o00;oool01000ooooooooooooo`800?l2oooo00@00?ooooooool00?l2
oooo00<00?ooool00?l00_ooo`04003ooooooooooooo1000o`03oooo003ooooo00800?l00oooo`00
ooooo`02oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0oooo`800?l2oooo00@00?oooooo
ool00?l4oooo00D00?ooooooooooool00?l01Oooo`800?l9oooo0`00o`?oool2003o0_ooo`@00?l0
0oooo`00ooooo`02oooo00<00?ooooooool01oooo`<00?l00oooo`00o`00o`02oooo0`00o`Goool0
0`00ooooooooo`03oooo00P00?ooool00?l00?ooool00?ooool00?l3oooo00H00?ooooooool00?oo
ool00?l2oooo0P00o`05oooo003ooooooooo003o00;oool01P00ooooooooo`00ooooo`00o`?oool2
003o0_ooo`@00?l3oooo0P00o`Coool3003o00Koool00?ooooooool00?ooool2003o0_ooo`06003o
oooooooo003ooooo003o0oooo`X00?l4oooo00@00?ooool00?l00?l3oooo00<00?ooooooool00P00
o`[oool01000ooooooooo`00oc7oool100000Oooo`005oooo`030000oooooooo00Woool00`00oooo
ooooo`0Soooo00<00?ooool00?l01?ooo`03003ooooo003o00Coool2003o0oooo`03003ooooooooo
00;oool2003o00Ooool00?ooooooool00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`05003o
oooooooo003ooooo00800?l00oooo`00ooooo`02oooo00D00?ooool00?ooool00?l00_ooo`03003o
oooooooo00<00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo
oooo1000o`03oooo003ooooo00800?l00oooo`00ooooo`02oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o0oooo`800?l2oooo00@00?ooooooool00?l4oooo00D00?ooooooooooool00?l01Ooo
o`800?l9oooo00<00?ooool00?l00oooo`800?l2oooo1000o`03oooo003ooooo00;oool00`00oooo
ooooo`07oooo0`00o`03oooo003ooooo00;oool3003o1Oooo`03003ooooooooo00;oool2003o00Co
ool00?l00?ooool2003o1?ooo`06003ooooooooo003ooooo003o0_ooo`800?l01Oooo`00oooooooo
o`00o`02oooo00H00?ooooooool00?ooool00?l3oooo0P00o`;oool4003o0oooo`800?l4oooo0`00
o`06oooo003ooooooooo003ooooo0P00o`;oool01P00ooooooooo`00ooooo`00o`;oool;003o1?oo
o`04003ooooo003o003o0oooo`04003ooooooooo003o2oooo`04003ooooooooo003o<Oooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02?oool00`00ooooo`00o`04oooo00<0
0?ooool00?l01?ooo`800?l3oooo00<00?ooooooool00_ooo`800?l01oooo`00ooooooooo`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00T00?oooooo
ooooool00?ooool00?ooool00?l00_ooo`03003ooooooooo00<00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooool00?l00_ooo`04003ooooooooooooo0P00o`05oooo003ooooo003ooooo00800?l0
0oooo`00ooooo`02oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0oooo`800?l2oooo00@0
0?ooooooool00?l4oooo00D00?ooooooooooool00?l01Oooo`800?l9oooo00<00?ooool00?l00ooo
o`800?l2oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`07oooo0`00o`03oooo003ooooo
00;oool3003o1Oooo`03003ooooooooo00;oool00`00ooooooooo`02003o00?oool00?l00?l01?oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00o`?oool2003o0_ooo`@00?l3oooo0P00o`Coool01@00ooooo`00ooooo`00o`02
oooo00@00?ooool00?l00?l2oooo00H00?ooooooool00?ooool00?l2oooo2`00o`Coool01000oooo
o`00o`00o`?oool01000ooooooooo`00o`_oool01000ooooooooo`00oc7oool100000Oooo`001Ooo
o`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Woool00`00ooooooooo`0Soooo00<00?ooool00?l00oooo`04003ooooooooo003o1?ooo`800?l3
oooo00<00?ooooooool00_ooo`800?l01oooo`00ooooooooo`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00T00?ooooooooooool00?ooool00?ooool0
0?l00_ooo`03003ooooooooo00<00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`04003ooooooooooooo0P00o`05oooo003ooooo003ooooo00800?l00oooo`00ooooo`02oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`<00?l2oooo00@00?ooooooool00?l4oooo00<0
0?ooooooool00P00o`Goool2003o1?ooo`05003ooooooooooooo003o00;oool01000oooooooooooo
o`800?l2oooo00H00?ooooooool00?ooool00?l3oooo00<00?ooooooool01oooo`<00?l00oooo`00
ooooo`02oooo0`00o`Goool00`00ooooooooo`02oooo00<00?ooooooool00P00o`03oooo003o003o
00Coool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?l3oooo0P00o`;oool4003o0oooo`800?l4oooo00D00?ooool00?ooool0
0?l00_ooo`03003ooooo003o00?oool01P00ooooooooo`00ooooo`00o`;oool8003o00?oool00?l0
0?l01?ooo`04003ooooo003o003o0oooo`04003ooooooooo003o2oooo`04003ooooooooo003o<Ooo
o`400001oooo0004oooo00<0003oool000001oooo`030000oooo000000Koool00`000?ooooooo`09
oooo00<00?ooooooool08oooo`03003ooooo003o00?oool01000ooooooooo`00o`Coool2003o0ooo
o`03003ooooooooo00;oool2003o00Goool00?ooooooool00?l00_ooo`03003ooooo003o00;oool0
1000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00T00?ooooooooooool00?ooool00?ooool0
0?l00_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00;oool01000ooooooooooooo`800?l01Oooo`00ooooo`00ooooo`02003o00?oool00?ooool00_oo
o`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l3oooo0P00o`;oool2003o1Oooo`800?l4oooo00D00?ooooooooooool00?l00_ooo`04003o
oooooooooooo0P00o`;oool01P00ooooooooo`00ooooo`00o`?oool00`00ooooooooo`07oooo00D0
0?ooool00?ooool00?l00oooo`<00?l5oooo00<00?ooooooool00_ooo`03003ooooooooo00800?l0
0oooo`00o`00o`04oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`06003ooooooooo003ooooo003o0oooo`800?l2oooo1000o`?oool2003o1?ooo`05003o
oooo003ooooo003o00;oool00`00ooooo`00o`03oooo00@00?ooooooool00?l2oooo00<00?ooool0
0?l01`00o`03oooo003o003o00Coool01000ooooo`00o`00o`?oool01000ooooooooo`00o`_oool0
1000ooooooooo`00oc7oool100000Oooo`001?ooo`030000oooo000000Woool00`000?ooooooo`04
oooo0`0000Woool00`00ooooooooo`0Soooo00<00?ooool00?l00oooo`04003ooooooooo003o1?oo
o`800?l3oooo0`00o`;oool2003o00Goool00?ooooooool00?l00_ooo`03003ooooo003o00;oool0
1000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00T00?ooooooooooool00?ooool00?ooool0
0?l00_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00;oool01000ooooooooooooo`800?l01Oooo`00ooooo`00ooooo`02003o00?oool00?ooool00_oo
o`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l3oooo0P00o`;oool2003o1Oooo`800?l4oooo00D00?ooooooooooool00?l00_ooo`04003o
oooooooooooo0`00o`07oooo003ooooooooo003ooooo003o00?oool00`00ooooooooo`02oooo00<0
0?ooooooool00_ooo`05003ooooo003ooooo003o00Coool2003o1Oooo`03003ooooooooo00;oool0
0`00ooooooooo`02003o00?oool00?l00?l01?ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`?oool2003o0_ooo`@00?l3
oooo0P00o`Coool01@00ooooo`00ooooo`00o`02oooo00<00?ooool00?l00oooo`04003ooooooooo
003o0_ooo`03003ooooo003o00800?l00oooo`00o`00o`02003o00?oool00?l00?l01?ooo`04003o
oooo003o003o0oooo`04003ooooooooo003o2oooo`03003ooooo003o033oool300000Oooo`001?oo
o`030000oooo000000Ooool200001oooo`030000oooooooo00Woool00`00ooooooooo`0Soooo00<0
0?ooool00?l00oooo`04003ooooooooo003o1?ooo`800?l3oooo0`00o`;oool2003o00Goool00?oo
ooooool00?l00_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02
oooo00T00?ooooooooooool00?ooool00?ooool00?l00_ooo`06003ooooooooo003ooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooooooo`800?l01Oooo`00
ooooo`00ooooo`02003o00?oool00?ooool00_ooo`03003ooooo003o00;oool01000ooooooooo`00
o`;oool00`00ooooo`00o`02oooo00@00?ooooooool00?l3oooo0P00o`;oool2003o1Oooo`800?l4
oooo00D00?ooooooooooool00?l00_ooo`04003ooooooooooooo0`00o`04oooo003ooooooooo0`00
o`?oool00`00ooooooooo`02oooo00D00?ooooooooooool00?l00_ooo`03003ooooo003o00Coool2
003o1Oooo`03003ooooooooo00;oool00`00ooooooooo`02003o00?oool00?l00?l01?ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01P00ooooooooo`00
ooooo`00o`?oool2003o0_ooo`@00?l3oooo0P00o`Coool01@00ooooo`00ooooo`00o`02oooo00<0
0?ooool00?l00oooo`04003ooooooooo003o0_ooo`04003ooooo003o003o0_ooo`@00?l00oooo`00
o`00o`04oooo00@00?ooool00?l00?l3oooo00@00?ooooooool00?l;oooo00<00?ooool00?l0<_oo
o`400001oooo0004oooo00<0003oool000001oooo`030000oooooooo00Koool00`000?ooooooo`09
oooo00<00?ooooooool08oooo`03003ooooo003o00?oool01000ooooooooo`00o`Coool2003o0ooo
o`<00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l2oooo00<00?ooool00?l00_ooo`09003ooooooooooooo003ooooo003ooooo003o00;oool0
1P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooooooool2003o00Goool00?ooool00?ooool00P00o`03oooo003ooooo00;oool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`07003ooooooooo003ooooo
003ooooo00800?l2oooo0P00o`Goool2003o1?ooo`05003ooooooooooooo003o00;oool01000oooo
ooooooooo`<00?l01?ooo`00ooooooooo`<00?l3oooo00<00?ooooooool00_ooo`05003ooooooooo
oooo003o00;oool00`00ooooo`00o`04oooo0P00o`Goool00`00ooooooooo`02oooo00<00?oooooo
ool00P00o`03oooo003o003o00Coool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l3oooo0P00o`;oool4003o0oooo`800?l4
oooo00<00?ooool00?l00P00o`;oool00`00ooooo`00o`03oooo00@00?ooooooool00?l2oooo00@0
0?ooool00?l00?l2oooo1000o`03oooo003o003o00Coool01000ooooo`00o`00o`?oool01000oooo
ooooo`00o`_oool00`00ooooo`00o`0boooo0@00007oool000Goool00`000?ooooooo`06oooo0`00
00Koool00`000?ooooooo`09oooo00<00?ooooooool08oooo`03003ooooo003o00?oool01000oooo
ooooo`00o`Coool2003o0oooo`<00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003ooooooooooooo003o
oooo003ooooo003o00;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooo`00o`02oooo00@00?ooooooooooool2003o00Koool00?ooool00?ooool00?l2oooo00L0
0?ooooooooooool00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
1`00ooooooooo`00ooooo`00ooooo`02003o0_ooo`800?l2oooo00D00?ooool00?ooool00?l01?oo
o`05003ooooooooooooo003o00;oool01000ooooooooooooo`<00?l01?ooo`00ooooooooo`800?l4
oooo00<00?ooooooool00_ooo`05003ooooooooooooo003o00;oool00`00ooooo`00o`04oooo00<0
0?ooooooool01?ooo`03003ooooooooo00;oool01000ooooooooo`00o`;oool2003o1?ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01P00ooooooooo`00
ooooo`00o`?oool2003o0_ooo`@00?l3oooo0P00o`Coool00`00ooooo`00o`02003o0_ooo`03003o
oooo003o00?oool01000ooooooooo`00o`;oool01000ooooo`00o`00o`;oool4003o00?oool00?l0
0?l01?ooo`03003ooooo003o00Coool01000ooooooooo`00o`_oool00`00ooooo`00o`0boooo0@00
007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool08oooo`03003ooooo003o00?oool0
1000ooooooooo`00o`Coool2003o0oooo`<00?l2oooo00@00?ooooooool00?l2oooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003ooooooooo
oooo003ooooo003ooooo003o00;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooo`00o`02oooo00@00?ooooooooooool2003o0oooo`03003ooooo003o00;oool0
1`00ooooooooooooo`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`07003ooooooooo003ooooo003ooooo00800?l2oooo0P00o`;oool01@00ooooo`00ooooo`00o`04
oooo00D00?ooooooooooool00?l00_ooo`04003ooooooooooooo0`00o`04oooo003ooooooooo0P00
o`Coool2003o0oooo`05003ooooooooooooo003o00;oool00`00ooooo`00o`0<oooo00D00?oooooo
ooooool00?l00_ooo`03003ooooooooo00800?l4oooo00@00?ooooooool00?l2oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0oooo`800?l2oooo1000
o`?oool2003o1?ooo`03003ooooo003o00800?l2oooo00<00?ooool00?l00oooo`04003ooooooooo
003o0_ooo`04003ooooo003o003o0_ooo`@00?l00oooo`00o`00o`04oooo00<00?ooool00?l01?oo
o`04003ooooooooo003o2oooo`03003ooooo003o03;oool100000Oooo`005oooo`030000oooooooo
00Woool00`00ooooooooo`0Soooo00<00?ooool00?l00oooo`04003ooooooooo003o0oooo`03003o
oooo003o00?oool3003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00;oool02@00ooooooooooooo`00ooooo`00oooo
o`00o`02oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool0
0?l00_ooo`04003ooooooooooooo0P00o`?oool00`00ooooo`00o`02oooo00L00?ooooooooooool0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01@00ooooooooo`00
ooooo`04003o0_ooo`800?l2oooo00D00?ooool00?ooool00?l01?ooo`03003ooooooooo00800?l2
oooo00@00?ooooooooooool3003o00Coool00?ooooooool2003o1Oooo`03003ooooooooo00800?l3
oooo00H00?ooooooool00?ooool00?l<oooo00D00?ooooooooooool00?l01Oooo`800?l4oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool01P00ooooooooo`00
ooooo`00o`?oool2003o0_ooo`@00?l3oooo0P00o`Coool00`00ooooo`00o`03003o00Coool00?oo
ool00?l3oooo00@00?ooooooool00?l2oooo00@00?ooool00?l00?l2oooo1000o`03oooo003o003o
00Coool00`00ooooo`00o`04oooo00@00?ooooooool00?l;oooo00<00?ooool00?l0<_ooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo02?oool00`00ooooo`00o`03oooo00@0
0?ooooooool00?l3oooo00<00?ooool00?l00oooo`<00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003o
oooooooooooo003ooooo003ooooo003o00;oool01P00ooooooooo`00ooooo`00o`;oool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00o`?oool2003o0oooo`03003ooooo003o00;oool0
1`00ooooooooooooo`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`05003ooooooooo003ooooo00@00?l2oooo0P00o`;oool01@00ooooo`00ooooo`00o`04oooo0P00
o`03oooo003o003o00;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`02oooo0P00o`Goool0
0`00ooooooooo`02003o0oooo`06003ooooooooo003ooooo003o3?ooo`05003ooooooooooooo003o
00Goool2003o1?ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool00`00ooooo`00o`03
oooo00H00?ooooooool00?ooool00?l3oooo0P00o`;oool4003o0oooo`800?l4oooo00<00?ooool0
0?l00`00o`04oooo003ooooo003o0oooo`04003ooooooooo003o0_ooo`04003ooooo003o003o0_oo
o`@00?l00oooo`00o`00o`04oooo00<00?ooool00?l01?ooo`04003ooooooooo003o2oooo`03003o
oooo003o03;oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0Koooo00<0
0?ooooooool01?ooo`800?l00oooo`00ooooo`02oooo00@00?ooooooool00?l3oooo00<00?ooool0
0?l00oooo`<00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003ooooooooooooo003ooooo003ooooo003o
00?oool01@00ooooo`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l3oooo0P00o`?oool00`00ooooo`00o`02oooo00L00?ooooooooooool00?ooool00?l00_oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01@00ooooooooo`00ooooo`04003o0_oo
o`800?l2oooo00D00?ooool00?ooool00?l01?ooo`800?l00oooo`00o`00o`02oooo00T00?oooooo
ooooool00?ooool00?ooool00?l00_ooo`800?l5oooo00<00?ooooooool00P00o`?oool01P00oooo
ooooo`00ooooo`00o`coool01@00ooooooooooooo`00o`06oooo00<00?ooooooool00_ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool00`00ooooo`00o`03oooo00H00?ooooooool00?oo
ool00?l3oooo0P00o`;oool4003o0oooo`800?l4oooo00<00?ooool00?l00`00o`04oooo003ooooo
003o0oooo`04003ooooooooo003o0_ooo`04003ooooo003o003o0_ooo`@00?l00oooo`00o`00o`04
oooo00<00?ooool00?l01?ooo`04003ooooooooo003o2oooo`03003ooooo003o03;oool100000Ooo
o`005oooo`030000oooooooo00Woool00`00ooooooooo`0Koooo00<00?ooooooool01?ooo`800?l0
0oooo`00ooooo`02oooo00@00?ooooooool00?l3oooo00<00?ooool00?l00oooo`<00?l2oooo00@0
0?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooool00?l00_ooo`09003ooooooooooooo003ooooo003ooooo003o00?oool01@00ooooo`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l3oooo0P00o`?oool0
0`00ooooo`00o`02oooo00L00?ooooooooooool00?ooool00?l00_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00;oool01@00ooooooooo`00ooooo`04003o0_ooo`800?l01oooo`00o`00oooo
o`00ooooo`00o`04oooo0P00o`03oooo003o003o00;oool02@00ooooooooooooo`00ooooo`00oooo
o`00o`02oooo0P00o`Goool00`00ooooooooo`02003o0_ooo`800?l2oooo00<00?ooool00?l03?oo
o`05003ooooooooooooo003o00Koool00`00ooooooooo`02oooo00@00?ooooooool00?l2oooo00<0
0?ooool00?l00_ooo`03003ooooo003o00?oool01P00ooooooooo`00ooooo`00o`?oool2003o0_oo
o`@00?l3oooo0P00o`Coool00`00ooooo`00o`03003o00Coool00?ooool00?l3oooo00@00?oooooo
ool00?l2oooo00@00?ooool00?l00?l2oooo1000o`03oooo003o003o00Coool00`00ooooo`00o`04
oooo00@00?ooooooool00?l;oooo00<00?ooool00?l0<_ooo`400001oooo000Goooo00<0003ooooo
ool02Oooo`03003ooooooooo01_oool00`00ooooooooo`04oooo00@00?ooooooool00?l3oooo00@0
0?ooooooool00?l3oooo00<00?ooool00?l00oooo`<00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003o
oooooooooooo003ooooo003ooooo003o00?oool01@00ooooo`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?l3oooo0P00o`?oool00`00ooooo`00o`02oooo00L0
0?ooooooooooool00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
1@00ooooooooo`00ooooo`04003o0_ooo`800?l01oooo`00o`00ooooo`00ooooo`00o`04oooo1@00
o`;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`02oooo0P00o`Goool00`00ooooooooo`02
003o0_ooo`800?l2oooo00<00?ooool00?l03?ooo`03003ooooooooo00800?l<oooo00<00?ooool0
0?l00_ooo`03003ooooo003o00;oool00`00ooooo`00o`03oooo00H00?ooooooool00?ooool00?l3
oooo0P00o`;oool4003o0oooo`800?l4oooo00<00?ooool00?l00`00o`03oooo003o003o00Coool0
1000ooooooooo`00o`;oool01000ooooo`00o`00o`;oool4003o0_ooo`03003ooooooooo00;oool0
0`00ooooo`00o`04oooo00@00?ooooooool00?l;oooo00<00?ooool00?l0<_ooo`400001oooo000G
oooo0P0000[oool00`00ooooooooo`0Koooo00<00?ooooooool01?ooo`04003ooooooooo003o0ooo
o`04003ooooooooo003o0oooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool0
0?l00_ooo`09003ooooooooooooo003ooooo003ooooo003o00?oool01@00ooooo`00ooooo`00o`02
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l3oooo00<00?ooooooool00_oo
o`03003ooooo003o00;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03oooo00H00?oooooo
ool00?ooool00?l2oooo00D00?ooooooool00?ooool01000o`;oool2003o00Ooool00?l00?ooool0
0?ooool00?l01?ooo`D00?l2oooo00T00?ooooooooooool00?ooool00?ooool00?l00_ooo`800?l5
oooo00<00?ooooooool00P00o`;oool2003o0_ooo`03003ooooo003o00coool00`00ooooooooo`02
003o3?ooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`06003o
oooooooo003ooooo003o0oooo`800?l2oooo1000o`?oool2003o1?ooo`03003ooooo003o00<00?l0
0oooo`00o`00o`04oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00oooo`@00?l2oooo00<0
0?ooooooool00_ooo`03003ooooo003o00Coool01000ooooooooo`00o`_oool00`00ooooo`00o`0a
oooo0P00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool06oooo`03003ooooooooo
00Coool01000ooooooooo`00o`?oool01000ooooooooo`00o`?oool00`00ooooo`00o`03oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03
oooo00D00?ooool00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o0oooo`03003ooooooooo00;oool00`00ooooo`00o`02oooo00T00?ooooooooooool00?ooool0
0?ooool00?l00oooo`06003ooooooooo003ooooo003o0_ooo`05003ooooooooo003ooooo00@00?l2
oooo1@00o`04oooo003ooooo003o1?ooo`D00?l2oooo00T00?ooooooooooool00?ooool00?ooool0
0?l00_ooo`800?l5oooo00<00?ooooooool00P00o`04oooo003o003o003o0_ooo`03003ooooo003o
00coool00`00ooooooooo`02003o3?ooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00<0
0?ooool00?l00oooo`06003ooooooooo003ooooo003o0oooo`800?l2oooo1000o`?oool2003o1?oo
o`03003ooooo003o00<00?l00oooo`00o`00o`04oooo00<00?ooool00?l00oooo`03003ooooo003o
00?oool4003o0_ooo`03003ooooooooo00;oool00`00ooooo`00o`04oooo00@00?ooooooool00?l;
oooo00<00?ooool00?l0<_ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo
01_oool00`00ooooooooo`02oooo00<00?ooool00?l00_ooo`05003ooooooooooooo003o00;oool0
1`00ooooooooooooo`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_oo
o`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
2@00ooooooooooooo`00ooooo`00ooooo`00o`03oooo00D00?ooool00?ooool00?l00_ooo`04003o
oooooooo003o0_ooo`06003ooooooooo003ooooo003o0oooo`03003ooooooooo00;oool00`00oooo
o`00o`02oooo00T00?ooooooooooool00?ooool00?ooool00?l00oooo`06003ooooooooo003ooooo
003o0_ooo`05003ooooooooo003ooooo00@00?l2oooo1@00o`04oooo003ooooo003o1?ooo`D00?l2
oooo00T00?ooooooooooool00?ooool00?ooool00?l00_ooo`800?l5oooo00<00?ooooooool00P00
o`04oooo003o003o003o0_ooo`03003ooooo003o00coool00`00ooooooooo`02003o3?ooo`03003o
oooo003o00;oool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`06003ooooooooo003ooooo
003o0oooo`800?l2oooo1000o`?oool2003o1?ooo`03003ooooo003o00<00?l00oooo`00o`00o`04
oooo00<00?ooool00?l00oooo`03003ooooo003o00?oool4003o1oooo`03003ooooo003o00Coool0
1000ooooooooo`00o`_oool00`00ooooo`00o`0boooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool03oooo`03003ooooooooo00Woool00`00ooooooooo`02oooo00<00?ooool0
0?l00_ooo`05003ooooooooooooo003o00;oool01`00ooooooooooooo`00ooooo`00o`03oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03
oooo00D00?ooool00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o0oooo`03003ooooooooo00;oool00`00ooooo`00o`02oooo00T00?ooooooooooool00?ooool0
0?ooool00?l00oooo`08003ooooooooo003ooooo003ooooo003o0oooo`03003ooooo003o00<00?l2
oooo1@00o`04oooo003ooooo003o1?ooo`D00?l2oooo00T00?ooooooooooool00?ooool00?ooool0
0?l00_ooo`800?l5oooo00<00?ooooooool00P00o`04oooo003o003o003o0_ooo`03003ooooo003o
00coool00`00ooooooooo`02003o3?ooo`03003ooooo003o00;oool00`00ooooo`00o`02oooo00<0
0?ooool00?l00oooo`06003ooooooooo003ooooo003o0oooo`800?l2oooo1000o`;oool3003o1?oo
o`03003ooooo003o00H00?l4oooo00<00?ooool00?l00oooo`03003ooooo003o00?oool4003o1ooo
o`03003ooooo003o00Coool01000ooooooooo`00o`_oool00`00ooooo`00o`0boooo0@00007oool0
01Ooool00`000?ooooooo`09oooo00<00?ooooooool03oooo`03003ooooooooo00Woool00`00oooo
ooooo`02oooo00<00?ooool00?l00_ooo`05003ooooooooooooo003o00;oool01`00oooooooooooo
o`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool02@00oooooooooooo
o`00ooooo`00ooooo`00o`03oooo0P00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooo`00o`03oooo00<00?ooooooool00_ooo`03003ooooo003o00;oool02@00oooo
ooooooooo`00ooooo`00ooooo`00o`03oooo00P00?ooooooool00?ooool00?ooool00?l3oooo00<0
0?ooool00?l00`00o`;oool5003o00Coool00?ooool00?l4oooo1@00o`;oool02@00oooooooooooo
o`00ooooo`00ooooo`00o`02oooo0P00o`Goool00`00ooooooooo`02003o00Coool00?l00?l00?l2
oooo00<00?ooool00?l03?ooo`03003ooooooooo00800?l<oooo00<00?ooool00?l00_ooo`03003o
oooo003o00;oool00`00ooooo`00o`03oooo00H00?ooooooool00?ooool00?l3oooo0P00o`;oool4
003o0_ooo`<00?l4oooo00<00?ooool00?l01P00o`Coool00`00ooooo`00o`03oooo00<00?ooool0
0?l00oooo`<00?l8oooo00<00?ooool00?l01?ooo`04003ooooooooo003o2oooo`03003ooooo003o
03;oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0?oooo00<00?oooooo
ool02Oooo`03003ooooooooo00;oool00`00ooooo`00o`02oooo00D00?ooooooooooool00?l00_oo
o`07003ooooooooooooo003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2
oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`09003ooooooooooooo003ooooo003ooooo003o00?oool2003o0_ooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00?oool00`00ooooooooo`02oooo00<00?ooool0
0?l00_ooo`03003ooooooooo00800?l01?ooo`00ooooo`00o`?oool02000ooooooooo`00ooooo`00
ooooo`00o`?oool00`00ooooo`00o`03003o0_ooo`D00?l01?ooo`00ooooo`00o`Coool5003o0_oo
o`09003ooooooooooooo003ooooo003ooooo003o00;oool2003o1Oooo`03003ooooooooo00800?l0
1?ooo`00o`00o`00o`;oool00`00ooooo`00o`0<oooo00<00?ooooooool00P00o`coool00`00oooo
o`00o`02oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool01P00ooooo`00o`00ooooo`00
o`?oool2003o0_ooo`@00?l2oooo0`00o`Coool00`00ooooo`00o`06003o1?ooo`03003ooooo003o
00?oool00`00ooooo`00o`03oooo0`00o`Soool00`00ooooo`00o`04oooo00@00?ooooooool00?l;
oooo00<00?ooool00?l0<_ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo
00ooool00`00ooooooooo`09oooo00<00?ooooooool00_ooo`03003ooooo003o00;oool01@00oooo
ooooooooo`00o`02oooo00L00?ooooooooooool00?ooool00?l00oooo`03003ooooo003o00;oool0
1000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooo`00o`02oooo00T00?ooooooooooool00?ooool00?ooool00?l00oooo`800?l2oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00oooo`03003ooooooooo
00;oool00`00ooooo`00o`02oooo00<00?ooooooool00P00o`04oooo003ooooo003o0oooo`800?l0
1_ooo`00ooooo`00ooooo`00o`?oool00`00ooooo`00o`03003o0_ooo`D00?l01Oooo`00oooooooo
o`00o`03oooo1000o`?oool00`00ooooooooo`02003o00Coool00?ooool00?l2oooo0P00o`Goool0
0`00ooooo`00o`02003o00Coool00?l00?l00?l2oooo00<00?ooool00?l03?ooo`03003ooooooooo
00800?l<oooo0`00o`;oool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`06003ooooo003o
003ooooo003o0oooo`800?l2oooo1000o`;oool3003o1?ooo`03003ooooo003o00H00?l4oooo00<0
0?ooool00?l00oooo`03003ooooo003o00?oool3003o2?ooo`03003ooooo003o00Coool01000oooo
ooooo`00o`_oool00`00ooooo`00o`0boooo0@00007oool001Ooool00`000?ooooooo`09oooo00<0
0?ooooooool03oooo`03003ooooooooo00Woool00`00ooooooooo`02oooo00<00?ooool00?l00_oo
o`05003ooooooooooooo003o00;oool01`00ooooooooooooo`00ooooo`00o`03oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooo003o00;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03oooo0P00
o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`03oooo00<0
0?ooooooool00_ooo`03003ooooo003o00;oool00`00ooooooooo`02003o00Coool00?ooool00?l3
oooo0P00o`06oooo003ooooo003ooooo003o0oooo`03003ooooo003o00<00?l2oooo1@00o`05oooo
003ooooooooo003o00;oool2003o00?oool00?l00?l00oooo`03003ooooooooo00800?l01?ooo`00
ooooo`00o`;oool2003o1Oooo`03003ooooo003o00800?l01?ooo`00o`00o`00o`;oool00`00oooo
o`00o`0<oooo00<00?ooooooool00P00o`coool2003o0oooo`03003ooooo003o00;oool00`00oooo
o`00o`03oooo00H00?ooool00?l00?ooool00?l3oooo0P00o`;oool4003o0_ooo`<00?l4oooo00<0
0?ooool00?l01P00o`Coool00`00ooooo`00o`03oooo00<00?ooool00?l00oooo`<00?l8oooo00<0
0?ooool00?l01?ooo`04003ooooooooo003o2oooo`03003ooooo003o03;oool100000Oooo`005ooo
o`030000oooooooo00Woool00`00ooooooooo`0?oooo00<00?ooooooool02Oooo`03003ooooooooo
00;oool00`00ooooo`00o`02oooo00D00?ooooooooooool00?l00_ooo`07003ooooooooooooo003o
oooo003o00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`09003ooooooooooooo003o
oooo003ooooo003o00?oool2003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00?oool00`00ooooooooo`02oooo00<00?ooool00?l00_ooo`03003ooooooooo
00800?l01?ooo`00ooooo`00o`?oool3003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`03
003o0_ooo`D00?l01Oooo`00ooooooooo`00o`02oooo0P00o`;oool01@00ooooooooooooo`00o`02
oooo0P00o`04oooo003ooooo003o0_ooo`800?l5oooo00<00?ooool00?l00P00o`04oooo003o003o
003o0_ooo`03003ooooo003o00coool00`00ooooooooo`02003o3?ooo`800?l3oooo00<00?ooool0
0?l00_ooo`800?l4oooo00H00?ooool00?l00?ooool00?l3oooo0P00o`;oool2003o00Coool00?oo
ooooool3003o1?ooo`03003ooooo003o00H00?l4oooo00<00?ooool00?l00oooo`03003ooooo003o
00?oool2003o2Oooo`03003ooooo003o00Coool01000ooooooooo`00o`_oool00`00ooooo`00o`0b
oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool03oooo`03003ooooooooo
00Goool01@00ooooooooooooo`00o`04oooo0P00o`?oool01@00ooooooooooooo`00o`02oooo00L0
0?ooooooooooool00?ooool00?l00oooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool0
1P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l00oooo`800?l2oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l00oooo`03003ooooooooo00;oool00`00ooooo`00o`02
oooo00<00?ooooooool00P00o`04oooo003ooooo003o0oooo`<00?l2oooo00<00?ooool00?l00ooo
o`03003ooooo003o00<00?l2oooo1@00o`05oooo003ooooooooo003o00;oool2003o0_ooo`05003o
oooooooooooo003o00;oool2003o00Coool00?ooool00?l2oooo0P00o`Goool00`00ooooo`00o`02
003o00Coool00?l00?l00?l2oooo00<00?ooool00?l03?ooo`03003ooooooooo00800?l<oooo0P00
o`?oool00`00ooooo`00o`02oooo0P00o`Coool00`00ooooo`00o`02oooo00@00?ooooooooooool2
003o0_ooo`800?l01?ooo`00ooooooooo`<00?l4oooo00<00?ooool00?l01P00o`Coool00`00oooo
o`00o`03oooo00<00?ooool00?l00oooo`800?l9oooo00<00?ooool00?l01?ooo`04003ooooooooo
003o2oooo`03003ooooo003o03;oool100000Oooo`005oooo`80000:oooo00<00?ooooooool03ooo
o`03003ooooooooo00Coool2003o0oooo`03003ooooooooo00;oool2003o0oooo`05003ooooooooo
oooo003o00;oool01000ooooooooo`00o`;oool01`00ooooooooooooo`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00?oool2003o0_ooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00?oool00`00ooooooooo`02
oooo00<00?ooool00?l00_ooo`03003ooooo003o00800?l01?ooo`00ooooo`00o`?oool3003o0_oo
o`03003ooooo003o00?oool00`00ooooo`00o`03003o0_ooo`D00?l01Oooo`00ooooooooo`00o`02
oooo0P00o`Koool00`00ooooooooo`02003o00Coool00?ooool00?l2oooo0P00o`Goool00`00oooo
o`00o`02003o00Coool00?l00?l00?l2oooo0`00o`coool00`00ooooooooo`02003o3?ooo`800?l3
oooo00<00?ooool00?l00_ooo`800?l4oooo00<00?ooool00?l00_ooo`04003ooooooooooooo0P00
o`;oool2003o00Coool00?ooooooool3003o1?ooo`03003ooooo003o00H00?l4oooo00<00?ooool0
0?l00oooo`03003ooooo003o00?oool2003o2Oooo`03003ooooo003o00Coool01000ooooooooo`00
o`_oool00`00ooooo`00o`0aoooo0P00007oool001Ooool00`000?ooooooo`09oooo00<00?oooooo
ool03oooo`03003ooooooooo00Coool2003o0oooo`03003ooooooooo00;oool2003o0oooo`05003o
oooooooooooo003o00;oool01000ooooooooo`00o`;oool01`00ooooooooooooo`00ooooo`00o`02
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00<00?ooool00?l00ooo
o`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooo`00o`03oooo0P00o`;oool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`03oooo00<00?oooooo
ool00_ooo`03003ooooo003o00;oool00`00ooooo`00o`02003o00Coool00?ooool00?l3oooo0`00
o`;oool00`00ooooo`00o`03oooo00<00?ooool00?l00`00o`;oool5003o00Goool00?ooooooool0
0?l00_ooo`800?l6oooo00<00?ooooooool00P00o`04oooo003ooooo003o0_ooo`800?l5oooo00<0
0?ooool00?l00P00o`04oooo003o003o003o0oooo`800?l<oooo00<00?ooooooool00P00o`coool2
003o0oooo`<00?l2oooo0P00o`Coool00`00ooooo`00o`02oooo0`00o`03oooo003o003o00;oool2
003o00Coool00?ooooooool3003o1?ooo`03003ooooo003o00H00?l4oooo00<00?ooool00?l00ooo
o`03003ooooo003o00?oool2003o2Oooo`03003ooooo003o00Coool01000ooooooooo`00o`_oool0
0`00ooooo`00o`0boooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?ooooooool03ooo
o`03003ooooooooo00Coool2003o0oooo`03003ooooooooo00;oool2003o0oooo`05003ooooooooo
oooo003o00;oool01000ooooooooo`00o`;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03
oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00oooo`800?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l02?ooo`03003ooooo003o00;oool0
0`00ooooo`00o`02003o00Coool00?ooool00?l3oooo0`00o`;oool00`00ooooo`00o`03oooo00<0
0?ooool00?l00`00o`;oool5003o00Goool00?ooooooool00?l00_ooo`800?l6oooo00<00?oooooo
ool00P00o`04oooo003ooooo003o0_ooo`800?l5oooo00<00?ooool00?l00P00o`04oooo003o003o
003o0oooo`800?l<oooo00<00?ooooooool00P00o`coool2003o0oooo`<00?l2oooo0P00o`Coool0
0`00ooooo`00o`02oooo1P00o`;oool2003o00Coool00?ooooooool3003o0oooo`03003ooooooooo
00L00?l4oooo00<00?ooool00?l00oooo`03003ooooo003o00?oool2003o2Oooo`03003ooooo003o
00Coool01000ooooooooo`00o`_oool00`00ooooo`00o`0boooo0@00007oool001Ooool00`000?oo
ooooo`09oooo00<00?ooooooool03oooo`03003ooooooooo00Coool2003o0oooo`04003ooooooooo
oooo0`00o`?oool01@00ooooooooooooo`00o`02oooo00@00?ooooooool00?l2oooo00T00?oooooo
ooooool00?ooool00?ooool00?l00oooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
0`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00?oool2003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00Soool00`00ooooo`00o`02oooo00<00?ooool00?l00P00o`04oooo003ooooo003o0oooo`<00?l2
oooo00<00?ooool00?l00oooo`03003ooooo003o00<00?l2oooo1@00o`05oooo003ooooooooo003o
00;oool00`00ooooooooo`05oooo00<00?ooooooool00P00o`04oooo003ooooo003o0_ooo`800?l5
oooo00<00?ooool00?l00P00o`04oooo003o003o003o0oooo`800?l<oooo00@00?ooooooool00?l=
oooo00<00?ooooooool00_ooo`<00?l2oooo0P00o`Coool00`00ooooo`00o`02oooo1P00o`;oool2
003o00Coool00?ooooooool3003o0oooo`03003ooooooooo00L00?l4oooo00<00?ooool00?l00ooo
o`03003ooooo003o00?oool2003o2_ooo`800?l4oooo00@00?ooooooool00?l;oooo0P00oc?oool1
00000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0?oooo0P00o`Goool2003o0ooo
o`04003ooooooooooooo0`00o`?oool01@00ooooooooooooo`00o`02oooo00@00?ooooooool00?l2
oooo00T00?ooooooooooool00?ooool00?ooool00?l00oooo`04003ooooooooo003o0_ooo`03003o
oooo003o00;oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00?oool2003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l00_ooo`03003ooooo003o00800?l01?ooo`00ooooo`00
o`?oool3003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`03003o0_ooo`D00?l01Oooo`00
ooooooooo`00o`02oooo00<00?ooooooool01Oooo`03003ooooooooo00800?l01?ooo`00ooooo`00
o`;oool2003o1Oooo`06003ooooo003ooooo003ooooo0P00o`Coool2003o3?ooo`04003ooooooooo
003o3Oooo`03003ooooooooo00?oool2003o0_ooo`800?l4oooo0`00o`;oool6003o0_ooo`800?l0
1?ooo`00ooooooooo`<00?l3oooo00<00?ooooooool01`00o`Coool00`00ooooo`00o`03oooo00<0
0?ooool00?l00oooo`800?l:oooo0P00o`Coool01000ooooooooo`00o`_oool2003o<oooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00ooool2003o0_ooo`03003ooooooooo
00800?l3oooo00@00?ooooooooooool3003o0oooo`05003ooooooooooooo003o00;oool01000oooo
ooooo`00o`;oool02@00ooooooooooooo`00ooooo`00ooooo`00o`03oooo00<00?ooool00?l00ooo
o`03003ooooo003o00;oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`03003ooooo003o00?oool2003o0oooo`03003ooooo003o00;oool00`00ooooo`00o`03
oooo00<00?ooool00?l02?ooo`03003ooooo003o00;oool00`00ooooo`00o`02003o00Coool00?oo
ool00?l3oooo0`00o`;oool00`00ooooo`00o`03oooo00<00?ooool00?l00`00o`;oool5003o00Go
ool00?ooooooool00?l00_ooo`03003ooooooooo00Goool00`00ooooooooo`02003o00Coool00?oo
ool00?l2oooo0P00o`Goool01P00ooooo`00ooooo`00ooooo`800?l4oooo00<00?ooooooool02ooo
o`04003ooooooooo003o4oooo`800?l2oooo0P00o`Coool3003o0oooo`D00?l2oooo0P00o`04oooo
003ooooooooo0`00o`?oool00`00ooooooooo`07003o1?ooo`<00?l3oooo00<00?ooool00?l00ooo
o`800?l:oooo0P00o`Coool01000ooooooooo`00o`_oool2003o<oooo`400001oooo000Goooo00<0
003oooooool02Oooo`03003ooooooooo00ooool2003o0_ooo`03003ooooooooo00800?l3oooo00@0
0?ooooooooooool3003o0oooo`05003ooooooooooooo003o00;oool01000ooooooooo`00o`;oool0
2@00ooooooooooooo`00ooooo`00ooooo`00o`03oooo00<00?ooool00?l00oooo`03003ooooo003o
00;oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003o
oooo003o00?oool2003o0oooo`03003ooooo003o00;oool00`00ooooo`00o`03oooo00<00?ooool0
0?l02?ooo`03003ooooo003o00;oool00`00ooooo`00o`02003o00Coool00?ooool00?l3oooo0`00
o`;oool00`00ooooo`00o`03oooo00<00?ooool00?l00`00o`;oool5003o00Goool00?ooooooool0
0?l00_ooo`03003ooooooooo00Goool00`00ooooooooo`02003o00Coool00?ooool00?l2oooo0P00
o`Goool2003o0_ooo`04003ooooo003o003o1?ooo`03003ooooooooo00_oool01000ooooooooo`00
oa?oool2003o0_ooo`800?l4oooo0`00o`?oool5003o0_ooo`800?l01?ooo`00ooooooooo`<00?l3
oooo00<00?ooooooool01`00o`Goool2003o0oooo`03003ooooo003o00?oool2003o2_ooo`800?l4
oooo00@00?ooooooool00?l;oooo0P00oc?oool100000Oooo`005oooo`030000oooooooo00Woool0
0`00ooooooooo`0?oooo0P00o`;oool00`00ooooooooo`02003o0oooo`04003ooooooooooooo0`00
o`?oool01@00ooooooooooooo`00o`02oooo00@00?ooooooool00?l2oooo00T00?ooooooooooool0
0?ooool00?ooool00?l00oooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00<00?ooool0
0?l00oooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooo`00o`03oooo0P00
o`?oool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`03003ooooo003o00Soool00`00oooo
o`00o`02oooo00<00?ooool00?l00P00o`04oooo003ooooo003o0oooo`<00?l2oooo00<00?ooool0
0?l00oooo`03003ooooo003o00<00?l2oooo1@00o`05oooo003ooooooooo003o00;oool00`00oooo
ooooo`05oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`03003ooooooooo00Coool2
003o0_ooo`@00?l4oooo00<00?ooooooool02oooo`04003ooooooooo003o4oooo`800?l2oooo0P00
o`Coool3003o0oooo`D00?l2oooo0P00o`07oooo003ooooooooo003ooooo003o00?oool00`00oooo
ooooo`02003o00?oool00?l00?l00P00o`Goool2003o0oooo`03003ooooo003o00?oool2003o2_oo
o`800?l4oooo00@00?ooooooool00?l;oooo0P00oc?oool100000Oooo`005oooo`030000oooooooo
00Woool00`00ooooooooo`0?oooo0P00o`;oool00`00ooooooooo`02003o0oooo`04003ooooooooo
oooo0`00o`?oool01@00ooooooooooooo`00o`02oooo00@00?ooooooool00?l2oooo00D00?oooooo
ooooool00?l00_ooo`800?l3oooo00<00?ooool00?l00oooo`03003ooooo003o00;oool00`00oooo
o`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00?oool0
0`00ooooooooo`02oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`08
oooo00<00?ooool00?l00_ooo`03003ooooo003o00800?l01?ooo`00ooooo`00o`?oool3003o0_oo
o`03003ooooo003o00?oool00`00ooooo`00o`03003o0_ooo`D00?l01Oooo`00ooooooooo`00o`02
oooo00<00?ooooooool01Oooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool00`00oooo
ooooo`04oooo0P00o`;oool3003o1Oooo`03003ooooooooo00_oool01000ooooooooo`00oa?oool2
003o0oooo`03003ooooooooo00;oool3003o0oooo`D00?l2oooo0P00o`07oooo003ooooooooo003o
oooo003o00?oool00`00ooooooooo`02003o00Goool00?l00?ooool00?l01Oooo`800?l3oooo00<0
0?ooool00?l00oooo`800?l:oooo0P00o`Coool01000ooooooooo`00o`_oool2003o<oooo`400001
oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00ooool2003o0_ooo`03003ooooooooo
00800?l3oooo00@00?ooooooooooool3003o0oooo`05003ooooooooooooo003o00;oool01000oooo
ooooo`00o`;oool01@00ooooooooooooo`00o`02oooo0P00o`?oool00`00ooooo`00o`03oooo00<0
0?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2
oooo0`00o`?oool00`00ooooooooo`02oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l00_ooo`09003ooooo003ooooo003ooooo003ooooo003o
00?oool3003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`03003o0_ooo`D00?l01Oooo`00
ooooooooo`00o`02oooo00<00?ooooooool01Oooo`04003ooooooooo003o0_ooo`03003ooooo003o
00;oool00`00ooooooooo`04oooo0P00o`;oool3003o1Oooo`03003ooooooooo00_oool01000oooo
ooooo`00oa?oool2003o0oooo`03003ooooooooo00;oool2003o1?ooo`D00?l2oooo00@00?oooooo
ool00?l2oooo00<00?ooool00?l00oooo`03003ooooooooo00800?l01Oooo`00ooooooooo`00o`05
oooo0P00o`?oool00`00ooooo`00o`03oooo0P00o`[oool2003o1?ooo`04003ooooooooo003o2ooo
o`800?lcoooo0@00007oool001Ooool200002_ooo`03003ooooooooo00ooool2003o0_ooo`03003o
oooooooo00800?l3oooo00@00?ooooooooooool3003o0oooo`05003ooooooooooooo003o00;oool0
1000ooooooooo`00o`;oool01@00ooooooooooooo`00o`02oooo0P00o`?oool00`00ooooo`00o`03
oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo0`00o`Soool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`03003ooooo003o
00Soool00`00ooooo`00o`02oooo00T00?ooool00?ooool00?ooool00?ooool00?l00oooo`<00?l2
oooo00<00?ooool00?l00oooo`06003ooooo003o003ooooo003o0_ooo`800?l01?ooo`00o`00o`00
o`?oool01000ooooooooo`00o`Ooool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00<0
0?ooooooool01?ooo`800?l2oooo0`00o`Goool00`00ooooooooo`0;oooo00@00?ooooooool00?lC
oooo0P00o`?oool00`00ooooooooo`02oooo0P00o`Coool5003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00?oool00`00ooooooooo`02003o00Goool00?ooooooool00?l01Oooo`800?l3
oooo00<00?ooool00?l00oooo`800?l:oooo0P00o`Coool01000ooooooooo`00o`_oool2003o<_oo
o`800001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00ooool2003o0_ooo`03003o
oooooooo00800?l2oooo0P00o`;oool4003o0oooo`05003ooooooooooooo003o00;oool01000oooo
ooooo`00o`;oool01@00ooooooooooooo`00o`02oooo0P00o`?oool00`00ooooo`00o`03oooo00<0
0?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2
oooo0P00o`Woool00`00ooooo`00o`02oooo00<00?ooool00?l00oooo`03003ooooo003o00Soool0
0`00ooooo`00o`02oooo00T00?ooool00?ooool00?ooool00?ooool00?l00oooo`03003ooooo003o
00;oool00`00ooooo`00o`03oooo00H00?ooool00?l00?ooool00?l2oooo0P00o`04oooo003o003o
003o0oooo`04003ooooo003o003o1oooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
0`00ooooooooo`04oooo0P00o`;oool3003o1Oooo`03003ooooooooo00_oool01000ooooooooo`00
oa?oool2003o0oooo`03003ooooooooo00;oool2003o1?ooo`D00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooool00?l00oooo`03003ooooooooo00800?l01Oooo`00ooooooooo`00o`05oooo0P00
o`?oool00`00ooooo`00o`03oooo00<00?ooooooool02Oooo`800?l4oooo00@00?ooooooool00?l;
oooo0P00oc?oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`0?oooo0P00
o`;oool00`00ooooooooo`02003o0_ooo`800?l2oooo1000o`?oool01@00ooooooooooooo`00o`02
oooo00@00?ooool00?l00?l2oooo00D00?ooooooooooool00?l00_ooo`800?l3oooo00<00?ooool0
0?l00oooo`03003ooooo003o00;oool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o0_ooo`800?l9oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool00`00oooo
o`00o`08oooo00<00?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`05oooo00H0
0?ooooooool00?ooool00?l3oooo00H00?ooool00?l00?ooool00?l2oooo0P00o`04oooo003o003o
003o0oooo`04003ooooo003o003o1oooo`04003ooooooooo003o0_ooo`03003ooooo003o00Woool2
003o0_ooo`<00?l5oooo00<00?ooooooool02oooo`04003ooooooooo003o4oooo`800?l3oooo00<0
0?ooooooool00_ooo`800?l4oooo1@00o`03oooo003ooooo00;oool01P00ooooooooo`00ooooo`00
o`?oool00`00ooooooooo`02003o00?oool00?ooool01oooo`800?l3oooo00<00?ooool00?l00ooo
o`03003ooooooooo00Woool2003o1?ooo`04003ooooooooo003o2oooo`800?lcoooo0@00007oool0
01Ooool00`000?ooooooo`09oooo00<00?ooooooool01Oooo`03003ooooooooo00Ooool2003o0_oo
o`03003ooooooooo00800?l2oooo0P00o`03oooo003o003o00<00?l3oooo00D00?ooooooooooool0
0?l00_ooo`04003ooooo003o003o0_ooo`05003ooooooooooooo003o00;oool2003o0oooo`03003o
oooo003o00?oool3003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo0P00o`Woool2003o0oooo`03003ooooo003o00?oool00`00ooooo`00o`08oooo00<0
0?ooool00?l00_ooo`03003ooooo003o00?oool00`00ooooo`00o`05oooo00H00?ooooooool00?oo
ool00?l3oooo00H00?ooool00?l00?ooool00?l2oooo0P00o`;oool2003o0oooo`04003ooooo003o
003o1oooo`04003ooooo003o003o0_ooo`03003ooooo003o00Woool2003o0_ooo`800?l6oooo00<0
0?ooooooool02oooo`04003ooooooooo003o4oooo`800?l8oooo0P00o`Coool5003o00?oool00?oo
ool00_ooo`06003ooooooooo003ooooo003o0oooo`03003ooooooooo00800?l00oooo`00ooooo`07
oooo0P00o`?oool00`00ooooo`00o`03oooo00<00?ooooooool02Oooo`800?l4oooo00@00?oooooo
ool00?l;oooo0P00oc?oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`05
oooo00<00?ooooooool01oooo`800?l2oooo00<00?ooooooool00P00o`;oool2003o00?oool00?l0
0?l00`00o`?oool01@00ooooooooooooo`00o`02oooo1000o`;oool01@00ooooooooooooo`00o`02
oooo0P00o`?oool00`00ooooo`00o`03oooo0`00o`;oool00`00ooooo`00o`03oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`800?l9oooo0P00o`?oool00`00ooooo`00o`03oooo00<0
0?ooool00?l02?ooo`03003ooooo003o00;oool00`00ooooo`00o`03oooo00<00?ooool00?l01Ooo
o`06003ooooooooo003ooooo003o0oooo`06003ooooo003o003ooooo003o0_ooo`800?l2oooo0P00
o`?oool01000ooooo`00o`00o`Ooool01000ooooo`00o`00o`;oool00`00ooooo`00o`09oooo0P00
o`;oool2003o1_ooo`03003ooooooooo00_oool01000ooooooooo`00oa?oool2003o2?ooo`800?l4
oooo0`00o`04oooo003ooooo003o0oooo`06003ooooooooo003ooooo003o0oooo`03003ooooooooo
00800?l00oooo`00ooooo`07oooo0P00o`?oool00`00ooooo`00o`03oooo00<00?ooooooool02Ooo
o`03003ooooooooo00?oool01000ooooooooo`00o`_oool2003o<oooo`400001oooo000Goooo00<0
003oooooool02Oooo`03003ooooooooo00Goool00`00ooooooooo`07oooo0P00o`;oool00`00oooo
ooooo`02003o0_ooo`800?l00oooo`00o`00o`03003o0oooo`05003ooooooooooooo003o00;oool4
003o0_ooo`05003ooooooooooooo003o00;oool2003o0oooo`03003ooooo003o00?oool3003o0_oo
o`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l3oooo00<00?oooooo
ool01oooo`800?l3oooo00<00?ooool00?l00oooo`03003ooooo003o00Soool00`00ooooo`00o`02
oooo00<00?ooool00?l00oooo`03003ooooo003o00Soool3003o0oooo`06003ooooo003o003ooooo
003o0_ooo`800?l2oooo0P00o`?oool01000ooooo`00o`00o`Ooool01000ooooo`00o`00o`;oool0
0`00ooooo`00o`09oooo0P00o`;oool2003o1_ooo`03003ooooooooo00_oool01000ooooooooo`00
oa?oool2003o2?ooo`800?l4oooo0`00o`04oooo003ooooo003o0oooo`06003ooooooooo003ooooo
003o0oooo`03003ooooooooo00800?l:oooo0P00o`?oool00`00ooooo`00o`03oooo00<00?oooooo
ool03oooo`04003ooooooooo003o@?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003o
oooooooo00Goool00`00ooooooooo`07oooo0P00o`;oool00`00ooooooooo`02003o0_ooo`800?l0
0oooo`00o`00o`03003o0oooo`05003ooooooooooooo003o00;oool3003o0oooo`05003ooooooooo
oooo003o00;oool2003o0oooo`03003ooooo003o00?oool3003o0_ooo`03003ooooo003o00?oool0
0`00ooooo`00o`02oooo00@00?ooooooool00?l3oooo00<00?ooooooool01oooo`800?l3oooo00<0
0?ooool00?l01?ooo`800?l8oooo00<00?ooool00?l00oooo`800?l3oooo00<00?ooool00?l02?oo
o`<00?l3oooo00H00?ooool00?l00?ooool00?l2oooo0P00o`;oool2003o0oooo`04003ooooo003o
003o1oooo`04003ooooo003o003o0_ooo`03003ooooo003o00Woool2003o0_ooo`800?l6oooo00<0
0?ooooooool02oooo`04003ooooooooo003o4oooo`800?l8oooo0P00o`Coool3003o00Coool00?oo
ool00?l3oooo00H00?ooooooool00?ooool00?l3oooo00<00?ooooooool00P00o`[oool2003o0ooo
o`03003ooooo003o00?oool00`00ooooooooo`0?oooo00@00?ooooooool00?m0oooo0@00007oool0
01Ooool00`000?ooooooo`09oooo00<00?ooooooool01Oooo`03003ooooooooo00Ooool2003o0_oo
o`03003ooooooooo00800?l2oooo0P00o`03oooo003o003o00<00?l3oooo00D00?ooooooooooool0
0?l00_ooo`<00?l3oooo00D00?ooooooooooool00?l00_ooo`800?l3oooo00<00?ooool00?l00ooo
o`<00?l2oooo00<00?ooool00?l00oooo`03003ooooo003o00;oool01000ooooooooo`00o`goool2
003o0oooo`03003ooooo003o00Coool2003o2?ooo`03003ooooo003o00?oool2003o0oooo`03003o
oooo003o00Soool3003o0oooo`06003ooooo003o003ooooo003o0_ooo`800?l2oooo0P00o`?oool0
1000ooooo`00o`00o`Ooool01000ooooo`00o`00o`;oool00`00ooooo`00o`09oooo0P00o`;oool2
003o5?ooo`04003ooooooooo003o4oooo`800?l8oooo0P00o`Coool3003o00Coool00?ooool00?l3
oooo00H00?ooooooool00?ooool00?l3oooo00<00?ooooooool00P00o`[oool2003o0oooo`03003o
oooo003o01Goool01000ooooooooo`00od3oool100000Oooo`005oooo`030000oooooooo00Woool0
0`00ooooooooo`05oooo00<00?ooooooool01oooo`800?l2oooo00<00?ooooooool00P00o`;oool2
003o00?oool00?l00?l00`00o`?oool01@00ooooooooooooo`00o`02oooo0`00o`?oool01@00oooo
ooooooooo`00o`02oooo0P00o`?oool00`00ooooo`00o`04oooo0P00o`;oool00`00ooooo`00o`03
oooo00<00?ooool00?l00_ooo`04003ooooooooo003o3Oooo`800?l3oooo00<00?ooool00?l01?oo
o`800?l8oooo00<00?ooool00?l00oooo`800?l3oooo00<00?ooool00?l02Oooo`800?l3oooo00H0
0?ooool00?l00?ooool00?l2oooo0P00o`;oool2003o0oooo`04003ooooo003o003o1oooo`04003o
oooo003o003o0_ooo`03003ooooo003o00Woool2003o0_ooo`800?lDoooo00@00?ooooooool00?lC
oooo0P00o`Soool2003o1?ooo`<00?l01?ooo`00ooooo`00o`?oool01P00ooooooooo`00ooooo`00
o`?oool00`00ooooooooo`02003o2_ooo`800?l3oooo00<00?ooool00?l05Oooo`04003ooooooooo
003o@?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00Goool00`00oooo
ooooo`07oooo0P00o`;oool00`00ooooooooo`02003o0_ooo`800?l00oooo`00o`00o`03003o0ooo
o`05003ooooooooooooo003o00;oool3003o0oooo`05003ooooooooooooo003o00;oool2003o0ooo
o`03003ooooo003o00Coool2003o0_ooo`03003ooooo003o00?oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l=oooo0P00o`?oool00`00ooooo`00o`04oooo0P00o`Soool00`00ooooo`00o`03
oooo0P00o`?oool00`00ooooo`00o`09oooo0P00o`?oool01P00ooooo`00o`00ooooo`00o`;oool2
003o0_ooo`800?l3oooo00@00?ooool00?l00?l7oooo00@00?ooool00?l00?l2oooo00<00?ooool0
0?l02Oooo`800?l2oooo0P00oaCoool01000ooooooooo`00oa?oool2003o2?ooo`800?l4oooo0`00
o`04oooo003ooooo003o0oooo`06003ooooooooo003ooooo003o0oooo`03003ooooooooo00800?l:
oooo0P00o`?oool00`00ooooo`00o`0Eoooo00@00?ooooooool00?m0oooo0@00007oool001Ooool2
00002_ooo`03003ooooooooo00Goool00`00ooooooooo`07oooo0P00o`;oool00`00ooooooooo`02
003o0_ooo`800?l00oooo`00o`00o`03003o0oooo`04003ooooooooo003o0oooo`<00?l3oooo00D0
0?ooooooooooool00?l00_ooo`800?l3oooo00<00?ooool00?l01?ooo`800?l2oooo00<00?ooool0
0?l00oooo`03003ooooo003o00;oool01000ooooooooo`00o`goool2003o0oooo`03003ooooo003o
00Coool2003o2?ooo`03003ooooo003o00?oool2003o0oooo`03003ooooo003o00Woool2003o0ooo
o`06003ooooo003o003ooooo003o0_ooo`800?l2oooo0P00o`?oool01000ooooo`00o`00o`Ooool0
1000ooooo`00o`00o`;oool00`00ooooo`00o`09oooo0P00o`;oool2003o5?ooo`04003ooooooooo
003o4oooo`800?l8oooo0P00o`Koool01@00ooooo`00ooooo`00o`03oooo00H00?ooooooool00?oo
ool00?l3oooo00<00?ooooooool00P00o`[oool2003o0oooo`03003ooooo003o01Goool01000oooo
ooooo`00ocooool200000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`05oooo00<0
0?ooooooool01oooo`800?l2oooo0P00o`03oooo003o003o00;oool2003o00?oool00?l00?l00`00
o`?oool01000ooooooooo`00o`Coool00`00ooooooooo`02oooo00D00?ooooooooooool00?l00_oo
o`800?l3oooo00<00?ooool00?l01?ooo`800?l2oooo00<00?ooool00?l00oooo`03003ooooo003o
00;oool01000ooooooooo`00o`goool2003o0oooo`03003ooooo003o00Coool2003o2?ooo`03003o
oooo003o00?oool2003o0oooo`03003ooooo003o00Woool2003o0oooo`06003ooooo003o003ooooo
003o0_ooo`04003ooooooooooooo0P00o`?oool01000ooooo`00o`00o`Ooool01000ooooo`00o`00
o`;oool00`00ooooo`00o`09oooo0P00o`;oool2003o5?ooo`04003ooooooooo003o4oooo`800?l8
oooo0P00o`Koool01@00ooooo`00ooooo`00o`03oooo00H00?ooooooool00?ooool00?l3oooo00<0
0?ooooooool00P00o`[oool2003o0oooo`03003ooooo003o01Goool01000ooooooooo`00od3oool1
00000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`05oooo00<00?ooooooool01ooo
o`800?l2oooo0P00o`03oooo003o003o00;oool2003o00?oool00?l00?l00`00o`?oool01000oooo
ooooo`00o`Coool00`00ooooooooo`02oooo00D00?ooooooooooool00?l00_ooo`800?l3oooo00<0
0?ooool00?l01Oooo`06003ooooooooo003ooooo003o0oooo`03003ooooo003o00;oool01000oooo
ooooo`00o`goool2003o0oooo`03003ooooo003o00Coool2003o2?ooo`03003ooooo003o00?oool2
003o0oooo`03003ooooo003o00koool00`00ooooo`00o`02oooo00@00?ooooooool00?l3oooo0P00
o`?oool01000ooooo`00o`00o`Ooool01000ooooo`00o`00o`;oool00`00ooooo`00o`09oooo0P00
o`;oool2003o5?ooo`04003ooooooooo003o4oooo`800?l8oooo0P00o`Koool01@00ooooo`00oooo
o`00o`03oooo00H00?ooooooool00?ooool00?l3oooo00<00?ooooooool00P00o`[oool2003o0ooo
o`03003ooooo003o01Goool01000ooooooooo`00od3oool100000Oooo`005oooo`030000oooooooo
00Woool00`00ooooooooo`05oooo00<00?ooooooool01oooo`800?l2oooo0P00o`03oooo003o003o
00;oool2003o00?oool00?l00?l00`00o`?oool01000ooooooooo`00o`Coool00`00ooooooooo`02
oooo00D00?ooooooooooool00?l00_ooo`800?l3oooo00<00?ooool00?l02?ooo`03003ooooo003o
00?oool00`00ooooo`00o`02oooo00@00?ooooooool00?l=oooo0P00o`?oool00`00ooooo`00o`04
oooo0P00o`Soool00`00ooooo`00o`03oooo0P00o`?oool00`00ooooo`00o`0>oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0oooo`800?l3oooo00@00?ooool00?l00?l7oooo00@00?ooool0
0?l00?l2oooo00<00?ooool00?l02_ooo`03003ooooooooo00800?lDoooo00@00?ooooooool00?lM
oooo0P00o`Koool01@00ooooo`00ooooo`00o`03oooo0P00o`04oooo003ooooo003o0oooo`03003o
oooooooo00800?l;oooo00L00?ooooooooooool00?ooool00?l05Oooo`04003ooooooooo003o@?oo
o`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00Goool00`00ooooooooo`07
oooo0P00o`;oool2003o00?oool00?l00?l00_ooo`800?l00oooo`00o`00o`03003o0oooo`04003o
oooooooo003o1?ooo`03003ooooooooo00;oool01000ooooooooo`00o`?oool2003o0oooo`03003o
oooo003o00Soool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo003o3Ooo
o`800?l3oooo00<00?ooool00?l01?ooo`800?l8oooo00<00?ooool00?l00oooo`800?l3oooo00<0
0?ooool00?l03_ooo`03003ooooo003o00;oool01000ooooo`00o`00o`?oool2003o0oooo`04003o
oooo003o003o1oooo`04003ooooo003o003o0_ooo`03003ooooo003o00[oool00`00ooooooooo`02
003o5?ooo`04003ooooooooo003o7Oooo`800?l6oooo00D00?ooool00?ooool00?l00oooo`@00?l0
0oooo`00ooooo`02oooo00<00?ooooooool00P00o`_oool01`00ooooooooooooo`00ooooo`00o`0E
oooo00@00?ooooooool00?m0oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?oooooo
ool01Oooo`03003ooooooooo00Ooool2003o0_ooo`800?l00oooo`00o`00o`02oooo0P00o`03oooo
003o003o00<00?l3oooo00@00?ooooooool00?l9oooo00@00?ooooooool00?l3oooo0P00o`?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l00oooo`03003ooooo003o00;oool01000ooooooooo`00
o`goool2003o0oooo`03003ooooo003o00Coool2003o2?ooo`03003ooooo003o00?oool2003o0ooo
o`03003ooooo003o00koool00`00ooooo`00o`02oooo00@00?ooool00?l00?l3oooo0P00o`?oool0
1000ooooo`00o`00o`Ooool01000ooooo`00o`00o`;oool00`00ooooo`00o`0:oooo00<00?oooooo
ool00P00oaCoool2003o00?oool00?ooool07?ooo`800?l6oooo00<00?ooooooool00P00o`?oool4
003o00?oool00?ooool00_ooo`03003ooooooooo00800?l;oooo00L00?ooooooooooool00?ooool0
0?l05Oooo`04003ooooooooo003o@?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003o
oooooooo00Goool00`00ooooooooo`07oooo0P00o`;oool2003o00?oool00?l00?l00_ooo`800?l0
1_ooo`00o`00o`00ooooo`00o`?oool01000ooooooooo`00o`Woool01000ooooooooo`00o`?oool2
003o0oooo`03003ooooo003o00Soool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o3Oooo`800?l3oooo00<00?ooool00?l01?ooo`800?l8oooo00<00?ooool00?l00ooo
o`800?l3oooo00<00?ooool00?l03_ooo`03003ooooo003o00;oool01000ooooo`00o`00o`?oool2
003o0oooo`04003ooooo003o003o1oooo`03003ooooo003o00?oool00`00ooooo`00o`0:oooo00<0
0?ooooooool00P00oaCoool2003o00?oool00?ooool07?ooo`800?l6oooo00<00?ooooooool00P00
o`?oool4003o00?oool00?ooool00_ooo`03003ooooooooo00800?l?oooo00<00?ooool00?l05Ooo
o`04003ooooooooo003o@?ooo`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo
00Goool00`00ooooooooo`07oooo0P00o`;oool2003o00?oool00?l00?l00_ooo`800?l01_ooo`00
o`00o`00ooooo`00o`?oool01000ooooooooo`00o`Woool01000ooooooooo`00o`?oool2003o0ooo
o`03003ooooo003o00Soool00`00ooooo`00o`03oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o3Oooo`800?l3oooo00<00?ooool00?l01?ooo`03003ooooooooo00Ooool00`00ooooo`00o`03
oooo0P00o`?oool00`00ooooo`00o`0>oooo00<00?ooool00?l00_ooo`04003ooooo003o003o0ooo
o`800?l3oooo00@00?ooool00?l00?l7oooo00<00?ooool00?l00oooo`03003ooooo003o00goool2
003o5?ooo`800?l00oooo`00ooooo`0Loooo0P00o`Koool00`00ooooooooo`02003o0oooo`@00?l0
0oooo`00ooooo`02oooo00<00?ooooooool00P00o`ooool00`00ooooo`00o`0Eoooo00@00?oooooo
ool00?m0oooo0@00007oool000goool500001Oooo`030000oooooooo00Woool00`00ooooooooo`05
oooo00@00?ooooooool00?l6oooo0P00o`;oool2003o00?oool00?l00?l00_ooo`800?l01_ooo`00
o`00o`00ooooo`00o`?oool01000ooooooooo`00o`Woool01000ooooooooo`00o`Coool01`00oooo
ooooooooo`00ooooo`00o`08oooo00<00?ooool00?l00oooo`03003ooooo003o00;oool01000oooo
ooooo`00o`goool2003o0oooo`03003ooooo003o00Coool00`00ooooooooo`07oooo00<00?ooool0
0?l00oooo`800?l3oooo00<00?ooool00?l03_ooo`03003ooooo003o00;oool01000ooooo`00o`00
o`?oool2003o0oooo`03003ooooo003o00Soool00`00ooooo`00o`03oooo00<00?ooool00?l03Ooo
o`800?lDoooo0P00o`03oooo003ooooo01coool2003o1_ooo`03003ooooooooo00800?l3oooo1000
o`03oooo003ooooo00;oool00`00ooooooooo`02003o3oooo`03003ooooo003o01Goool00`00oooo
o`00o`11oooo0@00007oool000ooool00`000?ooooooo`05oooo00<0003oooooool02Oooo`03003o
oooooooo00Coool2003o0_ooo`03003ooooooooo00Coool2003o0_ooo`800?l00oooo`00o`00o`02
oooo0P00o`06oooo003ooooo003ooooo003o0oooo`04003ooooooooo003o2Oooo`04003ooooooooo
003o1?ooo`07003ooooooooooooo003ooooo003o00Soool00`00ooooo`00o`03oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o3Oooo`800?l3oooo00<00?ooool00?l01?ooo`03003ooooooooo
00Ooool3003o0oooo`800?l3oooo00<00?ooool00?l03_ooo`03003ooooo003o00;oool00`00oooo
o`00o`04oooo0P00o`?oool00`00ooooo`00o`08oooo00<00?ooool00?l01?ooo`800?l=oooo0P00
oaCoool2003o00?oool00?ooool07?ooo`800?l6oooo00<00?ooooooool00P00o`?oool4003o00?o
ool00?ooool00_ooo`03003ooooooooo00800?l?oooo00<00?ooool00?l05Oooo`03003ooooo003o
047oool100000Oooo`003oooo`030000oooooooo00Goool300002Oooo`03003ooooooooo00Coool2
003o0_ooo`03003ooooooooo00Coool2003o0_ooo`800?l00oooo`00o`00o`02oooo0P00o`06oooo
003ooooo003ooooo003o0oooo`04003ooooooooo003o2Oooo`04003ooooooooo003o1?ooo`07003o
oooooooooooo003ooooo003o00Woool2003o0oooo`03003ooooo003o00;oool01000ooooooooo`00
o`goool2003o0oooo`03003ooooo003o00Coool00`00ooooooooo`07oooo0`00o`?oool2003o1?oo
o`800?l>oooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool00`00ooooo`00o`08oooo00<0
0?ooool00?l01?ooo`03003ooooooooo00coool2003o5?ooo`@00?lMoooo0P00o`Koool00`00oooo
ooooo`02003o0oooo`@00?l00oooo`00ooooo`02oooo00<00?ooooooool00P00o`ooool00`00oooo
o`00o`0Eoooo00<00?ooool00?l0?oooo`<00001oooo000?oooo00<0003oooooool01Oooo`030000
oooooooo00Woool00`00ooooooooo`04oooo0P00o`;oool00`00ooooooooo`04oooo0P00o`;oool2
003o00?oool00?l00?l00_ooo`800?l01_ooo`00ooooo`00ooooo`00o`?oool01000ooooooooo`00
o`Woool01000ooooooooo`00o`Coool01`00ooooooooooooo`00ooooo`00o`09oooo0P00o`?oool0
0`00ooooo`00o`02oooo00@00?ooooooool00?l=oooo0P00o`?oool00`00ooooo`00o`04oooo00<0
0?ooooooool01oooo`<00?l3oooo0P00o`Coool2003o3_ooo`03003ooooo003o00;oool3003o1?oo
o`800?l3oooo00<00?ooool00?l02?ooo`03003ooooo003o00Coool00`00ooooooooo`0<oooo0P00
oaCoool4003o7Oooo`800?l6oooo00<00?ooooooool00P00o`?oool4003o00?oool00?ooool00_oo
o`03003ooooooooo00800?l?oooo00<00?ooool00?l05Oooo`03003ooooo003o047oool100000Ooo
o`003oooo`030000oooooooo00Goool00`000?ooooooo`09oooo00<00?ooooooool01?ooo`800?l2
oooo00<00?ooooooool01?ooo`<00?l01?ooo`00o`00ooooo`800?l2oooo0P00o`06oooo003ooooo
003ooooo003o0oooo`04003ooooooooo003o2Oooo`04003ooooooooo003o2?ooo`03003ooooo003o
00Woool2003o0oooo`03003ooooo003o00;oool01000ooooooooo`00o`goool2003o0oooo`03003o
oooo003o00koool3003o0oooo`800?l4oooo0P00o`koool00`00ooooo`00o`02oooo0`00o`Coool2
003o0oooo`03003ooooo003o00Soool00`00ooooo`00o`04oooo00<00?ooooooool03?ooo`800?lD
oooo1000oagoool2003o1_ooo`03003ooooooooo00800?l3oooo1000o`03oooo003ooooo00;oool0
0`00ooooooooo`02003o3oooo`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool0
00koool200001oooo`030000oooooooo00Woool00`00ooooooooo`04oooo0P00o`;oool00`00oooo
ooooo`04oooo0`00o`03oooo003o003o00<00?l2oooo0P00o`06oooo003ooooo003ooooo003o0ooo
o`04003ooooooooo003o2Oooo`04003ooooooooo003o2?ooo`03003ooooo003o00Woool2003o0ooo
o`03003ooooo003o00;oool01000ooooooooo`00o`goool2003o0oooo`03003ooooo003o00koool2
003o1?ooo`800?l4oooo0P00o`koool00`00ooooo`00o`02oooo0`00o`Coool2003o0oooo`03003o
oooo003o00Soool00`00ooooo`00o`04oooo00<00?ooooooool03?ooo`800?lDoooo1000oagoool2
003o1_ooo`04003ooooooooo003o1?ooo`@00?l00oooo`00ooooo`02oooo00<00?ooooooool00P00
o`ooool00`00ooooo`00o`0Eoooo00<00?ooool00?l0@Oooo`400001oooo000Goooo00<0003ooooo
ool02Oooo`03003ooooooooo00Coool2003o0_ooo`05003ooooooooooooo003o00;oool3003o00?o
ool00?l00?l00`00o`;oool2003o00Koool00?ooool00?ooool00?l3oooo00@00?ooooooool00?l9
oooo00@00?ooooooool00?l8oooo00<00?ooool00?l02Oooo`800?l3oooo00<00?ooool00?l00_oo
o`800?l00oooo`00ooooo`0<oooo0P00o`?oool00`00ooooo`00o`0>oooo0P00o`Coool2003o1Ooo
o`03003ooooooooo00coool00`00ooooo`00o`02oooo0`00o`Coool2003o0oooo`03003ooooo003o
00Soool00`00ooooo`00o`04oooo00<00?ooooooool03?ooo`800?lDoooo1000oagoool2003o1_oo
o`04003ooooooooo003o1?ooo`@00?l00oooo`00ooooo`02oooo00<00?ooooooool00P00o`ooool0
0`00ooooo`00o`0Eoooo00<00?ooool00?l0@Oooo`400001oooo000Goooo00<0003oooooool02Ooo
o`03003ooooooooo00Coool2003o0_ooo`05003ooooooooooooo003o00;oool3003o00?oool00?l0
0?l00`00o`;oool2003o00Koool00?ooool00?ooool00?l3oooo00@00?ooooooool00?l9oooo00@0
0?ooooooool00?l8oooo00<00?ooool00?l02Oooo`03003ooooooooo00;oool00`00ooooo`00o`02
oooo0P00o`03oooo003ooooo00coool2003o0oooo`03003ooooo003o00koool2003o1?ooo`800?lD
oooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool00`00ooooo`00o`08oooo00<00?ooool0
0?l01?ooo`03003ooooooooo00coool2003o5?ooo`@00?lMoooo0P00o`Koool01000ooooooooo`00
o`Coool4003o00?oool00?ooool00_ooo`03003ooooooooo00800?l?oooo00<00?ooool00?l05Ooo
o`03003ooooo003o047oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`04
oooo0P00o`;oool01@00ooooooooooooo`00o`02oooo0`00o`03oooo003o003o00<00?l2oooo0P00
o`03oooo003ooooo00;oool01@00ooooooooooooo`00o`02oooo00<00?ooooooool01oooo`04003o
oooooooo003o2?ooo`03003ooooo003o00Woool00`00ooooooooo`03oooo00@00?ooooooooooool2
003o00?oool00?ooool03?ooo`800?l3oooo00<00?ooool00?l05?ooo`800?lDoooo00<00?ooool0
0?l00_ooo`<00?l4oooo0P00o`?oool00`00ooooo`00o`08oooo00<00?ooool00?l01?ooo`03003o
oooooooo00coool2003o5?ooo`<00?lNoooo0P00o`Koool01000ooooooooo`00o`Coool4003o00?o
ool00?ooool00_ooo`03003ooooooooo00800?l?oooo00<00?ooool00?l05Oooo`03003ooooo003o
047oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`04oooo0P00o`;oool0
1@00ooooooooooooo`00o`02oooo0`00o`06oooo003o003o003ooooo003o0_ooo`<00?l4oooo00D0
0?ooooooooooool00?l00_ooo`03003ooooooooo00Ooool01000ooooooooo`00o`Soool00`00oooo
o`00o`09oooo00<00?ooooooool00oooo`04003ooooooooooooo1000o`goool2003o0oooo`03003o
oooo003o01Coool2003o5?ooo`03003ooooo003o00;oool3003o1?ooo`800?l3oooo00<00?ooool0
0?l02?ooo`03003ooooo003o00Coool00`00ooooooooo`0<oooo0P00oaCoool3003o7_ooo`800?l6
oooo00@00?ooooooool00?l4oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3ooo
o`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool01?ooo`800?l2oooo00D00?ooooooooooool00?l00_ooo`<00?l01_ooo`00
o`00o`00ooooo`00o`;oool3003o1?ooo`05003ooooooooooooo003o00;oool00`00ooooooooo`07
oooo00@00?ooooooool00?l8oooo00<00?ooool00?l02Oooo`03003ooooooooo00?oool01000oooo
ooooooooo`@00?l=oooo0P00o`?oool00`00ooooo`00o`0Doooo0P00oaCoool00`00ooooo`00o`02
oooo0`00o`Coool2003o0oooo`03003ooooo003o00Soool00`00ooooo`00o`04oooo00<00?oooooo
ool03?ooo`800?lDoooo0`00oakoool2003o1_ooo`04003ooooooooo003o1?ooo`@00?l00oooo`00
ooooo`02oooo00<00?ooooooool00P00o`ooool00`00ooooo`00o`0Eoooo00<00?ooool00?l0@Ooo
o`400001oooo000Goooo00<0003oooooool02Oooo`03003ooooooooo00Coool2003o0_ooo`05003o
oooooooooooo003o00;oool3003o00Koool00?l00?l00?ooool00?l2oooo0`00o`Coool01@00oooo
ooooooooo`00o`02oooo00<00?ooooooool01oooo`04003ooooooooo003o2?ooo`03003ooooo003o
00Woool00`00ooooooooo`03oooo00@00?ooooooooooool4003o3Oooo`800?l3oooo00<00?ooool0
0?l05?ooo`800?lDoooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool00`00ooooo`00o`08
oooo00<00?ooool00?l05?ooo`03003ooooooooo01;oool3003o7_ooo`800?l6oooo00@00?oooooo
ool00?l4oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3oooo`03003ooooo003o
01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool200002_ooo`03003ooooooooo00Coool2
003o0_ooo`05003ooooooooooooo003o00;oool3003o00Koool00?l00?l00?ooool00?l2oooo0`00
o`Coool01@00ooooooooooooo`00o`02oooo00<00?ooooooool01oooo`04003ooooooooo003o2?oo
o`03003ooooo003o00Woool00`00ooooooooo`03oooo00@00?ooooooooooool4003o3Oooo`800?l3
oooo00<00?ooool00?l05?ooo`800?lDoooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l05?ooo`03003ooooooooo01;oool3003o7_ooo`800?l6
oooo00@00?ooooooool00?l4oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3ooo
o`03003ooooo003o01Goool00`00ooooo`00o`10oooo0P00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool01?ooo`800?l2oooo00D00?ooooooooooool00?l00_ooo`<00?l01_ooo`00
o`00o`00ooooo`00o`;oool00`00ooooo`00o`08oooo00@00?ooooooool00?l9oooo00@00?oooooo
ool00?l8oooo00<00?ooool00?l02Oooo`03003ooooooooo00?oool01000ooooooooooooo`@00?l=
oooo0P00o`?oool2003o5Oooo`800?lDoooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l05?ooo`03003ooooooooo01;oool3003o7_ooo`800?l6
oooo00@00?ooooooool00?l4oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3ooo
o`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool01?ooo`800?l2oooo00D00?ooooooooooool00?l00_ooo`<00?l01_ooo`00
o`00o`00ooooo`00o`;oool00`00ooooo`00o`08oooo00@00?ooooooool00?l9oooo00@00?oooooo
ool00?l8oooo00<00?ooool00?l02Oooo`03003ooooooooo00?oool01000ooooooooooooo`@00?l=
oooo0P00o`?oool2003o5Oooo`800?lDoooo00<00?ooool00?l00_ooo`<00?l4oooo0P00o`?oool0
0`00ooooo`00o`08oooo00<00?ooool00?l05?ooo`03003ooooooooo01;oool3003o7_ooo`800?l6
oooo00@00?ooooooool00?l4oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3ooo
o`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`09
oooo00<00?ooooooool01?ooo`800?l2oooo00D00?ooooooooooool00?l00_ooo`<00?l01_ooo`00
o`00o`00ooooo`00o`;oool00`00ooooo`00o`08oooo00@00?ooooooool00?l9oooo00@00?oooooo
ool00?l8oooo00<00?ooool00?l03oooo`04003ooooooooooooo1000o`goool2003o0oooo`800?lE
oooo0P00oaCoool00`00ooooo`00o`02oooo0`00o`Coool2003o1?ooo`800?l8oooo00<00?ooool0
0?l05?ooo`03003ooooooooo01;oool00`00ooooo`00o`0Noooo0P00o`Koool01000ooooooooo`00
o`Coool4003o00?oool00?ooool00_ooo`03003ooooooooo00800?l?oooo00<00?ooool00?l05Ooo
o`03003ooooo003o047oool100000Oooo`005oooo`030000oooooooo00Woool00`00ooooooooo`04
oooo0P00o`;oool01@00ooooooooooooo`00o`02oooo0`00o`07oooo003o003o003ooooo003ooooo
00800?l00oooo`00ooooo`07oooo00@00?ooooooool00?l9oooo00@00?ooooooool00?l8oooo00<0
0?ooool00?l03oooo`04003ooooooooooooo1000o`goool2003o0oooo`800?lEoooo0P00oaCoool0
0`00ooooo`00o`02oooo0P00o`Goool2003o1?ooo`800?l8oooo00<00?ooool00?l0:Oooo`03003o
oooo003o01koool2003o1_ooo`04003ooooooooo003o1?ooo`@00?l00oooo`00ooooo`02oooo00<0
0?ooooooool00P00o`ooool00`00ooooo`00o`0Eoooo00<00?ooool00?l0@Oooo`400001oooo000G
oooo00<0003oooooool02Oooo`03003ooooo003o00Coool2003o0_ooo`05003ooooooooooooo003o
00;oool3003o00Goool00?l00?l00?ooool01000o`03oooo003ooooo00Ooool01000ooooooooo`00
o`Woool01000ooooooooo`00o`Soool00`00ooooo`00o`0?oooo00@00?ooooooooooool4003o3Ooo
o`800?l3oooo0P00oaGoool2003o5?ooo`03003ooooo003o00;oool2003o1Oooo`800?l4oooo0P00
o`Soool00`00ooooo`00o`0Yoooo00<00?ooool00?l07_ooo`800?l6oooo00@00?ooooooool00?l4
oooo1000o`03oooo003ooooo00;oool00`00ooooooooo`02003o3oooo`03003ooooo003o01Goool0
0`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`09oooo00<00?ooool00?l01?oo
o`800?l2oooo00D00?ooooooooooool00?l00_ooo`<00?l01Oooo`00o`00o`00ooooo`04003o00?o
ool00?ooool01oooo`04003ooooooooo003o2Oooo`04003ooooooooo003o2?ooo`03003ooooo003o
01?oool4003o3Oooo`800?l3oooo0P00oaGoool2003o5?ooo`03003ooooo003o00;oool2003o1Ooo
o`800?l4oooo0P00o`Soool00`00ooooo`00o`0Yoooo00<00?ooool00?l07_ooo`800?l6oooo00@0
0?ooooooool00?l4oooo0`00o`;oool01@00ooooooooooooo`00o`02oooo0P00o`ooool00`00oooo
o`00o`0Eoooo00<00?ooool00?l0@Oooo`400001oooo000Goooo00<0003oooooool02Oooo`03003o
oooo003o00Coool2003o0_ooo`05003ooooooooooooo003o00;oool3003o00Goool00?l00?l00?oo
ool01000o`03oooo003ooooo00Ooool01000ooooooooo`00o`Woool01000ooooooooo`00o`Soool0
0`00ooooo`00o`0Coooo1000o`goool2003o0oooo`800?lEoooo0P00oaCoool00`00ooooo`00o`02
oooo0P00o`Goool2003o1?ooo`800?l8oooo00<00?ooool00?l0:Oooo`03003ooooo003o01koool2
003o1_ooo`04003ooooooooo003o1?ooo`03003ooooo003o00;oool01@00ooooooooooooo`00o`02
oooo00<00?ooooooool03_ooo`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool0
01Ooool00`000?ooooooo`0:oooo0P00o`Coool2003o0_ooo`05003ooooooooooooo003o00;oool3
003o00Goool00?l00?l00?ooool01000o`03oooo003ooooo00Ooool01000ooooooooo`00o`Woool0
1000ooooooooo`00o`Soool2003o5?ooo`@00?l=oooo00<00?ooooooool00_ooo`800?lEoooo0P00
oaCoool00`00ooooo`00o`02oooo0P00o`Goool2003o1?ooo`800?l8oooo00<00?ooool00?l0:Ooo
o`03003ooooooooo01koool2003o1_ooo`03003ooooooooo00Goool00`00ooooo`00o`02oooo00D0
0?ooooooooooool00?l00_ooo`03003ooooooooo00koool00`00ooooo`00o`0Eoooo00<00?ooool0
0?l0@Oooo`400001oooo000Goooo00<0003oooooool02_ooo`800?l4oooo0P00o`;oool01@00oooo
ooooooooo`00o`02oooo0`00o`05oooo003o003o003ooooo00@00?l00oooo`00ooooo`07oooo00@0
0?ooooooool00?l9oooo00@00?ooooooool00?l8oooo0P00oaGoool3003o3Oooo`03003ooooooooo
00;oool2003o5Oooo`800?lDoooo00<00?ooool00?l00_ooo`800?l5oooo0P00o`Coool2003o2?oo
o`03003ooooo003o02Woool00`00ooooooooo`0Noooo0P00o`Koool00`00ooooooooo`07oooo00@0
0?ooooooool00?l3oooo00@00?ooooooool00?l@oooo00<00?ooool00?l05Oooo`03003ooooo003o
047oool100000Oooo`005oooo`80000;oooo0P00o`Coool2003o0_ooo`06003ooooooooooooo003o
oooo1000o`05oooo003o003o003ooooo00@00?l00oooo`00ooooo`07oooo00@00?ooooooool00?l9
oooo00@00?ooooooool00?l8oooo0P00oaGoool3003o3Oooo`03003ooooooooo00;oool2003o5Ooo
o`800?lDoooo00<00?ooool00?l00oooo`03003ooooooooo00?oool2003o1?ooo`800?l8oooo00<0
0?ooool00?l0:Oooo`03003ooooooooo01koool2003o4?ooo`04003ooooooooo003o0oooo`04003o
oooooooo003o4?ooo`03003ooooo003o01Goool00`00ooooo`00o`10oooo0P00007oool001Ooool0
0`000?ooooooo`0:oooo0P00o`Coool01@00ooooo`00ooooo`00o`03oooo00@00?ooool00?ooool2
003o00Goool00?l00?l00?ooool01000o`03oooo003ooooo00Ooool01000ooooooooo`00o`Woool0
1000ooooooooo`00o`Soool2003o5Oooo`<00?l=oooo00<00?ooooooool00_ooo`800?lEoooo0P00
oaCoool00`00ooooo`00o`03oooo00<00?ooooooool00oooo`800?l4oooo0P00o`Soool00`00oooo
o`00o`0Yoooo00<00?ooooooool07_ooo`03003ooooooooo00ooool01000ooooooooo`00o`?oool0
1000ooooooooo`00oa3oool00`00ooooo`00o`0Eoooo00<00?ooool00?l0@Oooo`400001oooo000G
oooo00<0003oooooool02_ooo`800?l4oooo00D00?ooool00?ooool00?l00oooo`04003ooooo003o
oooo0P00o`05oooo003o003o003ooooo00@00?l00oooo`00ooooo`07oooo00@00?ooooooool00?l9
oooo00@00?ooooooool00?l8oooo0P00oaGoool3003o3Oooo`03003ooooooooo00;oool2003o5Ooo
o`800?lDoooo00<00?ooool00?l02Oooo`800?l4oooo0P00o`Soool00`00ooooo`00o`1:oooo00<0
0?ooooooool04oooo`04003ooooooooo003o4oooo`03003ooooo003o01Goool00`00ooooo`00o`11
oooo0@00007oool001Ooool00`000?ooooooo`0:oooo0P00o`Coool01@00ooooo`00ooooo`00o`03
oooo0`00o`04oooo003o003ooooo0`00o`03oooo003o003o00800?l00oooo`00ooooo`07oooo00@0
0?ooooooool00?l9oooo00@00?ooooooool00?l8oooo0P00oaGoool3003o3Oooo`03003ooooooooo
00;oool2003o5Oooo`800?lDoooo00<00?ooool00?l02Oooo`800?l4oooo0P00o`Soool00`00oooo
o`00o`1:oooo00<00?ooooooool04oooo`04003ooooooooo003o4oooo`03003ooooo003o01Goool0
0`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`0:oooo0P00o`Coool01@00oooo
o`00ooooo`00o`03oooo0`00o`04oooo003o003ooooo0`00o`03oooo003o003o00800?l00oooo`00
ooooo`07oooo00@00?ooooooool00?l9oooo00@00?ooooooool00?l8oooo0P00oaGoool3003o4_oo
o`800?lEoooo0P00oaCoool00`00ooooo`00o`09oooo0P00o`Coool2003o2?ooo`03003ooooo003o
04[oool00`00ooooooooo`0Coooo00@00?ooooooool00?lCoooo00<00?ooool00?l05Oooo`03003o
oooo003o047oool100000Oooo`005oooo`030000oooooooo00[oool2003o1?ooo`05003ooooo003o
oooo003o00?oool3003o00Coool00?l00?ooool3003o00?oool00?l00?l00P00o`03oooo003ooooo
00Ooool01000ooooooooo`00o`Woool01000ooooooooo`00o`Soool2003o5Oooo`<00?lBoooo0P00
oaGoool2003o5?ooo`03003ooooo003o00Woool2003o1?ooo`800?l8oooo00<00?ooool00?l0H?oo
o`04003ooooooooo003o4oooo`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool0
01Ooool00`000?ooooooo`0:oooo0P00o`06oooo003ooooooooo003ooooo0`00o`?oool3003o00Co
ool00?l00?ooool3003o00?oool00?l00?l00P00o`03oooo003ooooo00Ooool01000ooooooooo`00
o`Woool01000ooooooooo`00o`Soool2003o5Oooo`<00?lBoooo0P00oaGoool2003o5?ooo`03003o
oooo003o00Woool2003o1?ooo`800?l8oooo00<00?ooool00?l0H?ooo`04003ooooooooo003o4ooo
o`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`0:
oooo00@00?ooool00?l00?l2oooo00H00?ooool00?l00?ooool00?l2oooo0`00o`04oooo003o003o
oooo0`00o`03oooo003o003o00800?l00oooo`00ooooo`07oooo00@00?ooooooool00?l9oooo00@0
0?ooooooool00?l8oooo0P00oaGoool3003o4_ooo`800?lEoooo00<00?ooooooool04oooo`03003o
oooo003o00Woool2003o1?ooo`800?l8oooo00<00?ooool00?l0H?ooo`04003ooooooooo003o4ooo
o`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`0:
oooo00@00?ooool00?l00?l2oooo00H00?ooool00?l00?ooool00?l2oooo0`00o`04oooo003o003o
oooo0`00o`03oooo003o003o00800?l:oooo00@00?ooooooool00?l9oooo00<00?ooool00?l02Ooo
o`800?lEoooo0P00oa?oool2003o5Oooo`03003ooooooooo01?oool00`00ooooo`00o`09oooo0P00
o`Coool2003o2?ooo`03003ooooo003o063oool01000ooooooooo`00oa?oool00`00ooooo`00o`0E
oooo00<00?ooool00?l0@Oooo`400001oooo000Goooo00<0003oooooool02_ooo`04003ooooo003o
003o0_ooo`06003ooooo003o003ooooo003o0_ooo`<00?l01?ooo`00o`00ooooo`800?l2oooo1000
o`[oool01000ooooooooo`00o`Woool00`00ooooo`00o`09oooo0P00oaGoool2003o4oooo`800?lE
oooo00<00?ooooooool04oooo`03003ooooo003o00Woool2003o1?ooo`800?l8oooo00<00?ooool0
0?l0H?ooo`04003ooooooooo003o4oooo`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00
007oool001Ooool200002oooo`04003ooooo003o003o0_ooo`06003ooooo003o003ooooo003o0_oo
o`<00?l01?ooo`00o`00ooooo`800?l2oooo1000o`[oool01000ooooooooo`00o`Woool00`00oooo
o`00o`09oooo0P00oaGoool2003o4oooo`800?lEoooo00<00?ooooooool04oooo`03003ooooo003o
00Woool2003o1?ooo`800?l8oooo00<00?ooool00?l0H?ooo`04003ooooooooo003o4oooo`03003o
oooo003o01Goool00`00ooooo`00o`10oooo0P00007oool001Ooool00`000?ooooooo`0:oooo00@0
0?ooool00?l00?l2oooo00H00?ooool00?l00?ooool00?l2oooo0`00o`05oooo003o003ooooo003o
00?oool4003o2_ooo`04003ooooooooo003o2Oooo`03003ooooo003o00Woool2003o:_ooo`800?lE
oooo00<00?ooooooool04oooo`03003ooooo003o00Woool2003o1?ooo`800?l8oooo00<00?ooool0
0?l0H?ooo`04003ooooooooo003o4oooo`03003ooooo003o01Goool00`00ooooo`00o`11oooo0@00
007oool001Ooool00`000?ooooooo`0:oooo00@00?ooool00?l00?l2oooo00H00?ooool00?l00?oo
ool00?l2oooo0`00o`05oooo003o003ooooo003o00?oool4003o2_ooo`04003ooooooooo003o2Ooo
o`03003ooooo003o00Woool2003o:_ooo`800?lEoooo00<00?ooooooool04oooo`03003ooooo003o
00Woool2003o1?ooo`800?l8oooo00<00?ooool00?l0H?ooo`04003ooooooooo003o4oooo`03003o
oooo003o01Goool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`0:oooo00@0
0?ooool00?l00?l2oooo00H00?ooool00?l00?ooool00?l2oooo0`00o`05oooo003o003ooooo003o
00?oool4003o2_ooo`04003ooooooooo003o2Oooo`03003ooooo003o00Woool2003o:_ooo`800?lE
oooo00<00?ooooooool04oooo`03003ooooo003o00Woool00`00ooooooooo`03oooo0P00o`Soool0
0`00ooooo`00o`1Poooo00@00?ooooooool00?lDoooo0P00oaGoool00`00ooooo`00o`11oooo0@00
007oool001Ooool00`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool00?ooool2003o00Co
ool00?l00?ooool3003o00Goool00?l00?ooool00?l00oooo`@00?l:oooo00@00?ooooooool00?l9
oooo00<00?ooool00?l02Oooo`800?lZoooo0P00oaGoool00`00ooooooooo`0Coooo0P00o`[oool0
0`00ooooooooo`03oooo0P00o`Soool00`00ooooo`00o`1Poooo00@00?ooooooool00?lDoooo0P00
oaGoool00`00ooooo`00o`11oooo0@00007oool001Ooool00`000?ooooooo`0:oooo00P00?oooooo
ooooool00?ooool00?ooool2003o00Coool00?l00?ooool3003o00Goool00?l00?ooool00?l00ooo
o`@00?l:oooo00@00?ooooooool00?l9oooo00<00?ooool00?l02Oooo`800?lZoooo0P00oaGoool0
0`00ooooooooo`0Coooo0P00o`[oool00`00ooooooooo`03oooo0P00o`Soool00`00ooooo`00o`1P
oooo00@00?ooooooool00?lDoooo0P00oaGoool00`00ooooo`00o`11oooo0@00007oool001Ooool0
0`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool00?ooool2003o00Coool00?l00?ooool3
003o00Goool00?l00?ooool00?l00oooo`@00?l:oooo00@00?ooooooool00?l9oooo00<00?ooool0
0?l02Oooo`800?lZoooo0P00oaGoool00`00ooooooooo`0Coooo0P00o`[oool00`00ooooooooo`03
oooo0P00o`Soool00`00ooooo`00o`1Poooo00@00?ooooooool00?lDoooo0P00oaGoool3003o@Ooo
o`400001oooo000Goooo00<0003oooooool02_ooo`08003ooooooooooooo003ooooo003ooooo0P00
o`04oooo003o003ooooo0P00o`;oool2003o00?oool00?ooool00_ooo`@00?l:oooo00@00?oooooo
ool00?l9oooo00<00?ooool00?l02Oooo`800?lZoooo0P00oaGoool00`00ooooooooo`0Coooo0P00
o`[oool00`00ooooooooo`03oooo0P00o`Soool00`00ooooo`00o`1Poooo00@00?ooooooool00?lD
oooo0P00oaGoool3003o@Oooo`400001oooo000Goooo00<0003oooooool02_ooo`08003ooooooooo
oooo003ooooo003ooooo0P00o`04oooo003o003ooooo0P00o`;oool2003o00?oool00?ooool00ooo
o`<00?l:oooo00@00?ooooooool00?l9oooo00<00?ooool00?l02Oooo`800?lZoooo0P00oaGoool0
0`00ooooooooo`0Coooo0P00o`[oool00`00ooooooooo`03oooo0P00o`Soool00`00ooooo`00o`1P
oooo00@00?ooooooool00?lDoooo0P00oaGoool3003o@Oooo`400001oooo000Goooo00<0003ooooo
ool02_ooo`08003ooooooooooooo003ooooo003ooooo0P00o`04oooo003o003ooooo0P00o`;oool2
003o00?oool00?ooool00oooo`<00?l:oooo00@00?ooooooool00?l9oooo00<00?ooool00?l02Ooo
o`800?lZoooo0P00oaGoool00`00ooooooooo`0Coooo0P00o`[oool00`00ooooooooo`03oooo0P00
o`Soool00`00ooooo`00o`1Poooo00@00?ooooooool00?lDoooo0P00oaKoool2003o@Oooo`400001
oooo000Goooo0P0000_oool02000ooooooooooooo`00ooooo`00ooooo`800?l01?ooo`00o`00oooo
o`800?l2oooo0P00o`03oooo003ooooo00?oool3003o2_ooo`04003ooooooooo003o2Oooo`03003o
oooo003o00Woool2003o:_ooo`800?lEoooo00<00?ooooooool04oooo`800?l:oooo00<00?oooooo
ool00oooo`800?l8oooo00<00?ooool00?l0H?ooo`04003ooooooooo003o5?ooo`800?lFoooo0P00
od3oool200000Oooo`005oooo`030000oooooooo00[oool02000ooooooooooooo`00ooooo`00oooo
o`800?l01?ooo`00o`00ooooo`800?l2oooo0P00o`03oooo003ooooo00?oool3003o2_ooo`800?l0
0oooo`00ooooo`08oooo00<00?ooool00?l02Oooo`800?lZoooo0P00oaGoool00`00ooooooooo`0C
oooo0P00o`[oool00`00ooooooooo`03oooo0P00o`Soool00`00ooooo`00o`1Poooo00@00?oooooo
ool00?lDoooo0P00oaKoool2003o@Oooo`400001oooo000Goooo00<0003oooooool02_ooo`08003o
oooooooooooo003ooooo003ooooo0P00o`04oooo003o003ooooo0P00o`;oool2003o00?oool00?oo
ool00oooo`<00?l:oooo0P00o`03oooo003ooooo00Soool00`00ooooo`00o`09oooo0P00ob[oool2
003o5Oooo`03003ooooooooo01?oool2003o2_ooo`03003ooooooooo00?oool2003o2?ooo`03003o
oooo003o063oool01000ooooooooo`00oaCoool2003o5_ooo`800?m1oooo0@00007oool001Ooool0
0`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool00?ooool2003o00Coool00?l00?ooool2
003o0_ooo`04003ooooo003o003o1?ooo`<00?l:oooo0P00o`03oooo003ooooo00Soool00`00oooo
o`00o`09oooo0P00ob[oool2003o5Oooo`03003ooooooooo01?oool2003o4?ooo`800?l8oooo00<0
0?ooool00?l0H?ooo`04003ooooooooo003o5?ooo`800?lFoooo0P00od7oool100000Oooo`005ooo
o`030000oooooooo00[oool02000ooooooooooooo`00ooooo`00ooooo`800?l01?ooo`00o`00oooo
o`800?l2oooo00@00?ooool00?l00?l4oooo0`00o`[oool2003o00?oool00?ooool02?ooo`03003o
oooo003o00[oool00`00ooooooooo`0Xoooo0P00oaGoool00`00ooooooooo`0Coooo0P00oa3oool2
003o2?ooo`03003ooooo003o063oool01000ooooooooo`00oaCoool2003o5_ooo`800?m1oooo0@00
007oool001Ooool00`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool00?ooool2003o00Co
ool00?l00?ooool2003o0_ooo`04003ooooo003o003o1?ooo`<00?l:oooo0`00o`[oool00`00oooo
o`00o`0:oooo00<00?ooooooool0:Oooo`03003ooooooooo01?oool00`00ooooooooo`0Coooo0P00
oa3oool2003o2?ooo`03003ooooo003o063oool01000ooooooooo`00oaCoool2003o5_ooo`800?m1
oooo0@00007oool001Ooool00`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool00?ooool2
003o00Coool00?l00?ooool2003o0_ooo`04003ooooo003o003o1?ooo`<00?l;oooo0P00o`[oool0
0`00ooooo`00o`0:oooo00<00?ooooooool0:Oooo`03003ooooooooo01?oool00`00ooooooooo`0C
oooo0P00oa3oool2003o2?ooo`<00?mPoooo00@00?ooooooool00?lDoooo00<00?ooooooool05Ooo
o`800?m1oooo0@00007oool001Ooool00`000?ooooooo`0:oooo00P00?ooooooooooool00?ooool0
0?ooool2003o00Coool00?l00?ooool2003o0_ooo`04003ooooo003o003o1Oooo`800?l;oooo0P00
o`[oool00`00ooooo`00o`0:oooo00<00?ooooooool0:Oooo`03003ooooooooo01?oool00`00oooo
ooooo`0Coooo0P00oa3oool2003o2?ooo`<00?mPoooo00@00?ooooooool00?lDoooo00<00?oooooo
ool05Oooo`800?m1oooo0@00007oool000?oool500000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02_ooo`08003ooooooooooooo003ooooo003ooooo0P00o`04oooo
003o003ooooo0P00o`;oool01000ooooo`00o`00o`Goool2003o2oooo`800?l:oooo00<00?ooool0
0?l02_ooo`03003ooooooooo02Woool00`00ooooooooo`0Coooo00<00?ooooooool04oooo`800?l@
oooo0P00o`Soool3003oH?ooo`04003ooooooooo003o5?ooo`03003ooooooooo01Goool2003o@Ooo
o`400001oooo0005oooo00<0003oooooool01_ooo`030000oooo000000Koool00`000?ooooooo`0:
oooo00P00?ooooooooooool00?ooool00?ooool2003o00Goool00?l00?ooool00?l00oooo`04003o
oooo003o003o1Oooo`800?l;oooo0P00o`[oool00`00ooooo`00o`0:oooo00<00?ooooooool0:Ooo
o`03003ooooooooo01?oool00`00ooooooooo`0Coooo0P00oa3oool2003o2?ooo`<00?mPoooo00@0
0?ooooooool00?lDoooo00<00?ooooooool05Oooo`800?m1oooo0@00007oool000Goool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`<0000:oooo00P00?ooooooooooool00?ooool00?ooool2
003o00Goool00?l00?ooool00?l00oooo`04003ooooo003o003o1Oooo`800?l;oooo0P00o`[oool0
0`00ooooo`00o`0:oooo00<00?ooooooool0:Oooo`03003ooooooooo02Woool2003o4?ooo`800?l8
oooo0`00of3oool01000ooooooooo`00oaCoool00`00ooooooooo`0Eoooo0P00ocooool300000Ooo
o`001Oooo`030000oooooooo00Koool200001oooo`030000oooooooo00koool01000ooooo`00oooo
o`800?l01Oooo`00o`00ooooo`00o`03oooo00@00?ooool00?l00?l5oooo0P00o`_oool2003o2_oo
o`800?l;oooo00<00?ooooooool0:Oooo`03003ooooooooo02Woool2003o4?ooo`800?l8oooo0`00
of3oool01000ooooooooo`00oaCoool00`00ooooooooo`0Eoooo0P00od7oool100000Oooo`001Ooo
o`030000oooooooo00Koool00`000?ooooooo`06oooo00<0003oooooool03_ooo`04003ooooo003o
oooo0P00o`05oooo003o003ooooo003o00?oool01000ooooo`00o`00o`Goool2003o2oooo`800?l:
oooo0P00o`_oool00`00ooooooooo`0Yoooo00<00?ooooooool0:Oooo`800?l@oooo00<00?oooooo
ool01oooo`<00?mPoooo00@00?ooooooool00?lDoooo00<00?ooooooool05Oooo`800?m1oooo0@00
007oool000Coool200002?ooo`<00006oooo00<0003oooooool03_ooo`04003ooooo003ooooo0P00
o`05oooo003o003ooooo003o00?oool01000ooooo`00o`00o`Goool2003o2oooo`800?l:oooo0P00
o`_oool00`00ooooooooo`0Yoooo00<00?ooooooool0:Oooo`800?l@oooo00<00?ooooooool01ooo
o`<00?mPoooo00@00?ooooooool00?lDoooo00<00?ooooooool05Oooo`800?m1oooo0@00007oool0
01Ooool00`000?ooooooo`0>oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l00ooo
o`04003ooooo003o003o1Oooo`800?l;oooo0P00o`[oool2003o2oooo`03003ooooooooo05Goool2
003o4?ooo`03003ooooooooo00Ooool3003oH?ooo`04003ooooooooo003o5?ooo`03003ooooooooo
01Goool2003o@Oooo`400001oooo000Goooo00<0003oooooool03_ooo`04003ooooo003ooooo0P00
o`05oooo003o003ooooo003o00?oool01000ooooo`00o`00o`Goool2003o2oooo`800?l:oooo0P00
o`_oool00`00ooooooooo`1Eoooo0P00oa3oool00`00ooooooooo`07oooo0`00of3oool01000oooo
ooooo`00oaCoool00`00ooooooooo`0Eoooo0P00od7oool100000Oooo`005oooo`030000oooooooo
00koool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`03oooo00@00?ooool00?l00?l5
oooo0P00o`_oool2003o2_ooo`800?mSoooo0P00oa[oool3003oH?ooo`04003ooooooooo003o5?oo
o`03003ooooooooo01Goool2003o@Oooo`400001oooo000Goooo00<0003oooooool03_ooo`04003o
oooo003ooooo0P00o`04oooo003o003o003o1_ooo`800?l5oooo0P00o`_oool2003o2_ooo`800?mS
oooo0P00oa[oool2003oHOooo`04003ooooooooo003o;?ooo`800?m1oooo0@00007oool001Ooool0
0`000?ooooooo`0>oooo00@00?ooool00?ooool2003o00Coool00?l00?l00?l6oooo0P00o`Goool2
003o2oooo`800?l:oooo0P00of?oool2003o6_ooo`800?mQoooo00<00?ooool00?l0;Oooo`800?m1
oooo0@00007oool001Ooool00`000?ooooooo`0>oooo00@00?ooool00?ooool2003o00Coool00?l0
0?l00?l6oooo0P00o`Goool2003o2oooo`800?l:oooo0P00of?oool2003o6_ooo`800?mQoooo00<0
0?ooool00?l0;Oooo`800?m1oooo0@00007oool001Ooool200003oooo`04003ooooo003ooooo0P00
o`;oool2003o1_ooo`800?l5oooo0P00o`_oool2003o2_ooo`800?mSoooo0P00oa[oool2003oHOoo
o`03003ooooo003o02goool2003o@?ooo`800001oooo000Goooo00<0003oooooool03_ooo`03003o
oooo003o00;oool00`00ooooooooo`02003o1_ooo`800?l5oooo0P00o`_oool2003o2_ooo`800?mS
oooo0P00oa[oool2003oHOooo`03003ooooo003o02goool2003o@Oooo`400001oooo000Goooo00<0
003oooooool03_ooo`03003ooooo003o00;oool00`00ooooooooo`02003o1_ooo`800?l5oooo0P00
o`_oool2003o2oooo`03003ooooooooo067oool2003o6_ooo`800?mQoooo00<00?ooool00?l0;Ooo
o`800?m1oooo0@00007oool001Ooool00`000?ooooooo`0>oooo00<00?ooool00?l01Oooo`800?l6
oooo0P00o`Goool2003o2oooo`800?l;oooo00<00?ooooooool0HOooo`800?lKoooo00<00?oooooo
ool0Goooo`03003ooooo003o02goool2003o@Oooo`400001oooo000Goooo00<0003oooooool03_oo
o`03003ooooo003o00Goool2003o1_ooo`800?l5oooo0P00o`_oool2003o2oooo`03003ooooooooo
06;oool00`00ooooooooo`0Ioooo00<00?ooooooool0Goooo`03003ooooo003o02koool00`00oooo
ooooo`0ooooo0@00007oool001Ooool00`000?ooooooo`0>oooo00<00?ooool00?l01Oooo`800?l6
oooo0P00o`Goool2003o2oooo`800?l;oooo00<00?ooooooool0H_ooo`03003ooooooooo01Woool0
0`00ooooooooo`1Ooooo00<00?ooool00?l0;_ooo`03003ooooooooo03ooool100000Oooo`005ooo
o`030000oooooooo00koool00`00ooooo`00o`05oooo0P00o`Koool2003o1Oooo`800?l;oooo0P00
o`_oool00`00ooooooooo`1Roooo00<00?ooooooool06Oooo`03003ooooooooo05ooool00`00oooo
o`00o`0^oooo00<00?ooooooool0?oooo`400001oooo000Goooo00<0003oooooool03_ooo`03003o
oooo003o00Goool2003o1_ooo`800?l5oooo0P00o`_oool2003o2oooo`03003ooooooooo07koool0
0`00ooooooooo`1Ooooo00<00?ooool00?l0;_ooo`03003ooooooooo03ooool100000Oooo`005ooo
o`030000oooooooo00koool00`00ooooo`00o`05oooo0P00o`Koool2003o1Oooo`800?l;oooo0P00
o`_oool00`00ooooooooo`1noooo00<00?ooooooool0Goooo`03003ooooo003o02koool00`00oooo
ooooo`0ooooo0@00007oool001Ooool00`000?ooooooo`0>oooo00<00?ooool00?l01Oooo`800?l6
oooo0P00o`Goool2003o2oooo`800?l;oooo00<00?ooooooool0O_ooo`03003ooooooooo05ooool0
0`00ooooo`00o`1`oooo0@00007oool001Ooool200003oooo`03003ooooo003o00Goool2003o1_oo
o`800?l5oooo0P00o`_oool2003o2oooo`03003ooooooooo0>3oool00`00ooooo`00o`1_oooo0P00
007oool001Ooool00`000?ooooooo`0>oooo00<00?ooool00?l01Oooo`800?l6oooo0P00o`Goool2
003o2oooo`800?l;oooo00<00?ooooooool0h?ooo`03003ooooo003o073oool100000Oooo`005ooo
o`030000oooooooo00koool00`00ooooo`00o`05oooo0P00o`Koool2003o1Oooo`800?l;oooo0P00
o`_oool00`00ooooooooo`3Poooo00<00?ooool00?l0L?ooo`400001oooo000Goooo00<0003ooooo
ool03_ooo`800?l6oooo0P00o`Koool2003o1Oooo`800?l<oooo00<00?ooooooool02Oooo`03003o
oooooooo0>3oool00`00ooooo`00o`1`oooo0@00007oool001Ooool00`000?ooooooo`0>oooo0P00
o`Koool2003o1_ooo`800?l5oooo0P00o`coool00`00ooooooooo`09oooo00<00?ooooooool0h?oo
o`03003ooooo003o073oool100000Oooo`005oooo`030000oooooooo00koool2003o1_ooo`800?l6
oooo0P00o`Koool00`00ooooooooo`0:oooo00<00?ooooooool02Oooo`03003ooooooooo0>3oool0
0`00ooooo`00o`1`oooo0@00007oool001Ooool00`000?ooooooo`0?oooo00<00?ooooooool01?oo
o`800?l6oooo0P00o`Koool00`00ooooooooo`0:oooo00<00?ooooooool02Oooo`03003ooooooooo
0>3oool00`00ooooo`00o`1`oooo0@00007oool001Ooool00`000?ooooooo`0?oooo00<00?oooooo
ool01?ooo`800?l6oooo0P00o`Koool00`00ooooooooo`0:oooo00<00?ooooooool02Oooo`03003o
oooooooo0>3oool00`00ooooo`00o`1`oooo0@00007oool001Ooool00`000?ooooooo`0?oooo00<0
0?ooooooool01?ooo`800?l6oooo0P00o`Koool00`00ooooooooo`0:oooo00<00?ooooooool02Ooo
o`03003ooooooooo0>3oool00`00ooooo`00o`1`oooo0@00007oool001Ooool00`000?ooooooo`0?
oooo00<00?ooooooool01?ooo`800?l6oooo00<00?ooooooool01Oooo`03003ooooooooo00[oool0
0`00ooooooooo`09oooo00<00?ooooooool0h?ooo`03003ooooo003o073oool100000Oooo`005ooo
o`80000@oooo00<00?ooooooool01?ooo`800?l6oooo00<00?ooooooool01Oooo`03003ooooooooo
00[oool00`00ooooooooo`3/oooo00<00?ooool00?l0Koooo`800001oooo000Goooo00<0003ooooo
ool03oooo`03003ooooooooo00Coool2003o1_ooo`03003ooooooooo0?ooool2oooo0`00og3oool1
00000Oooo`005oooo`030000oooooooo00ooool00`00ooooooooo`04oooo0P00o`Koool00`00oooo
ooooo`3ooooo0_ooo`<00?m`oooo0@00007oool001Ooool00`000?ooooooo`0?oooo00<00?oooooo
ool01?ooo`800?l6oooo00<00?ooooooool0ooooo`;oool3003oL?ooo`400001oooo000Goooo00<0
003oooooool03oooo`03003ooooooooo00Coool2003o1_ooo`03003ooooooooo0?ooool2oooo0`00
og3oool100000Oooo`005oooo`030000oooooooo00ooool00`00ooooooooo`04oooo0P00o`Koool0
0`00ooooooooo`3ooooo0_ooo`<00?m`oooo0@00007oool001Ooool00`000?ooooooo`0?oooo00<0
0?ooooooool01?ooo`800?l6oooo00<00?ooooooool0ooooo`;oool3003oL?ooo`400001oooo000G
oooo00<0003oooooool05_ooo`800?l6oooo00<00?ooooooool0ooooo`;oool3003oL?ooo`400001
oooo000Goooo00<0003oooooool05_ooo`800?l6oooo00<00?ooooooool0ooooo`;oool3003oL?oo
o`400001oooo000Goooo00<0003oooooool05_ooo`800?l6oooo00<00?ooooooool0ooooo`;oool3
003oL?ooo`400001oooo000Goooo0P0001Ooool2003o1_ooo`03003ooooooooo0?ooool2oooo0`00
ofooool200000Oooo`005oooo`030000oooooooo01Koool2003o1_ooo`03003ooooooooo0?ooool2
oooo0`00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003o1_ooo`03003ooooooooo
0?ooool2oooo0`00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003o1_ooo`03003o
oooooooo0?ooool2oooo0`00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003o1_oo
o`03003ooooooooo0?ooool2oooo0`00og3oool100000Oooo`005oooo`030000oooooooo01Koool2
003o1_ooo`03003ooooooooo0?ooool2oooo0`00og3oool100000Oooo`005oooo`030000oooooooo
01Koool2003o1_ooo`03003ooooooooo0?ooool3oooo0P00og3oool100000Oooo`005oooo`030000
oooooooo01Koool2003o1_ooo`03003ooooooooo0?ooool3oooo0P00og3oool100000Oooo`003_oo
o`<00006oooo00<0003oooooool05_ooo`800?l6oooo00<00?ooooooool0ooooo`?oool2003oL?oo
o`400001oooo000>oooo00<0003oooooool01_ooo`030000oooooooo01Koool2003o1_ooo`03003o
oooooooo0?ooool3oooo0P00og3oool100000Oooo`003oooo`030000oooooooo00Goool300005_oo
o`800?oooooo3?ooo`800?m^oooo0`00007oool000ooool00`000?ooooooo`05oooo00<0003ooooo
ool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool000koool00`000?ooo`000006oooo00<0
003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool000ooool00`000?ooooooo`05
oooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool001Ooool00`000?oo
ooooo`0Foooo0P00ooooool<oooo0P00og3oool100000Oooo`005oooo`030000oooooooo01Koool2
003oooooo`coool2003oL?ooo`400001oooo000Goooo00<0003oooooool05_ooo`800?oooooo3?oo
o`800?m`oooo0@00007oool001Ooool00`000?ooooooo`0Foooo0P00ooooool<oooo0P00og3oool1
00000Oooo`005oooo`030000oooooooo01Koool2003oooooo`coool2003oL?ooo`400001oooo000G
oooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool001Ooool200005ooo
o`800?oooooo3?ooo`800?m_oooo0P00007oool001Ooool00`000?ooooooo`0Foooo0P00ooooool<
oooo0P00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003oooooo`coool2003oL?oo
o`400001oooo000Goooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool0
01Ooool00`000?ooooooo`0Foooo0P00ooooool<oooo0P00og3oool100000Oooo`005oooo`030000
oooooooo01Koool2003oooooo`coool2003oL?ooo`400001oooo000Goooo00<0003oooooool05_oo
o`800?oooooo3?ooo`800?m`oooo0@00007oool001Ooool00`000?ooooooo`0Foooo0P00ooooool<
oooo0P00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003oooooo`coool2003oL?oo
o`400001oooo000Goooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool0
01Ooool200005oooo`800?oooooo3?ooo`800?m_oooo0P00007oool001Ooool00`000?ooooooo`0F
oooo0P00ooooool<oooo0P00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003ooooo
o`coool2003oL?ooo`400001oooo000Goooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`
oooo0@00007oool001Ooool00`000?ooooooo`0Foooo0P00ooooool<oooo0P00og3oool100000Ooo
o`005oooo`030000oooooooo01Koool2003oooooo`coool2003oL?ooo`400001oooo000Goooo00<0
003oooooool05_ooo`800?oooooo3?ooo`800?m`oooo0@00007oool001Ooool00`000?ooooooo`0F
oooo0P00ooooool<oooo0P00og3oool100000Oooo`005oooo`030000oooooooo01Koool2003ooooo
o`coool2003oL?ooo`400001oooo000Goooo00<0003oooooool05_ooo`800?oooooo3?ooo`800?m`
oooo0@00007oool001Ooool200005oooo`800?oooooo3?ooo`03003ooooooooo06koool200000Ooo
o`005oooo`030000oooooooo01Koool2003oooooo`coool00`00ooooooooo`1_oooo0@00007oool0
01Ooool00`000?ooooooo`0Foooo00<00?ooooooool0ooooo`_oool00`00ooooooooo`1_oooo0@00
007oool001Ooool00`000?ooooooo`0Foooo00<00?ooooooool0ooooo`_oool00`00ooooooooo`1_
oooo0@00007oool001Ooool00`000?ooooooo`0Foooo00<00?ooooooool0ooooo`_oool00`00oooo
ooooo`1_oooo0@00007oool001Ooool00`000?ooooooo`3ooooo9?ooo`03003ooooooooo06ooool1
00000Oooo`005oooo`030000oooooooo0?oooolToooo00<00?ooooooool0Koooo`400001oooo000G
oooo00<0003oooooool0ooooobCoool00`00ooooooooo`1_oooo0@00007oool001Ooool00`000?oo
ooooo`3ooooo9?ooo`03003ooooooooo06ooool100000Oooo`005oooo`030000oooooooo0?oooolT
oooo00<00?ooooooool0Koooo`400001oooo000Goooo0P000?oooolUoooo00<00?ooooooool0K_oo
o`800001oooo000Goooo00<0003oooooool0oooooiKoool100000Oooo`005oooo`030000oooooooo
0?oooonFoooo0@00007oool001Ooool00`000?ooooooo`3oooooU_ooo`400001oooo000Goooo00<0
003oooooool01_ooo`030000oooooooo06?oool00`000?ooooooo`1Roooo00<0003oooooool0H_oo
o`030000oooooooo05coool100000Oooo`005oooo`030000oooooooo00Koool00`000?ooooooo`0B
oooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003ooooo
ool04_ooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000
oooooooo01;oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0B
oooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003ooooo
ool02oooo`400001oooo000Gooooo`0009X00001oooo0000\
\>"],
  ImageRangeCache->{{{0, 432}, {266.5, 0}} -> {-161.93, -0.200139, 4.93398, 
  0.00999785}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sfa = {}; \nPrevMaxLoc = {1, 1}; \n
    PrevTable = 
      Table[0, {
          Length[T\[LSlash]AutoK\[LeftDoubleBracket]1
              \[RightDoubleBracket]]}]; \n
    For[i = 1, i <= Length[T\[LSlash]AutoK], \(i++\), \n\tMaxLoc = {0, 0}; \n
      \tMaxVal = {
          Max[T\[LSlash]AutoK\[LeftDoubleBracket]i\[RightDoubleBracket]], 0}; 
      \n\tFor[j = 1, 
        j <= Length[
            T\[LSlash]AutoK\[LeftDoubleBracket]i\[RightDoubleBracket]], 
        \(j++\), \n\t\t
        If[T\[LSlash]AutoK\[LeftDoubleBracket]i, j\[RightDoubleBracket] == 
            MaxVal\[LeftDoubleBracket]1\[RightDoubleBracket], 
          MaxLoc\[LeftDoubleBracket]1\[RightDoubleBracket] = j]; \n\t\t
        If[T\[LSlash]AutoK\[LeftDoubleBracket]i, j\[RightDoubleBracket] > 
              MaxVal\[LeftDoubleBracket]2\[RightDoubleBracket] && 
            T\[LSlash]AutoK\[LeftDoubleBracket]i, j\[RightDoubleBracket] < 
              MaxVal\[LeftDoubleBracket]1\[RightDoubleBracket], 
          MaxVal\[LeftDoubleBracket]2\[RightDoubleBracket] = 
            T\[LSlash]AutoK\[LeftDoubleBracket]i, j\[RightDoubleBracket]; 
          MaxLoc\[LeftDoubleBracket]2\[RightDoubleBracket] = j]]; \n\t
      sfal = \((
              T\[LSlash]AutoK\[LeftDoubleBracket]i, 
                MaxLoc\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\[RightDoubleBracket])\)*
            \((PrevTable
                \[LeftDoubleBracket]MaxLoc\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\[RightDoubleBracket])\) + \n\t\t\t
          \((T\[LSlash]AutoK\[LeftDoubleBracket]i, 
                MaxLoc\[LeftDoubleBracket]2
                  \[RightDoubleBracket]\[RightDoubleBracket])\)*
            \((PrevTable
                \[LeftDoubleBracket]MaxLoc\[LeftDoubleBracket]2
                  \[RightDoubleBracket]\[RightDoubleBracket])\) + \n\t\t\t
          \((T\[LSlash]AutoK\[LeftDoubleBracket]i, 
                PrevMaxLoc\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\[RightDoubleBracket])\)*
            \((PrevTable
                \[LeftDoubleBracket]PrevMaxLoc\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\[RightDoubleBracket])\) + \n\t\t\t
          \((T\[LSlash]AutoK\[LeftDoubleBracket]i, 
                PrevMaxLoc\[LeftDoubleBracket]2
                  \[RightDoubleBracket]\[RightDoubleBracket])\)*
            \((PrevTable
                \[LeftDoubleBracket]PrevMaxLoc\[LeftDoubleBracket]2
                  \[RightDoubleBracket]\[RightDoubleBracket])\); \n\t
      AppendTo[sfa, sfal]; \n\ \ 
      PrevTable = T\[LSlash]AutoK\[LeftDoubleBracket]i\[RightDoubleBracket]; 
      \n\tPrevMaxLoc = MaxLoc]; \nsfa *= 4; \)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`sfal\\)\\\" is similar to existing symbol \\\"\\!\
\\(TraditionalForm\\`sfa\\)\\\".\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[sfa, PlotRange -> All, PlotJoined -> True, 
      PlotStyle -> RGBColor[0, 1, 0], Frame -> True]; \)\)], "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0233132 0.00049629 0.0147344 0.0247341 [
[.02331 -0.0125 -3 -9 ]
[.02331 -0.0125 3 0 ]
[.27146 -0.0125 -9 -9 ]
[.27146 -0.0125 9 0 ]
[.5196 -0.0125 -12 -9 ]
[.5196 -0.0125 12 0 ]
[.76775 -0.0125 -12 -9 ]
[.76775 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01473 -6 -4.5 ]
[-0.0125 .01473 0 4.5 ]
[-0.0125 .1384 -6 -4.5 ]
[-0.0125 .1384 0 4.5 ]
[-0.0125 .26208 -12 -4.5 ]
[-0.0125 .26208 0 4.5 ]
[-0.0125 .38575 -12 -4.5 ]
[-0.0125 .38575 0 4.5 ]
[-0.0125 .50942 -12 -4.5 ]
[-0.0125 .50942 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02331 0 m
.02331 .00625 L
s
[(0)] .02331 -0.0125 0 1 Mshowa
.27146 0 m
.27146 .00625 L
s
[(500)] .27146 -0.0125 0 1 Mshowa
.5196 0 m
.5196 .00625 L
s
[(1000)] .5196 -0.0125 0 1 Mshowa
.76775 0 m
.76775 .00625 L
s
[(1500)] .76775 -0.0125 0 1 Mshowa
.125 Mabswid
.07294 0 m
.07294 .00375 L
s
.12257 0 m
.12257 .00375 L
s
.1722 0 m
.1722 .00375 L
s
.22183 0 m
.22183 .00375 L
s
.32109 0 m
.32109 .00375 L
s
.37072 0 m
.37072 .00375 L
s
.42035 0 m
.42035 .00375 L
s
.46997 0 m
.46997 .00375 L
s
.56923 0 m
.56923 .00375 L
s
.61886 0 m
.61886 .00375 L
s
.66849 0 m
.66849 .00375 L
s
.71812 0 m
.71812 .00375 L
s
.81738 0 m
.81738 .00375 L
s
.86701 0 m
.86701 .00375 L
s
.91664 0 m
.91664 .00375 L
s
.96626 0 m
.96626 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01473 m
.00625 .01473 L
s
[(0)] -0.0125 .01473 1 0 Mshowa
0 .1384 m
.00625 .1384 L
s
[(5)] -0.0125 .1384 1 0 Mshowa
0 .26208 m
.00625 .26208 L
s
[(10)] -0.0125 .26208 1 0 Mshowa
0 .38575 m
.00625 .38575 L
s
[(15)] -0.0125 .38575 1 0 Mshowa
0 .50942 m
.00625 .50942 L
s
[(20)] -0.0125 .50942 1 0 Mshowa
.125 Mabswid
0 .03947 m
.00375 .03947 L
s
0 .0642 m
.00375 .0642 L
s
0 .08894 m
.00375 .08894 L
s
0 .11367 m
.00375 .11367 L
s
0 .16314 m
.00375 .16314 L
s
0 .18787 m
.00375 .18787 L
s
0 .21261 m
.00375 .21261 L
s
0 .23734 m
.00375 .23734 L
s
0 .28681 m
.00375 .28681 L
s
0 .31154 m
.00375 .31154 L
s
0 .33628 m
.00375 .33628 L
s
0 .36101 m
.00375 .36101 L
s
0 .41048 m
.00375 .41048 L
s
0 .43521 m
.00375 .43521 L
s
0 .45995 m
.00375 .45995 L
s
0 .48468 m
.00375 .48468 L
s
0 .53415 m
.00375 .53415 L
s
0 .55888 m
.00375 .55888 L
s
0 .58362 m
.00375 .58362 L
s
0 .60835 m
.00375 .60835 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02331 .61178 m
.02331 .61803 L
s
.27146 .61178 m
.27146 .61803 L
s
.5196 .61178 m
.5196 .61803 L
s
.76775 .61178 m
.76775 .61803 L
s
.125 Mabswid
.07294 .61428 m
.07294 .61803 L
s
.12257 .61428 m
.12257 .61803 L
s
.1722 .61428 m
.1722 .61803 L
s
.22183 .61428 m
.22183 .61803 L
s
.32109 .61428 m
.32109 .61803 L
s
.37072 .61428 m
.37072 .61803 L
s
.42035 .61428 m
.42035 .61803 L
s
.46997 .61428 m
.46997 .61803 L
s
.56923 .61428 m
.56923 .61803 L
s
.61886 .61428 m
.61886 .61803 L
s
.66849 .61428 m
.66849 .61803 L
s
.71812 .61428 m
.71812 .61803 L
s
.81738 .61428 m
.81738 .61803 L
s
.86701 .61428 m
.86701 .61803 L
s
.91664 .61428 m
.91664 .61803 L
s
.96626 .61428 m
.96626 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01473 m
1 .01473 L
s
.99375 .1384 m
1 .1384 L
s
.99375 .26208 m
1 .26208 L
s
.99375 .38575 m
1 .38575 L
s
.99375 .50942 m
1 .50942 L
s
.125 Mabswid
.99625 .03947 m
1 .03947 L
s
.99625 .0642 m
1 .0642 L
s
.99625 .08894 m
1 .08894 L
s
.99625 .11367 m
1 .11367 L
s
.99625 .16314 m
1 .16314 L
s
.99625 .18787 m
1 .18787 L
s
.99625 .21261 m
1 .21261 L
s
.99625 .23734 m
1 .23734 L
s
.99625 .28681 m
1 .28681 L
s
.99625 .31154 m
1 .31154 L
s
.99625 .33628 m
1 .33628 L
s
.99625 .36101 m
1 .36101 L
s
.99625 .41048 m
1 .41048 L
s
.99625 .43521 m
1 .43521 L
s
.99625 .45995 m
1 .45995 L
s
.99625 .48468 m
1 .48468 L
s
.99625 .53415 m
1 .53415 L
s
.99625 .55888 m
1 .55888 L
s
.99625 .58362 m
1 .58362 L
s
.99625 .60835 m
1 .60835 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 1 0 r
.5 Mabswid
.02381 .01473 m
.02431 .01473 L
.0248 .01473 L
.0253 .01474 L
.02579 .01474 L
.02629 .01474 L
.02679 .01474 L
.02728 .01474 L
.02778 .01474 L
.02828 .01474 L
.02877 .01476 L
.02927 .01475 L
.02977 .01472 L
.03026 .01595 L
.03076 .03453 L
.03125 .19091 L
.03175 .2533 L
.03225 .24872 L
.03274 .21615 L
.03324 .18904 L
.03374 .17449 L
.03423 .16875 L
.03473 .16508 L
.03522 .16336 L
.03572 .17682 L
.03622 .19863 L
.03671 .20254 L
.03721 .20108 L
.03771 .20716 L
.0382 .20611 L
.0387 .19689 L
.03919 .19747 L
.03969 .19946 L
.04019 .19582 L
.04068 .20281 L
.04118 .21897 L
.04168 .24802 L
.04217 .28354 L
.04267 .31303 L
.04316 .3354 L
.04366 .35588 L
.04416 .3697 L
.04465 .38191 L
.04515 .39136 L
.04565 .3778 L
.04614 .33673 L
.04664 .28512 L
.04714 .2382 L
.04763 .19439 L
.04813 .15234 L
Mistroke
.04862 .11911 L
.04912 .09663 L
.04962 .08867 L
.05011 .09649 L
.05061 .12251 L
.05111 .1658 L
.0516 .21604 L
.0521 .25271 L
.05259 .26981 L
.05309 .27712 L
.05359 .28428 L
.05408 .28639 L
.05458 .27268 L
.05508 .24621 L
.05557 .21336 L
.05607 .17476 L
.05656 .14264 L
.05706 .12536 L
.05756 .13881 L
.05805 .19282 L
.05855 .2646 L
.05905 .29563 L
.05954 .2621 L
.06004 .20518 L
.06054 .20542 L
.06103 .28018 L
.06153 .42617 L
.06202 .55109 L
.06252 .60332 L
.06302 .59437 L
.06351 .54912 L
.06401 .49117 L
.06451 .4252 L
.065 .34478 L
.0655 .26591 L
.06599 .19238 L
.06649 .15103 L
.06699 .15005 L
.06748 .17468 L
.06798 .20919 L
.06848 .23924 L
.06897 .23723 L
.06947 .20613 L
.06996 .18629 L
.07046 .19781 L
.07096 .20682 L
.07145 .19596 L
.07195 .17867 L
.07245 .17392 L
.07294 .16851 L
Mistroke
.07344 .14452 L
.07393 .10839 L
.07443 .07809 L
.07493 .06332 L
.07542 .07822 L
.07592 .13491 L
.07642 .21608 L
.07691 .27247 L
.07741 .28013 L
.07791 .23419 L
.0784 .1697 L
.0789 .13509 L
.07939 .14457 L
.07989 .18866 L
.08039 .24497 L
.08088 .30136 L
.08138 .35844 L
.08188 .40662 L
.08237 .41023 L
.08287 .34331 L
.08336 .23287 L
.08386 .14559 L
.08436 .09638 L
.08485 .08542 L
.08535 .10643 L
.08585 .14856 L
.08634 .18603 L
.08684 .19449 L
.08733 .18648 L
.08783 .18622 L
.08833 .19095 L
.08882 .18162 L
.08932 .15705 L
.08982 .13996 L
.09031 .13832 L
.09081 .13379 L
.0913 .11571 L
.0918 .09729 L
.0923 .07994 L
.09279 .07323 L
.09329 .08702 L
.09379 .12928 L
.09428 .18545 L
.09478 .22844 L
.09528 .24868 L
.09577 .23883 L
.09627 .20614 L
.09676 .17328 L
.09726 .16017 L
.09776 .17317 L
Mistroke
.09825 .20596 L
.09875 .24734 L
.09925 .29466 L
.09974 .34024 L
.10024 .35407 L
.10073 .31149 L
.10123 .22663 L
.10173 .14047 L
.10222 .08432 L
.10272 .05977 L
.10322 .06391 L
.10371 .09092 L
.10421 .12512 L
.1047 .15311 L
.1052 .16821 L
.1057 .17971 L
.10619 .19198 L
.10669 .18147 L
.10719 .14011 L
.10768 .11736 L
.10818 .11299 L
.10868 .11207 L
.10917 .10107 L
.10967 .09041 L
.11016 .08505 L
.11066 .0858 L
.11116 .09284 L
.11165 .10805 L
.11215 .12437 L
.11265 .13476 L
.11314 .13149 L
.11364 .11311 L
.11413 .09047 L
.11463 .07218 L
.11513 .06073 L
.11562 .05773 L
.11612 .06474 L
.11662 .08523 L
.11711 .1165 L
.11761 .14118 L
.1181 .14526 L
.1186 .12798 L
.1191 .09768 L
.11959 .07207 L
.12009 .06015 L
.12059 .0568 L
.12108 .0556 L
.12158 .05603 L
.12207 .05667 L
.12257 .05399 L
Mistroke
.12307 .04796 L
.12356 .04144 L
.12406 .03532 L
.12456 .0297 L
.12505 .02428 L
.12555 .02102 L
.12605 .02067 L
.12654 .02207 L
.12704 .02411 L
.12753 .02367 L
.12803 .01847 L
.12853 .1594 L
.12902 .2521 L
.12952 .26197 L
.13002 .25403 L
.13051 .26362 L
.13101 .30297 L
.1315 .35671 L
.132 .37593 L
.1325 .34882 L
.13299 .31095 L
.13349 .29039 L
.13399 .25756 L
.13448 .20711 L
.13498 .17624 L
.13547 .17014 L
.13597 .14579 L
.13647 .1096 L
.13696 .08938 L
.13746 .0748 L
.13796 .06187 L
.13845 .0513 L
.13895 .04247 L
.13945 .0372 L
.13994 .03703 L
.14044 .03813 L
.14093 .03671 L
.14143 .03299 L
.14193 .02942 L
.14242 .02647 L
.14292 .02562 L
.14342 .02542 L
.14391 .02395 L
.14441 .02216 L
.1449 .01568 L
.1454 .03845 L
.1459 .09012 L
.14639 .09937 L
.14689 .08904 L
.14739 .09499 L
Mistroke
.14788 .10461 L
.14838 .10787 L
.14887 .10218 L
.14937 .09397 L
.14987 .09166 L
.15036 .09586 L
.15086 .10055 L
.15136 .09901 L
.15185 .09044 L
.15235 .0869 L
.15284 .08981 L
.15334 .08658 L
.15384 .07166 L
.15433 .05766 L
.15483 .05227 L
.15533 .05386 L
.15582 .05496 L
.15632 .05183 L
.15682 .04695 L
.15731 .04552 L
.15781 .04625 L
.1583 .04314 L
.1588 .03936 L
.1593 .03659 L
.15979 .03867 L
.16029 .08792 L
.16079 .23517 L
.16128 .29892 L
.16178 .32493 L
.16227 .3425 L
.16277 .33303 L
.16327 .29253 L
.16376 .25733 L
.16426 .23765 L
.16476 .23669 L
.16525 .22237 L
.16575 .2081 L
.16624 .19916 L
.16674 .17746 L
.16724 .14629 L
.16773 .12766 L
.16823 .11675 L
.16873 .07932 L
.16922 .04326 L
.16972 .03179 L
.17022 .03979 L
.17071 .05506 L
.17121 .0562 L
.1717 .05078 L
.1722 .04648 L
Mistroke
.1727 .04421 L
.17319 .04999 L
.17369 .05731 L
.17419 .04284 L
.17468 .05571 L
.17518 .07142 L
.17567 .08483 L
.17617 .09239 L
.17667 .09742 L
.17716 .10222 L
.17766 .10667 L
.17816 .11768 L
.17865 .12563 L
.17915 .12783 L
.17964 .11544 L
.18014 .09496 L
.18064 .07377 L
.18113 .05528 L
.18163 .0437 L
.18213 .03953 L
.18262 .04048 L
.18312 .04318 L
.18361 .04227 L
.18411 .03642 L
.18461 .02994 L
.1851 .02462 L
.1856 .02274 L
.1861 .02306 L
.18659 .02472 L
.18709 .02694 L
.18759 .02903 L
.18808 .02566 L
.18858 .018 L
.18907 .04236 L
.18957 .12466 L
.19007 .1873 L
.19056 .24953 L
.19106 .28072 L
.19156 .26565 L
.19205 .23914 L
.19255 .2118 L
.19304 .17763 L
.19354 .14674 L
.19404 .13033 L
.19453 .1127 L
.19503 .0938 L
.19553 .08205 L
.19602 .07386 L
.19652 .05675 L
.19701 .03419 L
Mistroke
.19751 .02448 L
.19801 .02241 L
.1985 .02116 L
.199 .02054 L
.1995 .02134 L
.19999 .02222 L
.20049 .02348 L
.20099 .02523 L
.20148 .02471 L
.20198 .02197 L
.20247 .02337 L
.20297 .04051 L
.20347 .06378 L
.20396 .088 L
.20446 .09682 L
.20496 .09862 L
.20545 .09624 L
.20595 .09329 L
.20644 .09642 L
.20694 .10495 L
.20744 .10743 L
.20793 .10227 L
.20843 .08526 L
.20893 .06396 L
.20942 .04266 L
.20992 .0248 L
.21041 .02321 L
.21091 .02821 L
.21141 .02919 L
.2119 .02799 L
.2124 .0276 L
.2129 .0283 L
.21339 .03109 L
.21389 .03464 L
.21438 .0373 L
.21488 .03544 L
.21538 .03276 L
.21587 .03516 L
.21637 .04071 L
.21687 .08435 L
.21736 .12501 L
.21786 .14622 L
.21836 .1451 L
.21885 .14181 L
.21935 .13831 L
.21984 .1347 L
.22034 .11898 L
.22084 .10584 L
.22133 .09718 L
.22183 .08673 L
Mistroke
.22233 .07371 L
.22282 .06266 L
.22332 .05596 L
.22381 .04683 L
.22431 .03902 L
.22481 .03198 L
.2253 .02766 L
.2258 .0262 L
.2263 .02513 L
.22679 .02376 L
.22729 .02395 L
.22778 .02525 L
.22828 .02706 L
.22878 .02837 L
.22927 .02491 L
.22977 .02688 L
.23027 .05734 L
.23076 .10881 L
.23126 .12227 L
.23176 .13516 L
.23225 .14185 L
.23275 .1443 L
.23324 .15251 L
.23374 .16169 L
.23424 .15658 L
.23473 .14052 L
.23523 .11932 L
.23573 .08851 L
.23622 .0597 L
.23672 .0375 L
.23721 .02523 L
.23771 .02763 L
.23821 .038 L
.2387 .03742 L
.2392 .03125 L
.2397 .02568 L
.24019 .02189 L
.24069 .0215 L
.24118 .02268 L
.24168 .02252 L
.24218 .0232 L
.24267 .01853 L
.24317 .03437 L
.24367 .09284 L
.24416 .17446 L
.24466 .20428 L
.24515 .19035 L
.24565 .16364 L
.24615 .14833 L
.24664 .15194 L
Mistroke
.24714 .16232 L
.24764 .17196 L
.24813 .18656 L
.24863 .20658 L
.24913 .20628 L
.24962 .16336 L
.25012 .1096 L
.25061 .084 L
.25111 .0778 L
.25161 .07197 L
.2521 .06303 L
.2526 .05512 L
.2531 .0372 L
.25359 .03251 L
.25409 .03243 L
.25458 .03127 L
.25508 .02874 L
.25558 .02558 L
.25607 .02295 L
.25657 .02733 L
.25707 .05179 L
.25756 .07111 L
.25806 .08402 L
.25855 .08986 L
.25905 .0981 L
.25955 .0992 L
.26004 .09366 L
.26054 .09027 L
.26104 .08809 L
.26153 .08722 L
.26203 .08683 L
.26253 .08084 L
.26302 .06401 L
.26352 .03882 L
.26401 .02422 L
.26451 .02311 L
.26501 .02749 L
.2655 .02867 L
.266 .02651 L
.2665 .02598 L
.26699 .02677 L
.26749 .02609 L
.26798 .02355 L
.26848 .02102 L
.26898 .01887 L
.26947 .01744 L
.26997 .01715 L
.27047 .01895 L
.27096 .03378 L
.27146 .053 L
Mistroke
.27195 .07155 L
.27245 .07513 L
.27295 .07674 L
.27344 .08204 L
.27394 .0837 L
.27444 .07504 L
.27493 .06739 L
.27543 .06734 L
.27592 .06973 L
.27642 .06226 L
.27692 .05397 L
.27741 .04589 L
.27791 .04151 L
.27841 .04412 L
.2789 .04337 L
.2794 .04013 L
.2799 .03471 L
.28039 .02692 L
.28089 .02113 L
.28138 .0232 L
.28188 .02561 L
.28238 .02754 L
.28287 .03568 L
.28337 .07702 L
.28387 .14235 L
.28436 .17872 L
.28486 .18704 L
.28535 .18151 L
.28585 .17097 L
.28635 .15353 L
.28684 .13487 L
.28734 .12033 L
.28784 .10823 L
.28833 .09323 L
.28883 .07624 L
.28932 .06099 L
.28982 .04404 L
.29032 .03156 L
.29081 .02834 L
.29131 .03046 L
.29181 .03086 L
.2923 .02946 L
.2928 .02855 L
.2933 .02751 L
.29379 .02638 L
.29429 .0256 L
.29478 .02401 L
.29528 .02163 L
.29578 .01892 L
.29627 .01587 L
Mistroke
.29677 .02741 L
.29727 .10005 L
.29776 .20388 L
.29826 .25761 L
.29875 .27125 L
.29925 .24865 L
.29975 .21784 L
.30024 .19526 L
.30074 .16131 L
.30124 .13715 L
.30173 .1226 L
.30223 .10684 L
.30272 .09311 L
.30322 .0792 L
.30372 .05874 L
.30421 .04262 L
.30471 .03521 L
.30521 .0307 L
.3057 .02891 L
.3062 .02828 L
.30669 .02682 L
.30719 .02439 L
.30769 .02295 L
.30818 .02354 L
.30868 .02333 L
.30918 .02326 L
.30967 .02956 L
.31017 .04334 L
.31067 .05323 L
.31116 .05589 L
.31166 .06104 L
.31215 .06981 L
.31265 .0849 L
.31315 .10131 L
.31364 .10988 L
.31414 .11654 L
.31464 .12539 L
.31513 .12957 L
.31563 .12249 L
.31612 .09988 L
.31662 .06863 L
.31712 .04318 L
.31761 .03037 L
.31811 .02657 L
.31861 .02893 L
.3191 .03198 L
.3196 .02766 L
.32009 .02381 L
.32059 .02512 L
.32109 .03021 L
Mistroke
.32158 .03438 L
.32208 .03181 L
.32258 .02909 L
.32307 .0272 L
.32357 .02258 L
.32407 .01899 L
.32456 .0181 L
.32506 .02403 L
.32555 .05677 L
.32605 .07379 L
.32655 .06782 L
.32704 .05821 L
.32754 .05379 L
.32804 .05372 L
.32853 .04967 L
.32903 .04486 L
.32952 .04339 L
.33002 .04102 L
.33052 .03886 L
.33101 .03634 L
.33151 .03252 L
.33201 .03383 L
.3325 .04187 L
.333 .04655 L
.33349 .04307 L
.33399 .03888 L
.33449 .03403 L
.33498 .0321 L
.33548 .0325 L
.33598 .03209 L
.33647 .02841 L
.33697 .02255 L
.33746 .03113 L
.33796 .08018 L
.33846 .11937 L
.33895 .13932 L
.33945 .13617 L
.33995 .13012 L
.34044 .12623 L
.34094 .12611 L
.34144 .13283 L
.34193 .14039 L
.34243 .13619 L
.34292 .11902 L
.34342 .08937 L
.34392 .05688 L
.34441 .03944 L
.34491 .03837 L
.34541 .04501 L
.3459 .04519 L
Mistroke
.3464 .03949 L
.34689 .03168 L
.34739 .02348 L
.34789 .01838 L
.34838 .01671 L
.34888 .01618 L
.34938 .01648 L
.34987 .01771 L
.35037 .01904 L
.35086 .01916 L
.35136 .0234 L
.35186 .03481 L
.35235 .09025 L
.35285 .20241 L
.35335 .25488 L
.35384 .23763 L
.35434 .19301 L
.35484 .15775 L
.35533 .13163 L
.35583 .10681 L
.35632 .08727 L
.35682 .07087 L
.35732 .06555 L
.35781 .07254 L
.35831 .07169 L
.35881 .07569 L
.3593 .08558 L
.3598 .07999 L
.36029 .0522 L
.36079 .02841 L
.36129 .02138 L
.36178 .02361 L
.36228 .02325 L
.36278 .02361 L
.36327 .02532 L
.36377 .02752 L
.36426 .02903 L
.36476 .04584 L
.36526 .09075 L
.36575 .11469 L
.36625 .12068 L
.36675 .12768 L
.36724 .13155 L
.36774 .13206 L
.36823 .13051 L
.36873 .13343 L
.36923 .13787 L
.36972 .13774 L
.37022 .13436 L
.37072 .12183 L
Mistroke
.37121 .09186 L
.37171 .05723 L
.37221 .03487 L
.3727 .02684 L
.3732 .02959 L
.37369 .03264 L
.37419 .03056 L
.37469 .02448 L
.37518 .02076 L
.37568 .02139 L
.37618 .02518 L
.37667 .02759 L
.37717 .02456 L
.37766 .02304 L
.37816 .02329 L
.37866 .02474 L
.37915 .02907 L
.37965 .04254 L
.38015 .0766 L
.38064 .08766 L
.38114 .08854 L
.38163 .08347 L
.38213 .07517 L
.38263 .06943 L
.38312 .07639 L
.38362 .08693 L
.38412 .08755 L
.38461 .09021 L
.38511 .09321 L
.38561 .09281 L
.3861 .08442 L
.3866 .06822 L
.38709 .0531 L
.38759 .04519 L
.38809 .04525 L
.38858 .04662 L
.38908 .04071 L
.38958 .03541 L
.39007 .02873 L
.39057 .02569 L
.39106 .02356 L
.39156 .02885 L
.39206 .04823 L
.39255 .07672 L
.39305 .09957 L
.39355 .10086 L
.39404 .10032 L
.39454 .10423 L
.39503 .10557 L
.39553 .10738 L
Mistroke
.39603 .10831 L
.39652 .10846 L
.39702 .1052 L
.39752 .09495 L
.39801 .07835 L
.39851 .06083 L
.399 .04398 L
.3995 .03554 L
.4 .03651 L
.40049 .03837 L
.40099 .035 L
.40149 .03324 L
.40198 .02841 L
.40248 .02224 L
.40298 .01813 L
.40347 .01598 L
.40397 .01612 L
.40446 .01692 L
.40496 .01717 L
.40546 .01687 L
.40595 .02119 L
.40645 .03124 L
.40695 .05963 L
.40744 .13311 L
.40794 .25475 L
.40843 .3122 L
.40893 .30101 L
.40943 .28886 L
.40992 .29355 L
.41042 .26714 L
.41092 .20729 L
.41141 .15381 L
.41191 .1142 L
.4124 .08009 L
.4129 .05288 L
.4134 .04656 L
.41389 .07186 L
.41439 .10284 L
.41489 .09466 L
.41538 .0657 L
.41588 .05954 L
.41638 .07591 L
.41687 .08689 L
.41737 .08075 L
.41786 .06181 L
.41836 .04166 L
.41886 .03179 L
.41935 .03487 L
.41985 .05094 L
.42035 .10879 L
Mistroke
.42084 .18409 L
.42134 .18025 L
.42183 .16446 L
.42233 .13849 L
.42283 .12129 L
.42332 .12678 L
.42382 .14448 L
.42432 .1583 L
.42481 .13458 L
.42531 .12218 L
.4258 .12674 L
.4263 .10983 L
.4268 .08057 L
.42729 .05305 L
.42779 .04226 L
.42829 .05471 L
.42878 .09365 L
.42928 .09695 L
.42977 .09189 L
.43027 .07138 L
.43077 .06882 L
.43126 .06133 L
.43176 .064 L
.43226 .07821 L
.43275 .08131 L
.43325 .08381 L
.43375 .09027 L
.43424 .09456 L
.43474 .07445 L
.43523 .05317 L
.43573 .04463 L
.43623 .13292 L
.43672 .21338 L
.43722 .23276 L
.43772 .21417 L
.43821 .1697 L
.43871 .15988 L
.4392 .1528 L
.4397 .09773 L
.4402 .08423 L
.44069 .06242 L
.44119 .05287 L
.44169 .05249 L
.44218 .05507 L
.44268 .04696 L
.44317 .02847 L
.44367 .02416 L
.44417 .02966 L
.44466 .03255 L
.44516 .02127 L
Mistroke
.44566 .02138 L
.44615 .02261 L
.44665 .03079 L
.44715 .04305 L
.44764 .06669 L
.44814 .11842 L
.44863 .14952 L
.44913 .12524 L
.44963 .12495 L
.45012 .16706 L
.45062 .20592 L
.45112 .25307 L
.45161 .28074 L
.45211 .27892 L
.4526 .2739 L
.4531 .2356 L
.4536 .21577 L
.45409 .19632 L
.45459 .13651 L
.45509 .08431 L
.45558 .07472 L
.45608 .10113 L
.45657 .12284 L
.45707 .10447 L
.45757 .0772 L
.45806 .05557 L
.45856 .04522 L
.45906 .04534 L
.45955 .05615 L
.46005 .06593 L
.46054 .06352 L
.46104 .06352 L
.46154 .05738 L
.46203 .0486 L
.46253 .05588 L
.46303 .05864 L
.46352 .05288 L
.46402 .05985 L
.46452 .06897 L
.46501 .07182 L
.46551 .06394 L
.466 .05372 L
.4665 .05098 L
.467 .05299 L
.46749 .06037 L
.46799 .06051 L
.46849 .05442 L
.46898 .05037 L
.46948 .04152 L
.46997 .0318 L
Mistroke
.47047 .02685 L
.47097 .02303 L
.47146 .02784 L
.47196 .03607 L
.47246 .03565 L
.47295 .02472 L
.47345 .02345 L
.47394 .02271 L
.47444 .02172 L
.47494 .02749 L
.47543 .09583 L
.47593 .23049 L
.47643 .29133 L
.47692 .33236 L
.47742 .33339 L
.47792 .28674 L
.47841 .28848 L
.47891 .32205 L
.4794 .2975 L
.4799 .23963 L
.4804 .2174 L
.48089 .21197 L
.48139 .15853 L
.48189 .09033 L
.48238 .07354 L
.48288 .09421 L
.48337 .1152 L
.48387 .11065 L
.48437 .08144 L
.48486 .05773 L
.48536 .04049 L
.48586 .03211 L
.48635 .03965 L
.48685 .05221 L
.48734 .05128 L
.48784 .04385 L
.48834 .02945 L
.48883 .03418 L
.48933 .05154 L
.48983 .0511 L
.49032 .05137 L
.49082 .07425 L
.49131 .11128 L
.49181 .13252 L
.49231 .14554 L
.4928 .14909 L
.4933 .14038 L
.4938 .13703 L
.49429 .13198 L
.49479 .11869 L
Mistroke
.49529 .09225 L
.49578 .06056 L
.49628 .04361 L
.49677 .0412 L
.49727 .04103 L
.49777 .03558 L
.49826 .02659 L
.49876 .02444 L
.49926 .03071 L
.49975 .03955 L
.50025 .04251 L
.50074 .04011 L
.50124 .03398 L
.50174 .03111 L
.50223 .056 L
.50273 .07916 L
.50323 .08875 L
.50372 .08348 L
.50422 .07796 L
.50471 .0713 L
.50521 .05152 L
.50571 .04415 L
.5062 .04595 L
.5067 .04203 L
.5072 .03414 L
.50769 .03156 L
.50819 .03483 L
.50869 .03406 L
.50918 .02932 L
.50968 .02884 L
.51017 .02894 L
.51067 .02667 L
.51117 .02516 L
.51166 .02351 L
.51216 .02113 L
.51266 .01993 L
.51315 .01715 L
.51365 .017 L
.51414 .0192 L
.51464 .02006 L
.51514 .01654 L
.51563 .0192 L
.51613 .02658 L
.51663 .02862 L
.51712 .03846 L
.51762 .0496 L
.51811 .05106 L
.51861 .05229 L
.51911 .06355 L
.5196 .08391 L
Mistroke
.5201 .10104 L
.5206 .11224 L
.52109 .11758 L
.52159 .10926 L
.52208 .10791 L
.52258 .11744 L
.52308 .10723 L
.52357 .08213 L
.52407 .07379 L
.52457 .07839 L
.52506 .0736 L
.52556 .07138 L
.52606 .07758 L
.52655 .07748 L
.52705 .07359 L
.52754 .06876 L
.52804 .06044 L
.52854 .05032 L
.52903 .05372 L
.52953 .10432 L
.53003 .14708 L
.53052 .13788 L
.53102 .14565 L
.53151 .1261 L
.53201 .08987 L
.53251 .07851 L
.533 .08797 L
.5335 .09427 L
.534 .08308 L
.53449 .07009 L
.53499 .06932 L
.53548 .06393 L
.53598 .05945 L
.53648 .0648 L
.53697 .06095 L
.53747 .06303 L
.53797 .07873 L
.53846 .07805 L
.53896 .06952 L
.53946 .06984 L
.53995 .06306 L
.54045 .03935 L
.54094 .03625 L
.54144 .03255 L
.54194 .02921 L
.54243 .033 L
.54293 .03261 L
.54343 .0385 L
.54392 .03614 L
.54442 .03804 L
Mistroke
.54491 .04417 L
.54541 .03193 L
.54591 .02657 L
.5464 .03499 L
.5469 .05218 L
.5474 .05606 L
.54789 .07232 L
.54839 .08956 L
.54888 .08085 L
.54938 .08005 L
.54988 .09368 L
.55037 .07914 L
.55087 .05516 L
.55137 .0452 L
.55186 .03945 L
.55236 .03649 L
.55285 .03664 L
.55335 .03218 L
.55385 .02091 L
.55434 .0217 L
.55484 .02076 L
.55534 .02206 L
.55583 .02217 L
.55633 .03262 L
.55683 .03394 L
.55732 .0364 L
.55782 .02964 L
.55831 .02446 L
.55881 .02326 L
.55931 .02626 L
.5598 .0297 L
.5603 .02347 L
.5608 .02494 L
.56129 .03323 L
.56179 .03546 L
.56228 .04037 L
.56278 .0407 L
.56328 .03834 L
.56377 .04079 L
.56427 .03956 L
.56477 .0433 L
.56526 .04907 L
.56576 .04323 L
.56625 .0352 L
.56675 .02991 L
.56725 .02942 L
.56774 .02905 L
.56824 .02079 L
.56874 .02079 L
.56923 .02 L
Mistroke
.56973 .01949 L
.57023 .02276 L
.57072 .02759 L
.57122 .02938 L
.57171 .02872 L
.57221 .02864 L
.57271 .02898 L
.5732 .02763 L
.5737 .02586 L
.5742 .0257 L
.57469 .02454 L
.57519 .03205 L
.57568 .03396 L
.57618 .03181 L
.57668 .02843 L
.57717 .02656 L
.57767 .02505 L
.57817 .02123 L
.57866 .0189 L
.57916 .01927 L
.57965 .01993 L
.58015 .01965 L
.58065 .02098 L
.58114 .01967 L
.58164 .01957 L
.58214 .04778 L
.58263 .1069 L
.58313 .16081 L
.58362 .19 L
.58412 .18019 L
.58462 .15106 L
.58511 .12967 L
.58561 .1375 L
.58611 .1545 L
.5866 .15682 L
.5871 .16706 L
.5876 .17308 L
.58809 .15039 L
.58859 .13994 L
.58908 .13955 L
.58958 .13803 L
.59008 .14352 L
.59057 .12395 L
.59107 .0814 L
.59157 .06073 L
.59206 .05741 L
.59256 .06086 L
.59305 .07027 L
.59355 .0744 L
.59405 .05765 L
Mistroke
.59454 .03906 L
.59504 .0323 L
.59554 .03188 L
.59603 .03251 L
.59653 .03953 L
.59702 .03962 L
.59752 .0344 L
.59802 .03541 L
.59851 .03423 L
.59901 .03561 L
.59951 .03707 L
.6 .0441 L
.6005 .04729 L
.601 .04606 L
.60149 .04947 L
.60199 .04927 L
.60248 .04008 L
.60298 .02675 L
.60348 .01848 L
.60397 .01763 L
.60447 .01761 L
.60497 .01796 L
.60546 .01794 L
.60596 .01797 L
.60645 .01945 L
.60695 .0221 L
.60745 .02531 L
.60794 .02239 L
.60844 .02392 L
.60894 .03877 L
.60943 .05173 L
.60993 .05333 L
.61042 .05001 L
.61092 .04993 L
.61142 .0467 L
.61191 .04007 L
.61241 .03797 L
.61291 .0373 L
.6134 .0336 L
.6139 .03238 L
.61439 .0356 L
.61489 .0324 L
.61539 .02458 L
.61588 .02331 L
.61638 .02482 L
.61688 .02194 L
.61737 .01996 L
.61787 .0214 L
.61837 .02207 L
.61886 .01929 L
Mistroke
.61936 .01737 L
.61985 .01657 L
.62035 .01646 L
.62085 .01684 L
.62134 .01687 L
.62184 .0167 L
.62234 .01926 L
.62283 .02295 L
.62333 .02763 L
.62382 .05544 L
.62432 .07479 L
.62482 .08106 L
.62531 .0724 L
.62581 .06379 L
.62631 .06984 L
.6268 .07344 L
.6273 .06733 L
.62779 .07057 L
.62829 .07588 L
.62879 .06775 L
.62928 .04696 L
.62978 .03015 L
.63028 .02259 L
.63077 .02153 L
.63127 .02401 L
.63177 .02704 L
.63226 .02726 L
.63276 .02681 L
.63325 .02378 L
.63375 .01977 L
.63425 .01806 L
.63474 .0182 L
.63524 .01819 L
.63574 .01788 L
.63623 .04091 L
.63673 .05398 L
.63722 .05891 L
.63772 .06715 L
.63822 .07502 L
.63871 .07742 L
.63921 .08122 L
.63971 .09142 L
.6402 .10424 L
.6407 .11441 L
.64119 .1173 L
.64169 .11242 L
.64219 .09111 L
.64268 .06305 L
.64318 .04179 L
.64368 .03243 L
Mistroke
.64417 .03447 L
.64467 .04012 L
.64516 .03953 L
.64566 .03449 L
.64616 .03124 L
.64665 .03332 L
.64715 .03743 L
.64765 .03776 L
.64814 .03555 L
.64864 .03599 L
.64914 .03642 L
.64963 .05578 L
.65013 .07283 L
.65062 .0841 L
.65112 .08715 L
.65162 .08486 L
.65211 .0837 L
.65261 .07576 L
.65311 .0672 L
.6536 .06232 L
.6541 .05589 L
.65459 .05188 L
.65509 .05306 L
.65559 .05162 L
.65608 .04862 L
.65658 .04623 L
.65708 .04022 L
.65757 .03493 L
.65807 .03244 L
.65856 .03033 L
.65906 .02797 L
.65956 .02589 L
.66005 .02421 L
.66055 .02338 L
.66105 .02388 L
.66154 .02349 L
.66204 .02302 L
.66254 .02407 L
.66303 .02978 L
.66353 .07035 L
.66402 .15523 L
.66452 .18045 L
.66502 .17995 L
.66551 .1768 L
.66601 .1472 L
.66651 .12514 L
.667 .12828 L
.6675 .10702 L
.66799 .08035 L
.66849 .07979 L
Mistroke
.66899 .08605 L
.66948 .08137 L
.66998 .07187 L
.67048 .06301 L
.67097 .06508 L
.67147 .07037 L
.67196 .06084 L
.67246 .03837 L
.67296 .02556 L
.67345 .02737 L
.67395 .03159 L
.67445 .03176 L
.67494 .0302 L
.67544 .03067 L
.67593 .03112 L
.67643 .03339 L
.67693 .03937 L
.67742 .04744 L
.67792 .08145 L
.67842 .11075 L
.67891 .09092 L
.67941 .08423 L
.67991 .09526 L
.6804 .10209 L
.6809 .10537 L
.68139 .08789 L
.68189 .07445 L
.68239 .07461 L
.68288 .10319 L
.68338 .15627 L
.68388 .14463 L
.68437 .08918 L
.68487 .09044 L
.68536 .09536 L
.68586 .06334 L
.68636 .03689 L
.68685 .02906 L
.68735 .03462 L
.68785 .0522 L
.68834 .07563 L
.68884 .09311 L
.68933 .10116 L
.68983 .11195 L
.69033 .14962 L
.69082 .16038 L
.69132 .14242 L
.69182 .13641 L
.69231 .12925 L
.69281 .11626 L
.69331 .111 L
Mistroke
.6938 .1182 L
.6943 .10421 L
.69479 .09308 L
.69529 .08518 L
.69579 .07976 L
.69628 .06977 L
.69678 .03989 L
.69728 .03095 L
.69777 .04038 L
.69827 .05987 L
.69876 .07998 L
.69926 .07285 L
.69976 .05988 L
.70025 .06267 L
.70075 .0633 L
.70125 .05263 L
.70174 .04263 L
.70224 .03955 L
.70273 .04149 L
.70323 .04771 L
.70373 .06756 L
.70422 .13005 L
.70472 .16578 L
.70522 .15059 L
.70571 .14104 L
.70621 .13635 L
.7067 .11973 L
.7072 .11618 L
.7077 .12982 L
.70819 .14934 L
.70869 .15465 L
.70919 .16887 L
.70968 .17103 L
.71018 .1284 L
.71068 .09244 L
.71117 .07022 L
.71167 .07014 L
.71216 .08154 L
.71266 .07763 L
.71316 .06534 L
.71365 .04145 L
.71415 .03057 L
.71465 .0286 L
.71514 .02643 L
.71564 .02399 L
.71613 .02063 L
.71663 .05247 L
.71713 .17569 L
.71762 .31921 L
.71812 .40506 L
Mistroke
.71862 .41129 L
.71911 .38465 L
.71961 .36509 L
.7201 .41565 L
.7206 .54097 L
.7211 .5911 L
.72159 .54079 L
.72209 .53136 L
.72259 .53889 L
.72308 .46265 L
.72358 .361 L
.72408 .28351 L
.72457 .20254 L
.72507 .13119 L
.72556 .09352 L
.72606 .08354 L
.72656 .07561 L
.72705 .04538 L
.72755 .02998 L
.72805 .02219 L
.72854 .01964 L
.72904 .02062 L
.72953 .02698 L
.73003 .03514 L
.73053 .03942 L
.73102 .0271 L
.73152 .03039 L
.73202 .03826 L
.73251 .07512 L
.73301 .16221 L
.7335 .17749 L
.734 .16876 L
.7345 .16265 L
.73499 .14754 L
.73549 .1115 L
.73599 .07222 L
.73648 .04202 L
.73698 .02558 L
.73747 .02075 L
.73797 .02357 L
.73847 .04185 L
.73896 .08213 L
.73946 .08731 L
.73996 .06923 L
.74045 .05379 L
.74095 .05222 L
.74145 .05997 L
.74194 .07447 L
.74244 .08122 L
.74293 .07413 L
Mistroke
.74343 .07693 L
.74393 .07123 L
.74442 .05986 L
.74492 .0396 L
.74542 .03392 L
.74591 .0662 L
.74641 .08261 L
.7469 .07775 L
.7474 .06685 L
.7479 .06217 L
.74839 .05638 L
.74889 .05407 L
.74939 .05099 L
.74988 .04732 L
.75038 .04179 L
.75087 .03933 L
.75137 .03117 L
.75187 .03704 L
.75236 .03381 L
.75286 .03224 L
.75336 .02756 L
.75385 .02469 L
.75435 .02576 L
.75485 .02393 L
.75534 .02251 L
.75584 .02183 L
.75633 .0187 L
.75683 .01758 L
.75733 .01679 L
.75782 .02017 L
.75832 .01813 L
.75882 .02325 L
.75931 .04671 L
.75981 .07161 L
.7603 .07847 L
.7608 .07782 L
.7613 .07823 L
.76179 .08695 L
.76229 .09971 L
.76279 .10946 L
.76328 .1153 L
.76378 .11976 L
.76427 .11828 L
.76477 .10822 L
.76527 .08623 L
.76576 .05831 L
.76626 .04516 L
.76676 .04785 L
.76725 .05169 L
.76775 .04788 L
Mistroke
.76824 .03809 L
.76874 .02729 L
.76924 .01944 L
.76973 .0168 L
.77023 .0172 L
.77073 .02039 L
.77122 .02562 L
.77172 .02696 L
.77222 .02658 L
.77271 .02822 L
.77321 .04278 L
.7737 .09401 L
.7742 .16188 L
.7747 .1839 L
.77519 .19619 L
.77569 .20898 L
.77619 .23043 L
.77668 .26276 L
.77718 .27846 L
.77767 .2763 L
.77817 .24656 L
.77867 .17176 L
.77916 .07925 L
.77966 .04203 L
.78016 .04782 L
.78065 .05615 L
.78115 .05313 L
.78164 .04224 L
.78214 .03294 L
.78264 .02641 L
.78313 .02483 L
.78363 .02804 L
.78413 .02925 L
.78462 .0331 L
.78512 .04206 L
.78562 .04642 L
.78611 .04226 L
.78661 .03566 L
.7871 .02764 L
.7876 .02783 L
.7881 .03717 L
.78859 .06459 L
.78909 .08242 L
.78959 .0996 L
.79008 .09549 L
.79058 .09015 L
.79107 .07567 L
.79157 .05518 L
.79207 .03941 L
.79256 .0304 L
Mistroke
.79306 .02584 L
.79356 .02341 L
.79405 .02483 L
.79455 .03827 L
.79504 .05898 L
.79554 .06185 L
.79604 .05061 L
.79653 .039 L
.79703 .037 L
.79753 .03969 L
.79802 .0421 L
.79852 .03946 L
.79901 .0376 L
.79951 .03517 L
.80001 .0324 L
.8005 .03067 L
.801 .03133 L
.8015 .02941 L
.80199 .04606 L
.80249 .05593 L
.80299 .04895 L
.80348 .0419 L
.80398 .03689 L
.80447 .03537 L
.80497 .03493 L
.80547 .03271 L
.80596 .0312 L
.80646 .02824 L
.80696 .0231 L
.80745 .02859 L
.80795 .02974 L
.80844 .02579 L
.80894 .02222 L
.80944 .02101 L
.80993 .02185 L
.81043 .02094 L
.81093 .01895 L
.81142 .01701 L
.81192 .01715 L
.81241 .01798 L
.81291 .01675 L
.81341 .01739 L
.8139 .01795 L
.8144 .01728 L
.8149 .01735 L
.81539 .01912 L
.81589 .0221 L
.81639 .03814 L
.81688 .06074 L
.81738 .07626 L
Mistroke
.81787 .08991 L
.81837 .09706 L
.81887 .09772 L
.81936 .09753 L
.81986 .09852 L
.82036 .0913 L
.82085 .07793 L
.82135 .06362 L
.82184 .04971 L
.82234 .04044 L
.82284 .03841 L
.82333 .04271 L
.82383 .04703 L
.82433 .04326 L
.82482 .03422 L
.82532 .02608 L
.82581 .02121 L
.82631 .0209 L
.82681 .02245 L
.8273 .02216 L
.8278 .02217 L
.8283 .02395 L
.82879 .02647 L
.82929 .02775 L
.82978 .02652 L
.83028 .02429 L
.83078 .02209 L
.83127 .02033 L
.83177 .01912 L
.83227 .01837 L
.83276 .02962 L
.83326 .10837 L
.83376 .19625 L
.83425 .22066 L
.83475 .22171 L
.83524 .22973 L
.83574 .24956 L
.83624 .27499 L
.83673 .30343 L
.83723 .31808 L
.83773 .30106 L
.83822 .24892 L
.83872 .1807 L
.83921 .12385 L
.83971 .08353 L
.84021 .05735 L
.8407 .04746 L
.8412 .04292 L
.8417 .03363 L
.84219 .02816 L
Mistroke
.84269 .02993 L
.84318 .03584 L
.84368 .03697 L
.84418 .03281 L
.84467 .0297 L
.84517 .02752 L
.84567 .02384 L
.84616 .02129 L
.84666 .02076 L
.84716 .02106 L
.84765 .02103 L
.84815 .02195 L
.84864 .02678 L
.84914 .03201 L
.84964 .03251 L
.85013 .03095 L
.85063 .02853 L
.85113 .02581 L
.85162 .02233 L
.85212 .01874 L
.85261 .01828 L
.85311 .01967 L
.85361 .02034 L
.8541 .02006 L
.8546 .0202 L
.8551 .02146 L
.85559 .02237 L
.85609 .02151 L
.85658 .01974 L
.85708 .01867 L
.85758 .01836 L
.85807 .01841 L
.85857 .01943 L
.85907 .02143 L
.85956 .02275 L
.86006 .02234 L
.86055 .02113 L
.86105 .01998 L
.86155 .01879 L
.86204 .01765 L
.86254 .0172 L
.86304 .01708 L
.86353 .01665 L
.86403 .01664 L
.86453 .01756 L
.86502 .01917 L
.86552 .01976 L
.86601 .01951 L
.86651 .01912 L
.86701 .01867 L
Mistroke
.8675 .01798 L
.868 .01688 L
.8685 .01667 L
.86899 .01977 L
.86949 .02733 L
.86998 .04557 L
.87048 .07188 L
.87098 .09256 L
.87147 .09905 L
.87197 .09542 L
.87247 .08799 L
.87296 .0813 L
.87346 .07773 L
.87395 .07341 L
.87445 .06725 L
.87495 .05936 L
.87544 .05131 L
.87594 .04556 L
.87644 .04285 L
.87693 .04263 L
.87743 .04224 L
.87793 .03849 L
.87842 .0354 L
.87892 .03359 L
.87941 .03125 L
.87991 .02789 L
.88041 .02638 L
.8809 .02697 L
.8814 .02802 L
.8819 .02881 L
.88239 .02804 L
.88289 .0259 L
.88338 .02306 L
.88388 .01996 L
.88438 .01805 L
.88487 .01799 L
.88537 .01874 L
.88587 .01921 L
.88636 .01996 L
.88686 .0213 L
.88735 .02194 L
.88785 .02155 L
.88835 .02072 L
.88884 .0197 L
.88934 .01906 L
.88984 .0189 L
.89033 .01884 L
.89083 .01859 L
.89132 .01824 L
.89182 .01781 L
Mistroke
.89232 .01735 L
.89281 .01713 L
.89331 .01727 L
.89381 .0176 L
.8943 .01782 L
.8948 .01813 L
.8953 .01873 L
.89579 .01913 L
.89629 .01885 L
.89678 .01812 L
.89728 .01729 L
.89778 .01669 L
.89827 .01652 L
.89877 .01673 L
.89927 .01702 L
.89976 .01706 L
.90026 .01678 L
.90075 .01629 L
.90125 .01597 L
.90175 .01595 L
.90224 .01599 L
.90274 .01583 L
.90324 .01552 L
.90373 .01529 L
.90423 .01513 L
.90472 .01506 L
.90522 .01506 L
.90572 .01508 L
.90621 .01514 L
.90671 .01543 L
.90721 .01572 L
.9077 .01566 L
.9082 .01547 L
.9087 .0154 L
.90919 .01543 L
.90969 .01546 L
.91018 .01545 L
.91068 .01541 L
.91118 .0154 L
.91167 .01543 L
.91217 .01548 L
.91267 .01553 L
.91316 .01552 L
.91366 .01548 L
.91415 .01544 L
.91465 .01539 L
.91515 .0153 L
.91564 .01521 L
.91614 .01513 L
.91664 .01515 L
Mistroke
.91713 .01518 L
.91763 .01511 L
.91812 .015 L
.91862 .01491 L
.91912 .01488 L
.91961 .01494 L
.92011 .01506 L
.92061 .01515 L
.9211 .01514 L
.9216 .01509 L
.92209 .01503 L
.92259 .015 L
.92309 .01499 L
.92358 .01498 L
.92408 .01497 L
.92458 .01498 L
.92507 .01499 L
.92557 .01502 L
.92607 .01512 L
.92656 .01527 L
.92706 .01533 L
.92755 .01529 L
.92805 .01524 L
.92855 .01518 L
.92904 .01511 L
.92954 .01504 L
.93004 .01497 L
.93053 .01493 L
.93103 .01494 L
.93152 .01492 L
.93202 .01488 L
.93252 .0149 L
.93301 .01494 L
.93351 .01491 L
.93401 .01483 L
.9345 .01482 L
.935 .01486 L
.93549 .01489 L
.93599 .01487 L
.93649 .01485 L
.93698 .01487 L
.93748 .01492 L
.93798 .01497 L
.93847 .01501 L
.93897 .01503 L
.93946 .01499 L
.93996 .01493 L
.94046 .01491 L
.94095 .01488 L
.94145 .01483 L
Mistroke
.94195 .0148 L
.94244 .01481 L
.94294 .01483 L
.94344 .01482 L
.94393 .01482 L
.94443 .01481 L
.94492 .01482 L
.94542 .01483 L
.94592 .01482 L
.94641 .01482 L
.94691 .01483 L
.94741 .01483 L
.9479 .0148 L
.9484 .0148 L
.94889 .01479 L
.94939 .01478 L
.94989 .01477 L
.95038 .01477 L
.95088 .01477 L
.95138 .01478 L
.95187 .0148 L
.95237 .01483 L
.95286 .01484 L
.95336 .01481 L
.95386 .01481 L
.95435 .01483 L
.95485 .01483 L
.95535 .0148 L
.95584 .01477 L
.95634 .01475 L
.95684 .01477 L
.95733 .01478 L
.95783 .01478 L
.95832 .01477 L
.95882 .01476 L
.95932 .01477 L
.95981 .01481 L
.96031 .01483 L
.96081 .0148 L
.9613 .01477 L
.9618 .01477 L
.96229 .01476 L
.96279 .01478 L
.96329 .01481 L
.96378 .0148 L
.96428 .01478 L
.96478 .0148 L
.96527 .01483 L
.96577 .01484 L
.96626 .01484 L
Mistroke
.96676 .01483 L
.96726 .01483 L
.96775 .01482 L
.96825 .0148 L
.96875 .01479 L
.96924 .01479 L
.96974 .01479 L
.97023 .01478 L
.97073 .01476 L
.97123 .01475 L
.97172 .01475 L
.97222 .01475 L
.97272 .01475 L
.97321 .01475 L
.97371 .01474 L
.97421 .01474 L
.9747 .01475 L
.9752 .01476 L
.97569 .01478 L
.97619 .01478 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{433, 267.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a00012aP00`40o`000?l0003ooooook;oool0
01goool00`000?ooooooo`1Moooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`1Doooo1@0000;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
057oool500000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0F_oo
o`007?ooo`030000oooo000005goool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Ooool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Coool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005_oool001coool00`000?ooo`00001Ooooo00H0003oooooool0003oool00002oooo00<0
003oool00000Eoooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0
003oool00000E?ooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`0000;oool00`000?oo
o`00001Koooo000Loooo00<0003oool00000GOooo`800003oooo00<0003oool000000_ooo`030000
oooo000005Ooool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Coool010000?ooooooooooo`800003oooo00<0003oool000000_ooo`030000oooo0000
05_oool001coool00`000?ooo`00001Moooo00<0003oooooool00_ooo`030000oooo000000;oool0
0`000?ooo`00001Goooo00L0003oooooooooool0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`00001Doooo00D0003oooooooooool000001?ooo`030000oooo000000;oool00`000?oo
o`00001Koooo000Moooo00<0003oooooool0G?ooo`<00003oooo00<0003oooooool00_ooo`030000
oooooooo05Goool200001?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool0D_ooo`800003oooo0`0000?oool00`000?ooooooo`02oooo00<0003oooooool0F_ooo`00oooo
ok;oool00?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooo
ok;oool001Cooooo0000VP0000Coool001Coool00`000?ooooooo`06oooo00<0003oooooool04_oo
o`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo
01;oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?oo
ooooo`0Boooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Boooo00<0
003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04_oo
o`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo000Doooo00<0003oooooool01_ooo`030000oooooooo01;oool0
0`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0B
oooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003ooooo
ool04_ooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04_ooo`030000
oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0;
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00Koool00`000?ooooooo`1Soooo00<0
003oooooool0H_ooo`030000oooooooo06;oool00`000?ooooooo`1Loooo00<0003oooooool00_oo
o`003?ooo`030000oooooooo00Goool00`000?ooooooo`3oooooU_ooo`030000oooooooo00;oool0
00_oool00`000?ooo`000006oooo00<0003oooooool0oooooiKoool00`000?ooooooo`02oooo000;
oooo00<0003oool000001_ooo`<00007oooo0`3o0?oooomUoooo7P3o00Ooool300001?ooo`002ooo
o`030000oooo000000Koool00`000?ooooooo`09oooo00<0o`3oooooool0;?ooo`030?l0oooooooo
033oool00`3o0?ooooooo`08oooo00<0o`3oooooool04_ooo`80o`0Eoooo00<0o`3oooooool0:Ooo
o`80o`0Soooo0P3o00Goool20?l01?ooo`030?l0oooooooo02ooool00`3o0?ooooooo`02oooo00<0
o`3oooooool03_ooo`<0o`0Boooo0`3o00Woool70?l000?oool0o`00o`008_ooo`030000oooooooo
00;oool000_oool00`000?ooo`000006oooo00<0003oooooool02Oooo`030?l0oooooooo02Goool0
0`3o0?ooooooo`04oooo00<0o`3oooooool03oooo`030?l0oooooooo01?oool00`3o0?ooooooo`08
oooo00<0o`3oooooool02?ooo`030?l0oooooooo00Soool00`3o0?ooooooo`07oooo0P3o01Coool0
0`3o0?ooo`3o000Zoooo0P3o01Goool0103o0?ooooooooooo`80o`08oooo0P3o00Coool30?l01?oo
o`030?l0oooooooo02?oool00`3o0?ooooooo`09oooo00<0o`3oooooool00_ooo`80o`0?oooo0`3o
00Goool20?l01oooo`P0o`05oooo1P3o02Woool00`000?ooooooo`02oooo000<oooo00<0003ooooo
ool01Oooo`030000oooooooo00Woool00`3o0?ooooooo`0Toooo0P3o00Koool00`3o0?ooooooo`0>
oooo0P3o00?oool20?l03oooo`80o`09oooo0P3o00Coool00`3o0?ooooooo`02oooo0P3o00[oool2
0?l00oooo`030?l0oooooooo00;oool20?l00oooo`030?l0oooooooo00?oool00`3o0?ooooooo`08
oooo00<0o`3oool0o`003oooo`030?l0oooooooo00Soool20?l03_ooo`80o`0?oooo0P3o00Coool2
0?l00_ooo`80o`08oooo00<0o`3oool0o`000oooo`030?l0oooo0?l000;oool30?l08?ooo`030?l0
oooooooo00;oool20?l00_ooo`030?l0oooooooo00Coool00`3o0?ooo`3o0003oooo0P3o00koool2
0?l000?oool0o`3oool00_ooo`@0o`04oooo0P3o0005oooo0?l00?l0oooo0?l000?oool00`3o0?oo
ooooo`03oooo0`3o02coool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo02Coool20?l01_ooo`030?l0oooooooo00goool30?l00_ooo`040?l0oooo0?l00?l00_oo
o`030?l0oooooooo00?oool20?l00oooo`<0o`04oooo00@0o`3oooooooooool30?l00oooo`80o`04
oooo0P3o00?oool20?l01?ooo`<0o`03oooo00<0o`3oooooool00_ooo`80o`03oooo0P3o00Coool2
0?l01Oooo`070?l0oooooooooooo0?l0oooo0?l000koool20?l02Oooo`<0o`08oooo00<0o`3ooooo
ool00oooo`030?l0oooo0?l000koool40?l00_ooo`<0o`000oooo`3o003o0008oooo00<0o`3oool0
o`000_ooo`80o`001?ooo`3o0?ooooooo`<0o`09oooo0P3o01Goool00`3o0?ooooooo`02oooo0P3o
00;oool00`3o0?ooooooo`04oooo00<0o`3oool0o`000oooo`80o`04oooo00D0o`3oooooooooool0
o`001?ooo`80o`02oooo00@0o`3oooooooooool40?l01?ooo`<0o`07oooo00<0o`3oooooool00ooo
o`030?l0oooooooo02coool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo02Coool20?l01Oooo`80o`0?oooo0`3o00;oool0103o0?ooooooo`3o00;oool20?l01?oo
o`<0o`02oooo0`3o00Coool20?l00_ooo`<0o`03oooo0P3o00Coool20?l00oooo`80o`03oooo103o
00?oool20?l00oooo`80o`03oooo0P3o00?oool40?l00oooo`80o`03oooo00<0o`3oool0o`003_oo
o`80o`09oooo0`3o00Soool00`3o0?ooooooo`02oooo00@0o`3oooooool0o`0;oooo00<0o`3ooooo
ool0103o00;oool40?l000?oool0o`3oool01oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o
00;oool30?l02Oooo`030?l0oooo0?l000?oool00`3o0?ooooooo`0>oooo00<0o`3oooooool00_oo
o`80o`02oooo00<0o`3oooooool00oooo`80o`000oooo`3o0?ooo`02oooo0P3o00?oool30?l00_oo
o`030?l0oooooooo00;oool20?l00_ooo`040?l0oooooooooooo103o00Coool30?l01oooo`040?l0
oooooooooooo0P3o02ooool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo02Coool20?l01Oooo`80o`0?oooo0`3o00;oool0103o0?ooooooo`3o00;oool20?l01?oo
o`<0o`02oooo0`3o00Coool20?l00_ooo`030?l0oooo0?l000?oool20?l00oooo`030?l0oooo0?l0
00?oool20?l00oooo`@0o`03oooo0P3o00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002
oooo0P3o0003oooo0?l0oooo00;oool20?l00oooo`030?l0oooo0?l000koool20?l02Oooo`<0o`04
oooo00@0o`3oooooooooool20?l00oooo`040?l0oooooooo0?l02Oooo`030?l0oooo0?l000;oool4
0?l000?oool0o`00o`000`3o0003oooo0?l0oooo00Ooool00`3o0?ooo`3o0002oooo00@0o`3ooooo
ool0o`02oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`000oooo`030?l0oooooooo00;oool0
0`3o0?ooooooo`09oooo00<0o`3oooooool00_ooo`<0o`000oooo`3o0?ooo`04oooo00@0o`3ooooo
ool0o`03oooo0P3o00?oool30?l000?oool0o`00o`000_ooo`040?l0oooo0?l00?l00_ooo`050?l0
oooooooooooo0?l000;oool0103o0?ooooooooooo`80o`000oooo`3o0?ooo`06oooo00@0o`3ooooo
ooooool20?l0;oooo`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3ooooo
ool09?ooo`80o`05oooo0P3o00Woool00`3o0?ooooooo`03oooo00<0o`3oool0o`000_ooo`040?l0
oooooooo0?l00_ooo`80o`04oooo00@0o`3oool0o`3oool40?l00oooo`<0o`001Oooo`3o0?oooooo
o`3o0003oooo0P3o00;oool20?l000Ooool0o`3oooooool0o`3oool0o`000oooo`80o`001Oooo`3o
0?ooo`3o0?ooo`020?l00_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000;oool20?l000?o
ool0o`3oool00_ooo`80o`03oooo00<0o`3oool0o`001?ooo`030?l0oooooooo00Ooool20?l02Ooo
o`<0o`03oooo0P3o00?oool30?l000?oool0o`00o`000_ooo`030?l0oooooooo00Ooool30?l00_oo
o`@0o`000oooo`3o0?ooo`02oooo00<0o`3oool0o`001Oooo`070?l0oooooooo0?l0oooo0?l0oooo
0080o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oooooool00P3o00Coool00`3o0?ooo`3o0003
oooo0P3o00?oool00`3o0?ooooooo`02oooo00<0o`3oooooool00oooo`80o`04oooo0`3o0003oooo
0?l0oooo00Coool0103o0?ooooooo`3o00?oool20?l00oooo`<0o`001?ooo`3o003o0?ooo`80o`00
0oooo`3o0?ooo`02oooo00D0o`3oooooooooool0o`000_ooo`040?l0oooooooooooo0P3o0003oooo
0?l0oooo00Koool01@3o0?ooooooooooo`3o000`oooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo00Woool00`3o0?ooooooo`0Toooo0P3o00Goool20?l02Oooo`030?l0oooooooo00?oool0
0`3o0?ooo`3o0002oooo00L0o`3oooooool0o`3oool0o`3oool00P3o00?oool0103o0?ooo`3o0?oo
o`80o`000oooo`3o0?ooo`02oooo00D0o`3oool0o`3oool0o`000_ooo`040?l0oooooooooooo0P3o
00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo0P3o0003oooo0?l0oooo0080o`00
1Oooo`3o0?ooooooo`3o0002oooo00H0o`3oooooool0o`3oool0o`02oooo00@0o`3oooooool0o`03
oooo0P3o00?oool00`3o0?ooo`3o0004oooo00<0o`3oooooool01oooo`80o`09oooo0`3o00?oool2
0?l00oooo`<0o`000oooo`3o003o0002oooo00<0o`3oooooool01oooo`<0o`02oooo0P3o0004oooo
0?l0oooo0?l00oooo`040?l0oooooooo0?l01?ooo`80o`001Oooo`3o0?ooo`3o0?ooo`020?l00_oo
o`040?l0oooooooo0?l00_ooo`030?l0oooooooo0080o`03oooo00@0o`3oooooool0o`02oooo00<0
o`3oool0o`000oooo`030?l0oooooooo00;oool00`3o0?ooooooo`03oooo0P3o00Coool30?l000Go
ool0o`3oooooool0o`000_ooo`040?l0oooooooo0?l00oooo`80o`03oooo1P3o0005oooo0?l00?l0
oooo0?l000?oool01@3o0?ooooooooooo`3o0002oooo00@0o`3oooooooooool20?l02Oooo`050?l0
oooooooooooo0?l0033oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo02Coool20?l01?ooo`030?l0oooo0?l000Goool01@3o0?ooooooooooo`3o0005oooo00<0
o`3oool0o`000_ooo`070?l0oooooooo0?l0oooo0?l0oooo0080o`02oooo00D0o`3oooooool0o`3o
ool00P3o0003oooo0?l0oooo00;oool01@3o0?ooo`3o0?ooo`3o0002oooo00@0o`3oooooooooool2
0?l00_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000?oool01@3o0?ooooooo`3o0?ooo`02
0?l000Goool0o`3oooooool0o`000_ooo`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo
0?l00oooo`80o`02oooo00@0o`3oooooool0o`04oooo00<0o`3oooooool01oooo`80o`09oooo0`3o
00?oool20?l00oooo`<0o`000oooo`3o0?ooo`02oooo00<0o`3oooooool01oooo`<0o`002?ooo`3o
003o003o0?ooo`3o0?ooo`3o00Koool00`3o0?ooooooo`02oooo103o0003oooo0?l0oooo0080o`02
oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000`3o00;oool0103o0?ooooooo`3o00;oool0
0`3o0?ooo`3o0003oooo00@0o`3oooooooooool20?l01Oooo`80o`04oooo0`3o0006oooo0?l0oooo
oooo0?l0oooo0P3o00;oool01`3o0?ooooooooooo`3o0?ooo`3o0002oooo2P3o00Coool01@3o0?oo
ooooooooo`3o0002oooo00D0o`3oooooooooool0o`002_ooo`040?l0oooooooo0?l0<Oooo`030000
oooooooo00;oool001Coool200002_ooo`030?l0oooooooo02?oool00`3o0?ooo`3o0004oooo00<0
o`3oool0o`001Oooo`050?l0oooooooooooo0?l000Coool20?l000Goool0o`3oooooool0o`000_oo
o`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool01P3o0?ooo`3o003o0?ooo`3o00?oool0
1@3o0?ooo`3o0?ooo`3o0002oooo00@0o`3oooooooooool20?l00_ooo`040?l0oooooooo0?l00_oo
o`030?l0oooo0?l000;oool01P3o0?ooooooooooo`3o0?ooo`80o`000oooo`3o0?ooo`020?l00_oo
o`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo0?l00oooo`80o`02oooo00@0o`3ooooo
ool0o`04oooo00<0o`3oooooool01oooo`80o`09oooo00<0o`3oool0o`000oooo`80o`03oooo0`3o
0003oooo0?l0oooo00;oool00`3o0?ooooooo`07oooo0`3o0003oooo0?l0oooo00;oool30?l01_oo
o`030?l0oooooooo00;oool40?l000Coool0o`3oool0o`03oooo00@0o`3oooooool0o`02oooo00<0
o`3oool0o`000`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo00@0o`3ooooo
ooooool20?l000?oool0o`3oool00_ooo`80o`04oooo0`3o0007oooo0?l0oooooooo0?l0oooo0?l0
00?oool01`3o0?ooooooooooo`3o0?ooo`3o0002oooo2P3o00Coool0103o0?ooooooo`3o00?oool0
103o0?ooooooo`3o00_oool0103o0?ooooooo`3o033oool200001?ooo`005?ooo`030000oooooooo
00Woool00`3o0?ooooooo`0Soooo00<0o`3oool0o`001?ooo`030?l0oooo0?l000Coool20?l00ooo
o`030?l0oooooooo00;oool20?l000Goool0o`3oooooool0o`000_ooo`030?l0oooo0?l000;oool0
103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00T0o`3oooooooooool0o`3oool0o`3oool0
o`000_ooo`030?l0oooooooo00<0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_oo
o`060?l0oooooooooooo0?l0oooo0P3o0003oooo0?l0oooo0080o`02oooo00H0o`3oooooool0o`3o
ool0o`02oooo00@0o`3oooooool0o`03oooo0P3o00;oool0103o0?ooooooo`3o00Coool01@3o0?oo
ooooooooo`3o0005oooo0P3o00Woool00`3o0?ooo`3o0003oooo0P3o00?oool30?l000?oool0o`3o
ool00_ooo`030?l0oooooooo00Ooool30?l000?oool0o`3oool00_ooo`<0o`06oooo00<0o`3ooooo
ool00_ooo`080?l0oooo0?l00?l0oooo0?l0oooo0?l01?ooo`030?l0oooo0?l000;oool01P3o0?oo
o`3o003o0?ooo`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo00@0o`3ooooo
ooooool40?l00oooo`80o`04oooo00D0o`3oool0o`3oool0o`000_ooo`030?l0oooo0?l000?oool0
203o0?ooooooooooo`3o0?ooo`3o0?ooo`/0o`04oooo00@0o`3oooooool0o`03oooo00@0o`3ooooo
ool0o`0;oooo00@0o`3oooooool0o`0aoooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
00Woool00`3o0?ooooooo`0Soooo00<0o`3oool0o`001?ooo`030?l0oooo0?l000Coool20?l00ooo
o`<0o`02oooo0P3o0005oooo0?l0oooooooo0?l000;oool00`3o0?ooo`3o0002oooo00@0o`3ooooo
ool0o`02oooo00<0o`3oool0o`000_ooo`090?l0oooooooooooo0?l0oooo0?l0oooo0?l000?oool0
0`3o0?ooo`3o00020?l00_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000;oool0103o0?oo
ooooooooo`80o`001Oooo`3o0?ooo`3o0?ooo`020?l00_ooo`060?l0oooooooo0?l0oooo0?l00_oo
o`040?l0oooooooo0?l00oooo`80o`02oooo00@0o`3oooooool0o`04oooo00D0o`3oooooooooool0
o`000_ooo`030?l0oooooooo0080o`09oooo00<0o`3oool0o`000oooo`<0o`000oooo`3o0?ooo`04
0?l00oooo`030?l0oooooooo00Ooool30?l000?oool0o`3oool00oooo`80o`06oooo00<0o`3ooooo
ool00_ooo`050?l0oooo0?l00?l0oooo0080o`05oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l0
00;oool0103o0?ooooooo`3o00;oool01P3o0?ooooooo`3o0?ooo`3o00?oool20?l00_ooo`@0o`03
oooo0P3o00Coool01@3o0?ooo`3o0?ooo`3o0002oooo00<0o`3oool0o`000oooo`040?l0oooooooo
0?l00_ooo`050?l0oooo0?l00?l0oooo00D0o`000oooo`3o003o0004oooo00@0o`3oooooool0o`03
oooo00@0o`3oooooool0o`0;oooo00@0o`3oooooool0o`0aoooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo00Woool00`3o0?ooooooo`0Soooo00<0o`3oool0o`001?ooo`030?l0oooo0?l0
00Coool20?l00oooo`<0o`02oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3oool0o`02
oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`090?l0oooooooooooo0?l0oooo0?l0
oooo0?l000?oool01@3o0?ooo`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00<0o`3oool0
o`000_ooo`040?l0oooooooooooo0P3o0005oooo0?l0oooo0?l0oooo0080o`02oooo00H0o`3ooooo
ool0o`3oool0o`02oooo00@0o`3oooooool0o`02oooo0`3o00;oool0103o0?ooooooo`3o00;oool0
0`3o0?ooo`3o0003oooo00@0o`3oooooool0o`02oooo0P3o00Coool01@3o0?ooooooooooo`3o0002
oooo00@0o`3oooooooooool30?l000Coool0o`3oooooool30?l00oooo`030?l0oooooooo00Ooool0
1@3o0?ooo`3o0?ooo`3o0005oooo00<0o`3oooooool01?ooo`030?l0oooooooo00;oool0103o0?oo
o`3o003o00;oool00`3o0?ooooooo`03oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l000;oool0
103o0?ooooooo`3o00;oool01P3o0?ooooooo`3o0?ooo`3o00?oool20?l00_ooo`@0o`03oooo0P3o
00Coool01@3o0?ooo`3o0?ooo`3o0002oooo00<0o`3oool0o`000oooo`040?l0oooooooo0?l00_oo
o`050?l0oooo0?l00?l0oooo00D0o`000oooo`3o003o0004oooo00@0o`3oool0o`00o`03oooo00@0
o`3oooooool0o`0;oooo00<0o`3oool0o`00<_ooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`09oooo00<0o`3oooooool08oooo`030?l0oooo0?l000?oool0103o0?ooooooo`3o00Coool2
0?l00oooo`<0o`02oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3oool0o`02oooo00@0
o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`090?l0oooooooooooo0?l0oooo0?l0oooo0?l0
00?oool01@3o0?ooo`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3o
ool0o`03oooo0P3o00?oool00`3o0?ooo`3o0003oooo00H0o`3oooooool0o`3oool0o`02oooo00@0
o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l0
00;oool20?l00_ooo`030?l0oooooooo0080o`04oooo0P3o00;oool0103o0?ooooooo`3o00?oool3
0?l000Coool0o`3oooooool20?l01?ooo`030?l0oooooooo00Ooool01@3o0?ooo`3o0?ooo`3o0005
oooo00<0o`3oooooool01?ooo`050?l0oooooooooooo0?l000;oool20?l00_ooo`030?l0oooooooo
00?oool00`3o0?ooo`3o0002oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00_ooo`060?l0
oooooooo0?l0oooo0?l00oooo`80o`02oooo103o00?oool20?l01?ooo`050?l0oooo0?l0oooo0?l0
00;oool00`3o0?ooo`3o0003oooo00@0o`3oooooool0o`02oooo00@0o`3oool0o`00o`02oooo103o
0003oooo0?l00?l000Coool00`3o0?ooo`3o0004oooo00@0o`3oooooool0o`0;oooo00<0o`3oool0
o`00<_ooo`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool08ooo
o`030?l0oooo0?l000?oool0103o0?ooooooo`3o00Coool20?l00oooo`<0o`02oooo00@0o`3ooooo
ool0o`02oooo00H0o`3oooooool0o`3oool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0
o`000_ooo`090?l0oooooooooooo0?l0oooo0?l0oooo0?l000?oool01@3o0?ooo`3o0?ooo`3o0002
oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3oool0o`03oooo0P3o00?oool00`3o0?oo
o`3o0003oooo00H0o`3oooooool0o`3oool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0
o`000_ooo`050?l0oooooooo0?l0oooo00@0o`02oooo0P3o00;oool01@3o0?ooo`3o0?ooo`3o0004
oooo0P3o0003oooo0?l00?l000;oool0103o0?ooooooooooo`<0o`001?ooo`3o0?ooooooo`80o`04
oooo00<0o`3oooooool00_ooo`050?l0oooooooooooo0?l000;oool00`3o0?ooo`3o000<oooo00D0
o`3oooooooooool0o`001_ooo`030?l0oooooooo00?oool00`3o0?ooo`3o0002oooo00<0o`3oool0
o`000_ooo`040?l0oooo0?l00?l00_ooo`060?l0oooooooo0?l0oooo0?l00oooo`80o`02oooo103o
00?oool20?l01?ooo`040?l0oooo0?l0oooo0P3o0004oooo0?l0oooo0?l00oooo`040?l0oooooooo
0?l00_ooo`040?l0oooo0?l00?l00_ooo`@0o`000oooo`3o003o0004oooo00<0o`3oool0o`001?oo
o`040?l0oooooooo0?l02oooo`030?l0oooo0?l003;oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool02Oooo`030?l0oooooooo02?oool00`3o0?ooo`3o0003oooo00@0o`3oooooool0o`03
oooo00<0o`3oool0o`000oooo`<0o`02oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3o
ool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`090?l0oooooooooooo0?l0
oooo0?l0oooo0?l000?oool01@3o0?ooo`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00H0
o`3oooooool0o`3oool0o`03oooo0P3o00?oool00`3o0?ooo`3o0003oooo00H0o`3oooooool0o`3o
ool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`050?l0oooooooo0?l0oooo
00@0o`02oooo0P3o00;oool01@3o0?ooo`3o0?ooo`3o0004oooo1@3o00;oool02@3o0?oooooooooo
o`3o0?ooo`3o0?ooo`3o0002oooo0P3o00Goool01@3o0?ooooooooooo`3o0003oooo00H0o`3ooooo
ool0o`3oool0o`0<oooo00D0o`3oooooooooool0o`001_ooo`030?l0oooooooo00?oool00`3o0?oo
o`3o0002oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l000?oool01P3o0?ooooooo`3o0?ooo`3o
00?oool20?l00_ooo`@0o`03oooo0P3o00Coool0103o0?ooo`3o0?ooo`80o`001?ooo`3o0?ooo`3o
00?oool00`3o0?ooo`3o0003oooo00@0o`3oool0o`00o`02oooo103o0003oooo0?l0oooo00Coool0
0`3o0?ooo`3o0004oooo00@0o`3oooooool0o`0;oooo00<0o`3oool0o`00<_ooo`030000oooooooo
00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool08_ooo`80o`000oooo`3o0?ooo`02
oooo00@0o`3oooooool0o`03oooo00<0o`3oool0o`000oooo`<0o`02oooo00@0o`3oooooool0o`02
oooo00H0o`3oooooool0o`3oool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_oo
o`090?l0oooooooooooo0?l0oooo0?l0oooo0?l000?oool01@3o0?ooo`3o0?ooo`3o0002oooo00@0
o`3oooooool0o`02oooo00H0o`3oooooool0o`3oool0o`03oooo00<0o`3oooooool00_ooo`030?l0
oooo0?l000?oool01P3o0?ooooooo`3o0?ooo`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?oo
o`3o0002oooo00D0o`3oooooool0o`3oool0103o00;oool20?l00_ooo`030?l0oooo0?l000;oool0
103o0?ooooooooooo`D0o`02oooo00T0o`3oooooooooool0o`3oool0o`3oool0o`000_ooo`80o`05
oooo00<0o`3oooooool00P3o00?oool01P3o0?ooooooo`3o0?ooo`3o00coool01@3o0?oooooooooo
o`3o000<oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00H0
o`3oooooool0o`3oool0o`03oooo0P3o00;oool40?l00oooo`80o`04oooo00@0o`3oool0o`3oool5
0?l01?ooo`030?l0oooo0?l000?oool0103o0?ooo`3o003o00;oool40?l000?oool0o`3oool01?oo
o`030?l0oooo0?l000Coool0103o0?ooooooo`3o00_oool00`3o0?ooo`3o000boooo00<0003ooooo
ool00_ooo`005?ooo`030000oooooooo00Woool00`3o0?ooooooo`0Poooo00<0o`3oool0o`000_oo
o`050?l0oooooooooooo0?l000;oool01`3o0?ooooooooooo`3o0?ooo`3o0003oooo00<0o`3oool0
o`000_ooo`040?l0oooooooo0?l00_ooo`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo
0?l00_ooo`030?l0oooo0?l000;oool02@3o0?ooooooooooo`3o0?ooo`3o0?ooo`3o0003oooo00<0
o`3oool0o`000_ooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003
oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000?oool01P3o0?ooooooo`3o0?ooo`3o00;oool0
103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00D0o`3oooooool0o`3oool0103o00;oool2
0?l00_ooo`030?l0oooo0?l000;oool0103o0?ooooooooooo`D0o`02oooo00T0o`3oooooooooool0
o`3oool0o`3oool0o`000_ooo`80o`05oooo00<0o`3oooooool00P3o00;oool20?l00_ooo`030?l0
oooo0?l000coool01@3o0?ooooooooooo`3o000<oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l0
00;oool00`3o0?ooo`3o0003oooo00H0o`3oooooool0o`3oool0o`03oooo0P3o00;oool40?l00ooo
o`80o`04oooo00<0o`3oool0o`001P3o00Coool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000ooo
o`@0o`07oooo00<0o`3oool0o`001?ooo`040?l0oooooooo0?l02oooo`030?l0oooo0?l003;oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0oooooooo01_oool00`3o0?oo
ooooo`02oooo00<0o`3oool0o`000_ooo`050?l0oooooooooooo0?l000;oool01`3o0?oooooooooo
o`3o0?ooo`3o0003oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00_ooo`060?l0oooooooo
0?l0oooo0?l00_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000;oool02@3o0?oooooooooo
o`3o0?ooo`3o0?ooo`3o0003oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l000;oool0103o0?oo
ooooo`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000?oool0
1P3o0?ooooooo`3o0?ooo`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00D0
o`3oooooool0o`3oool0103o00;oool30?l000Coool0o`3oool0o`02oooo00@0o`3oooooooooool5
0?l00_ooo`090?l0oooooooooooo0?l0oooo0?l0oooo0?l000;oool20?l01Oooo`030?l0oooooooo
0080o`001?ooo`3o003o003o00;oool00`3o0?ooo`3o000<oooo00<0o`3oooooool00P3o00coool0
0`3o0?ooo`3o0002oooo00<0o`3oool0o`000_ooo`030?l0oooo0?l000?oool01P3o0?ooooooo`3o
0?ooo`3o00?oool20?l00_ooo`@0o`03oooo0P3o00?oool00`3o0?ooooooo`070?l01?ooo`030?l0
oooo0?l000?oool00`3o0?ooo`3o0003oooo0P3o0003oooo0?l0oooo00Koool00`3o0?ooo`3o0004
oooo00@0o`3oooooool0o`0;oooo00<0o`3oool0o`00<_ooo`030000oooooooo00;oool001Coool2
00002_ooo`030?l0oooooooo00ooool00`3o0?ooooooo`09oooo00<0o`3oooooool00_ooo`030?l0
oooo0?l000;oool01@3o0?ooooooooooo`3o0002oooo00L0o`3oooooooooool0o`3oool0o`000ooo
o`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool01P3o0?ooooooo`3o0?ooo`3o00;oool0
103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00T0o`3oooooooooool0o`3oool0o`3oool0
o`000oooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00<0
o`3oool0o`000oooo`030?l0oooooooo00;oool00`3o0?ooo`3o0003oooo00H0o`3oooooool0o`3o
ool0o`02oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`050?l0oooooooo0?l0oooo
00@0o`02oooo0`3o0004oooo0?l0oooo0?l00_ooo`040?l0oooooooooooo103o00?oool02@3o0?oo
ooooooooo`3o0?ooo`3o0?ooo`3o0002oooo0P3o00Goool00`3o0?ooooooo`020?l000Coool0o`00
o`00o`02oooo00<0o`3oool0o`003?ooo`030?l0oooooooo0080o`0<oooo00<0o`3oool0o`000_oo
o`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00H0o`3oooooool0o`3oool0o`03oooo0P3o
00;oool40?l00oooo`80o`03oooo00<0o`3oooooool00P3o0003oooo0?l00?l00080o`04oooo00<0
o`3oool0o`000oooo`030?l0oooo0?l000?oool20?l02Oooo`030?l0oooo0?l000Coool0103o0?oo
ooooo`3o00_oool00`3o0?ooo`3o000aoooo0P0000Coool001Coool00`000?ooooooo`09oooo00<0
o`3oooooool03oooo`030?l0oooooooo00Woool00`3o0?ooooooo`02oooo00<0o`3oool0o`000_oo
o`050?l0oooooooooooo0?l000;oool01`3o0?ooooooooooo`3o0?ooo`3o0003oooo00<0o`3oool0
o`000_ooo`040?l0oooooooo0?l00_ooo`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo
0?l00_ooo`030?l0oooo0?l000;oool02@3o0?ooooooooooo`3o0?ooo`3o0?ooo`3o0003oooo00<0
o`3oool0o`000_ooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003
oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000?oool01P3o0?ooo`3o003o0?ooo`3o00;oool0
103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00D0o`3oooooool0o`3oool0103o00;oool5
0?l000Goool0o`3oooooool0o`000oooo`80o`000oooo`3o0?ooo`02oooo00T0o`3oooooooooool0
o`3oool0o`3oool0o`000_ooo`80o`05oooo00<0o`3oooooool00P3o0004oooo0?l00?l00?l00ooo
o`80o`0<oooo00<0o`3oooooool00P3o00coool00`3o0?ooo`3o0002oooo00<0o`3oool0o`000_oo
o`030?l0oooo0?l000?oool0103o0?ooooooo`3o00;oool00`3o0?ooooooo`020?l00_ooo`@0o`03
oooo0P3o00?oool00`3o0?ooooooo`020?l000?oool0o`00o`000P3o00Coool00`3o0?ooo`3o0003
oooo00<0o`3oool0o`000oooo`80o`09oooo00<0o`3oool0o`001?ooo`040?l0oooooooo0?l02ooo
o`030?l0oooo0?l003;oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo00ooool00`3o0?ooooooo`09oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000;oool0
1@3o0?ooooooooooo`3o0002oooo00L0o`3oooooooooool0o`3oool0o`000oooo`030?l0oooo0?l0
00;oool0103o0?ooooooo`3o00;oool01P3o0?ooooooo`3o0?ooo`3o00;oool0103o0?ooooooo`3o
00;oool00`3o0?ooo`3o0002oooo00T0o`3oooooooooool0o`3oool0o`3oool0o`000oooo`<0o`02
oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000?oool00`3o0?oo
ooooo`02oooo00<0o`3oool0o`000oooo`060?l0oooo0?l00?l0oooo0?l00_ooo`040?l0oooooooo
0?l00_ooo`030?l0oooo0?l000;oool01@3o0?ooooooo`3o0?ooo`040?l00_ooo`D0o`001Oooo`3o
0?ooooooo`3o0003oooo00@0o`3oooooool0o`03oooo00T0o`3oooooooooool0o`3oool0o`3oool0
o`000_ooo`80o`05oooo00<0o`3oooooool00P3o0004oooo0?l00?l00?l00oooo`80o`0<oooo00<0
o`3oooooool00P3o00coool30?l00_ooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00@0
o`3oool0o`00o`02oooo00<0o`3oooooool00P3o00;oool20?l000?oool0o`3oool00_ooo`80o`03
oooo00<0o`3oooooool00P3o0003oooo0?l00?l00080o`04oooo00<0o`3oool0o`000oooo`030?l0
oooo0?l000?oool20?l02_ooo`80o`04oooo00@0o`3oooooool0o`0;oooo00<0o`3oool0o`00<_oo
o`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool03oooo`80o`0:
oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000;oool01@3o0?ooooooooooo`3o0002oooo00L0
o`3oooooooooool0o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool0
1P3o0?ooooooo`3o0?ooo`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00T0
o`3oooooooooool0o`3oool0o`3oool0o`000oooo`<0o`02oooo00<0o`3oool0o`000_ooo`040?l0
oooooooo0?l00_ooo`030?l0oooo0?l000?oool00`3o0?ooooooo`02oooo00<0o`3oool0o`000ooo
o`060?l0oooo0?l00?l0oooo0?l00_ooo`030?l0oooooooo0080o`001_ooo`3o0?ooo`3o0?ooo`3o
00?oool00`3o0?ooo`3o00030?l00_ooo`D0o`001Oooo`3o0?ooooooo`3o0003oooo00@0o`3ooooo
ool0o`03oooo00T0o`3oooooooooool0o`3oool0o`3oool0o`000_ooo`80o`05oooo00<0o`3oool0
o`000P3o0004oooo0?l00?l00?l00oooo`80o`0<oooo00<0o`3oooooool00P3o00coool30?l00_oo
o`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00@0o`3oool0o`00o`02oooo00<0o`3ooooo
ool00P3o00;oool20?l000Coool0o`3oooooool30?l00oooo`030?l0oooooooo0080o`000oooo`3o
003o00020?l01?ooo`030?l0oooo0?l000?oool00`3o0?ooo`3o0003oooo0P3o00[oool20?l01?oo
o`040?l0oooooooo0?l02oooo`030?l0oooo0?l003;oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool02Oooo`030?l0oooooooo00ooool20?l01_ooo`050?l0oooooooooooo0?l000Coool0
0`3o0?ooo`3o0002oooo00D0o`3oooooooooool0o`000_ooo`070?l0oooooooooooo0?l0oooo0?l0
00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00H0o`3oooooool0o`3oool0o`02
oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`000_ooo`090?l0oooooooooooo0?l0oooo0?l0
oooo0?l000?oool20?l00oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?oo
o`3o0003oooo00<0o`3oooooool00_ooo`030?l0oooo0?l000?oool01P3o0?ooo`3o003o0?ooo`3o
00;oool00`3o0?ooooooo`020?l000Koool0o`3oool0o`3oool0o`03oooo00<0o`3oool0o`000`3o
00;oool50?l000Goool0o`3oooooool0o`000oooo`030?l0oooooooo00Coool00`3o0?ooooooo`02
0?l000Coool0o`3oool0o`02oooo0P3o00Goool00`3o0?ooo`3o00020?l000Coool0o`00o`00o`03
oooo0P3o00coool00`3o0?ooooooo`020?l03?ooo`80o`03oooo00<0o`3oool0o`000_ooo`80o`04
oooo00<0o`3oool0o`000oooo`030?l0oooooooo0080o`02oooo0P3o0004oooo0?l0oooooooo0`3o
00?oool00`3o0?ooooooo`020?l000?oool0o`00o`000P3o00Coool00`3o0?ooo`3o0003oooo00<0
o`3oool0o`000oooo`80o`0:oooo0P3o00Coool0103o0?ooooooo`3o00_oool00`3o0?ooo`3o000b
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00Woool00`3o0?ooooooo`0?oooo0P3o
00Koool01@3o0?ooooooooooo`3o0004oooo00<0o`3oool0o`000_ooo`050?l0oooooooooooo0?l0
00;oool01`3o0?ooooooooooo`3o0?ooo`3o0003oooo00<0o`3oool0o`000_ooo`040?l0oooooooo
0?l00_ooo`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l0
00;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo0P3o00?oool00`3o0?ooo`3o0002
oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000?oool0203o0?oo
o`3o003o0?ooo`3o0?ooo`3o00?oool20?l000Koool0o`3oool0o`3oool0o`03oooo00<0o`3oool0
o`000`3o00;oool50?l000Goool0o`3oooooool0o`000_ooo`80o`06oooo00<0o`3oooooool00P3o
0004oooo0?l0oooo0?l00_ooo`80o`05oooo00<0o`3oool0o`000P3o0004oooo0?l00?l00?l00ooo
o`80o`0<oooo00<0o`3oooooool00P3o00coool20?l00oooo`030?l0oooo0?l000;oool20?l01?oo
o`030?l0oooo0?l000?oool20?l000?oool0o`00o`000_ooo`80o`001?ooo`3o0?ooooooo`<0o`03
oooo00<0o`3oooooool00P3o0005oooo0?l00?l0oooo0?l000Coool00`3o0?ooo`3o0003oooo00<0
o`3oool0o`000oooo`80o`0:oooo0P3o00Coool0103o0?ooooooo`3o00_oool20?l0<oooo`030000
oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool03oooo`80o`06oooo00D0
o`3oooooooooool0o`001?ooo`030?l0oooo0?l000;oool01@3o0?ooooooooooo`3o0002oooo00L0
o`3oooooooooool0o`3oool0o`000oooo`060?l0oooooooo0?l0oooo0?l00_ooo`040?l0oooooooo
0?l00_ooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00@0
o`3oooooool0o`02oooo00<0o`3oool0o`000oooo`80o`03oooo00<0o`3oool0o`000_ooo`040?l0
oooooooo0?l00_ooo`030?l0oooo0?l000Soool00`3o0?ooo`3o0003oooo00P0o`3oool0o`00o`3o
ool0o`3oool0o`03oooo0`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000`3o00;oool5
0?l000Goool0o`3oooooool0o`000_ooo`80o`06oooo00<0o`3oooooool00P3o0004oooo0?l0oooo
0?l00_ooo`80o`05oooo00<0o`3oool0o`001P3o00?oool20?l03?ooo`040?l0oooooooo0?l03Ooo
o`030?l0oooooooo00?oool20?l00_ooo`80o`04oooo00<0o`3oool0o`000oooo`80o`000oooo`3o
003o0002oooo0P3o0004oooo0?l0oooooooo0`3o00?oool00`3o0?ooooooo`020?l000Goool0o`00
o`3oool0o`001?ooo`<0o`03oooo00<0o`3oool0o`000oooo`80o`0:oooo0P3o00Coool0103o0?oo
ooooo`3o00_oool20?l0<oooo`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0
o`3oooooool03oooo`80o`06oooo00D0o`3oooooooooool0o`001?ooo`030?l0oooo0?l000;oool0
1@3o0?ooooooooooo`3o0002oooo00@0o`3oooooool0o`02oooo00D0o`3oooooooooool0o`000_oo
o`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0002oooo00<0o`3oool0
o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo0P3o
00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`002?ooo`030?l0
oooo0?l000?oool20?l000Koool0o`3oool0o`3oool0o`03oooo0`3o00;oool00`3o0?ooo`3o0003
oooo00<0o`3oool0o`000`3o00;oool50?l000Goool0o`3oooooool0o`000_ooo`80o`06oooo00<0
o`3oooooool00P3o0004oooo0?l0oooo0?l00_ooo`80o`05oooo00@0o`3oool0o`3oool30?l01Ooo
o`80o`0<oooo00@0o`3oooooool0o`0=oooo00<0o`3oooooool00oooo`80o`02oooo0P3o00Coool0
0`3o0?ooo`3o0003oooo0P3o0003oooo0?l00?l000;oool20?l000Coool0o`3oooooool30?l00ooo
o`030?l0oooooooo0080o`001Oooo`3o003o0?ooo`3o0005oooo0P3o00?oool00`3o0?ooo`3o0003
oooo0P3o00[oool20?l01?ooo`040?l0oooooooo0?l02oooo`80o`0coooo00<0003oooooool00_oo
o`005?ooo`030000oooooooo00Woool00`3o0?ooooooo`0?oooo0P3o00Koool01@3o0?oooooooooo
o`3o0003oooo0P3o0005oooo0?l0oooooooo0?l000?oool0103o0?ooooooo`3o00;oool0103o0?oo
ooooo`3o00?oool01P3o0?ooooooo`3o0?ooo`3o00;oool0103o0?ooooooo`3o00;oool00`3o0?oo
o`3o0002oooo00<0o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool0
0`3o0?ooo`3o0003oooo0P3o00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`02oooo00<0
o`3oool0o`002?ooo`030?l0oooo0?l000?oool20?l000Koool0o`3oool0o`3oool0o`03oooo0`3o
00;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000`3o00;oool20?l000Goool0o`00o`3oool0
o`000_ooo`030?l0oooooooo0080o`06oooo00<0o`3oooooool00P3o0004oooo0?l0oooo0?l00_oo
o`80o`05oooo00@0o`3oool0o`3oool30?l01Oooo`80o`0<oooo00@0o`3oooooool0o`0Coooo0P3o
00;oool20?l01?ooo`030?l0oooo0?l000?oool20?l000?oool0o`00o`000_ooo`040?l0oooooooo
0?l00_ooo`030?l0oooo0?l000?oool00`3o0?ooooooo`020?l000Goool0o`3oooooool0o`001Ooo
o`80o`03oooo00<0o`3oool0o`000oooo`80o`0:oooo0P3o00Coool0103o0?ooooooo`3o00_oool2
0?l0<oooo`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool03ooo
o`80o`02oooo00D0o`3oooooooooool0o`000oooo`030?l0oooooooo00@0o`03oooo00D0o`3ooooo
ooooool0o`000_ooo`040?l0oooooooo0?l00_ooo`050?l0oooooooooooo0?l000;oool20?l00ooo
o`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00<0o`3oool0
o`000_ooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000Soool00`3o0?ooo`3o0002oooo00@0
o`3oooooool0o`02oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000?oool20?l000Koool0o`3o
ool0o`3oool0o`03oooo0`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000`3o00;oool2
0?l000Goool0o`00o`3oool0o`000_ooo`030?l0oooooooo0080o`06oooo00<0o`3oooooool00P3o
0004oooo0?l0oooo0?l00_ooo`030?l0oooooooo00Coool0103o0?ooo`3o0?ooo`<0o`05oooo00<0
o`3oooooool02oooo`040?l0oooooooo0?l04oooo`80o`02oooo0P3o00Coool00`3o0?ooo`3o0003
oooo0P3o0003oooo0?l00?l000;oool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0003oooo00<0
o`3oooooool00P3o0003oooo0?l0oooo00Ooool20?l00oooo`030?l0oooo0?l000?oool20?l02_oo
o`80o`04oooo00@0o`3oooooool0o`0;oooo0P3o03?oool00`000?ooooooo`02oooo000Doooo0P00
00[oool00`3o0?ooooooo`05oooo00<0o`3oooooool01oooo`80o`02oooo00D0o`3oooooooooool0
o`000oooo`030?l0oooooooo00@0o`03oooo00D0o`3oooooooooool0o`000_ooo`040?l0oooooooo
0?l00_ooo`050?l0oooooooooooo0?l000;oool20?l00oooo`030?l0oooo0?l000?oool00`3o0?oo
o`3o0002oooo00<0o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool3
0?l02?ooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`002?ooo`030?l0
oooo0?l000?oool20?l00oooo`030?l0oooo0?l000?oool30?l00_ooo`030?l0oooo0?l000?oool0
0`3o0?ooo`3o00030?l00_ooo`80o`001Oooo`3o003o0?ooo`3o0002oooo00<0o`3oooooool00P3o
00Koool00`3o0?ooooooo`020?l000Coool0o`3oool0o`02oooo00<0o`3oooooool01?ooo`040?l0
oooo0?l0oooo0`3o00Goool00`3o0?ooooooo`0;oooo00@0o`3oooooool0o`0Coooo0P3o00?oool0
0`3o0?ooooooo`02oooo00<0o`3oool0o`000oooo`80o`000oooo`3o003o0002oooo00@0o`3ooooo
ool0o`02oooo00<0o`3oool0o`000oooo`030?l0oooooooo0080o`000oooo`3o0?ooo`07oooo0P3o
00?oool00`3o0?ooo`3o0003oooo0P3o00[oool20?l01?ooo`040?l0oooooooo0?l02oooo`80o`0b
oooo0P0000Coool001Coool00`000?ooooooo`09oooo00<0o`3oooooool01Oooo`030?l0oooooooo
00Ooool20?l00_ooo`030?l0oooooooo0080o`03oooo00<0o`3oooooool0103o00?oool01@3o0?oo
ooooooooo`3o0002oooo0P3o0005oooo0?l0oooooooo0?l000?oool00`3o0?ooooooo`020?l00ooo
o`030?l0oooo0?l000?oool00`3o0?ooo`3o0002oooo00<0o`3oool0o`000oooo`030?l0oooo0?l0
00;oool0103o0?ooooooo`3o00;oool20?l02Oooo`030?l0oooo0?l000;oool00`3o0?ooo`3o0003
oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000?oool20?l00oooo`030?l0oooo0?l000Goool0
1P3o0?ooooooo`3o0?ooo`3o00?oool01P3o0?ooo`3o003o0?ooo`3o00;oool20?l000Goool0o`00
o`3oool0o`000_ooo`030?l0oooooooo0080o`06oooo00<0o`3oooooool00P3o0004oooo0?l0oooo
0?l02Oooo`040?l0oooo0?l0oooo0`3o00Goool00`3o0?ooooooo`0;oooo00@0o`3oooooool0o`0C
oooo0P3o00Soool00`3o0?ooo`3o0003oooo1@3o00;oool0103o0?ooooooo`3o00;oool00`3o0?oo
o`3o0003oooo00<0o`3oooooool00P3o00[oool20?l00oooo`030?l0oooo0?l000?oool20?l02_oo
o`80o`04oooo00@0o`3oooooool0o`0;oooo0P3o03?oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool02Oooo`030?l0oooooooo00Goool00`3o0?ooooooo`07oooo0P3o00;oool00`3o0?oo
ooooo`020?l00oooo`030?l0oooooooo00@0o`03oooo00D0o`3oooooooooool0o`000_ooo`@0o`02
oooo00D0o`3oooooooooool0o`000_ooo`80o`03oooo00<0o`3oool0o`000oooo`<0o`02oooo00<0
o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00;oool20?l02Oooo`030?l0
oooo0?l000;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000?oool2
0?l00oooo`030?l0oooo0?l000Goool01P3o0?ooooooo`3o0?ooo`3o00?oool01P3o0?ooo`3o003o
0?ooo`3o00;oool20?l000Coool0o`00o`00o`03oooo00@0o`3oooooool0o`07oooo00<0o`3ooooo
ool00P3o0004oooo0?l0oooo0?l02Oooo`040?l0oooo0?l0oooo0`3o00Goool00`3o0?ooooooo`0;
oooo00@0o`3oooooool0o`0Coooo0P3o00Soool00`3o0?ooo`3o0003oooo1@3o00;oool0103o0?oo
ooooo`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oooooool00P3o00[oool20?l00oooo`030?l0
oooo0?l000?oool00`3o0?ooooooo`09oooo0P3o00Coool0103o0?ooooooo`3o00_oool20?l0<ooo
o`030000oooooooo00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool01Oooo`030?l0
oooooooo00Ooool20?l00_ooo`030?l0oooooooo0080o`03oooo00<0o`3oool0o`00103o00?oool0
1@3o0?ooooooooooo`3o0003oooo0`3o00;oool01@3o0?ooooooooooo`3o0002oooo0P3o00?oool0
0`3o0?ooo`3o0003oooo0`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000_ooo`040?l0
oooooooo0?l00oooo`030?l0oooooooo00Ooool00`3o0?ooo`3o0002oooo00<0o`3oool0o`001?oo
o`80o`08oooo00<0o`3oool0o`000oooo`80o`03oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l0
00?oool01P3o0?ooo`3o003o0?ooo`3o00;oool20?l000Coool0o`00o`00o`03oooo00@0o`3ooooo
ool0o`07oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`002Oooo`80o`02oooo0`3o01?oool0
103o0?ooooooo`3o01?oool20?l02?ooo`80o`04oooo1@3o00;oool0103o0?ooooooo`3o00;oool0
0`3o0?ooo`3o0003oooo00<0o`3oooooool00P3o00[oool20?l00oooo`030?l0oooo0?l000?oool0
0`3o0?ooooooo`09oooo0P3o00Coool0103o0?ooooooo`3o00_oool20?l0<oooo`030000oooooooo
00;oool001Coool00`000?ooooooo`09oooo00<0o`3oooooool01Oooo`030?l0oooooooo00Ooool2
0?l00_ooo`80o`000oooo`3o003o0003oooo00<0o`3oool0o`00103o00?oool01@3o0?oooooooooo
o`3o0003oooo0`3o00;oool01@3o0?ooooooooooo`3o0002oooo0P3o00?oool00`3o0?ooo`3o0003
oooo0`3o00;oool00`3o0?ooo`3o0003oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00ooo
o`030?l0oooooooo00Ooool00`3o0?ooo`3o0002oooo00<0o`3oool0o`001?ooo`80o`08oooo00<0
o`3oool0o`000oooo`80o`03oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000?oool01P3o0?oo
o`3o003o0?ooo`3o00;oool20?l00_ooo`80o`03oooo00@0o`3oooooool0o`07oooo00@0o`3ooooo
ool0o`02oooo00<0o`3oool0o`002Oooo`80o`02oooo0P3o01Coool0103o0?ooooooo`3o01?oool2
0?l02?ooo`80o`04oooo0`3o0005oooo0?l0oooooooo0?l000;oool01P3o0?ooooooo`3o0?ooo`3o
00?oool00`3o0?ooooooo`020?l02_ooo`80o`03oooo00<0o`3oool0o`000oooo`030?l0oooooooo
00Woool20?l01?ooo`040?l0oooooooo0?l03?ooo`030?l0oooooooo037oool00`000?ooooooo`02
oooo000Doooo00<0003oooooool02Oooo`030?l0oooooooo00Goool00`3o0?ooooooo`07oooo0P3o
00;oool20?l000?oool0o`00o`000oooo`030?l0oooo0?l000@0o`03oooo00D0o`3oooooooooool0
o`000oooo`<0o`02oooo00D0o`3oooooooooool0o`000_ooo`80o`03oooo00<0o`3oool0o`001?oo
o`80o`02oooo00<0o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00?oool0
0`3o0?ooooooo`07oooo0P3o00?oool00`3o0?ooo`3o0004oooo0P3o00Soool00`3o0?ooo`3o0003
oooo0P3o00?oool00`3o0?ooo`3o0008oooo0`3o00?oool01P3o0?ooo`3o003o0?ooo`3o00;oool0
103o0?ooooooooooo`80o`03oooo00@0o`3oooooool0o`07oooo00@0o`3oooooool0o`02oooo00<0
o`3oool0o`002Oooo`80o`02oooo0P3o01Coool0103o0?ooooooo`3o01?oool20?l02?ooo`80o`04
oooo0`3o0004oooo0?l0oooo0?l00oooo`060?l0oooooooo0?l0oooo0?l00oooo`030?l0oooooooo
0080o`0:oooo0P3o00?oool00`3o0?ooo`3o0003oooo00<0o`3oooooool03oooo`040?l0oooooooo
0?l03?ooo`030?l0oooooooo037oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Ooo
o`030?l0oooooooo00Goool00`3o0?ooooooo`07oooo0P3o00;oool20?l000?oool0o`00o`000ooo
o`030?l0oooo0?l00080o`000oooo`3o0?ooo`02oooo00D0o`3oooooooooool0o`000oooo`80o`03
oooo00D0o`3oooooooooool0o`000_ooo`80o`03oooo00<0o`3oool0o`001?ooo`80o`02oooo00<0
o`3oool0o`000oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00goool20?l00oooo`030?l0
oooo0?l000Coool20?l02?ooo`030?l0oooo0?l000?oool20?l00oooo`030?l0oooo0?l000Woool2
0?l00oooo`060?l0oooo0?l00?l0oooo0?l00_ooo`040?l0oooooooooooo0P3o00?oool0103o0?oo
ooooo`3o00Ooool0103o0?ooooooo`3o00;oool00`3o0?ooo`3o0009oooo0P3o00;oool20?l05?oo
o`040?l0oooooooo0?l04oooo`80o`08oooo0P3o00Coool30?l000Coool0o`3oool0o`03oooo00H0
o`3oooooool0o`3oool0o`03oooo00<0o`3oooooool00P3o00[oool20?l00oooo`030?l0oooo0?l0
01Goool0103o0?ooooooo`3o043oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Ooo
o`030?l0oooooooo00Goool00`3o0?ooooooo`07oooo0P3o00;oool20?l000?oool0o`00o`000ooo
o`030?l0oooo0?l00080o`000oooo`3o0?ooo`02oooo00D0o`3oooooooooool0o`000oooo`030?l0
oooooooo00;oool01@3o0?ooooooooooo`3o0002oooo0P3o00?oool00`3o0?ooo`3o0004oooo0P3o
00?oool20?l00oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00goool20?l00oooo`030?l0
oooo0?l000Coool20?l02?ooo`030?l0oooo0?l000?oool20?l00oooo`030?l0oooo0?l000Woool2
0?l00oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00?oool20?l00oooo`040?l0oooooooo
0?l01oooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000Woool20?l00_ooo`80o`0Doooo00@0
o`3oooooool0o`0Coooo0P3o00Soool20?l01?ooo`<0o`001?ooo`3o0?ooo`3o00?oool01P3o0?oo
ooooo`3o0?ooo`3o00?oool00`3o0?ooooooo`020?l02_ooo`80o`03oooo00<0o`3oool0o`005Ooo
o`030?l0oooo0?l0047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Oooo`030?l0
oooooooo00Goool00`3o0?ooooooo`07oooo0P3o00;oool20?l000?oool0o`00o`000oooo`030?l0
oooo0?l00080o`000oooo`3o0?ooo`02oooo00D0o`3oooooooooool0o`000oooo`030?l0oooooooo
00;oool01@3o0?ooooooooooo`3o0002oooo0P3o00?oool00`3o0?ooo`3o0005oooo00@0o`3ooooo
ooooool20?l00oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00goool20?l00oooo`030?l0
oooo0?l000Coool20?l02?ooo`030?l0oooo0?l000?oool20?l00oooo`030?l0oooo0?l000Woool2
0?l00oooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00?oool20?l00oooo`040?l0oooooooo
0?l01oooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000Woool20?l00_ooo`80o`0Doooo00@0
o`3oooooool0o`0Coooo0P3o00Soool20?l01?ooo`070?l0oooo0?l0oooo0?l0oooo0?l000?oool0
1P3o0?ooooooo`3o0?ooo`3o00?oool00`3o0?ooooooo`020?l02_ooo`80o`03oooo00<0o`3oool0
o`005Oooo`030?l0oooo0?l0047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02Ooo
o`030?l0oooooooo00Goool20?l02?ooo`80o`02oooo0P3o0003oooo0?l00?l000?oool00`3o0?oo
o`3o00020?l000?oool0o`3oool00_ooo`050?l0oooooooooooo0?l000Soool01@3o0?oooooooooo
o`3o0002oooo0P3o00?oool00`3o0?ooo`3o0009oooo0P3o00?oool00`3o0?ooo`3o0002oooo00@0
o`3oooooool0o`0=oooo0P3o00?oool00`3o0?ooo`3o0004oooo0P3o00Soool00`3o0?ooo`3o0003
oooo0P3o00?oool00`3o0?ooo`3o000>oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l00ooo
o`80o`03oooo00@0o`3oooooool0o`07oooo00@0o`3oooooool0o`02oooo00<0o`3oool0o`002Ooo
o`80o`02oooo0P3o01Coool0103o0?ooooooo`3o01?oool20?l02?ooo`80o`04oooo00L0o`3oool0
o`3oool0o`3oool0o`000oooo`060?l0oooooooo0?l0oooo0?l00oooo`030?l0oooooooo0080o`0:
oooo0P3o00?oool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0:oooo00<0o`3oooooool01?ooo`80o`08oooo0P3o00;oool20?l000?o
ool0o`00o`000oooo`030?l0oooo0?l00080o`000oooo`3o0?ooo`02oooo00D0o`3oooooooooool0
o`002?ooo`050?l0oooooooooooo0?l000?oool01`3o0?ooooooooooo`3o0?ooo`3o0009oooo0P3o
00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`0=oooo0P3o00?oool00`3o0?ooo`3o0004
oooo0P3o00Soool00`3o0?ooo`3o0003oooo0P3o00?oool00`3o0?ooo`3o000>oooo00<0o`3oool0
o`000_ooo`040?l0oooooooo0?l00oooo`80o`03oooo00@0o`3oool0o`00o`07oooo00@0o`3ooooo
ool0o`02oooo00<0o`3oool0o`002Oooo`80o`02oooo0P3o01Coool0103o0?ooooooo`3o01?oool2
0?l02?ooo`80o`06oooo00D0o`3oool0o`3oool0o`000oooo`060?l0oooooooo0?l0oooo0?l00ooo
o`030?l0oooooooo0080o`0:oooo0P3o00?oool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Ooo
o`030000oooooooo00;oool001Coool200002oooo`030?l0oooooooo00Coool20?l02?ooo`80o`02
oooo0P3o0003oooo0?l00?l000;oool20?l000Koool0o`00o`00o`3oool0o`03oooo00D0o`3ooooo
ooooool0o`002?ooo`050?l0oooooooooooo0?l000?oool01`3o0?ooooooooooo`3o0?ooo`3o0009
oooo0P3o00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`0=oooo0P3o00?oool00`3o0?oo
o`3o0004oooo0P3o00Soool00`3o0?ooo`3o0003oooo0P3o00?oool00`3o0?ooo`3o000>oooo00<0
o`3oool0o`000_ooo`040?l0oooooooo0?l00oooo`80o`03oooo00@0o`3oool0o`00o`07oooo00@0
o`3oooooool0o`02oooo00<0o`3oool0o`002_ooo`030?l0oooooooo0080o`0Doooo00@0o`3ooooo
ool0o`0Coooo0P3o00Soool20?l01_ooo`050?l0oooo0?l0oooo0?l000?oool0103o0?ooooooo`3o
00;oool0103o0?ooooooo`3o00;oool20?l02_ooo`80o`03oooo00<0o`3oool0o`005Oooo`030?l0
oooo0?l0043oool200001?ooo`005?ooo`030000oooooooo00[oool00`3o0?ooooooo`04oooo0P3o
00Soool20?l00_ooo`80o`000oooo`3o003o0002oooo0P3o0006oooo0?l0oooo0?l0oooo0?l00ooo
o`050?l0oooooooooooo0?l000Soool01@3o0?ooooooooooo`3o0003oooo00L0o`3oooooooooool0
o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l03Oooo`80o`03
oooo00<0o`3oool0o`001?ooo`80o`08oooo00<0o`3oool0o`000oooo`80o`03oooo00<0o`3oool0
o`003_ooo`030?l0oooo0?l000;oool0103o0?ooooooo`3o00?oool20?l00oooo`040?l0oooo0?l0
0?l01oooo`040?l0oooooooo0?l00_ooo`030?l0oooo0?l000[oool00`3o0?ooooooo`020?l05?oo
o`040?l0oooooooo0?l05?ooo`030?l0oooooooo00Koool20?l01_ooo`050?l0oooo0?l0oooo0?l0
00?oool0103o0?ooo`3o003o00;oool0103o0?ooooooo`3o00;oool20?l02oooo`070?l0oooooooo
oooo0?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo00[oool00`3o0?ooooooo`04oooo0P3o00Soool20?l00_ooo`80o`000oooo`3o003o0002
oooo0P3o0006oooo0?l0oooo0?l0oooo0?l00oooo`050?l0oooooooooooo0?l000Soool01@3o0?oo
ooooooooo`3o0003oooo00L0o`3oooooooooool0o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0
o`000_ooo`040?l0oooooooo0?l03Oooo`80o`03oooo00<0o`3oool0o`001?ooo`80o`08oooo00<0
o`3oool0o`000oooo`80o`03oooo00<0o`3oool0o`003_ooo`030?l0oooo0?l000;oool0103o0?oo
ooooo`3o00?oool20?l00oooo`040?l0oooo0?l00?l01oooo`040?l0oooooooo0?l00_ooo`030?l0
oooo0?l000goool20?l05?ooo`040?l0oooooooo0?l07Oooo`80o`06oooo00D0o`3oool0o`3oool0
o`000oooo`@0o`02oooo00@0o`3oooooool0o`02oooo0P3o00_oool01`3o0?ooooooooooo`3o0?oo
o`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:
oooo00<0o`3oooooool01?ooo`80o`08oooo0P3o00;oool20?l000?oool0o`00o`000_ooo`80o`00
1_ooo`3o0?ooo`3o0?ooo`3o00?oool01@3o0?ooooooooooo`3o0008oooo00@0o`3oooooool0o`04
oooo00L0o`3oooooooooool0o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0o`000_ooo`040?l0
oooooooo0?l03Oooo`80o`03oooo00<0o`3oool0o`001?ooo`80o`08oooo00<0o`3oool0o`000ooo
o`80o`03oooo00<0o`3oool0o`003_ooo`030?l0oooo0?l000;oool40?l00oooo`80o`03oooo00@0
o`3oool0o`00o`07oooo00@0o`3oooooool0o`03oooo0P3o00goool20?l05?ooo`040?l0oooooooo
0?l07Oooo`80o`06oooo00D0o`3oool0o`3oool0o`000oooo`@0o`02oooo00@0o`3oooooool0o`02
oooo0P3o00ooool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0:oooo00<0o`3oooooool01?ooo`80o`000oooo`3o0?ooo`05oooo0P3o
00;oool20?l000?oool0o`00o`000_ooo`80o`001_ooo`3o0?ooo`3o0?ooo`3o00?oool01@3o0?oo
ooooooooo`3o0008oooo00@0o`3oooooool0o`04oooo00L0o`3oooooooooool0o`3oool0o`002Ooo
o`80o`03oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l03Oooo`80o`03oooo00<0o`3oool0
o`001?ooo`80o`08oooo00<0o`3oool0o`000oooo`80o`04oooo0P3o00koool00`3o0?ooo`3o0002
oooo103o00?oool20?l00oooo`030?l0oooo0?l000Soool00`3o0?ooo`3o0004oooo0P3o00goool2
0?l05?ooo`040?l0oooooooo0?l07Oooo`80o`06oooo00D0o`3oool0o`3oool0o`000oooo`@0o`02
oooo00@0o`3oooooool0o`02oooo0P3o00ooool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Ooo
o`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo00<0o`3oooooool01?ooo`80o`00
0oooo`3o0?ooo`05oooo0P3o00;oool20?l000?oool0o`00o`000_ooo`80o`001_ooo`3o0?ooo`3o
0?ooo`3o00?oool01@3o0?ooooooooooo`3o0008oooo00@0o`3oooooool0o`04oooo00L0o`3ooooo
ooooool0o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0o`000_ooo`040?l0oooooooo0?l03Ooo
o`80o`03oooo00<0o`3oool0o`001Oooo`030?l0oooooooo00Koool30?l00oooo`80o`04oooo0P3o
00koool00`3o0?ooo`3o0002oooo103o00?oool20?l00oooo`030?l0oooo0?l000Soool00`3o0?oo
o`3o0004oooo0P3o00goool20?l05?ooo`040?l0oooooooo0?l07Oooo`80o`06oooo00D0o`3oool0
o`3oool0o`000oooo`@0o`02oooo00@0o`3oooooool0o`02oooo0P3o00ooool00`3o0?ooo`3o000E
oooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo00<0
o`3oooooool01?ooo`80o`000oooo`3o0?ooo`05oooo0P3o00;oool20?l000?oool0o`00o`000_oo
o`80o`001_ooo`3o0?ooo`3o0?ooo`3o00?oool0103o0?ooooooo`3o00Woool0103o0?ooooooo`3o
00Soool00`3o0?ooo`3o0009oooo0P3o00?oool00`3o0?ooo`3o0002oooo00@0o`3oooooool0o`0=
oooo0P3o00?oool00`3o0?ooo`3o0005oooo00<0o`3oooooool01_ooo`<0o`03oooo0P3o00Coool2
0?l03_ooo`030?l0oooo0?l000;oool30?l01?ooo`80o`03oooo00<0o`3oool0o`002?ooo`030?l0
oooo0?l000Coool20?l03Oooo`80o`0Doooo0P3o0003oooo0?l0oooo01coool20?l01_ooo`050?l0
oooo0?l0oooo0?l000?oool40?l00_ooo`040?l0oooooooo0?l00_ooo`80o`0?oooo00<0o`3oool0
o`005Oooo`030?l0oooo0?l0047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02_oo
o`030?l0oooooooo00Coool20?l000?oool0o`3oool01Oooo`80o`02oooo0P3o0003oooo0?l00?l0
00;oool20?l000Koool0o`3oool0o`3oool0o`03oooo00@0o`3oooooool0o`09oooo00@0o`3ooooo
ool0o`08oooo00<0o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0o`000_ooo`040?l0oooooooo
0?l03Oooo`80o`03oooo00<0o`3oool0o`003_ooo`<0o`03oooo0P3o00Coool20?l03_ooo`030?l0
oooo0?l000;oool30?l01?ooo`80o`03oooo00<0o`3oool0o`002?ooo`030?l0oooo0?l000Coool2
0?l03Oooo`80o`0Doooo0P3o0003oooo0?l0oooo01coool20?l01_ooo`030?l0oooooooo0080o`03
oooo103o00;oool0103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?oo
o`3o0011oooo00<0003oooooool00_ooo`003?ooo`030000oooooooo00Goool00`000?ooooooo`0:
oooo00<0o`3oooooool01?ooo`80o`000oooo`3o0?ooo`05oooo0`3o0004oooo0?l00?l0oooo0P3o
00;oool20?l000Koool0o`3oool0o`3oool0o`03oooo00@0o`3oooooool0o`09oooo00@0o`3ooooo
ool0o`08oooo00<0o`3oool0o`002Oooo`80o`03oooo00<0o`3oool0o`000oooo`030?l0oooo0?l0
00goool20?l00oooo`030?l0oooo0?l000koool30?l00oooo`80o`04oooo0P3o00koool00`3o0?oo
o`3o0002oooo0`3o00Coool20?l00oooo`030?l0oooo0?l000Soool00`3o0?ooo`3o0004oooo00<0
o`3oooooool03?ooo`80o`0Doooo0P3o0003oooo0?l0oooo01coool20?l01_ooo`040?l0oooooooo
0?l01?ooo`@0o`02oooo00@0o`3oooooool0o`02oooo0P3o00ooool00`3o0?ooo`3o000Eoooo00<0
o`3oool0o`00@Oooo`030000oooooooo00;oool000_oool00`000?ooo`000006oooo00<0003ooooo
ool02_ooo`030?l0oooooooo00Coool20?l000?oool0o`3oool01Oooo`<0o`001?ooo`3o003o0?oo
o`80o`02oooo0P3o0003oooo0?l0oooo00;oool01@3o0?ooooooooooo`3o0002oooo00<0o`3ooooo
ool01oooo`040?l0oooooooo0?l02?ooo`030?l0oooo0?l000Woool00`3o0?ooooooo`02oooo00<0
o`3oool0o`000oooo`030?l0oooo0?l000goool20?l00oooo`030?l0oooo0?l000koool30?l00ooo
o`80o`05oooo00<0o`3oooooool03?ooo`030?l0oooo0?l000;oool30?l01?ooo`80o`03oooo00<0
o`3oool0o`002?ooo`030?l0oooo0?l000Coool00`3o0?ooooooo`0<oooo0P3o01Coool20?l000?o
ool0o`3oool07?ooo`80o`06oooo00@0o`3oooooool0o`04oooo103o00;oool0103o0?ooooooo`3o
00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_oo
o`003Oooo`030000oooooooo00Coool300002_ooo`030?l0oooooooo00Coool20?l000?oool0o`3o
ool01Oooo`<0o`001?ooo`3o003o0?ooo`80o`02oooo00@0o`3oool0o`00o`03oooo00D0o`3ooooo
ooooool0o`000_ooo`030?l0oooooooo00Ooool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o0009
oooo00<0o`3oooooool00oooo`80o`03oooo00<0o`3oool0o`003Oooo`80o`03oooo00<0o`3oool0
o`003_ooo`80o`04oooo0P3o01Coool00`3o0?ooo`3o0002oooo0`3o00Coool20?l00oooo`030?l0
oooo0?l000Soool00`3o0?ooo`3o0004oooo00<0o`3oooooool03?ooo`80o`0Doooo103o01goool2
0?l01_ooo`040?l0oooooooo0?l01?ooo`@0o`02oooo00@0o`3oooooool0o`02oooo0P3o00ooool0
0`3o0?ooo`3o000Eoooo00<0o`3oool0o`00?oooo`<00004oooo000;oooo0P0000Ooool00`000?oo
ooooo`0:oooo00<0o`3oooooool01?ooo`80o`000oooo`3o0?ooo`05oooo0`3o0004oooo0?l00?l0
oooo0P3o00;oool0103o0?ooo`3o003o00?oool01@3o0?ooooooooooo`3o0002oooo00<0o`3ooooo
ool01oooo`040?l0oooooooo0?l02?ooo`030?l0oooo0?l000Woool00`3o0?ooooooo`03oooo0P3o
00?oool00`3o0?ooo`3o000=oooo0P3o00?oool00`3o0?ooo`3o000Doooo0P3o01Coool00`3o0?oo
o`3o0002oooo0`3o00Coool20?l00oooo`030?l0oooo0?l000Soool00`3o0?ooo`3o0004oooo00<0
o`3oooooool03?ooo`80o`0Doooo103o01goool20?l01_ooo`040?l0oooooooo0?l01?ooo`@0o`02
oooo00@0o`3oooooool0o`02oooo0P3o00ooool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Ooo
o`030000oooooooo00;oool000_oool00`000?ooooooo`06oooo00<0003oooooool02_ooo`030?l0
oooooooo00Coool20?l000?oool0o`3oool01Oooo`<0o`001?ooo`3o003o0?ooo`80o`02oooo00@0
o`3oool0o`00o`03oooo00D0o`3oooooooooool0o`000_ooo`030?l0oooooooo00Ooool0103o0?oo
ooooo`3o00Soool00`3o0?ooo`3o0009oooo00<0o`3oooooool00oooo`80o`03oooo00<0o`3oool0
o`003Oooo`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0o`3oool0o`000_ooo`<0o`04
oooo0P3o00?oool00`3o0?ooo`3o0008oooo00<0o`3oool0o`001?ooo`030?l0oooooooo00coool2
0?l05?ooo`@0o`0Moooo0P3o00Koool0103o0?ooooooo`3o00Coool40?l00_ooo`040?l0oooooooo
0?l00_ooo`80o`0?oooo00<0o`3oool0o`005Oooo`030?l0oooo0?l0047oool00`000?ooooooo`02
oooo000;oooo0`0000Koool00`000?ooooooo`0:oooo00<0o`3oooooool01?ooo`80o`000oooo`3o
0?ooo`05oooo0`3o0004oooo0?l00?l0oooo0P3o00;oool0103o0?ooo`3o003o00Ooool0103o0?oo
ooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o0009oooo00<0o`3oooooool00ooo
o`80o`03oooo00<0o`3oool0o`003Oooo`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0
o`3oool0o`000oooo`80o`04oooo0P3o00?oool30?l02?ooo`030?l0oooo0?l000Coool00`3o0?oo
ooooo`0<oooo0P3o01Coool30?l07_ooo`80o`06oooo00@0o`3oooooool0o`04oooo103o00;oool0
103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo00[oool00`3o0?ooooooo`04oooo0P3o0003oooo
0?l0oooo00;oool00`3o0?ooooooo`030?l000Koool0o`00o`00o`3oool0o`02oooo00@0o`3oool0
o`00o`07oooo00@0o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`003ooo
o`030?l0oooooooo00;oool00`3o0?ooo`3o000=oooo0P3o00?oool00`3o0?ooo`3o000Doooo0P3o
01Coool00`3o0?ooo`3o0003oooo0P3o00Coool20?l00oooo`<0o`08oooo00<0o`3oool0o`001?oo
o`030?l0oooooooo02;oool30?l07_ooo`80o`06oooo00@0o`3oooooool0o`05oooo0`3o00;oool0
103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo00[oool00`3o0?ooooooo`04oooo0P3o0003oooo
0?l0oooo00;oool00`3o0?ooooooo`030?l000Koool0o`00o`00o`3oool0o`02oooo00@0o`3oool0
o`00o`07oooo00@0o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`003ooo
o`030?l0oooooooo00;oool30?l03Oooo`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0
o`3oool0o`000oooo`80o`04oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l002Woool30?l07_oo
o`80o`06oooo00@0o`3oooooool0o`05oooo0`3o00;oool0103o0?ooooooo`3o00;oool20?l03ooo
o`030?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo00[oool00`3o0?ooooooo`04oooo0P3o0003oooo0?l0oooo00;oool00`3o0?ooooooo`03
0?l000Koool0o`00o`00o`3oool0o`02oooo00@0o`3oool0o`00o`07oooo00@0o`3oooooool0o`09
oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`003oooo`030?l0oooooooo00;oool30?l03Ooo
o`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0o`3oool0o`000oooo`80o`04oooo0P3o
00Coool20?l02?ooo`030?l0oooo0?l002Woool30?l07_ooo`80o`06oooo00@0o`3oooooool0o`05
oooo0`3o00;oool0103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?oo
o`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool00`3o0?ooooooo`04
oooo0P3o0003oooo0?l0oooo00;oool00`3o0?ooooooo`030?l000Koool0o`00o`00o`3oool0o`02
oooo00@0o`3oool0o`00o`07oooo00@0o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0
o`3oool0o`003oooo`030?l0oooooooo00;oool30?l03Oooo`80o`03oooo00<0o`3oool0o`005?oo
o`80o`0Doooo00<0o`3oool0o`000oooo`80o`04oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l0
02Woool30?l07_ooo`80o`06oooo00@0o`3oooooool0o`05oooo0`3o00;oool0103o0?ooooooo`3o
00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_oo
o`005?ooo`030000oooooooo00[oool00`3o0?ooooooo`04oooo0P3o0003oooo0?l0oooo00;oool0
0`3o0?ooooooo`030?l000Koool0o`00o`00o`3oool0o`02oooo00@0o`3oool0o`00o`07oooo00@0
o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`003oooo`030?l0oooooooo
00;oool30?l03Oooo`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0o`3oool0o`000ooo
o`80o`04oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l002Woool30?l07_ooo`80o`09oooo00<0
o`3oooooool00oooo`<0o`02oooo00@0o`3oooooool0o`02oooo0P3o00ooool00`3o0?ooo`3o000E
oooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo00<0
o`3oooooool01?ooo`80o`000oooo`3o0?ooo`02oooo00<0o`3oooooool00`3o0007oooo0?l00?l0
0?l0oooo0?l0oooo0080o`000oooo`3o0?ooo`07oooo00@0o`3oooooool0o`09oooo00@0o`3ooooo
ool0o`08oooo00<0o`3oool0o`003oooo`030?l0oooooooo00;oool30?l03Oooo`80o`03oooo00<0
o`3oool0o`005?ooo`80o`0Doooo00<0o`3oool0o`000oooo`030?l0oooooooo00?oool20?l01?oo
o`80o`08oooo00<0o`3oool0o`00:Oooo`<0o`0Noooo0P3o00Woool00`3o0?ooooooo`03oooo0`3o
00;oool0103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011
oooo00<0003oooooool00_ooo`005?ooo`80000;oooo0P3o00Goool20?l000?oool0o`3oool00_oo
o`030?l0oooooooo00<0o`001oooo`3o003o003o0?ooo`3o0?ooo`020?l000?oool0o`3oool01ooo
o`040?l0oooooooo0?l02Oooo`040?l0oooooooo0?l02?ooo`030?l0oooo0?l001Coool30?l03Ooo
o`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0o`3oool0o`000oooo`030?l0oooooooo
00?oool20?l01?ooo`80o`08oooo00<0o`3oool0o`00:Oooo`<0o`0Noooo0P3o00ooool30?l00_oo
o`040?l0oooooooo0?l00_ooo`80o`0?oooo00<0o`3oool0o`005Oooo`030?l0oooo0?l0043oool2
00001?ooo`005?ooo`030000oooooooo00[oool20?l01Oooo`80o`000oooo`3o003o0002oooo00<0
o`3oooooool00`3o0007oooo0?l00?l00?l0oooo0?l0oooo0080o`000oooo`3o0?ooo`07oooo00@0
o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`005?ooo`<0o`0=oooo0P3o
00?oool00`3o0?ooo`3o000Doooo0P3o01Coool00`3o0?ooo`3o0003oooo00<0o`3oooooool00ooo
o`80o`04oooo0P3o00Soool00`3o0?ooo`3o000Yoooo00<0o`3oool0o`007_ooo`80o`0?oooo0`3o
00;oool0103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool20?l01Oooo`80o`000oooo`3o
003o0002oooo00<0o`3oooooool00`3o0005oooo0?l00?l00?l0oooo00@0o`000oooo`3o0?ooo`07
oooo00@0o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`005?ooo`<0o`0=
oooo0P3o00?oool00`3o0?ooo`3o000Doooo0P3o01Coool00`3o0?ooo`3o0003oooo00<0o`3ooooo
ool00oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o000Yoooo00<0o`3oool0o`007_ooo`80o`0@
oooo0P3o00;oool0103o0?ooooooo`3o00;oool20?l03oooo`030?l0oooo0?l001Goool00`3o0?oo
o`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool20?l01Oooo`80o`00
0oooo`3o003o0002oooo00@0o`3oool0o`3oool20?l000Goool0o`00o`00o`3oool0103o0003oooo
0?l0oooo00Ooool0103o0?ooooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o000D
oooo0`3o00goool20?l00oooo`030?l0oooo0?l001Coool20?l05?ooo`030?l0oooo0?l000?oool0
0`3o0?ooooooo`03oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l002Woool00`3o0?ooo`3o000N
oooo0P3o017oool0103o0?ooooooo`3o00;oool00`3o0?ooooooo`020?l03oooo`030?l0oooo0?l0
01Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool2
0?l01?ooo`040?l0oooo0?l0oooo0P3o00;oool0103o0?ooo`3o0?ooo`80o`001Oooo`3o003o003o
0?ooo`040?l000?oool0o`3oool01oooo`040?l0oooooooo0?l02Oooo`040?l0oooooooo0?l02?oo
o`030?l0oooo0?l001Coool30?l03Oooo`80o`03oooo00<0o`3oool0o`005?ooo`80o`0Doooo00<0
o`3oool0o`000oooo`030?l0oooooooo00?oool20?l01?ooo`80o`08oooo00<0o`3oool0o`00:Ooo
o`030?l0oooo0?l001koool20?l05?ooo`040?l0oooooooo0?l00_ooo`030?l0oooooooo00koool0
0`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0:oooo0P3o00Coool0103o0?ooo`3o0?ooo`80o`02oooo00@0o`3oool0o`3oool20?l000Go
ool0o`00o`00o`3oool0103o0003oooo0?l0oooo00Ooool0103o0?ooooooo`3o00Woool0103o0?oo
ooooo`3o00Soool00`3o0?ooo`3o000Doooo0`3o00goool00`3o0?ooooooo`02oooo00<0o`3oool0
o`005?ooo`80o`0Doooo00<0o`3oool0o`000oooo`030?l0oooooooo00?oool20?l01?ooo`80o`08
oooo00<0o`3oool0o`00:Oooo`030?l0oooooooo01koool20?l05?ooo`040?l0oooooooo0?l00_oo
o`030?l0oooooooo00koool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo
00;oool001Coool00`000?ooooooo`0:oooo0P3o00Coool0103o0?ooo`3o0?ooo`80o`02oooo00@0
o`3oool0o`3oool20?l000Goool0o`00o`00o`3oool0103o0003oooo0?l0oooo00Ooool0103o0?oo
ooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o000Doooo0`3o00goool00`3o0?oo
ooooo`02oooo0P3o01Goool20?l05?ooo`030?l0oooo0?l000?oool00`3o0?ooooooo`03oooo0P3o
00Coool20?l02?ooo`030?l0oooo0?l002Woool00`3o0?ooooooo`0Noooo00<0o`3oooooool04ooo
o`040?l0oooooooo0?l00_ooo`030?l0oooooooo00koool00`3o0?ooo`3o000Eoooo00<0o`3oool0
o`00@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo0P3o00Coool0103o0?oo
o`3o0?ooo`80o`02oooo00@0o`3oool0o`3oool20?l000Goool0o`00o`00o`3oool0103o0003oooo
0?l0oooo00Ooool0103o0?ooooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o000D
oooo0`3o00goool00`3o0?ooooooo`02oooo0P3o01Goool20?l05?ooo`030?l0oooo0?l000?oool0
0`3o0?ooooooo`03oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l002Woool00`3o0?ooooooo`0N
oooo00<0o`3oooooool04oooo`040?l0oooooooo0?l04oooo`030?l0oooo0?l001Goool00`3o0?oo
o`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool20?l01?ooo`040?l0
oooo0?l0oooo0P3o00;oool0103o0?ooo`3o0?ooo`80o`001Oooo`3o003o003o0?ooo`040?l000?o
ool0o`3oool01oooo`040?l0oooooooo0?l02Oooo`040?l0oooooooo0?l02?ooo`030?l0oooo0?l0
01Coool30?l03Oooo`030?l0oooooooo00;oool20?l05Oooo`80o`0Doooo00<0o`3oool0o`000ooo
o`030?l0oooooooo00?oool20?l01?ooo`80o`08oooo00<0o`3oool0o`00:Oooo`030?l0oooooooo
03Coool0103o0?ooooooo`3o01?oool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0:oooo0P3o00Coool0103o0?ooo`3o0?ooo`80o`02
oooo0`3o0004oooo0?l00?l0oooo0`3o0003oooo0?l00?l00080o`000oooo`3o0?ooo`07oooo00@0
o`3oooooool0o`09oooo00@0o`3oooooool0o`08oooo00<0o`3oool0o`005?ooo`<0o`0=oooo00<0
o`3oooooool00_ooo`80o`0Eoooo0P3o01Coool00`3o0?ooo`3o0009oooo0P3o00Coool20?l02?oo
o`030?l0oooo0?l002Woool00`3o0?ooooooo`0doooo00@0o`3oooooool0o`0Coooo00<0o`3oool0
o`005Oooo`030?l0oooo0?l0047oool00`000?ooooooo`02oooo000Doooo0P0000_oool00`3o0?oo
o`3o0003oooo00@0o`3oool0o`3oool20?l00_ooo`<0o`001?ooo`3o003o0?ooo`<0o`000oooo`3o
003o00020?l000?oool0o`3oool01oooo`040?l0oooooooo0?l02Oooo`040?l0oooooooo0?l02?oo
o`030?l0oooo0?l001Coool30?l03Oooo`030?l0oooooooo00;oool20?l05Oooo`80o`0Doooo00<0
o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o000Yoooo00<0o`3oooooool0=?oo
o`040?l0oooooooo0?l04oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0010oooo0P0000Coool0
01Coool00`000?ooooooo`0:oooo00<0o`3oool0o`000oooo`040?l0oooo0?l0oooo0P3o00;oool3
0?l000Coool0o`00o`3oool30?l000?oool0o`00o`000P3o0003oooo0?l0oooo00Ooool0103o0?oo
ooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o000Doooo0`3o01;oool20?l05Ooo
o`80o`0Doooo00<0o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o000Yoooo00<0
o`3oooooool0=?ooo`040?l0oooooooo0?l04oooo`030?l0oooo0?l001Goool00`3o0?ooo`3o0011
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool00`3o0?ooo`3o0003oooo00@0
o`3oool0o`3oool20?l00_ooo`<0o`001?ooo`3o003o0?ooo`80o`02oooo103o0003oooo0?l0oooo
00Ooool0103o0?ooooooo`3o00Woool0103o0?ooooooo`3o00Soool00`3o0?ooo`3o000Doooo0`3o
01;oool20?l05Oooo`80o`0Doooo00<0o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?oo
o`3o001Poooo00@0o`3oooooool0o`0Coooo00<0o`3oool0o`005Oooo`030?l0oooo0?l0047oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool02_ooo`040?l0oooo0?l00?l00_ooo`040?l0
oooo0?l0oooo0P3o00;oool30?l000Coool0o`00o`3oool20?l00_ooo`@0o`0:oooo00@0o`3ooooo
ool0o`09oooo00@0o`3oooooool0o`08oooo0P3o01Goool30?l04_ooo`80o`0Eoooo0P3o01Coool0
0`3o0?ooo`3o0009oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l0063oool0103o0?ooooooo`3o
01?oool00`3o0?ooo`3o000Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0:oooo00@0o`3oool0o`00o`02oooo00@0o`3oool0o`3oool20?l00_ooo`<0o`00
1Oooo`3o003o0?ooo`3o0003oooo103o00[oool0103o0?ooooooo`3o00Woool0103o0?ooooooo`3o
00Soool20?l05Oooo`<0o`0Boooo0P3o01Goool20?l05?ooo`030?l0oooo0?l000Woool20?l01?oo
o`80o`08oooo00<0o`3oool0o`00H?ooo`040?l0oooooooo0?l04oooo`030?l0oooo0?l001Goool0
0`3o0?ooo`3o0011oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00[oool0103o0?oo
o`3o003o00;oool0103o0?ooo`3o0?ooo`80o`02oooo0`3o0005oooo0?l00?l0oooo0?l000?oool4
0?l02_ooo`040?l0oooooooo0?l02Oooo`040?l0oooooooo0?l02?ooo`80o`0Eoooo0`3o01;oool2
0?l05Oooo`80o`0Doooo00<0o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o001P
oooo00@0o`3oooooool0o`0Coooo00<0o`3oool0o`005Oooo`030?l0oooo0?l0047oool00`000?oo
ooooo`02oooo000Doooo00<0003oooooool02_ooo`040?l0oooo0?l00?l00_ooo`040?l0oooo0?l0
oooo0P3o00;oool30?l000Goool0o`00o`3oool0o`000oooo`@0o`0:oooo00@0o`3oooooool0o`09
oooo00@0o`3oooooool0o`08oooo0P3o01Goool30?l04_ooo`80o`0Eoooo0P3o01Coool00`3o0?oo
o`3o0009oooo0P3o00Coool20?l02?ooo`030?l0oooo0?l0063oool0103o0?ooooooo`3o01Coool2
0?l05Oooo`030?l0oooo0?l0047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02_oo
o`040?l0oooo0?l00?l00_ooo`040?l0oooo0?l0oooo0`3o0005oooo0?l00?l00?l0oooo0080o`00
0oooo`3o0?ooo`02oooo103o00_oool00`3o0?ooo`3o0009oooo00@0o`3oooooool0o`08oooo0P3o
01Goool30?l04_ooo`80o`0Eoooo0P3o01Coool00`3o0?ooo`3o0009oooo0P3o00Coool20?l02?oo
o`030?l0oooo0?l0063oool0103o0?ooooooo`3o01Coool20?l05Oooo`030?l0oooo0?l0047oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool02_ooo`040?l0oooo0?l00?l00_ooo`040?l0
oooo0?l0oooo0`3o0005oooo0?l00?l00?l0oooo0080o`000oooo`3o0?ooo`03oooo0`3o00_oool0
0`3o0?ooo`3o0009oooo00@0o`3oooooool0o`08oooo0P3o01Koool00`3o0?ooooooo`0Aoooo0P3o
01Goool20?l05?ooo`030?l0oooo0?l000Woool20?l01?ooo`80o`08oooo00<0o`3oool0o`00H?oo
o`040?l0oooooooo0?l05?ooo`80o`0Eoooo00<0o`3oool0o`00@Oooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0:oooo00@0o`3oooooool0o`02oooo00@0o`3oool0o`3oool30?l000?o
ool0o`00o`000_ooo`80o`000oooo`3o0?ooo`03oooo0`3o00_oool00`3o0?ooo`3o0009oooo00@0
o`3oooooool0o`08oooo0P3o02[oool20?l05Oooo`80o`0Doooo00<0o`3oool0o`002Oooo`80o`04
oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0o`3oooooool0o`0Doooo0P3o01Goool00`3o0?oo
o`3o0011oooo00<0003oooooool00_ooo`005?ooo`80000;oooo00X0o`3oooooooooool0o`3oool0
o`3oool0o`3oool30?l000?oool0o`00o`000_ooo`80o`000oooo`3o0?ooo`03oooo0`3o00_oool0
0`3o0?ooo`3o0009oooo00@0o`3oooooool0o`08oooo0P3o02[oool20?l05Oooo`80o`0Doooo00<0
o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0o`3oooooool0o`0D
oooo0P3o01Goool00`3o0?ooo`3o0010oooo0P0000Coool001Coool00`000?ooooooo`0:oooo00X0
o`3oooooooooool0o`3oool0o`3oool0o`3oool30?l000?oool0o`00o`000_ooo`80o`000oooo`3o
0?ooo`03oooo0`3o00_oool00`3o0?ooo`3o0009oooo00<0o`3oool0o`002Oooo`80o`0Zoooo0P3o
01Goool00`3o0?ooooooo`0Coooo00<0o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?oo
o`3o001Poooo00@0o`3oooooool0o`0Doooo0P3o01Goool00`3o0?ooo`3o0011oooo00<0003ooooo
ool00_ooo`005?ooo`030000oooooooo00[oool02P3o0?ooooooooooo`3o0?ooo`3o0?ooo`3o0?oo
o`<0o`000oooo`3o003o0002oooo103o00Coool30?l02oooo`030?l0oooo0?l000Woool00`3o0?oo
o`3o0009oooo0P3o02[oool20?l05Oooo`030?l0oooooooo01?oool00`3o0?ooo`3o0009oooo0P3o
00Coool20?l02?ooo`030?l0oooo0?l0063oool0103o0?ooooooo`3o01Coool20?l05Oooo`030?l0
oooo0?l0047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02_ooo`0:0?l0oooooooo
oooo0?l0oooo0?l0oooo0?l0oooo0`3o0003oooo0?l00?l000;oool40?l01?ooo`<0o`0;oooo00<0
o`3oool0o`002Oooo`030?l0oooo0?l000[oool00`3o0?ooooooo`0Xoooo0P3o01Goool00`3o0?oo
ooooo`0Coooo00<0o`3oool0o`002Oooo`80o`04oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0
o`3oooooool0o`0Doooo0P3o01Goool00`3o0?ooo`3o0011oooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo00[oool02P3o0?ooooooooooo`3o0?ooo`3o0?ooo`3o0?ooo`<0o`000oooo`3o
003o0002oooo103o00Coool30?l02oooo`030?l0oooo0?l000Woool00`3o0?ooo`3o000:oooo00<0
o`3oooooool0:?ooo`80o`0Eoooo00<0o`3oooooool04oooo`030?l0oooo0?l000Woool20?l01?oo
o`80o`08oooo00<0o`3oool0o`00H?ooo`040?l0oooooooo0?l05?ooo`80o`0Foooo0P3o047oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool02_ooo`0:0?l0oooooooooooo0?l0oooo0?l0
oooo0?l0oooo0`3o0003oooo0?l00?l000;oool40?l01?ooo`<0o`0;oooo00<0o`3oool0o`002Ooo
o`030?l0oooo0?l000[oool00`3o0?ooooooo`0Xoooo0P3o01Goool00`3o0?ooooooo`0Coooo00<0
o`3oool0o`002Oooo`030?l0oooooooo00?oool20?l02?ooo`030?l0oooo0?l0063oool0103o0?oo
ooooo`3o01Coool20?l05_ooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
00[oool02P3o0?ooooooooooo`3o0?ooo`3o0?ooo`3o0?ooo`<0o`000oooo`3o003o0002oooo103o
00Coool30?l02oooo`030?l0oooo0?l000Woool00`3o0?ooo`3o000:oooo00<0o`3oooooool0:?oo
o`80o`0Eoooo00<0o`3oooooool04oooo`030?l0oooo0?l000Woool00`3o0?ooooooo`03oooo0P3o
00Soool00`3o0?ooo`3o001Poooo00@0o`3oooooool0o`0Doooo0P3o01Koool20?l0@Oooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0:oooo00P0o`3oooooooooool0o`3oool0o`3oool2
0?l000Coool0o`00o`3oool20?l00_ooo`@0o`04oooo0`3o00_oool00`3o0?ooo`3o0009oooo00<0
o`3oool0o`002_ooo`030?l0oooooooo02Woool00`3o0?ooooooo`0Coooo00<0o`3oooooool04ooo
o`030?l0oooo0?l000Woool00`3o0?ooooooo`03oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0
o`3oooooool0o`0Doooo0P3o01Koool20?l0@Oooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0:oooo00P0o`3oooooooooool0o`3oool0o`3oool20?l000Coool0o`00o`3oool20?l00_oo
o`@0o`04oooo0`3o00_oool00`3o0?ooo`3o0009oooo00<0o`3oool0o`002_ooo`030?l0oooooooo
02Woool00`3o0?ooooooo`0Coooo00<0o`3oooooool04oooo`030?l0oooo0?l000Woool00`3o0?oo
ooooo`03oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0o`3oooooool0o`0Doooo0P3o01Koool2
0?l0@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo00P0o`3oooooooooool0
o`3oool0o`3oool20?l000Coool0o`00o`3oool20?l00_ooo`@0o`04oooo0`3o00_oool00`3o0?oo
o`3o0009oooo00<0o`3oool0o`002_ooo`030?l0oooooooo02Woool00`3o0?ooooooo`0Coooo00<0
o`3oooooool04oooo`030?l0oooo0?l000ooool20?l02?ooo`030?l0oooo0?l0063oool0103o0?oo
ooooo`3o01Coool20?l05_ooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`80000;oooo00P0
o`3oooooooooool0o`3oool0o`3oool20?l000Coool0o`00o`3oool20?l00_ooo`@0o`04oooo0`3o
00_oool00`3o0?ooo`3o0009oooo00<0o`3oool0o`002_ooo`030?l0oooooooo02Woool00`3o0?oo
ooooo`0Coooo00<0o`3oooooool04oooo`80o`0@oooo0P3o00Soool00`3o0?ooo`3o001Poooo00@0
o`3oooooool0o`0Doooo0P3o01Koool20?l0@?ooo`800004oooo000Doooo00<0003oooooool02_oo
o`080?l0oooooooooooo0?l0oooo0?l0oooo0P3o0004oooo0?l00?l0oooo0P3o00;oool40?l01?oo
o`<0o`0;oooo00<0o`3oool0o`002Oooo`030?l0oooo0?l000[oool00`3o0?ooooooo`0Yoooo00<0
o`3oooooool04oooo`030?l0oooooooo01?oool20?l04?ooo`80o`08oooo00<0o`3oool0o`00H?oo
o`040?l0oooooooo0?l05?ooo`80o`0Foooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool02_ooo`080?l0oooooooooooo0?l0oooo0?l0oooo0P3o0005oooo0?l00?l0oooo0?l0
00?oool40?l01?ooo`<0o`0;oooo00<0o`3oool0o`002Oooo`030?l0oooo0?l000[oool00`3o0?oo
ooooo`0Yoooo00<0o`3oooooool04oooo`030?l0oooooooo01?oool20?l04?ooo`80o`08oooo00<0
o`3oool0o`00H?ooo`040?l0oooooooo0?l05?ooo`80o`0Foooo0P3o047oool00`000?ooooooo`02
oooo000Doooo00<0003oooooool02_ooo`080?l0oooooooooooo0?l0oooo0?l0oooo0P3o0005oooo
0?l00?l0oooo0?l000?oool40?l01?ooo`<0o`0;oooo00<0o`3oool0o`002Oooo`030?l0oooo0?l0
00[oool00`3o0?ooooooo`0Yoooo00<0o`3oooooool04oooo`030?l0oooooooo01?oool20?l04?oo
o`80o`08oooo00<0o`3oool0o`00H?ooo`030?l0oooo0?l001Goool20?l05_ooo`80o`11oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo00[oool0203o0?ooooooooooo`3o0?ooo`3o0?oo
o`80o`001Oooo`3o003o0?ooo`3o0003oooo103o00Coool30?l02oooo`030?l0oooo0?l000Woool0
0`3o0?ooo`3o000:oooo00<0o`3oooooool0:Oooo`030?l0oooooooo01?oool00`3o0?ooooooo`0C
oooo0P3o013oool20?l02?ooo`030?l0oooo0?l0063oool00`3o0?ooo`3o000Eoooo0P3o01Koool2
0?l0@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0:oooo00P0o`3oooooooooool0
o`3oool0o`3oool20?l000Goool0o`00o`3oool0o`000oooo`@0o`04oooo0`3o00_oool00`3o0?oo
o`3o0009oooo00<0o`3oool0o`002_ooo`030?l0oooooooo02Woool00`3o0?ooooooo`0Coooo00<0
o`3oooooool04oooo`80o`0@oooo0P3o00Soool00`3o0?ooo`3o001Poooo00<0o`3oool0o`005Ooo
o`80o`0Foooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool02_ooo`080?l0
oooooooooooo0?l0oooo0?l0oooo0P3o0005oooo0?l00?l0oooo0?l000?oool40?l01Oooo`80o`0;
oooo00<0o`3oool0o`002Oooo`030?l0oooo0?l000[oool00`3o0?ooooooo`0Yoooo00<0o`3ooooo
ool04oooo`030?l0oooooooo01?oool20?l04?ooo`80o`08oooo00<0o`3oool0o`00H?ooo`030?l0
oooo0?l001Goool20?l05_ooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
00[oool0203o0?ooooooooooo`3o0?ooo`3o0?ooo`80o`001Oooo`3o003o0?ooo`3o0003oooo103o
00Goool20?l02oooo`030?l0oooo0?l000Woool00`3o0?ooo`3o000:oooo00<0o`3oooooool0:Ooo
o`030?l0oooooooo01?oool00`3o0?ooooooo`0Coooo0P3o013oool20?l02?ooo`030?l0oooo0?l0
063oool00`3o0?ooo`3o000Eoooo0P3o01Koool20?l0@Oooo`030000oooooooo00;oool000Goool5
00000_ooo`030000oooooooo00Goool00`000?ooooooo`0>oooo00@0o`3oool0o`3oool20?l000Go
ool0o`00o`3oool0o`000oooo`@0o`05oooo0P3o00_oool00`3o0?ooo`3o0009oooo00<0o`3oool0
o`002_ooo`030?l0oooooooo02Woool00`3o0?ooooooo`0Yoooo0P3o013oool20?l02?ooo`030?l0
oooo0?l0063oool00`3o0?ooo`3o000Eoooo0P3o01Koool20?l0@Oooo`030000oooooooo00;oool0
00Ooool01`000?ooooooooooo`000?ooo`000006oooo00<0003oooooool03_ooo`040?l0oooo0?l0
oooo0P3o0005oooo0?l00?l0oooo0?l000?oool0103o0?ooo`3o003o00Goool20?l02oooo`030?l0
oooo0?l000Woool00`3o0?ooo`3o000:oooo00<0o`3oooooool0:Oooo`030?l0oooooooo02Woool2
0?l04?ooo`80o`08oooo00<0o`3oool0o`00H?ooo`030?l0oooo0?l001Goool20?l05_ooo`80o`11
oooo00<0003oooooool00_ooo`001oooo`070000oooooooooooo0000oooo000000Koool300003_oo
o`040?l0oooo0?l0oooo0P3o0005oooo0?l00?l0oooo0?l000?oool0103o0?ooo`3o003o00Goool2
0?l02oooo`030?l0oooo0?l000Woool00`3o0?ooo`3o000:oooo00<0o`3oooooool0:Oooo`030?l0
oooooooo02Woool20?l04?ooo`80o`08oooo00<0o`3oool0o`00H?ooo`030?l0oooo0?l001Goool0
0`3o0?ooooooo`0Eoooo0P3o03ooool300001?ooo`001oooo`070000oooooooooooo0000oooo0000
00Koool00`000?ooooooo`0>oooo00@0o`3oool0o`3oool20?l000Goool0o`00o`3oool0o`000ooo
o`040?l0oooo0?l00?l01Oooo`80o`0;oooo00<0o`3oool0o`002Oooo`030?l0oooo0?l000[oool0
0`3o0?ooooooo`0Yoooo00<0o`3oooooool0:Oooo`80o`0@oooo0P3o00Soool00`3o0?ooo`3o001P
oooo00<0o`3oool0o`005Oooo`030?l0oooooooo01Goool20?l0@Oooo`030000oooooooo00;oool0
00Ooool01`000?ooooooooooo`000?ooo`000006oooo00<0003oooooool03_ooo`040?l0oooo0?l0
oooo0P3o0005oooo0?l00?l0oooo0?l000?oool0103o0?ooo`3o003o00Goool20?l02oooo`030?l0
oooo0?l000[oool20?l02_ooo`030?l0oooooooo02Woool00`3o0?ooooooo`0Yoooo0P3o013oool2
0?l02?ooo`030?l0oooo0?l0063oool00`3o0?ooo`3o000Eoooo00<0o`3oooooool05Oooo`80o`11
oooo00<0003oooooool00_ooo`001_ooo`800004oooo00<0003oooooool01Oooo`030000oooooooo
00koool0103o0?ooo`3o0?ooo`80o`001Oooo`3o003o0?ooo`3o0003oooo00@0o`3oool0o`00o`05
oooo0P3o00_oool00`3o0?ooo`3o000:oooo0P3o00[oool00`3o0?ooooooo`0Yoooo00<0o`3ooooo
ool0:Oooo`80o`0@oooo0P3o00Soool00`3o0?ooo`3o001Poooo00<0o`3oool0o`005Oooo`030?l0
oooooooo01Goool20?l0@Oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0>oooo00@0
o`3oool0o`3oool20?l000Goool0o`00o`3oool0o`000oooo`040?l0oooo0?l00?l01Oooo`80o`0;
oooo00<0o`3oool0o`002_ooo`80o`0:oooo00<0o`3oooooool0:Oooo`030?l0oooooooo02Woool2
0?l04?ooo`80o`08oooo00<0o`3oool0o`00H?ooo`030?l0oooo0?l001Goool00`3o0?ooooooo`0E
oooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool03_ooo`030?l0oooo0?l0
00;oool01P3o0?ooo`3o003o0?ooo`3o00?oool0103o0?ooo`3o003o00Goool20?l02oooo`80o`0;
oooo0P3o00[oool00`3o0?ooooooo`1Eoooo0P3o013oool20?l02?ooo`030?l0oooo0?l0063oool0
0`3o0?ooo`3o000Eoooo00<0o`3oooooool05Oooo`80o`11oooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo00koool00`3o0?ooo`3o0002oooo00H0o`3oool0o`00o`3oool0o`03oooo00@0
o`3oool0o`00o`05oooo0P3o00_oool20?l02oooo`80o`0:oooo00<0o`3oooooool0EOooo`80o`0@
oooo00<0o`3oooooool01oooo`030?l0oooo0?l0063oool00`3o0?ooo`3o000Eoooo00<0o`3ooooo
ool05Oooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00koool00`3o0?oo
o`3o0002oooo00H0o`3oool0o`00o`3oool0o`03oooo00@0o`3oool0o`00o`05oooo0P3o00_oool2
0?l02oooo`80o`0:oooo00<0o`3oooooool0EOooo`80o`0@oooo00<0o`3oooooool01oooo`030?l0
oooo0?l0063oool00`3o0?ooo`3o000Eoooo00<0o`3oooooool05Oooo`80o`11oooo00<0003ooooo
ool00_ooo`005?ooo`030000oooooooo00koool00`3o0?ooo`3o0002oooo00H0o`3oool0o`00o`3o
ool0o`03oooo00@0o`3oool0o`00o`05oooo0P3o00_oool20?l02oooo`80o`0:oooo00<0o`3ooooo
ool0EOooo`80o`0@oooo00<0o`3oooooool01oooo`030?l0oooo0?l0063oool00`3o0?ooo`3o000]
oooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool03_ooo`030?l0oooo0?l0
00;oool01P3o0?ooo`3o003o0?ooo`3o00Goool20?l01Oooo`80o`0;oooo0P3o00_oool20?l0Hooo
o`030?l0oooooooo01Soool00`3o0?ooo`3o001Poooo00<0o`3oool0o`00;Oooo`80o`11oooo00<0
003oooooool00_ooo`005?ooo`80000?oooo00<0o`3oool0o`000_ooo`060?l0oooo0?l00?l0oooo
0?l01Oooo`80o`05oooo0P3o00_oool20?l02oooo`80o`1Soooo00<0o`3oooooool06?ooo`<0o`1P
oooo00<0o`3oool0o`00;Oooo`80o`10oooo0P0000Coool001Coool00`000?ooooooo`0>oooo00<0
o`3oool0o`001?ooo`80o`000oooo`3o0?ooo`04oooo0P3o00Goool20?l02oooo`80o`0;oooo0P3o
06?oool00`3o0?ooooooo`0Hoooo0`3o063oool00`3o0?ooo`3o000]oooo0P3o047oool00`000?oo
ooooo`02oooo000Doooo00<0003oooooool03_ooo`030?l0oooo0?l000Coool20?l000?oool0o`3o
ool01?ooo`80o`05oooo0P3o00_oool20?l02oooo`80o`1Soooo00<0o`3oooooool06?ooo`<0o`1P
oooo00<0o`3oool0o`00;Oooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
00koool00`3o0?ooo`3o0004oooo0P3o0003oooo0?l0oooo00Coool20?l01Oooo`80o`0;oooo0P3o
00_oool20?l0Hoooo`030?l0oooooooo01Soool30?l0H?ooo`030?l0oooo0?l002goool20?l0@Ooo
o`030000oooooooo00;oool001Coool00`000?ooooooo`0>oooo00<0o`3oool0o`001?ooo`80o`00
0oooo`3o0?ooo`04oooo0P3o00Goool20?l02oooo`80o`0;oooo0P3o06?oool00`3o0?ooooooo`0H
oooo0`3o063oool00`3o0?ooo`3o000]oooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool03_ooo`030?l0oooo0?l000Goool00`3o0?ooo`3o0005oooo0P3o00Goool20?l02ooo
o`80o`0;oooo0P3o06?oool00`3o0?ooooooo`0Hoooo0`3o063oool00`3o0?ooo`3o000]oooo0P3o
047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool03_ooo`030?l0oooo0?l000Goool0
0`3o0?ooo`3o0005oooo0P3o00Goool20?l02oooo`80o`0;oooo0P3o06?oool00`3o0?ooooooo`0H
oooo0`3o063oool00`3o0?ooo`3o000]oooo0P3o047oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool03_ooo`030?l0oooo0?l000Goool00`3o0?ooo`3o0005oooo0P3o00Goool20?l02ooo
o`80o`0;oooo0P3o06?oool00`3o0?ooooooo`0Hoooo0`3o063oool00`3o0?ooo`3o000]oooo0P3o
047oool00`000?ooooooo`02oooo000Doooo00<0003oooooool03_ooo`030?l0oooo0?l000Goool2
0?l01_ooo`80o`05oooo0P3o00_oool20?l02oooo`80o`1Soooo00<0o`3oooooool06?ooo`<0o`1P
oooo00<0o`3oool0o`00;Oooo`80o`11oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
00koool00`3o0?ooo`3o0005oooo0P3o00Koool20?l01Oooo`80o`0;oooo0P3o00_oool20?l0Hooo
o`030?l0oooooooo01Soool30?l0H?ooo`030?l0oooo0?l002goool20?l0@Oooo`030000oooooooo
00;oool001Coool200003oooo`030?l0oooo0?l000Goool20?l01_ooo`80o`05oooo0P3o00_oool2
0?l02oooo`80o`1Soooo00<0o`3oooooool06?ooo`80o`1Qoooo00<0o`3oool0o`00;_ooo`030?l0
oooooooo03koool200001?ooo`005?ooo`030000oooooooo00koool00`3o0?ooo`3o0005oooo0P3o
00Koool20?l01Oooo`80o`0;oooo0P3o00_oool00`3o0?ooooooo`1Roooo00<0o`3oooooool06Ooo
o`030?l0oooooooo05ooool00`3o0?ooo`3o000^oooo00<0o`3oooooool0?oooo`030000oooooooo
00;oool001Coool00`000?ooooooo`0>oooo00<0o`3oool0o`001Oooo`80o`06oooo0P3o00Goool2
0?l02oooo`80o`0;oooo00<0o`3oooooool0O_ooo`030?l0oooooooo05ooool00`3o0?ooo`3o000^
oooo00<0o`3oooooool0?oooo`030000oooooooo00;oool001Coool00`000?ooooooo`0>oooo00<0
o`3oool0o`001Oooo`80o`06oooo0P3o00Koool00`3o0?ooooooo`09oooo0P3o00_oool00`3o0?oo
ooooo`1noooo00<0o`3oooooool0Goooo`030?l0oooo0?l002koool00`3o0?ooooooo`0ooooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo00koool00`3o0?ooo`3o0005oooo0P3o00Koool2
0?l01_ooo`030?l0oooooooo00Woool20?l02oooo`030?l0oooooooo07koool00`3o0?ooooooo`1O
oooo00<0o`3oool0o`00L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0>oooo00<0
o`3oool0o`001Oooo`80o`06oooo0P3o00Koool00`3o0?ooooooo`09oooo0P3o00_oool00`3o0?oo
ooooo`1noooo00<0o`3oooooool0Goooo`030?l0oooo0?l0073oool00`000?ooooooo`02oooo000D
oooo00<0003oooooool03_ooo`030?l0oooo0?l000Goool20?l01_ooo`80o`06oooo00<0o`3ooooo
ool02Oooo`80o`0;oooo00<0o`3oooooool0O_ooo`030?l0oooooooo05ooool00`3o0?ooo`3o001`
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00koool00`3o0?ooo`3o0005oooo0P3o
00Koool20?l01_ooo`030?l0oooooooo00Woool20?l02oooo`030?l0oooooooo07koool00`3o0?oo
ooooo`1Ooooo00<0o`3oool0o`00L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0>
oooo00<0o`3oool0o`001Oooo`80o`06oooo0P3o00Koool00`3o0?ooooooo`0:oooo00<0o`3ooooo
ool02Oooo`030?l0oooooooo07koool00`3o0?ooooooo`1Ooooo00<0o`3oool0o`00L?ooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0>oooo00<0o`3oool0o`001Oooo`80o`06oooo0P3o
00Koool00`3o0?ooooooo`0:oooo00<0o`3oooooool02Oooo`030?l0oooooooo07koool00`3o0?oo
ooooo`1Ooooo00<0o`3oool0o`00L?ooo`030000oooooooo00;oool001Coool200003oooo`030?l0
oooo0?l000Goool20?l01_ooo`80o`06oooo00<0o`3oooooool02_ooo`030?l0oooooooo00Woool0
0`3o0?ooooooo`3Poooo00<0o`3oool0o`00Koooo`800004oooo000Doooo00<0003oooooool03_oo
o`030?l0oooo0?l000Goool20?l01_ooo`80o`06oooo00<0o`3oooooool02_ooo`030?l0oooooooo
00Woool00`3o0?ooooooo`3Poooo00<0o`3oool0o`00L?ooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0>oooo00<0o`3oool0o`001Oooo`80o`06oooo0P3o00Koool00`3o0?ooooooo`0:
oooo00<0o`3oooooool02Oooo`030?l0oooooooo0>3oool00`3o0?ooo`3o001`oooo00<0003ooooo
ool00_ooo`005?ooo`030000oooooooo00koool00`3o0?ooo`3o0005oooo0P3o00Koool20?l01_oo
o`030?l0oooooooo00[oool00`3o0?ooooooo`09oooo00<0o`3oooooool0h?ooo`030?l0oooo0?l0
073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool03oooo`80o`05oooo0P3o00Koool2
0?l01_ooo`030?l0oooooooo00[oool00`3o0?ooooooo`3/oooo00<0o`3oool0o`00L?ooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0?oooo0P3o00Goool20?l01_ooo`80o`06oooo00<0
o`3oooooool02_ooo`030?l0oooooooo0>coool00`3o0?ooo`3o001`oooo00<0003oooooool00_oo
o`005?ooo`030000oooooooo00ooool20?l01Oooo`80o`06oooo0P3o00Koool00`3o0?ooooooo`0:
oooo00<0o`3oooooool0k?ooo`030?l0oooo0?l0073oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool03oooo`80o`05oooo0P3o00Koool20?l01_ooo`030?l0oooooooo00[oool00`3o0?oo
ooooo`3/oooo00<0o`3oool0o`00L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0?
oooo0P3o00Goool20?l01_ooo`80o`06oooo00<0o`3oooooool02_ooo`030?l0oooooooo0>coool0
0`3o0?ooo`3o001`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00ooool00`3o0?oo
ooooo`04oooo0P3o00Koool20?l04oooo`030?l0oooooooo0>coool00`3o0?ooo`3o001`oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo00ooool00`3o0?ooooooo`04oooo0P3o00Koool2
0?l04oooo`030?l0oooooooo0>coool00`3o0?ooo`3o001`oooo00<0003oooooool00_ooo`005?oo
o`80000@oooo00<0o`3oooooool01?ooo`80o`06oooo0P3o01?oool00`3o0?ooooooo`3/oooo00<0
o`3oool0o`00Koooo`800004oooo000Doooo00<0003oooooool03oooo`030?l0oooooooo00Coool2
0?l01_ooo`80o`0Coooo00<0o`3oooooool0k?ooo`<0o`1`oooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo00ooool00`3o0?ooooooo`04oooo0P3o00Koool20?l04oooo`030?l0oooooooo
0>coool30?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0?oooo00<0o`3ooooo
ool01?ooo`80o`06oooo0P3o01?oool00`3o0?ooooooo`3/oooo0`3o073oool00`000?ooooooo`02
oooo000Doooo00<0003oooooool03oooo`030?l0oooooooo00Coool20?l01_ooo`80o`0Coooo00<0
o`3oooooool0k?ooo`<0o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo00ooool0
0`3o0?ooooooo`04oooo0P3o00Koool20?l04oooo`030?l0oooooooo0>coool30?l0L?ooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0?oooo00<0o`3oooooool01?ooo`80o`06oooo00<0
o`3oooooool04_ooo`030?l0oooooooo0>coool30?l0L?ooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0?oooo00<0o`3oooooool01?ooo`80o`06oooo00<0o`3oooooool0ooooo`;oool3
0?l0L?ooo`030000oooooooo00;oool000Goool500000_ooo`030000oooooooo00Goool00`000?oo
ooooo`0?oooo00<0o`3oooooool01?ooo`80o`06oooo00<0o`3oooooool0ooooo`;oool30?l0L?oo
o`030000oooooooo00;oool000Ooool01`000?ooooooooooo`000?ooo`000006oooo00<0003ooooo
ool03oooo`030?l0oooooooo00Coool20?l01_ooo`030?l0oooooooo0?ooool2oooo0`3o073oool0
0`000?ooooooo`02oooo0007oooo00<0003oooooool00oooo`030000oooooooo00Coool300003ooo
o`030?l0oooooooo00Coool20?l01_ooo`030?l0oooooooo0?ooool2oooo0`3o06koool300001?oo
o`001oooo`040000oooooooooooo0P0000Ooool00`000?ooooooo`0?oooo00<0o`3oooooool01?oo
o`80o`06oooo00<0o`3oooooool0ooooo`;oool30?l0L?ooo`030000oooooooo00;oool000Ooool0
1@000?ooooooooooo`000008oooo00<0003oooooool03oooo`030?l0oooooooo00Coool20?l01_oo
o`030?l0oooooooo0?ooool2oooo0`3o073oool00`000?ooooooo`02oooo0006oooo0P0000?oool3
00001_ooo`030000oooooooo01Koool20?l01_ooo`030?l0oooooooo0?ooool2oooo0`3o073oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`06oooo00<0o`3oooooool0oooo
o`;oool30?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o00Koool0
0`3o0?ooooooo`3ooooo0_ooo`<0o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
01Koool20?l01_ooo`030?l0oooooooo0?ooool2oooo0`3o073oool00`000?ooooooo`02oooo000D
oooo00<0003oooooool05_ooo`80o`06oooo00<0o`3oooooool0ooooo`;oool30?l0L?ooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o00Koool00`3o0?ooooooo`3ooooo0_oo
o`<0o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l01_ooo`030?l0
oooooooo0?ooool2oooo0`3o073oool00`000?ooooooo`02oooo000Doooo0P0001Ooool20?l01_oo
o`030?l0oooooooo0?ooool2oooo0`3o06ooool200001?ooo`005?ooo`030000oooooooo01Koool2
0?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o
0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3o
oooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0oooo
o`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<
oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?oo
o`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool2
0?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o
073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`
oooo00<0003oooooool00_ooo`005?ooo`80000Goooo0P3o0?ooool<oooo0P3o06ooool200001?oo
o`005?ooo`030000oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000D
oooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0
003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0003ooooo
ool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`80000Goooo0P3o
0?ooool<oooo0P3o06ooool200001?ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool2
0?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o
073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool20?l0L?oo
o`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool0
0`000?ooooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000
oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?oo
ooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003ooooo
ool00_ooo`005?ooo`80000Goooo0P3o0?ooool<oooo0P3o06ooool200001?ooo`005?ooo`030000
oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0003ooooo
ool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0F
oooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo00<0003oooooool05_oo
o`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool2
0?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool000Koool300000oooo`030000oooooooo
00Goool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo0006
oooo00<0003oooooool00_ooo`030000oooo000000Koool00`000?ooooooo`0Foooo0P3o0?ooool<
oooo0P3o073oool00`000?ooooooo`02oooo0007oooo00L0003oooooooooool0003oool000001_oo
o`<0000Foooo0P3o0?ooool<oooo0P3o06koool300001?ooo`001oooo`070000oooooooooooo0000
oooo000000Koool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02
oooo0006oooo00<0003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`0Foooo0P3o
0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo0007oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02
oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_oo
o`005?ooo`030000oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000D
oooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?oo
o`030000oooooooo01Koool20?l0ooooo`coool20?l0L?ooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0Foooo0P3o0?ooool<oooo0P3o073oool00`000?ooooooo`02oooo000Doooo0P00
01Ooool20?l0ooooo`coool20?l0Koooo`800004oooo000Doooo00<0003oooooool05_ooo`80o`3o
oooo3?ooo`80o`1`oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0oooo
o`coool20?l0L?ooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<
oooo00<0o`3oooooool0Koooo`030000oooooooo00;oool001Coool00`000?ooooooo`0Foooo0P3o
0?ooool<oooo00<0o`3oooooool0Koooo`030000oooooooo00;oool001Coool00`000?ooooooo`0F
oooo0P3o0?ooool<oooo00<0o`3oooooool0Koooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0Foooo0P3o0?ooool<oooo00<0o`3oooooool0Koooo`030000oooooooo00;oool001Coool0
0`000?ooooooo`0Foooo0P3o0?ooool<oooo00<0o`3oooooool0Koooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo00<0o`3oooooool0Koooo`030000oooooooo
00;oool001Coool00`000?ooooooo`0Foooo0P3o0?ooool<oooo00<0o`3oooooool0Koooo`030000
oooooooo00;oool001Coool200005oooo`80o`3ooooo3?ooo`030?l0oooooooo06koool200001?oo
o`005?ooo`030000oooooooo01Koool20?l0ooooo`coool00`3o0?ooooooo`1_oooo00<0003ooooo
ool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool00`3o0?ooooooo`1_oooo00<0
003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool00`3o0?ooooooo`1_
oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool00`3o0?oo
ooooo`1_oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0ooooo`coool0
0`3o0?ooooooo`1_oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool20?l0oooo
o`coool00`3o0?ooooooo`1_oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo01Koool2
0?l0ooooo`coool00`3o0?ooooooo`1_oooo00<0003oooooool00_ooo`005?ooo`030000oooooooo
01Koool20?l0ooooo`coool00`3o0?ooooooo`1_oooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo01Koool20?l0ooooo`coool00`3o0?ooooooo`1_oooo00<0003oooooool00_ooo`005?oo
o`80000Goooo0P3o0?ooool<oooo00<0o`3oooooool0K_ooo`800004oooo000Doooo00<0003ooooo
ool05_ooo`80o`3ooooo3?ooo`030?l0oooooooo06ooool00`000?ooooooo`02oooo000Doooo00<0
003oooooool05_ooo`80o`3ooooo3?ooo`030?l0oooooooo06ooool00`000?ooooooo`02oooo000D
oooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`030?l0oooooooo06ooool00`000?ooooooo`02
oooo000Doooo00<0003oooooool05_ooo`80o`3ooooo3?ooo`030?l0oooooooo06ooool00`000?oo
ooooo`02oooo000Doooo00<0003oooooool05_ooo`80o`3oooooO_ooo`030000oooooooo00;oool0
01Coool00`000?ooooooo`0Foooo0P3o0?oooomnoooo00<0003oooooool00_ooo`005?ooo`030000
oooooooo01Koool00`3o0?ooooooo`3oooooOOooo`030000oooooooo00;oool001Coool00`000?oo
ooooo`0Foooo00<0o`3oooooool0oooooggoool00`000?ooooooo`02oooo000Doooo00<0003ooooo
ool0oooooiKoool00`000?ooooooo`02oooo000Doooo00<0003oooooool0oooooiKoool00`000?oo
ooooo`02oooo000Doooo0P000?oooonFoooo0P0000Coool001Coool00`000?ooooooo`06oooo00<0
003oooooool0Hoooo`030000oooooooo06;oool00`000?ooooooo`1Roooo00<0003oooooool0G?oo
o`030000oooooooo00;oool001Coool00`000?ooooooo`06oooo00<0003oooooool04_ooo`030000
oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0B
oooo00<0003oooooool04Oooo`030000oooooooo017oool00`000?ooooooo`0Boooo00<0003ooooo
ool04Oooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04_ooo`030000
oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000oooooooo00_oool0
0`000?ooooooo`02oooo000Dooooo`0009X00004oooo0000\
\>"],
  ImageRangeCache->{{{0, 432}, {266.438, 0}} -> {-147.394, -1.99243, 4.93518, 
  0.0990244}}]
}, Open  ]],

Cell["Parametr segmentacji", "MathCaption"],

Cell[BoxData[
    \(\(SegMeas = \@\(sfa\^2 + sft\^2\); \)\)], "Input",
  CellLabel->"In[27]:="],

Cell["Miara segmentacji", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[SegMeas, PlotRange -> {0, 2}, \ PlotJoined -> True, 
      PlotStyle -> RGBColor[1, 0, 0], Frame -> True]; \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000496032 0 0.309017 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.27183 -0.0125 -9 -9 ]
[.27183 -0.0125 9 0 ]
[.51984 -0.0125 -12 -9 ]
[.51984 -0.0125 12 0 ]
[.76786 -0.0125 -12 -9 ]
[.76786 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.27183 0 m
.27183 .00625 L
s
[(500)] .27183 -0.0125 0 1 Mshowa
.51984 0 m
.51984 .00625 L
s
[(1000)] .51984 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(1500)] .76786 -0.0125 0 1 Mshowa
.125 Mabswid
.07341 0 m
.07341 .00375 L
s
.12302 0 m
.12302 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.37103 0 m
.37103 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.56944 0 m
.56944 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66865 0 m
.66865 .00375 L
s
.71825 0 m
.71825 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.86706 0 m
.86706 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.96627 0 m
.96627 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.25)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.75)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.27183 .61178 m
.27183 .61803 L
s
.51984 .61178 m
.51984 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.125 Mabswid
.07341 .61428 m
.07341 .61803 L
s
.12302 .61428 m
.12302 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.37103 .61428 m
.37103 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.56944 .61428 m
.56944 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66865 .61428 m
.66865 .61803 L
s
.71825 .61428 m
.71825 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.86706 .61428 m
.86706 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.96627 .61428 m
.96627 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02431 .00043 m
.0248 .0003 L
.0253 .0011 L
.02579 .00209 L
.02629 .00216 L
.02679 .00151 L
.02728 .00068 L
.02778 .00088 L
.02827 .00153 L
.02877 .00329 L
.02927 .00337 L
.02976 .00211 L
.03026 .03035 L
.03075 .0805 L
.03125 .37899 L
s
.03125 .37899 m
.03131 .61803 L
s
.10313 .61803 m
.10317 .58951 L
s
.10317 .58951 m
.1034 .61803 L
s
.11553 .61803 m
.11558 .60591 L
.11607 .57024 L
s
.11607 .57024 m
.11633 .61803 L
s
.12046 .61803 m
.12054 .59597 L
.12103 .55508 L
.12153 .53971 L
.12202 .54585 L
.12252 .55377 L
.12302 .51915 L
.12351 .44269 L
.12401 .36131 L
.1245 .28432 L
.125 .21079 L
.1255 .14151 L
.12599 .10194 L
.12649 .10071 L
.12698 .12208 L
.12748 .1479 L
.12798 .13656 L
.12847 .28412 L
s
.12847 .28412 m
.12858 .61803 L
s
.13839 .61803 m
.13839 .61551 L
.13889 .48344 L
.13938 .37204 L
.13988 .30843 L
.14038 .30879 L
.14087 .32141 L
.14137 .30138 L
.14187 .25252 L
.14236 .20777 L
.14286 .17059 L
.14335 .16367 L
.14385 .15864 L
.14435 .13868 L
.14484 .11546 L
.14534 .08839 L
.14583 .36602 L
s
.14583 .36602 m
.14604 .61803 L
s
.15461 .61803 m
.15476 .56391 L
.15526 .49835 L
.15575 .51969 L
.15625 .53225 L
.15675 .49198 L
.15724 .42928 L
.15774 .41473 L
.15823 .42312 L
.15873 .38209 L
.15923 .33535 L
.15972 .30084 L
.16022 .35512 L
s
.16022 .35512 m
.16042 .61803 L
s
.16938 .61803 m
.16964 .37545 L
.17014 .24073 L
.17063 .35862 L
.17113 .53582 L
.17163 .54862 L
.17212 .47943 L
.17262 .42595 L
.17312 .40012 L
.17361 .47478 L
.17411 .56524 L
.1746 .3839 L
.1751 .55472 L
s
.1751 .55472 m
.17527 .61803 L
s
.18136 .61803 m
.18155 .53266 L
.18204 .38775 L
.18254 .34154 L
.18304 .35656 L
.18353 .38915 L
.18403 .3731 L
.18452 .29782 L
.18502 .21376 L
.18552 .14718 L
.18601 .12734 L
.18651 .12914 L
.187 .15662 L
.1875 .18373 L
.188 .20932 L
.18849 .16102 L
.18899 .10671 L
.18948 .42379 L
s
.18948 .42379 m
.18958 .61803 L
s
.19676 .61803 m
.19692 .54706 L
.19742 .26343 L
.19792 .1435 L
.19841 .12215 L
.19891 .10392 L
.1994 .10127 L
.1999 .11023 L
.2004 .12223 L
.20089 .14587 L
.20139 .15878 L
.20188 .15042 L
.20238 .12271 L
.20288 .16611 L
.20337 .36686 L
s
.20337 .36686 m
.20381 .61803 L
s
.20937 .61803 m
.20982 .3702 L
.21032 .14283 L
.21081 .14082 L
.21131 .19884 L
.21181 .20838 L
.2123 .1935 L
.2128 .19209 L
.21329 .19942 L
.21379 .23752 L
.21429 .2819 L
.21478 .31215 L
.21528 .28473 L
.21577 .25218 L
.21627 .29237 L
.21677 .37627 L
s
.21677 .37627 m
.21699 .61803 L
s
.22328 .61803 m
.22371 .54213 L
.22421 .42852 L
.2247 .32751 L
.2252 .2399 L
.22569 .18709 L
.22619 .17062 L
.22669 .15599 L
.22718 .13795 L
.22768 .14451 L
.22817 .16285 L
.22867 .1851 L
.22917 .19939 L
.22966 .15313 L
.23016 .21814 L
.23065 .58934 L
s
.23065 .58934 m
.23068 .61803 L
s
.23656 .61803 m
.23661 .58628 L
.2371 .30695 L
.2376 .15434 L
.2381 .2072 L
.23859 .32414 L
.23909 .31004 L
.23958 .23132 L
.24008 .15936 L
.24058 .11145 L
.24107 .11295 L
.24157 .1255 L
.24206 .12272 L
.24256 .13593 L
.24306 .1044 L
.24355 .31113 L
s
.24355 .31113 m
.24376 .61803 L
s
.25257 .61803 m
.25298 .52921 L
.25347 .30435 L
.25397 .24861 L
.25446 .25046 L
.25496 .23096 L
.25546 .20167 L
.25595 .15763 L
.25645 .13594 L
.25694 .21273 L
.25744 .50323 L
s
.25744 .50323 m
.25768 .61803 L
s
.26343 .61803 m
.26389 .31931 L
.26438 .13804 L
.26488 .13885 L
.26538 .19465 L
.26587 .20086 L
.26637 .17472 L
.26687 .16974 L
.26736 .18062 L
.26786 .16724 L
.26835 .13366 L
.26885 .10312 L
.26935 .0721 L
.26984 .05386 L
.27034 .06646 L
.27083 .11008 L
.27133 .28216 L
.27183 .51904 L
s
.27183 .51904 m
.27204 .61803 L
s
.2768 .61803 m
.27728 .51955 L
.27778 .41611 L
.27827 .36398 L
.27877 .40041 L
.27927 .38528 L
.27976 .34515 L
.28026 .27297 L
.28075 .17498 L
.28125 .10596 L
.28175 .13712 L
.28224 .17182 L
.28274 .18892 L
.28323 .31538 L
s
.28323 .31538 m
.28353 .61803 L
s
.28965 .61803 m
.28968 .60399 L
.29018 .38782 L
.29067 .23305 L
.29117 .19842 L
.29167 .22859 L
.29216 .22902 L
.29266 .21246 L
.29315 .19992 L
.29365 .18757 L
.29415 .17081 L
.29464 .16357 L
.29514 .13957 L
.29563 .10922 L
.29613 .07161 L
.29663 .05955 L
.29712 .2623 L
s
.29712 .2623 m
.29733 .61803 L
s
.30398 .61803 m
.30407 .57467 L
.30456 .373 L
.30506 .28147 L
.30556 .22458 L
.30605 .20642 L
.30655 .19446 L
.30704 .17681 L
.30754 .14453 L
.30804 .13092 L
.30853 .13722 L
.30903 .13164 L
.30952 .1376 L
.31002 .23355 L
.31052 .39634 L
.31101 .51245 L
.31151 .54562 L
.312 .61203 L
s
.312 .61203 m
.31203 .61803 L
s
.31709 .61803 m
.31746 .37814 L
.31796 .2183 L
.31845 .17611 L
.31895 .21025 L
.31944 .24523 L
.31994 .18307 L
.32044 .13958 L
.32093 .16314 L
.32143 .22815 L
.32192 .27474 L
.32242 .2382 L
.32292 .2071 L
.32341 .17983 L
.32391 .11685 L
.3244 .07157 L
.3249 .08003 L
.3254 .19424 L
.32589 .56608 L
s
.32589 .56608 m
.32602 .61803 L
s
.3272 .61803 m
.32738 .57388 L
.32788 .5165 L
.32837 .51998 L
.32887 .46182 L
.32937 .40626 L
.32986 .38429 L
.33036 .35759 L
.33085 .32754 L
.33135 .29848 L
.33185 .24677 L
.33234 .272 L
.33284 .37227 L
.33333 .42984 L
.33383 .38443 L
.33433 .32814 L
.33482 .26817 L
.33532 .24371 L
.33581 .25291 L
.33631 .2437 L
.33681 .19391 L
.3373 .11749 L
.3378 .27785 L
s
.3378 .27785 m
.33809 .61803 L
s
.34416 .61803 m
.34425 .55139 L
.34474 .33318 L
.34524 .33243 L
.34573 .41108 L
.34623 .40967 L
.34673 .3348 L
.34722 .23462 L
.34772 .12673 L
.34821 .06198 L
.34871 .04319 L
.34921 .03607 L
.3497 .0474 L
.3502 .06443 L
.35069 .08101 L
.35119 .08817 L
.35169 .14144 L
.35218 .30956 L
s
.35218 .30956 m
.3524 .61803 L
s
.36043 .61803 m
.36062 .48819 L
.36111 .18738 L
.36161 .11489 L
.3621 .13857 L
.3626 .13304 L
.3631 .13656 L
.36359 .16508 L
.36409 .18613 L
.36458 .21154 L
.36508 .44485 L
s
.36508 .44485 m
.36524 .61803 L
s
.37195 .61803 m
.37202 .55243 L
.37252 .27119 L
.37302 .17996 L
.37351 .21686 L
.37401 .25269 L
.3745 .22061 L
.375 .14082 L
.3755 .09633 L
.37599 .1164 L
.37649 .1646 L
.37698 .18639 L
.37748 .14483 L
.37798 .12844 L
.37847 .13683 L
.37897 .15301 L
.37946 .2171 L
.37996 .40576 L
s
.37996 .40576 m
.38022 .61803 L
s
.38711 .61803 m
.3874 .50344 L
.3879 .40841 L
.38839 .41236 L
.38889 .42936 L
.38938 .35315 L
.38988 .28433 L
.39038 .20102 L
.39087 .16142 L
.39137 .13517 L
.39187 .22341 L
.39236 .45967 L
s
.39236 .45967 m
.39258 .61803 L
s
.39877 .61803 m
.39881 .60224 L
.39931 .38855 L
.3998 .28768 L
.4003 .30656 L
.40079 .32379 L
.40129 .2805 L
.40179 .25932 L
.40228 .19148 L
.40278 .11229 L
.40327 .05703 L
.40377 .03264 L
.40427 .0372 L
.40476 .0533 L
.40526 .04967 L
.40575 .05031 L
.40625 .13524 L
.40675 .25278 L
.40724 .60882 L
s
.40724 .60882 m
.40725 .61803 L
s
.41303 .61803 m
.41319 .50318 L
.41369 .43671 L
s
.41369 .43671 m
.41397 .61803 L
s
.416 .61803 m
.41617 .59598 L
s
.41617 .59598 m
.41622 .61803 L
s
.41814 .61803 m
.41815 .61302 L
.41865 .35917 L
.41915 .23877 L
.41964 .29135 L
.42014 .49775 L
s
.42014 .49775 m
.42022 .61803 L
s
.42742 .61803 m
.42758 .50389 L
.42808 .37084 L
.42857 .55048 L
s
.42857 .55048 m
.42864 .61803 L
s
.43151 .61803 m
.43155 .61162 L
s
.43155 .61162 m
.43162 .61803 L
s
.43531 .61803 m
.43552 .5073 L
.43601 .44678 L
s
.43601 .44678 m
.43609 .61803 L
s
.44098 .61803 m
.44147 .50995 L
.44196 .50357 L
.44246 .53734 L
.44296 .42678 L
.44345 .19322 L
.44395 .15214 L
.44444 .22534 L
.44494 .24804 L
.44544 .11209 L
.44593 .11005 L
.44643 .15683 L
.44692 .24536 L
.44742 .38943 L
s
.44742 .38943 m
.44779 .61803 L
s
.45818 .61803 m
.45833 .53484 L
.45883 .40815 L
.45933 .41779 L
.45982 .55511 L
s
.45982 .55511 m
.46009 .61803 L
s
.46146 .61803 m
.46181 .5625 L
.4623 .45768 L
.4628 .54736 L
.46329 .57958 L
.46379 .51206 L
.46429 .60054 L
s
.46429 .60054 m
.46437 .61803 L
s
.46587 .61803 m
.46627 .51644 L
.46677 .48386 L
.46726 .50876 L
.46776 .60452 L
.46825 .59991 L
.46875 .52776 L
.46925 .47213 L
.46974 .36118 L
.47024 .23465 L
.47073 .17809 L
.47123 .14029 L
.47173 .20416 L
.47222 .30057 L
.47272 .28584 L
.47321 .14943 L
.47371 .13632 L
.47421 .12463 L
.4747 .12351 L
.4752 .23379 L
s
.4752 .23379 m
.47542 .61803 L
s
.48503 .61803 m
.48512 .56242 L
.48562 .34267 L
.48611 .24399 L
.48661 .35492 L
.4871 .49795 L
.4876 .48668 L
.4881 .38756 L
.48859 .23315 L
.48909 .29209 L
.48958 .49482 L
.49008 .48036 L
.49058 .49212 L
s
.49058 .49212 m
.49079 .61803 L
s
.496 .61803 m
.49603 .59465 L
.49653 .38564 L
.49702 .36101 L
.49752 .35497 L
.49802 .28558 L
.49851 .16803 L
.49901 .15385 L
.4995 .23592 L
.5 .34282 L
.5005 .37501 L
.50099 .34388 L
.50149 .26665 L
.50198 .25643 L
.50248 .55871 L
s
.50248 .55871 m
.50258 .61803 L
s
.50519 .61803 m
.50546 .48607 L
.50595 .40087 L
.50645 .42209 L
.50694 .36725 L
.50744 .26844 L
.50794 .24173 L
.50843 .28383 L
.50893 .26511 L
.50942 .20807 L
.50992 .20701 L
.51042 .20293 L
.51091 .17465 L
.51141 .15762 L
.5119 .13368 L
.5124 .10056 L
.5129 .0896 L
.51339 .04986 L
.51389 .05945 L
.51438 .08374 L
.51488 .09039 L
.51538 .05665 L
.51587 .11088 L
.51637 .17516 L
.51687 .20682 L
.51736 .33519 L
.51786 .46641 L
.51835 .48117 L
.51885 .49895 L
s
.51885 .49895 m
.51925 .61803 L
s
.52818 .61803 m
.52827 .59939 L
.52877 .47084 L
.52927 .53655 L
s
.52927 .53655 m
.52933 .61803 L
s
.53596 .61803 m
.53621 .5924 L
s
.53621 .5924 m
.5364 .61803 L
s
.53708 .61803 m
.5372 .60415 L
s
.5372 .60415 m
.53739 .61803 L
s
.5402 .61803 m
.54067 .33507 L
.54117 .30569 L
.54167 .26285 L
.54216 .2152 L
.54266 .25732 L
.54315 .25759 L
.54365 .32874 L
.54415 .29376 L
.54464 .32673 L
.54514 .39664 L
.54563 .23418 L
.54613 .18713 L
.54663 .30532 L
.54712 .49732 L
.54762 .54965 L
s
.54762 .54965 m
.54778 .61803 L
s
.55095 .61803 m
.55109 .53254 L
.55159 .40713 L
.55208 .33771 L
.55258 .30111 L
.55308 .30663 L
.55357 .24068 L
.55407 .11002 L
.55456 .10977 L
.55506 .10112 L
.55556 .12225 L
.55605 .15343 L
.55655 .25047 L
.55704 .27346 L
.55754 .29882 L
.55804 .20637 L
.55853 .14629 L
.55903 .13066 L
.55952 .18262 L
.56002 .21128 L
.56052 .12874 L
.56101 .17017 L
.56151 .26049 L
.562 .28766 L
.5625 .35431 L
.563 .34979 L
.56349 .32509 L
.56399 .35485 L
.56448 .33699 L
.56498 .39269 L
.56548 .45778 L
.56597 .38143 L
.56647 .27959 L
.56696 .21304 L
.56746 .21415 L
.56796 .20232 L
.56845 .09902 L
.56895 .1016 L
.56944 .08758 L
.56994 .08972 L
.57044 .13195 L
.57093 .19482 L
.57143 .20726 L
.57192 .20478 L
.57242 .20034 L
.57292 .20891 L
.57341 .18479 L
.57391 .16908 L
.5744 .16418 L
.5749 .16304 L
Mistroke
.5754 .2487 L
.57589 .26656 L
.57639 .23989 L
.57688 .20008 L
.57738 .17638 L
.57788 .15374 L
.57837 .10205 L
.57887 .07108 L
.57937 .09238 L
.57986 .09071 L
.58036 .08845 L
.58085 .10493 L
.58135 .08057 L
.58185 .12494 L
.58234 .46934 L
Mfstroke
.58234 .46934 m
.58244 .61803 L
s
.59174 .61803 m
.59177 .60306 L
.59226 .56202 L
.59276 .60865 L
s
.59276 .60865 m
.5928 .61803 L
s
.59411 .61803 m
.59425 .55945 L
.59474 .32641 L
.59524 .24954 L
.59573 .24444 L
.59623 .26066 L
.59673 .34148 L
.59722 .33939 L
.59772 .27802 L
.59821 .28962 L
.59871 .27639 L
.59921 .28917 L
.5997 .31358 L
.6002 .40154 L
.60069 .43349 L
.60119 .42144 L
.60169 .4651 L
.60218 .45942 L
.60268 .34046 L
.60317 .16633 L
.60367 .06543 L
.60417 .05972 L
.60466 .05813 L
.60516 .06323 L
.60565 .06378 L
.60615 .06603 L
.60665 .08777 L
.60714 .12288 L
.60764 .16252 L
.60813 .11567 L
.60863 .1604 L
.60913 .34474 L
.60962 .49584 L
.61012 .51109 L
.61062 .4706 L
.61111 .47283 L
.61161 .42668 L
.6121 .34354 L
.6126 .31901 L
.6131 .30987 L
.61359 .25985 L
.61409 .25012 L
.61458 .29052 L
.61508 .24184 L
.61558 .14326 L
.61607 .13759 L
.61657 .15159 L
.61706 .10886 L
.61756 .08864 L
.61806 .1145 L
Mistroke
.61855 .11333 L
.61905 .07523 L
.61954 .05034 L
.62004 .03967 L
.62054 .04102 L
.62103 .04905 L
.62153 .04488 L
.62202 .05566 L
.62252 .08756 L
.62302 .13513 L
.62351 .22242 L
.62401 .55051 L
Mfstroke
.62401 .55051 m
.62415 .61803 L
s
.6291 .61803 m
.62946 .42367 L
.62996 .2129 L
.63046 .11988 L
.63095 .11119 L
.63145 .15008 L
.63194 .18107 L
.63244 .18432 L
.63294 .17588 L
.63343 .13307 L
.63393 .08064 L
.63442 .06166 L
.63492 .06828 L
.63542 .06894 L
.63591 .12375 L
.63641 .36794 L
.6369 .52567 L
.6374 .58701 L
s
.6374 .58701 m
.63755 .61803 L
s
.64288 .61803 m
.64335 .3589 L
.64385 .24602 L
.64435 .28091 L
.64484 .34697 L
.64534 .33663 L
.64583 .27068 L
.64633 .23327 L
.64683 .26363 L
.64732 .31374 L
.64782 .31501 L
.64831 .28653 L
.64881 .29852 L
.64931 .31894 L
.6498 .55274 L
s
.6498 .55274 m
.64996 .61803 L
s
.65382 .61803 m
.65427 .54317 L
.65476 .49443 L
.65526 .5105 L
.65575 .48874 L
.65625 .45331 L
.65675 .4216 L
.65724 .34429 L
.65774 .27805 L
.65823 .24918 L
.65873 .2217 L
.65923 .19036 L
.65972 .16363 L
.66022 .14444 L
.66071 .13477 L
.66121 .14308 L
.66171 .1326 L
.6622 .13091 L
.6627 .15016 L
.66319 .23494 L
s
.66319 .23494 m
.66356 .61803 L
s
.67205 .61803 m
.67212 .60059 L
.67262 .31325 L
.67312 .16532 L
.67361 .19086 L
.67411 .24613 L
.6746 .23665 L
.6751 .22155 L
.6756 .22619 L
.67609 .23683 L
.67659 .26691 L
.67708 .33807 L
.67758 .44836 L
s
.67758 .44836 m
.67778 .61803 L
s
.68603 .61803 m
.68651 .29583 L
.687 .20511 L
.6875 .28926 L
.688 .50749 L
s
.688 .50749 m
.68818 .61803 L
s
.69655 .61803 m
.69692 .33266 L
.69742 .23966 L
.69792 .36096 L
.69841 .60534 L
s
.69841 .60534 m
.69844 .61803 L
s
.69983 .61803 m
.6999 .59546 L
s
.6999 .59546 m
.70019 .61803 L
s
.70096 .61803 m
.70139 .50085 L
.70188 .37566 L
.70238 .33916 L
.70288 .36819 L
.70337 .44659 L
s
.70337 .44659 m
.7037 .61803 L
s
.71336 .61803 m
.71379 .35458 L
.71429 .22778 L
.71478 .19747 L
.71528 .17512 L
.71577 .13789 L
.71627 .14261 L
.71677 .55391 L
s
.71677 .55391 m
.71679 .61803 L
s
.7269 .61803 m
.72718 .40206 L
.72768 .21548 L
.72817 .10906 L
.72867 .08985 L
.72917 .11085 L
.72966 .19176 L
.73016 .29163 L
.73065 .33519 L
.73115 .19482 L
.73165 .22199 L
.73214 .34245 L
s
.73214 .34245 m
.73243 .61803 L
s
.73628 .61803 m
.73661 .36269 L
.7371 .15501 L
.7376 .09548 L
.7381 .15757 L
.73859 .40072 L
s
.73859 .40072 m
.73882 .61803 L
s
.74031 .61803 m
.74058 .51624 L
.74107 .50118 L
.74157 .60273 L
s
.74157 .60273 m
.74161 .61803 L
s
.74445 .61803 m
.74454 .58986 L
.74504 .33405 L
.74554 .30406 L
s
.74554 .30406 m
.74595 .61803 L
s
.74805 .61803 m
.74851 .55242 L
.74901 .52262 L
.7495 .48303 L
.75 .43467 L
.7505 .36547 L
.75099 .33784 L
.75149 .24571 L
.75198 .31432 L
.75248 .27049 L
.75298 .24552 L
.75347 .18459 L
.75397 .16003 L
.75446 .16431 L
.75496 .13963 L
.75546 .12231 L
.75595 .11333 L
.75645 .07927 L
.75694 .05704 L
.75744 .06116 L
.75794 .10195 L
.75843 .07361 L
.75893 .16353 L
.75942 .44403 L
s
.75942 .44403 m
.75971 .61803 L
s
.7658 .61803 m
.76587 .56687 L
.76637 .40885 L
.76687 .44888 L
.76736 .49185 L
.76786 .44274 L
.76835 .31466 L
.76885 .1768 L
.76935 .07385 L
.76984 .04611 L
.77034 .06418 L
.77083 .11047 L
.77133 .16566 L
.77183 .18017 L
.77232 .17433 L
.77282 .19991 L
.77331 .3988 L
s
.77331 .3988 m
.77348 .61803 L
s
.77949 .61803 m
.77976 .36976 L
.78026 .44832 L
.78075 .54885 L
.78125 .50659 L
.78175 .36791 L
.78224 .25127 L
.78274 .16724 L
.78323 .15719 L
.78373 .19592 L
.78423 .20921 L
.78472 .26358 L
.78522 .3748 L
.78571 .4238 L
.78621 .36945 L
.78671 .28564 L
.7872 .18855 L
.7877 .19175 L
.78819 .32681 L
s
.78819 .32681 m
.78862 .61803 L
s
.7915 .61803 m
.79167 .52955 L
.79216 .33141 L
.79266 .21998 L
.79315 .16409 L
.79365 .13485 L
.79415 .16363 L
.79464 .34232 L
.79514 .58989 L
.79563 .61781 L
.79613 .47365 L
.79663 .32802 L
.79712 .30803 L
.79762 .34354 L
.79812 .3712 L
.79861 .33716 L
.79911 .31386 L
.7996 .28296 L
.8001 .24825 L
.8006 .22692 L
.80109 .23597 L
.80159 .22965 L
.80208 .42902 L
.80258 .54826 L
.80308 .45435 L
.80357 .36831 L
.80407 .30224 L
.80456 .28864 L
.80506 .27811 L
.80556 .25755 L
.80605 .23109 L
.80655 .19758 L
.80704 .14105 L
.80754 .20929 L
.80804 .20984 L
.80853 .16329 L
.80903 .11453 L
.80952 .10895 L
.81002 .11344 L
.81052 .10158 L
.81101 .07038 L
.81151 .04752 L
.812 .05375 L
.8125 .06455 L
.813 .0493 L
.81349 .0554 L
.81399 .06448 L
.81448 .05185 L
.81498 .05636 L
.81548 .08502 L
Mistroke
.81597 .15228 L
.81647 .33904 L
.81696 .61166 L
Mfstroke
.81696 .61166 m
.81698 .61803 L
s
.82148 .61803 m
.82192 .46107 L
.82242 .34681 L
.82292 .3256 L
.82341 .3838 L
.82391 .43453 L
.8244 .3825 L
.8249 .26517 L
.8254 .16145 L
.82589 .10248 L
.82639 .10778 L
.82688 .12388 L
.82738 .11651 L
.82788 .12001 L
.82837 .14413 L
.82887 .17602 L
.82937 .18883 L
.82986 .17181 L
.83036 .14258 L
.83085 .11364 L
.83135 .09067 L
.83185 .07566 L
.83234 .06908 L
.83284 .27764 L
s
.83284 .27764 m
.83302 .61803 L
s
.84018 .61803 m
.84028 .55596 L
.84077 .43767 L
.84127 .37922 L
.84177 .25929 L
.84226 .19268 L
.84276 .22362 L
.84325 .2981 L
.84375 .30725 L
.84425 .2527 L
.84474 .21566 L
.84524 .18543 L
.84573 .13593 L
.84623 .10453 L
.84673 .10072 L
.84722 .1048 L
.84772 .10249 L
.84821 .11967 L
.84871 .18379 L
.84921 .24571 L
.8497 .25021 L
.8502 .22907 L
.85069 .19733 L
.85119 .16227 L
.85169 .115 L
.85218 .06675 L
.85268 .06937 L
.85317 .08914 L
.85367 .09456 L
.85417 .08929 L
.85466 .0936 L
.85516 .11127 L
.85565 .12006 L
.85615 .10652 L
.85665 .08249 L
.85714 .07093 L
.85764 .06756 L
.85813 .0687 L
.85863 .08611 L
.85913 .1117 L
.85962 .12602 L
.86012 .11802 L
.86062 .1021 L
.86111 .08641 L
.86161 .07004 L
.8621 .05453 L
.8626 .05012 L
.8631 .04807 L
.86359 .04063 L
.86409 .04502 L
Mistroke
.86458 .06155 L
.86508 .08092 L
.86558 .08653 L
.86607 .08144 L
.86657 .07649 L
.86706 .07037 L
.86756 .05923 L
.86806 .04191 L
.86855 .05284 L
.86905 .09556 L
.86954 .19878 L
.87004 .42715 L
Mfstroke
.87004 .42715 m
.87033 .61803 L
s
.87484 .61803 m
.875 .58586 L
.8755 .48427 L
.87599 .41272 L
.87649 .38035 L
.87698 .37879 L
.87748 .37198 L
.87798 .32378 L
.87847 .2857 L
.87897 .26302 L
.87946 .23114 L
.87996 .1881 L
.88046 .17159 L
.88095 .18022 L
.88145 .19357 L
.88194 .20262 L
.88244 .19136 L
.88294 .16293 L
.88343 .12483 L
.88393 .08355 L
.88442 .06032 L
.88492 .06456 L
.88542 .07415 L
.88591 .07962 L
.88641 .09202 L
.8869 .10918 L
.8874 .11521 L
.8879 .10907 L
.88839 .09757 L
.88889 .08426 L
.88938 .07692 L
.88988 .07554 L
.89038 .07435 L
.89087 .07075 L
.89137 .06588 L
.89187 .05925 L
.89236 .05216 L
.89286 .05024 L
.89335 .05306 L
.89385 .05784 L
.89435 .06045 L
.89484 .06573 L
.89534 .07419 L
.89583 .07803 L
.89633 .07266 L
.89683 .06195 L
.89732 .04998 L
.89782 .04218 L
.89831 .04157 L
.89881 .04589 L
Mistroke
.89931 .04935 L
.8998 .04883 L
.9003 .04333 L
.90079 .0351 L
.90129 .03101 L
.90179 .03193 L
.90228 .03168 L
.90278 .02835 L
.90327 .02267 L
.90377 .01815 L
.90427 .01488 L
.90476 .01373 L
.90526 .01488 L
.90575 .01481 L
.90625 .01817 L
.90675 .02496 L
.90724 .02767 L
.90774 .02515 L
.90823 .02184 L
.90873 .02198 L
.90923 .02279 L
.90972 .02309 L
.91022 .02241 L
.91071 .02159 L
.91121 .02143 L
.91171 .02236 L
.9122 .02343 L
.9127 .02439 L
.91319 .02381 L
.91369 .02338 L
.91419 .02266 L
.91468 .02122 L
.91518 .01925 L
.91567 .01697 L
.91617 .01571 L
.91667 .01719 L
.91716 .01717 L
.91766 .01458 L
.91815 .01189 L
.91865 .00927 L
.91915 .00971 L
.91964 .01254 L
.92014 .01558 L
.92063 .017 L
.92113 .01637 L
.92163 .01474 L
.92212 .01356 L
.92262 .01282 L
.92312 .01277 L
.92361 .01216 L
Mistroke
.92411 .01165 L
.9246 .01243 L
.9251 .01276 L
.9256 .01389 L
.92609 .01727 L
.92659 .01981 L
.92708 .01987 L
.92758 .01917 L
.92808 .01797 L
.92857 .01696 L
.92907 .01511 L
.92956 .01351 L
.93006 .0113 L
.93056 .01092 L
.93105 .01126 L
.93155 .00981 L
.93204 .0087 L
.93254 .01039 L
.93304 .0111 L
.93353 .00924 L
.93403 .00612 L
.93452 .00728 L
.93502 .00932 L
.93552 .0094 L
.93601 .00824 L
.93651 .00778 L
.937 .0094 L
.9375 .01118 L
.938 .01236 L
.93849 .01357 L
.93899 .01341 L
.93948 .01149 L
.93998 .01043 L
.94048 .00997 L
.94097 .00846 L
.94147 .00591 L
.94196 .00588 L
.94246 .00705 L
.94296 .00726 L
.94345 .00666 L
.94395 .00646 L
.94444 .00675 L
.94494 .00721 L
.94544 .00693 L
.94593 .0064 L
.94643 .0069 L
.94692 .00774 L
.94742 .00672 L
.94792 .00561 L
.94841 .00608 L
Mistroke
.94891 .00517 L
.9494 .00437 L
.9499 .00456 L
.9504 .00452 L
.95089 .00472 L
.95139 .0051 L
.95188 .00644 L
.95238 .00804 L
.95288 .0072 L
.95337 .00576 L
.95387 .00726 L
.95437 .00738 L
.95486 .00696 L
.95536 .00544 L
.95585 .00363 L
.95635 .00358 L
.95685 .00459 L
.95734 .00483 L
.95784 .00447 L
.95833 .00384 L
.95883 .00359 L
.95933 .00474 L
.95982 .00749 L
.96032 .00665 L
.96081 .00512 L
.96131 .00412 L
.96181 .00377 L
.9623 .00384 L
.9628 .00613 L
.96329 .00652 L
.96379 .00507 L
.96429 .005 L
.96478 .00705 L
.96528 .00756 L
.96577 .00795 L
.96627 .00712 L
.96677 .0073 L
.96726 .00733 L
.96776 .00587 L
.96825 .00593 L
.96875 .00509 L
.96925 .00525 L
.96974 .00513 L
.97024 .00431 L
.97073 .00278 L
.97123 .00271 L
.97173 .00257 L
.97222 .00288 L
.97272 .00268 L
.97321 .00238 L
Mistroke
.97371 .00188 L
.97421 .00269 L
.9747 .00289 L
.9752 .00419 L
.97569 .00503 L
.97619 .00491 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{426, 263.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Z00011aP00`40o`000?l0003ooooooj_oool0
02Koool00`000?ooooooo`1Joooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`1@oooo1@0000;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
04koool500000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0E?oo
o`009Oooo`030000oooo000005[oool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005?oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo0000057oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000005Goool002Goool00`000?ooo`00001Loooo00H0003oooooool0003oool00002oooo00<0
003oool00000Doooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0
003oool00000DOooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`0000;oool00`000?oo
o`00001Eoooo000Uoooo00<0003oool00000F_ooo`800003oooo00<0003oool000000_ooo`030000
oooo000005?oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo0000057oool010000?ooooooooooo`800003oooo00<0003oool000000_ooo`030000oooo0000
05Goool002Goool00`000?ooo`00001Joooo00<0003oooooool00_ooo`030000oooo000000;oool0
0`000?ooo`00001Coooo00L0003oooooooooool0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`00001Aoooo00D0003oooooooooool000001?ooo`030000oooo000000;oool00`000?oo
o`00001Eoooo000Voooo00<0003oooooool0FOooo`<00003oooo00<0003oooooool00_ooo`030000
oooooooo057oool200001?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool0Coooo`800003oooo0`0000?oool00`000?ooooooo`02oooo00<0003oooooool0E?ooo`00oooo
oj_oool00?oooon[oooo003oooooZoooo`00oooooj_oool00?oooon[oooo003oooooZoooo`00oooo
oj_oool001goool:000000?o000000000000o`0008000001oooo000Moooo00<0003oooooool01ooo
o`?o000@oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0
003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04?oo
o`030000oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo
013oool00`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?oo
ooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0@oooo00<0
003ooooo00000_l000Woool100000Oooo`007Oooo`030000oooooooo00Ooool00`000?ooool0000@
oooo00<0003oooooool04Oooo`030000oooooooo013oool00`000?ooooooo`0Aoooo00<0003ooooo
ool04?ooo`030000oooooooo017oool00`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000
oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool04Oooo`030000oooooooo013oool0
0`000?ooooooo`0Aoooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`0A
oooo00<0003oooooool04?ooo`030000oooooooo017oool00`000?ooooooo`09oooo0_l00003oooo
o`00o`0000Go00000oooool00?ooo`08oooo0@00007oool001goool00`000?ooooooo`07oooo00<0
003ooooo0000G_ooo`030000oooooooo05ooool00`000?ooooooo`1Ooooo00<0003oooooool0?ooo
o`;o00001Oooool00?l00?l00?ooo`02o`0000?ooooo003o00000_l000coool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`3oooooGOooo`03o`00oooooooo00;oool4o`005ooo
o`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo0?oooomLoooo1?l00004oooo
o`00o`00oooo0_l001Ooool100000Oooo`007Oooo`<00009oooo00?o003oooooool0oooooeOoool0
0ol00?ooooooo`02oooo1?l00004ooooo`00oooooooo0_l001Goool300000Oooo`007Oooo`030000
oooooooo00Woool00ol00?ooooooo`3oooooEoooo`;o0002oooo1_l001coool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`3oooooE_ooo`03o`00ooooo`0000;oool00ol00?oo
ooooo`02oooo00?o003oooooool06_ooo`400001oooo000Moooo00<0003oooooool02Oooo`03o`00
oooooooo0?oooomFoooo00?o003ooooo00000ol0027oool100000Oooo`007Oooo`030000oooooooo
00Woool00ol00?ooooooo`3oooooE_ooo`05o`00ooooo`00ooooo`0002;oool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`3oooooE_ooo`03o`00ooooo`0002Coool100000Ooo
o`007Oooo`<00009oooo00?o003oooooool0oooooeKoool00ol00?ooooooo`0Roooo0`00007oool0
01goool00`000?ooooooo`09oooo00?o003oooooool0T?ooo`03o`00oooooooo0<7oool2o`009_oo
o`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo07_oool00ol00?ooooooo`0B
oooo0_l00<;oool00ol00?ooooooo`0Uoooo0@00007oool001goool00`000?ooooooo`09oooo00?o
003oooooool0Noooo`03o`00oooooooo01;oool2o`00`_ooo`03o`00oooooooo02Goool100000Ooo
o`007Oooo`030000oooooooo00Woool00ol00?ooooooo`1koooo00?o003oooooool04_ooo`;o001D
oooo00?o003oooooool0GOooo`03o`00oooooooo00_oool00ol00?ooooooo`0Uoooo0@00007oool0
01goool00`000?ooooooo`09oooo00?o003oooooool0Noooo`03o`00oooooooo01;oool2o`00E?oo
o`03o`00oooooooo05goool00ol00?ooool0000:oooo0_l002Ooool100000Oooo`007Oooo`030000
oooooooo00Woool00ol00?ooooooo`1koooo00?o003oooooool04_ooo`;o001Doooo00?o003ooooo
ool0>?ooo`03o`00oooooooo02;oool00ol00?ooool0000:oooo0_l002Ooool100000Oooo`007Ooo
o`<00009oooo00?o003oooooool0Noooo`03o`00oooooooo01;oool2o`00E?ooo`03o`00oooooooo
03Soool00ol00?ooooooo`0=oooo00?o003oooooool04_ooo`03o`00ooooo`0000[oool2o`009Ooo
o`<00001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo07_oool00ol00?ooooooo`0B
oooo0_l002[oool00ol00?ooooooo`0Woooo0_l003Woool00ol00?ooooooo`0=oooo0_l001;oool2
o`0000?ooooo003oool01oooo`04o`00ooooo`00o`009oooo`400001oooo000Moooo00<0003ooooo
ool02Oooo`03o`00oooooooo05coool00ol00?ooooooo`0Loooo00?o003oooooool04_ooo`;o000Z
oooo00?o003oooooool09oooo`;o000ioooo00?o003oooooool03Oooo`;o000Boooo1?l000Soool3
o`00:?ooo`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo05coool00ol00?oo
ooooo`0Loooo00?o003oooooool04_ooo`;o000Zoooo00?o003oooooool09oooo`;o000ioooo00?o
003oooooool03Oooo`?o000Aoooo1?l000Soool3o`00:?ooo`400001oooo000Moooo00<0003ooooo
ool02Oooo`03o`00oooooooo05coool00ol00?ooooooo`0Loooo00?o003oooooool04_ooo`;o000Z
oooo00?o003oooooool08Oooo`03o`00oooooooo00?oool2o`00=?ooo`03o`00oooooooo00;oool0
0ol00?ooooooo`0=oooo0ol0017oool4o`002?ooo`?o000Xoooo0@00007oool001goool00`000?oo
ooooo`09oooo00?o003oooooool0G?ooo`03o`00oooooooo00Ooool00ol00?ooooooo`0Boooo00?o
003oooooool04_ooo`;o000Zoooo00?o003oooooool08?ooo`;o0005oooo0_l003Coool00ol00?oo
ooooo`02oooo00?o003oooooool03Oooo`?o000Aoooo1?l000Goool00ol00?ooooooo`03o`00:?oo
o`400001oooo000Moooo0`0000Woool00ol00?ooooooo`1Koooo0_l000Woool00ol00?ooooooo`0B
oooo00?o003oooooool04_ooo`;o000Zoooo00?o003oooooool08?ooo`;o0004oooo00?o003ooooo
00000oooo`03o`00oooooooo02koool00ol00?ooooooo`02oooo00?o003oooooool03Oooo`?o000A
oooo1?l000Goool00ol00?ooooooo`03o`009_ooo`<00001oooo000Moooo00<0003oooooool02Ooo
o`03o`00oooooooo05_oool2o`002Oooo`03o`00oooooooo01;oool00ol00?ooooooo`0Boooo0_l0
02[oool00ol00?ooooooo`0Poooo0_l000Coool00ol00?ooool00003oooo0_l002ooool00ol00?oo
ooooo`02oooo00?o003oooooool03Oooo`?o000Aoooo1?l000Goool00ol00?ooooooo`03o`00:?oo
o`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo05_oool2o`002Oooo`03o`00
oooooooo01;oool00ol00?ooooooo`0Boooo0_l002[oool00ol00?ooooooo`0Poooo0_l000Coool0
0ol00?ooool00003oooo0_l002ooool00ol00?ooooooo`02oooo00?o003oooooool03Oooo`03o`00
ooooo`0000Goool00ol00?ooooooo`05oooo00?o003ooooo00001Ol000Goool00ol00?ooooooo`03
o`00:?ooo`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo05_oool2o`002Ooo
o`03o`00oooooooo00Soool00ol00?ooooooo`07oooo00?o003oooooool04_ooo`;o000Yoooo0_l0
01Woool00ol00?ooooooo`06oooo0_l000Coool00ol00?ooool00003oooo0_l002ooool00ol00?oo
ooooo`02oooo00?o003oooooool03Oooo`03o`00ooooo`0000Goool00ol00?ooooooo`05oooo2?l0
00Goool00ol00?ooooooo`03o`00:?ooo`400001oooo0006oooo00<0003oooooool00_ooo`040000
oooooooooooo0`0000?oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`03o`00oooooooo
05_oool2o`002Oooo`03o`00oooooooo00Soool00ol00?ooooooo`07oooo0_l001?oool2o`00:Ooo
o`;o000Ioooo00?o003oooooool01_ooo`;o0004oooo00?o003ooooo00000oooo`;o000_oooo00?o
003oooooool00_ooo`03o`00oooooooo00goool00ol00?ooool00005oooo00?o003oooooool01Ooo
o`So0005oooo00Co003ooooo003oool2o`00:?ooo`400001oooo0005oooo00<0003oool000001ooo
o`030000oooooooo00;oool00`000?ooo`000006oooo00<0003oooooool02Oooo`03o`00oooooooo
05_oool2o`002Oooo`03o`00oooooooo00Soool00ol00?ooooooo`07oooo0_l001?oool2o`00:Ooo
o`;o000Ioooo00?o003oooooool01_ooo`;o0004oooo00?o003ooooo00000oooo`;o000_oooo00?o
003oooooool00_ooo`03o`00oooooooo00goool00ol00?ooool00005oooo00?o003oooooool01Ooo
o`So0005oooo00Co003ooooo003oool2o`00:?ooo`400001oooo0005oooo00<0003oool000002?oo
o`030000oooooooo00?oool00`000?ooooooo`04oooo100000Soool00ol00?ooooooo`1Koooo0_l0
00Woool00ol00?ooooooo`08oooo00?o003oooooool01oooo`;o000Coooo0_l002Woool2o`006Ooo
o`03o`00oooooooo00Koool2o`001?ooo`03o`00ooooo`0000?oool2o`00;oooo`03o`00oooooooo
00;oool00ol00?ooooooo`0=oooo00?o003ooooo00001Oooo`03o`00oooooooo00Goool8o`001Ooo
o`?o0002oooo00?o003oooooool08oooo`@00001oooo0005oooo00<0003oool000002?ooo`040000
oooooooooooo0P0000Ooool00`000?ooooooo`09oooo00?o003oooooool0Foooo`;o0009oooo00?o
003oooooool02?ooo`03o`00oooooooo00Ooool2o`004oooo`;o000Yoooo0_l001Woool00ol00?oo
ooooo`06oooo0_l000Coool00ol00?ooool00003oooo0_l002ooool00ol00?ooooooo`02oooo00?o
003oooooool03Oooo`03o`00ooooo`0000Goool00ol00?ooooooo`05oooo2?l000Goool3o`00:ooo
o`400001oooo0005oooo00<0003oool000001oooo`030000oooo000000;oool00`000?ooooooo`06
oooo00<0003oooooool02Oooo`03o`00oooooooo05_oool2o`002Oooo`03o`00oooooooo00Soool0
0ol00?ooooooo`07oooo0_l001?oool2o`00:Oooo`;o000Ioooo00?o003oooooool01_ooo`;o0004
oooo00?o003ooooo00000oooo`;o000_oooo00?o003oooooool00_ooo`03o`00oooooooo00goool0
0ol00?ooool00005oooo00?o003oooooool01Oooo`Go00000oooool00?l00005oooo0ol002_oool1
00000Oooo`001_ooo`030000oooooooo00Ooool010000?ooooooooooo`<00006oooo00<0003ooooo
ool02Oooo`03o`00oooooooo05_oool2o`002Oooo`03o`00oooooooo00Soool00ol00?ooooooo`07
oooo0_l001?oool2o`00:Oooo`?o000Goooo0_l000Soool2o`001?ooo`03o`00ooooo`0000?oool2
o`00;oooo`03o`00oooooooo00;oool00ol00?ooooooo`0=oooo00?o003ooooo00001Oooo`03o`00
oooooooo00Goool5o`0000?ooooo003o00001Oooo`?o000[oooo0@00007oool001goool00`000?oo
ooooo`09oooo00?o003oooooool0:oooo`03o`00oooooooo02goool2o`002Oooo`03o`00oooooooo
00Soool00ol00?ooooooo`07oooo0_l001?oool2o`00:Oooo`?o000Doooo00?o003oooooool00_l0
00Soool2o`001?ooo`03o`00ooooo`0000?oool2o`00;oooo`03o`00oooooooo00;oool00ol00?oo
ooooo`0=oooo00?o003ooooo00001Oooo`03o`00oooooooo00Goool5o`000_ooo`03o`00oooooooo
00?oool3o`00:oooo`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo02_oool0
0ol00?ooooooo`0]oooo0_l000Woool00ol00?ooooooo`08oooo00?o003oooooool01oooo`;o000C
oooo0_l002Woool3o`005?ooo`03o`00oooooooo00;o0008oooo0_l000Coool00ol00?ooool00003
oooo0_l002Coool00ol00?ooooooo`08oooo00?o003oooooool00_ooo`03o`00oooooooo00goool0
0ol00?ooool00005oooo00?o003oooooool01Oooo`Go0002oooo00?o003oooooool00oooo`?o000[
oooo0@00007oool001goool300002Oooo`03o`00oooooooo02_oool00ol00?ooooooo`0]oooo0_l0
00Woool00ol00?ooooooo`08oooo00?o003oooooool01oooo`;o000Coooo0_l002Woool00ol00?oo
ool0000Doooo00?o003oooooool00_l000Soool2o`001?ooo`03o`00ooooo`0000?oool2o`009?oo
o`03o`00oooooooo00Soool00ol00?ooooooo`02oooo00?o003oooooool03Oooo`03o`00ooooo`00
00Goool00ol00?ooooooo`05oooo1Ol000;oool00ol00?ooooooo`03oooo0ol002Woool300000Ooo
o`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0[oooo00?o003oooooool0;Oooo`;o0009
oooo00?o003oooooool02?ooo`03o`00oooooooo00Koool00ol00?ooool00008oooo00?o003ooooo
ool02?ooo`;o000Yoooo00?o003ooooo00005?ooo`03o`00oooooooo00;o0008oooo0_l000Coool0
0ol00?ooool00003oooo0_l002Coool01?l00?ooooooool000Ooool00ol00?ooooooo`02oooo00?o
003oooooool03Oooo`03o`00ooooo`0000Goool00ol00?ooooooo`05oooo1Ol000;oool00ol00?oo
ooooo`03oooo0ol002_oool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0[
oooo00?o003oooooool0;Oooo`;o0009oooo00?o003oooooool02?ooo`03o`00oooooooo00Koool0
0ol00?ooool00008oooo00?o003oooooool02?ooo`;o000Yoooo00?o003ooooo00004oooo`;o0002
oooo0_l000Soool2o`001?ooo`03o`00ooooo`0000?oool2o`009?ooo`04o`00ooooooooo`001_oo
o`;o0004oooo00?o003oooooool03Oooo`03o`00ooooo`0000Goool00ol00?ooooooo`05oooo1Ol0
00;oool00ol00?ooooooo`03oooo0ol002_oool100000Oooo`007Oooo`030000oooooooo00Woool0
0ol00?ooooooo`0Soooo00?o003oooooool01Oooo`03o`00oooooooo01;oool00ol00?ooooooo`0H
oooo0_l000Woool00ol00?ooooooo`08oooo00?o003oooooool01_ooo`03o`00ooooo`0000Soool0
0ol00?ooooooo`08oooo0_l002Woool00ol00?ooool0000>oooo00?o003oooooool00_ooo`;o0002
oooo0_l000Soool2o`001?ooo`03o`00ooooo`0000?oool2o`008oooo`;o0002oooo00?o003ooooo
ool01?ooo`;o0004oooo00?o003oooooool03Oooo`03o`00ooooo`0000Goool00ol00?ooooooo`03
oooo00?o003ooooo00001?l000;oool00ol00?ooooooo`03oooo0ol002_oool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`0Soooo00?o003oooooool01?ooo`;o000Doooo00?o
003oooooool03_ooo`03o`00oooooooo00Ooool2o`002Oooo`03o`00oooooooo00Soool00ol00?oo
ooooo`06oooo00?o003ooooo00002?ooo`03o`00oooooooo00Soool2o`00:Oooo`03o`00ooooo`00
00koool00ol00?ooooooo`02oooo0_l000;oool3o`001oooo`;o0004oooo00?o003ooooo00000ooo
o`;o000Soooo0_l000;oool00ol00?ooooooo`04oooo0_l000Coool00ol00?ooooooo`0=oooo00?o
003ooooo00000oooo`03o`00ooooo`0000Goool7o`000_ooo`03o`00oooooooo00?oool2o`00;?oo
o`400001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo02?oool00ol00?ooooooo`04
oooo0_l0013oool01Ol00?ooooooooooool0000@oooo00?o003oooooool01oooo`;o0003oooo00?o
003oooooool00oooo`03o`00oooooooo00Soool00ol00?ooooooo`06oooo00?o003ooooo00002?oo
o`03o`00oooooooo00Soool2o`00:Oooo`03o`00ooooo`0000koool00ol00?ooooooo`02oooo0_l0
00;oool3o`001oooo`03o`00ooooo`0000?oool00ol00?ooool00003oooo0_l002?oool2o`000_oo
o`03o`00oooooooo00Coool2o`001?ooo`03o`00oooooooo00goool00ol00?ooool00003oooo00?o
003ooooo00001Oooo`Oo0002oooo00?o003oooooool00oooo`;o000/oooo0@00007oool001goool3
00002Oooo`03o`00oooooooo02?oool00ol00?ooooooo`04oooo0_l0013oool01Ol00?oooooooooo
ool0000@oooo00?o003oooooool01oooo`;o0003oooo00?o003oooooool00oooo`03o`00oooooooo
00Soool00ol00?ooooooo`06oooo00?o003ooooo00002?ooo`03o`00oooooooo00Soool2o`00:Ooo
o`03o`00ooooo`0000koool00ol00?ooooooo`02oooo0_l000;oool00ol00?ooool00007oooo00?o
003ooooo00000oooo`03o`00ooooo`0000?oool2o`008oooo`;o0002oooo00?o003oooooool01?oo
o`;o0004oooo00?o003oooooool03?ooo`;o00000oooool00?ooo`02oooo00?o003ooooo00001Ooo
o`Oo0002oooo00?o003oooooool00oooo`;o000Zoooo0`00007oool001goool00`000?ooooooo`09
oooo00?o003oooooool08oooo`03o`00oooooooo00Coool2o`004?ooo`05o`00ooooooooooooo`00
00ooool2o`002Oooo`;o0003oooo00?o003oooooool00oooo`03o`00oooooooo00Soool00ol00?oo
ooooo`06oooo00?o003ooooo00002?ooo`03o`00oooooooo00Soool2o`003oooo`03o`00oooooooo
01Ooool00ol00?ooool0000>oooo00?o003oooooool00_ooo`;o0002oooo00?o003ooooo00001ooo
o`03o`00ooooo`0000?oool00ol00?ooool00002oooo0ol002?oool2o`000_ooo`03o`00oooooooo
00Coool2o`001?ooo`03o`00oooooooo00coool2o`0000?ooooo003oool00_ooo`03o`00ooooo`00
00Goool6o`000oooo`03o`00oooooooo00?oool2o`00;?ooo`400001oooo000Moooo00<0003ooooo
ool02Oooo`03o`00oooooooo02?oool00ol00?ooooooo`04oooo0_l0013oool00ol00?ooooooo`02
o`003oooo`;o0009oooo0_l000?oool00ol00?ooooooo`03oooo00?o003oooooool02?ooo`03o`00
oooooooo00Koool00ol00?ooool00008oooo00?o003oooooool02?ooo`;o000?oooo00?o003ooooo
ool05oooo`03o`00ooooo`0000koool00ol00?ooooooo`02oooo0_l000;oool00ol00?ooool00007
oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`008oooo`;o0002oooo00?o003ooooo
ool01?ooo`;o0004oooo00?o003oooooool03?ooo`;o00000oooool00?ooo`02oooo00?o003ooooo
00001Oooo`Ko0003oooo00?o003oooooool00oooo`;o000/oooo0@00007oool001goool00`000?oo
ooooo`09oooo00?o003oooooool08oooo`03o`00oooooooo00Coool2o`004?ooo`03o`00oooooooo
00;o000?oooo0_l000Woool2o`000oooo`03o`00oooooooo00?oool00ol00?ooooooo`08oooo00?o
003oooooool01_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003oooooool02?oo
o`;o000?oooo00?o003oooooool05oooo`03o`00ooooo`0000koool00ol00?ooooooo`02oooo0_l0
00;oool00ol00?ooool00007oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`008ooo
o`;o0002oooo00?o003oooooool01?ooo`;o0004oooo00?o003oooooool03?ooo`04o`00oooooooo
o`000oooo`?o0005oooo0ol00003ooooo`00o`0000?oool00ol00?ooooooo`03oooo0_l002coool1
00000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo00?o003oooooool01?oo
o`;o000@oooo00?o003oooooool00_l000ooool2o`002Oooo`;o0003oooo00?o003oooooool00ooo
o`03o`00oooooooo00Soool00ol00?ooooooo`02oooo00Oo003ooooooooooooo003ooooo00000ooo
o`03o`00oooooooo00;oool00ol00?ooooooo`08oooo0_l000ooool00ol00?ooooooo`0Goooo00?o
003ooooo00003_ooo`03o`00oooooooo00;oool2o`000_ooo`03o`00ooooo`0000Ooool00ol00?oo
ool00003oooo00?o003ooooo00000_ooo`?o000Soooo0_l000;oool00ol00?ooooooo`04oooo00?o
003ooooo00000oooo`03o`00oooooooo00coool01?l00?ooooooool000?oool3o`001Oooo`?o0000
0oooool00?l00003oooo00?o003oooooool00oooo`03o`00oooooooo02_oool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`0Soooo00?o003oooooool01?ooo`;o000@oooo00?o
003oooooool00_l000ooool2o`002Oooo`;o0003oooo00?o003oooooool00oooo`03o`00oooooooo
00Soool00ol00?ooooooo`02oooo00Oo003ooooooooooooo003ooooo00000oooo`03o`00oooooooo
00;oool00ol00?ooooooo`08oooo0_l000ooool00ol00?ooooooo`0Goooo00?o003ooooo00003_oo
o`03o`00oooooooo00;oool2o`000_ooo`03o`00ooooo`0000Ooool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`?o000Soooo0_l000;oool00ol00?ooooooo`04oooo00?o003ooooo00000ooo
o`03o`00oooooooo00coool01?l00?ooooooool000?oool3o`001Oooo`?o00000oooool00?l00003
oooo00?o003oooooool00oooo`03o`00oooooooo02_oool100000Oooo`007Oooo`<00009oooo00?o
003oooooool08oooo`03o`00oooooooo00Coool2o`004?ooo`03o`00oooooooo00?o000>oooo0_l0
00Woool2o`000oooo`03o`00oooooooo00?oool00ol00?ooooooo`08oooo00?o003oooooool00_oo
o`07o`00ooooooooooooo`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003oooooool02?oo
o`;o000?oooo00?o003oooooool02?ooo`03o`00oooooooo00coool00ol00?ooool0000>oooo00?o
003oooooool00_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00ooooo`0000?oool00ol00?oo
ool00002oooo0ol002?oool2o`000_ooo`03o`00oooooooo00Coool00ol00?ooool00003oooo00?o
003oooooool03?ooo`04o`00ooooooooo`000oooo`?o0005oooo0ol000;oool01Ol00?oooooooooo
ool00005oooo00?o003oooooool0:Oooo`<00001oooo000Moooo00<0003oooooool02Oooo`03o`00
oooooooo02?oool00ol00?ooooooo`04oooo0_l000ooool2o`000_ooo`?o000>oooo0_l000Woool2
o`000oooo`03o`00oooooooo00?oool00ol00?ooooooo`08oooo00?o003oooooool00_ooo`07o`00
ooooooooooooo`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`;o000?
oooo00?o003oooooool02?ooo`03o`00oooooooo00coool00ol00?ooool0000>oooo00?o003ooooo
ool00_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00ooooo`0000?oool00ol00?ooool00002
oooo0ol002?oool2o`000_ooo`03o`00oooooooo00Coool00ol00?ooool00002oooo0_l000koool0
1?l00?ooooooool000?oool3o`001Oooo`?o0002oooo00Go003ooooooooooooo00001Oooo`03o`00
oooooooo02_oool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo00?o
003oooooool01?ooo`;o000?oooo0_l000;oool3o`003_ooo`;o0009oooo0_l000?oool00ol00?oo
ooooo`03oooo00?o003oooooool02?ooo`03o`00oooooooo00;oool01ol00?ooooooooooool00?oo
ool00003oooo00?o003oooooool00_ooo`;o0009oooo0_l000ooool00ol00?ooooooo`08oooo00?o
003oooooool03?ooo`03o`00ooooo`0000koool00ol00?ooool00002oooo0_l000;oool00ol00?oo
ool00007oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`008oooo`;o0002oooo00?o
003oooooool01?ooo`03o`00ooooo`0000;oool2o`003_ooo`04o`00ooooooooo`000oooo`?o0005
oooo0ol000Koool00ol00?ooooooo`03oooo00?o003oooooool0:oooo`400001oooo000Moooo00<0
003oooooool02Oooo`03o`00oooooooo02?oool00ol00?ooooooo`04oooo0_l000ooool2o`000_oo
o`?o000>oooo0_l000Woool2o`000oooo`03o`00oooooooo00?oool00ol00?ooooooo`02oooo00?o
003oooooool00oooo`03o`00oooooooo00;oool01ol00?ooooooooooool00?ooool00003oooo00?o
003oooooool00_ooo`;o0009oooo0_l000ooool00ol00?ooooooo`08oooo00?o003oooooool03?oo
o`03o`00ooooo`0000koool00ol00?ooool00002oooo0_l000;oool00ol00?ooool00007oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0009oooo00?o003oooooool05oooo`;o0002
oooo00?o003oooooool01?ooo`03o`00ooooo`0000;oool2o`003_ooo`04o`00ooooooooo`000ooo
o`?o0005oooo0ol000Koool00ol00?ooooooo`03oooo00?o003oooooool0:oooo`400001oooo000M
oooo00<0003oooooool02Oooo`03o`00oooooooo02?oool00ol00?ooooooo`04oooo0_l000ooool2
o`000_ooo`?o000>oooo0_l000Woool2o`000oooo`03o`00oooooooo00?oool00ol00?ooooooo`02
oooo00?o003oooooool00oooo`03o`00oooooooo00;oool01ol00?ooooooooooool00?ooool00003
oooo00?o003oooooool00_ooo`;o0009oooo0_l000ooool00ol00?ooooooo`08oooo00?o003ooooo
ool03?ooo`03o`00ooooo`0000koool00ol00?ooool00002oooo0_l000;oool00ol00?ooool00007
oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0009oooo00?o003oooooool05ooo
o`;o0002oooo00?o003oooooool01?ooo`03o`00ooooo`0000;oool2o`002?ooo`03o`00oooooooo
00?oool01?l00?ooooooool000?oool3o`001Oooo`?o0006oooo00?o003oooooool00oooo`03o`00
oooooooo02_oool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l0
00Goool2o`003_ooo`?o0002oooo0ol000koool2o`001?ooo`03o`00oooooooo00;oool2o`000ooo
o`03o`00oooooooo00?oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo
00;oool01ol00?ooooooooooool00?ooool00003oooo00?o003oooooool00_ooo`;o0005oooo00Co
003oooooooooool2o`003oooo`03o`00oooooooo00Soool00ol00?ooooooo`0<oooo00?o003ooooo
00003_ooo`03o`00ooooo`0000;oool2o`000_ooo`03o`00ooooo`0000Ooool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo0ol000Woool00ol00?ooooooo`0Goooo0_l000;oool00ol00?oo
ooooo`04oooo00?o003ooooo00000_ooo`;o0008oooo00?o003oooooool00oooo`04o`00oooooooo
o`000oooo`?o0005oooo0ol000Koool00ol00?ooooooo`03oooo00?o003oooooool0:oooo`400001
oooo000Moooo0`0000Woool00ol00?ooooooo`0Soooo0_l000Goool2o`003_ooo`?o0002oooo0ol0
00Woool00ol00?ooooooo`02oooo0_l000Coool00ol00?ooooooo`04o`000oooo`03o`00oooooooo
00?oool01?l00?ooooooooooo`;o0004oooo0ol000?oool01ol00?ooooooooooool00?ooool00003
oooo00?o003oooooool00_ooo`;o0005oooo00Co003oooooooooool2o`003oooo`03o`00oooooooo
00Soool00ol00?ooooooo`0<oooo00?o003ooooo00003_ooo`?o0002oooo0_l000;oool00ol00?oo
ool00007oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0009oooo00?o003ooooo
ool04oooo`04o`00oooooooooooo0_l000;oool00ol00?ooooooo`04oooo00?o003ooooo00000_oo
o`;o0008oooo00?o003oooooool00oooo`04o`00ooooooooo`000oooo`?o0005oooo0ol000Koool0
0ol00?ooooooo`03oooo00?o003oooooool0:Oooo`<00001oooo000Moooo00<0003oooooool02Ooo
o`03o`00oooooooo02?oool2o`001Oooo`;o000>oooo0ol000;oool3o`000_ooo`03o`00oooooooo
00Coool00ol00?ooooooo`02oooo0_l000Coool00ol00?ooooooo`04o`000oooo`03o`00oooooooo
00?oool01?l00?ooooooooooo`;o0004oooo0ol000?oool01ol00?ooooooooooool00?ooool00003
oooo00?o003oooooool00_ooo`;o0005oooo00Co003oooooooooool2o`003oooo`03o`00oooooooo
00Ooool2o`003_ooo`03o`00ooooo`0000koool3o`000_ooo`;o0002oooo00?o003ooooo00001ooo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`002Oooo`;o000Doooo00Co003ooooo
ooooool2o`000_ooo`03o`00oooooooo00Coool00ol00?ooool00002oooo0_l000Soool00ol00?oo
ooooo`03oooo00Co003ooooooooo0003oooo0ol000Goool3o`001_ooo`03o`00oooooooo00?oool0
0ol00?ooooooo`0[oooo0@00007oool001goool00`000?ooooooo`09oooo00?o003oooooool08ooo
o`;o0005oooo0_l000koool3o`000_ooo`?o0002oooo00?o003oooooool01?ooo`03o`00oooooooo
00;oool2o`001?ooo`03o`00oooooooo00Co0003oooo00?o003oooooool00oooo`04o`00oooooooo
oooo0_l000Coool3o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool00ol00?ooooooo`02
oooo0_l000Goool01?l00?ooooooooooo`;o000?oooo00?o003oooooool01oooo`;o000>oooo00?o
003ooooo00003_ooo`?o0002oooo0_l000;oool00ol00?ooool00007oooo00?o003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`?o0009oooo0_l001Coool01?l00?ooooooooooo`;o0002oooo00?o
003oooooool01?ooo`03o`00ooooo`0000;oool2o`002?ooo`03o`00oooooooo00?oool01?l00?oo
ooooool000?oool3o`001Oooo`?o0006oooo00?o003oooooool00_ooo`03o`00oooooooo02coool1
00000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Goool2o`003_oo
o`?o0002oooo0ol000;oool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`;o0004oooo00?o
003oooooool01?l000?oool00ol00?ooooooo`03oooo00Co003oooooooooool2o`001?ooo`?o0003
oooo00Oo003ooooooooooooo003ooooo00000oooo`03o`00oooooooo00;oool3o`001?ooo`04o`00
oooooooooooo0_l000ooool00ol00?ooooooo`07oooo0_l000koool00ol00?ooool0000>oooo0ol0
00;oool2o`000_ooo`03o`00ooooo`0000Ooool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo0ol000Woool2o`005?ooo`04o`00oooooooooooo0_l000;oool00ol00?ooooooo`04oooo00?o
003ooooo00000_ooo`;o0008oooo00?o003oooooool00oooo`04o`00ooooooooo`000oooo`?o0005
oooo0ol000Koool00ol00?ooooooo`02oooo00?o003oooooool0;?ooo`400001oooo000;oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Ooo
o`03o`00oooooooo02?oool2o`001Oooo`;o000>oooo0ol000;oool3o`000_ooo`03o`00oooooooo
00Coool00ol00?ooooooo`02oooo0_l000Coool00ol00?ooooooo`04o`000oooo`03o`00oooooooo
00?oool01?l00?ooooooooooo`;o0004oooo0ol000?oool01ol00?ooooooooooool00?ooool00003
oooo00?o003oooooool00_ooo`?o0003oooo0_l000?oool2o`003oooo`03o`00oooooooo00Ooool2
o`003_ooo`03o`00ooooo`0000koool3o`000_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool3o`002Oooo`;o000Doooo00Co003oooooooooool2
o`000_ooo`03o`00oooooooo00Coool00ol00?ooool00002oooo0_l000Soool00ol00?ooooooo`03
oooo00Co003ooooooooo0003oooo0ol000Goool3o`001_ooo`03o`00oooooooo00;oool00ol00?oo
ooooo`0/oooo0@00007oool000[oool00`000?ooo`000007oooo00<0003oool000001_ooo`030000
oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Goool2o`003_ooo`?o0002oooo0ol000;oool0
0ol00?ooooooo`04oooo00?o003oooooool00_ooo`;o0004oooo00?o003oooooool01?l000?oool0
0ol00?ooooooo`02oooo0_l000?oool2o`001?ooo`?o0003oooo00Oo003ooooooooooooo003ooooo
00000oooo`;o0003oooo0ol000?oool2o`000oooo`;o000>oooo0_l000Woool2o`003_ooo`03o`00
ooooo`0000koool3o`000_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00ooooo`0000;oool0
1?l00?ooooooool000;oool3o`002Oooo`;o000Doooo00Co003oooooooooool2o`000_ooo`03o`00
oooooooo00Coool00ol00?ooool00002oooo0_l000Soool00ol00?ooooooo`03oooo00Co003ooooo
oooo0003oooo0ol000Goool3o`001_ooo`03o`00oooooooo00;oool00ol00?ooooooo`0/oooo0@00
007oool000[oool00`000?ooo`000009oooo00<0003oooooool01?ooo`@00008oooo00?o003ooooo
ool08oooo`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`0000;oool00ol00?ooooooo`04
oooo0_l000;oool3o`001?ooo`03o`00oooooooo00Co0003oooo0_l000?oool2o`000oooo`;o0004
oooo0ol000?oool01ol00?ooooooooooool00?ooool00003oooo0_l000?oool3o`000oooo`;o0003
oooo0_l000koool2o`002Oooo`;o0009oooo00?o003oooooool00_ooo`03o`00ooooo`0000koool3
o`000_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool3o`002?ooo`03o`00ooooo`0001Coool01?l00?ooooooooooo`;o0002oooo00?o003ooooo
ool01?ooo`03o`00ooooo`0000;oool2o`002?ooo`03o`00oooooooo00?oool01?l00?ooooooool0
00?oool3o`001Oooo`?o0006oooo00?o003oooooool00_ooo`03o`00oooooooo02Woool400000Ooo
o`002_ooo`030000oooo000000Ooool200001oooo`030000oooooooo00Woool00ol00?ooooooo`0S
oooo0_l000Goool2o`003_ooo`?o0002oooo00?o003ooooo00000_ooo`03o`00oooooooo00Coool2
o`000_ooo`?o0004oooo00?o003oooooool01?l000?oool2o`000oooo`;o0003oooo0_l000Coool3
o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000oooo`?o0003oooo0_l000?oool2
o`003_ooo`;o0009oooo0_l000Woool00ol00?ooooooo`02oooo00?o003ooooo00003_ooo`?o0002
oooo0_l000;oool00ol00?ooool00007oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_oo
o`?o0008oooo00?o003ooooo00004oooo`;o0003oooo0_l000;oool00ol00?ooooooo`04oooo00?o
003ooooo00000_ooo`;o0004oooo00Go003ooooooooooooo00001Oooo`04o`00ooooooooo`000ooo
o`?o0005oooo0ol000Koool00ol00?ooooooo`02oooo00?o003oooooool0;?ooo`400001oooo000:
oooo00<0003oool000001oooo`030000oooooooo00Koool00`000?ooooooo`09oooo00?o003ooooo
ool08oooo`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`0000;oool00ol00?ooooooo`04
oooo0_l000;oool3o`001?ooo`03o`00oooooooo00Co0003oooo0_l000?oool2o`000oooo`;o0004
oooo0ol000?oool01ol00?ooooooooooool00?ooool00003oooo0_l000?oool3o`000oooo`;o0003
oooo0_l000koool2o`002Oooo`;o0009oooo00?o003oooooool00_ooo`03o`00ooooo`0000koool3
o`000_ooo`;o0002oooo00?o003ooooo00001oooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool3o`002?ooo`03o`00ooooo`0001?oool2o`000oooo`;o0002oooo00?o003oooooool01?oo
o`03o`00ooooo`0000;oool2o`001?ooo`05o`00ooooooooooooo`0000Goool01?l00?ooooooool0
00?oool3o`001Oooo`?o0006oooo00?o003oooooool00_ooo`03o`00oooooooo02coool100000Ooo
o`002oooo`030000oooooooo00Koool300001_ooo`030000oooooooo00Woool00ol00?ooooooo`0S
oooo0_l000Goool2o`003_ooo`?o0002oooo00?o003ooooo00000_ooo`03o`00oooooooo00Coool2
o`000_ooo`?o0004oooo00?o003oooooool01?l000?oool2o`000oooo`;o0003oooo0_l000?oool4
o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000oooo`?o0003oooo0_l000?oool2
o`003_ooo`;o0009oooo0_l000Woool00ol00?ooooooo`02oooo00?o003ooooo00003_ooo`?o0002
oooo0_l000;oool00ol00?ooool00007oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_oo
o`?o0008oooo00?o003ooooo00004oooo`;o0003oooo0_l000;oool00ol00?ooooooo`04oooo00?o
003ooooo00000_ooo`;o0004oooo00Go003ooooooooooooo00001Oooo`04o`00ooooooooo`000ooo
o`?o0005oooo0ol000Koool00ol00?ooooooo`02oooo00?o003oooooool0;?ooo`400001oooo000M
oooo00<0003oooooool02Oooo`03o`00oooooooo02?oool2o`001Oooo`;o000>oooo0ol000;oool0
0ol00?ooool00002oooo00?o003oooooool00oooo`?o0002oooo0ol000Coool00ol00?ooooooo`04
o`000oooo`;o0003oooo0_l000?oool2o`000oooo`Co0003oooo00Oo003ooooooooooooo003ooooo
00000oooo`;o0003oooo0ol000?oool2o`000oooo`;o000>oooo0_l000Woool2o`002Oooo`03o`00
oooooooo00;oool00ol00?ooool0000>oooo0ol000;oool2o`0000Gooooo003o003ooooo00001ooo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`002?ooo`03o`00ooooo`0000?oool0
0ol00?ooooooo`0=oooo0_l000?oool2o`000_ooo`03o`00oooooooo00Coool00ol00?ooool00002
oooo0_l000Coool01Ol00?ooooooooooool00005oooo00Co003ooooooooo0003oooo0ol000Goool3
o`001_ooo`03o`00oooooooo00;oool00ol00?ooooooo`0/oooo0@00007oool001goool00`000?oo
ooooo`09oooo00?o003oooooool08oooo`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`00
00;oool00ol00?ooooooo`03oooo0ol000;oool3o`001?ooo`03o`00oooooooo00Co0003oooo0_l0
00?oool2o`000oooo`;o0003oooo1?l000?oool01ol00?ooooooooooool00?ooool00003oooo0_l0
00?oool3o`000oooo`;o0003oooo0_l000koool2o`002Oooo`;o0009oooo00?o003oooooool00_oo
o`03o`00ooooo`0000koool3o`000_ooo`;o00001Oooool00?l00?ooool00007oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`?o0008oooo00?o003ooooo00000oooo`03o`00oooooooo
00goool2o`000oooo`;o0002oooo00?o003oooooool01?ooo`03o`00ooooo`0000;oool2o`001?oo
o`05o`00ooooooooooooo`0000Goool01?l00?ooooooool000?oool3o`001Oooo`?o0006oooo00?o
003oooooool00_ooo`03o`00oooooooo02coool100000Oooo`007Oooo`<00009oooo00?o003ooooo
ool08oooo`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`0000;oool00ol00?ooooooo`03
oooo0ol000;oool3o`001?ooo`03o`00oooooooo00Co0003oooo0_l000?oool2o`000oooo`;o0003
oooo1?l000?oool01ol00?ooooooooooool00?ooool00003oooo0_l000?oool3o`000oooo`;o0003
oooo0_l000koool2o`002Oooo`;o0009oooo00?o003oooooool00_ooo`03o`00ooooo`0000koool3
o`000_ooo`;o00001Oooool00?l00?ooool00007oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`?o0008oooo00?o003ooooo00000oooo`03o`00oooooooo00goool2o`000oooo`;o0002
oooo00?o003oooooool01?ooo`03o`00ooooo`0000;oool2o`001?ooo`05o`00ooooooooooooo`00
00Coool2o`000_ooo`04o`00oooooooooooo0ol000Goool3o`001_ooo`03o`00oooooooo00;oool0
0ol00?ooooooo`0Zoooo0`00007oool001goool00`000?ooooooo`09oooo00?o003oooooool08ooo
o`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`0000;oool2o`001?ooo`?o0002oooo0ol0
00Coool00ol00?ooooooo`04o`000oooo`;o0003oooo0_l000?oool2o`000oooo`Co0003oooo00Oo
003ooooooooooooo003ooooo00000oooo`;o0003oooo0ol000?oool2o`000oooo`;o000>oooo0_l0
00Woool2o`002Oooo`03o`00oooooooo00;oool00ol00?ooool0000>oooo0ol000;oool2o`0000Go
oooo003o003ooooo00001oooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`002?oo
o`03o`00ooooo`0000?oool00ol00?ooooooo`0=oooo0_l000?oool2o`000_ooo`03o`00oooooooo
00?oool01?l00?ooooooool000;oool2o`001?ooo`05o`00ooooooooooooo`0000Coool2o`000_oo
o`04o`00oooooooooooo0ol000Goool3o`001_ooo`04o`00oooooooooooo0_l002koool100000Ooo
o`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Goool2o`003_ooo`?o0002
oooo00?o003ooooo00000_ooo`;o0004oooo0ol000;oool3o`001?ooo`;o00000oooool00?l00002
o`000oooo`;o0003oooo0_l000?oool2o`000oooo`Co0003oooo00Oo003ooooooooooooo003ooooo
00000oooo`;o0003oooo0ol000?oool2o`000oooo`;o000>oooo0_l000Woool2o`002Oooo`03o`00
oooooooo00;oool00ol00?ooool0000>oooo0ol000;oool2o`0000Gooooo003o003ooooo00001ooo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`002?ooo`03o`00ooooo`0000?oool0
0ol00?ooooooo`0=oooo0_l000?oool2o`000_ooo`03o`00oooooooo00?oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo00Go003ooooooooooooo00001?ooo`;o0002oooo00Co003ooooo
ooooool4o`001?ooo`?o0006oooo00Co003oooooooooool2o`00;_ooo`400001oooo000Moooo00<0
003oooooool02Oooo`03o`00oooooooo02?oool2o`001Oooo`;o000>oooo0ol000;oool00ol00?oo
ool00002oooo0_l000Coool3o`000_ooo`?o0004oooo0_l00003ooooo`00o`0000;o0003oooo0_l0
00?oool2o`000oooo`;o0003oooo1?l000?oool01ol00?ooooooooooool00?ooool00003oooo0_l0
00?oool3o`000oooo`;o0003oooo0_l000koool2o`002Oooo`;o0009oooo00?o003oooooool00_oo
o`03o`00ooooo`0000koool3o`000_ooo`Go00000oooool00?ooo`06oooo00?o003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`?o0008oooo00?o003ooooo00000oooo`03o`00oooooooo00goool2
o`000oooo`;o0002oooo00?o003oooooool00oooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool01Ol00?ooooooooooool00004oooo0_l000;oool01?l00?ooooooooooo`Co0004oooo0ol0
00Koool01?l00?ooooooooooo`;o000^oooo0@00007oool001goool00`000?ooooooo`09oooo00?o
003oooooool08oooo`;o0005oooo0_l000koool3o`000_ooo`03o`00ooooo`0000;oool2o`001?oo
o`?o0002oooo0ol000Coool2o`0000?ooooo003o00000_l000?oool2o`000oooo`;o0003oooo0_l0
00?oool4o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000_ooo`Co0003oooo0_l0
00?oool2o`003_ooo`;o0009oooo0ol000Soool00ol00?ooooooo`02oooo00?o003ooooo00003_oo
o`?o0002oooo1Ol00003ooooo`00oooo00Koool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo0ol000Soool00ol00?ooool00003oooo00?o003oooooool03Oooo`;o0003oooo0_l000;oool0
0ol00?ooooooo`03oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000Coool2o`000_ooo`04o`00oooooooooooo1?l000Coool3o`001_ooo`04o`00oooooooo
oooo0_l002koool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l0
00Goool2o`003_ooo`?o0002oooo00?o003ooooo00000_ooo`;o0004oooo0ol000;oool3o`001?oo
o`;o00001Oooool00?l00?ooool00003oooo0_l000?oool2o`000oooo`;o0003oooo1?l000?oool0
1ol00?ooooooooooool00?ooool00003oooo0_l000;oool4o`000oooo`;o0003oooo0_l000koool2
o`002Oooo`?o0008oooo00?o003oooooool00_ooo`03o`00ooooo`0000koool3o`000_ooo`Go0000
0oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0008oooo00?o
003ooooo00000oooo`03o`00oooooooo00goool2o`000oooo`;o0002oooo00?o003oooooool00ooo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00004oooo0_l0
00;oool01?l00?ooooooooooo`;o00000oooool00?ooo`03oooo0ol000Koool01?l00?oooooooooo
o`;o000^oooo0@00007oool001goool300002Oooo`03o`00oooooooo02?oool2o`001Oooo`;o000>
oooo0ol000;oool00ol00?ooool00002oooo0_l000Coool3o`000_ooo`?o0004oooo0_l00005oooo
o`00o`00ooooo`0000?oool2o`000oooo`;o0003oooo0_l000?oool4o`000oooo`07o`00oooooooo
ooooo`00ooooo`0000?oool2o`000_ooo`Co0003oooo0_l000?oool2o`003_ooo`;o0009oooo0ol0
00Soool00ol00?ooooooo`02oooo00?o003ooooo00003_ooo`?o0002oooo1Ol00003ooooo`00oooo
00Koool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0ol000Soool00ol00?ooool00003
oooo00?o003oooooool03Oooo`;o0003oooo0_l000;oool00ol00?ooooooo`03oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Coool2o`000_ooo`04o`00
oooooooooooo0_l00003ooooo`00oooo00?oool3o`001_ooo`04o`00oooooooooooo0_l002coool3
00000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Goool2o`003_oo
o`?o0002oooo00?o003ooooo00000_ooo`;o0004oooo0ol000;oool3o`001?ooo`;o00001Oooool0
0?l00?ooool00003oooo0_l000?oool2o`000oooo`;o0003oooo1?l000?oool01ol00?oooooooooo
ool00?ooool00003oooo0_l000;oool4o`000oooo`;o0003oooo0_l000koool2o`002Oooo`?o0008
oooo00?o003oooooool00_ooo`03o`00ooooo`0000_oool00ol00?ooooooo`03o`000_ooo`Go0000
0oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00Soool00ol00?ooool00003oooo00?o003oooooool03Oooo`;o0003oooo0_l000;oool00ol00?oo
ooooo`03oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`00
00Coool2o`000_ooo`04o`00oooooooooooo0_l00003ooooo`00oooo00?oool3o`001_ooo`04o`00
oooooooooooo0_l002koool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0S
oooo0_l000Coool00ol00?ooool0000>oooo0ol000;oool00ol00?ooool00002oooo0_l000Coool3
o`000_ooo`?o0004oooo0_l00005ooooo`00o`00ooooo`0000?oool2o`000oooo`;o0003oooo0_l0
00?oool4o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000_ooo`;o00000oooool0
0?ooo`02oooo0_l000?oool2o`003_ooo`;o0009oooo0ol000Soool00ol00?ooooooo`02oooo00?o
003ooooo00002oooo`03o`00oooooooo00?o0002oooo1Ol00003ooooo`00oooo00Koool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00002?ooo`03o`00ooooo`0000?oool0
0ol00?ooooooo`0=oooo0_l000?oool2o`000_ooo`03o`00oooooooo00?oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00001?ooo`;o0002oooo00Co003ooooo
ooooool2o`0000?ooooo003oool00oooo`?o0006oooo00Co003oooooooooool2o`00;_ooo`400001
oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo02?oool2o`001?ooo`03o`00ooooo`00
00koool3o`000_ooo`03o`00ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?oo
o`;o00001Oooool00?l00?ooool00003oooo0_l000?oool2o`000oooo`;o0003oooo1?l000?oool0
1ol00?ooooooooooool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003
oooo0_l000koool2o`002Oooo`?o0008oooo00?o003oooooool00_ooo`03o`00ooooo`0000_oool0
0ol00?ooooooo`03o`000_ooo`Go00000oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003oooo00?o003oooooool03Ooo
o`;o0003oooo0_l000;oool00ol00?ooooooo`03oooo00Co003ooooooooo0002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000Coool2o`000_ooo`05o`00ooooooooooooo`0000;oool0
1Ol00?ooooooool00?ooo`03o`001_ooo`04o`00oooooooooooo0_l002koool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Coool00ol00?ooool0000>oooo0ol0
00;oool00ol00?ooool00002oooo0_l000Coool00ol00?ooool00002oooo0ol000Coool2o`0000Go
oooo003o003ooooo00000oooo`;o0003oooo0_l000?oool2o`000oooo`Co0003oooo00Oo003ooooo
oooooooo003ooooo00000oooo`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00
ooooo`0000goool2o`002Oooo`?o0008oooo00?o003oooooool00_ooo`03o`00ooooo`0000_oool0
0ol00?ooooooo`03o`000_ooo`Go00000oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003oooo00?o003oooooool03Ooo
o`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool000;oool00ol00?ooool00003
oooo00Go003ooooo003ooooo00001?ooo`;o0002oooo00Go003ooooooooooooo00000_ooo`05o`00
ooooooooo`00oooo00?o0006oooo00Co003oooooooooool2o`00;_ooo`400001oooo000Moooo00<0
003oooooool02Oooo`03o`00oooooooo02?oool2o`001?ooo`03o`00ooooo`0000koool3o`000_oo
o`03o`00ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?ooo`;o00001Oooool0
0?l00?ooool00003oooo0_l000;oool3o`000oooo`;o0003oooo1?l000?oool01ol00?oooooooooo
ool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo
00003Oooo`;o0009oooo0ol000Soool00ol00?ooooooo`02oooo00?o003ooooo00002oooo`03o`00
oooooooo00?o0002oooo1Ol00003ooooo`00oooo00Koool00ol00?ooool00002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00002?ooo`03o`00ooooo`0000?oool00ol00?ooooooo`0=oooo0_l0
00?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00004oooo0_l000;oool01Ol00?ooooooooooool00002oooo00Go003ooooo
oooo003oool00ol000Koool01?l00?ooooooooooo`;o000^oooo0@00007oool001goool300002Ooo
o`03o`00oooooooo02?oool2o`001?ooo`03o`00ooooo`0000koool3o`000_ooo`03o`00ooooo`00
00;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?ooo`;o00001Oooool00?l00?ooool00003
oooo0_l000;oool3o`000oooo`;o0003oooo1?l000?oool01ol00?ooooooooooool00?ooool00003
oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo00003Oooo`;o0009
oooo0ol000Soool00ol00?ooooooo`02oooo00?o003ooooo00002oooo`03o`00oooooooo00?o0002
oooo1Ol00003ooooo`00oooo00Koool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o
003ooooo00002?ooo`03o`00ooooo`0000?oool00ol00?ooooooo`0=oooo0_l000?oool3o`0000?o
oooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?oo
ool00004oooo0_l000;oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l00003oooo
o`00o`0000Koool01?l00?ooooooooooo`;o000/oooo0`00007oool001goool00`000?ooooooo`09
oooo00?o003oooooool08oooo`;o0004oooo00?o003ooooo00003_ooo`?o0002oooo00?o003ooooo
00000_ooo`;o0004oooo00?o003ooooo00000_ooo`?o0004oooo0_l00005ooooo`00ooooooooo`00
00?oool2o`000_ooo`?o0003oooo0_l000?oool4o`000oooo`07o`00ooooooooooooo`00ooooo`00
00?oool2o`000_ooo`;o00000oooool00?ooo`02oooo0_l000?oool00ol00?ooool0000=oooo0_l0
00Woool3o`002?ooo`03o`00oooooooo00;oool00ol00?ooool0000;oooo00?o003oooooool00ol0
00;oool00ol00?ooool00002o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`03o`00oooooooo00goool2
o`000oooo`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`05o`00ooooo`00ooooo`0000Coool2o`000_ooo`05o`00ooooooooooooo`0000;oool00ol00?oo
ooooo`02o`0000?ooooo003o00001_ooo`04o`00oooooooooooo0_l002koool100000Oooo`007Ooo
o`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Coool00ol00?ooool0000>oooo0ol0
00;oool00ol00?ooool00002oooo0_l000Coool00ol00?ooool00002oooo0ol000Coool2o`0000Go
oooo003ooooooooo00000oooo`;o0002oooo0ol000?oool2o`000oooo`Co0003oooo00Oo003ooooo
oooooooo003ooooo00000oooo`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00
ooooo`0000goool2o`002Oooo`?o0008oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo
00Woool00ol00?ooooooo`03o`000_ooo`03o`00ooooo`0000;o00000oooool00?ooo`06oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003
oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool2o`000oooo`?o00000oooool00?ooo`04
oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o00000oooool00?ooo`03oooo0_l0
00;oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l00003ooooo`00o`0000Koool0
1Ol00?ooooooooooool0000_oooo0@00007oool001goool00`000?ooooooo`09oooo00?o003ooooo
ool08oooo`;o0004oooo00?o003ooooo00003_ooo`?o0002oooo00?o003ooooo00000_ooo`;o0004
oooo00?o003ooooo00000_ooo`?o0004oooo0_l00005ooooo`00ooooooooo`0000?oool2o`000_oo
o`?o0003oooo0_l000?oool4o`000oooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000_oo
o`;o00000oooool00?ooo`02oooo0_l000?oool00ol00?ooool0000=oooo0_l000Woool3o`002?oo
o`05o`00ooooooooooooo`0000;oool00ol00?ooooooo`09oooo00?o003oooooool00ol000;oool0
0ol00?ooool00002o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool00ol00?oo
ooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool3o`0000?ooooo003oool00oooo`;o0002oooo00Go003ooooooooooooo00000_oo
o`03o`00oooooooo00;o00000oooool00?l00006oooo00Go003ooooooooooooo0000;oooo`400001
oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo02?oool2o`001?ooo`03o`00ooooo`00
00koool3o`000_ooo`03o`00ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?oo
o`;o00001Oooool00?ooooooool00003oooo0_l000;oool3o`000oooo`;o0003oooo1?l000?oool0
1ol00?ooooooooooool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003
oooo00?o003ooooo00003Oooo`;o0009oooo0ol000Soool01Ol00?ooooooooooool00002oooo00?o
003oooooool02Oooo`03o`00oooooooo00?o0002oooo00?o003ooooo00000_l00003ooooo`00oooo
00Koool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00002?ooo`03o`00
ooooo`0000?oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`;o0003oooo0ol00003oooo
o`00oooo00Coool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol00003ooooo`00oooo
00?oool2o`000_ooo`05o`00ooooooooooooo`0000;oool00ol00?ooooooo`02o`0000?ooooo003o
00001_ooo`05o`00ooooooooooooo`0002ooool100000Oooo`007Oooo`030000oooooooo00Woool0
0ol00?ooooooo`0Soooo0_l000Coool00ol00?ooool0000>oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?ooo`;o00001Oooool00?oooooo
ool00003oooo0_l000;oool3o`000oooo`;o0003oooo1?l000?oool01ol00?ooooooooooool00?oo
ool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo00003Ooo
o`;o0009oooo0ol000Soool01Ol00?ooooooooooool00002oooo00?o003oooooool02?ooo`;o0002
oooo0ol000;oool00ol00?ooooooo`02o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool0
1?l00?ooooooool000;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`03o`00oooooooo
00;oool00ol00?ooooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool3o`0000?ooooo003oool00oooo`05o`00ooooooooooooo`00
00?oool01?l00?ooooooool000;oool2o`0000?ooooo003o00001_ooo`05o`00ooooooooooooo`00
02ooool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Coool0
0ol00?ooool0000>oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool2o`001?ooo`03o`00
ooooo`0000;oool3o`001?ooo`;o00001Oooool00?ooooooool00003oooo0_l000;oool3o`000ooo
o`;o0003oooo1?l000?oool01ol00?ooooooooooool00?ooool00003oooo0_l000;oool2o`0000?o
oooo003oool00_ooo`;o0003oooo00?o003ooooo00003Oooo`;o0009oooo0ol000Soool01Ol00?oo
ooooooooool00002oooo00?o003oooooool01oooo`?o0002oooo0_l00004ooooo`00ooooo`000_oo
o`;o00000oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000Soool00ol00?ooool00003oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool2
o`000oooo`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`?o00000oooool00?ooo`03oooo00Go003ooooooooooooo00000oooo`04o`00ooooooooo`000_oo
o`;o00000oooool00?l00006oooo00Go003ooooooooooooo0000;oooo`400001oooo000Moooo0`00
00Woool00ol00?ooooooo`0Soooo0_l000Coool00ol00?ooool0000>oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool3o`001?ooo`;o00001Oooool0
0?ooooooool00003oooo0_l000;oool3o`000oooo`;o0003oooo1?l000?oool01ol00?oooooooooo
ool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo
00003Oooo`;o0009oooo0ol000Soool01Ol00?ooooooooooool00002oooo00?o003oooooool01ooo
o`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003oooo00?o
003oooooool00_ooo`03o`00oooooooo00Soool2o`000oooo`?o00000oooool00?ooo`04oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`?o00000oooool00?ooo`03oooo00Go003ooooo
oooooooo00000oooo`04o`00ooooooooo`000_ooo`;o00000oooool00?l00006oooo00Go003ooooo
oooooooo0000;Oooo`<00001oooo000Moooo00<0003oooooool02Oooo`03o`00oooooooo02?oool2
o`001?ooo`03o`00ooooo`0000koool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000ooo
o`;o0002oooo0ol000?oool2o`000oooo`Co0003oooo00Oo003ooooooooooooo003ooooo00000ooo
o`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`0000goool2o`002Ooo
o`?o0008oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00Ooool3o`000_ooo`;o0000
1?ooool00?ooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool0
0ol00?ooooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool3o`0000?ooooo003oool00oooo`05o`00ooooooooooooo`0000?oool0
1?l00?ooooooool000;oool2o`0000?ooooo003o00001_ooo`05o`00ooooooooooooo`0002ooool1
00000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Coool00ol00?oo
ool0000>oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`?o0004oooo0_l00005ooooo`00ooooooooo`0000?oool2o`000_ooo`03o`00
ooooo`0000?oool2o`000oooo`;o00000oooool00?ooo`02oooo00Oo003ooooooooooooo003ooooo
00000oooo`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`0000goool2
o`002Oooo`?o0008oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00Ooool3o`000_oo
o`;o00001?ooool00?ooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool0
1?l00?ooooooool000;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`03o`00oooooooo
00;oool00ol00?ooooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool3o`0000?ooooo003oool00oooo`05o`00ooooooooooooo`00
00?oool01?l00?ooooooool000;oool2o`0000?ooooo003o00001_ooo`05o`00ooooooooooooo`00
02ooool100000Oooo`007Oooo`030000oooooooo00Woool00ol00?ooooooo`0Soooo0_l000Coool0
0ol00?ooool0000>oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00?o003ooooo00000_ooo`?o0004oooo0_l00005ooooo`00ooooooooo`0000?oool2o`000_oo
o`03o`00ooooo`0000?oool2o`000oooo`;o00000oooool00?ooo`02oooo00Oo003ooooooooooooo
003ooooo00000oooo`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`00
00goool2o`002Oooo`?o0008oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00Ooool3
o`000_ooo`;o00001?ooool00?ooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`00
00;oool01?l00?ooooooool000;oool00ol00?ooool00008oooo00?o003ooooo00000oooo`;o0003
oooo00?o003oooooool02?ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo0ol00003ooooo`00oooo00?oool01Ol00?ooooooooooool00003
oooo00Co003ooooooooo0002oooo0_l00003ooooo`00o`0000Koool01Ol00?ooooooooooool0000_
oooo0@00007oool000Koool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`03o`00oooooooo02?oool2o`001?oo
o`03o`00ooooo`0000koool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool00ol00?ooool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000oooo`;o0002
oooo00?o003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00;oool01ol00?oooooooooo
ool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo
00003Oooo`;o0009oooo0ol000Soool01Ol00?ooooooooooool00002oooo00?o003oooooool01ooo
o`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003oooo0_l0
00?oool00ol00?ooooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool3o`0000Oooooo003ooooooooo003ooooo00000oooo`05o`00
ooooooooooooo`0000;oool00ol00?ooooooo`02o`0000?ooooo003o00001_ooo`05o`00oooooooo
ooooo`0002ooool100000Oooo`001Oooo`030000oooo000000Soool01`000?ooooooooooo`000?oo
o`000006oooo00<0003oooooool02_ooo`03o`00oooooooo02;oool2o`001?ooo`03o`00ooooo`00
00koool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?oo
ool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000oooo`;o0002oooo00?o003ooooo
00000oooo`;o0003oooo0_l00003ooooo`00oooo00;oool01ol00?ooooooooooool00?ooool00003
oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo00003Oooo`;o0009
oooo0ol000Soool01Ol00?ooooooooooool00002oooo00?o003oooooool01oooo`?o0002oooo0_l0
0004ooooo`00ooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000Soool00ol00?ooool00003oooo0_l000?oool00ol00?oo
ooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool3o`0000Oooooo003ooooooooo003ooooo00000oooo`05o`00ooooooooooooo`00
00;oool00ol00?ooooooo`02o`0000?ooooo003o00001_ooo`05o`00ooooooooooooo`0002ooool1
00000Oooo`001Oooo`030000oooo000000Soool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`@00009oooo00?o003oooooool08_ooo`;o0004oooo00?o003ooooo00003_ooo`03o`00ooooo`00
00;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`001?oo
o`;o00001Oooool00?ooooooool00003oooo0_l000;oool00ol00?ooool00003oooo0_l000?oool2
o`0000?ooooo003oool00_ooo`07o`00ooooooooooooo`00ooooo`0000?oool2o`000_ooo`;o0000
0oooool00?ooo`02oooo0_l000?oool00ol00?ooool0000=oooo0_l000Woool3o`001?ooo`05o`00
ooooooooooooo`0000?oool01?l00?ooooooool000Woool3o`000_ooo`;o00001?ooool00?ooool0
00;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool0
0ol00?ooool00003oooo00?o003oooooool00_ooo`03o`00ooooo`0000?oool2o`000oooo`03o`00
oooooooo00Soool2o`000oooo`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`?o00001oooool00?ooooooool00?ooool00003oooo00Go003ooooooooooooo
00000_ooo`03o`00oooooooo00;o00000oooool00?l00006oooo00Go003ooooooooooooo0000;?oo
o`@00001oooo0005oooo00<0003oool000002Oooo`030000oooooooo00800007oooo00<0003ooooo
ool02_ooo`03o`00oooooooo02;oool2o`001?ooo`03o`00ooooo`0000koool00ol00?ooool00002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002oooo0ol000Coool2
o`0000Gooooo003ooooooooo00000oooo`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l0
0003ooooo`00oooo00;oool01ol00?ooooooooooool00?ooool00003oooo0_l000;oool2o`0000?o
oooo003oool00_ooo`;o0003oooo00?o003ooooo00003Oooo`;o0009oooo0ol000Coool01Ol00?oo
ooooooooool00003oooo00Co003ooooooooo0009oooo0ol000;oool2o`0000Cooooo003ooooo0002
oooo0_l00003ooooo`00oooo00Koool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`03o`00oooooooo00;oool00ol00?ooool00003oooo0_l000?oool00ol00?oo
ooooo`08oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool3o`0000Oooooo003ooooooooo003ooooo00000oooo`05o`00ooooooooooooo`00
00;oool00ol00?ooooooo`02o`0000?ooooo003o00001_ooo`05o`00ooooooooooooo`0002ooool1
00000Oooo`001Oooo`030000oooo000000Ooool00`000?ooo`000002oooo00<0003oooooool01_oo
o`030000oooooooo00[oool00ol00?ooooooo`0Roooo0_l000Coool00ol00?ooool0000>oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_oo
o`?o0004oooo0_l00005ooooo`00ooooooooo`0000?oool2o`000_ooo`03o`00ooooo`0000?oool2
o`000oooo`;o00000oooool00?ooo`02oooo00Oo003ooooooooooooo003ooooo00000oooo`;o0002
oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`0000Coool00ol00?ooooooo`06
oooo0_l000Woool3o`001?ooo`05o`00ooooooooooooo`0000?oool01?l00?ooooooool000Woool3
o`000_ooo`;o00001?ooool00?ooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`00
00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00?o003oooooool00_ooo`03o`00
ooooo`0000?oool2o`000oooo`03o`00oooooooo00Soool2o`000oooo`?o00000oooool00?ooo`04
oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o00001oooool00?ooooooool00?oo
ool00003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00;o00000oooool00?l00006
oooo00Go003ooooooooooooo0000;oooo`400001oooo0006oooo00<0003oooooool01_ooo`<00002
oooo0`0000Koool00`000?ooooooo`0:oooo00?o003oooooool08_ooo`;o0004oooo00?o003ooooo
00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000ooo
o`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00;oool01ol00?oo
ooooooooool00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o
003ooooo00001?ooo`03o`00oooooooo00Koool2o`002Oooo`?o0004oooo00Go003ooooooooooooo
00000oooo`04o`00ooooooooo`002Oooo`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`;o0000
0oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`?o0003oooo00Go003ooooooooooooo
00001_ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo0ol00007ooooo`00ooooooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002
oooo00?o003oooooool00_l00003ooooo`00oooo00Koool01Ol00?ooooooooooool0000_oooo0@00
007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08_ooo`;o0004oooo00?o003ooooo
00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000ooo
o`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00004ooooo`00oooooooo0_l000?oool0
0ol00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo
00001?ooo`03o`00oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool01Ol00?oooooooooo
ool00002oooo00?o003oooooool01oooo`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`;o0000
0oooool00?ooo`06oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`?o0003oooo00Go003ooooooooooooo
00001_ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo0ol00007ooooo`00ooooooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002
oooo00?o003oooooool00_l00003ooooo`00oooo00Koool01Ol00?ooooooooooool0000_oooo0@00
007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08_ooo`;o0004oooo00?o003ooooo
00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo0ol000Coool2o`0000Gooooo003ooooooooo00000ooo
o`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00004ooooo`00oooooooo0_l000?oool0
0ol00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003oooo00?o003ooooo
00001?ooo`03o`00oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool01Ol00?oooooooooo
ool00002oooo00?o003oooooool01oooo`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`;o0000
0oooool00?ooo`03oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`;o0004oooo00?o003ooooo00000_ooo`?o0003oooo00Go003ooooooooooooo
00001_ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo0ol00007ooooo`00ooooooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002
oooo00?o003oooooool00_l00003ooooo`00oooo00Koool01Ol00?ooooooooooool0000_oooo0@00
007oool001goool300002_ooo`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo
00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo0ol000?oool3o`0000Gooooo003ooooooooo00000ooo
o`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00?o0003oooo00?o
003ooooo00000oooo`;o0002oooo0_l00003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`00
00Coool00ol00?ooooooo`06oooo0_l000Woool3o`000oooo`;o0003oooo00Go003ooooooooooooo
00000_ooo`03o`00oooooooo00Ooool3o`000_ooo`;o00001?ooool00?ooool000;oool2o`0000?o
oooo003oool00oooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000;oool2o`001?ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo
oooooooo00001_ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?ooooooool000;oool0
0ol00?ooool00003oooo0ol00007ooooo`00ooooooooo`00ooooo`0000?oool01Ol00?oooooooooo
ool00002oooo00?o003oooooool00_l00003ooooo`00oooo00Koool01Ol00?ooooooooooool0000]
oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00Coool00ol00?ooool00008oooo00?o003oooooool00oooo`03o`00ooooo`0000;oool00ol00?oo
ool00002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`000oooo`?o00001Oooool0
0?ooooooool00003oooo0_l000;oool00ol00?ooool00003oooo0_l000?oool2o`0000?ooooo003o
ool00ol000?oool00ol00?ooool00003oooo0_l000;oool2o`0000?ooooo003oool00_ooo`;o0003
oooo00?o003ooooo00001?ooo`03o`00oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool0
1Ol00?ooooooooooool00002oooo00?o003oooooool01oooo`?o0002oooo0_l00004ooooo`00oooo
o`000_ooo`;o00000oooool00?ooo`03oooo00Oo003ooooooooo003ooooo003oool00_l000;oool0
1_l00?ooooooool00?ooool000;oool2o`001?ooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00Go003ooooooooooooo00001_ooo`;o0003oooo0ol00003ooooo`00oooo00Coool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0ol00007ooooo`00ooooooooo`00ooooo`0000?oool0
1Ol00?ooooooooooool00002oooo00?o003oooooool00_l00003ooooo`00oooo00Koool01Ol00?oo
ooooooooool0000_oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000Coool00ol00?ooool00008oooo00?o003oooooool00oooo`03o`00ooooo`00
00;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool3o`000ooo
o`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo00000ooo
o`;o0003oooo0_l00003ooooo`00oooo00?o0003oooo00?o003ooooo00000oooo`;o0002oooo0_l0
0003ooooo`00oooo00;oool2o`000oooo`03o`00ooooo`0000Coool00ol00?ooooooo`06oooo0_l0
00Woool3o`000oooo`;o0003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00Ooool3
o`000_ooo`;o00001?ooool00?ooool000;oool01?l00?ooooooool000Coool01ol00?ooooooool0
0?ooool00?ooo`02o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`;o0004oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000?o
oooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool3o`0000Oooooo003o
003ooooo003ooooo00000oooo`05o`00ooooooooooooo`0000;oool00ol00?ooooooo`02o`002Ooo
o`05o`00ooooooooooooo`0002ooool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?oo
ooooo`0Qoooo00?o003ooooo00001?ooo`03o`00ooooo`0000Soool00ol00?ooooooo`03oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_oo
o`?o0003oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?oo
ool00003oooo0_l000?oool2o`0000?ooooo003oool00ol000?oool00ol00?ooool00003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`000oooo`03o`00ooooo`0000Coool00ol00?ooooooo`06
oooo0_l000Woool3o`000oooo`;o0003oooo0_l00003ooooo`00o`0000;oool00ol00?ooooooo`07
oooo0ol000;oool2o`0000Cooooo003ooooo0002oooo00Co003ooooooooo0004oooo00Oo003ooooo
oooo003ooooo003oool00_l000;oool01_l00?ooooooool00?ooool000;oool2o`001?ooo`03o`00
ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooooooooooo00001_ooo`;o0003oooo0ol0
0003ooooo`00oooo00Coool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol00007oooo
o`00o`00ooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l0
00Woool01Ol00?ooooooooooool0000_oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000Coool00ol00?ooool00008oooo00?o003oooooool00ooo
o`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool3o`000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o
003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00?o0003oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooooooo0003oooo0_l000?oool00ol00?ooool00004oooo00?o003ooooo
ool01_ooo`;o0009oooo0ol000?oool2o`000oooo`;o00000oooool00?l00002oooo00?o003ooooo
ool01oooo`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`04o`00ooooooooo`001?ooo`07o`00
ooooooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0002oooo0_l000Coool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000ooo
o`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o0000
1oooool00?l00?ooool00?ooool00003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo
00;o0009oooo00Go003ooooooooooooo0000;oooo`400001oooo000Moooo00<0003oooooool02_oo
o`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo00002?ooo`03o`00oooooooo
00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?oo
ool00002oooo0ol000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_oo
o`03o`00ooooo`0000?oool2o`000oooo`;o00000oooool00?ooo`03o`000oooo`03o`00ooooo`00
00?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0003oooo00?o003ooooo00001?ooo`03o`00
oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool2o`0000?ooooo003o00000_ooo`03o`00
oooooooo00Ooool3o`000_ooo`;o00001?ooool00?ooool000;oool01?l00?ooooooool000Coool0
1ol00?ooooooool00?ooool00?ooo`02o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`;o0004
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l0
00?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool3
o`0000Oooooo003o003ooooo003ooooo00000oooo`05o`00ooooooooooooo`0000;oool00ol00?oo
ooooo`02o`002Oooo`05o`00ooooooooooooo`0002ooool100000Oooo`007Oooo`<0000:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000Coool00ol00?ooool00008oooo00?o003oooooool00ooo
o`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool3o`000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o
003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00?o0003oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooooooo0003oooo0_l000?oool00ol00?ooool00004oooo00?o003ooooo
ool01_ooo`;o0009oooo0ol000?oool2o`000oooo`;o00000oooool00?l00002oooo00?o003ooooo
ool01oooo`?o0002oooo0_l00004ooooo`00ooooo`000_ooo`04o`00ooooooooo`001?ooo`07o`00
ooooooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0002oooo0_l000Coool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000ooo
o`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o0000
1oooool00?l00?ooool00?ooool00003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo
00;o0009oooo00Go003ooooooooooooo0000;Oooo`<00001oooo000Moooo00<0003oooooool02_oo
o`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo00002?ooo`03o`00oooooooo
00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?oo
ool00002oooo0ol000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_oo
o`03o`00ooooo`0000?oool2o`000oooo`;o00000oooool00?ooo`03o`000oooo`03o`00ooooo`00
00?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0003oooo00?o003ooooo00001?ooo`03o`00
oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool2o`0000?ooooo003o00000_ooo`03o`00
oooooooo00Ooool3o`000_ooo`;o00001?ooool00?ooool000;oool01?l00?ooooooool000Coool0
1ol00?ooooooool00?ooool00?ooo`02o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`;o0004
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l0
00?oool3o`0000?ooooo003oool01?ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool3
o`0000Oooooo003o003ooooo003ooooo00000oooo`05o`00ooooooooooooo`0000;oool00ol00?oo
ooooo`02o`002Oooo`05o`00ooooooooooooo`0002ooool100000Oooo`007Oooo`030000oooooooo
00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00001?ooo`03o`00ooooo`0000Soool00ol00?oo
ooooo`03oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`?o0003oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l0
00;oool00ol00?ooool00003oooo0_l000?oool2o`0000?ooooo003oool00ol000?oool00ol00?oo
ool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000oooo`03o`00ooooo`0000Coool0
0ol00?ooooooo`06oooo0_l000Woool3o`000oooo`;o0003oooo0_l00003ooooo`00o`0000;oool0
0ol00?ooooooo`07oooo0ol000;oool2o`0000Cooooo003ooooo0005oooo00?o003oooooool00_oo
o`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0002oooo0_l0
00Coool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2
o`000oooo`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`?o00001oooool00?l00?ooool00?ooool00003oooo00Go003ooooooooooooo00000_ooo`03o`00
oooooooo00;o0009oooo00Go003ooooooooooooo0000;oooo`400001oooo000Moooo00<0003ooooo
ool02_ooo`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo00002?ooo`03o`00
oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oo
ooooooooo`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00003ooooo`00oooo00?o0003
oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?oo
ooooool000Coool00ol00?ooooooo`06oooo0_l000Woool3o`000oooo`;o0003oooo0_l00003oooo
o`00o`0000;oool00ol00?ooooooo`07oooo0ol000;oool2o`0000Cooooo003ooooo0005oooo00?o
003oooooool00_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003o
oooo0002oooo0_l000Coool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000Koool2o`000oooo`?o00000oooool00?ooo`04oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`?o00001oooool00?l00?ooool00?ooool00003oooo00Go003ooooooooooooo
00000_ooo`03o`00oooooooo00;o0009oooo00Go003ooooooooooooo0000;oooo`400001oooo000M
oooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo
00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`00
00;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo00000oooo`;o0003oooo0_l00003oooo
o`00oooo00?o0003oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l0
00;oool01?l00?ooooooool000Coool00ol00?ooooooo`06oooo0_l000Woool3o`000oooo`;o0003
oooo0_l00003ooooo`00o`0000;oool00ol00?ooooooo`07oooo0ol00008ooooo`00ooooo`00oooo
o`00ooooo`001Oooo`03o`00oooooooo00;oool01ol00?ooooooool00?ooool00?ooo`02o`000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`;o0004oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000?ooooo003oool01?ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool3o`0000Oooooo003o003ooooo003ooooo00000ooo
o`05o`00ooooooooooooo`0000;oool00ol00?ooooooo`02o`002Oooo`05o`00ooooooooooooo`00
02ooool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo
00001?ooo`03o`00ooooo`0000Soool00ol00?ooooooo`03oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`0000?oool2
o`000oooo`;o00000oooool00?ooo`03o`000oooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0004oooo00?o003oooooool01_ooo`;o0009
oooo0ol000?oool2o`000oooo`;o00000oooool00?l00002oooo00?o003oooooool01oooo`?o0000
2?ooool00?ooool00?ooool00?ooool000Goool00ol00?ooooooo`02oooo0_l00005ooooo`00oooo
o`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0002oooo0_l000Coool00ol00?ooool00002
oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000oooo`?o00000oooool0
0?ooo`04oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o00001oooool00?l00?oo
ool00?ooool00003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00;o0009oooo00Go
003ooooooooooooo0000;oooo`400001oooo000Moooo0`0000[oool00ol00?ooooooo`0Qoooo00?o
003ooooo00001?ooo`03o`00ooooo`0000Soool00ol00?ooooooo`03oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`00
00?oool2o`000oooo`05o`00ooooooooo`00oooo00?o0003oooo00?o003ooooo00000oooo`;o0002
oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?ooooooool000Coool00ol00?ooooooo`06
oooo0_l000Woool3o`000oooo`;o0003oooo0_l00003ooooo`00o`0000;oool00ol00?ooooooo`07
oooo0ol00008ooooo`00ooooo`00ooooo`00ooooo`001Oooo`03o`00oooooooo00;oool2o`0000Go
oooo003ooooo003oool00_l000;oool01_l00?ooooooool00?ooool000;oool2o`001?ooo`03o`00
ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooooooooooo00001_ooo`;o0003oooo0ol0
0003ooooo`00o`0000Coool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol00007oooo
o`00o`00ooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l0
00Woool01Ol00?ooooooooooool0000]oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000Coool00ol00?ooool00008oooo00?o003oooooool00ooo
o`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l0
00;oool00ol00?ooool00003oooo0_l000?oool01Ol00?ooooooool00?ooo`03o`000oooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0004
oooo00?o003oooooool01_ooo`;o0009oooo0ol000?oool2o`000oooo`;o00000oooool00?l00002
oooo00?o003oooooool01oooo`?o00002?ooool00?ooool00?ooool00?ooool000Goool00ol00?oo
ooooo`02oooo0_l00005ooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0002
oooo0_l000Coool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`00
00Koool2o`000oooo`?o00000oooool00?l00004oooo00Co003ooooooooo0002oooo00?o003ooooo
00000oooo`?o00001oooool00?l00?ooool00?ooool00003oooo00Go003ooooooooooooo00000_oo
o`03o`00oooooooo00;o0009oooo00Go003ooooooooooooo0000;oooo`400001oooo000Moooo00<0
003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00004oooo00?o003ooooo00002?oo
o`03o`00oooooooo00?oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool0
1?l00?ooooooooooo`;o0002oooo00?o003ooooo00000oooo`;o0003oooo00Go003ooooooooo003o
ool00ol000?oool00ol00?ooool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_oo
o`04o`00ooooooooo`001?ooo`03o`00oooooooo00Koool2o`002Oooo`?o0003oooo0_l000?oool2
o`0000?ooooo003o00000_ooo`03o`00oooooooo00Ooool3o`0000Sooooo003ooooo003ooooo003o
oooo0005oooo00?o003oooooool00_ooo`Co00000oooool00?ooo`02o`000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`;o0004oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?oo
ooooooooool00006oooo0_l000?oool3o`0000?ooooo003o00001?ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool3o`0000Oooooo003o003ooooo003ooooo00000oooo`05o`00oooooooo
ooooo`0000;oool00ol00?ooooooo`02o`002Oooo`05o`00ooooooooooooo`0002ooool100000Ooo
o`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00001?ooo`03o`00
ooooo`0000Soool00ol00?ooooooo`03oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool0
0ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?oo
ool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`0000?oool2o`000oooo`05o`00
ooooooooo`00oooo00?o0003oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooooooo0003
oooo0_l000;oool01?l00?ooooooool000Coool00ol00?ooooooo`06oooo0_l000Woool3o`000ooo
o`;o0003oooo0_l00003ooooo`00oooo00;oool00ol00?ooooooo`07oooo0ol00008ooooo`00oooo
o`00ooooo`00ooooo`001Oooo`03o`00oooooooo00;oool4o`0000?ooooo003oool00_l000;oool0
1_l00?ooooooool00?ooool000;oool3o`000oooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00Go003ooooooooooooo00001_ooo`;o0003oooo0ol00003ooooo`00o`0000Coool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0ol00007ooooo`00o`00ooooo`00ooooo`0000?oool0
1Ol00?ooooooooooool00002oooo00?o003oooooool00_l000Woool01Ol00?ooooooooooool0000_
oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00Coool00ol00?ooool00008oooo00?o003oooooool00oooo`03o`00ooooo`0000;oool00ol00?oo
ool00002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go
003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00003oooo0_l0
00?oool01Ol00?ooooooool00?ooo`03o`000oooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0004oooo00?o003oooooool01_ooo`;o0009
oooo0ol000?oool2o`000oooo`;o00000oooool00?ooo`02oooo00?o003oooooool01oooo`?o0000
2?ooool00?ooool00?ooool00?ooool000Goool00ol00?ooooooo`02oooo1?l00003ooooo`00oooo
00;o0002oooo00Ko003ooooooooo003ooooo0002oooo0ol000?oool00ol00?ooool00002oooo00?o
003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000oooo`?o00000oooool00?l00004
oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o00001oooool00?l00?ooool00?oo
ool00003oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00;o0009oooo00Go003ooooo
oooooooo0000;oooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool0
0ol00?ooool00004oooo00?o003ooooo00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo
00000oooo`;o0003oooo00Go003ooooooooo003oool00ol000?oool00ol00?ooool00003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`001?ooo`03o`00oooooooo
00Koool2o`002Oooo`?o0003oooo0_l000?oool2o`0000?ooooo003oool00_ooo`03o`00oooooooo
00Ooool3o`0000Sooooo003ooooo003ooooo003ooooo0005oooo00?o003oooooool00_ooo`Co0000
0oooool00?ooo`02o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`?o0003oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000?o
oooo003o00000oooo`;o0002oooo00Ko003ooooooooo003ooooo0003oooo0ol00007ooooo`00o`00
ooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l000Woool0
1Ol00?ooooooooooool0000_oooo0@00007oool001goool300002_ooo`03o`00oooooooo027oool0
0ol00?ooool00004oooo00?o003ooooo00002?ooo`03o`00oooooooo00?oool00ol00?ooool00002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo
00000oooo`;o0003oooo00Go003ooooooooo003oool00ol000?oool00ol00?ooool00003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`001?ooo`03o`00oooooooo
00Koool2o`002Oooo`03o`00ooooo`0000?oool2o`000oooo`;o00000oooool00?ooo`02oooo00?o
003oooooool01oooo`?o00002?ooool00?ooool00?ooool00?ooool000Goool00ol00?ooooooo`02
oooo1?l00004ooooo`00ooooo`000oooo`06o`00ooooooooo`00ooooo`000_ooo`?o0003oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3
o`0000?ooooo003o00000oooo`;o0002oooo00Ko003ooooooooo003ooooo0003oooo0ol00007oooo
o`00o`00ooooo`00ooooo`0000?oool01Ol00?ooooooooooool00002oooo00?o003oooooool00_l0
00Woool01Ol00?ooooooooooool0000]oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000Coool00ol00?ooool00008oooo00?o003oooooool00ooo
o`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l0
00;oool00ol00?ooool00003oooo0_l000?oool01Ol00?ooooooool00?ooo`03o`000oooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0004
oooo00?o003oooooool01_ooo`;o0009oooo00?o003ooooo00000oooo`;o0003oooo0_l00003oooo
o`00oooo00;oool00ol00?ooooooo`07oooo0ol00008ooooo`00ooooo`00ooooo`00ooooo`001Ooo
o`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002
oooo0ol000?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`00
00Koool2o`000oooo`?o00000oooool00?l00003oooo0_l000;oool01_l00?ooooooool00?ooool0
00?oool3o`0000Cooooo003o003oool2o`001?ooo`05o`00ooooooooooooo`0000;oool00ol00?oo
ooooo`02o`002Oooo`05o`00ooooooooooooo`0002ooool100000Oooo`007Oooo`030000oooooooo
00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00001?ooo`03o`00ooooo`0000Soool00ol00?oo
ooooo`03oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003ooooo
ooooool2o`000_ooo`03o`00ooooo`0000?oool2o`000_ooo`06o`00ooooooooooooo`00oooo0ol0
00?oool00ol00?ooool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00
ooooooooo`000oooo`;o0008oooo0_l000Soool2o`0000?ooooo003oool00_ooo`;o0003oooo0_l0
0003ooooo`00oooo00;oool00ol00?ooooooo`07oooo0ol00008ooooo`00ooooo`00ooooo`00oooo
o`001Oooo`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003o
oooo0002oooo0ol000?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000Koool2o`000oooo`?o00000oooool00?l00003oooo0_l000;oool01_l00?ooooooool0
0?ooool000?oool3o`0000?ooooo003o00000ol000Coool01Ol00?ooooooooooool00002oooo00?o
003oooooool00_l000Woool01Ol00?ooooooooooool0000_oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000Coool00ol00?ooool00004oooo00Go
003ooooooooooooo00001Oooo`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_oo
o`04o`00oooooooooooo0_l000;oool00ol00?ooool00003oooo0_l000;oool01_l00?oooooooooo
ool00?ooo`?o0003oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`002?ooo`;o0008oooo0_l00003ooooo`00oooo00;oool2
o`000oooo`;o00000oooool00?ooo`02oooo00?o003oooooool01oooo`?o00000oooool00?ooo`02
oooo00?o003ooooo00001Oooo`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00Ko
003ooooooooo003ooooo0002oooo0ol000?oool00ol00?ooool00002oooo00?o003ooooo00000ooo
o`05o`00ooooooooooooo`0000Koool2o`000oooo`?o00000oooool00?l00003oooo0_l000;oool0
1_l00?ooooooool00?ooool000?oool3o`0000?ooooo003o00000ol000Coool01Ol00?oooooooooo
ool00002oooo00?o003oooooool00_l000Woool01Ol00?ooooooooooool0000_oooo0@00007oool0
01?oool500001Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00001?oo
o`03o`00ooooo`0000Coool01Ol00?ooooooooooool00005oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`0000?oool2
o`000_ooo`06o`00ooooooooooooo`00oooo0ol000?oool00ol00?ooool00003oooo0_l000;oool0
1?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0008oooo0_l000Soool0
1?l00?ooooooool000?oool2o`000oooo`;o00000oooool00?ooo`02oooo00?o003oooooool01ooo
o`?o00000oooool00?ooo`02oooo00?o003ooooo00001Oooo`03o`00oooooooo00;oool4o`0000Co
oooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002oooo0ol000?oool00ol00?ooool00002
oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000oooo`?o00001_ooool0
0?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0003oooo0ol00003ooooo`00o`00
00?o0004oooo00Go003ooooooooooooo00000_ooo`03o`00oooooooo00;o0009oooo00Go003ooooo
oooooooo0000;oooo`400001oooo000Eoooo00<0003oooooool01Oooo`030000oooooooo00[oool0
0ol00?ooooooo`0Qoooo00?o003ooooo00001?ooo`03o`00ooooo`0000Coool01Ol00?oooooooooo
ool00005oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003ooooo
ooooool2o`000_ooo`03o`00ooooo`0000?oool2o`000_ooo`06o`00ooooooooooooo`00oooo0ol0
00?oool00ol00?ooool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00
ooooooooo`000oooo`;o0008oooo0_l000Soool01?l00?ooooooool000?oool2o`000oooo`;o0000
0oooool00?ooo`02oooo00?o003oooooool01oooo`?o00000oooool00?ooo`02oooo00?o003ooooo
00001Oooo`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003o
oooo0002oooo0ol000?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000Koool2o`000oooo`?o00001_ooool00?l00?ooool00?ooo`;o0002oooo00Ko003ooooo
oooo003ooooo0003oooo0ol00003ooooo`00o`0000?o0004oooo00Go003ooooooooooooo00000_oo
o`03o`00oooooooo00;o0009oooo00Co003ooooooooo000`oooo0@00007oool001Goool00`000?oo
ooooo`05oooo100000Woool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`;o00000oooool0
0?ooo`03oooo00Go003ooooooooooooo00001Oooo`03o`00ooooo`0000;oool00ol00?ooool00002
oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo
003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00003oooo0_l000;oool0
1_l00?ooooooooooool00?ooo`?o0003oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo
oooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`002?ooo`;o0008oooo00Co003ooooo
oooo0003oooo0_l000?oool2o`0000?ooooo003oool00_ooo`03o`00oooooooo00Ooool3o`0000?o
oooo003oool00_ooo`03o`00ooooo`0000Goool00ol00?ooooooo`02oooo1?l00004ooooo`00oooo
o`000oooo`06o`00ooooooooo`00ooooo`000_ooo`?o0003oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000Kooooo003o003ooooo
003oool2o`000_ooo`06o`00ooooooooo`00ooooo`000oooo`?o00000oooool00?l00003o`001?oo
o`05o`00ooooooooooooo`0000;oool01?l00?ooooooool000[oool01?l00?ooooooool002goool4
00000Oooo`005Oooo`030000oooooooo00Goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool2o`0000?ooooo003oool00oooo`05o`00ooooooooooooo`0000Goool0
0ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002
oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002
oooo00?o003ooooo00000oooo`;o0002oooo00Ko003ooooooooooooo003oool3o`000oooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003
oooo0_l000Soool2o`002?ooo`04o`00ooooooooo`000oooo`;o0003oooo0_l00003ooooo`00oooo
00;oool00ol00?ooooooo`07oooo0ol00003ooooo`00oooo00;oool00ol00?ooool00005oooo00?o
003oooooool00_ooo`Co00001?ooool00?ooool000?oool01_l00?ooooooool00?ooool000;oool3
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006
oooo0_l000?oool3o`0000Kooooo003o003ooooo003oool2o`000_ooo`06o`00ooooooooo`00oooo
o`000oooo`?o00000oooool00?l00003o`001?ooo`05o`00ooooooooooooo`0000;oool01?l00?oo
ooooool000[oool01?l00?ooooooool0033oool100000Oooo`005Oooo`030000oooooooo00Goool0
0`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool2o`0000?ooooo003o
ool00oooo`05o`00ooooooooooooo`0000Goool00ol00?ooool00002oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000?oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00
ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo00000oooo`;o0002oooo00Ko
003ooooooooooooo003oool3o`000oooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool2o`002?ooo`04o`00oooooooo
o`000oooo`;o0003oooo0_l00003ooooo`00oooo00;oool00ol00?ooooooo`07oooo0ol00003oooo
o`00oooo00;oool00ol00?ooool00005oooo00?o003oooooool00_ooo`Co00001?ooool00?ooool0
00?oool01_l00?ooooooool00?ooool000;oool3o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000Kooooo003o003ooooo
003oool2o`000_ooo`06o`00ooooooooo`00ooooo`000oooo`?o00000oooool00?l00003o`001?oo
o`05o`00ooooooooooooo`0000;oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool1
00000Oooo`005?ooo`800007oooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?oo
ool00003oooo0_l00003ooooo`00oooo00?oool01Ol00?ooooooooooool00005oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00003oooo00?o003ooooo00000_l000?oool00ol00?oo
ool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`000ooo
o`;o0008oooo0_l000Soool01?l00?ooooooool000?oool2o`000oooo`;o00000oooool00?ooo`02
oooo00?o003oooooool01oooo`?o00000oooool00?ooo`02oooo00?o003ooooo00001Oooo`03o`00
oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002oooo0ol0
00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00Go003ooooooooooooo00001_oo
o`;o0003oooo0ol00007ooooo`00o`00ooooo`00ooooo`0000?oool01_l00?ooooooool00?ooool0
00?oool3o`0000?ooooo003o00000ol000Coool01Ol00?ooooooooooool00002oooo00Co003ooooo
oooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000?oool2o`0000?ooooo003oool00oooo`05o`00oooooooo
ooooo`0000Goool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oo
ooooooooo`;o0002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000?oool00ol00?oo
ool00002o`000oooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002
oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007oooo00Co003ooooooooo0003
oooo0_l000?oool2o`0000?ooooo003oool00_ooo`03o`00oooooooo00Ooool3o`0000?ooooo003o
ool00_ooo`03o`00ooooo`0000Goool00ol00?ooooooo`02oooo1?l00004ooooo`00ooooo`000ooo
o`03o`00ooooo`0000;oool00ol00?ooooooo`03o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000Oooooo003o003ooooo
003ooooo00000oooo`06o`00ooooooooo`00ooooo`000oooo`?o00000oooool00?l00003o`001?oo
o`05o`00ooooooooooooo`0000;oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool1
00000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000ooo
o`;o00000oooool00?ooo`03oooo00Go003ooooooooooooo00001Oooo`03o`00ooooo`0000;oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00003
oooo00Go003ooooo003ooooo00000oooo`03o`00ooooo`0000;o0003oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`002?oo
o`03o`00ooooo`0000Ooool01?l00?ooooooool000?oool2o`000_ooo`?o00000oooool00?ooo`02
oooo00?o003oooooool01_ooo`06o`00ooooo`00o`00ooooo`000oooo`03o`00ooooo`0000Goool0
0ol00?ooooooo`02oooo1?l00004ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool00ol00?oo
ooooo`03o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01Ol00?oooooooooo
ool00006oooo0_l000?oool3o`0000Oooooo003o003ooooo003ooooo00000oooo`06o`00oooooooo
o`00ooooo`000oooo`?o00000oooool00?l00003o`001?ooo`05o`00ooooooooooooo`0000;oool0
1?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`<0000:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000Coool01Ol00?oooooooooo
ool00005oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003ooooo
ooooool2o`000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00003oooo00?o003ooooo
00000_l000?oool00ol00?ooool00003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_oo
o`04o`00ooooooooo`000oooo`;o0008oooo00?o003ooooo00001oooo`04o`00ooooooooo`000ooo
o`;o0002oooo0ol00003ooooo`00oooo00;oool00ol00?ooooooo`06oooo00Ko003ooooo003o003o
oooo0003oooo00?o003ooooo00001Oooo`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003
oooo00?o003ooooo00000_ooo`03o`00oooooooo00?o0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`05o`00ooooooooooooo`0000Koool2o`000oooo`?o00001oooool00?l00?oo
ool00?ooool00003oooo00Ko003ooooooooo003ooooo0003oooo0ol00003ooooo`00o`0000?o0004
oooo00Co003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co003ooooooooo000^oooo0`00
007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool0
1?l00?ooooooool000Coool01Ol00?ooooooooooool00005oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool00ol00?ooool00002o`000oooo`03o`00ooooo`0000?oool2
o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool0
0ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool3o`0000?ooooo003oool00_oo
o`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool000?oool00ol00?ooool00005oooo00?o
003oooooool00_ooo`Co00001?ooool00?ooool000?oool00ol00?ooool00002oooo00?o003ooooo
ool00ol000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00Go003ooooooooooooo
00001_ooo`;o0003oooo0ol00007ooooo`00o`00ooooo`00ooooo`0000?oool01_l00?ooooooool0
0?ooool000?oool3o`0000?ooooo003o00000ol000Coool01?l00?ooooooool000?oool01?l00?oo
ooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool0
0ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`001?ooo`05o`00oooooooo
ooooo`0000Goool00ol00?ooool00002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oo
ooooooooo`;o0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00
ooooo`0000;o0003oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`002?ooo`03o`00ooooo`0000Ooool01?l00?ooooooool0
00?oool2o`000_ooo`?o00000oooool00?ooo`02oooo00?o003oooooool01_ooo`06o`00ooooo`00
o`00ooooo`000oooo`03o`00ooooo`0000Goool00ol00?ooooooo`02oooo1?l00004ooooo`00oooo
o`000oooo`03o`00ooooo`0000;oool00ol00?ooooooo`03o`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool01Ol00?ooooooooooool00006oooo0_l000?oool3o`0000Oooooo003o
003ooooo003ooooo00000oooo`06o`00ooooooooo`00ooooo`000oooo`?o00001_ooool00?l00?l0
0?ooool000Coool01?l00?ooooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0
033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo
00000oooo`04o`00ooooooooo`001?ooo`05o`00ooooooooooooo`0000Goool00ol00?ooool00002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00ooooo`0000;o0002oooo0_l00003oooo
o`00oooo00;oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003
oooo0_l000Soool00ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool3o`0000?o
oooo003oool00_ooo`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool000?oool2o`001_oo
o`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00?o003ooooo00000_ooo`03o`00
oooooooo00?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000Koool2o`000oooo`?o00001oooool00?l00?ooool00?ooool00003oooo00Ko003ooooo
oooo003ooooo0003oooo0ol00006ooooo`00o`00o`00ooooo`001?ooo`04o`00ooooooooo`000ooo
o`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003ooooo
ool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Go
003ooooooooooooo00001Oooo`03o`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_oo
o`04o`00oooooooooooo0_l000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003
oooo00?o003ooooo00000_l000;oool2o`0000?ooooo003oool00_ooo`;o0002oooo00Co003ooooo
oooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`002?ooo`03o`00ooooo`0000Ooool0
1?l00?ooooooool000?oool2o`000_ooo`?o00000oooool00?ooo`02oooo00?o003oooooool01_oo
o`06o`00ooooo`00o`00ooooo`000oooo`;o0006oooo00?o003oooooool00_ooo`Co00001?ooool0
0?ooool000?oool00ol00?ooool00002oooo00?o003oooooool00ol000;oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo00Go003ooooooooooooo00001_ooo`;o0003oooo0ol00007oooo
o`00o`00ooooo`00ooooo`0000?oool01_l00?ooooooool00?ooool000?oool3o`0000Kooooo003o
003o003ooooo0004oooo00Co003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co003ooooo
oooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00
ooooo`0000?oool01?l00?ooooooool000Coool01Ol00?ooooooooooool00005oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o
003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00ooooo`0000;o0002oooo0_l0
0003ooooo`00oooo00;oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooo
oooo0003oooo0_l000Soool00ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool3
o`0000?ooooo003oool00_ooo`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool000?oool2
o`001_ooo`03o`00oooooooo00;oool4o`0000Cooooo003ooooo0003oooo00?o003ooooo00000_oo
o`03o`00oooooooo00?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`05o`00
ooooooooooooo`0000Koool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooooooo`00ooooo`000oooo`?o00001_ooool00?l00?l00?ooool000Coool01?l00?oo
ooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Ooo
o`<0000:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000Coool0
1Ol00?ooooooooooool00005oooo00?o003ooooo00000_ooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`00
00;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000oooo`03o`00ooooo`0000;o0002oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool0
1?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0008oooo00?o003ooooo
00001oooo`04o`00ooooooooo`000oooo`;o0002oooo0ol00003ooooo`00oooo00;oool00ol00?oo
ooooo`06oooo00Ko003ooooo003o003ooooo0003oooo0_l000Koool00ol00?ooooooo`02oooo1?l0
0004ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool00ol00?ooooooo`03o`000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?ooooooooooool00?ooool00004oooo0_l0
00?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooooooool00?ooool0
00?oool3o`0000Kooooo003o003o003ooooo0004oooo00Co003ooooooooo0003oooo00Co003ooooo
oooo000:oooo00Co003ooooooooo000^oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000Coool01Ol00?oooooooooo
ool00004oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oo
ooooooooo`;o0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`Go0002
oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000?oool2o`000_oo
o`04o`00ooooooooo`000oooo`;o0008oooo00?o003ooooo00001oooo`04o`00ooooooooo`000ooo
o`;o0002oooo0ol00003ooooo`00oooo00;oool00ol00?ooooooo`06oooo00Ko003ooooo003o003o
oooo0003oooo0_l000Koool00ol00?ooooooo`02oooo1?l00004ooooo`00ooooo`000oooo`03o`00
ooooo`0000;oool00ol00?ooooooo`03o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool01ol00?ooooooooooool00?ooool00004oooo0_l000?oool01?l00?ooool00?ooo`;o0000
1?ooool00?ooool000?oool01_l00?ooooooool00?ooool000?oool3o`0000Kooooo003o003o003o
oooo0004oooo00Co003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`
oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00?oool01?l00?ooooooool000Coool01Ol00?ooooooooooool00004oooo0_l00007ooooo`00oooo
ooooo`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`Go0002oooo0_l00007ooooo`00ooooooooo`00
ooooo`0000;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00ooooooooo`000oooo`;o0008
oooo00?o003ooooo00001oooo`04o`00ooooooooo`000oooo`;o0002oooo0ol00003ooooo`00oooo
00;oool00ol00?ooooooo`06oooo00Ko003ooooo003o003ooooo0003oooo0_l000Koool00ol00?oo
ooooo`02oooo00So003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo00000_ooo`03o`00
oooooooo00?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`07o`00oooooooo
ooooo`00ooooo`0000Coool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooooooo`00ooooo`000oooo`?o00001_ooool00?l00?l00?ooool000Coool01?l00?oo
ooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Ooo
o`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00oooooooo
o`001?ooo`05o`00ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo
003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007
oooo00Co003ooooooooo0003oooo0_l000;oool3o`0000?ooooo003oool00_ooo`03o`00oooooooo
00Koool01_l00?ooool00?l00?ooool000?oool2o`001_ooo`03o`00oooooooo00;oool02?l00?oo
ool00?l00?ooool00?ooool000?oool00ol00?ooool00002oooo00?o003oooooool00ol000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo00Oo003ooooooooooooo003ooooo00001?oo
o`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003o
oooo0003oooo0ol00006ooooo`00o`00o`00ooooo`001?ooo`04o`00ooooooooo`000oooo`04o`00
ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003oooooool02_oo
o`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Go003ooooo
oooooooo00001?ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co
003oooooooooool2o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool5
o`000_ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0003oooo0_l0
00;oool01?l00?ooooooool000?oool2o`002?ooo`03o`00ooooo`0000Ooool01?l00?ooooooool0
00?oool2o`000_ooo`?o00000oooool00?ooo`02oooo00?o003oooooool01_ooo`06o`00ooooo`00
o`00ooooo`000oooo`;o0006oooo00?o003oooooool00_ooo`08o`00ooooo`00o`00ooooo`00oooo
o`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo00Oo003ooooooooooooo003ooooo00001?ooo`;o0003oooo00Co
003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0003oooo0ol0
0006ooooo`00o`00o`00ooooo`001?ooo`04o`00ooooooooo`000oooo`04o`00ooooooooo`002_oo
o`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo
027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Go003ooooooooooooo00001?oo
o`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool5o`000_ooo`;o0000
1oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?oo
ooooool000?oool2o`002?ooo`03o`00ooooo`0000Ooool01?l00?ooooooool000?oool2o`000_oo
o`?o00000oooool00?ooo`02oooo00?o003oooooool01_ooo`06o`00ooooo`00o`00ooooo`000ooo
o`;o0006oooo00?o003oooooool00_ooo`08o`00ooooo`00o`00ooooo`00ooooo`000oooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo00Oo003ooooooooooooo003ooooo00001?ooo`;o0003oooo00Co003ooooo003oool2
o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0003oooo0ol00006ooooo`00o`00
o`00ooooo`001?ooo`04o`00ooooooooo`000oooo`04o`00ooooooooo`002_ooo`04o`00oooooooo
o`00<?ooo`400001oooo000Moooo0`0000[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000ooo
o`04o`00ooooooooo`001?ooo`05o`00ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo
00000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool0
0ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool3o`0000?ooooo003oool00_oo
o`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool000?oool2o`001_ooo`03o`00oooooooo
00;oool02?l00?ooool00?l00?ooool00?ooool000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`07o`00oooooooo
ooooo`00ooooo`0000Coool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooooooo`00ooooo`000oooo`?o00001_ooool00?l00?l00?ooool000Coool01?l00?oo
ooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool002koool300000Oooo`007Ooo
o`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00oooooooo
o`001?ooo`05o`00ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo
003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007
oooo00Co003ooooooooo0003oooo0_l000;oool3o`0000?ooooo003oool00_ooo`03o`00oooooooo
00Koool01_l00?ooool00?l00?ooool000Coool00ol00?ooooooo`04oooo00?o003oooooool00_oo
o`08o`00ooooo`00o`00ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00Oo003ooooooooooooo
003ooooo00001?ooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko
003ooooooooo003ooooo0003oooo0ol00006ooooo`00o`00o`00ooooo`001?ooo`04o`00oooooooo
o`000oooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0
003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004
oooo00Go003ooooooooooooo00001?ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?oo
ool00002oooo00Co003oooooooooool2o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000?oool5o`000_ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooo
oooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`002?ooo`03o`00ooooo`0000Ooool0
1?l00?ooooooool000?oool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooooooo`06
oooo00Ko003ooooo003o003ooooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo00;oool0
2?l00?ooool00?l00?ooool00?ooool000?oool00ol00?ooool00002oooo00Ko003ooooooooo003o
oooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`07o`00ooooooooooooo`00
ooooo`0000Coool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00
ooooooooo`00ooooo`000oooo`?o00001_ooool00?l00?l00?ooool000Coool01?l00?ooooooool0
00?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000
oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`001?oo
o`05o`00ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo
00000_ooo`04o`00oooooooooooo0_l000;oool00ol00?ooool00002oooo00Ko003ooooooooo003o
oooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007oooo00Co
003ooooooooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_oo
o`06o`00ooooo`00o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00So
003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?ooooooooooool00?oo
ool00004oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?oo
ooooool00?ooool000?oool3o`0000Kooooo003o003o003ooooo0004oooo00Co003ooooooooo0003
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000Coool0
1Ol00?ooooooooooool00004oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`00
00;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003o
oooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007oooo00Co
003ooooooooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_oo
o`06o`00ooooo`00o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00So
003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?ooooooooooool00?oo
ool00004oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?oo
ooooool00?ooool000?oool3o`0000Kooooo003o003o003ooooo0004oooo00Co003ooooooooo0003
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000Coool0
1Ol00?ooooooooooool00004oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`00
00;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003o
oooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000Soool00ol00?ooool00007oooo00Co
003ooooooooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_oo
o`06o`00ooooo`00o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00So
003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?ooooooooooool00?oo
ool00004oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?oo
ooooool00?ooool000?oool3o`0000Kooooo003o003o003ooooo0004oooo00Co003ooooooooo0003
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool300002_oo
o`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Go003ooooo
oooooooo00001?ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`Go0002oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000?oool2
o`000_ooo`04o`00ooooooooo`000oooo`;o0008oooo00?o003ooooo00001oooo`04o`00oooooooo
o`000oooo`;o0002oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?oo
ool00?l00?ooool000Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`08o`00ooooo`00
o`00ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo00Oo003ooooooooooooo003ooooo00001?oo
o`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003o
oooo0002oooo1?l00006ooooo`00o`00o`00ooooo`001?ooo`04o`00ooooooooo`000oooo`04o`00
ooooooooo`002_ooo`04o`00ooooooooo`00;_ooo`<00001oooo000Moooo00<0003oooooool02_oo
o`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Go003ooooo
oooooooo00001?ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`Go0002oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000?oool2
o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`00
00Ooool01?l00?ooooooool000?oool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?oo
ooooo`06oooo00Ko003ooooo003o003ooooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo
00;oool02?l00?ooool00?l00?ooool00?ooool000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`07o`00oooooooo
ooooo`00ooooo`0000Coool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooooooo`00ooooo`000_ooo`Co00001_ooool00?l00?l00?ooool000Coool01?l00?oo
ooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Ooo
o`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00oooooooo
o`001?ooo`05o`00ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000?oool5o`000_ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co
003ooooooooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_ooo`03o`00oooooooo
00?oool00ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool01Ol00?ooool00?oo
ool00003oooo00?o003oooooool01_ooo`06o`00ooooo`00o`00ooooo`001?ooo`03o`00oooooooo
00Coool00ol00?ooooooo`02oooo00So003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool01ol00?ooooooooooool00?ooool00004oooo0_l000?oool01?l00?ooool00?ooo`;o0000
1?ooool00?ooool000?oool01_l00?ooooooool00?ooool000;oool4o`0000?ooooo003o00000_oo
o`03o`00oooooooo00;oool01?l00?ooooooool000?oool01?l00?ooooooool000[oool01?l00?oo
ooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o
003ooooo00000oooo`04o`00ooooooooo`001?ooo`05o`00ooooooooooooo`0000Coool2o`0000Oo
oooo003ooooooooo003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool0
0ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool5o`000_ooo`;o00001oooool0
0?ooooooool00?ooool00002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?ooooooool0
00?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00007oooo00Co003ooooooooo0003
oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00ooooo`00
o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00So003ooooo003o003o
oooo003ooooo0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?ooooooooooool00?ooool00004oooo0_l0
00?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooooooool00?ooool0
00;oool4o`0000?ooooo003o00000_ooo`03o`00oooooooo00;oool01?l00?ooooooool000?oool0
1?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo
00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`001?ooo`05o`00
ooooooooooooo`0000Coool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool0
00?oool5o`000_ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0003
oooo0_l000;oool01?l00?ooooooool000?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?oo
ool00007oooo00Co003ooooooooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o
003oooooool01_ooo`06o`00ooooo`00o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?oo
ooooo`02oooo00So003ooooo003o003ooooo003ooooo0003oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?oo
ooooooooool00?ooool00004oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool0
00?oool01_l00?ooooooool00?ooool000;oool4o`0000?ooooo003o00000_ooo`03o`00oooooooo
00;oool01?l00?ooooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool1
00000Oooo`001?ooo`D00002oooo00@0003oooooooooool300000oooo`030000oooooooo00Goool0
0`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool0
00Coool01Ol00?ooooooooooool00004oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool0
1?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03
oooo00?o003ooooo00001oooo`04o`00ooooooooo`000oooo`;o0002oooo00Go003ooooo003ooooo
00000oooo`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool000Coool00ol00?ooooooo`04
oooo00?o003oooooool00_ooo`08o`00ooooo`00o`00ooooo`00ooooo`000oooo`03o`00ooooo`00
00;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003
oooo00Oo003ooooooooooooo003ooooo00001?ooo`;o0003oooo00Co003ooooo003oool2o`0000Co
oooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002oooo1?l00003ooooo`00o`0000;oool0
0ol00?ooooooo`02oooo00Co003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co003ooooo
oooo000`oooo0@00007oool000Koool00`000?ooooooo`06oooo00<0003oooooool00_ooo`030000
oooo000000Koool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool0
1?l00?ooooooool000Coool01ol00?ooooooooooool00?ooool00002oooo0_l00007ooooo`00oooo
ooooo`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?oo
ool00002oooo00Ko003ooooooooo003ooooo0003oooo1Ol000;oool2o`0000Oooooo003ooooooooo
003ooooo00000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l0
00;oool00ol00?ooooooo`03oooo00?o003ooooo00001oooo`04o`00ooooooooo`000oooo`;o0002
oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooool00?l00?ooool0
00Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`08o`00ooooo`00o`00ooooo`00oooo
o`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo00Oo003ooooooooooooo003ooooo00001?ooo`;o0003oooo00Co
003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002oooo1?l0
0003ooooo`00o`0000;oool00ol00?ooooooo`02oooo00Co003ooooooooo0003oooo00Co003ooooo
oooo000:oooo00Co003ooooooooo000`oooo0@00007oool000Koool00`000?ooooooo`07oooo00<0
003oooooool00oooo`030000oooooooo00Coool400002Oooo`03o`00oooooooo027oool00ol00?oo
ool00003oooo00Co003ooooooooo0004oooo00Oo003ooooooooooooo003ooooo00000_ooo`;o0000
1oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`Go0002oooo0_l00007oooo
o`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000?oool2o`000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`0000Ooool01?l00?ooooooool0
00?oool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooo
003o003ooooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo00;oool01Ol00?ooool00?l0
0?ooo`02o`001?ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo00Oo003ooooooooooooo003ooooo00001?ooo`;o0003
oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002
oooo1?l00003ooooo`00o`0000;oool00ol00?ooooooo`02oooo00Co003ooooooooo0003oooo00Co
003ooooooooo000:oooo00Co003ooooooooo000]oooo1000007oool000Koool00`000?ooooooo`07
oooo00@0003oooooooooool200001oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o
003ooooo00000oooo`04o`00ooooooooo`001?ooo`07o`00ooooooooooooo`00ooooo`0000;oool2
o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool5o`000_ooo`;o0000
1oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?oo
ooooool000?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00007oooo00Co003ooooo
oooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00
ooooo`00o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00Go003ooooo
003o003oool00_l000Coool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`07o`00ooooooooooooo`00ooooo`0000Coool2
o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooooooo`00oooo
o`000_ooo`Co00000oooool00?l00002oooo00?o003oooooool00_ooo`04o`00ooooooooo`000ooo
o`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo0006oooo00<0003ooooo
ool01_ooo`030000oooo000000;oool00`000?ooooooo`06oooo00<0003oooooool02_ooo`03o`00
oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Oo003ooooooooooooo
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003
oooo1Ol000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00ooooooooo`000ooo
o`;o0002oooo00Co003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03oooo00?o003ooooo
00001oooo`04o`00ooooooooo`000oooo`;o0002oooo00Go003ooooo003ooooo00000oooo`03o`00
oooooooo00Koool01_l00?ooool00?l00?ooool000Coool00ol00?ooooooo`04oooo00?o003ooooo
ool00_ooo`05o`00ooooo`00o`00oooo00;o0004oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01ol00?oooooooooo
ool00?ooool00004oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool0
1_l00?ooooooool00?ooool000;oool4o`0000?ooooo003o00000_ooo`03o`00oooooooo00;oool0
1?l00?ooooooool000?oool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Ooo
o`001Oooo`800009oooo00@0003oooooooooool300001_ooo`030000oooooooo00[oool00ol00?oo
ooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`001?ooo`07o`00ooooooooooooo`00
ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`Go0002oooo0_l00007ooooo`00ooooooooo`00ooooo`0000;oool01?l00?ooooooool000?oool2
o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`00
00Ooool01?l00?ooooooool000?oool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?oo
ooooo`06oooo00Ko003ooooo003o003ooooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo
00;oool01Ol00?ooool00?l00?ooo`02o`001?ooo`03o`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00Oo003ooooooooooooo
003ooooo00001?ooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko
003ooooooooo003ooooo0002oooo1?l00003ooooo`00o`0000;oool00ol00?ooooooo`02oooo00Co
003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool0
01goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?oo
ooooool000Coool01ol00?ooooooooooool00?ooool00002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003
oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`00
00;oool01_l00?ooooooool00?ooool000?oool5o`000_ooo`;o00001oooool00?ooooooool00?oo
ool00002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?ooooooool000?oool2o`000_oo
o`03o`00oooooooo00?oool00ol00?ooool00007oooo00Co003ooooooooo0003oooo0_l000;oool0
1Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00ooooo`00o`00ooooo`001?oo
o`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00Go003ooooo003o003oool00_l000Coool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`;o0002oooo00?o003ooooo00001?ooo`;o0003oooo00Co003ooooo003oool2
o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002oooo1?l00003ooooo`00o`00
00;oool00ol00?ooooooo`02oooo00Co003ooooooooo0003oooo00Co003ooooooooo000:oooo00Co
003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool01?l00?ooooooool000Coool01?l00?ooooooooooo`?o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool5o`000_ooo`;o0000
1oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0003oooo0_l000;oool01?l00?oo
ooooool000?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00007oooo00Co003ooooo
oooo0003oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00
ooooooooo`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00Go003ooooo
003o003oool00_l000Coool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`;o0002oooo00?o003ooooo00001?ooo`;o0003
oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0002
oooo1?l00003ooooo`00o`0000;oool00ol00?ooooooo`02oooo00Co003ooooooooo0003oooo00Co
003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool300002_ooo`03o`00
oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Co003oooooooooool3
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l0
0003ooooo`00o`0000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000oooo`;o0002oooo00Co003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03oooo00?o
003ooooo00001oooo`04o`00ooooooooo`000oooo`;o0002oooo00Go003ooooo003ooooo00000ooo
o`03o`00oooooooo00Koool01_l00?ooooooool00?ooool000Coool00ol00?ooooooo`04oooo00?o
003oooooool00_ooo`05o`00ooooo`00o`00oooo00;o0004oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000_oo
o`03o`00ooooo`0000Coool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooooooo`00ooooo`000_ooo`Co00000oooool00?l00002oooo00?o003oooooool00_oo
o`04o`00ooooooooo`000oooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00;_ooo`<00001
oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co
003ooooooooo0004oooo00Co003oooooooooool3o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000ooo
o`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo0_l00003ooooo`00o`0000;oool2o`0000Oooooo003o
oooooooo003ooooo00000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00Co003ooooooooo0003
oooo0_l000;oool00ol00?ooooooo`03oooo00?o003ooooo00001oooo`04o`00ooooooooo`000ooo
o`;o0002oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool0
0?ooool000Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`05o`00ooooo`00o`00oooo
00;o0004oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool2o`000_ooo`03o`00ooooo`0000Coool2o`000oooo`04o`00
ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooooooo`00ooooo`000_ooo`Co0000
0oooool00?l00002oooo00?o003oooooool00_ooo`04o`00ooooo`00o`000oooo`04o`00oooooooo
o`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00
oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0004oooo00Co003oooooooooool3
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l0
0003ooooo`00o`0000;oool2o`0000Oooooo003ooooooooo003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`?o0002oooo00Co003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03oooo00?o
003ooooo00000oooo`05o`00ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go
003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool00?ooool000Coool0
0ol00?ooooooo`04oooo00?o003oooooool00_ooo`05o`00ooooo`00o`00oooo00;o0004oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2
o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo1?l00003ooooo`00o`00
00;oool00ol00?ooooooo`02oooo00Co003ooooo003o0003oooo00Co003ooooooooo000:oooo00Co
003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool01?l00?ooooooool000Coool01?l00?ooooooooooo`?o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`0000?ooooo003o
00000_ooo`;o00001oooool00?ooooooool00?ooool00002oooo00Co003ooooooooo0002oooo0ol0
00;oool01?l00?ooooooool000?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00003
oooo00Go003ooooooooooooo00000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?ooool00?oo
ool00003oooo00?o003oooooool01_ooo`06o`00ooooooooo`00ooooo`001?ooo`03o`00oooooooo
00Coool00ol00?ooooooo`02oooo00Go003ooooo003o003oool00_l000Coool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool01_l00?ooool00?l00?ooool000;oool4o`0000?ooooo003o00000_ooo`03o`00
oooooooo00;oool01?l00?ooool00?l000?oool01?l00?ooooooool000[oool01?l00?ooooooool0
033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo
00000oooo`04o`00ooooooooo`001?ooo`04o`00oooooooooooo0ol000;oool01?l00?ooooooool0
00;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o00000oooool00?l00002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0002oooo00Co
003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03oooo00?o003ooooo00000oooo`05o`00
ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go003ooooo003ooooo00000ooo
o`03o`00oooooooo00Koool01_l00?ooooooool00?ooool000Coool00ol00?ooooooo`04oooo00?o
003oooooool00_ooo`05o`00ooooo`00o`00oooo00;o0004oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000_oo
o`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003
oooo00Ko003ooooo003o003ooooo0002oooo1?l00003ooooo`00o`0000;oool00ol00?ooooooo`02
oooo00Co003ooooo003o0003oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00
007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool0
1?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go
003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool2o`0000?ooooo003o00000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`000_ooo`04o`00ooooooooo`000ooo
o`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00002
oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooooooo`06
oooo00Ko003ooooooooo003ooooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo00;oool0
1Ol00?ooool00?l00?ooo`02o`001?ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool0
00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000;oool01?l00?ooool00?l0
00?oool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooo`00
o`00ooooo`000_ooo`Co00000oooool00?l00002oooo00?o003oooooool00_ooo`04o`00ooooo`00
o`000oooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo0`00
00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003
oooo0ol000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`;o00000oooool00?l00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`?o0002oooo00Co003ooooooooo0003oooo0_l000;oool00ol00?ooooooo`03
oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002
oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool00?ooool0
00Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`05o`00ooooo`00o`00oooo00;o0004
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo
003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo1?l00003oooo
o`00o`0000;oool00ol00?ooooooo`02oooo00Co003ooooo003o0003oooo00Co003ooooooooo000:
oooo00Co003ooooooooo000^oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o003ooooo
ool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`0000?ooooo003o
00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3
o`000_ooo`04o`00ooooooooo`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`00
00?oool01Ol00?ooooooooooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00
ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo0004oooo00?o003ooooo
ool01?ooo`03o`00oooooooo00;oool01?l00?ooool00?l000;oool00ol00?ooooooo`02oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2
o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo1?l00003ooooo`00o`00
00;oool00ol00?ooooooo`02oooo00Co003ooooo003o0003oooo00Co003ooooooooo000:oooo00Co
003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool0
0ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`0000?ooooo003o00000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`000_oo
o`04o`00ooooooooo`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`0000?oool0
1Ol00?ooooooooooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00ooooo`00
00?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo0004oooo00?o003oooooool01?oo
o`03o`00oooooooo00;oool01?l00?ooool00?l000;oool00ol00?ooooooo`02oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Co
oooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo1?l00003ooooo`00o`0000;oool0
0ol00?ooooooo`02oooo00Co003ooooo003o0003oooo00Co003ooooooooo000:oooo00Co003ooooo
oooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00
ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?oo
ool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`0000?ooooo003o00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool3o`000_ooo`04o`00
ooooooooo`000oooo`;o0002oooo00?o003oooooool00oooo`03o`00ooooo`0000?oool01Ol00?oo
ooooooooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool0
0ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo0004oooo00?o003oooooool01?ooo`03o`00
oooooooo00;oool01?l00?ooool00?l000;oool00ol00?ooooooo`02oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2
o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003o
oooo0003oooo00Ko003ooooo003o003ooooo0002oooo0_l00003ooooo`00oooo00;o0002oooo00?o
003oooooool00_ooo`04o`00ooooo`00o`000oooo`04o`00ooooooooo`002_ooo`04o`00oooooooo
o`00<?ooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?oo
ool00003oooo00Co003ooooooooo0003oooo0_l000?oool3o`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?oo
ool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l00003ooooo`00o`0000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0ol000;oool01?l00?oo
ooooool000?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00003oooo00Go003ooooo
oooooooo00000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o
003oooooool01_ooo`06o`00ooooooooo`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?oo
ooooo`02oooo00Co003ooooo003o0002oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l0
00;oool01?l00?ooool00?l000?oool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00oooo
o`000oooo`06o`00ooooo`00o`00ooooo`000_ooo`;o00000oooool00?ooo`02o`000_ooo`03o`00
oooooooo00;oool01?l00?ooool00?l000?oool01?l00?ooooooool000[oool01?l00?ooooooool0
033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo
00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o00000oooool00?l00002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`?o0002oooo00Co003ooooo
oooo0003oooo0_l000;oool00ol00?ooooooo`03oooo00?o003ooooo00000oooo`05o`00oooooooo
ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go003ooooo003ooooo00000oooo`03o`00
oooooooo00Koool01_l00?ooooooool00?ooool000Coool00ol00?ooooooo`04oooo00?o003ooooo
ool00_ooo`04o`00ooooo`00o`000_ooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`;o0002
oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool0
00?oool01_l00?ooool00?l00?ooool000;oool2o`0000Gooooo003o003ooooo00000_ooo`03o`00
oooooooo00;oool01?l00?ooool00?l000?oool01?l00?ooooooool000[oool01?l00?ooooooool0
033oool100000Oooo`007Oooo`<0000:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool0
1?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go
003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool2o`000_ooo`04o`00ooooooooo`000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00?oool2o`000_ooo`03o`00oooooooo00?oool00ol00?ooool00003oooo00Go003ooooooooooooo
00000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003ooooo
ool01_ooo`06o`00ooooooooo`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02
oooo00Co003ooooo003o0002oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000;oool0
1?l00?ooool00?l000?oool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000ooo
o`06o`00ooooo`00o`00ooooo`000_ooo`;o00001Oooool00?l00?ooool00002oooo00?o003ooooo
ool00_ooo`04o`00ooooo`00o`000oooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00;_oo
o`<00001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003
oooo00Co003ooooooooo0003oooo0_l000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo00000ooo
o`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo0_l000;oool01?l00?ooooooool000;oool01_l00?oo
ooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00Oo003ooooo
oooo003ooooo003oool00_l000;oool00ol00?ooooooo`03oooo00?o003ooooo00000oooo`05o`00
ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go003ooooo003ooooo00000ooo
o`03o`00oooooooo00Koool01_l00?ooooooool00?ooool000Coool00ol00?ooooooo`04oooo00?o
003oooooool00_ooo`04o`00ooooo`00o`000_ooo`03o`00oooooooo00;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool01_l00?ooool00?l00?ooool000;oool2o`0000Gooooo003o003ooooo00000_oo
o`03o`00oooooooo00;oool01?l00?ooool00?l000?oool01?l00?ooooooool000[oool01?l00?oo
ooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o
003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?ooooooool0
00;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0002oooo00Co003ooooooooo0002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_oo
o`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00?o003oooooool00oooo`03o`00ooooo`00
00?oool01Ol00?ooooooooooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00
ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo0004oooo00?o003ooooo
ool01?ooo`03o`00oooooooo00;oool01?l00?ooool00?l000;oool00ol00?ooooooo`02oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo003oool2
o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo00?o003oooooool00_l0
0005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co
003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool0
0ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`000_ooo`04o`00oooooooo
o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool01ol00?ooooooool00?ooool00?ooo`02o`000_ooo`03o`00oooooooo00?oool00ol00?oo
ool00003oooo00Go003ooooooooooooo00000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?oo
ool00?ooool00003oooo00?o003oooooool01_ooo`06o`00ooooooooo`00ooooo`001?ooo`03o`00
oooooooo00Coool00ol00?ooooooo`02oooo00Co003ooooo003o0002oooo00?o003oooooool00_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool0
0ol00?ooool00003oooo0_l000;oool01?l00?ooool00?l000?oool2o`000oooo`04o`00ooooo`00
oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooo`00o`00ooooo`000_ooo`03o`00oooooooo
00;o00001Oooool00?ooooooool00004oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_oo
o`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo
027oool00ol00?ooool00003oooo00Co003ooooooooo0003oooo0_l000?oool3o`000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002
oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool0
00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l000;oool01?l00?oo
ooooool000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?oo
ool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool00ol00?ooooooo`03oooo00?o
003ooooo00000oooo`05o`00ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go
003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool00?ooool000Coool0
0ol00?ooooooo`04oooo00?o003oooooool00_ooo`04o`00ooooooooo`000_ooo`03o`00oooooooo
00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?oo
ool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l00?ooool000;oool00ol00?oo
ooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?oo
ooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool0
1?l00?ooooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003o
oooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0002oooo00Co
003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002
oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool00?ooool0
00Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`04o`00ooooooooo`000_ooo`03o`00
oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool0
1?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l00?ooool000;oool0
0ol00?ooooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?oo
ooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`<0000:oooo00?o003ooooo
ool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`000oooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?oo
ool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01?l00?ooooooool000;oool0
0ol00?ooool00003oooo00Go003ooooooooooooo00000_ooo`04o`00oooooooooooo0_l000;oool0
1Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00ooooooooo`00ooooo`001?oo
o`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00Co003ooooooooo0002oooo00?o003ooooo
ool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool0
00;oool00ol00?ooool00003oooo0_l000;oool01?l00?ooool00?l000?oool2o`000oooo`04o`00
ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooo`00o`00ooooo`000_ooo`03o`00
oooooooo00;o00001Oooool00?ooooooool00004oooo00?o003ooooo00001?ooo`04o`00oooooooo
o`002_ooo`04o`00ooooooooo`00;_ooo`<00001oooo000Moooo00<0003oooooool02_ooo`03o`00
oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0003oooo0_l000?oool3o`000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?oo
ool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l000?oool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`05o`00ooooooooooooo`0000;oool01?l00?ooooooooooo`;o0002
oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?ooooooool00?ooool0
00Coool00ol00?ooooooo`04oooo00?o003oooooool00_ooo`04o`00ooooooooo`000_ooo`03o`00
oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool0
1?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l00?ooool000;oool0
0ol00?ooooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?oo
ooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool0
0ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol0
00;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0003
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000;oool01ol00?ooooooool00?ooool00?ooo`02o`000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool01Ol00?ooooooooooool00002oooo00Co003oooooooooool2
o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003o
oooo0004oooo00?o003oooooool01?ooo`03o`00oooooooo00;oool01?l00?ooooooool000;oool0
0ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003
oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002
oooo00?o003oooooool00_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co
003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:
oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000ooo
o`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2
o`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool0
00;oool00ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo00Go003ooooooooooooo00000_ooo`04o`00oooooooo
oooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool01_ooo`06o`00oooooooo
o`00ooooo`001?ooo`03o`00oooooooo00Coool00ol00?ooooooo`02oooo00Co003ooooooooo0002
oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000;oool01?l00?ooool00?l000?oool2
o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooo`00o`00oooo
o`000_ooo`03o`00oooooooo00;o00001Oooool00?ooooooool00004oooo00?o003ooooo00001?oo
o`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo0009oooo1@0000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00[oool00ol00?ooooooo`0Q
oooo00?o003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0003oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool01ol00?ooooooool00?ooool00?ooo`02o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00
ooooo`00ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo0004oooo00?o
003oooooool01?ooo`03o`00oooooooo00;oool01?l00?ooooooool000;oool00ol00?ooooooo`02
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000oooo`;o0003oooo00Co003ooooo
003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo00?o003ooooo
ool00_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:
oooo00Co003ooooooooo000`oooo0@00007oool000_oool00`000?ooooooo`06oooo00<0003oool0
00001_ooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000oooo`04o`00
ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?ooooooool000;oool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool01Ol00?oo
ool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01ol00?ooooooool00?ooool0
0?ooo`02o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool01Ol00?ooool00?oo
ool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?oo
ooooo`06oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_ooo`04o`00oooooooo
o`000_ooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002
oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003
oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l0
0?ooool000;oool00ol00?ooooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`00
00Coool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`002oooo`030000
oooooooo00Soool00`000?ooooooo`04oooo100000Woool00ol00?ooooooo`0Qoooo00?o003ooooo
00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00ooooo`00
00?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01ol00?oo
ooooool00?ooool00?ooo`02o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00ooooo`00ooooo`00
00?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_oo
o`04o`00ooooooooo`000_ooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`;o0002oooo00Co
003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool0
1_l00?ooool00?l00?ooool000;oool00ol00?ooooooo`02o`0000Gooooo003ooooooooo00001?oo
o`03o`00ooooo`0000Coool01?l00?ooooooool000[oool01?l00?ooooooool002goool400000Ooo
o`002oooo`030000oooooooo00Koool200001oooo`030000oooooooo00[oool00ol00?ooooooo`0Q
oooo00?o003ooooo00000oooo`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_oo
o`03o`00ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0003oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00;oool01ol00?ooooooool00?ooool00?ooo`02o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool01Ol00?ooool00?ooool00002oooo00Co003oooooooooool2o`000_ooo`05o`00
ooooo`00ooooo`0000?oool00ol00?ooooooo`06oooo00Ko003ooooooooo003ooooo000;oooo00?o
003oooooool00_ooo`04o`00ooooooooo`000_ooo`03o`00oooooooo00;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool01_l00?ooool00?l00?ooool000;oool00ol00?ooooooo`02o`0000Gooooo003o
oooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool01?l00?ooooooool0
033oool100000Oooo`002oooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0003ooooo
ool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0003oooo0_l0
00?oool3o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool00ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003
oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oo
ooooooooo`;o0002oooo00Go003ooooo003ooooo00000oooo`03o`00oooooooo00Koool01_l00?oo
ooooool00?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo
00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?oo
ool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l00?ooool000;oool00ol00?oo
ooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool01?l00?ooooooool0033oool100000Oooo`002_ooo`800008oooo0`0000Koool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2
o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool0
00?oool2o`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`04o`00
oooooooooooo0_l000;oool01Ol00?ooool00?ooool00003oooo00?o003oooooool00_ooo`05o`00
ooooooooooooo`0000;oool00ol00?ooool0000;oooo00?o003oooooool00_ooo`03o`00oooooooo
00?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000_ooo`04o`00ooooo`00o`000ooo
o`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003o
oooo0002oooo00?o003oooooool00_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2
o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool0
00?oool2o`000oooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`04o`00
oooooooooooo0_l000;oool01Ol00?ooool00?ooool00004oooo00Go003ooooooooooooo00000ooo
o`06o`00ooooooooo`00ooooo`002oooo`03o`00oooooooo00;oool00ol00?ooooooo`03oooo00?o
003oooooool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0_l000;oool01?l00?ooool00?l000?oool2o`000ooo
o`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`06o`00ooooo`00o`00ooooo`000_oo
o`03o`00oooooooo00;o00001Oooool00?ooooooool00004oooo00?o003ooooo00001?ooo`04o`00
ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0003oooooool02_oo
o`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0003oooo0_l000?oool3
o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool0
0ol00?ooool00002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l0
00?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000oooo`05o`00ooooo`00ooooo`0000;oool01?l00?oooooooooo
o`;o0002oooo00Go003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?oo
ooooool00?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo
00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`;o0002oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?oo
ool00?ooo`;o00001?ooool00?ooool000?oool01_l00?ooool00?l00?ooool000;oool00ol00?oo
ooooo`02o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`<0000:oooo00?o003oooooool08Ooo
o`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool0
0ol00?ooool00003oooo00Go003ooooo003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool2o`000oooo`03o`00ooooo`00
00;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00002
oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo00Go003ooooo003ooooo00000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?oo
ool00?ooool00004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002ooo
o`03o`00oooooooo00;oool00ol00?ooooooo`03oooo00?o003oooooool00_ooo`03o`00ooooo`00
00;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003
oooo0_l000;oool01?l00?ooool00?l000?oool2o`000oooo`04o`00ooooo`00oooo0_l00004oooo
o`00ooooo`000oooo`06o`00ooooo`00o`00ooooo`000_ooo`03o`00oooooooo00;o00001Oooool0
0?ooooooool00004oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`04o`00oooooooo
o`00;_ooo`<00001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?oo
ool00003oooo00Co003ooooooooo0003oooo0_l000?oool3o`000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool00ol00?ooool00002oooo00?o003ooooo
00000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?oo
ool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l000?oool00ol00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`07o`00
ooooooooo`00ooooo`00oooo00;o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`05o`00ooooo`00ooooo`0000;oool01?l00?ooooooooooo`;o0002oooo00Go003ooooo003ooooo
00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool000_oool00ol00?oo
ooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko
003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`;o0002
oooo00Co003ooooo003o0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool0
00?oool01_l00?ooool00?l00?ooool000;oool00ol00?ooooooo`02o`0000Gooooo003ooooooooo
00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool01?l00?ooooooool0033oool1
00000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Qoooo00?o003ooooo00000ooo
o`04o`00ooooooooo`000oooo`;o0003oooo0ol000;oool01?l00?ooooooool000;oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`03o`00ooooo`0000?oool0
1Ol00?ooool00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000;oool01ol00?ooooooool0
0?ooool00?ooo`02o`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?oo
ool00002o`000_ooo`04o`00oooooooooooo0_l000;oool01Ol00?ooool00?ooool00004oooo00Go
003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00oooooooo00;oool0
0ol00?ooooooo`03oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000;oool4o`000ooo
o`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003o
oooo0002oooo00?o003oooooool00_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2
o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003
oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`Go0002oooo00Co003oooooooooool3o`0000Ko
oooo003ooooo003ooooo0004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00oooo
o`002oooo`03o`00oooooooo00;oool00ol00?ooooooo`03oooo00?o003oooooool00_ooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo0_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003o
oooo0003oooo00Ko003ooooo003o003ooooo0002oooo00?o003oooooool00_l00005ooooo`00oooo
ooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`
oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`07o`00oooooooo
o`00ooooo`00oooo00;o0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`Go0002
oooo00Co003oooooooooool3o`0000Kooooo003ooooo003ooooo0004oooo00Go003ooooooooooooo
00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00oooooooo00;oool00ol00?ooooooo`03
oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000;oool4o`000oooo`;o0003oooo00Co
003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko003ooooo003o003ooooo0002oooo00?o
003oooooool00_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co003ooooo
oooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000?oool2o`000oooo`?o0002
oooo00Co003ooooooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo0_l000?oool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000_ooo`07o`00ooooooooo`00ooooo`00oooo00;o0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`Go0002oooo00Co003oooooooooool3o`0000Kooooo003ooooo003o
oooo0004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00
oooooooo00;oool00ol00?ooooooo`03oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l0
00;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00Ko
003ooooo003o003ooooo0002oooo00?o003oooooool00_l00005ooooo`00ooooooooo`0000Coool0
0ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool0
01goool300002_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0003
oooo0_l000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?ooool00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000;oool01ol00?ooooooool00?ooool00?ooo`02o`000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool5o`000_ooo`04o`00oooooooooooo0ol0
0006ooooo`00ooooo`00ooooo`001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool0
0?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo00;oool0
0ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01_l00?ooooooool0
0?ooool000?oool2o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00005ooooo`00oooo
ooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000^
oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00?oool01?l00?ooooooool000?oool2o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool00?ooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00
ooooo`00oooo0_l000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo1Ol000;oool0
3Ol00?ooooooooooool00?ooool00?ooool00?ooool00?ooool00004oooo00Go003ooooooooooooo
00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00oooooooo00;oool00ol00?ooooooo`03
oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01ol00?ooooooool00?ooool00?ooo`02
o`000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0002oooo1?l000?oool2o`000oooo`04o`00
ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool2o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?oo
ooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`000_ooo`?o0003oooo0ol000;oool0
1?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko
003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00ooooooooo`00oooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000oooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool01Ol00?oo
ool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool5o`000_ooo`0=o`00ooooooooooooo`00ooooo`00ooooo`00ooooo`00ooooo`00
00Coool01Ol00?ooooooooooool00003oooo00Ko003ooooooooo003ooooo000;oooo00?o003ooooo
ool00_ooo`03o`00oooooooo00?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`07o`00
ooooooooo`00ooooo`00oooo00;o0002oooo00Ko003ooooooooo003ooooo0003oooo0_l000;oool4
o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004oooo00?o003ooooo
00001?ooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001oooo000Moooo00<0
003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0002
oooo0ol000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?ooool00?ooool00002
oooo00So003ooooooooo003ooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`Go0002oooo00go003ooooooooooooo003ooooo
003ooooo003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool0
0?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo00;oool0
0ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01_l00?ooooooool0
0?ooool000?oool2o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00005ooooo`00oooo
ooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`
oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00?oool01?l00?ooooooool000;oool3o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool00?ooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00
ooooo`00oooo0_l000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo1Ol000;oool0
3Ol00?ooooooooooool00?ooool00?ooool00?ooool00?ooool00004oooo00Go003ooooooooooooo
00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00oooooooo00;oool00ol00?ooooooo`03
oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool01ol00?ooooooool00?ooool00?ooo`02
o`000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0002oooo1?l000?oool2o`000oooo`04o`00
ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool2o`0000Gooooo003ooooooooo00001?ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool01?l00?ooooooool0033oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?oo
ooooo`0Qoooo00?o003ooooo00000oooo`04o`00ooooooooo`000_ooo`?o0003oooo0ol000;oool0
1?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko
003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00ooooooooo`00oooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000oooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool01Ol00?oo
ool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`05o`00ooooooooo`00oooo00;o0000
0oooool00?ooo`02oooo1Ol000;oool03Ol00?ooooooooooool00?ooool00?ooool00?ooool00?oo
ool00004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00
oooooooo00;oool00ol00?ooooooo`03oooo00?o003oooooool00_ooo`03o`00ooooo`0000;oool0
1ol00?ooooooool00?ooool00?ooo`02o`000_ooo`06o`00ooooooooo`00ooooo`000oooo`;o0002
oooo1?l000?oool2o`000oooo`04o`00ooooo`00oooo0_l00004ooooo`00ooooo`000oooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool2o`0000Gooooo003ooooooooo00001?ooo`03o`00
ooooo`0000Coool01?l00?ooooooool000[oool01?l00?ooooooool0033oool100000Oooo`007Ooo
o`<0000:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000;oool3
o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool0
2?l00?ooooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003
oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01Ol00?oo
ooooool00?ooo`02o`0000?ooooo003oool00_ooo`Go0002oooo00go003ooooooooooooo003ooooo
003ooooo003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool0
0?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool00oooo`03o`00oooooooo00;oool0
0ol00?ooool00002oooo00Oo003ooooooooo003ooooo003oool00_l000;oool01_l00?ooooooool0
0?ooool000?oool2o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool0
0?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00005ooooo`00oooo
ooooo`0000Coool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000^
oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`00
00?oool01?l00?ooooooool000;oool3o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool00?ooool00?ooool000;oool01?l00?oo
ooooool000;oool00ol00?ooool00003oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00
ooooo`00oooo0_l000;oool01Ol00?ooooooool00?ooo`02o`0000?ooooo003oool00_ooo`Go0002
oooo00go003ooooooooooooo003ooooo003ooooo003ooooo003ooooo00001?ooo`05o`00oooooooo
ooooo`0000?oool01_l00?ooooooool00?ooool000_oool00ol00?ooooooo`02oooo00?o003ooooo
ool00oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Oo003ooooooooo003ooooo003o
ool00_l000;oool01_l00?ooooooool00?ooool000?oool2o`000_ooo`Co0003oooo0_l000?oool0
1?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooo
oooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co003ooooo
oooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:oooo00?o
003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000;oool3o`000oooo`?o0002
oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool0
0?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000?oool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go
003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01Ol00?ooooooool00?ooo`02
o`0000?ooooo003oool00_ooo`Go0002oooo00go003ooooooooooooo003ooooo003ooooo003ooooo
003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool000_oool0
0ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool02?l00?ooooooool0
0?ooool00?ooool000?oool01_l00?ooooooool00?ooool000?oool2o`000_ooo`Co0003oooo0_l0
00?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool00ol00?ooool00002oooo00Co
003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co
003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?ooooooo`0:
oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000;oool3o`000ooo
o`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l0
00?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01Ol00?ooooooool0
0?ooo`02o`0000?ooooo003oool00_ooo`Go0002oooo00go003ooooooooooooo003ooooo003ooooo
003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool0
00_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000?oool01_l00?ooooooool00?ooool000?oool2o`000_ooo`Co0003
oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000;oool3
o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool0
2?l00?ooooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003
oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01Ol00?oo
ooooool00?ooo`02o`0000?ooooo003oool00_ooo`Go0002oooo00go003ooooooooooooo003ooooo
003ooooo003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool0
0?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool0
2?l00?ooooooool00?ooool00?ooool000?oool01_l00?ooooooool00?ooool000?oool2o`000_oo
o`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?oo
ool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool001goool0
0`000?ooooooo`0:oooo00?o003oooooool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool0
00;oool3o`000oooo`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`00
00;oool02?l00?ooooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?oo
ool00003oooo0_l000?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool0
1Ol00?ooooooool00?ooo`02o`0000?ooooo003oool00_ooo`Go0002oooo00go003ooooooooooooo
003ooooo003ooooo003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?oo
ooooool00?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`00
00;oool02?l00?ooooooool00?ooool00?ooool000?oool01_l00?ooooooool00?ooool000?oool2
o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool0
0ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool0
0ol00?ooool00004oooo00Co003ooooooooo000:oooo00Co003ooooooooo000`oooo0@00007oool0
01goool300002_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooooooo0002
oooo0ol000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?ooool00?ooool00002
oooo00So003ooooooooo003ooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo
00000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Go
003ooooooooo003oool00_l00003ooooo`00oooo00;oool5o`000_ooo`0=o`00ooooooooooooo`00
ooooo`00ooooo`00ooooo`00ooooo`0000Coool01Ol00?ooooooooooool00003oooo00Ko003ooooo
oooo003ooooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool00ol00?ooool00002
oooo00So003ooooooooo003ooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0003oooo0_l0
00;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004oooo00?o
003ooooo00001?ooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00;_ooo`<00001oooo000M
oooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co003ooooo
oooo0002oooo0ol000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?ooool00?oo
ool00002oooo00So003ooooooooo003ooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o
003ooooo00000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002
oooo00Go003ooooooooo003oool00_l00003ooooo`00oooo00;oool5o`000_ooo`0=o`00oooooooo
ooooo`00ooooo`00ooooo`00ooooo`00ooooo`0000Coool01Ol00?ooooooooooool00003oooo00Ko
003ooooooooo003ooooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool00ol00?oo
ool00002oooo00So003ooooooooo003ooooo003ooooo0003oooo00Ko003ooooooooo003ooooo0003
oooo0_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003ooooo0003
oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004
oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?ooo`400001
oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003oooo00Co
003ooooooooo0002oooo0ol000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?oo
ool00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?oo
o`;o0002oooo00Go003ooooooooo003oool00_l00003ooooo`00oooo00;oool5o`000_ooo`0=o`00
ooooooooooooo`00ooooo`00ooooo`00ooooo`00ooooo`0000Coool01Ol00?ooooooooooool00003
oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool0
0ol00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0003oooo00Ko003ooooooooo003o
oooo0003oooo0_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Cooooo003o
oooo0003oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?oooooo
ool00004oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`04o`00ooooooooo`00<?oo
o`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?ooool00003
oooo00Co003ooooooooo0002oooo0ol000?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000?oool0
1Ol00?ooool00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0002oooo00Co003ooooo
oooo0002oooo00?o003ooooo00000oooo`;o0003oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?oo
ool00?ooo`;o0002oooo00Go003ooooooooo003oool00_l00003ooooo`00oooo00;oool5o`000_oo
o`0=o`00ooooooooooooo`00ooooo`00ooooo`00ooooo`00ooooo`0000Coool01Ol00?oooooooooo
ool00003oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo
00Soool00ol00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0003oooo00Ko003ooooo
oooo003ooooo0003oooo0_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000Co
oooo003ooooo0003oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool0
0?ooooooool00004oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`04o`00oooooooo
o`00<?ooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo027oool00ol00?oo
ool00003oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`?o0002oooo00Co003ooooo
oooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool00?ooool00?ooool0
00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l000?oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo
00000oooo`04o`00ooooo`00oooo0_l000;oool01Ol00?ooooooool00?ooo`02o`0000?ooooo003o
ool00_ooo`Go0002oooo00go003ooooooooooooo003ooooo003ooooo003ooooo003ooooo00001?oo
o`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool000_oool00ol00?ooooooo`02
oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool02?l00?ooooooool00?ooool00?ooool0
00?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_ooo`Co0003oooo0_l000?oool0
1?l00?ooool00?ooo`;o00001?ooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooo
oooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004oooo00Co003ooooo
oooo000:oooo00?o003ooooo0000<Oooo`400001oooo0004oooo1@0000;oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0:oooo00?o003ooooo
ool08Oooo`03o`00ooooo`0000?oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol0
00;oool01?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000ooo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool0
1Ol00?ooool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`05o`00ooooooooo`00oooo
00;o00000oooool00?ooo`02oooo1Ol000;oool03Ol00?ooooooooooool00?ooool00?ooool00?oo
ool00?ooool00004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002ooo
o`03o`00oooooooo00;oool00ol00?ooooooo`08oooo00?o003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000oooo`04o`00ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l0
00?oool2o`000oooo`04o`00ooooo`00oooo0_l00003ooooo`00o`0000Coool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00?o003ooooo0000<Oooo`400001oooo0006oooo00<0003ooooo
ool01oooo`070000oooooooooooo0000oooo000000Koool00`000?ooooooo`0:oooo00?o003ooooo
ool08?ooo`;o00000oooool00?ooo`02oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l0
00?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooooooo`Go0002oooo00go003ooooooooooooo003ooooo003ooooo
003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool0
00_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_oo
o`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00000oooool00?l00004oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004oooo00?o003ooooo
00001?ooo`04o`00ooooooooo`002_ooo`03o`00ooooo`00037oool100000Oooo`001_ooo`030000
oooooooo00Ooool00`000?ooooooo`03oooo00<0003oooooool01?ooo`@00009oooo00?o003ooooo
ool08?ooo`;o00000oooool00?ooo`02oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`?o0002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0_l0
00?oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooooooo`Go0002oooo00go003ooooooooooooo003ooooo003ooooo
003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool0
00_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`0000;oool02?l00?oo
ooooool00?ooool00?ooool000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_oo
o`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00000oooool00?l00004oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004oooo00?o003ooooo
00001?ooo`04o`00ooooooooo`002_ooo`03o`00ooooo`0002koool400000Oooo`001_ooo`030000
oooooooo00Soool00`000?ooooooo`0200001oooo`030000oooooooo00[oool00ol00?ooooooo`0P
oooo0_l00003ooooo`00oooo00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol0
00;oool01?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool2o`000ooo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool0
1Ol00?ooool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00oooooooooooo1Ol000;oool03Ol00?ooooooooooool00?ooool00?ooool00?oo
ool00?ooool00004oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002ooo
o`03o`00oooooooo00;oool00ol00?ooooooo`08oooo00?o003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000oooo`04o`00ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l0
00?oool2o`000oooo`04o`00ooooo`00oooo0_l00003ooooo`00o`0000Coool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo0_l00005ooooo`00ooooooooo`0000Coool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00?o003ooooo0000<Oooo`400001oooo0006oooo00<0003ooooo
ool01_ooo`030000oooo000000;oool00`000?ooooooo`06oooo00<0003oooooool02_ooo`03o`00
oooooooo023oool2o`0000?ooooo003oool00_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool3o`000_ooo`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00
ooooo`0000;oool01_l00?ooooooool00?ooool000?oool01Ol00?ooool00?ooool00002oooo00So
003ooooooooo003ooooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool0
1_l00?ooooooool00?ooool000;oool01?l00?ooooooooooo`Go0002oooo00go003ooooooooooooo
003ooooo003ooooo003ooooo003ooooo00001?ooo`05o`00ooooooooooooo`0000?oool01_l00?oo
ooooool00?ooool000_oool00ol00?ooooooo`02oooo00?o003oooooool02?ooo`03o`00ooooo`00
00;oool02?l00?ooooooool00?ooool00?ooool000?oool01?l00?ooooooool000;oool00ol00?oo
ooooo`02o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`;o00000oooool00?l00004
oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00001Oooool00?ooooooool00004
oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`03o`00ooooo`00037oool100000Ooo
o`001Oooo`800008oooo0`0000;oool300001_ooo`030000oooooooo00[oool00ol00?ooooooo`0P
oooo0_l00003ooooo`00oooo00;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo0ol0
00;oool01?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?oo
ooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00oooooooo
o`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003oooooooooool5o`000_ooo`0=o`00ooooooooooooo`00ooooo`00
ooooo`00ooooo`00ooooo`0000Coool01Ol00?ooooooooooool00003oooo00Ko003ooooooooo003o
oooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo00Soool00ol00?ooool00002oooo00So
003ooooooooo003ooooo003ooooo0003oooo00Co003ooooooooo0002oooo00?o003oooooool00_l0
00;oool4o`000oooo`;o0003oooo00Co003ooooo003oool2o`0000?ooooo003o00001?ooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`00
00Coool01?l00?ooooooool000[oool00ol00?ooool0000aoooo0@00007oool001goool00`000?oo
ooooo`0:oooo00?o003oooooool08?ooo`;o00000oooool00?ooo`02oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool01_l00?oo
ooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo00Go
003ooooo003ooooo00000_ooo`08o`00ooooooooo`00ooooo`00ooooo`000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool0
1?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5
o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?oooooooooo
ool00003oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_ooo`03o`00oooooooo
00Soool00ol00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0003oooo00Co003ooooo
oooo0002oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool5
o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2o`0000?ooooo003oool01_oo
o`03o`00ooooo`0000Coool01?l00?ooooooool000[oool00ol00?ooool0000aoooo0@00007oool0
01goool00`000?ooooooo`0:oooo00?o003oooooool08?ooo`;o00000oooool00?ooo`02oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003o
oooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00ooooooooo`00ooooo`00ooooo`000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00
ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool0
1Ol00?ooooooooooool00003oooo00Ko003ooooooooo003ooooo000;oooo00?o003oooooool00_oo
o`03o`00oooooooo00Soool00ol00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0003
oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003oooo00Co
003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2o`0000?o
oooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool00ol00?ooool0000a
oooo0@00007oool001goool300002_ooo`03o`00oooooooo023oool01?l00?ooooooool000?oool0
1?l00?ooooooool000;oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool01_l00?ooooooool0
0?ooool000?oool01Ol00?ooool00?ooool00002oooo00So003ooooooooo003ooooo003ooooo0002
oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool00ol00?oo
ool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo
003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01_l00?ooooooool00?ooool000;oool0
1?l00?ooooooooooo`Go0002oooo00[o003ooooooooooooo003ooooo003ooooo003oool2o`001Ooo
o`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool000_oool00ol00?ooooooo`02
oooo00?o003oooooool02?ooo`03o`00ooooo`0000?oool01ol00?ooool00?ooool00?ooool00003
oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003oooo00Co
003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2o`0000?o
oooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool00ol00?ooool0000_
oooo0`00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08?ooo`04o`00oooooooo
o`000oooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002oooo00Co
003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool00?ooool0
0?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00?o003oooooool00_oo
o`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool000;oool0
1Ol00?ooool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00oooooooooooo1Ol000;oool02_l00?ooooooooooool00?ooool00?ooool00?oo
o`;o0005oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002oooo`03o`00
oooooooo00;oool00ol00?ooooooo`08oooo00?o003ooooo00000oooo`07o`00ooooo`00ooooo`00
ooooo`0000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_ooo`Co0003oooo0_l0
00?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_oo
o`;o00000oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`03o`00
ooooo`00037oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Poooo00Co
003ooooooooo0003oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool01?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`08o`00oooooooo
o`00ooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?oo
ooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00oooooooo
o`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00
ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00003oooo00Ko003ooooooooo003ooooo000;
oooo00Co003oooooooooool2o`002_ooo`03o`00ooooo`0000?oool01ol00?ooool00?ooool00?oo
ool00003oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003
oooo00Co003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2
o`0000?ooooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool00ol00?oo
ool0000aoooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool08?ooo`04o`00
ooooooooo`000oooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooool00002
oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool02?l00?ooooooool0
0?ooool00?ooool000;oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00?o003ooooo
ool00_ooo`03o`00ooooo`0000;oool01_l00?ooooooool00?ooool000;oool01?l00?ooooooool0
00;oool01Ol00?ooool00?ooool00003oooo00Co003ooooo003oool2o`000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00oooooooooooo1Ol000;oool02_l00?ooooooooooool00?ooool00?oo
ool00?ooo`;o0005oooo00Go003ooooooooooooo00000oooo`06o`00ooooooooo`00ooooo`002ooo
o`04o`00oooooooooooo0_l000[oool00ol00?ooool00003oooo00Oo003ooooo003ooooo003ooooo
00000oooo`04o`00ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l000?oool2o`000ooo
o`04o`00ooooo`00oooo1Ol000Coool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l0
0003ooooo`00oooo00Koool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00?o003ooooo
0000<Oooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo023oool01?l00?oo
ooooool000?oool01?l00?ooooooool000;oool00ol00?ooool00003oooo00?o003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`03o`00ooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool01Ol00?ooool00?ooool00002oooo00So003ooooooooo003o
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00oooooooo
00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002
oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool01_l00?ooooooool0
0?ooool000;oool01?l00?ooooooooooo`Go0002oooo00[o003ooooooooooooo003ooooo003ooooo
003oool2o`001Oooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool00?ooool000_oool0
1?l00?ooooooooooo`;o000:oooo00?o003ooooo00000oooo`07o`00ooooo`00ooooo`00ooooo`00
00?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_ooo`Co0003oooo0_l000?oool0
1?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o0000
0oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_ooo`03o`00ooooo`00
037oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0Noooo00?o003ooooo
00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool00?ooool000?oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool00ol00?oo
ool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool0
0ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko
003ooooooooo003ooooo0002oooo00Co003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00
ooooo`00ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00003oooo00Ko003ooooooooo003o
oooo000;oooo00Co003oooooooooool2o`002_ooo`03o`00ooooo`0000?oool01ol00?ooool00?oo
ool00?ooool00003oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4o`000ooo
o`;o0003oooo00Co003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool0
00;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool0
0ol00?ooool0000aoooo0@00007oool001goool300002_ooo`03o`00oooooooo01koool00ol00?oo
ool00002oooo00Go003ooooooooooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00
ooooo`0000;oool01?l00?ooooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?oo
ool00002oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`03o`00
ooooo`0000;oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000ooo
o`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`04o`00ooooo`00oooo0_l000;oool0
1_l00?ooooooool00?ooool000;oool01?l00?ooooooooooo`Go0002oooo00[o003ooooooooooooo
003ooooo003ooooo003oool2o`001Oooo`05o`00ooooooooooooo`0000?oool01_l00?ooooooool0
0?ooool000_oool01?l00?ooooooooooo`;o000:oooo00?o003ooooo00000oooo`07o`00ooooo`00
ooooo`00ooooo`0000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_ooo`Co0003
oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00ooooooooo`002_oo
o`03o`00ooooo`0002ooool300000Oooo`007Oooo`030000oooooooo00[oool00ol00?ooooooo`0N
oooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool00?ooool0
00?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`00
00;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?oo
o`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5o`000_ooo`0:o`00
ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00003oooo00?o
003oooooool00_l000coool01?l00?ooooooooooo`;o000:oooo00?o003ooooo00000oooo`07o`00
ooooo`00ooooo`00ooooo`0000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_oo
o`Co0003oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00oooooooo
o`002_ooo`03o`00ooooo`00037oool100000Oooo`007Oooo`030000oooooooo00[oool00ol00?oo
ooooo`0Noooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool0
0?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003o
oooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00
ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_oo
o`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00oooooooo
o`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?oo
ool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5o`000_oo
o`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00003
oooo00?o003oooooool00_l000coool01?l00?ooooooooooo`;o000:oooo00?o003ooooo00000ooo
o`07o`00ooooo`00ooooo`00ooooo`0000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02
o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00
ooooooooo`002_ooo`03o`00ooooo`00037oool100000Oooo`007Oooo`030000oooooooo00[oool0
0ol00?ooooooo`0Noooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?oo
ooooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooo
oooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00
ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool0
1?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5
o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?oooooooooo
ool00003oooo00?o003oooooool00_l000coool01?l00?ooooooooooo`;o000:oooo00?o003ooooo
00000oooo`07o`00ooooo`00ooooo`00ooooo`0000?oool01?l00?ooooooool000;oool00ol00?oo
ooooo`02o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo
00000_ooo`04o`00ooooooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00001?oo
o`04o`00ooooooooo`002_ooo`03o`00ooooo`00037oool100000Oooo`007Oooo`030000oooooooo
00[oool00ol00?ooooooo`0Noooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`00
00?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
ooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?oo
ooooooooool00003oooo00?o003oooooool00_l000coool01?l00?ooooooooooo`;o000:oooo00?o
003ooooo00000oooo`07o`00ooooo`00ooooo`00ooooo`0000?oool01?l00?ooooooool000;oool0
0ol00?ooooooo`02o`000_ooo`Co0003oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo
00001?ooo`04o`00ooooooooo`002_ooo`03o`00ooooo`00037oool100000Oooo`007Oooo`030000
oooooooo00[oool00ol00?ooooooo`0Noooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`00
00;oool01_l00?ooooooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000oooo`05o`00ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_oo
o`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00
ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co
003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool0
1Ol00?ooooooooooool00003oooo00?o003oooooool00_l000coool01?l00?ooooooooooo`;o000:
oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool2o`000oooo`04o`00ooooooooo`000_oo
o`03o`00oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00ooooo`00oooo1Ol000Coool0
0ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00003ooooo`00oooo00Koool00ol00?oo
ool00004oooo00Co003ooooooooo000:oooo00?o003ooooo0000<Oooo`400001oooo000Moooo0`00
00[oool00ol00?ooooooo`0Noooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool0
1_l00?ooooooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko
003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000ooo
o`05o`00ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_oo
o`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`00
00?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
ooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?oo
ooooooooool00003oooo00?o003oooooool00_l000coool01?l00?ooooooooooo`;o000:oooo00?o
003ooooo00000oooo`03o`00ooooo`0000;oool2o`000oooo`04o`00ooooooooo`000_ooo`03o`00
oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00ooooo`00oooo1Ol000Coool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo0_l00003ooooo`00oooo00Koool00ol00?ooool00004
oooo00Co003ooooooooo000:oooo00?o003ooooo0000;oooo`<00001oooo000Moooo00<0003ooooo
ool02_ooo`03o`00oooooooo01Woool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`05o`00
ooooooooooooo`0000;oool01_l00?ooooooool00?ooool000?oool00ol00?ooool00002oooo00Co
003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_oo
o`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002oooo00Ko003ooooooooo003o
oooo0002oooo00Co003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00
oooo0_l000Goool01Ol00?ooooooooooool00003oooo00?o003oooooool00_l000coool01?l00?oo
ooooooooo`;o000:oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool2o`000oooo`04o`00
ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00ooooo`00
oooo1Ol000Coool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00003ooooo`00oooo
00Koool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00?o003ooooo0000<Oooo`400001
oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo01Woool00ol00?ooooooo`02oooo00?o
003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool00?ooool000?oool0
0ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o
003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool0
0ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`00
00?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_oo
o`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool01?l00?ooool00?ooo`;o0002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5o`000_ooo`0:o`00oooooooo
ooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00002oooo0_l000;oool2
o`003?ooo`04o`00oooooooooooo0_l000[oool00ol00?ooool00003oooo00?o003ooooo00000_oo
o`;o0003oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003
oooo00Co003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2
o`0000?ooooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool000[oool00ol00?oo
ool0000aoooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003oooooool06Oooo`03o`00
oooooooo00;oool00ol00?ooool00002oooo00Go003ooooooooooooo00000_ooo`06o`00oooooooo
o`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool01_l00?ooooooool0
0?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo00Go003ooooo
003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo00000oooo`03o`00
ooooo`0000?o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003oooooooooool5o`000_oo
o`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?ooooooooooool00002
oooo0_l000;oool2o`003?ooo`04o`00oooooooooooo0_l000[oool00ol00?ooool00003oooo00?o
003ooooo00000_ooo`;o0003oooo00Co003ooooooooo0002oooo00?o003oooooool00_l000;oool4
o`000oooo`;o0003oooo00Co003ooooo003oool5o`001?ooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000Coool01?l00?ooooooool0
00[oool00ol00?ooool0000aoooo0@00007oool001goool00`000?ooooooo`0:oooo00?o003ooooo
ool06Oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Go003ooooooooooooo00000_oo
o`06o`00ooooooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?ooooooool000;oool0
1_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003
oooo00Go003ooooo003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00002oooo00Co
003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool00ol00?ooool00002
oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go003ooooo003ooooo
00000oooo`03o`00ooooo`0000?o0002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooo
ooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l000Goool01Ol00?oo
ooooooooool00002oooo0_l000;oool2o`003?ooo`04o`00oooooooooooo0_l000[oool00ol00?oo
ool00003oooo00?o003ooooo00000_ooo`;o0003oooo00Co003ooooooooo0002oooo00?o003ooooo
ool00_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool5o`001?ooo`03o`00ooooo`00
00;oool01?l00?ooooooool000;oool2o`0000?ooooo003oool01_ooo`03o`00ooooo`0000Coool0
1?l00?ooooooool000[oool00ol00?ooool0000aoooo0@00007oool001goool00`000?ooooooo`0:
oooo00?o003oooooool06Oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Go003ooooo
oooooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go
003ooooo003ooooo00000oooo`03o`00ooooo`0000?o0002oooo00Ko003ooooooooo003ooooo0002
oooo00Co003oooooooooool5o`000_ooo`0:o`00ooooooooooooo`00ooooo`00ooooo`00oooo0_l0
00Goool01Ol00?ooooooooooool00002oooo0_l000;oool2o`003?ooo`04o`00oooooooooooo0_l0
00[oool00ol00?ooool00003oooo00?o003ooooo00000_ooo`;o0003oooo00Co003ooooooooo0002
oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool5o`001?oo
o`03o`00ooooo`0000;oool01?l00?ooooooool000;oool2o`0000?ooooo003oool01_ooo`03o`00
ooooo`0000Coool01?l00?ooooooool000[oool00ol00?ooool0000aoooo0@00007oool001goool3
00002_ooo`03o`00oooooooo01Woool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`05o`00
ooooooooooooo`0000;oool01_l00?ooooooool00?ooool000?oool00ol00?ooool00002oooo00Co
003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o
003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_oo
o`05o`00ooooo`00ooooo`0000?oool00ol00?ooool00003o`000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00oooooooooooo1Ol000;oool02_l00?ooooooooooool00?ooool00?ooool00?oo
o`;o0005oooo00Go003ooooooooooooo00000_ooo`;o0002oooo0_l000coool01?l00?oooooooooo
o`;o000:oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool2o`000oooo`04o`00oooooooo
o`000_ooo`03o`00oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00ooooo`00oooo1Ol0
00Coool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00003ooooo`00oooo00Koool0
0ol00?ooool00004oooo00Co003ooooooooo000:oooo00?o003ooooo0000;oooo`<00001oooo000M
oooo00<0003oooooool02_ooo`03o`00oooooooo01Woool00ol00?ooooooo`02oooo00?o003ooooo
00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool00?ooool000?oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002oooo00?o003ooooo
00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`0000;oool00ol00?oo
ool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00ooooo`0000?oool0
0ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00
ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooool00003o`000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00oooooooooooo1Ol000;oool02_l00?ooooooooooool00?oo
ool00?ooool00?ooo`;o0005oooo00Go003ooooooooooooo00000_ooo`;o0002oooo0_l000coool0
1?l00?ooooooooooo`;o000:oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool2o`000ooo
o`04o`00ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00
ooooo`00oooo1Ol000Coool00ol00?ooool00002oooo00Co003ooooooooo0002oooo0_l00003oooo
o`00oooo00Koool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00?o003ooooo0000<Ooo
o`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo01Woool00ol00?ooooooo`02
oooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?ooooooool00?ooool0
00?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooooooo003ooooo0002
oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00ooooo`00ooooo`00
00;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00ooooooooo`000_ooo`03o`00
ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00oooo
o`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool00ol00?ooool00003
o`000_ooo`06o`00ooooooooo`00ooooo`000_ooo`04o`00oooooooooooo1?l000?oool02_l00?oo
ooooooooool00?ooool00?ooool00?ooo`;o0005oooo00Go003ooooooooooooo00000_ooo`;o0002
oooo0_l000coool01?l00?ooooooooooo`;o000:oooo00?o003ooooo00000oooo`03o`00ooooo`00
00;oool2o`000oooo`04o`00ooooooooo`000_ooo`03o`00oooooooo00;o0002oooo1?l000?oool2
o`000oooo`04o`00ooooo`00oooo1Ol000Coool00ol00?ooool00002oooo00Co003ooooooooo0002
oooo0_l00003ooooo`00oooo00Koool00ol00?ooool00004oooo00Co003ooooooooo000:oooo00?o
003ooooo0000<Oooo`400001oooo000Moooo00<0003oooooool02_ooo`03o`00oooooooo01Woool0
0ol00?ooooooo`02oooo00?o003ooooo00000_ooo`05o`00ooooooooooooo`0000;oool01_l00?oo
ooooool00?ooool000?oool00ol00?ooool00002oooo00Co003ooooooooo0002oooo00Ko003ooooo
oooo003ooooo0002oooo00?o003ooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`05o`00
ooooo`00ooooo`0000;oool00ol00?ooool00002oooo00?o003ooooo00000_ooo`04o`00oooooooo
o`000_ooo`03o`00ooooo`0000?oool00ol00?ooooooo`02oooo00?o003ooooo00000_ooo`06o`00
ooooooooo`00ooooo`000_ooo`04o`00ooooooooo`000_ooo`05o`00ooooo`00ooooo`0000?oool0
0ol00?ooool00003o`000_ooo`;o00001?ooool00?ooool000;oool01?l00?ooooooooooo`Co0003
oooo00[o003ooooooooooooo003ooooo003ooooo003oool2o`001Oooo`05o`00ooooooooooooo`00
00;oool2o`000_ooo`;o000<oooo00Co003oooooooooool2o`002_ooo`03o`00ooooo`0000?oool0
0ol00?ooool00002oooo0_l000?oool01?l00?ooooooool000;oool00ol00?ooooooo`02o`000_oo
o`Co0003oooo0_l000?oool01?l00?ooool00?ooo`Go0004oooo00?o003ooooo00000_ooo`04o`00
ooooooooo`000_ooo`;o00000oooool00?ooo`06oooo00?o003ooooo00001?ooo`04o`00oooooooo
o`002_ooo`03o`00ooooo`00037oool100000Oooo`005?ooo`<00006oooo00<0003oooooool01ooo
o`040000ooooooooo`006oooo`03o`00oooooooo00;oool00ol00?ooool00002oooo00Go003ooooo
oooooooo00000_ooo`06o`00ooooooooo`00ooooo`000oooo`03o`00ooooo`0000;oool01?l00?oo
ooooool000;oool01_l00?ooooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooo
oooo003ooooo0003oooo00Go003ooooo003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?oo
ool00002oooo00Co003ooooooooo0002oooo00?o003ooooo00000oooo`03o`00oooooooo00;oool0
0ol00?ooool00002oooo00Ko003ooooooooo003ooooo0002oooo00Co003ooooooooo0002oooo00Go
003ooooo003ooooo00000oooo`03o`00ooooo`0000?o0002oooo0_l00004ooooo`00ooooo`000_oo
o`04o`00oooooooooooo1?l000?oool02_l00?ooooooooooool00?ooool00?ooool00?ooo`;o0005
oooo00Go003ooooooooooooo00000_ooo`;o0002oooo0_l000coool01?l00?ooooooooooo`;o000:
oooo00?o003ooooo00000oooo`03o`00ooooo`0000;oool2o`000oooo`04o`00ooooooooo`000_oo
o`03o`00oooooooo00;o0002oooo1?l000?oool2o`000oooo`04o`00ooooo`00oooo1Ol000Coool0
1_l00?ooool000000?ooool000;oool00ol00?ooooooo`02o`0000?ooooo003oool01_ooo`03o`00
ooooo`0000Coool01?l00?ooooooool000[oool00ol00?ooool0000aoooo0@00007oool001Coool0
0`000?ooooooo`06oooo00<0003oooooool01oooo`040000ooooooooo`003oooo`030000oooooooo
00Woool00ol00?ooooooo`02oooo00Ko003ooooo0000003ooooo0003oooo00Co003ooooooooo0002
oooo00?o003ooooo00000oooo`03o`000000o`0000;oool01?l00?ooooooool000;oool01_l00?oo
ooooool00?ooool000;oool00ol00?ooool00002oooo00Ko003ooooooooo003ooooo0003oooo00Go
003ooooo003ooooo00000_ooo`03o`00ooooo`0000;oool00ol00?ooool00002oooo00Co003ooooo
oooo0002oooo00Oo003ooooo003oool0003ooooo00001?ooo`03o`00ooooo`0000;oool01_l00?oo
ooooool00?ooool000;oool01?l00?ooooooool000;oool01Ol00?ooool00?ooool00003oooo00?o
003ooooo00000ol000;oool2o`0000Cooooo003ooooo0002oooo00Co003oooooooooool4o`0000Co
ool0003ooooo0003oooo00Ko003ooooo003ooooo003oool2o`001Oooo`05o`00ooooooooooooo`00
00;oool2o`000_ooo`;o0007oooo00<0003oooooool00_ooo`04o`00oooooooooooo0_l000Soool0
1@000?ooool00?ooool00003oooo00?o003ooooo00000_ooo`;o0003oooo00Co003oool0003o0002
oooo00?o003oooooool00_l000;oool4o`000oooo`;o0003oooo00Co003ooooo003oool5o`001?oo
o`06o`00ooooo`000000ooooo`000_ooo`03o`00oooooooo00;o00000oooool00?ooo`06oooo00?o
0000003o00001?ooo`04o`00ooooooooo`002Oooo`040000o`00ooooo`004?ooo`030000oooooooo
013oool00`000?ooooooo`0;oooo0@00007oool001Goool00`000?ooooooo`05oooo3@000003o`00
0000000001T000000ol0000000000002000000?o0000003o00000P000005o`00000000000000o`00
008000001_l0000000000?l000000?l000<000000ol000000?l00002000000Co00000000003o0002
000000Ko00000000003o0000003o0002000000?o0000003o00000P000006o`0000000000o`000000
o`000`000005o`000000o`000000o`00008000000ol000000?l00002000000?o0000003o00000P00
0004o`0000000000o`000P000003o`000000o`0000<000000ol0000000000002000000?o0000003o
00000P000006o`0000000000o`000000o`000P000004o`0000000000o`000P000005o`000000o`00
0000o`0000<000000ol000000?l00003o`000P0000;o000010000?l000000?l0008000001?l00000
0000000000Co0003000000[o000000000000003o0000003o0000003o00000002o`001@000005o`00
000000000000o`0000800002o`000P0000;o000<000000Co0000000000000002o`002P000003o`00
0000o`0000<000000ol000000?l0000200000_l000<000001?l0000000000?l0008000000ol00000
00000002o`000P0000Co000300000_l000<000001?l000000?l0000000Go0004000000?o0000003o
00000P000004o`0000000000o`000P0000;o00000`000?l000000006000000?o0000003o00001000
0004o`0000000000o`002P000003o`000000o`0003800001oooo000Eoooo00<0003oooooool0oooo
oi?oool001Coool00`000?ooo`00003oooooU?ooo`005Oooo`030000oooooooo0?oooonCoooo003o
ooooZoooo`00\
\>"],
  ImageRangeCache->{{{0, 425}, {262.188, 0}} -> {-199.808, -0.114305, 
  5.11148, 0.00820491}}]
}, Open  ]],

Cell["Pr\[OAcute]g segmentacji", "MathCaption"],

Cell[BoxData[
    \(\(SegTable = 
      Table[SegMeas\[LeftDoubleBracket]i\[RightDoubleBracket] < 1, {i, 2, 
          Length[SegMeas]}]; \)\)], "Input",
  CellLabel->"In[29]:="],

Cell["Tabela punkt\[OAcute]w segmentacji", "MathCaption"],

Cell[BoxData[
    \(\(SegPoints = 
      Table[If[SegTable\[LeftDoubleBracket]i\[RightDoubleBracket] && 
            \(! SegTable\[LeftDoubleBracket]i - 1\[RightDoubleBracket]\), 1, 
          0], {i, 2, Length[SegTable]}]; \)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(Gap = 10; \n
    For[i = 1, i <= Length[SegPoints] - Gap, \(i++\), \n\t
      If[SegPoints\[LeftDoubleBracket]i\[RightDoubleBracket] == 1, \n\t\t
        For[j = 1, j <= Gap - 1, \(j++\), \n\t\t\t
          SegPoints\[LeftDoubleBracket]i + j\[RightDoubleBracket] = 0]]]; 
    \)], "Input",
  CellLabel->"In[31]:="],

Cell[TextData["Liczba punkt\[OAcute]w podzia\[LSlash]u"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SegN = 
      1 + \[Sum]\+\(i = 1\)\%\(Length[SegPoints]\)SegPoints
            \[LeftDoubleBracket]i\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(TraditionalForm\`53\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Analiza sygna\[LSlash]u w segmentach"], "Section"],

Cell[TextData[
"Obliczenie \.9credniej wa\:017conej funkcji autokorelacji w segmentach"], 
  "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 0; \nprevj = 0; \nMeanWall = {}; \n
    MeanWAK = 
      Table[0, {
          Length[T\[LSlash]AutoK\[LeftDoubleBracket]1
              \[RightDoubleBracket]]}]; \nWy = {}; \n
    For[i = 1, i <= SegN, \(i++\), \n\tAutoKTable = {}; \n\t\(j++\); \n\t
      While[SegPoints\[LeftDoubleBracket]j\[RightDoubleBracket] != 1, \n\t\t
        AppendTo[AutoKTable, 
          T\[LSlash]AutoK\[LeftDoubleBracket]j\[RightDoubleBracket] 
            SegMeas\[LeftDoubleBracket]j\[RightDoubleBracket]]; \(j++\)]; \n\t
      For[k = 1, 
        k <= Length[
            T\[LSlash]AutoK\[LeftDoubleBracket]1\[RightDoubleBracket]], 
        \(k++\), \n\t\t
        MeanWAK\[LeftDoubleBracket]k\[RightDoubleBracket] = 
          Mean[Table[
              AutoKTable\[LeftDoubleBracket]l, k\[RightDoubleBracket], {l, 
                j - prevj - 1}]]]; \n\tprevj = j; \n\t
      AppendTo[MeanWall, MeanWAK\/Max[MeanWAK]]]; \)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Part::"partw"\), \( : \ \), 
        "\<\"Part \\!\\(TraditionalForm\\`1919\\) of \\!\\(TraditionalForm\\`\
\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\)\\) does not exist.\"\>"}], 
      TraditionalForm]], "Message"]
}, Open  ]],

Cell["Detekcja maksim\[OAcute]w funkcji autokorelacji", "MathCaption"],

Cell[BoxData[
    \(\(MaksSegAK = MaksAutoK[MeanWall]; \)\)], "Input",
  CellLabel->"In[34]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interfejs predyktora", "Section"],

Cell[TextData[
"Obliczenie d\[LSlash]ugo\.9cci segment\[OAcute]w"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SegL = {}; \nprev = 0; \n
    For[i = 1, i <= Length[SegPoints], \(i++\), \n\t
      If[SegPoints\[LeftDoubleBracket]i\[RightDoubleBracket] == 1, \n\t\t
        AppendTo[SegL, i - prev]; \n\t\tprev = i]]; \n
    AppendTo[SegL, Length[SegPoints] - prev]; \)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`SegL\\)\\\" is similar to existing symbol \\\"\\!\
\\(TraditionalForm\\`SegN\\)\\\".\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"spell1"\), \( : \ \), 
        "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(TraditionalForm\\`prev\\)\\\" is similar to existing symbol \\\"\\!\
\\(TraditionalForm\\`prevj\\)\\\".\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell[TextData[StyleBox[
"Wyznaczenie zakres\[OAcute]w poszczeg\[OAcute]lnych pasm \
p\[OAcute]\[LSlash]tonowych"]], "MathCaption"],

Cell[BoxData[
    \(\(Pasma = GetBands[444, CzMin, CzMax]; \)\)], "Input",
  CellLabel->"In[36]:="],

Cell[TextData[StyleBox[
"Wyznaczenie maksim\[OAcute]w funkcji autokorelacji w pasmach dla poszczeg\
\[OAcute]lnych segment\[OAcute]w"]], "MathCaption"],

Cell[BoxData[
    \(\(MaxWPasmach = GetMaksBands[MeanWall, Pasma]; \)\)], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[MaxWPasmach]; \)\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.24387 .16106 -11.5275 -9 ]
[.24387 .16106 .47255 0 ]
[.49274 .0632 -10.5833 -9 ]
[.49274 .0632 1.41667 0 ]
[.818 .17443 0 -6.08724 ]
[.818 .17443 12 2.91276 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 12 3.06285 ]
[.01783 .30448 -24 -2.77559 ]
[.01783 .30448 0 6.22441 ]
[.00844 .36333 -6 -2.82548 ]
[.00844 .36333 0 6.17452 ]
[-0.00131 .42444 -18 -2.87749 ]
[-0.00131 .42444 0 6.12251 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.25276 .17071 m
.25721 .17554 L
s
[(20)] .24387 .16106 .92124 1 Mshowa
.5007 .07363 m
.50469 .07884 L
s
[(40)] .49274 .0632 .76389 1 Mshowa
.125 Mabswid
.08106 .23795 m
.0839 .24068 L
s
.13703 .21603 m
.13981 .21882 L
s
.19425 .19363 m
.19697 .19647 L
s
.31262 .14728 m
.31522 .15023 L
s
.37386 .1233 m
.3764 .12631 L
s
.43654 .09875 m
.43901 .10182 L
s
.56641 .0479 m
.56872 .05109 L
s
.63371 .02155 m
.63593 .02479 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.80562 .1788 m
.79944 .18098 L
s
[(20)] .818 .17443 -1 .35272 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(40)] .9224 .33431 -1 .31937 Mshowa
.125 Mabswid
.71502 .0402 m
.71134 .04161 L
s
.74656 .08845 m
.74287 .08982 L
s
.77673 .1346 m
.77303 .13594 L
s
.83332 .22116 m
.82959 .22244 L
s
.85988 .26179 m
.85615 .26305 L
s
.88539 .30081 m
.88165 .30203 L
s
.93346 .37435 m
.92971 .37552 L
s
.95614 .40904 m
.95238 .41019 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03008 .29978 m
.03621 .29744 L
s
[(-0.5)] .01783 .30448 1 -0.3832 Mshowa
.02074 .35875 m
.02689 .35646 L
s
[(0)] .00844 .36333 1 -0.37212 Mshowa
.01104 .41999 m
.01721 .41776 L
s
[(0.5)] -0.00131 .42444 1 -0.36056 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.02824 .3114 m
.03192 .31 L
s
.02639 .32311 m
.03007 .32171 L
s
.02452 .3349 m
.0282 .33351 L
s
.02264 .34678 m
.02632 .3454 L
s
.01883 .37081 m
.02252 .36945 L
s
.0169 .38297 m
.0206 .38161 L
s
.01496 .39521 m
.01866 .39386 L
s
.01301 .40755 m
.01671 .40621 L
s
.00905 .43252 m
.01276 .43119 L
s
.00705 .44515 m
.01076 .44383 L
s
.00503 .45788 m
.00874 .45657 L
s
.003 .4707 m
.00671 .4694 L
s
.03191 .28825 m
.03559 .28684 L
s
.03373 .27681 m
.0374 .27538 L
s
.03553 .26544 m
.0392 .26401 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.474 .591 .89 r
.39585 .69094 .40179 .69906 .41174 .69548 .40564 .69256 Metetra
.896 .496 .245 r
.40564 .69256 .41174 .69548 .42096 .71779 .41487 .71414 Metetra
.925 .743 .637 r
.41487 .71414 .42096 .71779 .43173 .68872 .42606 .67274 Metetra
.827 .491 0 r
.42606 .67274 .43173 .68872 .44166 .69 .4352 .70477 Metetra
.155 0 .157 r
.4352 .70477 .44166 .69 .4517 .6894 .44554 .69406 Metetra
.588 .127 .126 r
.44554 .69406 .4517 .6894 .46157 .70048 .45559 .69776 Metetra
.911 .53 .287 r
.45559 .69776 .46157 .70048 .47131 .7284 .46532 .72493 Metetra
.939 .731 .597 r
.46532 .72493 .47131 .7284 .48231 .67055 .47651 .66254 Metetra
.835 .404 0 r
.47651 .66254 .48231 .67055 .49246 .67442 .48647 .68324 Metetra
.797 .451 .401 r
.48647 .68324 .49246 .67442 .5027 .67577 .49662 .70363 Metetra
.274 .027 .346 r
.49662 .70363 .5027 .67577 .51301 .67602 .50714 .68679 Metetra
.998 .819 .532 r
.50714 .68679 .51301 .67602 .52338 .66412 .51769 .62773 Metetra
.867 .608 .078 r
.51769 .62773 .52338 .66412 .53389 .71593 .52809 .71195 Metetra
.879 .442 .112 r
.52809 .71195 .53389 .71593 .54461 .73685 .53879 .73298 Metetra
.943 .747 .61 r
.53879 .73298 .54461 .73685 .5549 .6873 .5492 .68413 Metetra
.951 .736 .575 r
.5492 .68413 .5549 .6873 .56514 .6534 .55918 .61541 Metetra
.444 .339 .641 r
.55918 .61541 .56514 .6534 .57574 .65422 .56986 .62871 Metetra
.854 .565 .032 r
.56986 .62871 .57574 .65422 .58631 .64994 .58148 .69181 Metetra
.584 .324 .488 r
.58148 .69181 .58631 .64994 .59698 .64887 .59241 .69514 Metetra
.472 .234 .471 r
.59241 .69514 .59698 .64887 .60782 .65307 .60307 .68316 Metetra
.769 .7 .16 r
.60307 .68316 .60782 .65307 .61856 .65006 .61238 .61844 Metetra
.758 .565 .636 r
.61238 .61844 .61856 .65006 .62905 .63724 .62239 .59019 Metetra
.631 .458 .631 r
.62239 .59019 .62905 .63724 .63815 .58344 .6329 .58156 Metetra
.942 .598 .343 r
.6329 .58156 .63815 .58344 .65094 .63833 .64569 .63792 Metetra
.946 .623 .386 r
.64569 .63792 .65094 .63833 .66544 .72625 .6599 .72046 Metetra
0 .392 .844 r
.6599 .72046 .66544 .72625 .67707 .73246 .67155 .72686 Metetra
.845 .797 .805 r
.67155 .72686 .67707 .73246 .68796 .7205 .68248 .71462 Metetra
.96 .725 .537 r
.68248 .71462 .68796 .7205 .69487 .62789 .68976 .62627 Metetra
.975 .754 .54 r
.68976 .62627 .69487 .62789 .70237 .55655 .69755 .55789 Metetra
.69755 .55789 .70237 .55655 .71449 .57542 .7085 .55489 Metetra
.494 .436 .721 r
.7085 .55489 .71449 .57542 .72715 .60026 .71998 .56012 Metetra
.592 .441 .645 r
.71998 .56012 .72715 .60026 .73917 .61117 .73114 .55857 Metetra
.546 .394 .627 r
.73114 .55857 .73917 .61117 .75051 .60951 .74282 .56421 Metetra
.387 .293 .626 r
.74282 .56421 .75051 .60951 .76179 .60634 .75577 .58709 Metetra
0 0 .421 r
.75577 .58709 .76179 .60634 .77291 .6002 .76984 .62266 Metetra
.695 .378 .436 r
.76984 .62266 .77291 .6002 .78392 .59241 .78277 .63868 Metetra
.66 .388 .497 r
.78277 .63868 .78392 .59241 .79524 .58827 .79614 .65817 Metetra
.553 .318 .512 r
.79614 .65817 .79524 .58827 .8068 .58653 .80788 .65499 Metetra
.553 .317 .511 r
.80788 .65499 .8068 .58653 .81866 .58767 .81967 .65181 Metetra
.481 .258 .499 r
.81967 .65181 .81866 .58767 .83046 .58717 .83024 .63442 Metetra
.411 .191 .467 r
.83024 .63442 .83046 .58717 .84231 .58661 .84042 .61323 Metetra
.187 0 .346 r
.84042 .61323 .84231 .58661 .85419 .58566 .85023 .58889 Metetra
.95 .921 .562 r
.85023 .58889 .85419 .58566 .86606 .58387 .8599 .56426 Metetra
.794 .621 .667 r
.8599 .56426 .86606 .58387 .87782 .58058 .86972 .54204 Metetra
.691 .509 .636 r
.86972 .54204 .87782 .58058 .88964 .57727 .87992 .52432 Metetra
.641 .46 .623 r
.87992 .52432 .88964 .57727 .90148 .57376 .89064 .51179 Metetra
.614 .435 .616 r
.89064 .51179 .90148 .57376 .91304 .56737 .90186 .50374 Metetra
.602 .426 .616 r
.90186 .50374 .91304 .56737 .92414 .55689 .91339 .49832 Metetra
.604 .431 .62 r
.91339 .49832 .92414 .55689 .93466 .54159 .92497 .49297 Metetra
.621 .451 .63 r
.92497 .49297 .93466 .54159 .94458 .52186 .93631 .4855 Metetra
.09 .115 .593 r
.93631 .4855 .94458 .52186 .95875 .53556 .95423 .52911 Metetra
.657 .751 .919 r
.95423 .52911 .95875 .53556 .97082 .53214 .96633 .52566 Metetra
.657 .751 .919 r
.96633 .52566 .97082 .53214 .98294 .52871 .97849 .5222 Metetra
.699 .767 .904 r
.38976 .68581 .39585 .69094 .40564 .69256 .39977 .68179 Metetra
.885 .498 .041 r
.39977 .68179 .40564 .69256 .41487 .71414 .40883 .70763 Metetra
.909 .719 .634 r
.40883 .70763 .41487 .71414 .42606 .67274 .42018 .66352 Metetra
.958 .627 .337 r
.42018 .66352 .42606 .67274 .4352 .70477 .42885 .71099 Metetra
.861 .97 .65 r
.42885 .71099 .4352 .70477 .44554 .69406 .4394 .69482 Metetra
.853 .974 .868 r
.4394 .69482 .44554 .69406 .45559 .69776 .44977 .685 Metetra
.884 .517 .039 r
.44977 .685 .45559 .69776 .46532 .72493 .45938 .7162 Metetra
.909 .707 .618 r
.45938 .7162 .46532 .72493 .47651 .66254 .47051 .66443 Metetra
.839 .439 .287 r
.47051 .66443 .47651 .66254 .48647 .68324 .48052 .68234 Metetra
.913 .559 .352 r
.48052 .68234 .48647 .68324 .49662 .70363 .49053 .71722 Metetra
.788 .836 .371 r
.49053 .71722 .49662 .70363 .50714 .68679 .50122 .6895 Metetra
.97 .762 .568 r
.50122 .6895 .50714 .68679 .51769 .62773 .51196 .62149 Metetra
.955 .643 .399 r
.51196 .62149 .51769 .62773 .52809 .71195 .52224 .69842 Metetra
0 0 .333 r
.52224 .69842 .52809 .71195 .53879 .73298 .53291 .72177 Metetra
.882 .696 .647 r
.53291 .72177 .53879 .73298 .5492 .68413 .54348 .68603 Metetra
.97 .749 .549 r
.54348 .68603 .5492 .68413 .55918 .61541 .5535 .60409 Metetra
.389 .474 .826 r
.5535 .60409 .55918 .61541 .56986 .62871 .56407 .60893 Metetra
.975 .67 .317 r
.56407 .60893 .56986 .62871 .58148 .69181 .57612 .7103 Metetra
.617 .297 .405 r
.57612 .7103 .58148 .69181 .59241 .69514 .58718 .71592 Metetra
0 0 .179 r
.58718 .71592 .59241 .69514 .60307 .68316 .59778 .69451 Metetra
.995 .775 .489 r
.59778 .69451 .60307 .68316 .61238 .61844 .60656 .60022 Metetra
.764 .608 .685 r
.60656 .60022 .61238 .61844 .62239 .59019 .61691 .58343 Metetra
.779 .75 .827 r
.61691 .58343 .62239 .59019 .6329 .58156 .62747 .57519 Metetra
.951 .6 .281 r
.62747 .57519 .6329 .58156 .64569 .63792 .6401 .62893 Metetra
.963 .632 .311 r
.6401 .62893 .64569 .63792 .6599 .72046 .65402 .70635 Metetra
.359 .42 .788 r
.65402 .70635 .6599 .72046 .67155 .72686 .6657 .71365 Metetra
.718 .629 .758 r
.6657 .71365 .67155 .72686 .68248 .71462 .67683 .70563 Metetra
.947 .716 .555 r
.67683 .70563 .68248 .71462 .68976 .62627 .68472 .62727 Metetra
.984 .762 .522 r
.68472 .62727 .68976 .62627 .69755 .55789 .69241 .5539 Metetra
.607 .81 .978 r
.69241 .5539 .69755 .55789 .7085 .55489 .70343 .55138 Metetra
.625 .838 .982 r
.70343 .55138 .7085 .55489 .71998 .56012 .71446 .54831 Metetra
.648 .609 .796 r
.71446 .54831 .71998 .56012 .73114 .55857 .72553 .54506 Metetra
.706 .617 .754 r
.72553 .54506 .73114 .55857 .74282 .56421 .73639 .5378 Metetra
0 0 .537 r
.73639 .5378 .74282 .56421 .75577 .58709 .75009 .57301 Metetra
.891 .543 .058 r
.75009 .57301 .75577 .58709 .76984 .62266 .76571 .63143 Metetra
.83 .454 .341 r
.76571 .63143 .76984 .62266 .78277 .63868 .77949 .65829 Metetra
.777 .445 .426 r
.77949 .65829 .78277 .63868 .79614 .65817 .79369 .68734 Metetra
.52 .242 .433 r
.79369 .68734 .79614 .65817 .80788 .65499 .80559 .68418 Metetra
.52 .242 .433 r
.80559 .68418 .80788 .65499 .81967 .65181 .81753 .68101 Metetra
.07 0 .314 r
.81753 .68101 .81967 .65181 .83024 .63442 .82702 .64898 Metetra
.82702 .64898 .83024 .63442 .84042 .61323 .83626 .61597 Metetra
.994 .864 .531 r
.83626 .61597 .84042 .61323 .85023 .58889 .84508 .58016 Metetra
.932 .748 .63 r
.84508 .58016 .85023 .58889 .8599 .56426 .85387 .54598 Metetra
.835 .648 .65 r
.85387 .54598 .8599 .56426 .86972 .54204 .86308 .51758 Metetra
.752 .578 .66 r
.86308 .51758 .86972 .54204 .87992 .52432 .87307 .49792 Metetra
.662 .517 .677 r
.87307 .49792 .87992 .52432 .89064 .51179 .88423 .48965 Metetra
.568 .477 .712 r
.88423 .48965 .89064 .51179 .90186 .50374 .89645 .49067 Metetra
.595 .57 .795 r
.89645 .49067 .90186 .50374 .91339 .49832 .90852 .48972 Metetra
.659 .685 .863 r
.90852 .48972 .91339 .49832 .92497 .49297 .92035 .48625 Metetra
.66 .74 .909 r
.92035 .48625 .92497 .49297 .93631 .4855 .93223 .48276 Metetra
.882 .46 .052 r
.93223 .48276 .93631 .4855 .95423 .52911 .94967 .52261 Metetra
.657 .751 .919 r
.94967 .52261 .95423 .52911 .96633 .52566 .96181 .51914 Metetra
.657 .751 .919 r
.96181 .51914 .96633 .52566 .97849 .5222 .97401 .51565 Metetra
.76 .768 .86 r
.38364 .68048 .38976 .68581 .39977 .68179 .39376 .67403 Metetra
.951 .613 .336 r
.39376 .67403 .39977 .68179 .40883 .70763 .40223 .71575 Metetra
.986 .81 .583 r
.40223 .71575 .40883 .70763 .42018 .66352 .41402 .66243 Metetra
.887 .501 .294 r
.41402 .66243 .42018 .66352 .42885 .71099 .42335 .68513 Metetra
.639 .501 .679 r
.42335 .68513 .42885 .71099 .4394 .69482 .4336 .6799 Metetra
.607 .545 .759 r
.4336 .6799 .4394 .69482 .44977 .685 .44378 .67853 Metetra
.942 .585 .295 r
.44378 .67853 .44977 .685 .45938 .7162 .45324 .71538 Metetra
.951 .759 .608 r
.45324 .71538 .45938 .7162 .47051 .66443 .46449 .66419 Metetra
.441 0 0 r
.46449 .66419 .47051 .66443 .48052 .68234 .47471 .66797 Metetra
.08 .229 .718 r
.47471 .66797 .48052 .68234 .49053 .71722 .48491 .68009 Metetra
.604 .452 .649 r
.48491 .68009 .49053 .71722 .50122 .6895 .49537 .67712 Metetra
.891 .688 .622 r
.49537 .67712 .50122 .6895 .51196 .62149 .50611 .62887 Metetra
.901 .594 .454 r
.50611 .62887 .51196 .62149 .52224 .69842 .51635 .6939 Metetra
.922 .535 .236 r
.51635 .6939 .52224 .69842 .53291 .72177 .52702 .72465 Metetra
.983 .841 .625 r
.52702 .72465 .53291 .72177 .54348 .68603 .53769 .68954 Metetra
.973 .751 .54 r
.53769 .68954 .54348 .68603 .5535 .60409 .54785 .60042 Metetra
.941 .596 .337 r
.54785 .60042 .5535 .60409 .56407 .60893 .55886 .64824 Metetra
.71 .433 .503 r
.55886 .64824 .56407 .60893 .57612 .7103 .56997 .67664 Metetra
.607 .462 .659 r
.56997 .67664 .57612 .7103 .58718 .71592 .58082 .67362 Metetra
.68 .499 .634 r
.58082 .67362 .58718 .71592 .59778 .69451 .59145 .65658 Metetra
.767 .563 .622 r
.59145 .65658 .59778 .69451 .60656 .60022 .60158 .61962 Metetra
.60158 .61962 .60656 .60022 .61691 .58343 .6117 .58892 Metetra
.997 .86 .563 r
.6117 .58892 .61691 .58343 .62747 .57519 .62149 .55116 Metetra
.897 .594 .093 r
.62149 .55116 .62747 .57519 .6401 .62893 .63463 .62438 Metetra
.957 .631 .359 r
.63463 .62438 .6401 .62893 .65402 .70635 .64866 .70758 Metetra
.661 .13 0 r
.64866 .70758 .65402 .70635 .6657 .71365 .6604 .71552 Metetra
.707 .982 .799 r
.6604 .71552 .6657 .71365 .67683 .70563 .67155 .70633 Metetra
.981 .754 .52 r
.67155 .70633 .67683 .70563 .68472 .62727 .67942 .62371 Metetra
.968 .74 .539 r
.67942 .62371 .68472 .62727 .69241 .5539 .68716 .54851 Metetra
.571 .739 .955 r
.68716 .54851 .69241 .5539 .70343 .55138 .69827 .54717 Metetra
0 .196 .655 r
.69827 .54717 .70343 .55138 .71446 .54831 .70995 .5552 Metetra
.671 .244 .224 r
.70995 .5552 .71446 .54831 .72553 .54506 .72174 .563 Metetra
.649 .319 .399 r
.72174 .563 .72553 .54506 .73639 .5378 .73371 .57177 Metetra
.658 .371 .474 r
.73371 .57177 .73639 .5378 .75009 .57301 .7462 .58665 Metetra
.76 .405 .382 r
.7462 .58665 .75009 .57301 .76571 .63143 .7592 .60647 Metetra
.492 .416 .699 r
.7592 .60647 .76571 .63143 .77949 .65829 .77144 .61292 Metetra
.555 .41 .639 r
.77144 .61292 .77949 .65829 .79369 .68734 .78357 .6163 Metetra
.59 .414 .611 r
.78357 .6163 .79369 .68734 .80559 .68418 .79527 .61304 Metetra
.59 .414 .611 r
.79527 .61304 .80559 .68418 .81753 .68101 .80701 .60978 Metetra
.636 .446 .608 r
.80701 .60978 .81753 .68101 .82702 .64898 .81774 .59409 Metetra
.642 .46 .621 r
.81774 .59409 .82702 .64898 .83626 .61597 .82865 .58082 Metetra
.682 .51 .647 r
.82865 .58082 .83626 .61597 .84508 .58016 .83943 .56633 Metetra
.79 .66 .719 r
.83943 .56633 .84508 .58016 .85387 .54598 .85011 .55119 Metetra
.592 .815 .419 r
.85011 .55119 .85387 .54598 .86308 .51758 .86075 .53604 Metetra
.247 0 .298 r
.86075 .53604 .86308 .51758 .87307 .49792 .87143 .52156 Metetra
.359 .098 .375 r
.87143 .52156 .87307 .49792 .88423 .48965 .88224 .50858 Metetra
.342 .06 .332 r
.88224 .50858 .88423 .48965 .89645 .49067 .89324 .49759 Metetra
.89324 .49759 .89645 .49067 .90852 .48972 .90432 .48727 Metetra
.898 .937 .831 r
.90432 .48727 .90852 .48972 .92035 .48625 .91513 .47469 Metetra
.829 .701 .724 r
.91513 .47469 .92035 .48625 .93223 .48276 .92545 .45821 Metetra
0 0 .382 r
.92545 .45821 .93223 .48276 .94967 .52261 .94507 .51606 Metetra
.657 .751 .919 r
.94507 .51606 .94967 .52261 .96181 .51914 .95726 .51256 Metetra
.657 .751 .919 r
.95726 .51256 .96181 .51914 .97401 .51565 .96949 .50904 Metetra
.577 .651 .887 r
.37757 .67274 .38364 .68048 .39376 .67403 .38749 .67207 Metetra
.906 .541 .331 r
.38749 .67207 .39376 .67403 .40223 .71575 .39643 .69973 Metetra
.827 .648 .66 r
.39643 .69973 .40223 .71575 .41402 .66243 .40749 .67033 Metetra
.419 0 .124 r
.40749 .67033 .41402 .66243 .42335 .68513 .41758 .66917 Metetra
.712 .386 0 r
.41758 .66917 .42335 .68513 .4336 .6799 .42692 .69643 Metetra
.062 0 .129 r
.42692 .69643 .4336 .6799 .44378 .67853 .43749 .68274 Metetra
.644 .939 .693 r
.43749 .68274 .44378 .67853 .45324 .71538 .44795 .67329 Metetra
.698 .511 .632 r
.44795 .67329 .45324 .71538 .46449 .66419 .45863 .65252 Metetra
.962 .629 .294 r
.45863 .65252 .46449 .66419 .47471 .66797 .46807 .70393 Metetra
.114 0 .308 r
.46807 .70393 .47471 .66797 .48491 .68009 .47893 .67521 Metetra
.899 .77 .711 r
.47893 .67521 .48491 .68009 .49537 .67712 .48961 .65314 Metetra
.617 .495 .691 r
.48961 .65314 .49537 .67712 .50611 .62887 .50008 .65015 Metetra
.762 .458 .471 r
.50008 .65015 .50611 .62887 .51635 .6939 .51047 .67741 Metetra
.917 .581 .116 r
.51047 .67741 .51635 .6939 .52702 .72465 .52105 .72434 Metetra
.961 .819 .658 r
.52105 .72434 .52702 .72465 .53769 .68954 .53183 .69319 Metetra
.979 .772 .556 r
.53183 .69319 .53769 .68954 .54785 .60042 .5423 .6252 Metetra
.709 .409 .467 r
.5423 .6252 .54785 .60042 .55886 .64824 .55311 .64434 Metetra
.638 .819 .97 r
.55311 .64434 .55886 .64824 .56997 .67664 .56385 .64129 Metetra
.808 .594 .611 r
.56385 .64129 .56997 .67664 .58082 .67362 .57395 .59047 Metetra
0 0 .449 r
.57395 .59047 .58082 .67362 .59145 .65658 .58623 .67848 Metetra
.747 .437 .457 r
.58623 .67848 .59145 .65658 .60158 .61962 .59781 .70314 Metetra
.522 .295 .512 r
.59781 .70314 .60158 .61962 .6117 .58892 .60876 .69226 Metetra
.034 0 .382 r
.60876 .69226 .6117 .58892 .62149 .55116 .61725 .59058 Metetra
.377 .144 .429 r
.61725 .59058 .62149 .55116 .63463 .62438 .62768 .57253 Metetra
0 0 .437 r
.62768 .57253 .63463 .62438 .64866 .70758 .64084 .63736 Metetra
.541 .377 .609 r
.64084 .63736 .64866 .70758 .6604 .71552 .65237 .64468 Metetra
.59 .412 .61 r
.65237 .64468 .6604 .71552 .67155 .70633 .66358 .6414 Metetra
.761 .538 .595 r
.66358 .6414 .67155 .70633 .67942 .62371 .67239 .58151 Metetra
.815 .588 .595 r
.67239 .58151 .67942 .62371 .68716 .54851 .68078 .51966 Metetra
0 0 .46 r
.68078 .51966 .68716 .54851 .69827 .54717 .69398 .56107 Metetra
.885 .558 .426 r
.69398 .56107 .69827 .54717 .70995 .5552 .70863 .6232 Metetra
.73 .459 .518 r
.70863 .6232 .70995 .5552 .72174 .563 .72349 .68052 Metetra
.584 .353 .532 r
.72349 .68052 .72174 .563 .73371 .57177 .73582 .68808 Metetra
.558 .332 .529 r
.73582 .68808 .73371 .57177 .7462 .58665 .74759 .68493 Metetra
.446 .242 .508 r
.74759 .68493 .7462 .58665 .7592 .60647 .75733 .65072 Metetra
0 0 .255 r
.75733 .65072 .7592 .60647 .77144 .61292 .76488 .58774 Metetra
.802 .606 .637 r
.76488 .58774 .77144 .61292 .78357 .6163 .77442 .55658 Metetra
.738 .522 .6 r
.77442 .55658 .78357 .6163 .79527 .61304 .78279 .51222 Metetra
.604 .412 .595 r
.78279 .51222 .79527 .61304 .80701 .60978 .79367 .50195 Metetra
.535 .361 .592 r
.79367 .50195 .80701 .60978 .81774 .59409 .80653 .515 Metetra
.502 .347 .603 r
.80653 .515 .81774 .59409 .82865 .58082 .81993 .53246 Metetra
.455 .337 .63 r
.81993 .53246 .82865 .58082 .83943 .56633 .83349 .54955 Metetra
.273 .334 .744 r
.83349 .54955 .83943 .56633 .85011 .55119 .84681 .56202 Metetra
.614 .221 .274 r
.84681 .56202 .85011 .55119 .86075 .53604 .85962 .56761 Metetra
.529 .254 .442 r
.85962 .56761 .86075 .53604 .87143 .52156 .87172 .56518 Metetra
.535 .28 .475 r
.87172 .56518 .87143 .52156 .88224 .50858 .88378 .56178 Metetra
.542 .295 .491 r
.88378 .56178 .88224 .50858 .89324 .49759 .89589 .55835 Metetra
.504 .272 .496 r
.89589 .55835 .89324 .49759 .90432 .48727 .90709 .5465 Metetra
.446 .228 .488 r
.90709 .5465 .90432 .48727 .91513 .47469 .91713 .52483 Metetra
.363 .16 .465 r
.91713 .52483 .91513 .47469 .92545 .45821 .9262 .49587 Metetra
.641 .354 .468 r
.9262 .49587 .92545 .45821 .94507 .51606 .94044 .50946 Metetra
.657 .751 .919 r
.94044 .50946 .94507 .51606 .95726 .51256 .95266 .50593 Metetra
.657 .751 .919 r
.95266 .50593 .95726 .51256 .96949 .50904 .96494 .50239 Metetra
.05 0 0 r
.37096 .67656 .37757 .67274 .38749 .67207 .38101 .67366 Metetra
.884 .537 .387 r
.38101 .67366 .38749 .67207 .39643 .69973 .38987 .70318 Metetra
.973 .862 .67 r
.38987 .70318 .39643 .69973 .40749 .67033 .40098 .67509 Metetra
.142 0 0 r
.40098 .67509 .40749 .67033 .41758 .66917 .41118 .67217 Metetra
.834 .452 .328 r
.41118 .67217 .41758 .66917 .42692 .69643 .42076 .69097 Metetra
.908 .742 .664 r
.42076 .69097 .42692 .69643 .43749 .68274 .43187 .6589 Metetra
.736 .467 0 r
.43187 .6589 .43749 .68274 .44795 .67329 .4411 .70033 Metetra
.706 .714 .187 r
.4411 .70033 .44795 .67329 .45863 .65252 .45245 .65473 Metetra
.9 .564 .403 r
.45245 .65473 .45863 .65252 .46807 .70393 .46206 .69434 Metetra
.904 .705 .623 r
.46206 .69434 .46807 .70393 .47893 .67521 .47327 .64595 Metetra
.144 .152 .608 r
.47327 .64595 .47893 .67521 .48961 .65314 .48341 .66837 Metetra
.199 0 .181 r
.48341 .66837 .48961 .65314 .50008 .65015 .49403 .65815 Metetra
.866 .538 .428 r
.49403 .65815 .50008 .65015 .51047 .67741 .50436 .6971 Metetra
.818 .513 .475 r
.50436 .6971 .51047 .67741 .52105 .72434 .51498 .74011 Metetra
.989 .843 .472 r
.51498 .74011 .52105 .72434 .53183 .69319 .5259 .68356 Metetra
.903 .711 .633 r
.5259 .68356 .53183 .69319 .5423 .6252 .53658 .64253 Metetra
.714 .39 .427 r
.53658 .64253 .5423 .6252 .55311 .64434 .54743 .65802 Metetra
.368 .021 .238 r
.54743 .65802 .55311 .64434 .56385 .64129 .55824 .65276 Metetra
.996 .843 .498 r
.55824 .65276 .56385 .64129 .57395 .59047 .56849 .60109 Metetra
.905 .596 .451 r
.56849 .60109 .57395 .59047 .58623 .67848 .58055 .67981 Metetra
.746 .258 .079 r
.58055 .67981 .58623 .67848 .59781 .70314 .59187 .69074 Metetra
.832 .681 .696 r
.59187 .69074 .59781 .70314 .60876 .69226 .60262 .6697 Metetra
.92 .674 .549 r
.60262 .6697 .60876 .69226 .61725 .59058 .61063 .54396 Metetra
.077 .066 .541 r
.61063 .54396 .61725 .59058 .62768 .57253 .62275 .58724 Metetra
.912 .606 .453 r
.62275 .58724 .62768 .57253 .64084 .63736 .63719 .69271 Metetra
.609 .351 .502 r
.63719 .69271 .64084 .63736 .65237 .64468 .64903 .70264 Metetra
.516 .276 .489 r
.64903 .70264 .65237 .64468 .66358 .6414 .66031 .69477 Metetra
0 0 .015 r
.66031 .69477 .66358 .6414 .67239 .58151 .66763 .59168 Metetra
.996 .768 .46 r
.66763 .59168 .67239 .58151 .68078 .51966 .67456 .49368 Metetra
0 0 .317 r
.67456 .49368 .68078 .51966 .69398 .56107 .68794 .54091 Metetra
.87 .551 .036 r
.68794 .54091 .69398 .56107 .70863 .6232 .70266 .60656 Metetra
.867 .529 .019 r
.70266 .60656 .70863 .6232 .72349 .68052 .71737 .66284 Metetra
.484 .46 .755 r
.71737 .66284 .72349 .68052 .73582 .68808 .72951 .66742 Metetra
.623 .522 .719 r
.72951 .66742 .73582 .68808 .74759 .68493 .74126 .66422 Metetra
.855 .649 .623 r
.74126 .66422 .74759 .68493 .75733 .65072 .75062 .62379 Metetra
.868 .639 .589 r
.75062 .62379 .75733 .65072 .76488 .58774 .75841 .5635 Metetra
.781 .596 .65 r
.75841 .5635 .76488 .58774 .77442 .55658 .7684 .53847 Metetra
.842 .652 .645 r
.7684 .53847 .77442 .55658 .78279 .51222 .77786 .50781 Metetra
0 .361 .802 r
.77786 .50781 .78279 .51222 .79367 .50195 .79013 .51427 Metetra
.756 .385 .351 r
.79013 .51427 .79367 .50195 .80653 .515 .80349 .5325 Metetra
.75 .405 .398 r
.80349 .5325 .80653 .515 .81993 .53246 .81735 .55414 Metetra
.72 .39 .42 r
.81735 .55414 .81993 .53246 .83349 .54955 .83127 .57396 Metetra
.666 .349 .427 r
.83127 .57396 .83349 .54955 .84681 .56202 .8448 .58726 Metetra
.586 .282 .42 r
.8448 .58726 .84681 .56202 .85962 .56761 .8576 .59133 Metetra
.499 .204 .396 r
.8576 .59133 .85962 .56761 .87172 .56518 .86975 .58794 Metetra
.496 .197 .388 r
.86975 .58794 .87172 .56518 .88378 .56178 .88195 .58454 Metetra
.45 .16 .38 r
.88195 .58454 .88378 .56178 .89589 .55835 .89386 .57792 Metetra
.169 0 .282 r
.89386 .57792 .89589 .55835 .90709 .5465 .90444 .55923 Metetra
.90444 .55923 .90709 .5465 .91713 .52483 .91355 .52834 Metetra
.981 .845 .454 r
.91355 .52834 .91713 .52483 .9262 .49587 .92143 .48849 Metetra
0 .138 .678 r
.92143 .48849 .9262 .49587 .94044 .50946 .93577 .50281 Metetra
.657 .751 .919 r
.93577 .50281 .94044 .50946 .95266 .50593 .94803 .49925 Metetra
.657 .751 .919 r
.94803 .49925 .95266 .50593 .96494 .50239 .96035 .49568 Metetra
.81 .758 .804 r
.36471 .67074 .37096 .67656 .38101 .67366 .3751 .66054 Metetra
.839 .47 0 r
.3751 .66054 .38101 .67366 .38987 .70318 .38402 .68683 Metetra
.842 .653 .647 r
.38402 .68683 .38987 .70318 .40098 .67509 .39546 .65114 Metetra
.719 .456 0 r
.39546 .65114 .40098 .67509 .41118 .67217 .40418 .6903 Metetra
.25 0 .237 r
.40418 .6903 .41118 .67217 .42076 .69097 .41473 .67994 Metetra
.811 .678 .718 r
.41473 .67994 .42076 .69097 .43187 .6589 .42547 .66334 Metetra
.873 .536 .408 r
.42547 .66334 .43187 .6589 .4411 .70033 .43488 .69657 Metetra
.93 .751 .639 r
.43488 .69657 .4411 .70033 .45245 .65473 .44621 .65657 Metetra
.524 0 0 r
.44621 .65657 .45245 .65473 .46206 .69434 .45649 .66017 Metetra
0 0 .482 r
.45649 .66017 .46206 .69434 .47327 .64595 .46633 .69581 Metetra
.395 .165 .443 r
.46633 .69581 .47327 .64595 .48341 .66837 .47719 .67648 Metetra
.981 .766 .539 r
.47719 .67648 .48341 .66837 .49403 .65815 .48871 .5887 Metetra
0 0 .332 r
.48871 .5887 .49403 .65815 .50436 .6971 .49845 .6746 Metetra
0 0 .498 r
.49845 .6746 .50436 .6971 .51498 .74011 .50904 .70146 Metetra
.732 .539 .631 r
.50904 .70146 .51498 .74011 .5259 .68356 .51993 .67425 Metetra
.935 .705 .566 r
.51993 .67425 .5259 .68356 .53658 .64253 .53061 .58241 Metetra
.489 .343 .609 r
.53061 .58241 .53658 .64253 .54743 .65802 .54128 .59596 Metetra
0 0 .282 r
.54128 .59596 .54743 .65802 .55824 .65276 .55269 .68497 Metetra
.616 .332 .464 r
.55269 .68497 .55824 .65276 .56849 .60109 .56383 .69267 Metetra
.511 .287 .51 r
.56383 .69267 .56849 .60109 .58055 .67981 .57477 .67873 Metetra
.967 .744 .549 r
.57477 .67873 .58055 .67981 .59187 .69074 .58454 .59902 Metetra
.718 .499 .592 r
.58454 .59902 .59187 .69074 .60262 .6697 .59433 .54199 Metetra
.537 .356 .583 r
.59433 .54199 .60262 .6697 .61063 .54396 .60547 .55457 Metetra
.895 .574 .432 r
.60547 .55457 .61063 .54396 .62275 .58724 .61813 .61767 Metetra
.829 .53 .484 r
.61813 .61767 .62275 .58724 .63719 .69271 .63137 .68408 Metetra
.031 .333 .815 r
.63137 .68408 .63719 .69271 .64903 .70264 .64316 .69262 Metetra
.706 .674 .816 r
.64316 .69262 .64903 .70264 .66031 .69477 .65455 .68673 Metetra
.948 .725 .568 r
.65455 .68673 .66031 .69477 .66763 .59168 .66351 .61997 Metetra
.856 .735 .216 r
.66351 .61997 .66763 .59168 .67456 .49368 .67168 .54372 Metetra
.268 .073 .421 r
.67168 .54372 .67456 .49368 .68794 .54091 .6814 .51005 Metetra
.71 .534 .65 r
.6814 .51005 .68794 .54091 .70266 .60656 .6918 .49293 Metetra
.541 .362 .588 r
.6918 .49293 .70266 .60656 .71737 .66284 .70363 .50346 Metetra
.523 .342 .578 r
.70363 .50346 .71737 .66284 .72951 .66742 .71629 .52598 Metetra
.464 .302 .576 r
.71629 .52598 .72951 .66742 .74126 .66422 .73033 .56758 Metetra
.383 .254 .579 r
.73033 .56758 .74126 .66422 .75062 .62379 .74504 .61402 Metetra
0 0 .425 r
.74504 .61402 .75062 .62379 .75841 .5635 .75845 .63547 Metetra
.655 .394 .513 r
.75845 .63547 .75841 .5635 .7684 .53847 .77253 .66326 Metetra
.557 .331 .528 r
.77253 .66326 .7684 .53847 .77786 .50781 .78457 .66 Metetra
.559 .336 .534 r
.78457 .66 .77786 .50781 .79013 .51427 .79666 .65673 Metetra
.506 .295 .527 r
.79666 .65673 .79013 .51427 .80349 .5325 .80687 .62976 Metetra
.47 .259 .511 r
.80687 .62976 .80349 .5325 .81735 .55414 .81689 .60208 Metetra
.332 .126 .443 r
.81689 .60208 .81735 .55414 .83127 .57396 .8267 .5733 Metetra
.989 .87 .623 r
.8267 .5733 .83127 .57396 .8448 .58726 .83636 .5444 Metetra
.729 .528 .619 r
.83636 .5444 .8448 .58726 .8576 .59133 .84589 .51552 Metetra
.665 .462 .599 r
.84589 .51552 .8576 .59133 .86975 .58794 .85549 .48876 Metetra
.633 .432 .592 r
.85549 .48876 .86975 .58794 .88195 .58454 .86549 .46691 Metetra
.612 .413 .588 r
.86549 .46691 .88195 .58454 .89386 .57792 .87597 .45049 Metetra
.601 .404 .586 r
.87597 .45049 .89386 .57792 .90444 .55923 .88679 .43743 Metetra
.599 .403 .587 r
.88679 .43743 .90444 .55923 .91355 .52834 .89774 .42581 Metetra
.6 .407 .592 r
.89774 .42581 .91355 .52834 .92143 .48849 .90891 .41605 Metetra
.113 .086 .546 r
.90891 .41605 .92143 .48849 .93577 .50281 .93107 .4961 Metetra
.657 .751 .919 r
.93107 .4961 .93577 .50281 .94803 .49925 .94337 .49252 Metetra
.657 .751 .919 r
.94337 .49252 .94803 .49925 .96035 .49568 .95572 .48892 Metetra
.64 .591 .783 r
.35873 .65828 .36471 .67074 .3751 .66054 .36881 .65543 Metetra
.933 .576 .321 r
.36881 .65543 .3751 .66054 .38402 .68683 .37741 .68868 Metetra
.957 .771 .609 r
.37741 .68868 .38402 .68683 .39546 .65114 .38959 .63669 Metetra
.911 .561 .099 r
.38959 .63669 .39546 .65114 .40418 .6903 .39839 .67128 Metetra
.73 .585 .694 r
.39839 .67128 .40418 .6903 .41473 .67994 .40903 .65841 Metetra
.54 .457 .711 r
.40903 .65841 .41473 .67994 .42547 .66334 .4192 .66058 Metetra
.921 .563 .334 r
.4192 .66058 .42547 .66334 .43488 .69657 .42856 .69446 Metetra
.945 .744 .601 r
.42856 .69446 .43488 .69657 .44621 .65657 .44043 .63656 Metetra
.298 .312 .706 r
.44043 .63656 .44621 .65657 .45649 .66017 .45053 .64751 Metetra
0 0 .394 r
.45053 .64751 .45649 .66017 .46633 .69581 .4606 .66681 Metetra
.697 .532 .66 r
.4606 .66681 .46633 .69581 .47719 .67648 .47136 .65282 Metetra
.848 .636 .617 r
.47136 .65282 .47719 .67648 .48871 .5887 .48256 .60097 Metetra
.893 .594 .473 r
.48256 .60097 .48871 .5887 .49845 .6746 .4923 .67915 Metetra
.871 .519 .379 r
.4923 .67915 .49845 .6746 .50904 .70146 .50286 .71087 Metetra
.998 .855 .547 r
.50286 .71087 .50904 .70146 .51993 .67425 .51393 .66568 Metetra
.937 .707 .566 r
.51393 .66568 .51993 .67425 .53061 .58241 .52478 .57533 Metetra
.887 .471 .064 r
.52478 .57533 .53061 .58241 .54128 .59596 .53548 .60099 Metetra
.912 .59 .422 r
.53548 .60099 .54128 .59596 .55269 .68497 .54663 .66189 Metetra
.608 .497 .701 r
.54663 .66189 .55269 .68497 .56383 .69267 .55762 .65956 Metetra
.698 .524 .649 r
.55762 .65956 .56383 .69267 .57477 .67873 .5685 .64339 Metetra
.841 .615 .596 r
.5685 .64339 .57477 .67873 .58454 .59902 .57851 .57509 Metetra
.73 .566 .669 r
.57851 .57509 .58454 .59902 .59433 .54199 .58914 .55899 Metetra
0 0 .031 r
.58914 .55899 .59433 .54199 .60547 .55457 .5996 .53722 Metetra
.927 .598 .142 r
.5996 .53722 .60547 .55457 .61813 .61767 .6121 .59852 Metetra
.956 .637 .225 r
.6121 .59852 .61813 .61767 .63137 .68408 .62573 .68295 Metetra
.653 .096 0 r
.62573 .68295 .63137 .68408 .64316 .69262 .63758 .69233 Metetra
.803 .982 .896 r
.63758 .69233 .64316 .69262 .65455 .68673 .64891 .6833 Metetra
.968 .739 .537 r
.64891 .6833 .65455 .68673 .66351 .61997 .65744 .60171 Metetra
.913 .679 .572 r
.65744 .60171 .66351 .61997 .67168 .54372 .66578 .52716 Metetra
.637 .554 .744 r
.66578 .52716 .67168 .54372 .6814 .51005 .67692 .52362 Metetra
.528 .17 .303 r
.67692 .52362 .6814 .51005 .6918 .49293 .68831 .52432 Metetra
.514 .24 .436 r
.68831 .52432 .6918 .49293 .70363 .50346 .69955 .52096 Metetra
.545 .213 .358 r
.69955 .52096 .70363 .50346 .71629 .52598 .71109 .52196 Metetra
.848 .395 0 r
.71109 .52196 .71629 .52598 .73033 .56758 .72407 .54597 Metetra
0 0 .423 r
.72407 .54597 .73033 .56758 .74504 .61402 .7381 .58315 Metetra
.394 .33 .667 r
.7381 .58315 .74504 .61402 .75845 .63547 .75096 .59748 Metetra
.44 .344 .649 r
.75096 .59748 .75845 .63547 .77253 .66326 .76395 .61133 Metetra
.594 .428 .627 r
.76395 .61133 .77253 .66326 .78457 .66 .77586 .608 Metetra
.594 .428 .627 r
.77586 .608 .78457 .66 .79666 .65673 .78782 .60465 Metetra
.653 .469 .622 r
.78782 .60465 .79666 .65673 .80687 .62976 .79887 .58934 Metetra
.69 .506 .634 r
.79887 .58934 .80687 .62976 .81689 .60208 .80962 .57095 Metetra
.736 .552 .644 r
.80962 .57095 .81689 .60208 .8267 .5733 .82001 .54895 Metetra
.774 .593 .654 r
.82001 .54895 .8267 .5733 .83636 .5444 .83019 .52569 Metetra
.803 .632 .671 r
.83019 .52569 .83636 .5444 .84589 .51552 .84038 .5035 Metetra
.84 .701 .71 r
.84038 .5035 .84589 .51552 .85549 .48876 .85082 .48468 Metetra
.892 .878 .815 r
.85082 .48468 .85549 .48876 .86549 .46691 .86175 .47134 Metetra
.86175 .47134 .86549 .46691 .87597 .45049 .87329 .464 Metetra
.414 .066 .263 r
.87329 .464 .87597 .45049 .88679 .43743 .8852 .45973 Metetra
.447 .155 .376 r
.8852 .45973 .88679 .43743 .89774 .42581 .89689 .45321 Metetra
.396 .137 .399 r
.89689 .45321 .89774 .42581 .90891 .41605 .90794 .44089 Metetra
.822 .483 .414 r
.90794 .44089 .90891 .41605 .93107 .4961 .92633 .48934 Metetra
.657 .751 .919 r
.92633 .48934 .93107 .4961 .94337 .49252 .93867 .48573 Metetra
.657 .751 .919 r
.93867 .48573 .94337 .49252 .95572 .48892 .95106 .4821 Metetra
.331 .585 .936 r
.35243 .65175 .35873 .65828 .36881 .65543 .36228 .65425 Metetra
.918 .592 .41 r
.36228 .65425 .36881 .65543 .37741 .68868 .3704 .6977 Metetra
.993 .849 .594 r
.3704 .6977 .37741 .68868 .38959 .63669 .38238 .65467 Metetra
.39 .071 .298 r
.38238 .65467 .38959 .63669 .39839 .67128 .39274 .64882 Metetra
.67 .534 .69 r
.39274 .64882 .39839 .67128 .40903 .65841 .40319 .64118 Metetra
0 0 .304 r
.40319 .64118 .40903 .65841 .4192 .66058 .41259 .6666 Metetra
.896 .974 .671 r
.41259 .6666 .4192 .66058 .42856 .69446 .42344 .64927 Metetra
.647 .471 .631 r
.42344 .64927 .42856 .69446 .44043 .63656 .4341 .63776 Metetra
.866 .48 .309 r
.4341 .63776 .44043 .63656 .45053 .64751 .44395 .66027 Metetra
0 0 .011 r
.44395 .66027 .45053 .64751 .4606 .66681 .45469 .64876 Metetra
.963 .645 .253 r
.45469 .64876 .4606 .66681 .47136 .65282 .46415 .71085 Metetra
0 0 .174 r
.46415 .71085 .47136 .65282 .48256 .60097 .4759 .64215 Metetra
.176 0 .345 r
.4759 .64215 .48256 .60097 .4923 .67915 .48685 .61283 Metetra
.496 .342 .602 r
.48685 .61283 .4923 .67915 .50286 .71087 .49734 .62599 Metetra
.625 .431 .6 r
.49734 .62599 .50286 .71087 .51393 .66568 .50812 .61077 Metetra
.628 .448 .62 r
.50812 .61077 .51393 .66568 .52478 .57533 .51885 .60053 Metetra
.867 .575 .491 r
.51885 .60053 .52478 .57533 .53548 .60099 .52972 .69061 Metetra
.624 .378 .525 r
.52972 .69061 .53548 .60099 .54663 .66189 .5409 .71124 Metetra
.5409 .71124 .54663 .66189 .55762 .65956 .55149 .62915 Metetra
.703 .533 .655 r
.55149 .62915 .55762 .65956 .5685 .64339 .56234 .61342 Metetra
0 .047 .56 r
.56234 .61342 .5685 .64339 .57851 .57509 .5738 .64305 Metetra
.491 .259 .49 r
.5738 .64305 .57851 .57509 .58914 .55899 .58477 .6301 Metetra
0 0 .125 r
.58477 .6301 .58914 .55899 .5996 .53722 .59377 .52238 Metetra
.947 .612 .198 r
.59377 .52238 .5996 .53722 .6121 .59852 .6062 .58501 Metetra
.785 .422 0 r
.6062 .58501 .6121 .59852 .62573 .68295 .61832 .61855 Metetra
.588 .413 .612 r
.61832 .61855 .62573 .68295 .63758 .69233 .6296 .61533 Metetra
.677 .471 .6 r
.6296 .61533 .63758 .69233 .64891 .6833 .63999 .58439 Metetra
.638 .436 .593 r
.63999 .58439 .64891 .6833 .65744 .60171 .65052 .56088 Metetra
0 0 .275 r
.65052 .56088 .65744 .60171 .66578 .52716 .66479 .63194 Metetra
.579 .343 .523 r
.66479 .63194 .66578 .52716 .67692 .52362 .67678 .63836 Metetra
.553 .325 .523 r
.67678 .63836 .67692 .52362 .68831 .52432 .68842 .6351 Metetra
.413 .215 .5 r
.68842 .6351 .68831 .52432 .69955 .52096 .69802 .59077 Metetra
.455 .233 .487 r
.69802 .59077 .69955 .52096 .71109 .52196 .70867 .57014 Metetra
.533 .279 .476 r
.70867 .57014 .71109 .52196 .72407 .54597 .72025 .56678 Metetra
0 0 .115 r
.72025 .56678 .72407 .54597 .7381 .58315 .73028 .53733 Metetra
.61 .445 .633 r
.73028 .53733 .7381 .58315 .75096 .59748 .74172 .53169 Metetra
.588 .412 .611 r
.74172 .53169 .75096 .59748 .76395 .61133 .75334 .52826 Metetra
.605 .416 .6 r
.75334 .52826 .76395 .61133 .77586 .608 .76458 .5189 Metetra
.635 .435 .595 r
.76458 .5189 .77586 .608 .78782 .60465 .77501 .4987 Metetra
.629 .427 .589 r
.77501 .4987 .78782 .60465 .79887 .58934 .78524 .47689 Metetra
.539 .361 .588 r
.78524 .47689 .79887 .58934 .80962 .57095 .79807 .48753 Metetra
.525 .36 .599 r
.79807 .48753 .80962 .57095 .82001 .54895 .81114 .49923 Metetra
.507 .371 .63 r
.81114 .49923 .82001 .54895 .83019 .52569 .82421 .50908 Metetra
.41 .426 .766 r
.82421 .50908 .83019 .52569 .84038 .5035 .83717 .51629 Metetra
.661 .279 .312 r
.83717 .51629 .84038 .5035 .85082 .48468 .85047 .52561 Metetra
.617 .336 .469 r
.85047 .52561 .85082 .48468 .86175 .47134 .86403 .53599 Metetra
.552 .306 .497 r
.86403 .53599 .86175 .47134 .87329 .464 .87652 .53466 Metetra
.544 .304 .501 r
.87652 .53466 .87329 .464 .8852 .45973 .88884 .53112 Metetra
.544 .304 .502 r
.88884 .53112 .8852 .45973 .89689 .45321 .9012 .52756 Metetra
.463 .246 .497 r
.9012 .52756 .89689 .45321 .90794 .44089 .91144 .50516 Metetra
.541 .298 .496 r
.91144 .50516 .90794 .44089 .92633 .48934 .92384 .50156 Metetra
0 0 .024 r
.92384 .50156 .92633 .48934 .93867 .48573 .93393 .47889 Metetra
.657 .751 .919 r
.93393 .47889 .93867 .48573 .95106 .4821 .94636 .47523 Metetra
.34562 .65443 .35243 .65175 .36228 .65425 .35576 .65179 Metetra
.892 .494 .26 r
.35576 .65179 .36228 .65425 .3704 .6977 .36481 .67367 Metetra
.741 .573 .666 r
.36481 .67367 .3704 .6977 .38238 .65467 .37577 .65533 Metetra
.366 .836 .856 r
.37577 .65533 .38238 .65467 .39274 .64882 .38607 .65232 Metetra
.824 .44 .325 r
.38607 .65232 .39274 .64882 .40319 .64118 .39563 .67044 Metetra
.071 0 .239 r
.39563 .67044 .40319 .64118 .41259 .6666 .40675 .64738 Metetra
0 .06 .601 r
.40675 .64738 .41259 .6666 .42344 .64927 .41651 .66557 Metetra
.934 .875 .455 r
.41651 .66557 .42344 .64927 .4341 .63776 .42805 .62647 Metetra
.963 .631 .311 r
.42805 .62647 .4341 .63776 .44395 .66027 .4371 .67923 Metetra
.884 .844 .383 r
.4371 .67923 .44395 .66027 .45469 .64876 .44861 .63815 Metetra
0 .221 .741 r
.44861 .63815 .45469 .64876 .46415 .71085 .45895 .6483 Metetra
.607 .428 .613 r
.45895 .6483 .46415 .71085 .4759 .64215 .46969 .64115 Metetra
.832 .375 .132 r
.46969 .64115 .4759 .64215 .48685 .61283 .48015 .65689 Metetra
.739 .461 .509 r
.48015 .65689 .48685 .61283 .49734 .62599 .49052 .69831 Metetra
.304 .106 .438 r
.49052 .69831 .49734 .62599 .50812 .61077 .50175 .65911 Metetra
.064 0 .319 r
.50175 .65911 .50812 .61077 .51885 .60053 .5128 .61763 Metetra
.765 .44 .437 r
.5128 .61763 .51885 .60053 .52972 .69061 .52363 .64142 Metetra
.593 .428 .628 r
.52363 .64142 .52972 .69061 .5409 .71124 .5346 .63828 Metetra
.788 .557 .587 r
.5346 .63828 .5409 .71124 .55149 .62915 .54511 .55155 Metetra
0 0 .305 r
.54511 .55155 .55149 .62915 .56234 .61342 .5569 .6567 Metetra
.662 .386 .491 r
.5569 .6567 .56234 .61342 .5738 .64305 .56835 .6758 Metetra
.339 .088 .379 r
.56835 .6758 .5738 .64305 .58477 .6301 .57945 .65983 Metetra
.991 .779 .395 r
.57945 .65983 .58477 .6301 .59377 .52238 .58844 .53413 Metetra
.801 .451 .394 r
.58844 .53413 .59377 .52238 .6062 .58501 .6 .55892 Metetra
.916 .614 .131 r
.6 .55892 .6062 .58501 .61832 .61855 .61329 .64214 Metetra
.629 .316 .422 r
.61329 .64214 .61832 .61855 .6296 .61533 .62504 .65041 Metetra
.485 .218 .433 r
.62504 .65041 .6296 .61533 .63999 .58439 .63644 .64405 Metetra
0 0 .218 r
.63644 .64405 .63999 .58439 .65052 .56088 .64522 .56346 Metetra
.986 .755 .503 r
.64522 .56346 .65052 .56088 .66479 .63194 .65317 .47347 Metetra
.469 .301 .569 r
.65317 .47347 .66479 .63194 .67678 .63836 .66612 .51462 Metetra
.308 .188 .549 r
.66612 .51462 .67678 .63836 .68842 .6351 .68088 .58757 Metetra
0 0 .445 r
.68088 .58757 .68842 .6351 .69802 .59077 .69569 .64993 Metetra
.594 .336 .495 r
.69569 .64993 .69802 .59077 .70867 .57014 .70814 .65789 Metetra
.547 .312 .51 r
.70814 .65789 .70867 .57014 .72025 .56678 .72008 .65462 Metetra
.409 .205 .488 r
.72008 .65462 .72025 .56678 .73028 .53733 .73016 .6191 Metetra
.161 .017 .423 r
.73016 .6191 .73028 .53733 .74172 .53169 .73784 .54857 Metetra
.73784 .54857 .74172 .53169 .75334 .52826 .74735 .51176 Metetra
.903 .684 .596 r
.74735 .51176 .75334 .52826 .76458 .5189 .75577 .46207 Metetra
.513 .366 .618 r
.75577 .46207 .76458 .5189 .77501 .4987 .7683 .47188 Metetra
.225 .232 .657 r
.7683 .47188 .77501 .4987 .78524 .47689 .78184 .49292 Metetra
.778 .423 .384 r
.78184 .49292 .78524 .47689 .79807 .48753 .79596 .51832 Metetra
.711 .401 .45 r
.79596 .51832 .79807 .48753 .81114 .49923 .81025 .5426 Metetra
.653 .368 .475 r
.81025 .5426 .81114 .49923 .82421 .50908 .82425 .56068 Metetra
.596 .33 .484 r
.82425 .56068 .82421 .50908 .83717 .51629 .83754 .56878 Metetra
.534 .282 .479 r
.83754 .56878 .83717 .51629 .85047 .52561 .84985 .56529 Metetra
.523 .257 .454 r
.84985 .56529 .85047 .52561 .86403 .53599 .86222 .56178 Metetra
.486 .194 .395 r
.86222 .56178 .86403 .53599 .87652 .53466 .87455 .55735 Metetra
.235 0 .317 r
.87455 .55735 .87652 .53466 .88884 .53112 .88548 .53947 Metetra
.766 .79 .297 r
.88548 .53947 .88884 .53112 .9012 .52756 .89503 .50963 Metetra
.881 .674 .619 r
.89503 .50963 .9012 .52756 .91144 .50516 .90355 .4721 Metetra
.54 .423 .669 r
.90355 .4721 .91144 .50516 .92384 .50156 .91674 .47567 Metetra
.616 .494 .691 r
.91674 .47567 .92384 .50156 .93393 .47889 .92915 .472 Metetra
.657 .751 .919 r
.92915 .472 .93393 .47889 .94636 .47523 .94162 .46831 Metetra
.586 .88 .993 r
.33897 .65257 .34562 .65443 .35576 .65179 .34916 .64957 Metetra
.861 .428 .183 r
.34916 .64957 .35576 .65179 .36481 .67367 .35843 .66652 Metetra
.819 .736 .772 r
.35843 .66652 .36481 .67367 .37577 .65533 .36919 .65396 Metetra
.554 .889 .986 r
.36919 .65396 .37577 .65533 .38607 .65232 .37952 .65094 Metetra
.85 .413 .183 r
.37952 .65094 .38607 .65232 .39563 .67044 .38914 .66739 Metetra
.929 .766 .658 r
.38914 .66739 .39563 .67044 .40675 .64738 .40074 .63306 Metetra
.818 .459 0 r
.40074 .63306 .40675 .64738 .41651 .66557 .41012 .66139 Metetra
.899 .786 .726 r
.41012 .66139 .41651 .66557 .42805 .62647 .4212 .64086 Metetra
.812 .495 .452 r
.4212 .64086 .42805 .62647 .4371 .67923 .43079 .67316 Metetra
.931 .722 .598 r
.43079 .67316 .4371 .67923 .44861 .63815 .44291 .6105 Metetra
0 0 .266 r
.44291 .6105 .44861 .63815 .45895 .6483 .45256 .65073 Metetra
.677 .975 .814 r
.45256 .65073 .45895 .6483 .46969 .64115 .46338 .64258 Metetra
.8 .354 .186 r
.46338 .64258 .46969 .64115 .48015 .65689 .47388 .6565 Metetra
.905 .536 .323 r
.47388 .6565 .48015 .65689 .49052 .69831 .48432 .68905 Metetra
.92 .712 .606 r
.48432 .68905 .49052 .69831 .50175 .65911 .49577 .63304 Metetra
.537 .438 .689 r
.49577 .63304 .50175 .65911 .5128 .61763 .50662 .63564 Metetra
.627 .296 .391 r
.50662 .63564 .5128 .61763 .52363 .64142 .51755 .64253 Metetra
.792 .996 .866 r
.51755 .64253 .52363 .64142 .5346 .63828 .52856 .63326 Metetra
.951 .725 .56 r
.52856 .63326 .5346 .63828 .54511 .55155 .53926 .55054 Metetra
.947 .639 .418 r
.53926 .55054 .54511 .55155 .5569 .6567 .55088 .65263 Metetra
.836 .367 .001 r
.55088 .65263 .5569 .6567 .56835 .6758 .56234 .67163 Metetra
.902 .82 .756 r
.56234 .67163 .56835 .6758 .57945 .65983 .57347 .65384 Metetra
.957 .714 .528 r
.57347 .65384 .57945 .65983 .58844 .53413 .58275 .5316 Metetra
.906 .502 .209 r
.58275 .5316 .58844 .53413 .6 .55892 .59441 .56103 Metetra
.938 .615 .397 r
.59441 .56103 .6 .55892 .61329 .64214 .6076 .64361 Metetra
.472 0 0 r
.6076 .64361 .61329 .64214 .62504 .65041 .61926 .64741 Metetra
.839 .893 .878 r
.61926 .64741 .62504 .65041 .63644 .64405 .6306 .63756 Metetra
.96 .723 .535 r
.6306 .63756 .63644 .64405 .64522 .56346 .63917 .54581 Metetra
.915 .682 .571 r
.63917 .54581 .64522 .56346 .65317 .47347 .64787 .47237 Metetra
.94 .588 .321 r
.64787 .47237 .65317 .47347 .66612 .51462 .66149 .53055 Metetra
.884 .56 .429 r
.66149 .53055 .66612 .51462 .68088 .58757 .67601 .59838 Metetra
.884 .541 .393 r
.67601 .59838 .68088 .58757 .69569 .64993 .69033 .65053 Metetra
.189 0 0 r
.69033 .65053 .69569 .64993 .70814 .65789 .70247 .65171 Metetra
.646 .762 .934 r
.70247 .65171 .70814 .65789 .72008 .65462 .71445 .64841 Metetra
.959 .756 .586 r
.71445 .64841 .72008 .65462 .73016 .6191 .72382 .5993 Metetra
.913 .677 .568 r
.72382 .5993 .73016 .6191 .73784 .54857 .73161 .52903 Metetra
.843 .647 .638 r
.73161 .52903 .73784 .54857 .74735 .51176 .74142 .49616 Metetra
.906 .689 .598 r
.74142 .49616 .74735 .51176 .75577 .46207 .75002 .44822 Metetra
.163 .3 .758 r
.75002 .44822 .75577 .46207 .7683 .47188 .7627 .46017 Metetra
0 0 .367 r
.7627 .46017 .7683 .47188 .78184 .49292 .77668 .48731 Metetra
.837 .4 0 r
.77668 .48731 .78184 .49292 .79596 .51832 .79114 .51688 Metetra
.857 .402 .057 r
.79114 .51688 .79596 .51832 .81025 .5426 .80559 .54285 Metetra
.804 .315 .02 r
.80559 .54285 .81025 .5426 .82425 .56068 .81968 .56156 Metetra
.649 .096 0 r
.81968 .56156 .82425 .56068 .83754 .56878 .83317 .57133 Metetra
.2 0 0 r
.83317 .57133 .83754 .56878 .84985 .56529 .84583 .57072 Metetra
.199 0 0 r
.84583 .57072 .84985 .56529 .86222 .56178 .85829 .56719 Metetra
.199 0 0 r
.85829 .56719 .86222 .56178 .87455 .55735 .87079 .56365 Metetra
.87079 .56365 .87455 .55735 .88548 .53947 .88236 .55072 Metetra
.88236 .55072 .88548 .53947 .89503 .50963 .89242 .52422 Metetra
.89242 .52422 .89503 .50963 .90355 .4721 .90097 .4855 Metetra
.42 .061 .248 r
.90097 .4855 .90355 .4721 .91674 .47567 .91342 .48182 Metetra
.91342 .48182 .91674 .47567 .92915 .472 .92434 .46505 Metetra
.657 .751 .919 r
.92434 .46505 .92915 .472 .94162 .46831 .93685 .46133 Metetra
.695 .608 .755 r
.3329 .63908 .33897 .65257 .34916 .64957 .34327 .63268 Metetra
0 0 .253 r
.34327 .63268 .34916 .64957 .35843 .66652 .35211 .65745 Metetra
.892 .706 .643 r
.35211 .65745 .35843 .66652 .36919 .65396 .36418 .61725 Metetra
0 0 .302 r
.36418 .61725 .36919 .65396 .37952 .65094 .37236 .66198 Metetra
.37236 .66198 .37952 .65094 .38914 .66739 .38326 .64786 Metetra
.727 .583 .694 r
.38326 .64786 .38914 .66739 .40074 .63306 .39409 .63515 Metetra
.879 .521 .366 r
.39409 .63515 .40074 .63306 .41012 .66139 .40345 .66393 Metetra
.97 .801 .618 r
.40345 .66393 .41012 .66139 .4212 .64086 .41534 .62052 Metetra
.261 .286 .699 r
.41534 .62052 .4212 .64086 .43079 .67316 .42544 .63221 Metetra
.084 .072 .545 r
.42544 .63221 .43079 .67316 .44291 .6105 .43515 .66435 Metetra
.365 .137 .43 r
.43515 .66435 .44291 .6105 .45256 .65073 .44635 .64191 Metetra
.929 .706 .58 r
.44635 .64191 .45256 .65073 .46338 .64258 .45862 .56074 Metetra
0 0 .396 r
.45862 .56074 .46338 .64258 .47388 .6565 .46773 .64509 Metetra
0 0 .368 r
.46773 .64509 .47388 .6565 .48432 .68905 .47829 .66398 Metetra
.791 .602 .645 r
.47829 .66398 .48432 .68905 .49577 .63304 .48954 .63413 Metetra
.967 .748 .554 r
.48954 .63413 .49577 .63304 .50662 .63564 .50103 .55199 Metetra
.528 .356 .592 r
.50103 .55199 .50662 .63564 .51755 .64253 .51171 .56109 Metetra
0 0 .362 r
.51171 .56109 .51755 .64253 .52856 .63326 .52245 .65652 Metetra
.596 .284 .411 r
.52245 .65652 .52856 .63326 .53926 .55054 .53364 .66145 Metetra
.495 .274 .507 r
.53364 .66145 .53926 .55054 .55088 .65263 .54478 .64195 Metetra
.936 .705 .564 r
.54478 .64195 .55088 .65263 .56234 .67163 .55528 .55666 Metetra
.665 .452 .587 r
.55528 .55666 .56234 .67163 .57347 .65384 .56583 .51626 Metetra
.549 .36 .578 r
.56583 .51626 .57347 .65384 .58275 .5316 .57692 .5229 Metetra
.958 .617 .288 r
.57692 .5229 .58275 .5316 .59441 .56103 .58918 .58599 Metetra
.842 .534 .468 r
.58918 .58599 .59441 .56103 .6076 .64361 .60192 .64894 Metetra
.581 .104 .087 r
.60192 .64894 .6076 .64361 .61926 .64741 .61366 .6535 Metetra
.61366 .6535 .61926 .64741 .6306 .63756 .62512 .64461 Metetra
.999 .799 .502 r
.62512 .64461 .6306 .63756 .63917 .54581 .63469 .57721 Metetra
.766 .69 .145 r
.63469 .57721 .63917 .54581 .64787 .47237 .64376 .50652 Metetra
.269 .039 .369 r
.64376 .50652 .64787 .47237 .66149 .53055 .65435 .48508 Metetra
.619 .45 .631 r
.65435 .48508 .66149 .53055 .67601 .59838 .66545 .47777 Metetra
.58 .387 .584 r
.66545 .47777 .67601 .59838 .69033 .65053 .67668 .47271 Metetra
.542 .351 .572 r
.67668 .47271 .69033 .65053 .70247 .65171 .6888 .48498 Metetra
.469 .299 .567 r
.6888 .48498 .70247 .65171 .71445 .64841 .7027 .52782 Metetra
.377 .24 .565 r
.7027 .52782 .71445 .64841 .72382 .5993 .71771 .58344 Metetra
0 0 .566 r
.71771 .58344 .72382 .5993 .73161 .52903 .73123 .60675 Metetra
.64 .38 .509 r
.73123 .60675 .73161 .52903 .74142 .49616 .74513 .63208 Metetra
.551 .324 .523 r
.74513 .63208 .74142 .49616 .75002 .44822 .75735 .62869 Metetra
.554 .331 .531 r
.75735 .62869 .75002 .44822 .7627 .46017 .76963 .62528 Metetra
.497 .286 .523 r
.76963 .62528 .7627 .46017 .77668 .48731 .77982 .59333 Metetra
.46 .249 .505 r
.77982 .59333 .77668 .48731 .79114 .51688 .79 .56305 Metetra
.262 .063 .411 r
.79 .56305 .79114 .51688 .80559 .54285 .79984 .53052 Metetra
.902 .716 .641 r
.79984 .53052 .80559 .54285 .81968 .56156 .80948 .49752 Metetra
.691 .483 .601 r
.80948 .49752 .81968 .56156 .83317 .57133 .81919 .46713 Metetra
.633 .428 .587 r
.81919 .46713 .83317 .57133 .84583 .57072 .82936 .44328 Metetra
.604 .403 .582 r
.82936 .44328 .84583 .57072 .85829 .56719 .84018 .42726 Metetra
.588 .39 .58 r
.84018 .42726 .85829 .56719 .87079 .56365 .85157 .41722 Metetra
.579 .383 .579 r
.85157 .41722 .87079 .56365 .88236 .55072 .86335 .4109 Metetra
.575 .38 .58 r
.86335 .4109 .88236 .55072 .89242 .52422 .8754 .40684 Metetra
.577 .385 .585 r
.8754 .40684 .89242 .52422 .90097 .4855 .88754 .40308 Metetra
.287 .197 .576 r
.88754 .40308 .90097 .4855 .91342 .48182 .90699 .46177 Metetra
.626 .531 .727 r
.90699 .46177 .91342 .48182 .92434 .46505 .91949 .45804 Metetra
.657 .751 .919 r
.91949 .45804 .92434 .46505 .93685 .46133 .93203 .4543 Metetra
.712 .348 0 r
.32682 .62559 .3329 .63908 .34327 .63268 .33568 .64692 Metetra
.799 .871 .434 r
.33568 .64692 .34327 .63268 .35211 .65745 .34713 .62161 Metetra
.18 .149 .585 r
.34713 .62161 .35211 .65745 .36418 .61725 .35613 .64465 Metetra
.426 .14 .374 r
.35613 .64465 .36418 .61725 .37236 .66198 .36672 .63738 Metetra
.639 .507 .686 r
.36672 .63738 .37236 .66198 .38326 .64786 .37724 .63203 Metetra
0 .13 .66 r
.37724 .63203 .38326 .64786 .39409 .63515 .38701 .64599 Metetra
.993 .876 .57 r
.38701 .64599 .39409 .63515 .40345 .66393 .39892 .60588 Metetra
.478 .333 .605 r
.39892 .60588 .40345 .66393 .41534 .62052 .40887 .61845 Metetra
.927 .591 .38 r
.40887 .61845 .41534 .62052 .42544 .63221 .41795 .66373 Metetra
.41795 .66373 .42544 .63221 .43515 .66435 .42988 .61792 Metetra
.708 .513 .623 r
.42988 .61792 .43515 .66435 .44635 .64191 .4411 .59206 Metetra
.248 .175 .574 r
.4411 .59206 .44635 .64191 .45862 .56074 .45104 .62175 Metetra
.696 .43 .517 r
.45104 .62175 .45862 .56074 .46773 .64509 .46108 .65889 Metetra
.738 .823 .361 r
.46108 .65889 .46773 .64509 .47829 .66398 .47238 .63288 Metetra
.853 .628 .597 r
.47238 .63288 .47829 .66398 .48954 .63413 .48411 .56262 Metetra
.542 .372 .6 r
.48411 .56262 .48954 .63413 .50103 .55199 .49479 .56769 Metetra
.854 .541 .457 r
.49479 .56769 .50103 .55199 .51171 .56109 .5053 .61934 Metetra
.636 .373 .503 r
.5053 .61934 .51171 .56109 .52245 .65652 .51629 .6371 Metetra
.76 .605 .686 r
.51629 .6371 .52245 .65652 .53364 .66145 .52744 .6201 Metetra
.82 .595 .598 r
.52744 .6201 .53364 .66145 .54478 .64195 .53835 .55572 Metetra
.675 .466 .595 r
.53835 .55572 .54478 .64195 .55528 .55666 .54913 .52155 Metetra
.019 .048 .548 r
.54913 .52155 .55528 .55666 .56583 .51626 .56045 .55414 Metetra
.72 .43 .485 r
.56045 .55414 .56583 .51626 .57692 .5229 .57202 .58475 Metetra
.699 .428 .51 r
.57202 .58475 .57692 .5229 .58918 .58599 .58402 .62422 Metetra
.572 .294 .457 r
.58402 .62422 .58918 .58599 .60192 .64894 .59561 .62749 Metetra
.706 .567 .695 r
.59561 .62749 .60192 .64894 .61366 .6535 .60694 .6162 Metetra
.828 .602 .597 r
.60694 .6162 .61366 .6535 .62512 .64461 .61694 .55612 Metetra
.684 .471 .592 r
.61694 .55612 .62512 .64461 .63469 .57721 .62724 .51696 Metetra
.666 .47 .61 r
.62724 .51696 .63469 .57721 .64376 .50652 .63795 .49565 Metetra
.757 .68 .776 r
.63795 .49565 .64376 .50652 .65435 .48508 .64903 .48616 Metetra
.871 .994 .802 r
.64903 .48616 .65435 .48508 .66545 .47777 .65999 .47364 Metetra
.576 .042 0 r
.65999 .47364 .66545 .47777 .67668 .47271 .672 .48515 Metetra
.869 .525 .397 r
.672 .48515 .67668 .47271 .6888 .48498 .68588 .53249 Metetra
.775 .481 .489 r
.68588 .53249 .6888 .48498 .7027 .52782 .70083 .59278 Metetra
.684 .411 .503 r
.70083 .59278 .7027 .52782 .71771 .58344 .71496 .62896 Metetra
.549 .282 .464 r
.71496 .62896 .71771 .58344 .73123 .60675 .72731 .62909 Metetra
.479 .167 .36 r
.72731 .62909 .73123 .60675 .74513 .63208 .73952 .62569 Metetra
.875 .807 .779 r
.73952 .62569 .74513 .63208 .75735 .62869 .75098 .61021 Metetra
.839 .655 .653 r
.75098 .61021 .75735 .62869 .76963 .62528 .76144 .58077 Metetra
.829 .592 .581 r
.76144 .58077 .76963 .62528 .77982 .59333 .76898 .51325 Metetra
.673 .464 .594 r
.76898 .51325 .77982 .59333 .79 .56305 .77885 .48154 Metetra
.656 .451 .594 r
.77885 .48154 .79 .56305 .79984 .53052 .789 .45528 Metetra
.636 .439 .599 r
.789 .45528 .79984 .53052 .80948 .49752 .79973 .43718 Metetra
.565 .398 .614 r
.79973 .43718 .80948 .49752 .81919 .46713 .81204 .43785 Metetra
.519 .418 .68 r
.81204 .43785 .81919 .46713 .82936 .44328 .8248 .44242 Metetra
.27 0 0 r
.8248 .44242 .82936 .44328 .84018 .42726 .83763 .44645 Metetra
.522 .192 .349 r
.83763 .44645 .84018 .42726 .85157 .41722 .85016 .44644 Metetra
.499 .214 .412 r
.85016 .44644 .85157 .41722 .86335 .4109 .86239 .44272 Metetra
.505 .225 .423 r
.86239 .44272 .86335 .4109 .8754 .40684 .87467 .43899 Metetra
.459 .19 .418 r
.87467 .43899 .8754 .40684 .88754 .40308 .8865 .43076 Metetra
.717 .389 .421 r
.8865 .43076 .88754 .40308 .90699 .46177 .90206 .45474 Metetra
.657 .751 .919 r
.90206 .45474 .90699 .46177 .91949 .45804 .9146 .45098 Metetra
.657 .751 .919 r
.9146 .45098 .91949 .45804 .93203 .4543 .92718 .44721 Metetra
.432 0 .104 r
.31944 .63344 .32682 .62559 .33568 .64692 .32955 .63303 Metetra
.563 .539 .786 r
.32955 .63303 .33568 .64692 .34713 .62161 .33968 .63313 Metetra
.542 .163 .271 r
.33968 .63313 .34713 .62161 .35613 .64465 .34979 .63487 Metetra
.422 .541 .872 r
.34979 .63487 .35613 .64465 .36672 .63738 .35992 .63753 Metetra
.948 .832 .697 r
.35992 .63753 .36672 .63738 .37724 .63203 .37139 .61185 Metetra
.516 .453 .724 r
.37139 .61185 .37724 .63203 .38701 .64599 .38159 .61458 Metetra
.699 .472 0 r
.38159 .61458 .38701 .64599 .39892 .60588 .39006 .66374 Metetra
0 0 .091 r
.39006 .66374 .39892 .60588 .40887 .61845 .40313 .59399 Metetra
.458 .39 .693 r
.40313 .59399 .40887 .61845 .41795 .66373 .41335 .60035 Metetra
.515 .356 .603 r
.41335 .60035 .41795 .66373 .42988 .61792 .42362 .60874 Metetra
.957 .62 .319 r
.42362 .60874 .42988 .61792 .4411 .59206 .43287 .65972 Metetra
.147 0 .367 r
.43287 .65972 .4411 .59206 .45104 .62175 .44481 .6115 Metetra
.897 .707 .637 r
.44481 .6115 .45104 .62175 .46108 .65889 .45636 .57127 Metetra
.374 .237 .564 r
.45636 .57127 .46108 .65889 .47238 .63288 .46642 .60704 Metetra
.611 .487 .686 r
.46642 .60704 .47238 .63288 .48411 .56262 .47731 .60382 Metetra
.619 .342 .476 r
.47731 .60382 .48411 .56262 .49479 .56769 .48809 .61419 Metetra
.556 .292 .471 r
.48809 .61419 .49479 .56769 .5053 .61934 .49908 .61536 Metetra
.749 .848 .925 r
.49908 .61536 .5053 .61934 .51629 .6371 .51017 .60925 Metetra
.897 .657 .567 r
.51017 .60925 .51629 .6371 .52744 .6201 .5214 .50158 Metetra
.146 .061 .494 r
.5214 .50158 .52744 .6201 .53835 .55572 .53242 .59048 Metetra
.733 .438 .481 r
.53242 .59048 .53835 .55572 .54913 .52155 .54378 .62242 Metetra
.51 .281 .504 r
.54378 .62242 .54913 .52155 .56045 .55414 .55502 .60933 Metetra
.428 .192 .452 r
.55502 .60933 .56045 .55414 .57202 .58475 .5662 .59234 Metetra
.986 .885 .547 r
.5662 .59234 .57202 .58475 .58402 .62422 .57703 .55635 Metetra
.403 .275 .59 r
.57703 .55635 .58402 .62422 .59561 .62749 .58886 .58224 Metetra
.593 .432 .633 r
.58886 .58224 .59561 .62749 .60694 .6162 .60028 .57888 Metetra
.788 .576 .614 r
.60028 .57888 .60694 .6162 .61694 .55612 .61076 .53679 Metetra
.863 .657 .622 r
.61076 .53679 .61694 .55612 .62724 .51696 .62103 .4949 Metetra
.868 .65 .605 r
.62103 .4949 .62724 .51696 .63795 .49565 .63082 .44489 Metetra
0 0 .388 r
.63082 .44489 .63795 .49565 .64903 .48616 .6446 .51382 Metetra
.828 .515 .46 r
.6446 .51382 .64903 .48616 .65999 .47364 .65854 .57268 Metetra
.589 .345 .515 r
.65854 .57268 .65999 .47364 .672 .48515 .67092 .58399 Metetra
.626 .374 .517 r
.67092 .58399 .672 .48515 .68588 .53249 .68411 .6096 Metetra
.624 .365 .506 r
.68411 .6096 .68588 .53249 .70083 .59278 .69728 .62949 Metetra
.512 .237 .434 r
.69728 .62949 .70083 .59278 .71496 .62896 .70942 .62609 Metetra
.97 .824 .642 r
.70942 .62609 .71496 .62896 .72731 .62909 .71998 .59409 Metetra
.833 .606 .595 r
.71998 .59409 .72731 .62909 .73952 .62569 .72897 .53866 Metetra
.767 .529 .574 r
.72897 .53866 .73952 .62569 .75098 .61021 .73594 .45706 Metetra
.527 .342 .574 r
.73594 .45706 .75098 .61021 .76144 .58077 .74905 .47338 Metetra
.576 .385 .586 r
.74905 .47338 .76144 .58077 .76898 .51325 .76094 .46976 Metetra
.595 .437 .637 r
.76094 .46976 .76898 .51325 .77885 .48154 .77287 .46612 Metetra
.624 .567 .77 r
.77287 .46612 .77885 .48154 .789 .45528 .7849 .46321 Metetra
.635 .194 .184 r
.7849 .46321 .789 .45528 .79973 .43718 .79784 .47038 Metetra
.604 .308 .44 r
.79784 .47038 .79973 .43718 .81204 .43785 .81096 .4782 Metetra
.557 .282 .453 r
.81096 .4782 .81204 .43785 .8248 .44242 .82367 .47995 Metetra
.513 .241 .44 r
.82367 .47995 .8248 .44242 .83763 .44645 .83596 .47626 Metetra
.499 .213 .41 r
.83596 .47626 .83763 .44645 .85016 .44644 .84831 .47256 Metetra
.414 .134 .376 r
.84831 .47256 .85016 .44644 .86239 .44272 .86015 .46337 Metetra
.095 0 .25 r
.86015 .46337 .86239 .44272 .87467 .43899 .87071 .44199 Metetra
.964 .893 .515 r
.87071 .44199 .87467 .43899 .8865 .43076 .88024 .41194 Metetra
0 0 .496 r
.88024 .41194 .8865 .43076 .90206 .45474 .89709 .44765 Metetra
.657 .751 .919 r
.89709 .44765 .90206 .45474 .9146 .45098 .90967 .44386 Metetra
.657 .751 .919 r
.90967 .44386 .9146 .45098 .92718 .44721 .92229 .44006 Metetra
.683 .763 .912 r
.31279 .62781 .31944 .63344 .32955 .63303 .32312 .62396 Metetra
0 .229 .748 r
.32312 .62396 .32955 .63303 .33968 .63313 .3328 .63233 Metetra
.459 .866 .959 r
.3328 .63233 .33968 .63313 .34979 .63487 .34316 .62977 Metetra
.742 .792 .893 r
.34316 .62977 .34979 .63487 .35992 .63753 .35373 .62396 Metetra
0 0 .563 r
.35373 .62396 .35992 .63753 .37139 .61185 .36334 .63904 Metetra
.003 0 .179 r
.36334 .63904 .37139 .61185 .38159 .61458 .37475 .61666 Metetra
.805 .38 .238 r
.37475 .61666 .38159 .61458 .39006 .66374 .38458 .63115 Metetra
.648 .491 .656 r
.38458 .63115 .39006 .66374 .40313 .59399 .39542 .62265 Metetra
.698 .401 .469 r
.39542 .62265 .40313 .59399 .41335 .60035 .4053 .64221 Metetra
.4053 .64221 .41335 .60035 .42362 .60874 .41793 .58009 Metetra
.702 .46 0 r
.41793 .58009 .42362 .60874 .43287 .65972 .42715 .62704 Metetra
.69 .519 .651 r
.42715 .62704 .43287 .65972 .44481 .6115 .43828 .61234 Metetra
.771 .296 .112 r
.43828 .61234 .44481 .6115 .45636 .57127 .44879 .62422 Metetra
.638 .37 .497 r
.44879 .62422 .45636 .57127 .46642 .60704 .45935 .64105 Metetra
0 0 .002 r
.45935 .64105 .46642 .60704 .47731 .60382 .47107 .59478 Metetra
0 0 .497 r
.47107 .59478 .47731 .60382 .48809 .61419 .48181 .60868 Metetra
.024 .452 .873 r
.48181 .60868 .48809 .61419 .49908 .61536 .49279 .61341 Metetra
.867 .907 .857 r
.49279 .61341 .49908 .61536 .51017 .60925 .50396 .60223 Metetra
.94 .725 .584 r
.50396 .60223 .51017 .60925 .5214 .50158 .51528 .53757 Metetra
.843 .551 .495 r
.51528 .53757 .5214 .50158 .53242 .59048 .5263 .62777 Metetra
.605 .321 .46 r
.5263 .62777 .53242 .59048 .54378 .62242 .53768 .63572 Metetra
.53768 .63572 .54378 .62242 .55502 .60933 .54896 .61141 Metetra
.975 .739 .516 r
.54896 .61141 .55502 .60933 .5662 .59234 .55924 .49992 Metetra
.36 .229 .563 r
.55924 .49992 .5662 .59234 .57703 .55635 .57094 .54135 Metetra
.942 .602 .18 r
.57094 .54135 .57703 .55635 .58886 .58224 .5833 .60155 Metetra
.528 .196 .349 r
.5833 .60155 .58886 .58224 .60028 .57888 .59492 .60203 Metetra
.332 .042 .313 r
.59492 .60203 .60028 .57888 .61076 .53679 .60635 .59123 Metetra
0 0 .172 r
.60635 .59123 .61076 .53679 .62103 .4949 .61603 .51672 Metetra
.856 .771 .265 r
.61603 .51672 .62103 .4949 .63082 .44489 .62583 .46027 Metetra
.875 .546 .425 r
.62583 .46027 .63082 .44489 .6446 .51382 .63926 .51921 Metetra
.921 .578 .372 r
.63926 .51921 .6446 .51382 .65854 .57268 .65336 .58314 Metetra
.873 .521 .38 r
.65336 .58314 .65854 .57268 .67092 .58399 .6672 .62823 Metetra
.532 .265 .455 r
.6672 .62823 .67092 .58399 .68411 .6096 .67934 .62649 Metetra
.441 .099 .287 r
.67934 .62649 .68411 .6096 .69728 .62949 .69147 .62308 Metetra
.961 .753 .576 r
.69147 .62308 .69728 .62949 .70942 .62609 .70104 .56952 Metetra
.816 .576 .576 r
.70104 .56952 .70942 .62609 .71998 .59409 .70889 .49059 Metetra
.674 .457 .583 r
.70889 .49059 .71998 .59409 .72897 .53866 .71846 .44899 Metetra
.718 .492 .582 r
.71846 .44899 .72897 .53866 .73594 .45706 .72692 .39324 Metetra
.277 .192 .576 r
.72692 .39324 .73594 .45706 .74905 .47338 .7415 .43474 Metetra
.129 .127 .586 r
.7415 .43474 .74905 .47338 .76094 .46976 .756 .46961 Metetra
.897 .481 .176 r
.756 .46961 .76094 .46976 .77287 .46612 .77085 .50453 Metetra
.712 .407 .46 r
.77085 .50453 .77287 .46612 .7849 .46321 .78563 .53423 Metetra
.63 .364 .497 r
.78563 .53423 .7849 .46321 .79784 .47038 .80002 .5554 Metetra
.582 .333 .503 r
.80002 .5554 .79784 .47038 .81096 .4782 .8136 .56429 Metetra
.54 .3 .5 r
.8136 .56429 .81096 .4782 .82367 .47995 .82622 .56068 Metetra
.538 .297 .497 r
.82622 .56068 .82367 .47995 .83596 .47626 .8389 .55706 Metetra
.527 .288 .496 r
.8389 .55706 .83596 .47626 .84831 .47256 .85135 .5505 Metetra
.458 .235 .487 r
.85135 .5505 .84831 .47256 .86015 .46337 .86232 .52884 Metetra
.362 .157 .462 r
.86232 .52884 .86015 .46337 .87071 .44199 .87196 .4953 Metetra
.232 .053 .421 r
.87196 .4953 .87071 .44199 .88024 .41194 .88051 .45338 Metetra
.516 .248 .448 r
.88051 .45338 .88024 .41194 .89709 .44765 .8931 .44958 Metetra
.736 .961 .677 r
.8931 .44958 .89709 .44765 .90967 .44386 .90469 .43669 Metetra
.657 .751 .919 r
.90469 .43669 .90967 .44386 .92229 .44006 .91736 .43285 Metetra
.803 .691 .742 r
.30636 .61787 .31279 .62781 .32312 .62396 .31731 .60395 Metetra
.525 .459 .724 r
.31731 .60395 .32312 .62396 .3328 .63233 .32731 .60606 Metetra
0 0 .418 r
.32731 .60606 .3328 .63233 .34316 .62977 .33595 .63437 Metetra
.943 .961 .728 r
.33595 .63437 .34316 .62977 .35373 .62396 .34722 .61608 Metetra
.875 .726 .693 r
.34722 .61608 .35373 .62396 .36334 .63904 .35876 .59137 Metetra
.308 .217 .587 r
.35876 .59137 .36334 .63904 .37475 .61666 .36803 .61427 Metetra
.917 .558 .337 r
.36803 .61427 .37475 .61666 .38458 .63115 .37704 .64804 Metetra
.989 .863 .507 r
.37704 .64804 .38458 .63115 .39542 .62265 .38967 .59691 Metetra
.732 .563 .663 r
.38967 .59691 .39542 .62265 .4053 .64221 .40084 .57915 Metetra
.624 .437 .609 r
.40084 .57915 .4053 .64221 .41793 .58009 .41175 .56755 Metetra
.966 .643 .329 r
.41175 .56755 .41793 .58009 .42715 .62704 .42043 .62923 Metetra
.781 .334 .189 r
.42043 .62923 .42715 .62704 .43828 .61234 .43088 .64222 Metetra
0 0 .122 r
.43088 .64222 .43828 .61234 .44879 .62422 .44253 .61132 Metetra
.903 .693 .609 r
.44253 .61132 .44879 .62422 .45935 .64105 .45457 .55554 Metetra
.534 .358 .589 r
.45457 .55554 .45935 .64105 .47107 .59478 .46522 .56217 Metetra
.611 .465 .659 r
.46522 .56217 .47107 .59478 .48181 .60868 .47613 .55788 Metetra
.643 .46 .621 r
.47613 .55788 .48181 .60868 .49279 .61341 .48718 .54495 Metetra
0 0 .125 r
.48718 .54495 .49279 .61341 .50396 .60223 .49721 .65613 Metetra
.593 .328 .484 r
.49721 .65613 .50396 .60223 .51528 .53757 .50853 .66413 Metetra
.478 .259 .502 r
.50853 .66413 .51528 .53757 .5263 .62777 .52001 .63868 Metetra
.99 .762 .498 r
.52001 .63868 .5263 .62777 .53768 .63572 .53123 .5264 Metetra
.543 .358 .581 r
.53123 .5264 .53768 .63572 .54896 .61141 .54239 .5323 Metetra
.54 .366 .595 r
.54239 .5323 .54896 .61141 .55924 .49992 .55365 .53755 Metetra
.509 .237 .436 r
.55365 .53755 .55924 .49992 .57094 .54135 .56492 .53413 Metetra
.809 .763 .81 r
.56492 .53413 .57094 .54135 .5833 .60155 .57611 .52347 Metetra
.674 .466 .596 r
.57611 .52347 .5833 .60155 .59492 .60203 .58693 .49245 Metetra
.557 .369 .583 r
.58693 .49245 .59492 .60203 .60635 .59123 .59832 .4942 Metetra
.293 .179 .548 r
.59832 .4942 .60635 .59123 .61603 .51672 .61116 .54912 Metetra
.802 .495 .47 r
.61116 .54912 .61603 .51672 .62583 .46027 .62442 .60287 Metetra
.609 .367 .525 r
.62442 .60287 .62583 .46027 .63926 .51921 .63727 .63029 Metetra
.543 .309 .51 r
.63727 .63029 .63926 .51921 .65336 .58314 .64928 .6269 Metetra
.504 .239 .446 r
.64928 .6269 .65336 .58314 .6672 .62823 .66127 .62187 Metetra
.943 .772 .639 r
.66127 .62187 .6672 .62823 .67934 .62649 .672 .58658 Metetra
.82 .593 .594 r
.672 .58658 .67934 .62649 .69147 .62308 .68153 .52936 Metetra
.706 .483 .584 r
.68153 .52936 .69147 .62308 .70104 .56952 .69099 .47753 Metetra
.67 .457 .587 r
.69099 .47753 .70104 .56952 .70889 .49059 .70104 .44217 Metetra
.639 .459 .623 r
.70104 .44217 .70889 .49059 .71846 .44899 .71227 .43029 Metetra
.474 .446 .747 r
.71227 .43029 .71846 .44899 .72692 .39324 .72449 .43487 Metetra
.669 .376 .468 r
.72449 .43487 .72692 .39324 .7415 .43474 .7379 .45603 Metetra
.631 .297 .386 r
.7379 .45603 .7415 .43474 .756 .46961 .75071 .465 Metetra
0 .43 .847 r
.75071 .465 .756 .46961 .77085 .50453 .76341 .47049 Metetra
.561 .433 .662 r
.76341 .47049 .77085 .50453 .78563 .53423 .77586 .47117 Metetra
.58 .406 .611 r
.77586 .47117 .78563 .53423 .80002 .5554 .78812 .46823 Metetra
.577 .392 .594 r
.78812 .46823 .80002 .5554 .8136 .56429 .80036 .46451 Metetra
.575 .386 .588 r
.80036 .46451 .8136 .56429 .82622 .56068 .81266 .46078 Metetra
.579 .389 .588 r
.81266 .46078 .82622 .56068 .8389 .55706 .82491 .45591 Metetra
.585 .393 .587 r
.82491 .45591 .8389 .55706 .85135 .5505 .83699 .4488 Metetra
.598 .402 .587 r
.83699 .4488 .85135 .5505 .86232 .52884 .84865 .43719 Metetra
.62 .42 .589 r
.84865 .43719 .86232 .52884 .87196 .4953 .85968 .41956 Metetra
.648 .445 .595 r
.85968 .41956 .87196 .4953 .88051 .45338 .87014 .39713 Metetra
.307 .227 .601 r
.87014 .39713 .88051 .45338 .8931 .44958 .88703 .43331 Metetra
.635 .57 .765 r
.88703 .43331 .8931 .44958 .90469 .43669 .89968 .42946 Metetra
.657 .751 .919 r
.89968 .42946 .90469 .43669 .91736 .43285 .91239 .42559 Metetra
.584 .56 .793 r
.30012 .60461 .30636 .61787 .31731 .60395 .31027 .6038 Metetra
.871 .483 .3 r
.31027 .6038 .31731 .60395 .32731 .60606 .31914 .62532 Metetra
.687 .778 .298 r
.31914 .62532 .32731 .60606 .33595 .63437 .33106 .5964 Metetra
.423 .318 .631 r
.33106 .5964 .33595 .63437 .34722 .61608 .34069 .60787 Metetra
.823 .724 .756 r
.34069 .60787 .34722 .61608 .35876 .59137 .35175 .5938 Metetra
.896 .564 .41 r
.35175 .5938 .35876 .59137 .36803 .61427 .36019 .63418 Metetra
.752 .8 .317 r
.36019 .63418 .36803 .61427 .37704 .64804 .37221 .60098 Metetra
.608 .438 .627 r
.37221 .60098 .37704 .64804 .38967 .59691 .38296 .59504 Metetra
.892 .494 .26 r
.38296 .59504 .38967 .59691 .40084 .57915 .39258 .61923 Metetra
.321 .074 .375 r
.39258 .61923 .40084 .57915 .41175 .56755 .40391 .60127 Metetra
.803 .515 .5 r
.40391 .60127 .41175 .56755 .42043 .62923 .4127 .66018 Metetra
.995 .81 .442 r
.4127 .66018 .42043 .62923 .43088 .64222 .4266 .55865 Metetra
.339 .211 .556 r
.4266 .55865 .43088 .64222 .44253 .61132 .43632 .59579 Metetra
.716 .607 .735 r
.43632 .59579 .44253 .61132 .45457 .55554 .44739 .58673 Metetra
.545 .255 .425 r
.44739 .58673 .45457 .55554 .46522 .56217 .45828 .58763 Metetra
.48 .178 .376 r
.45828 .58763 .46522 .56217 .47613 .55788 .46931 .58432 Metetra
.392 .102 .349 r
.46931 .58432 .47613 .55788 .48718 .54495 .48045 .57572 Metetra
.807 .509 .485 r
.48045 .57572 .48718 .54495 .49721 .65613 .49097 .63094 Metetra
.836 .628 .622 r
.49097 .63094 .49721 .65613 .50853 .66413 .50258 .5865 Metetra
.739 .516 .591 r
.50258 .5865 .50853 .66413 .52001 .63868 .51401 .52803 Metetra
.528 .346 .578 r
.51401 .52803 .52001 .63868 .53123 .5264 .52512 .53782 Metetra
.364 0 .156 r
.52512 .53782 .53123 .5264 .54239 .5323 .53632 .5344 Metetra
.935 .965 .746 r
.53632 .5344 .54239 .5323 .55365 .53755 .54748 .51744 Metetra
0 0 .54 r
.54748 .51744 .55365 .53755 .56492 .53413 .559 .54125 Metetra
.237 0 0 r
.559 .54125 .56492 .53413 .57611 .52347 .57038 .53781 Metetra
.57038 .53781 .57611 .52347 .58693 .49245 .58147 .51386 Metetra
.623 .295 .394 r
.58147 .51386 .58693 .49245 .59832 .4942 .59311 .52171 Metetra
.816 .503 .46 r
.59311 .52171 .59832 .4942 .61116 .54912 .60595 .57442 Metetra
.824 .506 .452 r
.60595 .57442 .61116 .54912 .62442 .60287 .61923 .6273 Metetra
.477 .168 .364 r
.61923 .6273 .62442 .60287 .63727 .63029 .63122 .62389 Metetra
.898 .793 .736 r
.63122 .62389 .63727 .63029 .64928 .6269 .64269 .60403 Metetra
.926 .676 .542 r
.64269 .60403 .64928 .6269 .66127 .62187 .6508 .49713 Metetra
.634 .424 .579 r
.6508 .49713 .66127 .62187 .672 .58658 .66142 .4671 Metetra
.478 .31 .573 r
.66142 .4671 .672 .58658 .68153 .52936 .67441 .49285 Metetra
.187 .171 .606 r
.67441 .49285 .68153 .52936 .69099 .47753 .68776 .52068 Metetra
.522 .253 .449 r
.68776 .52068 .69099 .47753 .70104 .44217 .69979 .51806 Metetra
.534 .289 .491 r
.69979 .51806 .70104 .44217 .71227 .43029 .71183 .51446 Metetra
.508 .273 .493 r
.71183 .51446 .71227 .43029 .72449 .43487 .72352 .50398 Metetra
.47 .236 .476 r
.72352 .50398 .72449 .43487 .7379 .45603 .73489 .48864 Metetra
0 0 .128 r
.73489 .48864 .7379 .45603 .75071 .465 .74375 .4363 Metetra
.821 .608 .614 r
.74375 .4363 .75071 .465 .76341 .47049 .75321 .39692 Metetra
.666 .459 .594 r
.75321 .39692 .76341 .47049 .77586 .47117 .76336 .36973 Metetra
.417 .272 .576 r
.76336 .36973 .77586 .47117 .78812 .46823 .77847 .40728 Metetra
.238 .17 .575 r
.77847 .40728 .78812 .46823 .80036 .46451 .79452 .45179 Metetra
.651 .291 0 r
.79452 .45179 .80036 .46451 .81266 .46078 .81012 .48617 Metetra
.667 .337 .404 r
.81012 .48617 .81266 .46078 .82491 .45591 .82432 .50108 Metetra
.516 .25 .451 r
.82432 .50108 .82491 .45591 .83699 .4488 .83697 .49733 Metetra
.519 .257 .457 r
.83697 .49733 .83699 .4488 .84865 .43719 .84967 .49357 Metetra
.524 .268 .47 r
.84967 .49357 .84865 .43719 .85968 .41956 .86241 .48963 Metetra
.472 .24 .48 r
.86241 .48963 .85968 .41956 .87014 .39713 .87393 .4736 Metetra
.534 .289 .491 r
.87393 .4736 .87014 .39713 .88703 .43331 .88674 .46978 Metetra
.291 .067 .391 r
.88674 .46978 .88703 .43331 .89968 .42946 .89734 .44598 Metetra
0 0 .094 r
.89734 .44598 .89968 .42946 .91239 .42559 .90738 .41826 Metetra
.691 .856 .445 r
.29214 .61667 .30012 .60461 .31027 .6038 .30352 .59787 Metetra
.702 .761 .898 r
.30352 .59787 .31027 .6038 .31914 .62532 .31397 .59335 Metetra
.551 .424 .66 r
.31397 .59335 .31914 .62532 .33106 .5964 .32412 .59461 Metetra
.915 .567 .367 r
.32412 .59461 .33106 .5964 .34069 .60787 .33241 .63034 Metetra
.926 .86 .424 r
.33241 .63034 .34069 .60787 .35175 .5938 .34534 .58319 Metetra
.648 .635 .823 r
.34534 .58319 .35175 .5938 .36019 .63418 .35587 .57996 Metetra
.524 .368 .612 r
.35587 .57996 .36019 .63418 .37221 .60098 .36604 .58527 Metetra
.778 .431 0 r
.36604 .58527 .37221 .60098 .38296 .59504 .37532 .61316 Metetra
.765 .445 .444 r
.37532 .61316 .38296 .59504 .39258 .61923 .38495 .63817 Metetra
.977 .862 .476 r
.38495 .63817 .39258 .61923 .40391 .60127 .39769 .58585 Metetra
.814 .652 .682 r
.39769 .58585 .40391 .60127 .4127 .66018 .40914 .56334 Metetra
.624 .423 .589 r
.40914 .56334 .4127 .66018 .4266 .55865 .42041 .54447 Metetra
0 0 .433 r
.42041 .54447 .4266 .55865 .43632 .59579 .43055 .5639 Metetra
.602 .461 .662 r
.43055 .5639 .43632 .59579 .44739 .58673 .44144 .56056 Metetra
.841 .555 .014 r
.44144 .56056 .44739 .58673 .45828 .58763 .45114 .61457 Metetra
.751 .444 .465 r
.45114 .61457 .45828 .58763 .46931 .58432 .4617 .64471 Metetra
.12 0 .344 r
.4617 .64471 .46931 .58432 .48045 .57572 .47363 .59997 Metetra
.945 .824 .379 r
.47363 .59997 .48045 .57572 .49097 .63094 .48557 .5358 Metetra
.536 .356 .584 r
.48557 .5358 .49097 .63094 .50258 .5865 .49657 .54207 Metetra
.603 .439 .632 r
.49657 .54207 .50258 .5865 .51401 .52803 .50773 .5369 Metetra
.995 .863 .54 r
.50773 .5369 .51401 .52803 .52512 .53782 .51899 .49384 Metetra
.121 .097 .554 r
.51899 .49384 .52512 .53782 .53632 .5344 .53016 .5276 Metetra
.657 .741 .912 r
.53016 .5276 .53632 .5344 .54748 .51744 .54143 .52414 Metetra
.54143 .52414 .54748 .51744 .559 .54125 .5527 .51448 Metetra
.658 .514 .677 r
.5527 .51448 .559 .54125 .57038 .53781 .564 .50622 Metetra
0 0 .186 r
.564 .50622 .57038 .53781 .58147 .51386 .5763 .56366 Metetra
.777 .485 .494 r
.5763 .56366 .58147 .51386 .59311 .52171 .58919 .6277 Metetra
.539 .303 .505 r
.58919 .6277 .59311 .52171 .60595 .57442 .60112 .6243 Metetra
.343 .113 .413 r
.60112 .6243 .60595 .57442 .61923 .6273 .61259 .60127 Metetra
.862 .64 .6 r
.61259 .60127 .61923 .6273 .63122 .62389 .62305 .54649 Metetra
.723 .501 .589 r
.62305 .54649 .63122 .62389 .64269 .60403 .63335 .4964 Metetra
.657 .443 .582 r
.63335 .4964 .64269 .60403 .6508 .49713 .64389 .4608 Metetra
.456 .354 .65 r
.64389 .4608 .6508 .49713 .66142 .4671 .65607 .47072 Metetra
.755 .286 .135 r
.65607 .47072 .66142 .4671 .67441 .49285 .66854 .48406 Metetra
.611 .675 .887 r
.66854 .48406 .67441 .49285 .68776 .52068 .68046 .48188 Metetra
.596 .444 .646 r
.68046 .48188 .68776 .52068 .69979 .51806 .69236 .47823 Metetra
.62 .459 .642 r
.69236 .47823 .69979 .51806 .71183 .51446 .70413 .47115 Metetra
.712 .515 .621 r
.70413 .47115 .71183 .51446 .72352 .50398 .71488 .44619 Metetra
.653 .46 .61 r
.71488 .44619 .72352 .50398 .73489 .48864 .72597 .42825 Metetra
.674 .472 .604 r
.72597 .42825 .73489 .48864 .74375 .4363 .73659 .40421 Metetra
.547 .427 .667 r
.73659 .40421 .74375 .4363 .75321 .39692 .74891 .40602 Metetra
.671 .244 .226 r
.74891 .40602 .75321 .39692 .76336 .36973 .76188 .41553 Metetra
.613 .33 .464 r
.76188 .41553 .76336 .36973 .77847 .40728 .77518 .42727 Metetra
.644 .297 .368 r
.77518 .42727 .77847 .40728 .79452 .45179 .78854 .43757 Metetra
.363 .435 .802 r
.78854 .43757 .79452 .45179 .81012 .48617 .80175 .4443 Metetra
.553 .411 .642 r
.80175 .4443 .81012 .48617 .82432 .50108 .81465 .44584 Metetra
.586 .416 .619 r
.81465 .44584 .82432 .50108 .83697 .49733 .82714 .44202 Metetra
.586 .416 .619 r
.82714 .44202 .83697 .49733 .84967 .49357 .83969 .43818 Metetra
.597 .424 .618 r
.83969 .43818 .84967 .49357 .86241 .48963 .85208 .43222 Metetra
.637 .449 .612 r
.85208 .43222 .86241 .48963 .87393 .4736 .86363 .41788 Metetra
.559 .398 .619 r
.86363 .41788 .87393 .4736 .88674 .46978 .8768 .41873 Metetra
.588 .422 .625 r
.8768 .41873 .88674 .46978 .89734 .44598 .88954 .41481 Metetra
.605 .471 .672 r
.88954 .41481 .89734 .44598 .90738 .41826 .90233 .41088 Metetra
.237 .22 .637 r
.2868 .589 .29214 .61667 .30352 .59787 .29593 .60387 Metetra
.813 .449 .368 r
.29593 .60387 .30352 .59787 .31397 .59335 .30488 .6238 Metetra
.884 .825 .353 r
.30488 .6238 .31397 .59335 .32412 .59461 .31861 .56817 Metetra
.89 .605 .093 r
.31861 .56817 .32412 .59461 .33241 .63034 .3259 .61904 Metetra
.851 .691 .684 r
.3259 .61904 .33241 .63034 .34534 .58319 .33774 .59366 Metetra
.774 .423 .391 r
.33774 .59366 .34534 .58319 .35587 .57996 .3472 .61252 Metetra
.682 .389 .471 r
.3472 .61252 .35587 .57996 .36604 .58527 .35685 .63124 Metetra
.702 .685 .145 r
.35685 .63124 .36604 .58527 .37532 .61316 .3707 .56147 Metetra
.053 .025 .503 r
.3707 .56147 .37532 .61316 .38495 .63817 .37956 .60076 Metetra
.32 .249 .619 r
.37956 .60076 .38495 .63817 .39769 .58585 .38959 .61798 Metetra
0 0 .182 r
.38959 .61798 .39769 .58585 .40914 .56334 .40143 .58999 Metetra
.971 .833 .42 r
.40143 .58999 .40914 .56334 .42041 .54447 .41457 .51913 Metetra
.98 .687 .341 r
.41457 .51913 .42041 .54447 .43055 .5639 .42205 .62505 Metetra
.585 .324 .488 r
.42205 .62505 .43055 .5639 .44144 .56056 .43289 .63263 Metetra
.107 0 .349 r
.43289 .63263 .44144 .56056 .45114 .61457 .44528 .57936 Metetra
.859 .627 .587 r
.44528 .57936 .45114 .61457 .4617 .64471 .45797 .49677 Metetra
.443 .273 .554 r
.45797 .49677 .4617 .64471 .47363 .59997 .46816 .53496 Metetra
0 0 .173 r
.46816 .53496 .47363 .59997 .48557 .5358 .47786 .63192 Metetra
.536 .297 .499 r
.47786 .63192 .48557 .5358 .49657 .54207 .4893 .6286 Metetra
.368 .155 .454 r
.4893 .6286 .49657 .54207 .50773 .5369 .50101 .59395 Metetra
.748 .668 .116 r
.50101 .59395 .50773 .5369 .51899 .49384 .51282 .48858 Metetra
.926 .777 .677 r
.51282 .48858 .51899 .49384 .53016 .5276 .52396 .46073 Metetra
.371 .247 .579 r
.52396 .46073 .53016 .5276 .54143 .52414 .53516 .48806 Metetra
.73 .495 0 r
.53516 .48806 .54143 .52414 .5527 .51448 .5469 .55844 Metetra
.794 .499 .49 r
.5469 .55844 .5527 .51448 .564 .50622 .55914 .62464 Metetra
.55 .313 .509 r
.55914 .62464 .564 .50622 .5763 .56366 .57103 .6247 Metetra
.433 .194 .451 r
.57103 .6247 .5763 .56366 .58919 .6277 .58271 .60763 Metetra
.919 .68 .56 r
.58271 .60763 .58919 .6277 .60112 .6243 .59287 .51832 Metetra
.696 .473 .581 r
.59287 .51832 .60112 .6243 .61259 .60127 .60333 .46492 Metetra
.568 .371 .574 r
.60333 .46492 .61259 .60127 .62305 .54649 .61486 .4613 Metetra
.575 .389 .591 r
.61486 .4613 .62305 .54649 .63335 .4964 .62643 .45757 Metetra
.697 .511 .632 r
.62643 .45757 .63335 .4964 .64389 .4608 .63752 .43842 Metetra
.644 .525 .703 r
.63752 .43842 .64389 .4608 .65607 .47072 .64906 .43263 Metetra
.025 .051 .549 r
.64906 .43263 .65607 .47072 .66854 .48406 .6624 .46948 Metetra
.896 .544 .067 r
.6624 .46948 .66854 .48406 .68046 .48188 .67699 .5259 Metetra
.685 .39 .469 r
.67699 .5259 .68046 .48188 .69236 .47823 .69059 .55226 Metetra
.644 .375 .497 r
.69059 .55226 .69236 .47823 .70413 .47115 .70449 .57909 Metetra
.538 .301 .503 r
.70449 .57909 .70413 .47115 .71488 .44619 .71695 .5755 Metetra
.541 .307 .51 r
.71695 .5755 .71488 .44619 .72597 .42825 .72946 .57189 Metetra
.471 .256 .505 r
.72946 .57189 .72597 .42825 .73659 .40421 .74019 .53943 Metetra
.457 .245 .502 r
.74019 .53943 .73659 .40421 .74891 .40602 .75057 .50427 Metetra
.401 .194 .481 r
.75057 .50427 .74891 .40602 .76188 .41553 .76055 .46611 Metetra
.248 .049 .402 r
.76055 .46611 .76188 .41553 .77518 .42727 .77059 .43157 Metetra
.943 .914 .537 r
.77059 .43157 .77518 .42727 .78854 .43757 .78103 .40438 Metetra
.717 .534 .641 r
.78103 .40438 .78854 .43757 .80175 .4443 .79198 .38478 Metetra
.63 .441 .609 r
.79198 .38478 .80175 .4443 .81465 .44584 .8034 .37142 Metetra
.597 .409 .598 r
.8034 .37142 .81465 .44584 .82714 .44202 .81525 .363 Metetra
.582 .396 .595 r
.81525 .363 .82714 .44202 .83969 .43818 .82743 .35781 Metetra
.58 .394 .595 r
.82743 .35781 .83969 .43818 .85208 .43222 .83968 .35296 Metetra
.589 .401 .595 r
.83968 .35296 .85208 .43222 .86363 .41788 .85175 .34587 Metetra
.156 .109 .549 r
.85175 .34587 .86363 .41788 .8768 .41873 .87163 .41135 Metetra
.657 .751 .919 r
.87163 .41135 .8768 .41873 .88954 .41481 .8844 .4074 Metetra
.657 .751 .919 r
.8844 .4074 .88954 .41481 .90233 .41088 .89723 .40343 Metetra
0 .21 .736 r
.28025 .57867 .2868 .589 .29593 .60387 .28977 .58754 Metetra
0 .08 .629 r
.28977 .58754 .29593 .60387 .30488 .6238 .29905 .60166 Metetra
.753 .588 .672 r
.29905 .60166 .30488 .6238 .31861 .56817 .31052 .58314 Metetra
.624 .272 .354 r
.31052 .58314 .31861 .56817 .3259 .61904 .32046 .58947 Metetra
.648 .497 .665 r
.32046 .58947 .3259 .61904 .33774 .59366 .33131 .58164 Metetra
.868 .479 .003 r
.33131 .58164 .33774 .59366 .3472 .61252 .34035 .60751 Metetra
.905 .766 .698 r
.34035 .60751 .3472 .61252 .35685 .63124 .35222 .58198 Metetra
.605 .433 .623 r
.35222 .58198 .35685 .63124 .3707 .56147 .36307 .57588 Metetra
.775 .442 .422 r
.36307 .57588 .3707 .56147 .37956 .60076 .37264 .59913 Metetra
.875 .899 .845 r
.37264 .59913 .37956 .60076 .38959 .61798 .38388 .58729 Metetra
0 0 .449 r
.38388 .58729 .38959 .61798 .40143 .58999 .39343 .61911 Metetra
.965 .829 .407 r
.39343 .61911 .40143 .58999 .41457 .51913 .40697 .54477 Metetra
.718 .409 .454 r
.40697 .54477 .41457 .51913 .42205 .62505 .41704 .5666 Metetra
.662 .467 .611 r
.41704 .5666 .42205 .62505 .43289 .63263 .4285 .54685 Metetra
.444 .288 .574 r
.4285 .54685 .43289 .63263 .44528 .57936 .43885 .56882 Metetra
.648 .645 .834 r
.43885 .56882 .44528 .57936 .45797 .49677 .44996 .56543 Metetra
.581 .324 .492 r
.44996 .56543 .45797 .49677 .46816 .53496 .46091 .57308 Metetra
.708 .415 .478 r
.46091 .57308 .46816 .53496 .47786 .63192 .47167 .60098 Metetra
.802 .596 .624 r
.47167 .60098 .47786 .63192 .4893 .6286 .48351 .56129 Metetra
.741 .52 .595 r
.48351 .56129 .4893 .6286 .50101 .59395 .49525 .51004 Metetra
.51 .34 .586 r
.49525 .51004 .50101 .59395 .51282 .48858 .50638 .52032 Metetra
.49 .202 .403 r
.50638 .52032 .51282 .48858 .52396 .46073 .51768 .51682 Metetra
.26 .05 .392 r
.51768 .51682 .52396 .46073 .53516 .48806 .52899 .48493 Metetra
.927 .551 .266 r
.52899 .48493 .53516 .48806 .5469 .55844 .54049 .52465 Metetra
.599 .456 .658 r
.54049 .52465 .5469 .55844 .55914 .62464 .55198 .52112 Metetra
.614 .412 .584 r
.55198 .52112 .55914 .62464 .57103 .6247 .56336 .50336 Metetra
.574 .377 .577 r
.56336 .50336 .57103 .6247 .58271 .60763 .57486 .49773 Metetra
.248 .14 .528 r
.57486 .49773 .58271 .60763 .59287 .51832 .58775 .56447 Metetra
.738 .444 .482 r
.58775 .56447 .59287 .51832 .60333 .46492 .60066 .60786 Metetra
.541 .309 .512 r
.60066 .60786 .60333 .46492 .61486 .4613 .61276 .60437 Metetra
.511 .285 .508 r
.61276 .60437 .61486 .4613 .62643 .45757 .62456 .58892 Metetra
.247 .08 .447 r
.62456 .58892 .62643 .45757 .63752 .43842 .63409 .50522 Metetra
.039 0 .344 r
.63409 .50522 .63752 .43842 .64906 .43263 .64387 .44298 Metetra
.791 .406 .325 r
.64387 .44298 .64906 .43263 .6624 .46948 .65665 .46499 Metetra
.779 .293 0 r
.65665 .46499 .6624 .46948 .67699 .5259 .66956 .4845 Metetra
.56 .415 .641 r
.66956 .4845 .67699 .5259 .69059 .55226 .68179 .48483 Metetra
.579 .4 .604 r
.68179 .48483 .69059 .55226 .70449 .57909 .69389 .48112 Metetra
.581 .389 .586 r
.69389 .48112 .70449 .57909 .71695 .5755 .70589 .47457 Metetra
.604 .405 .584 r
.70589 .47457 .71695 .5755 .72946 .57189 .71745 .46013 Metetra
.695 .468 .574 r
.71745 .46013 .72946 .57189 .74019 .53943 .72638 .40387 Metetra
.642 .424 .572 r
.72638 .40387 .74019 .53943 .75057 .50427 .73619 .36616 Metetra
.606 .398 .573 r
.73619 .36616 .75057 .50427 .76055 .46611 .74695 .34503 Metetra
.468 .301 .571 r
.74695 .34503 .76055 .46611 .77059 .43157 .76131 .37349 Metetra
.267 .192 .583 r
.76131 .37349 .77059 .43157 .78103 .40438 .77671 .41153 Metetra
.864 .461 .27 r
.77671 .41153 .78103 .40438 .79198 .38478 .79216 .44556 Metetra
.625 .348 .478 r
.79216 .44556 .79198 .38478 .8034 .37142 .80662 .46386 Metetra
.546 .302 .496 r
.80662 .46386 .8034 .37142 .81525 .363 .81966 .4638 Metetra
.535 .296 .499 r
.81966 .4638 .81525 .363 .82743 .35781 .83244 .45994 Metetra
.535 .296 .5 r
.83244 .45994 .82743 .35781 .83968 .35296 .84527 .45605 Metetra
.504 .274 .498 r
.84527 .45605 .83968 .35296 .85175 .34587 .85717 .44247 Metetra
.534 .294 .497 r
.85717 .44247 .85175 .34587 .87163 .41135 .87007 .43854 Metetra
.204 0 .318 r
.87007 .43854 .87163 .41135 .8844 .4074 .88108 .41681 Metetra
.88108 .41681 .8844 .4074 .89723 .40343 .8921 .39593 Metetra
0 0 .082 r
.27123 .60128 .28025 .57867 .28977 .58754 .28275 .5831 Metetra
.744 .819 .91 r
.28275 .5831 .28977 .58754 .29905 .60166 .29338 .57726 Metetra
.361 .326 .684 r
.29338 .57726 .29905 .60166 .31052 .58314 .30306 .58645 Metetra
.796 .386 .273 r
.30306 .58645 .31052 .58314 .32046 .58947 .3125 .60122 Metetra
.859 .924 .533 r
.3125 .60122 .32046 .58947 .33131 .58164 .32436 .57768 Metetra
.917 .772 .685 r
.32436 .57768 .33131 .58164 .34035 .60751 .3364 .54938 Metetra
.094 .043 .503 r
.3364 .54938 .34035 .60751 .35222 .58198 .34471 .58974 Metetra
.788 .416 .354 r
.34471 .58974 .35222 .58198 .36307 .57588 .35443 .60796 Metetra
.786 .493 .492 r
.35443 .60796 .36307 .57588 .37264 .59913 .36295 .65573 Metetra
0 0 .159 r
.36295 .65573 .37264 .59913 .38388 .58729 .37641 .598 Metetra
.996 .865 .567 r
.37641 .598 .38388 .58729 .39343 .61911 .38904 .55365 Metetra
.57 .393 .603 r
.38904 .55365 .39343 .61911 .40697 .54477 .39988 .5517 Metetra
.993 .863 .601 r
.39988 .5517 .40697 .54477 .41704 .5666 .41202 .51308 Metetra
.194 .127 .548 r
.41202 .51308 .41704 .5666 .4285 .54685 .42177 .54622 Metetra
.94 .634 .43 r
.42177 .54622 .4285 .54685 .43885 .56882 .43017 .63913 Metetra
.574 .317 .489 r
.43017 .63913 .43885 .56882 .44996 .56543 .44133 .6457 Metetra
0 0 .209 r
.44133 .6457 .44996 .56543 .46091 .57308 .45452 .55948 Metetra
.443 .491 .814 r
.45452 .55948 .46091 .57308 .47167 .60098 .46565 .56284 Metetra
.484 .366 .643 r
.46565 .56284 .47167 .60098 .48351 .56129 .47682 .56996 Metetra
.82 .922 .534 r
.47682 .56996 .48351 .56129 .49525 .51004 .48841 .54919 Metetra
.963 .788 .349 r
.48841 .54919 .49525 .51004 .50638 .52032 .50063 .4353 Metetra
.005 0 .456 r
.50063 .4353 .50638 .52032 .51768 .51682 .51137 .50979 Metetra
0 0 .496 r
.51137 .50979 .51768 .51682 .52899 .48493 .52274 .52207 Metetra
.498 .218 .42 r
.52274 .52207 .52899 .48493 .54049 .52465 .53422 .51853 Metetra
.864 .796 .783 r
.53422 .51853 .54049 .52465 .55198 .52112 .54567 .50392 Metetra
.444 .445 .766 r
.54567 .50392 .55198 .52112 .56336 .50336 .55729 .50851 Metetra
.917 .576 .38 r
.55729 .50851 .56336 .50336 .57486 .49773 .56976 .56967 Metetra
.595 .334 .491 r
.56976 .56967 .57486 .49773 .58775 .56447 .58191 .58184 Metetra
.426 .077 .269 r
.58191 .58184 .58775 .56447 .60066 .60786 .59391 .57831 Metetra
.631 .492 .674 r
.59391 .57831 .60066 .60786 .61276 .60437 .60589 .572 Metetra
.655 .499 .66 r
.60589 .572 .61276 .60437 .62456 .58892 .61781 .56216 Metetra
.789 .597 .642 r
.61781 .56216 .62456 .58892 .63409 .50522 .62915 .53341 Metetra
.62915 .53341 .63409 .50522 .64387 .44298 .63956 .48175 Metetra
0 0 .165 r
.63956 .48175 .64387 .44298 .65665 .46499 .6497 .43073 Metetra
.768 .565 .623 r
.6497 .43073 .65665 .46499 .66956 .4845 .66037 .3994 Metetra
.627 .425 .589 r
.66037 .3994 .66956 .4845 .68179 .48483 .67147 .38075 Metetra
.584 .388 .581 r
.67147 .38075 .68179 .48483 .69389 .48112 .68301 .37223 Metetra
.549 .361 .579 r
.68301 .37223 .69389 .48112 .70589 .47457 .69514 .37447 Metetra
.476 .311 .577 r
.69514 .37447 .70589 .47457 .71745 .46013 .70843 .39548 Metetra
.488 .338 .603 r
.70843 .39548 .71745 .46013 .72638 .40387 .72142 .40762 Metetra
.748 .267 .1 r
.72142 .40762 .72638 .40387 .73619 .36616 .73469 .4214 Metetra
.61 .333 .472 r
.73469 .4214 .73619 .36616 .74695 .34503 .74814 .43497 Metetra
.578 .325 .497 r
.74814 .43497 .74695 .34503 .76131 .37349 .7615 .44473 Metetra
.553 .297 .482 r
.7615 .44473 .76131 .37349 .77671 .41153 .77446 .44707 Metetra
.495 .212 .414 r
.77446 .44707 .77671 .41153 .79216 .44556 .78702 .4432 Metetra
.558 .892 .985 r
.78702 .4432 .79216 .44556 .80662 .46386 .79964 .43931 Metetra
.648 .523 .697 r
.79964 .43931 .80662 .46386 .81966 .4638 .81205 .43236 Metetra
.703 .531 .653 r
.81205 .43236 .81966 .4638 .83244 .45994 .82363 .41609 Metetra
.709 .511 .618 r
.82363 .41609 .83244 .45994 .84527 .45605 .83436 .3915 Metetra
.688 .476 .595 r
.83436 .3915 .84527 .45605 .85717 .44247 .84442 .36126 Metetra
.388 .261 .585 r
.84442 .36126 .85717 .44247 .87007 .43854 .86115 .3964 Metetra
.592 .437 .64 r
.86115 .3964 .87007 .43854 .88108 .41681 .874 .39239 Metetra
.615 .504 .704 r
.874 .39239 .88108 .41681 .8921 .39593 .88692 .38836 Metetra
.44 .351 .659 r
.26606 .57099 .27123 .60128 .28275 .5831 .27568 .57852 Metetra
.726 .814 .92 r
.27568 .57852 .28275 .5831 .29338 .57726 .2863 .57327 Metetra
.914 .537 .289 r
.2863 .57327 .29338 .57726 .30306 .58645 .29473 .60109 Metetra
.933 .911 .525 r
.29473 .60109 .30306 .58645 .3125 .60122 .30725 .56877 Metetra
.525 .405 .658 r
.30725 .56877 .3125 .60122 .32436 .57768 .31749 .57157 Metetra
.496 0 0 r
.31749 .57157 .32436 .57768 .3364 .54938 .32744 .58072 Metetra
.722 .426 .476 r
.32744 .58072 .3364 .54938 .34471 .58974 .33655 .60726 Metetra
.999 .837 .525 r
.33655 .60726 .34471 .58974 .35443 .60796 .35059 .54297 Metetra
.389 .256 .577 r
.35059 .54297 .35443 .60796 .36295 .65573 .36011 .56477 Metetra
.621 .42 .589 r
.36011 .56477 .36295 .65573 .37641 .598 .37162 .54738 Metetra
0 0 .37 r
.37162 .54738 .37641 .598 .38904 .55365 .38012 .59979 Metetra
.584 .308 .464 r
.38012 .59979 .38904 .55365 .39988 .5517 .39082 .60636 Metetra
0 0 .176 r
.39082 .60636 .39988 .5517 .41202 .51308 .40384 .55125 Metetra
.39 .123 .385 r
.40384 .55125 .41202 .51308 .42177 .54622 .41517 .53927 Metetra
0 .211 .71 r
.41517 .53927 .42177 .54622 .43017 .63913 .42589 .54736 Metetra
.608 .41 .588 r
.42589 .54736 .43017 .63913 .44133 .6457 .43731 .53342 Metetra
.642 .431 .582 r
.43731 .53342 .44133 .6457 .45452 .55948 .44908 .50307 Metetra
.722 .532 0 r
.44908 .50307 .45452 .55948 .46565 .56284 .45823 .60049 Metetra
.554 .267 .434 r
.45823 .60049 .46565 .56284 .47682 .56996 .46964 .60294 Metetra
0 0 .173 r
.46964 .60294 .47682 .56996 .48841 .54919 .48156 .57131 Metetra
.995 .808 .443 r
.48156 .57131 .48841 .54919 .50063 .4353 .49387 .48307 Metetra
.598 .32 .468 r
.49387 .48307 .50063 .4353 .51137 .50979 .50508 .49225 Metetra
0 0 .404 r
.50508 .49225 .51137 .50979 .52274 .52207 .51637 .51782 Metetra
.498 .783 .996 r
.51637 .51782 .52274 .52207 .53422 .51853 .52789 .51651 Metetra
.807 .935 .915 r
.52789 .51651 .53422 .51853 .54567 .50392 .53944 .50792 Metetra
.994 .865 .595 r
.53944 .50792 .54567 .50392 .55729 .50851 .55079 .47143 Metetra
.777 .568 .616 r
.55079 .47143 .55729 .50851 .56976 .56967 .56195 .43408 Metetra
.356 .211 .542 r
.56195 .43408 .56976 .56967 .58191 .58184 .57432 .49104 Metetra
.221 .126 .53 r
.57432 .49104 .58191 .58184 .59391 .57831 .58719 .54908 Metetra
0 0 .386 r
.58719 .54908 .59391 .57831 .60589 .572 .6002 .59109 Metetra
.435 .095 .289 r
.6002 .59109 .60589 .572 .61781 .56216 .61242 .58753 Metetra
.447 .137 .346 r
.61242 .58753 .61781 .56216 .62915 .53341 .62466 .58266 Metetra
0 0 .269 r
.62466 .58266 .62915 .53341 .63956 .48175 .63541 .53142 Metetra
0 0 .208 r
.63541 .53142 .63956 .48175 .6497 .43073 .64547 .46922 Metetra
0 0 .182 r
.64547 .46922 .6497 .43073 .66037 .3994 .65569 .4205 Metetra
0 0 .038 r
.65569 .4205 .66037 .3994 .67147 .38075 .66645 .39051 Metetra
.742 .335 .278 r
.66645 .39051 .67147 .38075 .68301 .37223 .67925 .40598 Metetra
.595 .293 .427 r
.67925 .40598 .68301 .37223 .69514 .37447 .69182 .41343 Metetra
.654 .353 .449 r
.69182 .41343 .69514 .37447 .70843 .39548 .70512 .4314 Metetra
.6 .3 .432 r
.70512 .4314 .70843 .39548 .72142 .40762 .71807 .43991 Metetra
.599 .291 .419 r
.71807 .43991 .72142 .40762 .73469 .4214 .73114 .44785 Metetra
.558 .239 .384 r
.73114 .44785 .73469 .4214 .74814 .43497 .74404 .4511 Metetra
.411 .056 .249 r
.74404 .4511 .74814 .43497 .7615 .44473 .75655 .44724 Metetra
.75655 .44724 .7615 .44473 .77446 .44707 .76911 .44336 Metetra
.654 .881 .982 r
.76911 .44336 .77446 .44707 .78702 .4432 .78166 .43863 Metetra
.864 .886 .85 r
.78166 .43863 .78702 .4432 .79964 .43931 .79366 .42654 Metetra
.817 .7 .736 r
.79366 .42654 .79964 .43931 .81205 .43236 .8053 .41057 Metetra
.754 .597 .683 r
.8053 .41057 .81205 .43236 .82363 .41609 .81682 .39361 Metetra
.753 .593 .678 r
.81682 .39361 .82363 .41609 .83436 .3915 .82825 .37623 Metetra
.815 .672 .706 r
.82825 .37623 .83436 .3915 .84442 .36126 .83954 .35788 Metetra
.832 .379 0 r
.83954 .35788 .84442 .36126 .86115 .3964 .85584 .38884 Metetra
.657 .751 .919 r
.85584 .38884 .86115 .3964 .874 .39239 .86874 .38479 Metetra
.657 .751 .919 r
.86874 .38479 .874 .39239 .88692 .38836 .8817 .38073 Metetra
.914 .517 .139 r
.25928 .56192 .26606 .57099 .27568 .57852 .26759 .58663 Metetra
.379 0 .046 r
.26759 .58663 .27568 .57852 .2863 .57327 .27798 .58561 Metetra
.27798 .58561 .2863 .57327 .29473 .60109 .2894 .57049 Metetra
.524 .41 .666 r
.2894 .57049 .29473 .60109 .30725 .56877 .29961 .5731 Metetra
.85 .489 .369 r
.29961 .5731 .30725 .56877 .31749 .57157 .30845 .59868 Metetra
.825 .812 .327 r
.30845 .59868 .31749 .57157 .32744 .58072 .32183 .55259 Metetra
0 0 .193 r
.32183 .55259 .32744 .58072 .33655 .60726 .33014 .59123 Metetra
.832 .658 .666 r
.33014 .59123 .33655 .60726 .35059 .54297 .34236 .56321 Metetra
.798 .486 .461 r
.34236 .56321 .35059 .54297 .36011 .56477 .3512 .59957 Metetra
.3512 .59957 .36011 .56477 .37162 .54738 .36428 .55301 Metetra
.546 .069 .074 r
.36428 .55301 .37162 .54738 .38012 .59979 .3749 .55647 Metetra
.588 .428 .632 r
.3749 .55647 .38012 .59979 .39082 .60636 .3859 .55305 Metetra
.667 .474 .615 r
.3859 .55305 .39082 .60636 .40384 .55125 .39755 .53384 Metetra
0 0 .246 r
.39755 .53384 .40384 .55125 .41517 .53927 .40752 .5612 Metetra
.291 0 .254 r
.40752 .5612 .41517 .53927 .42589 .54736 .4189 .55138 Metetra
.984 .877 .643 r
.4189 .55138 .42589 .54736 .43731 .53342 .43089 .52007 Metetra
.865 .687 .66 r
.43089 .52007 .43731 .53342 .44908 .50307 .44274 .48916 Metetra
0 .008 .584 r
.44274 .48916 .44908 .50307 .45823 .60049 .45344 .50504 Metetra
.491 .319 .575 r
.45344 .50504 .45823 .60049 .46964 .60294 .46435 .51951 Metetra
.517 .343 .585 r
.46435 .51951 .46964 .60294 .48156 .57131 .47551 .52753 Metetra
.528 .386 .631 r
.47551 .52753 .48156 .57131 .49387 .48307 .48686 .53097 Metetra
.407 .154 .415 r
.48686 .53097 .49387 .48307 .50508 .49225 .49844 .51674 Metetra
.149 0 .225 r
.49844 .51674 .50508 .49225 .51637 .51782 .51001 .49993 Metetra
.647 .558 .74 r
.51001 .49993 .51637 .51782 .52789 .51651 .52152 .49503 Metetra
.624 .52 .715 r
.52152 .49503 .52789 .51651 .53944 .50792 .53308 .49098 Metetra
.723 .606 .727 r
.53308 .49098 .53944 .50792 .55079 .47143 .54464 .48053 Metetra
.988 .869 .516 r
.54464 .48053 .55079 .47143 .56195 .43408 .5559 .43816 Metetra
.99 .888 .603 r
.5559 .43816 .56195 .43408 .57432 .49104 .56707 .40626 Metetra
.222 .129 .532 r
.56707 .40626 .57432 .49104 .58719 .54908 .5795 .45969 Metetra
.083 .027 .489 r
.5795 .45969 .58719 .54908 .6002 .59109 .59281 .53329 Metetra
.196 .135 .557 r
.59281 .53329 .6002 .59109 .61242 .58753 .6059 .57261 Metetra
.418 .469 .806 r
.6059 .57261 .61242 .58753 .62466 .58266 .61841 .57716 Metetra
.637 .803 .962 r
.61841 .57716 .62466 .58266 .63541 .53142 .63078 .57354 Metetra
.38 .125 .396 r
.63078 .57354 .63541 .53142 .64547 .46922 .64279 .5581 Metetra
.246 .063 .425 r
.64279 .5581 .64547 .46922 .65569 .4205 .65322 .5025 Metetra
.188 .018 .405 r
.65322 .5025 .65569 .4205 .66645 .39051 .66317 .44356 Metetra
.257 .048 .393 r
.66317 .44356 .66645 .39051 .67925 .40598 .67399 .41129 Metetra
.99 .868 .519 r
.67399 .41129 .67925 .40598 .69182 .41343 .68432 .37232 Metetra
.26 .209 .609 r
.68432 .37232 .69182 .41343 .70512 .4314 .69789 .39795 Metetra
.373 .308 .654 r
.69789 .39795 .70512 .4314 .71807 .43991 .7111 .41226 Metetra
.296 .28 .672 r
.7111 .41226 .71807 .43991 .73114 .44785 .72459 .42803 Metetra
.199 .27 .712 r
.72459 .42803 .73114 .44785 .74404 .4511 .73821 .44256 Metetra
.017 .345 .824 r
.73821 .44256 .74404 .4511 .75655 .44724 .75162 .45127 Metetra
.207 0 0 r
.75162 .45127 .75655 .44724 .76911 .44336 .76445 .4498 Metetra
.185 0 0 r
.76445 .4498 .76911 .44336 .78166 .43863 .77716 .44588 Metetra
.223 0 0 r
.77716 .44588 .78166 .43863 .79366 .42654 .78993 .44195 Metetra
.111 0 .138 r
.78993 .44195 .79366 .42654 .8053 .41057 .80192 .42822 Metetra
0 0 .082 r
.80192 .42822 .8053 .41057 .81682 .39361 .8129 .40333 Metetra
.784 .796 .304 r
.8129 .40333 .81682 .39361 .82825 .37623 .82303 .37059 Metetra
.977 .804 .602 r
.82303 .37059 .82825 .37623 .83954 .35788 .83265 .33445 Metetra
0 0 .405 r
.83265 .33445 .83954 .35788 .85584 .38884 .85049 .38121 Metetra
.657 .751 .919 r
.85049 .38121 .85584 .38884 .86874 .38479 .86343 .37713 Metetra
.657 .751 .919 r
.86343 .37713 .86874 .38479 .8817 .38073 .87643 .37303 Metetra
.25146 .56517 .25928 .56192 .26759 .58663 .26202 .56078 Metetra
.601 .479 .685 r
.26202 .56078 .26759 .58663 .27798 .58561 .27251 .55786 Metetra
0 0 .364 r
.27251 .55786 .27798 .58561 .2894 .57049 .2807 .58759 Metetra
.73 .831 .378 r
.2807 .58759 .2894 .57049 .29961 .5731 .29298 .56128 Metetra
.865 .691 .664 r
.29298 .56128 .29961 .5731 .30845 .59868 .30549 .53 Metetra
.184 .097 .516 r
.30549 .53 .30845 .59868 .32183 .55259 .31344 .56964 Metetra
.848 .543 .473 r
.31344 .56964 .32183 .55259 .33014 .59123 .32089 .62317 Metetra
.955 .837 .408 r
.32089 .62317 .33014 .59123 .34236 .56321 .33574 .55167 Metetra
.863 .696 .674 r
.33574 .55167 .34236 .56321 .3512 .59957 .34792 .52343 Metetra
.569 .384 .592 r
.34792 .52343 .3512 .59957 .36428 .55301 .35872 .52062 Metetra
.93 .652 .175 r
.35872 .52062 .36428 .55301 .3749 .55647 .36599 .5947 Metetra
.564 .276 .437 r
.36599 .5947 .3749 .55647 .3859 .55305 .37685 .59848 Metetra
.37685 .59848 .3859 .55305 .39755 .53384 .39035 .53858 Metetra
.986 .825 .6 r
.39035 .53858 .39755 .53384 .40752 .5612 .40298 .49365 Metetra
.523 .355 .595 r
.40298 .49365 .40752 .5612 .4189 .55138 .4137 .49886 Metetra
.521 .367 .613 r
.4137 .49886 .4189 .55138 .43089 .52007 .42455 .50339 Metetra
.751 .619 .713 r
.42455 .50339 .43089 .52007 .44274 .48916 .43597 .49017 Metetra
.939 .63 .427 r
.43597 .49017 .44274 .48916 .45344 .50504 .44477 .58786 Metetra
.585 .329 .494 r
.44477 .58786 .45344 .50504 .46435 .51951 .45603 .59909 Metetra
.413 .182 .452 r
.45603 .59909 .46435 .51951 .47551 .52753 .46802 .57617 Metetra
.854 .743 .226 r
.46802 .57617 .47551 .52753 .48686 .53097 .48097 .47473 Metetra
.481 .335 .605 r
.48097 .47473 .48686 .53097 .49844 .51674 .49219 .48463 Metetra
.591 .454 .663 r
.49219 .48463 .49844 .51674 .51001 .49993 .50364 .48174 Metetra
.653 .559 .736 r
.50364 .48174 .51001 .49993 .52152 .49503 .51515 .47635 Metetra
.818 .642 .663 r
.51515 .47635 .52152 .49503 .53308 .49098 .52668 .45047 Metetra
.701 .511 .628 r
.52668 .45047 .53308 .49098 .54464 .48053 .53813 .42952 Metetra
.51 .362 .616 r
.53813 .42952 .54464 .48053 .5559 .43816 .54971 .4355 Metetra
.905 .497 .194 r
.54971 .4355 .5559 .43816 .56707 .40626 .56169 .46721 Metetra
.716 .43 .491 r
.56169 .46721 .56707 .40626 .5795 .45969 .57419 .51366 Metetra
.745 .451 .485 r
.57419 .51366 .5795 .45969 .59281 .53329 .58723 .56642 Metetra
.594 .288 .42 r
.58723 .56642 .59281 .53329 .6059 .57261 .59973 .57397 Metetra
.248 .757 .734 r
.59973 .57397 .6059 .57261 .61841 .57716 .61207 .57032 Metetra
.926 .784 .685 r
.61207 .57032 .61841 .57716 .63078 .57354 .62378 .54306 Metetra
.824 .61 .612 r
.62378 .54306 .63078 .57354 .64279 .5581 .63484 .49965 Metetra
.706 .496 .601 r
.63484 .49965 .64279 .5581 .65322 .5025 .64607 .46739 Metetra
.758 .558 .626 r
.64607 .46739 .65322 .5025 .66317 .44356 .65725 .43806 Metetra
.912 .827 .75 r
.65725 .43806 .66317 .44356 .67399 .41129 .66876 .41927 Metetra
.925 .887 .471 r
.66876 .41927 .67399 .41129 .68432 .37232 .67957 .38712 Metetra
0 0 .063 r
.67957 .38712 .68432 .37232 .69789 .39795 .6911 .37196 Metetra
.695 .542 .675 r
.6911 .37196 .69789 .39795 .7111 .41226 .70275 .35957 Metetra
.499 .355 .617 r
.70275 .35957 .7111 .41226 .72459 .42803 .71561 .36756 Metetra
.501 .349 .607 r
.71561 .36756 .72459 .42803 .73821 .44256 .72866 .37632 Metetra
.531 .366 .602 r
.72866 .37632 .73821 .44256 .75162 .45127 .74157 .3807 Metetra
.562 .385 .599 r
.74157 .3807 .75162 .45127 .76445 .4498 .75419 .37925 Metetra
.575 .394 .599 r
.75419 .37925 .76445 .4498 .77716 .44588 .76668 .37524 Metetra
.575 .394 .599 r
.76668 .37524 .77716 .44588 .78993 .44195 .77923 .37121 Metetra
.579 .397 .599 r
.77923 .37121 .78993 .44195 .80192 .42822 .79175 .3661 Metetra
.591 .411 .606 r
.79175 .3661 .80192 .42822 .8129 .40333 .80418 .35941 Metetra
.62 .451 .632 r
.80418 .35941 .8129 .40333 .82303 .37059 .81646 .35074 Metetra
.725 .593 .709 r
.81646 .35074 .82303 .37059 .83265 .33445 .82842 .33852 Metetra
.874 .445 .179 r
.82842 .33852 .83265 .33445 .85049 .38121 .8451 .37352 Metetra
.657 .751 .919 r
.8451 .37352 .85049 .38121 .86343 .37713 .85808 .3694 Metetra
.657 .751 .919 r
.85808 .3694 .86343 .37713 .87643 .37303 .87112 .36527 Metetra
0 .379 .82 r
.2443 .55921 .25146 .56517 .26202 .56078 .25415 .56414 Metetra
.629 .138 .069 r
.25415 .56414 .26202 .56078 .27251 .55786 .26402 .56993 Metetra
.095 0 0 r
.26402 .56993 .27251 .55786 .2807 .58759 .27497 .56238 Metetra
.625 .498 .688 r
.27497 .56238 .2807 .58759 .29298 .56128 .28574 .55762 Metetra
.513 .804 .998 r
.28574 .55762 .29298 .56128 .30549 .53 .29634 .55599 Metetra
.484 .172 .362 r
.29634 .55599 .30549 .53 .31344 .56964 .30701 .55391 Metetra
.813 .458 0 r
.30701 .55391 .31344 .56964 .32089 .62317 .31591 .58174 Metetra
.758 .553 .619 r
.31591 .58174 .32089 .62317 .33574 .55167 .3288 .54501 Metetra
.787 .308 0 r
.3288 .54501 .33574 .55167 .34792 .52343 .33864 .56071 Metetra
.384 .111 .371 r
.33864 .56071 .34792 .52343 .35872 .52062 .35004 .54957 Metetra
.79 .489 .479 r
.35004 .54957 .35872 .52062 .36599 .5947 .35869 .59471 Metetra
.96 .769 .6 r
.35869 .59471 .36599 .5947 .37685 .59848 .37228 .53909 Metetra
.562 .39 .606 r
.37228 .53909 .37685 .59848 .39035 .53858 .38328 .53798 Metetra
.11 0 0 r
.38328 .53798 .39035 .53858 .40298 .49365 .39425 .5393 Metetra
.234 0 .341 r
.39425 .5393 .40298 .49365 .4137 .49886 .40621 .51467 Metetra
.766 .424 .406 r
.40621 .51467 .4137 .49886 .42455 .50339 .41654 .53781 Metetra
.464 .177 .391 r
.41654 .53781 .42455 .50339 .43597 .49017 .42792 .53275 Metetra
.342 .087 .375 r
.42792 .53275 .43597 .49017 .44477 .58786 .43962 .51623 Metetra
.752 .526 .588 r
.43962 .51623 .44477 .58786 .45603 .59909 .45224 .4563 Metetra
.279 .145 .513 r
.45224 .4563 .45603 .59909 .46802 .57617 .46207 .52729 Metetra
.302 .216 .589 r
.46207 .52729 .46802 .57617 .48097 .47473 .47319 .55071 Metetra
.476 .231 .464 r
.47319 .55071 .48097 .47473 .49219 .48463 .48496 .53891 Metetra
.097 0 .316 r
.48496 .53891 .49219 .48463 .50364 .48174 .49697 .4983 Metetra
.704 .776 .289 r
.49697 .4983 .50364 .48174 .51515 .47635 .50872 .46751 Metetra
.662 .216 0 r
.50872 .46751 .51515 .47635 .52668 .45047 .52026 .48556 Metetra
.485 .197 .401 r
.52026 .48556 .52668 .45047 .53813 .42952 .53196 .48188 Metetra
.352 .113 .405 r
.53196 .48188 .53813 .42952 .54971 .4355 .54361 .46098 Metetra
.54361 .46098 .54971 .4355 .56169 .46721 .55506 .42608 Metetra
.783 .565 .605 r
.55506 .42608 .56169 .46721 .57419 .51366 .56622 .383 Metetra
.346 .203 .539 r
.56622 .383 .57419 .51366 .58723 .56642 .57878 .43853 Metetra
.303 .172 .532 r
.57878 .43853 .58723 .56642 .59973 .57397 .59199 .50239 Metetra
.265 .17 .556 r
.59199 .50239 .59973 .57397 .61207 .57032 .6052 .54305 Metetra
.245 .249 .666 r
.6052 .54305 .61207 .57032 .62378 .54306 .61812 .55956 Metetra
.408 .046 .235 r
.61812 .55956 .62378 .54306 .63484 .49965 .63062 .55604 Metetra
.51 .246 .45 r
.63062 .55604 .63484 .49965 .64607 .46739 .64318 .55231 Metetra
.264 .073 .423 r
.64318 .55231 .64607 .46739 .65725 .43806 .654 .50265 Metetra
.136 0 .367 r
.654 .50265 .65725 .43806 .66876 .41927 .6645 .45204 Metetra
.811 .703 .165 r
.6645 .45204 .66876 .41927 .67957 .38712 .67313 .36791 Metetra
.683 .571 .723 r
.67313 .36791 .67957 .38712 .6911 .37196 .68503 .35976 Metetra
.331 .456 .837 r
.68503 .35976 .6911 .37196 .70275 .35957 .69769 .36539 Metetra
.694 .222 .126 r
.69769 .36539 .70275 .35957 .71561 .36756 .71078 .37622 Metetra
.745 .316 .232 r
.71078 .37622 .71561 .36756 .72866 .37632 .72435 .39202 Metetra
.713 .332 .326 r
.72435 .39202 .72866 .37632 .74157 .3807 .73818 .40849 Metetra
.627 .298 .395 r
.73818 .40849 .74157 .3807 .75419 .37925 .75185 .4196 Metetra
.535 .247 .424 r
.75185 .4196 .75419 .37925 .76668 .37524 .76494 .4205 Metetra
.5 .226 .431 r
.76494 .4205 .76668 .37524 .77923 .37121 .77775 .41649 Metetra
.5 .226 .431 r
.77775 .41649 .77923 .37121 .79175 .3661 .79061 .41246 Metetra
.435 .178 .423 r
.79061 .41246 .79175 .3661 .80418 .35941 .80284 .40038 Metetra
.272 .046 .377 r
.80284 .40038 .80418 .35941 .81646 .35074 .81388 .37519 Metetra
0 0 .154 r
.81388 .37519 .81646 .35074 .82842 .33852 .82387 .34006 Metetra
.835 .367 .066 r
.82387 .34006 .82842 .33852 .8451 .37352 .83966 .36576 Metetra
.657 .751 .919 r
.83966 .36576 .8451 .37352 .85808 .3694 .85268 .36161 Metetra
.657 .751 .919 r
.85268 .36161 .85808 .3694 .87112 .36527 .86577 .35744 Metetra
.557 .57 .822 r
.23763 .54686 .2443 .55921 .25415 .56414 .2479 .54652 Metetra
0 0 .393 r
.2479 .54652 .25415 .56414 .26402 .56993 .2566 .56661 Metetra
.913 .79 .712 r
.2566 .56661 .26402 .56993 .27497 .56238 .26885 .54259 Metetra
.491 .445 .734 r
.26885 .54259 .27497 .56238 .28574 .55762 .27906 .54539 Metetra
.471 .53 .836 r
.27906 .54539 .28574 .55762 .29634 .55599 .28941 .54726 Metetra
.923 .532 .173 r
.28941 .54726 .29634 .55599 .30701 .55391 .2981 .57521 Metetra
.832 .846 .383 r
.2981 .57521 .30701 .55391 .31591 .58174 .31116 .5382 Metetra
.621 .45 .63 r
.31116 .5382 .31591 .58174 .3288 .54501 .32231 .53005 Metetra
.894 .534 .06 r
.32231 .53005 .3288 .54501 .33864 .56071 .33112 .56288 Metetra
.836 .996 .84 r
.33112 .56288 .33864 .56071 .35004 .54957 .34259 .55171 Metetra
.91 .579 .405 r
.34259 .55171 .35004 .54957 .35869 .59471 .35095 .60166 Metetra
.978 .77 .555 r
.35095 .60166 .35869 .59471 .37228 .53909 .36603 .51856 Metetra
.575 .495 .727 r
.36603 .51856 .37228 .53909 .38328 .53798 .377 .51759 Metetra
.736 .59 .692 r
.377 .51759 .38328 .53798 .39425 .5393 .38858 .50334 Metetra
.214 .178 .6 r
.38858 .50334 .39425 .5393 .40621 .51467 .39883 .52376 Metetra
.258 0 0 r
.39883 .52376 .40621 .51467 .41654 .53781 .4101 .52021 Metetra
.411 .423 .762 r
.4101 .52021 .41654 .53781 .42792 .53275 .42115 .52535 Metetra
.944 .584 .272 r
.42115 .52535 .42792 .53275 .43962 .51623 .43121 .57034 Metetra
.23 .009 .358 r
.43121 .57034 .43962 .51623 .45224 .4563 .44346 .54035 Metetra
.133 0 .361 r
.44346 .54035 .45224 .4563 .46207 .52729 .45615 .48273 Metetra
.732 .528 .616 r
.45615 .48273 .46207 .52729 .47319 .55071 .46806 .45196 Metetra
.55 .361 .577 r
.46806 .45196 .47319 .55071 .48496 .53891 .4794 .452 Metetra
.493 .323 .578 r
.4794 .452 .48496 .53891 .49697 .4983 .49069 .4639 Metetra
.555 .424 .656 r
.49069 .4639 .49697 .4983 .50872 .46751 .50221 .46399 Metetra
.623 .861 .988 r
.50221 .46399 .50872 .46751 .52026 .48556 .51383 .46027 Metetra
.776 .593 .652 r
.51383 .46027 .52026 .48556 .53196 .48188 .52549 .43576 Metetra
0 .004 .508 r
.52549 .43576 .53196 .48188 .54361 .46098 .5373 .4765 Metetra
.87 .535 .415 r
.5373 .4765 .54361 .46098 .55506 .42608 .5496 .53316 Metetra
.633 .372 .505 r
.5496 .53316 .55506 .42608 .56622 .383 .56213 .56753 Metetra
.535 .302 .509 r
.56213 .56753 .56622 .383 .57878 .43853 .57445 .56386 Metetra
.487 .256 .489 r
.57445 .56386 .57878 .43853 .59199 .50239 .58656 .54625 Metetra
.58656 .54625 .59199 .50239 .6052 .54305 .59714 .46117 Metetra
.734 .504 .579 r
.59714 .46117 .6052 .54305 .61812 .55956 .60787 .40324 Metetra
.507 .318 .559 r
.60787 .40324 .61812 .55956 .63062 .55604 .62044 .41949 Metetra
.497 .314 .563 r
.62044 .41949 .63062 .55604 .64318 .55231 .63326 .43717 Metetra
.562 .367 .574 r
.63326 .43717 .64318 .55231 .654 .50265 .64549 .43328 Metetra
.573 .392 .598 r
.64549 .43328 .654 .50265 .6645 .45204 .65778 .42938 Metetra
.735 .582 .684 r
.65778 .42938 .6645 .45204 .67313 .36791 .66961 .4141 Metetra
.341 .1 .396 r
.66961 .4141 .67313 .36791 .68503 .35976 .68116 .39372 Metetra
0 0 .151 r
.68116 .39372 .68503 .35976 .69769 .36539 .69131 .34796 Metetra
.802 .646 .689 r
.69131 .34796 .69769 .36539 .71078 .37622 .70267 .32844 Metetra
.47 .341 .623 r
.70267 .32844 .71078 .37622 .72435 .39202 .71574 .33853 Metetra
.342 .246 .599 r
.71574 .33853 .72435 .39202 .73818 .40849 .72996 .36382 Metetra
.291 .226 .609 r
.72996 .36382 .73818 .40849 .75185 .4196 .74448 .3893 Metetra
.247 .239 .652 r
.74448 .3893 .75185 .4196 .76494 .4205 .75888 .40901 Metetra
.084 .321 .799 r
.75888 .40901 .76494 .4205 .77775 .41649 .77282 .41943 Metetra
.77282 .41943 .77775 .41649 .79061 .41246 .78581 .41585 Metetra
.78581 .41585 .79061 .41246 .80284 .40038 .79882 .41178 Metetra
.33 0 .108 r
.79882 .41178 .80284 .40038 .81388 .37519 .81189 .40769 Metetra
.294 .04 .347 r
.81189 .40769 .81388 .37519 .82387 .34006 .82371 .38951 Metetra
.502 .232 .437 r
.82371 .38951 .82387 .34006 .83966 .36576 .83684 .38537 Metetra
0 0 .114 r
.83684 .38537 .83966 .36576 .85268 .36161 .84761 .35738 Metetra
.765 .909 .938 r
.84761 .35738 .85268 .36161 .86577 .35744 .86037 .34955 Metetra
.22857 .5615 .23763 .54686 .2479 .54652 .24011 .54698 Metetra
.196 0 0 r
.24011 .54698 .2479 .54652 .2566 .56661 .25035 .54807 Metetra
.622 .534 .735 r
.25035 .54807 .2566 .56661 .26885 .54259 .26102 .54466 Metetra
.868 .501 .35 r
.26102 .54466 .26885 .54259 .27906 .54539 .2695 .5709 Metetra
.714 .773 .281 r
.2695 .5709 .27906 .54539 .28941 .54726 .28276 .53402 Metetra
.639 .599 .794 r
.28276 .53402 .28941 .54726 .2981 .57521 .29355 .53057 Metetra
.406 .291 .609 r
.29355 .53057 .2981 .57521 .31116 .5382 .30332 .5433 Metetra
.689 .241 .184 r
.30332 .5433 .31116 .5382 .32231 .53005 .31349 .55187 Metetra
.794 .481 .46 r
.31349 .55187 .32231 .53005 .33112 .56288 .32208 .58903 Metetra
.968 .851 .443 r
.32208 .58903 .33112 .56288 .34259 .55171 .33664 .52568 Metetra
.631 .5 .685 r
.33664 .52568 .34259 .55171 .35095 .60166 .34779 .52003 Metetra
.654 .447 .591 r
.34779 .52003 .35095 .60166 .36603 .51856 .35999 .49408 Metetra
0 .035 .569 r
.35999 .49408 .36603 .51856 .377 .51759 .36992 .51465 Metetra
.718 .891 .959 r
.36992 .51465 .377 .51759 .38858 .50334 .38119 .50906 Metetra
.895 .562 .409 r
.38119 .50906 .38858 .50334 .39883 .52376 .39028 .55883 Metetra
.708 .405 .462 r
.39028 .55883 .39883 .52376 .4101 .52021 .40063 .58523 Metetra
0 0 .263 r
.40063 .58523 .4101 .52021 .42115 .52535 .41392 .53054 Metetra
.989 .876 .621 r
.41392 .53054 .42115 .52535 .43121 .57034 .42631 .49595 Metetra
.458 .301 .58 r
.42631 .49595 .43121 .57034 .44346 .54035 .43723 .51116 Metetra
.667 .514 .667 r
.43723 .51116 .44346 .54035 .45615 .48273 .44891 .50083 Metetra
.998 .818 .472 r
.44891 .50083 .45615 .48273 .46806 .45196 .46188 .42375 Metetra
.894 .602 .095 r
.46188 .42375 .46806 .45196 .4794 .452 .47207 .49281 Metetra
.53 .244 .425 r
.47207 .49281 .4794 .452 .49069 .4639 .48367 .49336 Metetra
.363 .072 .33 r
.48367 .49336 .49069 .4639 .50221 .46399 .49544 .48342 Metetra
.921 .835 .381 r
.49544 .48342 .50221 .46399 .51383 .46027 .50743 .43194 Metetra
0 0 .245 r
.50743 .43194 .51383 .46027 .52549 .43576 .51897 .47727 Metetra
.831 .527 .476 r
.51897 .47727 .52549 .43576 .5373 .4765 .53098 .56316 Metetra
.54 .287 .481 r
.53098 .56316 .5373 .4765 .5496 .53316 .54323 .5643 Metetra
.236 0 .293 r
.54323 .5643 .5496 .53316 .56213 .56753 .5554 .54671 Metetra
.892 .67 .595 r
.5554 .54671 .56213 .56753 .57445 .56386 .56702 .48962 Metetra
.739 .511 .583 r
.56702 .48962 .57445 .56386 .58656 .54625 .57834 .43474 Metetra
.657 .437 .574 r
.57834 .43474 .58656 .54625 .59714 .46117 .58967 .39664 Metetra
.387 .261 .585 r
.58967 .39664 .59714 .46117 .60787 .40324 .60226 .41969 Metetra
.728 .36 .354 r
.60226 .41969 .60787 .40324 .62044 .41949 .61497 .43809 Metetra
.414 .067 .265 r
.61497 .43809 .62044 .41949 .63326 .43717 .6272 .43419 Metetra
.758 .924 .944 r
.6272 .43419 .63326 .43717 .64549 .43328 .63937 .42683 Metetra
.889 .815 .769 r
.63937 .42683 .64549 .43328 .65778 .42938 .65119 .40994 Metetra
.877 .669 .617 r
.65119 .40994 .65778 .42938 .66961 .4141 .66193 .3688 Metetra
.689 .495 .618 r
.66193 .3688 .66961 .4141 .68116 .39372 .67336 .3476 Metetra
.652 .467 .622 r
.67336 .3476 .68116 .39372 .69131 .34796 .68506 .33317 Metetra
.113 .273 .749 r
.68506 .33317 .69131 .34796 .70267 .32844 .69818 .3453 Metetra
.712 .337 .337 r
.69818 .3453 .70267 .32844 .71574 .33853 .71177 .36233 Metetra
.696 .348 .382 r
.71177 .36233 .71574 .33853 .72996 .36382 .7257 .38111 Metetra
.707 .331 .333 r
.7257 .38111 .72996 .36382 .74448 .3893 .73974 .39801 Metetra
.671 .222 .177 r
.73974 .39801 .74448 .3893 .75888 .40901 .75357 .40858 Metetra
.083 .642 .777 r
.75357 .40858 .75888 .40901 .77282 .41943 .76674 .40814 Metetra
.649 .662 .849 r
.76674 .40814 .77282 .41943 .78581 .41585 .77972 .40405 Metetra
.647 .652 .841 r
.77972 .40405 .78581 .41585 .79882 .41178 .79276 .39995 Metetra
.812 .72 .764 r
.79276 .39995 .79882 .41178 .81189 .40769 .80498 .38578 Metetra
.814 .631 .656 r
.80498 .38578 .81189 .40769 .82371 .38951 .81611 .35997 Metetra
.603 .476 .68 r
.81611 .35997 .82371 .38951 .83684 .38537 .82918 .35578 Metetra
.659 .511 .671 r
.82918 .35578 .83684 .38537 .84761 .35738 .84175 .34583 Metetra
.65 .66 .846 r
.84175 .34583 .84761 .35738 .86037 .34955 .85492 .34159 Metetra
.434 .355 .669 r
.22321 .53316 .22857 .5615 .24011 .54698 .2329 .53976 Metetra
.7 .738 .88 r
.2329 .53976 .24011 .54698 .25035 .54807 .24365 .53491 Metetra
.905 .531 .085 r
.24365 .53491 .25035 .54807 .26102 .54466 .25176 .56327 Metetra
.789 .855 .406 r
.25176 .56327 .26102 .54466 .2695 .5709 .26461 .5336 Metetra
.589 .438 .644 r
.26461 .5336 .2695 .5709 .28276 .53402 .27539 .53013 Metetra
.697 .159 0 r
.27539 .53013 .28276 .53402 .29355 .53057 .28523 .5404 Metetra
.831 .491 .412 r
.28523 .5404 .29355 .53057 .30332 .5433 .29383 .5709 Metetra
.941 .852 .421 r
.29383 .5709 .30332 .5433 .31349 .55187 .30844 .5127 Metetra
.423 .316 .627 r
.30844 .5127 .31349 .55187 .32208 .58903 .31854 .52275 Metetra
.615 .424 .6 r
.31854 .52275 .32208 .58903 .33664 .52568 .33006 .51069 Metetra
.96 .626 .258 r
.33006 .51069 .33664 .52568 .34779 .52003 .33812 .5613 Metetra
.595 .305 .446 r
.33812 .5613 .34779 .52003 .35999 .49408 .34876 .56984 Metetra
0 0 .267 r
.34876 .56984 .35999 .49408 .36992 .51465 .36292 .50858 Metetra
.595 .755 .954 r
.36292 .50858 .36992 .51465 .38119 .50906 .37407 .5063 Metetra
.593 .872 .993 r
.37407 .5063 .38119 .50906 .39028 .55883 .38532 .50288 Metetra
.605 .425 .611 r
.38532 .50288 .39028 .55883 .40063 .58523 .39682 .49449 Metetra
.682 .465 .585 r
.39682 .49449 .40063 .58523 .41392 .53054 .40944 .45443 Metetra
0 0 .13 r
.40944 .45443 .41392 .53054 .42631 .49595 .41712 .56344 Metetra
.56 .294 .471 r
.41712 .56344 .42631 .49595 .43723 .51116 .42857 .56864 Metetra
.189 0 .344 r
.42857 .56864 .43723 .51116 .44891 .50083 .44112 .53424 Metetra
.976 .805 .388 r
.44112 .53424 .44891 .50083 .46188 .42375 .45492 .43372 Metetra
.855 .504 .387 r
.45492 .43372 .46188 .42375 .47207 .49281 .46562 .47124 Metetra
.412 .39 .725 r
.46562 .47124 .47207 .49281 .48367 .49336 .4771 .47757 Metetra
.632 .574 .772 r
.4771 .47757 .48367 .49336 .49544 .48342 .48882 .47383 Metetra
.711 .705 .843 r
.48882 .47383 .49544 .48342 .50743 .43194 .5006 .46765 Metetra
.133 0 .274 r
.5006 .46765 .50743 .43194 .51897 .47727 .51249 .44292 Metetra
.831 .607 .599 r
.51249 .44292 .51897 .47727 .53098 .56316 .52428 .38936 Metetra
.412 .242 .538 r
.52428 .38936 .53098 .56316 .54323 .5643 .53612 .43883 Metetra
.291 .161 .525 r
.53612 .43883 .54323 .5643 .5554 .54671 .54848 .50049 Metetra
0 0 .452 r
.54848 .50049 .5554 .54671 .56702 .48962 .56124 .54964 Metetra
.508 .244 .449 r
.56124 .54964 .56702 .48962 .57834 .43474 .57369 .54616 Metetra
.524 .28 .487 r
.57369 .54616 .57834 .43474 .58967 .39664 .58619 .54239 Metetra
.371 .167 .468 r
.58619 .54239 .58967 .39664 .60226 .41969 .59761 .48702 Metetra
0 0 .277 r
.59761 .48702 .60226 .41969 .61497 .43809 .60835 .41805 Metetra
.889 .67 .601 r
.60835 .41805 .61497 .43809 .6272 .43419 .61923 .36872 Metetra
.69 .477 .593 r
.61923 .36872 .6272 .43419 .63937 .42683 .63042 .33727 Metetra
.414 .265 .568 r
.63042 .33727 .63937 .42683 .65119 .40994 .64363 .36465 Metetra
.383 .284 .618 r
.64363 .36465 .65119 .40994 .66193 .3688 .65672 .38156 Metetra
.805 .421 .329 r
.65672 .38156 .66193 .3688 .67336 .3476 .67051 .40933 Metetra
.55 .28 .459 r
.67051 .40933 .67336 .3476 .68506 .33317 .68342 .41303 Metetra
.53 .275 .473 r
.68342 .41303 .68506 .33317 .69818 .3453 .69622 .41226 Metetra
.516 .256 .459 r
.69622 .41226 .69818 .3453 .71177 .36233 .70898 .40932 Metetra
.497 .222 .427 r
.70898 .40932 .71177 .36233 .7257 .38111 .72175 .40555 Metetra
.445 .124 .326 r
.72175 .40555 .7257 .38111 .73974 .39801 .73457 .40148 Metetra
.73457 .40148 .73974 .39801 .75357 .40858 .74744 .39738 Metetra
.677 .677 .842 r
.74744 .39738 .75357 .40858 .76674 .40814 .76028 .39208 Metetra
.71 .623 .758 r
.76028 .39208 .76674 .40814 .77972 .40405 .7729 .38315 Metetra
.742 .6 .699 r
.7729 .38315 .77972 .40405 .79276 .39995 .78506 .36846 Metetra
.735 .551 .644 r
.78506 .36846 .79276 .39995 .80498 .38578 .79664 .34724 Metetra
.736 .535 .621 r
.79664 .34724 .80498 .38578 .81611 .35997 .80766 .32071 Metetra
.313 .256 .632 r
.80766 .32071 .81611 .35997 .82918 .35578 .82306 .34209 Metetra
.643 .62 .812 r
.82306 .34209 .82918 .35578 .84175 .34583 .83621 .33784 Metetra
.657 .751 .919 r
.83621 .33784 .84175 .34583 .85492 .34159 .84943 .33356 Metetra
.345 0 .155 r
.21397 .54729 .22321 .53316 .2329 .53976 .22464 .54365 Metetra
.76 .334 .239 r
.22464 .54365 .2329 .53976 .24365 .53491 .23398 .55588 Metetra
.369 .032 .257 r
.23398 .55588 .24365 .53491 .25176 .56327 .24493 .55043 Metetra
.69 .63 .784 r
.24493 .55043 .25176 .56327 .26461 .5336 .25596 .54438 Metetra
.731 .36 .348 r
.25596 .54438 .26461 .5336 .27539 .53013 .26547 .55848 Metetra
0 0 .087 r
.26547 .55848 .27539 .53013 .28523 .5404 .27787 .53539 Metetra
.823 .345 0 r
.27787 .53539 .28523 .5404 .29383 .5709 .28747 .55099 Metetra
.674 .558 .716 r
.28747 .55099 .29383 .5709 .30844 .5127 .29879 .5435 Metetra
.702 .396 .455 r
.29879 .5435 .30844 .5127 .31854 .52275 .30821 .56593 Metetra
.718 .714 .185 r
.30821 .56593 .31854 .52275 .33006 .51069 .32307 .50238 Metetra
.953 .621 .348 r
.32307 .50238 .33006 .51069 .33812 .5613 .3308 .5568 Metetra
.918 .786 .701 r
.3308 .5568 .33812 .5613 .34876 .56984 .34332 .53076 Metetra
.298 .229 .609 r
.34332 .53076 .34876 .56984 .36292 .50858 .35354 .54791 Metetra
.63 .334 .449 r
.35354 .54791 .36292 .50858 .37407 .5063 .36412 .56157 Metetra
0 0 .089 r
.36412 .56157 .37407 .5063 .38532 .50288 .37813 .50099 Metetra
.906 .52 .276 r
.37813 .50099 .38532 .50288 .39682 .49449 .38806 .53227 Metetra
.56 .264 .422 r
.38806 .53227 .39682 .49449 .40944 .45443 .3993 .53638 Metetra
.464 .219 .457 r
.3993 .53638 .40944 .45443 .41712 .56344 .41121 .5233 Metetra
.855 .619 .581 r
.41121 .5233 .41712 .56344 .42857 .56864 .42529 .439 Metetra
0 0 .413 r
.42529 .439 .42857 .56864 .44112 .53424 .43372 .54486 Metetra
.646 .235 .252 r
.43372 .54486 .44112 .53424 .45492 .43372 .44525 .5531 Metetra
.43 .204 .468 r
.44525 .5531 .45492 .43372 .46562 .47124 .45766 .52452 Metetra
.916 .765 .279 r
.45766 .52452 .46562 .47124 .4771 .47757 .47157 .39822 Metetra
.143 .066 .503 r
.47157 .39822 .4771 .47757 .48882 .47383 .48232 .45107 Metetra
.919 .603 .129 r
.48232 .45107 .48882 .47383 .5006 .46765 .49341 .51717 Metetra
.509 .234 .432 r
.49341 .51717 .5006 .46765 .51249 .44292 .50544 .51506 Metetra
.457 .209 .449 r
.50544 .51506 .51249 .44292 .52428 .38936 .51757 .50217 Metetra
.088 0 .366 r
.51757 .50217 .52428 .38936 .53612 .43883 .52957 .41619 Metetra
.877 .656 .6 r
.52957 .41619 .53612 .43883 .54848 .50049 .5412 .36327 Metetra
.319 .178 .527 r
.5412 .36327 .54848 .50049 .56124 .54964 .55352 .42407 Metetra
.273 .148 .521 r
.55352 .42407 .56124 .54964 .57369 .54616 .56642 .48925 Metetra
.082 .053 .523 r
.56642 .48925 .57369 .54616 .58619 .54239 .57956 .53413 Metetra
.609 .715 .92 r
.57956 .53413 .58619 .54239 .59761 .48702 .59218 .53144 Metetra
.49 .209 .415 r
.59218 .53144 .59761 .48702 .60835 .41805 .60483 .52761 Metetra
.298 .102 .437 r
.60483 .52761 .60835 .41805 .61923 .36872 .61613 .47278 Metetra
.11 0 .381 r
.61613 .47278 .61923 .36872 .63042 .33727 .62625 .3912 Metetra
.118 0 .336 r
.62625 .3912 .63042 .33727 .64363 .36465 .63723 .34942 Metetra
.929 .702 .574 r
.63723 .34942 .64363 .36465 .65672 .38156 .64734 .29145 Metetra
.346 .216 .557 r
.64734 .29145 .65672 .38156 .67051 .40933 .66126 .33011 Metetra
.338 .217 .565 r
.66126 .33011 .67051 .40933 .68342 .41303 .67542 .36556 Metetra
.132 .109 .563 r
.67542 .36556 .68342 .41303 .69622 .41226 .69003 .4027 Metetra
.779 .363 0 r
.69003 .4027 .69622 .41226 .70898 .40932 .70474 .43438 Metetra
.706 .356 .382 r
.70474 .43438 .70898 .40932 .72175 .40555 .71917 .45567 Metetra
.578 .289 .441 r
.71917 .45567 .72175 .40555 .73457 .40148 .73306 .46414 Metetra
.506 .242 .449 r
.73306 .46414 .73457 .40148 .74744 .39738 .74627 .46008 Metetra
.506 .242 .449 r
.74627 .46008 .74744 .39738 .76028 .39208 .75953 .456 Metetra
.498 .237 .449 r
.75953 .456 .76028 .39208 .7729 .38315 .77276 .45052 Metetra
.413 .175 .441 r
.77276 .45052 .7729 .38315 .78506 .36846 .78486 .43027 Metetra
.285 .076 .41 r
.78486 .43027 .78506 .36846 .79664 .34724 .79564 .39519 Metetra
.053 0 .325 r
.79564 .39519 .79664 .34724 .80766 .32071 .80517 .3483 Metetra
.454 .143 .347 r
.80517 .3483 .80766 .32071 .82306 .34209 .81835 .34403 Metetra
.775 .974 .693 r
.81835 .34403 .82306 .34209 .83621 .33784 .83063 .32978 Metetra
.657 .751 .919 r
.83063 .32978 .83621 .33784 .84943 .33356 .84389 .32546 Metetra
0 0 .515 r
.20804 .52482 .21397 .54729 .22464 .54365 .21659 .54404 Metetra
.919 .902 .791 r
.21659 .54404 .22464 .54365 .23398 .55588 .22846 .52784 Metetra
.533 .426 .678 r
.22846 .52784 .23398 .55588 .24493 .55043 .2388 .52904 Metetra
.215 .255 .689 r
.2388 .52904 .24493 .55043 .25596 .54438 .24843 .53981 Metetra
.908 .776 .704 r
.24843 .53981 .25596 .54438 .26547 .55848 .26105 .51444 Metetra
.596 .43 .628 r
.26105 .51444 .26547 .55848 .27787 .53539 .27205 .50922 Metetra
.982 .695 .385 r
.27205 .50922 .27787 .53539 .28747 .55099 .27497 .61554 Metetra
.789 .732 .205 r
.27497 .61554 .28747 .55099 .29879 .5435 .29289 .51687 Metetra
.555 .448 .688 r
.29289 .51687 .29879 .5435 .30821 .56593 .30371 .5167 Metetra
.703 .503 .615 r
.30371 .5167 .30821 .56593 .32307 .50238 .31624 .49054 Metetra
.964 .652 .378 r
.31624 .49054 .32307 .50238 .3308 .5568 .32262 .56563 Metetra
.988 .894 .608 r
.32262 .56563 .3308 .5568 .34332 .53076 .33581 .53 Metetra
.958 .754 .585 r
.33581 .53 .34332 .53076 .35354 .54791 .35047 .46355 Metetra
.553 .365 .581 r
.35047 .46355 .35354 .54791 .36412 .56157 .36152 .46214 Metetra
.374 .222 .544 r
.36152 .46214 .36412 .56157 .37813 .50099 .37108 .4943 Metetra
.948 .602 .323 r
.37108 .4943 .37813 .50099 .38806 .53227 .3801 .54576 Metetra
.999 .818 .525 r
.3801 .54576 .38806 .53227 .3993 .53638 .39434 .47585 Metetra
.427 .288 .588 r
.39434 .47585 .3993 .53638 .41121 .5233 .40512 .49082 Metetra
.066 .091 .576 r
.40512 .49082 .41121 .5233 .42529 .439 .41579 .51423 Metetra
.42 .178 .438 r
.41579 .51423 .42529 .439 .43372 .54486 .42792 .49609 Metetra
.822 .588 .585 r
.42792 .49609 .43372 .54486 .44525 .5531 .4414 .42313 Metetra
0 0 .405 r
.4414 .42313 .44525 .5531 .45766 .52452 .45038 .5334 Metetra
.462 .008 .086 r
.45038 .5334 .45766 .52452 .47157 .39822 .46226 .53458 Metetra
.442 .216 .474 r
.46226 .53458 .47157 .39822 .48232 .45107 .47468 .50519 Metetra
.47468 .50519 .48232 .45107 .49341 .51717 .48765 .41671 Metetra
.56 .366 .574 r
.48765 .41671 .49341 .51717 .50544 .51506 .49939 .41283 Metetra
.602 .397 .576 r
.49939 .41283 .50544 .51506 .51757 .50217 .51124 .39665 Metetra
.559 .364 .572 r
.51124 .39665 .51757 .50217 .52957 .41619 .52304 .39273 Metetra
.732 .575 .679 r
.52304 .39273 .52957 .41619 .5412 .36327 .53485 .37729 Metetra
.884 .546 .403 r
.53485 .37729 .5412 .36327 .55352 .42407 .54716 .43862 Metetra
.807 .443 .368 r
.54716 .43862 .55352 .42407 .56642 .48925 .55968 .46927 Metetra
.587 .517 .743 r
.55968 .46927 .56642 .48925 .57956 .53413 .57205 .46729 Metetra
.375 .25 .58 r
.57205 .46729 .57956 .53413 .59218 .53144 .58496 .49148 Metetra
.138 .127 .582 r
.58496 .49148 .59218 .53144 .60483 .52761 .59824 .52035 Metetra
.646 .762 .934 r
.59824 .52035 .60483 .52761 .61613 .47278 .61099 .51647 Metetra
.194 0 .328 r
.61099 .51647 .61613 .47278 .62625 .3912 .62308 .48827 Metetra
.248 .059 .417 r
.62308 .48827 .62625 .3912 .63723 .34942 .63409 .43187 Metetra
0 0 .244 r
.63409 .43187 .63723 .34942 .64734 .29145 .64312 .332 Metetra
.39 .124 .384 r
.64312 .332 .64734 .29145 .66126 .33011 .65506 .31939 Metetra
.587 .638 .868 r
.65506 .31939 .66126 .33011 .67542 .36556 .66749 .31759 Metetra
.556 .399 .623 r
.66749 .31759 .67542 .36556 .69003 .4027 .68003 .31673 Metetra
.506 .333 .58 r
.68003 .31673 .69003 .4027 .70474 .43438 .69317 .3254 Metetra
.465 .295 .566 r
.69317 .3254 .70474 .43438 .71917 .45567 .70718 .34654 Metetra
.442 .279 .564 r
.70718 .34654 .71917 .45567 .73306 .46414 .7218 .37328 Metetra
.457 .297 .576 r
.7218 .37328 .73306 .46414 .74627 .46008 .73627 .39295 Metetra
.544 .373 .599 r
.73627 .39295 .74627 .46008 .75953 .456 .74967 .39367 Metetra
.572 .396 .605 r
.74967 .39367 .75953 .456 .77276 .45052 .76282 .38949 Metetra
.573 .398 .606 r
.76282 .38949 .77276 .45052 .78486 .43027 .77602 .38528 Metetra
.706 .506 .616 r
.77602 .38528 .78486 .43027 .79564 .39519 .78762 .36088 Metetra
.832 .602 .592 r
.78762 .36088 .79564 .39519 .80517 .3483 .79717 .31419 Metetra
.406 .333 .661 r
.79717 .31419 .80517 .3483 .81835 .34403 .81175 .32598 Metetra
.629 .562 .761 r
.81175 .32598 .81835 .34403 .83063 .32978 .825 .32165 Metetra
.657 .751 .919 r
.825 .32165 .83063 .32978 .84389 .32546 .8383 .3173 Metetra
.086 0 0 r
.19933 .53114 .20804 .52482 .21659 .54404 .21002 .52766 Metetra
0 .145 .673 r
.21002 .52766 .21659 .54404 .22846 .52784 .21937 .53944 Metetra
.21937 .53944 .22846 .52784 .2388 .52904 .23065 .53074 Metetra
.316 .803 .782 r
.23065 .53074 .2388 .52904 .24843 .53981 .24151 .52723 Metetra
.632 .238 0 r
.24151 .52723 .24843 .53981 .26105 .51444 .25073 .54426 Metetra
.25073 .54426 .26105 .51444 .27205 .50922 .26434 .50754 Metetra
.874 .461 .234 r
.26434 .50754 .27205 .50922 .27497 .61554 .27342 .52892 Metetra
.614 .412 .585 r
.27342 .52892 .27497 .61554 .29289 .51687 .2854 .51277 Metetra
.924 .559 .312 r
.2854 .51277 .29289 .51687 .30371 .5167 .29382 .54807 Metetra
.943 .842 .406 r
.29382 .54807 .30371 .5167 .31624 .49054 .30919 .48142 Metetra
.95 .598 .289 r
.30919 .48142 .31624 .49054 .32262 .56563 .31739 .52457 Metetra
.638 .467 .634 r
.31739 .52457 .32262 .56563 .33581 .53 .3291 .51407 Metetra
.336 .402 .783 r
.3291 .51407 .33581 .53 .35047 .46355 .3399 .51994 Metetra
.678 .394 .484 r
.3399 .51994 .35047 .46355 .36152 .46214 .34953 .55038 Metetra
.16 0 .355 r
.34953 .55038 .36152 .46214 .37108 .4943 .36348 .49771 Metetra
.697 .216 .103 r
.36348 .49771 .37108 .4943 .3801 .54576 .37434 .50713 Metetra
.436 .329 .635 r
.37434 .50713 .3801 .54576 .39434 .47585 .38536 .51606 Metetra
.398 .12 .371 r
.38536 .51606 .39434 .47585 .40512 .49082 .39725 .50579 Metetra
.998 .798 .506 r
.39725 .50579 .40512 .49082 .41579 .51423 .41182 .41905 Metetra
0 0 .28 r
.41182 .41905 .41579 .51423 .42792 .49609 .41979 .52539 Metetra
.665 .344 .419 r
.41979 .52539 .42792 .49609 .4414 .42313 .4311 .54163 Metetra
.449 .217 .468 r
.4311 .54163 .4414 .42313 .45038 .5334 .44354 .51901 Metetra
.942 .697 .538 r
.44354 .51901 .45038 .5334 .46226 .53458 .45802 .39468 Metetra
.436 .261 .544 r
.45802 .39468 .46226 .53458 .47468 .50519 .46901 .42601 Metetra
0 0 .424 r
.46901 .42601 .47468 .50519 .48765 .41671 .47976 .4972 Metetra
.539 .279 .47 r
.47976 .4972 .48765 .41671 .49939 .41283 .4918 .49945 Metetra
.487 .238 .463 r
.4918 .49945 .49939 .41283 .51124 .39665 .504 .49033 Metetra
.002 0 .317 r
.504 .49033 .51124 .39665 .52304 .39273 .51641 .4112 Metetra
.98 .822 .419 r
.51641 .4112 .52304 .39273 .53485 .37729 .52832 .34206 Metetra
0 0 .341 r
.52832 .34206 .53485 .37729 .54716 .43862 .54036 .38983 Metetra
0 0 .317 r
.54036 .38983 .54716 .43862 .55968 .46927 .55299 .45545 Metetra
.931 .576 .15 r
.55299 .45545 .55968 .46927 .57205 .46729 .56612 .51445 Metetra
.539 .252 .427 r
.56612 .51445 .57205 .46729 .58496 .49148 .57887 .51693 Metetra
.44 .115 .317 r
.57887 .51693 .58496 .49148 .59824 .52035 .5916 .51303 Metetra
.962 .752 .574 r
.5916 .51303 .59824 .52035 .61099 .51647 .60313 .45649 Metetra
.816 .571 .568 r
.60313 .45649 .61099 .51647 .62308 .48827 .61368 .37684 Metetra
.649 .428 .57 r
.61368 .37684 .62308 .48827 .63409 .43187 .62507 .34107 Metetra
.703 .473 .573 r
.62507 .34107 .63409 .43187 .64312 .332 .63579 .29173 Metetra
.185 .157 .591 r
.63579 .29173 .64312 .332 .65506 .31939 .64924 .31902 Metetra
.882 .451 .146 r
.64924 .31902 .65506 .31939 .66749 .31759 .66318 .35043 Metetra
.738 .406 .42 r
.66318 .35043 .66749 .31759 .68003 .31673 .67753 .38334 Metetra
.648 .359 .467 r
.67753 .38334 .68003 .31673 .69317 .3254 .69199 .41162 Metetra
.597 .326 .477 r
.69199 .41162 .69317 .3254 .70718 .34654 .70625 .43025 Metetra
.555 .291 .471 r
.70625 .43025 .70718 .34654 .7218 .37328 .72002 .43675 Metetra
.502 .237 .445 r
.72002 .43675 .7218 .37328 .73627 .39295 .73327 .43261 Metetra
.478 .188 .394 r
.73327 .43261 .73627 .39295 .74967 .39367 .74657 .42845 Metetra
.447 .153 .371 r
.74657 .42845 .74967 .39367 .76282 .38949 .7598 .42236 Metetra
.263 .004 .32 r
.7598 .42236 .76282 .38949 .77602 .38528 .77211 .40356 Metetra
.77211 .40356 .77602 .38528 .78762 .36088 .78335 .37236 Metetra
.83 .795 .298 r
.78335 .37236 .78762 .36088 .79717 .31419 .79361 .33162 Metetra
.39 .03 .229 r
.79361 .33162 .79717 .31419 .81175 .32598 .80688 .32728 Metetra
.795 .988 .734 r
.80688 .32728 .81175 .32598 .825 .32165 .81931 .31345 Metetra
.657 .751 .919 r
.81931 .31345 .825 .32165 .8383 .3173 .83266 .30906 Metetra
.46 .431 .739 r
.19307 .5116 .19933 .53114 .21002 .52766 .20309 .51493 Metetra
.829 .432 0 r
.20309 .51493 .21002 .52766 .21937 .53944 .21146 .53677 Metetra
.935 .753 .631 r
.21146 .53677 .21937 .53944 .23065 .53074 .22632 .48895 Metetra
0 0 .316 r
.22632 .48895 .23065 .53074 .24151 .52723 .23323 .52984 Metetra
.885 .983 .821 r
.23323 .52984 .24151 .52723 .25073 .54426 .245 .51659 Metetra
.536 .431 .682 r
.245 .51659 .25073 .54426 .26434 .50754 .25562 .5174 Metetra
.815 .465 .394 r
.25562 .5174 .26434 .50754 .27342 .52892 .26432 .54385 Metetra
.998 .839 .556 r
.26432 .54385 .27342 .52892 .2854 .51277 .2797 .48366 Metetra
0 .023 .546 r
.2797 .48366 .2854 .51277 .29382 .54807 .28893 .50549 Metetra
.296 .216 .594 r
.28893 .50549 .29382 .54807 .30919 .48142 .29866 .52322 Metetra
.274 .012 .322 r
.29866 .52322 .30919 .48142 .31739 .52457 .31086 .50535 Metetra
.891 .671 .599 r
.31086 .50535 .31739 .52457 .3291 .51407 .32601 .43845 Metetra
0 0 .187 r
.32601 .43845 .3291 .51407 .3399 .51994 .33174 .52839 Metetra
.792 .411 .334 r
.33174 .52839 .3399 .51994 .34953 .55038 .34192 .54881 Metetra
.958 .772 .61 r
.34192 .54881 .34953 .55038 .36348 .49771 .35593 .49797 Metetra
.965 .754 .567 r
.35593 .49797 .36348 .49771 .37434 .50713 .37084 .42261 Metetra
.465 .297 .568 r
.37084 .42261 .37434 .50713 .38536 .51606 .38138 .4365 Metetra
0 0 .409 r
.38138 .4365 .38536 .51606 .39725 .50579 .38992 .50379 Metetra
0 .554 .802 r
.38992 .50379 .39725 .50579 .41182 .41905 .40144 .50541 Metetra
.48 .23 .458 r
.40144 .50541 .41182 .41905 .41979 .52539 .41343 .49553 Metetra
.871 .64 .587 r
.41343 .49553 .41979 .52539 .4311 .54163 .42729 .424 Metetra
.637 .42 .571 r
.42729 .424 .4311 .54163 .44354 .51901 .43967 .39174 Metetra
.54 .342 .561 r
.43967 .39174 .44354 .51901 .45802 .39468 .45115 .39205 Metetra
.939 .589 .33 r
.45115 .39205 .45802 .39468 .46901 .42601 .46163 .44851 Metetra
.876 .559 .446 r
.46163 .44851 .46901 .42601 .47976 .4972 .47219 .53095 Metetra
.569 .256 .399 r
.47219 .53095 .47976 .4972 .4918 .49945 .48435 .53661 Metetra
.316 .043 .331 r
.48435 .53661 .4918 .49945 .504 .49033 .49681 .52164 Metetra
.941 .795 .336 r
.49681 .52164 .504 .49033 .51641 .4112 .5096 .43322 Metetra
.956 .818 .381 r
.5096 .43322 .51641 .4112 .52832 .34206 .52178 .36409 Metetra
0 0 .061 r
.52178 .36409 .52832 .34206 .54036 .38983 .53367 .34163 Metetra
.441 .316 .613 r
.53367 .34163 .54036 .38983 .55299 .45545 .54568 .35271 Metetra
.549 .356 .571 r
.54568 .35271 .55299 .45545 .56612 .51445 .55773 .35084 Metetra
.528 .328 .553 r
.55773 .35084 .56612 .51445 .57887 .51693 .56995 .35588 Metetra
.44 .263 .543 r
.56995 .35588 .57887 .51693 .5916 .51303 .58284 .39139 Metetra
.387 .232 .545 r
.58284 .39139 .5916 .51303 .60313 .45649 .59618 .43092 Metetra
.322 .313 .693 r
.59618 .43092 .60313 .45649 .61368 .37684 .60919 .44239 Metetra
.58 .302 .459 r
.60919 .44239 .61368 .37684 .62507 .34107 .62236 .45328 Metetra
.517 .269 .479 r
.62236 .45328 .62507 .34107 .63579 .29173 .63521 .44923 Metetra
.523 .283 .492 r
.63521 .44923 .63579 .29173 .64924 .31902 .64811 .44516 Metetra
.483 .246 .479 r
.64811 .44516 .64924 .31902 .66318 .35043 .66059 .42924 Metetra
.426 .186 .445 r
.66059 .42924 .66318 .35043 .67753 .38334 .67286 .40976 Metetra
0 0 .182 r
.67286 .40976 .67753 .38334 .69199 .41162 .68478 .38449 Metetra
.8 .604 .637 r
.68478 .38449 .69199 .41162 .70625 .43025 .69636 .35496 Metetra
.667 .452 .584 r
.69636 .35496 .70625 .43025 .72002 .43675 .70779 .32547 Metetra
.616 .402 .569 r
.70779 .32547 .72002 .43675 .73327 .43261 .71942 .30165 Metetra
.582 .373 .563 r
.71942 .30165 .73327 .43261 .74657 .42845 .73155 .28679 Metetra
.56 .355 .56 r
.73155 .28679 .74657 .42845 .7598 .42236 .74417 .27942 Metetra
.554 .351 .559 r
.74417 .27942 .7598 .42236 .77211 .40356 .757 .27429 Metetra
.565 .361 .563 r
.757 .27429 .77211 .40356 .78335 .37236 .76963 .26603 Metetra
.586 .381 .57 r
.76963 .26603 .78335 .37236 .79361 .33162 .78188 .25286 Metetra
.195 .123 .542 r
.78188 .25286 .79361 .33162 .80688 .32728 .80025 .30958 Metetra
.63 .568 .767 r
.80025 .30958 .80688 .32728 .81931 .31345 .81358 .30518 Metetra
.657 .751 .919 r
.81358 .30518 .81931 .31345 .83266 .30906 .82698 .30075 Metetra
.735 .262 .125 r
.18464 .5133 .19307 .5116 .20309 .51493 .19404 .52326 Metetra
.725 .331 .302 r
.19404 .52326 .20309 .51493 .21146 .53677 .20335 .53543 Metetra
.93 .823 .718 r
.20335 .53543 .21146 .53677 .22632 .48895 .21617 .51116 Metetra
.352 .016 .249 r
.21617 .51116 .22632 .48895 .23323 .52984 .22728 .50518 Metetra
.622 .5 .694 r
.22728 .50518 .23323 .52984 .245 .51659 .23831 .50038 Metetra
.48 .483 .783 r
.23831 .50038 .245 .51659 .25562 .5174 .24881 .50243 Metetra
.273 .378 .788 r
.24881 .50243 .25562 .5174 .26432 .54385 .25905 .50874 Metetra
0 0 .504 r
.25905 .50874 .26432 .54385 .2797 .48366 .26786 .53524 Metetra
.596 .313 .457 r
.26786 .53524 .2797 .48366 .28893 .50549 .27805 .54624 Metetra
.905 .817 .346 r
.27805 .54624 .28893 .50549 .29866 .52322 .29448 .47003 Metetra
.171 .104 .533 r
.29448 .47003 .29866 .52322 .31086 .50535 .30344 .49943 Metetra
.883 .784 .747 r
.30344 .49943 .31086 .50535 .32601 .43845 .31572 .48051 Metetra
.555 .263 .426 r
.31572 .48051 .32601 .43845 .33174 .52839 .32656 .48483 Metetra
.477 .346 .623 r
.32656 .48483 .33174 .52839 .34192 .54881 .33739 .49113 Metetra
.725 .511 .601 r
.33739 .49113 .34192 .54881 .35593 .49797 .35067 .45354 Metetra
.096 .07 .535 r
.35067 .45354 .35593 .49797 .37084 .42261 .36046 .48246 Metetra
.522 .251 .445 r
.36046 .48246 .37084 .42261 .38138 .4365 .37185 .48251 Metetra
.279 .026 .339 r
.37185 .48251 .38138 .4365 .38992 .50379 .38419 .4625 Metetra
.711 .517 .625 r
.38419 .4625 .38992 .50379 .40144 .50541 .39659 .43914 Metetra
.719 .543 0 r
.39659 .43914 .40144 .50541 .41343 .49553 .40423 .54613 Metetra
.536 .252 .432 r
.40423 .54613 .41343 .49553 .42729 .424 .41609 .54838 Metetra
.37 .151 .445 r
.41609 .54838 .42729 .424 .43967 .39174 .42927 .5079 Metetra
0 0 .146 r
.42927 .5079 .43967 .39174 .45115 .39205 .44462 .37282 Metetra
.821 .492 0 r
.44462 .37282 .45115 .39205 .46163 .44851 .4553 .41351 Metetra
.75 .506 0 r
.4553 .41351 .46163 .44851 .47219 .53095 .46593 .47731 Metetra
.54 .38 .612 r
.46593 .47731 .47219 .53095 .48435 .53661 .47802 .47788 Metetra
.615 .428 .606 r
.47802 .47788 .48435 .53661 .49681 .52164 .49031 .46642 Metetra
.808 .571 .579 r
.49031 .46642 .49681 .52164 .5096 .43322 .50301 .3959 Metetra
.82 .594 .597 r
.50301 .3959 .5096 .43322 .52178 .36409 .5152 .3446 Metetra
0 0 .504 r
.5152 .3446 .52178 .36409 .53367 .34163 .52715 .36822 Metetra
.761 .426 .418 r
.52715 .36822 .53367 .34163 .54568 .35271 .53939 .40115 Metetra
.646 .347 .449 r
.53939 .40115 .54568 .35271 .55773 .35084 .55188 .422 Metetra
.504 .243 .451 r
.55188 .422 .55773 .35084 .56995 .35588 .56431 .41841 Metetra
.497 .23 .44 r
.56431 .41841 .56995 .35588 .58284 .39139 .57679 .41436 Metetra
0 0 .041 r
.57679 .41436 .58284 .39139 .59618 .43092 .58888 .38753 Metetra
.766 .549 .604 r
.58888 .38753 .59618 .43092 .60919 .44239 .60058 .34938 Metetra
.614 .406 .577 r
.60058 .34938 .60919 .44239 .62236 .45328 .61259 .33034 Metetra
.603 .39 .565 r
.61259 .33034 .62236 .45328 .63521 .44923 .62447 .30892 Metetra
.472 .29 .552 r
.62447 .30892 .63521 .44923 .64811 .44516 .63782 .33092 Metetra
.481 .303 .561 r
.63782 .33092 .64811 .44516 .66059 .42924 .6512 .34695 Metetra
.448 .292 .576 r
.6512 .34695 .66059 .42924 .67286 .40976 .66488 .36473 Metetra
.379 .284 .62 r
.66488 .36473 .67286 .40976 .68478 .38449 .67872 .38097 Metetra
.519 0 0 r
.67872 .38097 .68478 .38449 .69636 .35496 .69252 .39195 Metetra
.532 .224 .392 r
.69252 .39195 .69636 .35496 .70779 .32547 .70601 .39421 Metetra
.5 .237 .447 r
.70601 .39421 .70779 .32547 .71942 .30165 .71923 .38997 Metetra
.509 .254 .464 r
.71923 .38997 .71942 .30165 .73155 .28679 .73251 .3857 Metetra
.494 .247 .468 r
.73251 .3857 .73155 .28679 .74417 .27942 .74553 .37682 Metetra
.445 .209 .461 r
.74553 .37682 .74417 .27942 .757 .27429 .75772 .35616 Metetra
.369 .146 .439 r
.75772 .35616 .757 .27429 .76963 .26603 .76903 .32517 Metetra
.234 .03 .386 r
.76903 .32517 .76963 .26603 .78188 .25286 .77963 .28764 Metetra
.623 .295 .395 r
.77963 .28764 .78188 .25286 .80025 .30958 .79443 .30127 Metetra
.657 .751 .919 r
.79443 .30127 .80025 .30958 .81358 .30518 .8078 .29683 Metetra
.657 .751 .919 r
.8078 .29683 .81358 .30518 .82698 .30075 .82124 .29237 Metetra
.607 .573 .791 r
.17779 .49894 .18464 .5133 .19404 .52326 .1884 .49653 Metetra
0 0 .272 r
.1884 .49653 .19404 .52326 .20335 .53543 .19594 .52589 Metetra
.905 .709 .628 r
.19594 .52589 .20335 .53543 .21617 .51116 .21129 .47581 Metetra
0 0 .32 r
.21129 .47581 .21617 .51116 .22728 .50518 .21857 .51082 Metetra
.736 .976 .731 r
.21857 .51082 .22728 .50518 .23831 .50038 .23028 .4991 Metetra
.16 .688 .864 r
.23028 .4991 .23831 .50038 .24881 .50243 .24101 .49885 Metetra
.919 .554 .32 r
.24101 .49885 .24881 .50243 .25905 .50874 .24898 .53288 Metetra
.98 .866 .488 r
.24898 .53288 .25905 .50874 .26786 .53524 .26461 .47374 Metetra
.391 .255 .573 r
.26461 .47374 .26786 .53524 .27805 .54624 .27416 .49055 Metetra
.406 .273 .586 r
.27416 .49055 .27805 .54624 .29448 .47003 .2841 .50466 Metetra
.169 0 .244 r
.2841 .50466 .29448 .47003 .30344 .49943 .29646 .48602 Metetra
.905 .695 .609 r
.29646 .48602 .30344 .49943 .31572 .48051 .31131 .42871 Metetra
.815 .604 .048 r
.31131 .42871 .31572 .48051 .32656 .48483 .31693 .51463 Metetra
.719 .402 .441 r
.31693 .51463 .32656 .48483 .33739 .49113 .32674 .54031 Metetra
0 0 .128 r
.32674 .54031 .33739 .49113 .35067 .45354 .34076 .49483 Metetra
.925 .808 .343 r
.34076 .49483 .35067 .45354 .36046 .48246 .35672 .40747 Metetra
.419 .267 .566 r
.35672 .40747 .36046 .48246 .37185 .48251 .36704 .4253 Metetra
0 0 .335 r
.36704 .4253 .37185 .48251 .38419 .4625 .3757 .48423 Metetra
.482 .135 .301 r
.3757 .48423 .38419 .4625 .39659 .43914 .38732 .48387 Metetra
.389 .116 .373 r
.38732 .48387 .39659 .43914 .40423 .54613 .39945 .47225 Metetra
.753 .522 .582 r
.39945 .47225 .40423 .54613 .41609 .54838 .41328 .41093 Metetra
.603 .388 .562 r
.41328 .41093 .41609 .54838 .42927 .5079 .42558 .38765 Metetra
.606 .393 .567 r
.42558 .38765 .42927 .5079 .44462 .37282 .43775 .36608 Metetra
.953 .613 .32 r
.43775 .36608 .44462 .37282 .4553 .41351 .44777 .4314 Metetra
.892 .572 .435 r
.44777 .4314 .4553 .41351 .46593 .47731 .45797 .51605 Metetra
.567 .261 .41 r
.45797 .51605 .46593 .47731 .47802 .47788 .47016 .52219 Metetra
.382 .109 .37 r
.47016 .52219 .47802 .47788 .49031 .46642 .48271 .50971 Metetra
.824 .735 .21 r
.48271 .50971 .49031 .46642 .50301 .3959 .49594 .42071 Metetra
.962 .81 .377 r
.49594 .42071 .50301 .3959 .5152 .3446 .50853 .3418 Metetra
.895 .904 .824 r
.50853 .3418 .5152 .3446 .52715 .36822 .52052 .3278 Metetra
.381 .288 .624 r
.52052 .3278 .52715 .36822 .53939 .40115 .53255 .34109 Metetra
.525 .36 .6 r
.53255 .34109 .53939 .40115 .55188 .422 .54471 .34359 Metetra
.491 .322 .579 r
.54471 .34359 .55188 .422 .56431 .41841 .55703 .35261 Metetra
.339 .222 .571 r
.55703 .35261 .56431 .41841 .57679 .41436 .56975 .37893 Metetra
0 .006 .531 r
.56975 .37893 .57679 .41436 .58888 .38753 .58289 .41205 Metetra
.612 .264 .356 r
.58289 .41205 .58888 .38753 .60058 .34938 .59586 .42154 Metetra
.554 .282 .457 r
.59586 .42154 .60058 .34938 .61259 .33034 .60893 .42811 Metetra
.509 .257 .468 r
.60893 .42811 .61259 .33034 .62447 .30892 .62182 .42398 Metetra
.513 .265 .476 r
.62182 .42398 .62447 .30892 .63782 .33092 .63476 .41983 Metetra
.444 .202 .451 r
.63476 .41983 .63782 .33092 .6512 .34695 .64726 .40219 Metetra
.356 .109 .396 r
.64726 .40219 .6512 .34695 .66488 .36473 .6596 .38187 Metetra
.6596 .38187 .66488 .36473 .67872 .38097 .67167 .35749 Metetra
.799 .618 .657 r
.67167 .35749 .67872 .38097 .69252 .39195 .68362 .33254 Metetra
.662 .459 .599 r
.68362 .33254 .69252 .39195 .70601 .39421 .6956 .31051 Metetra
.612 .407 .58 r
.6956 .31051 .70601 .39421 .71923 .38997 .7078 .29356 Metetra
.584 .382 .573 r
.7078 .29356 .71923 .38997 .73251 .3857 .72029 .2819 Metetra
.568 .368 .57 r
.72029 .2819 .73251 .3857 .74553 .37682 .73303 .27406 Metetra
.564 .366 .57 r
.73303 .27406 .74553 .37682 .75772 .35616 .74587 .2672 Metetra
.578 .381 .577 r
.74587 .2672 .75772 .35616 .76903 .32517 .75856 .25787 Metetra
.613 .417 .593 r
.75856 .25787 .76903 .32517 .77963 .28764 .77091 .244 Metetra
0 0 .515 r
.77091 .244 .77963 .28764 .79443 .30127 .78855 .2929 Metetra
.657 .751 .919 r
.78855 .2929 .79443 .30127 .8078 .29683 .80197 .28841 Metetra
.657 .751 .919 r
.80197 .28841 .8078 .29683 .82124 .29237 .81546 .28391 Metetra
.015 0 0 r
.16875 .50464 .17779 .49894 .1884 .49653 .17955 .50105 Metetra
.762 .342 .252 r
.17955 .50105 .1884 .49653 .19594 .52589 .18871 .51412 Metetra
.759 .675 .769 r
.18871 .51412 .19594 .52589 .21129 .47581 .20031 .50374 Metetra
.437 .117 .324 r
.20031 .50374 .21129 .47581 .21857 .51082 .21127 .50011 Metetra
.749 .313 0 r
.21127 .50011 .21857 .51082 .23028 .4991 .22038 .51731 Metetra
.833 .885 .455 r
.22038 .51731 .23028 .4991 .24101 .49885 .23386 .48694 Metetra
0 0 .372 r
.23386 .48694 .24101 .49885 .24898 .53288 .24331 .50253 Metetra
.708 .537 .655 r
.24331 .50253 .24898 .53288 .26461 .47374 .25554 .48615 Metetra
.829 .493 .418 r
.25554 .48615 .26461 .47374 .27416 .49055 .26376 .52062 Metetra
.909 .846 .393 r
.26376 .52062 .27416 .49055 .2841 .50466 .27912 .46362 Metetra
0 0 .445 r
.27912 .46362 .2841 .50466 .29646 .48602 .28768 .49749 Metetra
.28768 .49749 .29646 .48602 .31131 .42871 .2996 .48645 Metetra
.591 .309 .458 r
.2996 .48645 .31131 .42871 .31693 .51463 .31005 .49801 Metetra
.745 .393 0 r
.31005 .49801 .31693 .51463 .32674 .54031 .31973 .52483 Metetra
.883 .686 .631 r
.31973 .52483 .32674 .54031 .34076 .49483 .33375 .48094 Metetra
.717 .641 .772 r
.33375 .48094 .34076 .49483 .35672 .40747 .34561 .47262 Metetra
.608 .329 .468 r
.34561 .47262 .35672 .40747 .36704 .4253 .35623 .48915 Metetra
.444 .182 .422 r
.35623 .48915 .36704 .4253 .3757 .48423 .36832 .4787 Metetra
.953 .726 .556 r
.36832 .4787 .3757 .48423 .38732 .48387 .38399 .38659 Metetra
0 0 .22 r
.38399 .38659 .38732 .48387 .39945 .47225 .39076 .50104 Metetra
.637 .309 .399 r
.39076 .50104 .39945 .47225 .41328 .41093 .40217 .51374 Metetra
.445 .203 .452 r
.40217 .51374 .41328 .41093 .42558 .38765 .41477 .49566 Metetra
0 0 .113 r
.41477 .49566 .42558 .38765 .43775 .36608 .43058 .36732 Metetra
.827 .38 .168 r
.43058 .36732 .43775 .36608 .44777 .4314 .44171 .38639 Metetra
.766 .542 0 r
.44171 .38639 .44777 .4314 .45797 .51605 .45166 .46853 Metetra
.488 .351 .62 r
.45166 .46853 .45797 .51605 .47016 .52219 .46372 .47421 Metetra
.616 .441 .622 r
.46372 .47421 .47016 .52219 .48271 .50971 .47614 .46457 Metetra
.857 .612 .568 r
.47614 .46457 .48271 .50971 .49594 .42071 .48942 .37742 Metetra
.842 .602 .576 r
.48942 .37742 .49594 .42071 .50853 .3418 .50203 .30524 Metetra
0 0 .26 r
.50203 .30524 .50853 .3418 .52052 .3278 .51373 .35889 Metetra
.846 .523 .442 r
.51373 .35889 .52052 .3278 .53255 .34109 .52593 .43329 Metetra
.682 .399 .487 r
.52593 .43329 .53255 .34109 .54471 .34359 .5387 .48591 Metetra
.53 .282 .485 r
.5387 .48591 .54471 .34359 .55703 .35261 .55155 .48714 Metetra
.514 .269 .48 r
.55155 .48714 .55703 .35261 .56975 .37893 .56444 .4831 Metetra
.312 .102 .424 r
.56444 .4831 .56975 .37893 .58289 .41205 .57673 .43772 Metetra
.931 .786 .316 r
.57673 .43772 .58289 .41205 .59586 .42154 .58805 .35628 Metetra
.722 .498 .585 r
.58805 .35628 .59586 .42154 .60893 .42811 .59975 .3149 Metetra
.691 .456 .562 r
.59975 .3149 .60893 .42811 .62182 .42398 .61082 .25898 Metetra
.48 .29 .544 r
.61082 .25898 .62182 .42398 .63476 .41983 .62398 .28012 Metetra
.449 .271 .547 r
.62398 .28012 .63476 .41983 .64726 .40219 .63762 .30742 Metetra
.379 .235 .556 r
.63762 .30742 .64726 .40219 .6596 .38187 .65178 .33938 Metetra
.135 .121 .576 r
.65178 .33938 .6596 .38187 .67167 .35749 .66625 .37052 Metetra
.776 .372 .287 r
.66625 .37052 .67167 .35749 .68362 .33254 .68073 .39448 Metetra
.576 .29 .444 r
.68073 .39448 .68362 .33254 .6956 .31051 .69482 .40537 Metetra
.506 .252 .463 r
.69482 .40537 .6956 .31051 .7078 .29356 .70824 .40108 Metetra
.51 .258 .47 r
.70824 .40108 .7078 .29356 .72029 .2819 .72173 .39677 Metetra
.506 .258 .472 r
.72173 .39677 .72029 .2819 .73303 .27406 .73518 .39095 Metetra
.45 .216 .466 r
.73518 .39095 .73303 .27406 .74587 .2672 .74752 .36842 Metetra
.377 .157 .448 r
.74752 .36842 .74587 .2672 .75856 .25787 .7588 .33285 Metetra
.263 .061 .407 r
.7588 .33285 .75856 .25787 .77091 .244 .76932 .29019 Metetra
.477 .193 .404 r
.76932 .29019 .77091 .244 .78855 .2929 .78273 .28569 Metetra
.696 .803 .932 r
.78273 .28569 .78855 .2929 .80197 .28841 .79609 .27992 Metetra
.657 .751 .919 r
.79609 .27992 .80197 .28841 .81546 .28391 .80962 .27538 Metetra
.542 .526 .787 r
.16193 .48902 .16875 .50464 .17955 .50105 .17235 .48888 Metetra
.848 .443 0 r
.17235 .48888 .17955 .50105 .18871 .51412 .1806 .51048 Metetra
.926 .765 .663 r
.1806 .51048 .18871 .51412 .20031 .50374 .19481 .47453 Metetra
.423 .347 .666 r
.19481 .47453 .20031 .50374 .21127 .50011 .20476 .48085 Metetra
.618 .533 .736 r
.20476 .48085 .21127 .50011 .22038 .51731 .21576 .47713 Metetra
.287 .212 .595 r
.21576 .47713 .22038 .51731 .23386 .48694 .22504 .493 Metetra
.83 .46 .353 r
.22504 .493 .23386 .48694 .24331 .50253 .23375 .51736 Metetra
.995 .823 .558 r
.23375 .51736 .24331 .50253 .25554 .48615 .25037 .45012 Metetra
.425 .324 .636 r
.25037 .45012 .25554 .48615 .26376 .52062 .26057 .45794 Metetra
.503 .338 .589 r
.26057 .45794 .26376 .52062 .27912 .46362 .27114 .46263 Metetra
.533 .9 .966 r
.27114 .46263 .27912 .46362 .28768 .49749 .28244 .45885 Metetra
.735 .538 .626 r
.28244 .45885 .28768 .49749 .2996 .48645 .29543 .43172 Metetra
0 0 .121 r
.29543 .43172 .2996 .48645 .31005 .49801 .30174 .50259 Metetra
.792 .371 .25 r
.30174 .50259 .31005 .49801 .31973 .52483 .31203 .5196 Metetra
.942 .747 .612 r
.31203 .5196 .31973 .52483 .33375 .48094 .32672 .4669 Metetra
.892 .695 .629 r
.32672 .4669 .33375 .48094 .34561 .47262 .34062 .42305 Metetra
.497 .349 .611 r
.34062 .42305 .34561 .47262 .35623 .48915 .3517 .42768 Metetra
.541 .368 .596 r
.3517 .42768 .35623 .48915 .36832 .4787 .36313 .42744 Metetra
.494 .345 .608 r
.36313 .42744 .36832 .4787 .38399 .38659 .3744 .43256 Metetra
.476 .19 .401 r
.3744 .43256 .38399 .38659 .39076 .50104 .38616 .42876 Metetra
.568 .381 .588 r
.38616 .42876 .39076 .50104 .40217 .51374 .39803 .42351 Metetra
.638 .425 .578 r
.39803 .42351 .40217 .51374 .41477 .49566 .41065 .39815 Metetra
.712 .481 .573 r
.41065 .39815 .41477 .49566 .43058 .36732 .42419 .34063 Metetra
.937 .633 .174 r
.42419 .34063 .43058 .36732 .44171 .38639 .43362 .41709 Metetra
.859 .545 .456 r
.43362 .41709 .44171 .38639 .45166 .46853 .44345 .50364 Metetra
.545 .231 .386 r
.44345 .50364 .45166 .46853 .46372 .47421 .45572 .50751 Metetra
.267 0 .283 r
.45572 .50751 .46372 .47421 .47614 .46457 .46842 .49261 Metetra
.977 .805 .391 r
.46842 .49261 .47614 .46457 .48942 .37742 .48217 .3974 Metetra
.992 .809 .431 r
.48217 .3974 .48942 .37742 .50203 .30524 .49518 .31249 Metetra
.659 .2 .152 r
.49518 .31249 .50203 .30524 .51373 .35889 .5071 .32156 Metetra
.076 .084 .563 r
.5071 .32156 .51373 .35889 .52593 .43329 .51914 .34887 Metetra
.47 .302 .57 r
.51914 .34887 .52593 .43329 .5387 .48591 .53145 .36138 Metetra
.528 .331 .558 r
.53145 .36138 .5387 .48591 .55155 .48714 .54388 .36367 Metetra
.538 .34 .559 r
.54388 .36367 .55155 .48714 .56444 .4831 .55639 .36281 Metetra
.536 .338 .56 r
.55639 .36281 .56444 .4831 .57673 .43772 .56899 .3628 Metetra
.548 .366 .586 r
.56899 .3628 .57673 .43772 .58805 .35628 .58165 .36089 Metetra
.282 0 0 r
.58165 .36089 .58805 .35628 .59975 .3149 .59443 .36079 Metetra
.489 .201 .403 r
.59443 .36079 .59975 .3149 .61082 .25898 .60723 .35824 Metetra
.51 .255 .465 r
.60723 .35824 .61082 .25898 .62398 .28012 .62009 .35508 Metetra
.497 .234 .446 r
.62009 .35508 .62398 .28012 .63762 .30742 .63298 .35078 Metetra
.47 .181 .392 r
.63298 .35078 .63762 .30742 .65178 .33938 .64593 .34645 Metetra
.049 0 0 r
.64593 .34645 .65178 .33938 .66625 .37052 .65888 .34077 Metetra
.624 .489 .677 r
.65888 .34077 .66625 .37052 .68073 .39448 .67183 .33411 Metetra
.585 .404 .602 r
.67183 .33411 .68073 .39448 .69482 .40537 .6848 .32677 Metetra
.577 .385 .584 r
.6848 .32677 .69482 .40537 .70824 .40108 .69775 .31857 Metetra
.58 .385 .581 r
.69775 .31857 .70824 .40108 .72173 .39677 .71066 .30909 Metetra
.585 .385 .577 r
.71066 .30909 .72173 .39677 .73518 .39095 .72347 .29781 Metetra
.593 .389 .574 r
.72347 .29781 .73518 .39095 .74752 .36842 .73608 .28345 Metetra
.616 .409 .577 r
.73608 .28345 .74752 .36842 .7588 .33285 .74831 .26431 Metetra
.654 .444 .587 r
.74831 .26431 .7588 .33285 .76932 .29019 .76011 .24028 Metetra
.179 .141 .575 r
.76011 .24028 .76932 .29019 .78273 .28569 .77664 .27592 Metetra
.655 .717 .894 r
.77664 .27592 .78273 .28569 .79609 .27992 .79016 .27136 Metetra
.657 .751 .919 r
.79016 .27136 .79609 .27992 .80962 .27538 .80373 .26677 Metetra
.828 .364 0 r
.15418 .48147 .16193 .48902 .17235 .48888 .16284 .49756 Metetra
.759 .378 .332 r
.16284 .49756 .17235 .48888 .1806 .51048 .1717 .51345 Metetra
.964 .824 .657 r
.1717 .51345 .1806 .51048 .19481 .47453 .18616 .47642 Metetra
.589 .947 .873 r
.18616 .47642 .19481 .47453 .20476 .48085 .19738 .47026 Metetra
0 .21 .735 r
.19738 .47026 .20476 .48085 .21576 .47713 .20723 .47863 Metetra
.774 .99 .89 r
.20723 .47863 .21576 .47713 .22504 .493 .21882 .46969 Metetra
.231 .255 .68 r
.21882 .46969 .22504 .493 .23375 .51736 .22866 .48026 Metetra
0 0 .419 r
.22866 .48026 .23375 .51736 .25037 .45012 .23683 .51191 Metetra
.554 .277 .449 r
.23683 .51191 .25037 .45012 .26057 .45794 .24742 .51784 Metetra
.24742 .51784 .26057 .45794 .27114 .46263 .26478 .44021 Metetra
0 0 .305 r
.26478 .44021 .27114 .46263 .28244 .45885 .27372 .46698 Metetra
.972 .929 .642 r
.27372 .46698 .28244 .45885 .29543 .43172 .28695 .43849 Metetra
.892 .562 .416 r
.28695 .43849 .29543 .43172 .30174 .50259 .29444 .4907 Metetra
.334 .487 .863 r
.29444 .4907 .30174 .50259 .31203 .5196 .30558 .49447 Metetra
.874 .652 .598 r
.30558 .49447 .31203 .5196 .32672 .4669 .32111 .4296 Metetra
.298 .234 .614 r
.32111 .4296 .32672 .4669 .34062 .42305 .33155 .44451 Metetra
.461 .109 .281 r
.33155 .44451 .34062 .42305 .3517 .42768 .34306 .44348 Metetra
.34306 .44348 .3517 .42768 .36313 .42744 .35551 .42578 Metetra
.725 .943 .954 r
.35551 .42578 .36313 .42744 .3744 .43256 .36738 .41905 Metetra
.968 .654 .358 r
.36738 .41905 .3744 .43256 .38616 .42876 .37473 .51343 Metetra
.548 .281 .463 r
.37473 .51343 .38616 .42876 .39803 .42351 .38649 .51969 Metetra
.336 .108 .413 r
.38649 .51969 .39803 .42351 .41065 .39815 .39989 .48592 Metetra
.39989 .48592 .41065 .39815 .42419 .34063 .41637 .3571 Metetra
.787 .431 .382 r
.41637 .3571 .42419 .34063 .43362 .41709 .4272 .38556 Metetra
.877 .594 .073 r
.4272 .38556 .43362 .41709 .44345 .50364 .43716 .45723 Metetra
.575 .413 .625 r
.43716 .45723 .44345 .50364 .45572 .50751 .44948 .45322 Metetra
.689 .485 .605 r
.44948 .45322 .45572 .50751 .46842 .49261 .46228 .42756 Metetra
.823 .575 .565 r
.46228 .42756 .46842 .49261 .48217 .3974 .47601 .33486 Metetra
.696 .481 .592 r
.47601 .33486 .48217 .3974 .49518 .31249 .4884 .30325 Metetra
.945 .585 .225 r
.4884 .30325 .49518 .31249 .5071 .32156 .49996 .35903 Metetra
.785 .464 .444 r
.49996 .35903 .5071 .32156 .51914 .34887 .51204 .41139 Metetra
.578 .293 .447 r
.51204 .41139 .51914 .34887 .53145 .36138 .52462 .42257 Metetra
.487 .214 .426 r
.52462 .42257 .53145 .36138 .54388 .36367 .53732 .41843 Metetra
.426 .158 .401 r
.53732 .41843 .54388 .36367 .55639 .36281 .55003 .40766 Metetra
.025 0 .249 r
.55003 .40766 .55639 .36281 .56899 .3628 .56245 .3712 Metetra
.997 .835 .487 r
.56245 .3712 .56899 .3628 .58165 .36089 .57435 .31498 Metetra
.733 .522 .606 r
.57435 .31498 .58165 .36089 .59443 .36079 .58639 .28381 Metetra
.687 .464 .578 r
.58639 .28381 .59443 .36079 .60723 .35824 .59814 .24719 Metetra
.414 .251 .549 r
.59814 .24719 .60723 .35824 .62009 .35508 .61149 .27543 Metetra
.438 .282 .572 r
.61149 .27543 .62009 .35508 .63298 .35078 .62482 .29258 Metetra
.394 .27 .592 r
.62482 .29258 .63298 .35078 .64593 .34645 .6384 .3103 Metetra
.296 .249 .634 r
.6384 .3103 .64593 .34645 .65888 .34077 .65221 .32753 Metetra
0 .119 .67 r
.65221 .32753 .65888 .34077 .67183 .33411 .66618 .34312 Metetra
.662 .202 .15 r
.66618 .34312 .67183 .33411 .6848 .32677 .68016 .35402 Metetra
.499 .162 .326 r
.68016 .35402 .6848 .32677 .69775 .31857 .69379 .35464 Metetra
.454 .15 .36 r
.69379 .35464 .69775 .31857 .71066 .30909 .70723 .35022 Metetra
.464 .169 .38 r
.70723 .35022 .71066 .30909 .72347 .29781 .72074 .34578 Metetra
.376 .112 .381 r
.72074 .34578 .72347 .29781 .73608 .28345 .7336 .33054 Metetra
.183 0 .333 r
.7336 .33054 .73608 .28345 .74831 .26431 .74525 .29864 Metetra
0 0 .18 r
.74525 .29864 .74831 .26431 .76011 .24028 .75594 .25616 Metetra
.64 .232 .253 r
.75594 .25616 .76011 .24028 .77664 .27592 .77061 .26732 Metetra
.657 .751 .919 r
.77061 .26732 .77664 .27592 .79016 .27136 .78417 .26272 Metetra
.657 .751 .919 r
.78417 .26272 .79016 .27136 .80373 .26677 .79779 .25809 Metetra
0 .24 .755 r
.14666 .47131 .15418 .48147 .16284 .49756 .15624 .47882 Metetra
.728 .404 0 r
.15624 .47882 .16284 .49756 .1717 .51345 .16411 .50329 Metetra
.902 .708 .63 r
.16411 .50329 .1717 .51345 .18616 .47642 .17998 .45375 Metetra
.781 .486 0 r
.17998 .45375 .18616 .47642 .19738 .47026 .18731 .48556 Metetra
.18731 .48556 .19738 .47026 .20723 .47863 .19978 .46805 Metetra
.793 .357 0 r
.19978 .46805 .20723 .47863 .21882 .46969 .20879 .48642 Metetra
.741 .394 .393 r
.20879 .48642 .21882 .46969 .22866 .48026 .21783 .50649 Metetra
.995 .849 .502 r
.21783 .50649 .22866 .48026 .23683 .51191 .23527 .43431 Metetra
.35 .207 .542 r
.23527 .43431 .23683 .51191 .24742 .51784 .24409 .45816 Metetra
.39 .254 .574 r
.24409 .45816 .24742 .51784 .26478 .44021 .25385 .47351 Metetra
.242 0 .256 r
.25385 .47351 .26478 .44021 .27372 .46698 .2661 .45938 Metetra
.932 .724 .599 r
.2661 .45938 .27372 .46698 .28695 .43849 .28208 .3956 Metetra
.962 .696 .26 r
.28208 .3956 .28695 .43849 .29444 .4907 .28553 .50067 Metetra
.743 .349 .304 r
.28553 .50067 .29444 .4907 .30558 .49447 .29591 .51653 Metetra
.975 .864 .478 r
.29591 .51653 .30558 .49447 .32111 .4296 .31127 .45865 Metetra
.994 .826 .46 r
.31127 .45865 .32111 .4296 .33155 .44451 .32823 .36945 Metetra
.136 .052 .489 r
.32823 .36945 .33155 .44451 .34306 .44348 .33696 .41267 Metetra
.821 .552 0 r
.33696 .41267 .34306 .44348 .35551 .42578 .34545 .46715 Metetra
.462 .167 .378 r
.34545 .46715 .35551 .42578 .36738 .41905 .35739 .46322 Metetra
.226 0 .299 r
.35739 .46322 .36738 .41905 .37473 .51343 .37019 .44215 Metetra
.762 .529 .58 r
.37019 .44215 .37473 .51343 .38649 .51969 .38476 .37915 Metetra
.628 .404 .559 r
.38476 .37915 .38649 .51969 .39989 .48592 .39786 .34331 Metetra
.534 .33 .55 r
.39786 .34331 .39989 .48592 .41637 .3571 .4095 .34246 Metetra
.966 .639 .294 r
.4095 .34246 .41637 .3571 .4272 .38556 .41866 .41986 Metetra
.831 .516 .456 r
.41866 .41986 .4272 .38556 .43716 .45723 .42862 .49229 Metetra
.502 .189 .367 r
.42862 .49229 .43716 .45723 .44948 .45322 .44103 .49258 Metetra
.239 0 .292 r
.44103 .49258 .44948 .45322 .46228 .42756 .45394 .47368 Metetra
.818 .735 .209 r
.45394 .47368 .46228 .42756 .47601 .33486 .46808 .38272 Metetra
.46808 .38272 .47601 .33486 .4884 .30325 .48136 .30972 Metetra
.169 0 0 r
.48136 .30972 .4884 .30325 .49996 .35903 .49346 .30684 Metetra
.561 .393 .61 r
.49346 .30684 .49996 .35903 .51204 .41139 .50562 .30384 Metetra
.545 .346 .562 r
.50562 .30384 .51204 .41139 .52462 .42257 .51785 .30079 Metetra
.499 .308 .553 r
.51785 .30079 .52462 .42257 .53732 .41843 .53017 .30993 Metetra
.438 .267 .551 r
.53017 .30993 .53732 .41843 .55003 .40766 .54271 .33148 Metetra
.28 .169 .545 r
.54271 .33148 .55003 .40766 .56245 .3712 .55566 .36694 Metetra
.718 .2 0 r
.55566 .36694 .56245 .3712 .57435 .31498 .56872 .38328 Metetra
.612 .323 .454 r
.56872 .38328 .57435 .31498 .58639 .28381 .58207 .40372 Metetra
.506 .255 .468 r
.58207 .40372 .58639 .28381 .59814 .24719 .59516 .39945 Metetra
.511 .265 .478 r
.59516 .39945 .59814 .24719 .61149 .27543 .6083 .39516 Metetra
.468 .225 .462 r
.6083 .39516 .61149 .27543 .62482 .29258 .62118 .37998 Metetra
.424 .179 .437 r
.62118 .37998 .62482 .29258 .6384 .3103 .6339 .36092 Metetra
.303 .055 .362 r
.6339 .36092 .6384 .3103 .65221 .32753 .64644 .33887 Metetra
.64644 .33887 .65221 .32753 .66618 .34312 .65887 .31611 Metetra
.759 .582 .657 r
.65887 .31611 .66618 .34312 .68016 .35402 .67127 .29472 Metetra
.648 .447 .598 r
.67127 .29472 .68016 .35402 .69379 .35464 .68369 .27537 Metetra
.615 .409 .58 r
.68369 .27537 .69379 .35464 .70723 .35022 .69614 .25775 Metetra
.597 .39 .571 r
.69614 .25775 .70723 .35022 .72074 .34578 .70865 .24192 Metetra
.585 .377 .566 r
.70865 .24192 .72074 .34578 .7336 .33054 .72121 .22762 Metetra
.587 .378 .566 r
.72121 .22762 .7336 .33054 .74525 .29864 .73373 .21291 Metetra
.607 .4 .574 r
.73373 .21291 .74525 .29864 .75594 .25616 .74602 .1955 Metetra
0 0 .487 r
.74602 .1955 .75594 .25616 .77061 .26732 .76453 .25864 Metetra
.657 .751 .919 r
.76453 .25864 .77061 .26732 .78417 .26272 .77813 .254 Metetra
.657 .751 .919 r
.77813 .254 .78417 .26272 .79779 .25809 .7918 .24933 Metetra
.659 .739 .909 r
.13877 .4639 .14666 .47131 .15624 .47882 .14964 .46009 Metetra
.917 .582 .118 r
.14964 .46009 .15624 .47882 .16411 .50329 .15628 .49475 Metetra
.903 .721 .646 r
.15628 .49475 .16411 .50329 .17998 .45375 .17146 .45298 Metetra
.416 .849 .941 r
.17146 .45298 .17998 .45375 .18731 .48556 .18234 .45036 Metetra
.525 .396 .647 r
.18234 .45036 .18731 .48556 .19978 .46805 .19291 .4513 Metetra
.959 .625 .246 r
.19291 .4513 .19978 .46805 .20879 .48642 .19928 .49592 Metetra
.988 .829 .597 r
.19928 .49592 .20879 .48642 .21783 .50649 .21526 .44289 Metetra
.597 .407 .595 r
.21526 .44289 .21783 .50649 .23527 .43431 .22701 .43316 Metetra
0 .517 .721 r
.22701 .43316 .23527 .43431 .24409 .45816 .2378 .43444 Metetra
.769 .479 0 r
.2378 .43444 .24409 .45816 .25385 .47351 .24582 .46931 Metetra
.922 .552 .3 r
.24582 .46931 .25385 .47351 .2661 .45938 .25408 .50497 Metetra
.808 .773 .265 r
.25408 .50497 .2661 .45938 .28208 .3956 .27096 .43421 Metetra
.156 0 .242 r
.27096 .43421 .28208 .3956 .28553 .50067 .28368 .41385 Metetra
.493 .312 .564 r
.28368 .41385 .28553 .50067 .29591 .51653 .29439 .42086 Metetra
.594 .388 .572 r
.29439 .42086 .29591 .51653 .31127 .45865 .30667 .40642 Metetra
.623 .437 .61 r
.30667 .40642 .31127 .45865 .32823 .36945 .31876 .39452 Metetra
.858 .548 .462 r
.31876 .39452 .32823 .36945 .33696 .41267 .32554 .47043 Metetra
.675 .381 .468 r
.32554 .47043 .33696 .41267 .34545 .46715 .33545 .50209 Metetra
.33545 .50209 .34545 .46715 .35739 .46322 .35006 .45164 Metetra
.936 .709 .571 r
.35006 .45164 .35739 .46322 .37019 .44215 .3659 .37068 Metetra
.404 .256 .565 r
.3659 .37068 .37019 .44215 .38476 .37915 .3767 .38804 Metetra
.171 0 0 r
.3767 .38804 .38476 .37915 .39786 .34331 .38862 .38397 Metetra
.367 .082 .342 r
.38862 .38397 .39786 .34331 .4095 .34246 .40086 .37299 Metetra
.498 .175 .349 r
.40086 .37299 .4095 .34246 .41866 .41986 .4127 .37334 Metetra
.551 .393 .621 r
.4127 .37334 .41866 .41986 .42862 .49229 .42469 .37183 Metetra
.584 .372 .56 r
.42469 .37183 .42862 .49229 .44103 .49258 .43714 .35613 Metetra
.559 .35 .553 r
.43714 .35613 .44103 .49258 .45394 .47368 .44941 .34687 Metetra
.221 .097 .491 r
.44941 .34687 .45394 .47368 .46808 .38272 .46021 .41147 Metetra
.831 .502 .432 r
.46021 .41147 .46808 .38272 .48136 .30972 .47166 .47282 Metetra
.51 .264 .478 r
.47166 .47282 .48136 .30972 .49346 .30684 .48447 .46872 Metetra
.505 .26 .477 r
.48447 .46872 .49346 .30684 .50562 .30384 .49735 .46289 Metetra
.29 .09 .427 r
.49735 .46289 .50562 .30384 .51785 .30079 .51057 .3927 Metetra
.16 0 .36 r
.51057 .3927 .51785 .30079 .53017 .30993 .52332 .33584 Metetra
.52332 .33584 .53017 .30993 .54271 .33148 .53579 .30251 Metetra
.697 .535 .665 r
.53579 .30251 .54271 .33148 .55566 .36694 .54823 .2883 Metetra
.4 .254 .564 r
.54823 .2883 .55566 .36694 .56872 .38328 .56106 .30943 Metetra
.48 .315 .579 r
.56106 .30943 .56872 .38328 .58207 .40372 .57395 .31818 Metetra
.554 .362 .575 r
.57395 .31818 .58207 .40372 .59516 .39945 .58676 .3138 Metetra
.566 .371 .575 r
.58676 .3138 .59516 .39945 .6083 .39516 .59956 .30665 Metetra
.558 .363 .573 r
.59956 .30665 .6083 .39516 .62118 .37998 .61244 .30105 Metetra
.519 .34 .579 r
.61244 .30105 .62118 .37998 .6339 .36092 .62563 .30374 Metetra
.566 .392 .605 r
.62563 .30374 .6339 .36092 .64644 .33887 .63869 .29928 Metetra
.582 .432 .643 r
.63869 .29928 .64644 .33887 .65887 .31611 .65181 .2948 Metetra
.646 .549 .73 r
.65181 .2948 .65887 .31611 .67127 .29472 .6649 .28833 Metetra
.861 .854 .834 r
.6649 .28833 .67127 .29472 .68369 .27537 .6777 .27501 Metetra
.003 .58 .73 r
.6777 .27501 .68369 .27537 .69614 .25775 .69122 .2753 Metetra
.481 .093 .226 r
.69122 .2753 .69614 .25775 .70865 .24192 .70489 .27639 Metetra
.444 .136 .347 r
.70489 .27639 .70865 .24192 .72121 .22762 .71832 .2718 Metetra
.463 .171 .384 r
.71832 .2718 .72121 .22762 .73373 .21291 .73181 .26719 Metetra
.396 .134 .395 r
.73181 .26719 .73373 .21291 .74602 .1955 .74466 .25254 Metetra
.491 .211 .416 r
.74466 .25254 .74602 .1955 .76453 .25864 .75838 .24989 Metetra
.657 .751 .919 r
.75838 .24989 .76453 .25864 .77813 .254 .77203 .2452 Metetra
.657 .751 .919 r
.77203 .2452 .77813 .254 .7918 .24933 .78575 .24049 Metetra
0 .511 .821 r
.13032 .46053 .13877 .4639 .14964 .46009 .14051 .46286 Metetra
.847 .466 .328 r
.14051 .46286 .14964 .46009 .15628 .49475 .14843 .48584 Metetra
.903 .719 .643 r
.14843 .48584 .15628 .49475 .17146 .45298 .16388 .44267 Metetra
.77 .325 0 r
.16388 .44267 .17146 .45298 .18234 .45036 .1727 .45935 Metetra
.1727 .45935 .18234 .45036 .19291 .4513 .18404 .4536 Metetra
.747 .282 .144 r
.18404 .4536 .19291 .4513 .19928 .49592 .19367 .46508 Metetra
0 0 .406 r
.19367 .46508 .19928 .49592 .21526 .44289 .2019 .49248 Metetra
.739 .74 .222 r
.2019 .49248 .21526 .44289 .22701 .43316 .21925 .42562 Metetra
.812 .343 0 r
.21925 .42562 .22701 .43316 .2378 .43444 .22864 .44247 Metetra
.364 0 0 r
.22864 .44247 .2378 .43444 .24582 .46931 .2397 .44223 Metetra
.623 .494 .684 r
.2397 .44223 .24582 .46931 .25408 .50497 .25131 .43643 Metetra
.734 .51 .588 r
.25131 .43643 .25408 .50497 .27096 .43421 .26638 .38798 Metetra
.909 .663 .161 r
.26638 .38798 .27096 .43421 .28368 .41385 .27064 .47648 Metetra
.611 .325 .458 r
.27064 .47648 .28368 .41385 .29439 .42086 .28081 .49418 Metetra
.01 0 .253 r
.28081 .49418 .29439 .42086 .30667 .40642 .29592 .44414 Metetra
.908 .82 .352 r
.29592 .44414 .30667 .40642 .31876 .39452 .31234 .37041 Metetra
0 0 .319 r
.31234 .37041 .31876 .39452 .32554 .47043 .32185 .39939 Metetra
.395 .248 .562 r
.32185 .39939 .32554 .47043 .33545 .50209 .33231 .41702 Metetra
.544 .353 .573 r
.33231 .41702 .33545 .50209 .35006 .45164 .3441 .4146 Metetra
.597 .445 .646 r
.3441 .4146 .35006 .45164 .3659 .37068 .35611 .40914 Metetra
.212 0 .27 r
.35611 .40914 .3659 .37068 .3767 .38804 .3688 .39063 Metetra
.985 .837 .615 r
.3688 .39063 .3767 .38804 .38862 .38397 .38244 .34975 Metetra
.775 .571 .623 r
.38244 .34975 .38862 .38397 .40086 .37299 .39551 .3174 Metetra
0 0 .141 r
.39551 .3174 .40086 .37299 .4127 .37334 .40427 .39609 Metetra
.872 .549 .437 r
.40427 .39609 .4127 .37334 .42469 .37183 .41371 .4743 Metetra
.527 .265 .461 r
.41371 .4743 .42469 .37183 .43714 .35613 .42608 .47739 Metetra
.457 .212 .453 r
.42608 .47739 .43714 .35613 .44941 .34687 .43906 .46126 Metetra
.001 0 .305 r
.43906 .46126 .44941 .34687 .46021 .41147 .45362 .37316 Metetra
.868 .625 .569 r
.45362 .37316 .46021 .41147 .47166 .47282 .46743 .29311 Metetra
.573 .354 .544 r
.46743 .29311 .47166 .47282 .48447 .46872 .47984 .2735 Metetra
.478 .279 .531 r
.47984 .2735 .48447 .46872 .49735 .46289 .49176 .2934 Metetra
.484 .286 .536 r
.49176 .2934 .49735 .46289 .51057 .3927 .50395 .30923 Metetra
.443 .28 .564 r
.50395 .30923 .51057 .3927 .52332 .33584 .51636 .32443 Metetra
0 0 .38 r
.51636 .32443 .52332 .33584 .53579 .30251 .52899 .34481 Metetra
.587 .274 .406 r
.52899 .34481 .53579 .30251 .54823 .2883 .54183 .35524 Metetra
.497 .223 .428 r
.54183 .35524 .54823 .2883 .56106 .30943 .55473 .35312 Metetra
.491 .192 .386 r
.55473 .35312 .56106 .30943 .57395 .31818 .56771 .352 Metetra
.439 .126 .337 r
.56771 .352 .57395 .31818 .58676 .3138 .58073 .34762 Metetra
.439 .126 .337 r
.58073 .34762 .58676 .3138 .59956 .30665 .59381 .34321 Metetra
.385 .089 .334 r
.59381 .34321 .59956 .30665 .61244 .30105 .60683 .33406 Metetra
.378 .073 .317 r
.60683 .33406 .61244 .30105 .62563 .30374 .61989 .32547 Metetra
.249 0 .193 r
.61989 .32547 .62563 .30374 .63869 .29928 .63292 .31512 Metetra
.023 0 .025 r
.63292 .31512 .63869 .29928 .65181 .2948 .64584 .30177 Metetra
.64584 .30177 .65181 .2948 .6649 .28833 .65869 .28681 Metetra
.885 .975 .832 r
.65869 .28681 .6649 .28833 .6777 .27501 .67154 .27268 Metetra
.877 .964 .85 r
.67154 .27268 .6777 .27501 .69122 .2753 .68442 .25935 Metetra
.782 .668 .738 r
.68442 .25935 .69122 .2753 .70489 .27639 .69721 .24469 Metetra
.709 .535 .651 r
.69721 .24469 .70489 .27639 .71832 .2718 .70981 .2274 Metetra
.683 .488 .617 r
.70981 .2274 .71832 .2718 .73181 .26719 .72219 .20742 Metetra
.661 .453 .593 r
.72219 .20742 .73181 .26719 .74466 .25254 .73432 .18489 Metetra
.081 .048 .516 r
.73432 .18489 .74466 .25254 .75838 .24989 .75219 .24105 Metetra
.657 .751 .919 r
.75219 .24105 .75838 .24989 .77203 .2452 .76589 .23632 Metetra
.657 .751 .919 r
.76589 .23632 .77203 .2452 .78575 .24049 .77965 .23157 Metetra
.679 .194 0 r
.12244 .45183 .13032 .46053 .14051 .46286 .13141 .46435 Metetra
.825 .41 .254 r
.13141 .46435 .14051 .46286 .14843 .48584 .13994 .48194 Metetra
.924 .766 .666 r
.13994 .48194 .14843 .48584 .16388 .44267 .15469 .44619 Metetra
.09 0 0 r
.15469 .44619 .16388 .44267 .1727 .45935 .16551 .44476 Metetra
.542 .548 .81 r
.16551 .44476 .1727 .45935 .18404 .4536 .17628 .44428 Metetra
.833 .731 .752 r
.17628 .44428 .18404 .4536 .19367 .46508 .18874 .42818 Metetra
.338 .258 .617 r
.18874 .42818 .19367 .46508 .2019 .49248 .19841 .43964 Metetra
0 0 .441 r
.19841 .43964 .2019 .49248 .21925 .42562 .20583 .47595 Metetra
.635 .34 .452 r
.20583 .47595 .21925 .42562 .22864 .44247 .21517 .49506 Metetra
.826 .78 .275 r
.21517 .49506 .22864 .44247 .2397 .44223 .23364 .41495 Metetra
.342 .305 .672 r
.23364 .41495 .2397 .44223 .25131 .43643 .24397 .42348 Metetra
.875 .699 .661 r
.24397 .42348 .25131 .43643 .26638 .38798 .25787 .39059 Metetra
.903 .559 .383 r
.25787 .39059 .26638 .38798 .27064 .47648 .26536 .43641 Metetra
.536 .395 .635 r
.26536 .43641 .27064 .47648 .28081 .49418 .27675 .43622 Metetra
.726 .509 .597 r
.27675 .43622 .28081 .49418 .29592 .44414 .29095 .39835 Metetra
.576 .411 .621 r
.29095 .39835 .29592 .44414 .31234 .37041 .30266 .39379 Metetra
.56 .209 .33 r
.30266 .39379 .31234 .37041 .32185 .39939 .31378 .39886 Metetra
.68 .959 .945 r
.31378 .39886 .32185 .39939 .33231 .41702 .32575 .39232 Metetra
.556 .465 .707 r
.32575 .39232 .33231 .41702 .3441 .4146 .33742 .39121 Metetra
.973 .667 .301 r
.33742 .39121 .3441 .4146 .35611 .40914 .34411 .48283 Metetra
.549 .271 .447 r
.34411 .48283 .35611 .40914 .3688 .39063 .35585 .49 Metetra
.271 .051 .384 r
.35585 .49 .3688 .39063 .38244 .34975 .37004 .44845 Metetra
0 0 .138 r
.37004 .44845 .38244 .34975 .39551 .3174 .38667 .346 Metetra
.595 .258 .369 r
.38667 .346 .39551 .3174 .40427 .39609 .39818 .35475 Metetra
0 0 .477 r
.39818 .35475 .40427 .39609 .41371 .4743 .40891 .38924 Metetra
.551 .358 .573 r
.40891 .38924 .41371 .4743 .42608 .47739 .42124 .38505 Metetra
.646 .428 .572 r
.42124 .38505 .42608 .47739 .43906 .46126 .43435 .35531 Metetra
.69 .457 .565 r
.43435 .35531 .43906 .46126 .45362 .37316 .44787 .30345 Metetra
.637 .431 .587 r
.44787 .30345 .45362 .37316 .46743 .29311 .46042 .2834 Metetra
.928 .55 .16 r
.46042 .2834 .46743 .29311 .47984 .2735 .47179 .32845 Metetra
.667 .362 .447 r
.47179 .32845 .47984 .2735 .49176 .2934 .48382 .3578 Metetra
.549 .264 .435 r
.48382 .3578 .49176 .2934 .50395 .30923 .49637 .36472 Metetra
.471 .189 .404 r
.49637 .36472 .50395 .30923 .51636 .32443 .50913 .3604 Metetra
.415 .11 .336 r
.50913 .3604 .51636 .32443 .52899 .34481 .52194 .35411 Metetra
.642 .846 .453 r
.52194 .35411 .52899 .34481 .54183 .35524 .53477 .3354 Metetra
.85 .662 .648 r
.53477 .3354 .54183 .35524 .55473 .35312 .54744 .30417 Metetra
.705 .498 .606 r
.54744 .30417 .55473 .35312 .56771 .352 .56001 .27765 Metetra
.716 .485 .574 r
.56001 .27765 .56771 .352 .58073 .34762 .57217 .23281 Metetra
.469 .287 .55 r
.57217 .23281 .58073 .34762 .59381 .34321 .58522 .2473 Metetra
.492 .31 .562 r
.58522 .2473 .59381 .34321 .60683 .33406 .59833 .25519 Metetra
.495 .321 .575 r
.59833 .25519 .60683 .33406 .61989 .32547 .61156 .26147 Metetra
.491 .331 .591 r
.61156 .26147 .61989 .32547 .63292 .31512 .62493 .26729 Metetra
.462 .333 .618 r
.62493 .26729 .63292 .31512 .64584 .30177 .63851 .27478 Metetra
.368 .34 .696 r
.63851 .27478 .64584 .30177 .65869 .28681 .65232 .28381 Metetra
0 .303 .662 r
.65232 .28381 .65869 .28681 .67154 .27268 .66619 .28993 Metetra
.357 0 .17 r
.66619 .28993 .67154 .27268 .68442 .25935 .6797 .28588 Metetra
.409 .075 .285 r
.6797 .28588 .68442 .25935 .69721 .24469 .69326 .28125 Metetra
.442 .135 .347 r
.69326 .28125 .69721 .24469 .70981 .2274 .70688 .27659 Metetra
.322 .066 .361 r
.70688 .27659 .70981 .2274 .72219 .20742 .71962 .25702 Metetra
.17 0 .326 r
.71962 .25702 .72219 .20742 .73432 .18489 .73137 .2238 Metetra
.567 .243 .379 r
.73137 .2238 .73432 .18489 .75219 .24105 .74594 .23214 Metetra
.657 .751 .919 r
.74594 .23214 .75219 .24105 .76589 .23632 .75968 .22737 Metetra
.657 .751 .919 r
.75968 .22737 .76589 .23632 .77965 .23157 .77349 .22257 Metetra
0 .292 .787 r
.11458 .44248 .12244 .45183 .13141 .46435 .12426 .44892 Metetra
.748 .376 0 r
.12426 .44892 .13141 .46435 .13994 .48194 .13236 .46957 Metetra
.889 .697 .637 r
.13236 .46957 .13994 .48194 .15469 .44619 .14828 .4246 Metetra
.831 .517 0 r
.14828 .4246 .15469 .44619 .16551 .44476 .15532 .45639 Metetra
.875 .956 .613 r
.15532 .45639 .16551 .44476 .17628 .44428 .16856 .43411 Metetra
.807 .365 0 r
.16856 .43411 .17628 .44428 .18874 .42818 .17744 .45226 Metetra
.756 .43 .433 r
.17744 .45226 .18874 .42818 .19841 .43964 .18537 .48144 Metetra
.936 .842 .4 r
.18537 .48144 .19841 .43964 .20583 .47595 .20416 .40418 Metetra
.166 .069 .492 r
.20416 .40418 .20583 .47595 .21517 .49506 .21172 .43925 Metetra
.557 .383 .601 r
.21172 .43925 .21517 .49506 .23364 .41495 .22313 .43599 Metetra
.22313 .43599 .23364 .41495 .24397 .42348 .23577 .41962 Metetra
.944 .754 .615 r
.23577 .41962 .24397 .42348 .25787 .39059 .25146 .36732 Metetra
.979 .683 .364 r
.25146 .36732 .25787 .39059 .26536 .43641 .2545 .46535 Metetra
.643 .311 .393 r
.2545 .46535 .26536 .43641 .27675 .43622 .26492 .47924 Metetra
.798 .772 .264 r
.26492 .47924 .27675 .43622 .29095 .39835 .28161 .41226 Metetra
.999 .836 .543 r
.28161 .41226 .29095 .39835 .30266 .39379 .29759 .34953 Metetra
.254 .181 .577 r
.29759 .34953 .30266 .39379 .31378 .39886 .30766 .36828 Metetra
.837 .564 .019 r
.30766 .36828 .31378 .39886 .32575 .39232 .31568 .42218 Metetra
.419 .093 .304 r
.31568 .42218 .32575 .39232 .33742 .39121 .3277 .4181 Metetra
.257 0 .215 r
.3277 .4181 .33742 .39121 .34411 .48283 .34014 .40755 Metetra
.759 .523 .576 r
.34014 .40755 .34411 .48283 .35585 .49 .35547 .34329 Metetra
.604 .381 .552 r
.35547 .34329 .35585 .49 .37004 .44845 .36861 .315 Metetra
.501 .303 .543 r
.36861 .315 .37004 .44845 .38667 .346 .38002 .32154 Metetra
.832 .528 0 r
.38002 .32154 .38667 .346 .39818 .35475 .38981 .3695 Metetra
.903 .578 .422 r
.38981 .3695 .39818 .35475 .40891 .38924 .39856 .45599 Metetra
.541 .258 .434 r
.39856 .45599 .40891 .38924 .42124 .38505 .41086 .46192 Metetra
.411 .153 .41 r
.41086 .46192 .42124 .38505 .43435 .35531 .42395 .44664 Metetra
0 0 .221 r
.42395 .44664 .43435 .35531 .44787 .30345 .43884 .3638 Metetra
0 0 .141 r
.43884 .3638 .44787 .30345 .46042 .2834 .45269 .30207 Metetra
.876 .842 .378 r
.45269 .30207 .46042 .2834 .47179 .32845 .4658 .25822 Metetra
.499 .327 .579 r
.4658 .25822 .47179 .32845 .48382 .3578 .47791 .26271 Metetra
.497 .312 .56 r
.47791 .26271 .48382 .3578 .49637 .36472 .49014 .26878 Metetra
.431 .263 .551 r
.49014 .26878 .49637 .36472 .50913 .3604 .50242 .2872 Metetra
.158 .08 .511 r
.50242 .2872 .50913 .3604 .52194 .35411 .51486 .33088 Metetra
0 0 .439 r
.51486 .33088 .52194 .35411 .53477 .3354 .52773 .36044 Metetra
.451 .102 .282 r
.52773 .36044 .53477 .3354 .54744 .30417 .54079 .35897 Metetra
.468 .183 .398 r
.54079 .35897 .54744 .30417 .56001 .27765 .55391 .35455 Metetra
.47 .203 .427 r
.55391 .35455 .56001 .27765 .57217 .23281 .56706 .34768 Metetra
.48 .228 .453 r
.56706 .34768 .57217 .23281 .58522 .2473 .58022 .33894 Metetra
.439 .187 .433 r
.58022 .33894 .58522 .2473 .59833 .25519 .59328 .32414 Metetra
.422 .16 .409 r
.59328 .32414 .59833 .25519 .61156 .26147 .60635 .31091 Metetra
.317 .057 .351 r
.60635 .31091 .61156 .26147 .62493 .26729 .61925 .29212 Metetra
0 0 .105 r
.61925 .29212 .62493 .26729 .63851 .27478 .63191 .26828 Metetra
.939 .831 .711 r
.63191 .26828 .63851 .27478 .65232 .28381 .64445 .24417 Metetra
.689 .502 .628 r
.64445 .24417 .65232 .28381 .66619 .28993 .65713 .22548 Metetra
.597 .404 .592 r
.65713 .22548 .66619 .28993 .6797 .28588 .6701 .21421 Metetra
.566 .377 .584 r
.6701 .21421 .6797 .28588 .69326 .28125 .68332 .20756 Metetra
.568 .377 .582 r
.68332 .20756 .69326 .28125 .70688 .27659 .69654 .20032 Metetra
.59 .391 .579 r
.69654 .20032 .70688 .27659 .71962 .25702 .70951 .18803 Metetra
.628 .422 .584 r
.70951 .18803 .71962 .25702 .73137 .2238 .72203 .1692 Metetra
0 0 .496 r
.72203 .1692 .73137 .2238 .74594 .23214 .73963 .22314 Metetra
.657 .751 .919 r
.73963 .22314 .74594 .23214 .75968 .22737 .75342 .21833 Metetra
.657 .751 .919 r
.75342 .21833 .75968 .22737 .77349 .22257 .76728 .21349 Metetra
.54 .873 .606 r
.10442 .45046 .11458 .44248 .12426 .44892 .11626 .44008 Metetra
.549 .671 .918 r
.11626 .44008 .12426 .44892 .13236 .46957 .12698 .43883 Metetra
.589 .455 .667 r
.12698 .43883 .13236 .46957 .14828 .4246 .13808 .43496 Metetra
.827 .482 .403 r
.13808 .43496 .14828 .4246 .15532 .45639 .14523 .46565 Metetra
.983 .902 .647 r
.14523 .46565 .15532 .45639 .16856 .43411 .15986 .43219 Metetra
.584 .897 .986 r
.15986 .43219 .16856 .43411 .17744 .45226 .17112 .42827 Metetra
.469 .411 .71 r
.17112 .42827 .17744 .45226 .18537 .48144 .18172 .43104 Metetra
.336 .225 .576 r
.18172 .43104 .18537 .48144 .20416 .40418 .19115 .44619 Metetra
.678 .371 .448 r
.19115 .44619 .20416 .40418 .21172 .43925 .19983 .47075 Metetra
.978 .855 .467 r
.19983 .47075 .21172 .43925 .22313 .43599 .21802 .39815 Metetra
.155 .126 .57 r
.21802 .39815 .22313 .43599 .23577 .41962 .22736 .41717 Metetra
.942 .803 .678 r
.22736 .41717 .23577 .41962 .25146 .36732 .2414 .38543 Metetra
.769 .423 .398 r
.2414 .38543 .25146 .36732 .2545 .46535 .25036 .41195 Metetra
.594 .414 .607 r
.25036 .41195 .2545 .46535 .26492 .47924 .2624 .40376 Metetra
.144 .054 .485 r
.2624 .40376 .26492 .47924 .28161 .41226 .27075 .44332 Metetra
.7 .373 .419 r
.27075 .44332 .28161 .41226 .29759 .34953 .28065 .46684 Metetra
.208 0 .363 r
.28065 .46684 .29759 .34953 .30766 .36828 .29636 .41168 Metetra
0 0 .104 r
.29636 .41168 .30766 .36828 .31568 .42218 .3105 .37531 Metetra
.296 .207 .582 r
.3105 .37531 .31568 .42218 .3277 .4181 .32104 .39277 Metetra
.621 .504 .699 r
.32104 .39277 .3277 .4181 .34014 .40755 .33317 .38724 Metetra
.893 .673 .599 r
.33317 .38724 .34014 .40755 .35547 .34329 .34832 .32861 Metetra
.944 .594 .196 r
.34832 .32861 .35547 .34329 .36861 .315 .35743 .37865 Metetra
.473 .196 .412 r
.35743 .37865 .36861 .315 .38002 .32154 .36963 .37444 Metetra
.298 .036 .337 r
.36963 .37444 .38002 .32154 .38981 .3695 .38256 .35534 Metetra
.928 .705 .58 r
.38256 .35534 .38981 .3695 .39856 .45599 .39737 .28876 Metetra
.198 .065 .464 r
.39737 .28876 .39856 .45599 .41086 .46192 .4062 .37195 Metetra
0 0 .378 r
.4062 .37195 .41086 .46192 .42395 .44664 .41594 .4499 Metetra
.41594 .4499 .42395 .44664 .43884 .3638 .42878 .44568 Metetra
.343 .099 .393 r
.42878 .44568 .43884 .3638 .45269 .30207 .44224 .42002 Metetra
.114 0 .344 r
.44224 .42002 .45269 .30207 .4658 .25822 .45663 .34568 Metetra
0 0 .249 r
.45663 .34568 .4658 .25822 .47791 .26271 .47054 .2706 Metetra
.659 .885 .529 r
.47054 .2706 .47791 .26271 .49014 .26878 .48315 .25441 Metetra
.893 .526 .058 r
.48315 .25441 .49014 .26878 .50242 .2872 .49512 .30006 Metetra
.824 .441 .327 r
.49512 .30006 .50242 .2872 .51486 .33088 .50763 .33334 Metetra
.139 0 0 r
.50763 .33334 .51486 .33088 .52773 .36044 .52056 .33301 Metetra
.598 .484 .695 r
.52056 .33301 .52773 .36044 .54079 .35897 .53357 .32855 Metetra
.669 .516 .668 r
.53357 .32855 .54079 .35897 .55391 .35455 .54659 .3168 Metetra
.81 .586 .598 r
.54659 .3168 .55391 .35455 .56706 .34768 .55924 .27236 Metetra
.658 .44 .578 r
.55924 .27236 .56706 .34768 .58022 .33894 .57188 .24457 Metetra
.641 .419 .565 r
.57188 .24457 .58022 .33894 .59328 .32414 .58434 .21472 Metetra
.48 .294 .551 r
.58434 .21472 .59328 .32414 .60635 .31091 .59762 .22537 Metetra
.431 .27 .561 r
.59762 .22537 .60635 .31091 .61925 .29212 .61126 .24234 Metetra
.324 .233 .596 r
.61126 .24234 .61925 .29212 .63191 .26828 .62524 .26182 Metetra
.608 .109 0 r
.62524 .26182 .63191 .26828 .64445 .24417 .63939 .27866 Metetra
.578 .241 .362 r
.63939 .27866 .64445 .24417 .65713 .22548 .65349 .28783 Metetra
.488 .206 .411 r
.65349 .28783 .65713 .22548 .6701 .21421 .66725 .28566 Metetra
.478 .205 .421 r
.66725 .28566 .6701 .21421 .68332 .20756 .68097 .28096 Metetra
.479 .207 .423 r
.68097 .28096 .68332 .20756 .69654 .20032 .69477 .27624 Metetra
.419 .163 .416 r
.69477 .27624 .69654 .20032 .70951 .18803 .70799 .26087 Metetra
.332 .095 .397 r
.70799 .26087 .70951 .18803 .72203 .1692 .72041 .23322 Metetra
.473 .196 .412 r
.72041 .23322 .72203 .1692 .73963 .22314 .73425 .2284 Metetra
.736 .906 .53 r
.73425 .2284 .73963 .22314 .75342 .21833 .7471 .20921 Metetra
.657 .751 .919 r
.7471 .20921 .75342 .21833 .76728 .21349 .76101 .20433 Metetra
.434 .449 .776 r
.09745 .43301 .10442 .45046 .11626 .44008 .10762 .4357 Metetra
.894 .487 .229 r
.10762 .4357 .11626 .44008 .12698 .43883 .11536 .45859 Metetra
.992 .88 .564 r
.11536 .45859 .12698 .43883 .13808 .43496 .13237 .40695 Metetra
0 0 .266 r
.13237 .40695 .13808 .43496 .14523 .46565 .13963 .4356 Metetra
.61 .473 .67 r
.13963 .4356 .14523 .46565 .15986 .43219 .15108 .43002 Metetra
.577 0 0 r
.15108 .43002 .15986 .43219 .17112 .42827 .16116 .43703 Metetra
.821 .458 .369 r
.16116 .43703 .17112 .42827 .18172 .43104 .16925 .46359 Metetra
.974 .86 .469 r
.16925 .46359 .18172 .43104 .19115 .44619 .18776 .39318 Metetra
.255 .159 .549 r
.18776 .39318 .19115 .44619 .19983 .47075 .19664 .41378 Metetra
.462 .309 .587 r
.19664 .41378 .19983 .47075 .21802 .39815 .20709 .42049 Metetra
.311 0 .19 r
.20709 .42049 .21802 .39815 .22736 .41717 .21888 .41438 Metetra
.95 .75 .597 r
.21888 .41438 .22736 .41717 .2414 .38543 .23587 .35155 Metetra
.977 .694 .305 r
.23587 .35155 .2414 .38543 .25036 .41195 .23864 .44714 Metetra
.653 .331 .415 r
.23864 .44714 .25036 .41195 .2624 .40376 .2487 .46477 Metetra
0 0 .096 r
.2487 .46477 .2624 .40376 .27075 .44332 .26471 .41109 Metetra
.874 .641 .582 r
.26471 .41109 .27075 .44332 .28065 .46684 .28249 .33035 Metetra
.418 .234 .523 r
.28249 .33035 .28065 .46684 .29636 .41168 .29204 .35523 Metetra
0 0 .44 r
.29204 .35523 .29636 .41168 .3105 .37531 .30074 .39609 Metetra
.469 .098 .253 r
.30074 .39609 .3105 .37531 .32104 .39277 .31249 .39643 Metetra
.31249 .39643 .32104 .39277 .33317 .38724 .32466 .39156 Metetra
.985 .882 .64 r
.32466 .39156 .33317 .38724 .34832 .32861 .33857 .35763 Metetra
.74 .768 .265 r
.33857 .35763 .34832 .32861 .35743 .37865 .35298 .31168 Metetra
.634 .429 .588 r
.35298 .31168 .35743 .37865 .36963 .37444 .36574 .29289 Metetra
0 0 .365 r
.36574 .29289 .36963 .37444 .38256 .35534 .37424 .36304 Metetra
.919 .587 .398 r
.37424 .36304 .38256 .35534 .39737 .28876 .38292 .44339 Metetra
.518 .263 .468 r
.38292 .44339 .39737 .28876 .4062 .37195 .39537 .44618 Metetra
.386 .127 .394 r
.39537 .44618 .4062 .37195 .41594 .4499 .40866 .42905 Metetra
.926 .685 .554 r
.40866 .42905 .41594 .4499 .42878 .44568 .42427 .33751 Metetra
.725 .482 .559 r
.42427 .33751 .42878 .44568 .44224 .42002 .43867 .26711 Metetra
.591 .367 .546 r
.43867 .26711 .44224 .42002 .45663 .34568 .45153 .24168 Metetra
.472 .288 .549 r
.45153 .24168 .45663 .34568 .47054 .2706 .46355 .25248 Metetra
.347 .398 .772 r
.46355 .25248 .47054 .2706 .48315 .25441 .47583 .25822 Metetra
.7 .2 .049 r
.47583 .25822 .48315 .25441 .49512 .30006 .48818 .26993 Metetra
0 0 .519 r
.48818 .26993 .49512 .30006 .50763 .33334 .50059 .29798 Metetra
.023 .06 .56 r
.50059 .29798 .50763 .33334 .52056 .33301 .51334 .32444 Metetra
.102 .453 .884 r
.51334 .32444 .52056 .33301 .53357 .32855 .52639 .32981 Metetra
.501 0 0 r
.52639 .32981 .53357 .32855 .54659 .3168 .53959 .33607 Metetra
.35 0 .178 r
.53959 .33607 .54659 .3168 .55924 .27236 .55285 .33164 Metetra
.466 .183 .4 r
.55285 .33164 .55924 .27236 .57188 .24457 .56618 .3271 Metetra
.463 .198 .426 r
.56618 .3271 .57188 .24457 .58434 .21472 .57951 .3191 Metetra
.459 .204 .44 r
.57951 .3191 .58434 .21472 .59762 .22537 .59279 .30738 Metetra
.413 .159 .416 r
.59279 .30738 .59762 .22537 .61126 .24234 .60595 .29078 Metetra
.273 .017 .33 r
.60595 .29078 .61126 .24234 .62524 .26182 .61893 .26933 Metetra
.797 .905 .503 r
.61893 .26933 .62524 .26182 .63939 .27866 .63176 .24613 Metetra
.73 .547 .643 r
.63176 .24613 .63939 .27866 .65349 .28783 .64459 .22529 Metetra
.627 .427 .591 r
.64459 .22529 .65349 .28783 .66725 .28566 .65751 .20845 Metetra
.597 .394 .577 r
.65751 .20845 .66725 .28566 .68097 .28096 .67051 .19423 Metetra
.588 .382 .569 r
.67051 .19423 .68097 .28096 .69477 .27624 .68351 .18021 Metetra
.589 .378 .563 r
.68351 .18021 .69477 .27624 .70799 .26087 .69638 .1643 Metetra
.599 .385 .562 r
.69638 .1643 .70799 .26087 .72041 .23322 .70902 .14534 Metetra
.154 .078 .512 r
.70902 .14534 .72041 .23322 .73425 .2284 .72684 .20491 Metetra
.611 .519 .726 r
.72684 .20491 .73425 .2284 .7471 .20921 .74072 .2 Metetra
.657 .751 .919 r
.74072 .2 .7471 .20921 .76101 .20433 .75468 .19508 Metetra
.316 0 0 r
.08842 .43078 .09745 .43301 .10762 .4357 .09848 .43448 Metetra
.846 .416 .208 r
.09848 .43448 .10762 .4357 .11536 .45859 .10681 .45245 Metetra
.895 .766 .711 r
.10681 .45245 .11536 .45859 .13237 .40695 .12066 .42754 Metetra
.043 0 .017 r
.12066 .42754 .13237 .40695 .13963 .4356 .1328 .41609 Metetra
.061 .186 .682 r
.1328 .41609 .13963 .4356 .15108 .43002 .14232 .42681 Metetra
.883 .852 .808 r
.14232 .42681 .15108 .43002 .16116 .43703 .15492 .41183 Metetra
.176 .207 .655 r
.15492 .41183 .16116 .43703 .16925 .46359 .16456 .42335 Metetra
0 0 .501 r
.16456 .42335 .16925 .46359 .18776 .39318 .17292 .4482 Metetra
.611 .315 .442 r
.17292 .4482 .18776 .39318 .19664 .41378 .1824 .46467 Metetra
.806 .78 .276 r
.1824 .46467 .19664 .41378 .20709 .42049 .2011 .39148 Metetra
0 0 .486 r
.2011 .39148 .20709 .42049 .21888 .41438 .21006 .41409 Metetra
.953 .84 .693 r
.21006 .41409 .21888 .41438 .23587 .35155 .22409 .38508 Metetra
.737 .418 .441 r
.22409 .38508 .23587 .35155 .23864 .44714 .2324 .41812 Metetra
.461 .381 .68 r
.2324 .41812 .23864 .44714 .2487 .46477 .24358 .42171 Metetra
.806 .582 .598 r
.24358 .42171 .2487 .46477 .26471 .41109 .25965 .36776 Metetra
.063 .045 .522 r
.25965 .36776 .26471 .41109 .28249 .33035 .26907 .39347 Metetra
.523 .237 .422 r
.26907 .39347 .28249 .33035 .29204 .35523 .28045 .39694 Metetra
.358 .062 .32 r
.28045 .39694 .29204 .35523 .30074 .39609 .29292 .38688 Metetra
.922 .737 .634 r
.29292 .38688 .30074 .39609 .31249 .39643 .30762 .34455 Metetra
.912 .665 .165 r
.30762 .34455 .31249 .39643 .32466 .39156 .31231 .45279 Metetra
.542 .251 .422 r
.31231 .45279 .32466 .39156 .33857 .35763 .32412 .45925 Metetra
.242 .021 .365 r
.32412 .45925 .33857 .35763 .35298 .31168 .33895 .41565 Metetra
0 0 .016 r
.33895 .41565 .35298 .31168 .36574 .29289 .35795 .28964 Metetra
.927 .553 .279 r
.35795 .28964 .36574 .29289 .37424 .36304 .36764 .33322 Metetra
.756 .49 0 r
.36764 .33322 .37424 .36304 .38292 .44339 .37746 .38298 Metetra
.557 .379 .596 r
.37746 .38298 .38292 .44339 .39537 .44618 .39003 .37867 Metetra
.639 .434 .588 r
.39003 .37867 .39537 .44618 .40866 .42905 .40328 .35833 Metetra
.801 .554 .564 r
.40328 .35833 .40866 .42905 .42427 .33751 .41859 .27588 Metetra
.703 .484 .588 r
.41859 .27588 .42427 .33751 .43867 .26711 .43184 .24264 Metetra
.802 .499 0 r
.43184 .24264 .43867 .26711 .45153 .24168 .44276 .29148 Metetra
.743 .425 .445 r
.44276 .29148 .45153 .24168 .46355 .25248 .45416 .34056 Metetra
.599 .314 .456 r
.45416 .34056 .46355 .25248 .47583 .25822 .46653 .36376 Metetra
.487 .225 .443 r
.46653 .36376 .47583 .25822 .48818 .26993 .47957 .35931 Metetra
.467 .203 .429 r
.47957 .35931 .48818 .26993 .50059 .29798 .4927 .35207 Metetra
.029 0 .247 r
.4927 .35207 .50059 .29798 .51334 .32444 .50607 .31226 Metetra
.947 .728 .575 r
.50607 .31226 .51334 .32444 .52639 .32981 .51925 .25389 Metetra
.672 .45 .575 r
.51925 .25389 .52639 .32981 .53959 .33607 .53209 .22176 Metetra
.666 .43 .554 r
.53209 .22176 .53959 .33607 .55285 .33164 .54467 .1755 Metetra
.437 .249 .527 r
.54467 .1755 .55285 .33164 .56618 .3271 .55774 .20127 Metetra
.428 .25 .535 r
.55774 .20127 .56618 .3271 .57951 .3191 .57109 .22459 Metetra
.391 .235 .547 r
.57109 .22459 .57951 .3191 .59279 .30738 .58477 .2488 Metetra
.335 .226 .578 r
.58477 .2488 .59279 .30738 .60595 .29078 .59868 .26971 Metetra
.07 .193 .686 r
.59868 .26971 .60595 .29078 .61893 .26933 .61272 .28522 Metetra
.609 .191 .224 r
.61272 .28522 .61893 .26933 .63176 .24613 .62682 .29461 Metetra
.505 .2 .383 r
.62682 .29461 .63176 .24613 .64459 .22529 .64081 .2962 Metetra
.472 .196 .413 r
.64081 .2962 .64459 .22529 .65751 .20845 .65467 .29146 Metetra
.479 .209 .426 r
.65467 .29146 .65751 .20845 .67051 .19423 .6686 .28669 Metetra
.459 .199 .431 r
.6686 .28669 .67051 .19423 .68351 .18021 .68234 .27692 Metetra
.392 .149 .422 r
.68234 .27692 .68351 .18021 .69638 .1643 .69529 .25247 Metetra
.294 .073 .398 r
.69529 .25247 .69638 .1643 .70902 .14534 .70729 .21393 Metetra
.47 .194 .412 r
.70729 .21393 .70902 .14534 .72684 .20491 .72122 .20902 Metetra
.773 .94 .594 r
.72122 .20902 .72684 .20491 .74072 .2 .73429 .19072 Metetra
.657 .751 .919 r
.73429 .19072 .74072 .2 .75468 .19508 .74829 .18574 Metetra
.601 .661 .88 r
.08038 .42053 .08842 .43078 .09848 .43448 .09125 .41806 Metetra
.859 .493 0 r
.09125 .41806 .09848 .43448 .10681 .45245 .09853 .44354 Metetra
.892 .728 .672 r
.09853 .44354 .10681 .45245 .12066 .42754 .11347 .41075 Metetra
.723 .616 .738 r
.11347 .41075 .12066 .42754 .1328 .41609 .12548 .40044 Metetra
.527 .53 .802 r
.12548 .40044 .1328 .41609 .14232 .42681 .13628 .4002 Metetra
.215 .223 .652 r
.13628 .4002 .14232 .42681 .15492 .41183 .14584 .41115 Metetra
.892 .517 .319 r
.14584 .41115 .15492 .41183 .16456 .42335 .15335 .4414 Metetra
.9 .918 .524 r
.15335 .4414 .16456 .42335 .17292 .4482 .16812 .40846 Metetra
.572 .419 .635 r
.16812 .40846 .17292 .4482 .1824 .46467 .17964 .4045 Metetra
.645 .444 .597 r
.17964 .4045 .1824 .46467 .2011 .39148 .19274 .38586 Metetra
0 .426 .824 r
.19274 .38586 .2011 .39148 .21006 .41409 .2035 .38997 Metetra
.627 .514 .705 r
.2035 .38997 .21006 .41409 .22409 .38508 .21534 .38419 Metetra
.916 .564 .354 r
.21534 .38419 .22409 .38508 .2324 .41812 .22256 .42838 Metetra
.818 .449 .357 r
.22256 .42838 .2324 .41812 .24358 .42171 .2316 .45668 Metetra
.936 .845 .406 r
.2316 .45668 .24358 .42171 .25965 .36776 .24938 .38643 Metetra
.24938 .38643 .25965 .36776 .26907 .39347 .26297 .36206 Metetra
.587 .455 .668 r
.26297 .36206 .26907 .39347 .28045 .39694 .27488 .35784 Metetra
.634 .465 .637 r
.27488 .35784 .28045 .39694 .29292 .38688 .28732 .34727 Metetra
.665 .486 .632 r
.28732 .34727 .29292 .38688 .30762 .34455 .30007 .33239 Metetra
.645 .652 .842 r
.30007 .33239 .30762 .34455 .31231 .45279 .31209 .32809 Metetra
.456 .266 .533 r
.31209 .32809 .31231 .45279 .32412 .45925 .32296 .34252 Metetra
.536 .331 .549 r
.32296 .34252 .32412 .45925 .33895 .41565 .33515 .3382 Metetra
.743 .507 .573 r
.33515 .3382 .33895 .41565 .35795 .28964 .35041 .28041 Metetra
.946 .586 .251 r
.35041 .28041 .35795 .28964 .36764 .33322 .35964 .33084 Metetra
.949 .624 .377 r
.35964 .33084 .36764 .33322 .37746 .38298 .36723 .42495 Metetra
.538 .221 .378 r
.36723 .42495 .37746 .38298 .39003 .37867 .3796 .43016 Metetra
.236 0 .301 r
.3796 .43016 .39003 .37867 .40328 .35833 .39324 .40791 Metetra
.921 .782 .304 r
.39324 .40791 .40328 .35833 .41859 .27588 .41021 .2927 Metetra
.845 .86 .408 r
.41021 .2927 .41859 .27588 .43184 .24264 .42377 .25654 Metetra
.823 .449 .346 r
.42377 .25654 .43184 .24264 .44276 .29148 .43511 .29078 Metetra
.83 .362 .083 r
.43511 .29078 .44276 .29148 .45416 .34056 .44713 .31198 Metetra
.594 .476 .687 r
.44713 .31198 .45416 .34056 .46653 .36376 .45996 .30748 Metetra
.594 .41 .602 r
.45996 .30748 .46653 .36376 .47957 .35931 .47293 .29798 Metetra
.712 .49 .586 r
.47293 .29798 .47957 .35931 .4927 .35207 .48625 .26233 Metetra
.598 .387 .567 r
.48625 .26233 .4927 .35207 .50607 .31226 .49922 .24532 Metetra
.55 .366 .585 r
.49922 .24532 .50607 .31226 .51925 .25389 .51209 .24107 Metetra
.572 .617 .859 r
.51209 .24107 .51925 .25389 .53209 .22176 .52502 .23908 Metetra
.486 .085 .205 r
.52502 .23908 .53209 .22176 .54467 .1755 .53806 .24116 Metetra
.549 .256 .422 r
.53806 .24116 .54467 .1755 .55774 .20127 .55127 .25 Metetra
.448 .153 .371 r
.55127 .25 .55774 .20127 .57109 .22459 .56449 .24529 Metetra
.351 0 .193 r
.56449 .24529 .57109 .22459 .58477 .2488 .57777 .24056 Metetra
.698 .784 .917 r
.57777 .24056 .58477 .2488 .59868 .26971 .59108 .23447 Metetra
.634 .477 .653 r
.59108 .23447 .59868 .26971 .61272 .28522 .60436 .22463 Metetra
.502 .34 .594 r
.60436 .22463 .61272 .28522 .62682 .29461 .61804 .2275 Metetra
.488 .324 .584 r
.61804 .2275 .62682 .29461 .64081 .2962 .63193 .23255 Metetra
.521 .351 .591 r
.63193 .23255 .64081 .2962 .65467 .29146 .64578 .2328 Metetra
.558 .382 .599 r
.64578 .2328 .65467 .29146 .6686 .28669 .65953 .22794 Metetra
.558 .382 .599 r
.65953 .22794 .6686 .28669 .68234 .27692 .67334 .22306 Metetra
.615 .428 .605 r
.67334 .22306 .68234 .27692 .69529 .25247 .68681 .21039 Metetra
.737 .528 .61 r
.68681 .21039 .69529 .25247 .70729 .21393 .69935 .18188 Metetra
.463 .38 .677 r
.69935 .18188 .70729 .21393 .72122 .20902 .71381 .18633 Metetra
.613 .528 .734 r
.71381 .18633 .72122 .20902 .73429 .19072 .7278 .18134 Metetra
.657 .751 .919 r
.7278 .18134 .73429 .19072 .74829 .18574 .74185 .17632 Metetra
.336 .447 .826 r
.07283 .40634 .08038 .42053 .09125 .41806 .08287 .40995 Metetra
.933 .562 .276 r
.08287 .40995 .09125 .41806 .09853 .44354 .0893 .44133 Metetra
.94 .751 .62 r
.0893 .44133 .09853 .44354 .11347 .41075 .10744 .38489 Metetra
.913 .616 .127 r
.10744 .38489 .11347 .41075 .12548 .40044 .11269 .42772 Metetra
0 0 .041 r
.11269 .42772 .12548 .40044 .13628 .4002 .12564 .41105 Metetra
.441 0 .084 r
.12564 .41105 .13628 .4002 .14584 .41115 .13643 .41215 Metetra
.874 .493 .316 r
.13643 .41215 .14584 .41115 .15335 .4414 .14419 .43988 Metetra
.95 .751 .601 r
.14419 .43988 .15335 .4414 .16812 .40846 .16276 .37459 Metetra
0 0 .438 r
.16276 .37459 .16812 .40846 .17964 .4045 .17093 .40061 Metetra
.846 .387 .093 r
.17093 .40061 .17964 .4045 .19274 .38586 .1802 .41865 Metetra
.274 0 .236 r
.1802 .41865 .19274 .38586 .2035 .38997 .19263 .40803 Metetra
.997 .814 .54 r
.19263 .40803 .2035 .38997 .21534 .38419 .21209 .32669 Metetra
.909 .682 .179 r
.21209 .32669 .21534 .38419 .22256 .42838 .2134 .42964 Metetra
.864 .462 .271 r
.2134 .42964 .22256 .42838 .2316 .45668 .22261 .45578 Metetra
.961 .758 .583 r
.22261 .45578 .2316 .45668 .24938 .38643 .24066 .38517 Metetra
.961 .749 .571 r
.24066 .38517 .24938 .38643 .26297 .36206 .25892 .30718 Metetra
.211 .126 .535 r
.25892 .30718 .26297 .36206 .27488 .35784 .26839 .33117 Metetra
.971 .67 .281 r
.26839 .33117 .27488 .35784 .28732 .34727 .27353 .41435 Metetra
.464 .184 .402 r
.27353 .41435 .28732 .34727 .30007 .33239 .28583 .41012 Metetra
.329 .076 .369 r
.28583 .41012 .30007 .33239 .31209 .32809 .29949 .38748 Metetra
.827 .756 .241 r
.29949 .38748 .31209 .32809 .32296 .34252 .31814 .28843 Metetra
.639 .443 .602 r
.31814 .28843 .32296 .34252 .33515 .3382 .33092 .27242 Metetra
.396 .25 .563 r
.33092 .27242 .33515 .3382 .35041 .28041 .34189 .28671 Metetra
.892 .533 .356 r
.34189 .28671 .35041 .28041 .35964 .33084 .35123 .33417 Metetra
.932 .6 .385 r
.35123 .33417 .35964 .33084 .36723 .42495 .35919 .41739 Metetra
.052 .464 .883 r
.35919 .41739 .36723 .42495 .3796 .43016 .37161 .42204 Metetra
.902 .786 .723 r
.37161 .42204 .3796 .43016 .39324 .40791 .38539 .39848 Metetra
.958 .722 .54 r
.38539 .39848 .39324 .40791 .41021 .2927 .40188 .30355 Metetra
.957 .907 .536 r
.40188 .30355 .41021 .2927 .42377 .25654 .41563 .26733 Metetra
.715 .878 .479 r
.41563 .26733 .42377 .25654 .43511 .29078 .42871 .24645 Metetra
.694 .496 .615 r
.42871 .24645 .43511 .29078 .44713 .31198 .44174 .22462 Metetra
.542 .346 .564 r
.44174 .22462 .44713 .31198 .45996 .30748 .45429 .22 Metetra
.616 .401 .567 r
.45429 .22 .45996 .30748 .47293 .29798 .46721 .19874 Metetra
.211 .095 .496 r
.46721 .19874 .47293 .29798 .48625 .26233 .47901 .24724 Metetra
.938 .589 .172 r
.47901 .24724 .48625 .26233 .49922 .24532 .49112 .31404 Metetra
.597 .298 .432 r
.49112 .31404 .49922 .24532 .51209 .24107 .5042 .33319 Metetra
.566 .283 .445 r
.5042 .33319 .51209 .24107 .52502 .23908 .51755 .34926 Metetra
.495 .23 .441 r
.51755 .34926 .52502 .23908 .53806 .24116 .53111 .34774 Metetra
.482 .218 .437 r
.53111 .34774 .53806 .24116 .55127 .25 .54475 .34311 Metetra
.456 .191 .424 r
.54475 .34311 .55127 .25 .56449 .24529 .55841 .33397 Metetra
.379 .129 .404 r
.55841 .33397 .56449 .24529 .57777 .24056 .5719 .31185 Metetra
.228 .001 .347 r
.5719 .31185 .57777 .24056 .59108 .23447 .58505 .27653 Metetra
0 0 .162 r
.58505 .27653 .59108 .23447 .60436 .22463 .59785 .23502 Metetra
.912 .872 .439 r
.59785 .23502 .60436 .22463 .61804 .2275 .61047 .19661 Metetra
.787 .586 .629 r
.61047 .19661 .61804 .2275 .63193 .23255 .62317 .16749 Metetra
.625 .421 .585 r
.62317 .16749 .63193 .23255 .64578 .2328 .63614 .14982 Metetra
.548 .353 .568 r
.63614 .14982 .64578 .2328 .65953 .22794 .64956 .14421 Metetra
.544 .35 .568 r
.64956 .14421 .65953 .22794 .67334 .22306 .66307 .13923 Metetra
.56 .361 .568 r
.66307 .13923 .67334 .22306 .68681 .21039 .67649 .13103 Metetra
.616 .403 .57 r
.67649 .13103 .68681 .21039 .69935 .18188 .68929 .11123 Metetra
0 0 .468 r
.68929 .11123 .69935 .18188 .71381 .18633 .70721 .17692 Metetra
.657 .751 .919 r
.70721 .17692 .71381 .18633 .7278 .18134 .72124 .17188 Metetra
.657 .751 .919 r
.72124 .17188 .7278 .18134 .74185 .17632 .73534 .16682 Metetra
.549 .675 .921 r
.0645 .39734 .07283 .40634 .08287 .40995 .07524 .39591 Metetra
.941 .579 .196 r
.07524 .39591 .08287 .40995 .0893 .44133 .08149 .42784 Metetra
.884 .694 .641 r
.08149 .42784 .0893 .44133 .10744 .38489 .09802 .38467 Metetra
.012 .587 .726 r
.09802 .38467 .10744 .38489 .11269 .42772 .10873 .38471 Metetra
.36 .254 .596 r
.10873 .38471 .11269 .42772 .12564 .41105 .11821 .39512 Metetra
.934 .578 .162 r
.11821 .39512 .12564 .41105 .13643 .41215 .1249 .42934 Metetra
.995 .869 .573 r
.1249 .42934 .13643 .41215 .14419 .43988 .14239 .3759 Metetra
.575 .386 .587 r
.14239 .3759 .14419 .43988 .16276 .37459 .15428 .36815 Metetra
.452 .718 .982 r
.15428 .36815 .16276 .37459 .17093 .40061 .16539 .36756 Metetra
.782 .538 0 r
.16539 .36756 .17093 .40061 .1802 .41865 .17163 .4123 Metetra
.88 .445 .111 r
.17163 .4123 .1802 .41865 .19263 .40803 .18064 .4345 Metetra
.983 .866 .495 r
.18064 .4345 .19263 .40803 .21209 .32669 .19873 .37011 Metetra
.026 0 .167 r
.19873 .37011 .21209 .32669 .2134 .42964 .21264 .34432 Metetra
.523 .331 .561 r
.21264 .34432 .2134 .42964 .22261 .45578 .22411 .34317 Metetra
.53 .326 .547 r
.22411 .34317 .22261 .45578 .24066 .38517 .23587 .33963 Metetra
.703 .503 .614 r
.23587 .33963 .24066 .38517 .25892 .30718 .24951 .31541 Metetra
.918 .606 .436 r
.24951 .31541 .25892 .30718 .26839 .33117 .25309 .40959 Metetra
.598 .31 .45 r
.25309 .40959 .26839 .33117 .27353 .41435 .26337 .43024 Metetra
.956 .904 .529 r
.26337 .43024 .27353 .41435 .28583 .41012 .27859 .38952 Metetra
.92 .683 .562 r
.27859 .38952 .28583 .41012 .29949 .38748 .29771 .29237 Metetra
.414 .242 .537 r
.29771 .29237 .29949 .38748 .31814 .28843 .30831 .3092 Metetra
.339 0 .177 r
.30831 .3092 .31814 .28843 .33092 .27242 .32051 .30479 Metetra
.332 .012 .264 r
.32051 .30479 .33092 .27242 .34189 .28671 .333 .29647 Metetra
.52 .055 .091 r
.333 .29647 .34189 .28671 .35123 .33417 .34481 .30049 Metetra
.583 .445 .66 r
.34481 .30049 .35123 .33417 .35919 .41739 .3572 .29603 Metetra
.624 .397 .553 r
.3572 .29603 .35919 .41739 .37161 .42204 .37104 .26354 Metetra
.505 .296 .53 r
.37104 .26354 .37161 .42204 .38539 .39848 .38311 .26604 Metetra
.02 0 .409 r
.38311 .26604 .38539 .39848 .40188 .30355 .39171 .35415 Metetra
.733 .413 .44 r
.39171 .35415 .40188 .30355 .41563 .26733 .40268 .40062 Metetra
.485 .227 .446 r
.40268 .40062 .41563 .26733 .42871 .24645 .41585 .39617 Metetra
.485 .23 .451 r
.41585 .39617 .42871 .24645 .44174 .22462 .42912 .39084 Metetra
.324 .103 .416 r
.42912 .39084 .44174 .22462 .45429 .22 .44371 .33597 Metetra
.115 0 .334 r
.44371 .33597 .45429 .22 .46721 .19874 .45828 .26598 Metetra
.017 0 .257 r
.45828 .26598 .46721 .19874 .47901 .24724 .47199 .21765 Metetra
.7 .537 .663 r
.47199 .21765 .47901 .24724 .49112 .31404 .48495 .20267 Metetra
.481 .289 .543 r
.48495 .20267 .49112 .31404 .5042 .33319 .49768 .21042 Metetra
.427 .246 .531 r
.49768 .21042 .5042 .33319 .51755 .34926 .51052 .23106 Metetra
.513 .312 .545 r
.51052 .23106 .51755 .34926 .53111 .34774 .52365 .23137 Metetra
.533 .328 .547 r
.52365 .23137 .53111 .34774 .54475 .34311 .53687 .2266 Metetra
.54 .333 .548 r
.53687 .2266 .54475 .34311 .55841 .33397 .55013 .22009 Metetra
.557 .346 .55 r
.55013 .22009 .55841 .33397 .5719 .31185 .56339 .20904 Metetra
.564 .355 .555 r
.56339 .20904 .5719 .31185 .58505 .27653 .57664 .19738 Metetra
.497 .318 .569 r
.57664 .19738 .58505 .27653 .59785 .23502 .59023 .20084 Metetra
.46 .367 .663 r
.59023 .20084 .59785 .23502 .61047 .19661 .60398 .2053 Metetra
.377 0 0 r
.60398 .2053 .61047 .19661 .62317 .16749 .61777 .206 Metetra
.422 .109 .327 r
.61777 .206 .62317 .16749 .63614 .14982 .63148 .20107 Metetra
.445 .15 .369 r
.63148 .20107 .63614 .14982 .64956 .14421 .64526 .19611 Metetra
.427 .137 .367 r
.64526 .19611 .64956 .14421 .66307 .13923 .65901 .18901 Metetra
.33 .058 .341 r
.65901 .18901 .66307 .13923 .67649 .13103 .67235 .17254 Metetra
.195 0 .283 r
.67235 .17254 .67649 .13103 .68929 .11123 .68528 .14925 Metetra
.631 .283 .363 r
.68528 .14925 .68929 .11123 .70721 .17692 .70054 .16742 Metetra
.657 .751 .919 r
.70054 .16742 .70721 .17692 .72124 .17188 .71462 .16233 Metetra
.657 .751 .919 r
.71462 .16233 .72124 .17188 .73534 .16682 .72877 .15722 Metetra
0 .292 .713 r
.05564 .39146 .0645 .39734 .07524 .39591 .06547 .39658 Metetra
.869 .486 .317 r
.06547 .39658 .07524 .39591 .08149 .42784 .07257 .42197 Metetra
.922 .741 .64 r
.07257 .42197 .08149 .42784 .09802 .38467 .08965 .37586 Metetra
.802 .334 0 r
.08965 .37586 .09802 .38467 .10873 .38471 .09827 .39169 Metetra
.419 .818 .601 r
.09827 .39169 .10873 .38471 .11821 .39512 .11019 .38347 Metetra
.13 .389 .842 r
.11019 .38347 .11821 .39512 .1249 .42934 .12043 .38877 Metetra
0 0 .314 r
.12043 .38877 .1249 .42934 .14239 .3759 .12717 .4235 Metetra
.836 .811 .325 r
.12717 .4235 .14239 .3759 .15428 .36815 .14644 .35565 Metetra
0 0 .447 r
.14644 .35565 .15428 .36815 .16539 .36756 .15591 .36931 Metetra
.197 .723 .733 r
.15591 .36931 .16539 .36756 .17163 .4123 .16737 .36664 Metetra
.594 .423 .619 r
.16737 .36664 .17163 .4123 .18064 .4345 .17943 .35909 Metetra
.716 .489 .58 r
.17943 .35909 .18064 .4345 .19873 .37011 .19551 .31354 Metetra
.824 .625 .073 r
.19551 .31354 .19873 .37011 .21264 .34432 .19828 .3967 Metetra
.659 .352 .442 r
.19828 .3967 .21264 .34432 .22411 .34317 .2073 .42302 Metetra
0 0 .155 r
.2073 .42302 .22411 .34317 .23587 .33963 .22477 .36261 Metetra
.987 .862 .499 r
.22477 .36261 .23587 .33963 .24951 .31541 .24213 .29945 Metetra
.883 .516 .037 r
.24213 .29945 .24951 .31541 .25309 .40959 .25077 .33219 Metetra
.466 .291 .559 r
.25077 .33219 .25309 .40959 .26337 .43024 .26189 .33919 Metetra
.537 .339 .559 r
.26189 .33919 .26337 .43024 .27859 .38952 .27404 .33486 Metetra
.568 .39 .601 r
.27404 .33486 .27859 .38952 .29771 .29237 .28637 .32901 Metetra
.334 .023 .28 r
.28637 .32901 .29771 .29237 .30831 .3092 .29898 .31982 Metetra
.982 .902 .577 r
.29898 .31982 .30831 .3092 .32051 .30479 .31361 .28124 Metetra
.795 .616 .659 r
.31361 .28124 .32051 .30479 .333 .29647 .32715 .25635 Metetra
.712 .497 0 r
.32715 .25635 .333 .29647 .34481 .30049 .33554 .31519 Metetra
.9 .569 .413 r
.33554 .31519 .34481 .30049 .3572 .29603 .34319 .39688 Metetra
.533 .257 .442 r
.34319 .39688 .3572 .29603 .37104 .26354 .35541 .40557 Metetra
.428 .179 .432 r
.35541 .40557 .37104 .26354 .38311 .26604 .3692 .38531 Metetra
0 0 .225 r
.3692 .38531 .38311 .26604 .39171 .35415 .38642 .2866 Metetra
.762 .523 .572 r
.38642 .2866 .39171 .35415 .40268 .40062 .40127 .22924 Metetra
.585 .356 .535 r
.40127 .22924 .40268 .40062 .41585 .39617 .41469 .2007 Metetra
.45 .248 .513 r
.41469 .2007 .41585 .39617 .42912 .39084 .42635 .22259 Metetra
.49 .283 .525 r
.42635 .22259 .42912 .39084 .44371 .33597 .43872 .2293 Metetra
.388 .22 .529 r
.43872 .2293 .44371 .33597 .45828 .26598 .45082 .25332 Metetra
0 0 .561 r
.45082 .25332 .45828 .26598 .47199 .21765 .46339 .26892 Metetra
.56 .247 .395 r
.46339 .26892 .47199 .21765 .48495 .20267 .47628 .27865 Metetra
.495 .213 .414 r
.47628 .27865 .48495 .20267 .49768 .21042 .48947 .27919 Metetra
.464 .182 .399 r
.48947 .27919 .49768 .21042 .51052 .23106 .5028 .27522 Metetra
.431 .124 .342 r
.5028 .27522 .51052 .23106 .52365 .23137 .5162 .27046 Metetra
.381 .072 .311 r
.5162 .27046 .52365 .23137 .53687 .2266 .52966 .26271 Metetra
.196 0 .24 r
.52966 .26271 .53687 .2266 .55013 .22009 .5431 .2446 Metetra
.103 0 .127 r
.5431 .2446 .55013 .22009 .56339 .20904 .55652 .22913 Metetra
.025 0 .048 r
.55652 .22913 .56339 .20904 .57664 .19738 .56991 .21414 Metetra
.082 0 .019 r
.56991 .21414 .57664 .19738 .59023 .20084 .58336 .20304 Metetra
.526 .909 .758 r
.58336 .20304 .59023 .20084 .60398 .2053 .59688 .19456 Metetra
.786 .76 .829 r
.59688 .19456 .60398 .2053 .61777 .206 .61037 .18352 Metetra
.745 .603 .699 r
.61037 .18352 .61777 .206 .63148 .20107 .62371 .16789 Metetra
.693 .521 .651 r
.62371 .16789 .63148 .20107 .64526 .19611 .63701 .15188 Metetra
.631 .452 .622 r
.63701 .15188 .64526 .19611 .65901 .18901 .65042 .13936 Metetra
.619 .434 .61 r
.65042 .13936 .65901 .18901 .67235 .17254 .66383 .12677 Metetra
.673 .477 .612 r
.66383 .12677 .67235 .17254 .68528 .14925 .67688 .10742 Metetra
0 0 .442 r
.67688 .10742 .68528 .14925 .70054 .16742 .69382 .15782 Metetra
.657 .751 .919 r
.69382 .15782 .70054 .16742 .71462 .16233 .70795 .15269 Metetra
.657 .751 .919 r
.70795 .15269 .71462 .16233 .72877 .15722 .72215 .14753 Metetra
.042 0 0 r
.04459 .39968 .05564 .39146 .06547 .39658 .0558 .39562 Metetra
.845 .419 .218 r
.0558 .39562 .06547 .39658 .07257 .42197 .06384 .41416 Metetra
.841 .764 .777 r
.06384 .41416 .07257 .42197 .08965 .37586 .07677 .39893 Metetra
.245 0 .136 r
.07677 .39893 .08965 .37586 .09827 .39169 .08858 .39175 Metetra
.102 0 0 r
.08858 .39175 .09827 .39169 .11019 .38347 .09938 .39252 Metetra
.817 .977 .681 r
.09938 .39252 .11019 .38347 .12043 .38877 .11252 .3757 Metetra
.828 .417 0 r
.11252 .3757 .12043 .38877 .12717 .4235 .12084 .39696 Metetra
.369 .333 .687 r
.12084 .39696 .12717 .4235 .14644 .35565 .13125 .40296 Metetra
.652 .342 .434 r
.13125 .40296 .14644 .35565 .15591 .36931 .13983 .42553 Metetra
.855 .805 .317 r
.13983 .42553 .15591 .36931 .16737 .36664 .16082 .34222 Metetra
.929 .618 .152 r
.16082 .34222 .16737 .36664 .17943 .35909 .16673 .38954 Metetra
.16673 .38954 .17943 .35909 .19551 .31354 .1809 .36438 Metetra
.572 .265 .409 r
.1809 .36438 .19551 .31354 .19828 .3967 .19124 .37491 Metetra
.312 .338 .728 r
.19124 .37491 .19828 .3967 .2073 .42302 .20214 .38145 Metetra
.786 .569 .606 r
.20214 .38145 .2073 .42302 .22477 .36261 .21801 .33816 Metetra
0 0 .214 r
.21801 .33816 .22477 .36261 .24213 .29945 .22677 .36852 Metetra
.544 .252 .423 r
.22677 .36852 .24213 .29945 .25077 .33219 .2378 .37699 Metetra
.289 0 .284 r
.2378 .37699 .25077 .33219 .26189 .33919 .25091 .36315 Metetra
.998 .832 .492 r
.25091 .36315 .26189 .33919 .27404 .33486 .26962 .28096 Metetra
.956 .699 .249 r
.26962 .28096 .27404 .33486 .28637 .32901 .27107 .41188 Metetra
.531 .247 .429 r
.27107 .41188 .28637 .32901 .29898 .31982 .28284 .41924 Metetra
.268 .031 .358 r
.28284 .41924 .29898 .31982 .31361 .28124 .29783 .3832 Metetra
.761 .695 .152 r
.29783 .3832 .31361 .28124 .32715 .25635 .32043 .2308 Metetra
.89 .583 .078 r
.32043 .2308 .32715 .25635 .33554 .31519 .3289 .28502 Metetra
.928 .631 .158 r
.3289 .28502 .33554 .31519 .34319 .39688 .3367 .3594 Metetra
.553 .416 .649 r
.3367 .3594 .34319 .39688 .35541 .40557 .34943 .35674 Metetra
.654 .463 .613 r
.34943 .35674 .35541 .40557 .3692 .38531 .36297 .33969 Metetra
.867 .618 .559 r
.36297 .33969 .3692 .38531 .38642 .2866 .37999 .24823 Metetra
.828 .597 .59 r
.37999 .24823 .38642 .2866 .40127 .22924 .39469 .19551 Metetra
0 0 .16 r
.39469 .19551 .40127 .22924 .41469 .2007 .40502 .24621 Metetra
.758 .431 .431 r
.40502 .24621 .41469 .2007 .42635 .22259 .41586 .29695 Metetra
.609 .309 .436 r
.41586 .29695 .42635 .22259 .43872 .2293 .42805 .32091 Metetra
.469 .197 .418 r
.42805 .32091 .43872 .2293 .45082 .25332 .4413 .31626 Metetra
.448 .16 .383 r
.4413 .31626 .45082 .25332 .46339 .26892 .45462 .31111 Metetra
0 0 .142 r
.45462 .31111 .46339 .26892 .47628 .27865 .46855 .27599 Metetra
.984 .783 .553 r
.46855 .27599 .47628 .27865 .48947 .27919 .48264 .21584 Metetra
.702 .478 .581 r
.48264 .21584 .48947 .27919 .5028 .27522 .49606 .18161 Metetra
.692 .453 .556 r
.49606 .18161 .5028 .27522 .5162 .27046 .50936 .13426 Metetra
.399 .22 .519 r
.50936 .13426 .5162 .27046 .52966 .26271 .52229 .16213 Metetra
.383 .221 .534 r
.52229 .16213 .52966 .26271 .5431 .2446 .53555 .18599 Metetra
.222 .142 .549 r
.53555 .18599 .5431 .2446 .55652 .22913 .54917 .2143 Metetra
.638 .265 0 r
.54917 .2143 .55652 .22913 .56991 .21414 .56315 .24269 Metetra
.689 .319 .34 r
.56315 .24269 .56991 .21414 .58336 .20304 .5774 .26545 Metetra
.558 .251 .403 r
.5774 .26545 .58336 .20304 .59688 .19456 .59174 .27719 Metetra
.476 .197 .411 r
.59174 .27719 .59688 .19456 .61037 .18352 .60592 .27442 Metetra
.468 .195 .416 r
.60592 .27442 .61037 .18352 .62371 .16789 .62013 .26947 Metetra
.472 .203 .424 r
.62013 .26947 .62371 .16789 .63701 .15188 .63442 .2645 Metetra
.42 .167 .422 r
.63442 .2645 .63701 .15188 .65042 .13936 .64822 .24593 Metetra
.344 .108 .405 r
.64822 .24593 .65042 .13936 .66383 .12677 .66133 .21285 Metetra
.227 .012 .364 r
.66133 .21285 .66383 .12677 .67688 .10742 .67371 .16913 Metetra
.45 .162 .383 r
.67371 .16913 .67688 .10742 .69382 .15782 .68789 .16398 Metetra
.747 .901 .514 r
.68789 .16398 .69382 .15782 .70795 .15269 .70121 .14296 Metetra
.657 .751 .919 r
.70121 .14296 .70795 .15269 .72215 .14753 .71545 .13775 Metetra
.681 .562 .714 r
.03785 .37842 .04459 .39968 .0558 .39562 .04977 .36944 Metetra
.776 .501 0 r
.04977 .36944 .0558 .39562 .06384 .41416 .05583 .4008 Metetra
.887 .696 .639 r
.05583 .4008 .06384 .41416 .07677 .39893 .07293 .35655 Metetra
0 0 .404 r
.07293 .35655 .07677 .39893 .08858 .39175 .07965 .38544 Metetra
.874 .786 .76 r
.07965 .38544 .08858 .39175 .09938 .39252 .09304 .36709 Metetra
.667 .531 .69 r
.09304 .36709 .09938 .39252 .11252 .3757 .10522 .35763 Metetra
.965 .639 .28 r
.10522 .35763 .11252 .3757 .12084 .39696 .10989 .4066 Metetra
.982 .8 .585 r
.10989 .4066 .12084 .39696 .13125 .40296 .12966 .33821 Metetra
.445 .282 .565 r
.12966 .33821 .13125 .40296 .13983 .42553 .13984 .34551 Metetra
.295 .153 .512 r
.13984 .34551 .13983 .42553 .16082 .34222 .14814 .36978 Metetra
.14814 .36978 .16082 .34222 .16673 .38954 .16242 .34404 Metetra
.742 .531 .609 r
.16242 .34404 .16673 .38954 .1809 .36438 .17743 .31082 Metetra
0 0 .241 r
.17743 .31082 .1809 .36438 .19124 .37491 .18334 .36097 Metetra
.949 .595 .23 r
.18334 .36097 .19124 .37491 .20214 .38145 .19041 .40425 Metetra
.992 .861 .514 r
.19041 .40425 .20214 .38145 .21801 .33816 .20871 .33927 Metetra
.969 .845 .666 r
.20871 .33927 .21801 .33816 .22677 .36852 .22363 .3053 Metetra
.564 .377 .585 r
.22363 .3053 .22677 .36852 .2378 .37699 .23586 .29852 Metetra
.042 0 .438 r
.23586 .29852 .2378 .37699 .25091 .36315 .24355 .34339 Metetra
.242 .32 .744 r
.24355 .34339 .25091 .36315 .26962 .28096 .25483 .35091 Metetra
.29 .03 .335 r
.25483 .35091 .26962 .28096 .27107 .41188 .26868 .32875 Metetra
.74 .501 .568 r
.26868 .32875 .27107 .41188 .28284 .41924 .28541 .26837 Metetra
.517 .304 .529 r
.28541 .26837 .28284 .41924 .29783 .3832 .29754 .26544 Metetra
.586 .365 .548 r
.29754 .26544 .29783 .3832 .32043 .2308 .31091 .2456 Metetra
.768 .385 .329 r
.31091 .2456 .32043 .2308 .3289 .28502 .32133 .2696 Metetra
.969 .651 .334 r
.32133 .2696 .3289 .28502 .3367 .3594 .32739 .36878 Metetra
.767 .346 .25 r
.32739 .36878 .3367 .3594 .34943 .35674 .33891 .3888 Metetra
.174 0 .18 r
.33891 .3888 .34943 .35674 .36297 .33969 .35256 .37399 Metetra
.977 .812 .4 r
.35256 .37399 .36297 .33969 .37999 .24823 .37058 .27123 Metetra
.84 .832 .359 r
.37058 .27123 .37999 .24823 .39469 .19551 .38525 .2258 Metetra
.228 0 .203 r
.38525 .2258 .39469 .19551 .40502 .24621 .39824 .2137 Metetra
.391 .322 .659 r
.39824 .2137 .40502 .24621 .41586 .29695 .41052 .22082 Metetra
.541 .349 .57 r
.41052 .22082 .41586 .29695 .42805 .32091 .42335 .21606 Metetra
.573 .359 .552 r
.42335 .21606 .42805 .32091 .4413 .31626 .43653 .20119 Metetra
.411 .233 .527 r
.43653 .20119 .4413 .31626 .45462 .31111 .44881 .22155 Metetra
.364 .211 .535 r
.44881 .22155 .45462 .31111 .46855 .27599 .46132 .24436 Metetra
.224 .218 .642 r
.46132 .24436 .46855 .27599 .48264 .21584 .47426 .25879 Metetra
.666 .328 .393 r
.47426 .25879 .48264 .21584 .49606 .18161 .48731 .28423 Metetra
.47 .2 .422 r
.48731 .28423 .49606 .18161 .50936 .13426 .50091 .27941 Metetra
.48 .22 .442 r
.50091 .27941 .50936 .13426 .52229 .16213 .51459 .27457 Metetra
.322 .087 .394 r
.51459 .27457 .52229 .16213 .53555 .18599 .52829 .23828 Metetra
.185 0 .286 r
.52829 .23828 .53555 .18599 .54917 .2143 .54184 .21137 Metetra
.948 .911 .749 r
.54184 .21137 .54917 .2143 .56315 .24269 .55532 .19016 Metetra
.651 .452 .602 r
.55532 .19016 .56315 .24269 .5774 .26545 .56875 .17171 Metetra
.592 .377 .558 r
.56875 .17171 .5774 .26545 .59174 .27719 .58214 .15355 Metetra
.566 .347 .542 r
.58214 .15355 .59174 .27719 .60592 .27442 .59552 .13734 Metetra
.529 .316 .535 r
.59552 .13734 .60592 .27442 .62013 .26947 .60914 .13103 Metetra
.487 .285 .532 r
.60914 .13103 .62013 .26947 .63442 .2645 .62323 .13706 Metetra
.51 .305 .538 r
.62323 .13706 .63442 .2645 .64822 .24593 .63725 .13655 Metetra
.531 .326 .547 r
.63725 .13655 .64822 .24593 .66133 .21285 .65119 .13138 Metetra
.54 .346 .566 r
.65119 .13138 .66133 .21285 .67371 .16913 .66519 .12619 Metetra
.369 .28 .623 r
.66519 .12619 .67371 .16913 .68789 .16398 .68017 .13837 Metetra
.603 .505 .716 r
.68017 .13837 .68789 .16398 .70121 .14296 .6944 .13314 Metetra
.657 .751 .919 r
.6944 .13314 .70121 .14296 .71545 .13775 .7087 .12788 Metetra
.888 .99 .753 r
.0267 .38554 .03785 .37842 .04977 .36944 .03992 .36857 Metetra
.219 .735 .87 r
.03992 .36857 .04977 .36944 .05583 .4008 .05074 .36743 Metetra
.578 .439 .656 r
.05074 .36743 .05583 .4008 .07293 .35655 .06208 .36325 Metetra
.859 .511 .393 r
.06208 .36325 .07293 .35655 .07965 .38544 .06785 .39864 Metetra
.989 .89 .618 r
.06785 .39864 .07965 .38544 .09304 .36709 .08462 .35692 Metetra
.651 .694 .878 r
.08462 .35692 .09304 .36709 .10522 .35763 .09612 .35269 Metetra
0 .498 .852 r
.09612 .35269 .10522 .35763 .10989 .4066 .10674 .35555 Metetra
.346 .226 .571 r
.10674 .35555 .10989 .4066 .12966 .33821 .11624 .36787 Metetra
.765 .44 .436 r
.11624 .36787 .12966 .33821 .13984 .34551 .12278 .40534 Metetra
.761 .759 .247 r
.12278 .40534 .13984 .34551 .14814 .36978 .14343 .32915 Metetra
.357 .26 .606 r
.14343 .32915 .14814 .36978 .16242 .34404 .15354 .33867 Metetra
.885 .817 .776 r
.15354 .33867 .16242 .34404 .17743 .31082 .16689 .32108 Metetra
.694 .274 .243 r
.16689 .32108 .17743 .31082 .18334 .36097 .1769 .33342 Metetra
.617 .492 .687 r
.1769 .33342 .18334 .36097 .19041 .40425 .18906 .32725 Metetra
.147 .046 .473 r
.18906 .32725 .19041 .40425 .20871 .33927 .19699 .36254 Metetra
.791 .45 .411 r
.19699 .36254 .20871 .33927 .22363 .3053 .20499 .40061 Metetra
0 0 .232 r
.20499 .40061 .22363 .3053 .23586 .29852 .22264 .34164 Metetra
.22264 .34164 .23586 .29852 .24355 .34339 .23866 .29648 Metetra
.366 .254 .592 r
.23866 .29648 .24355 .34339 .25483 .35091 .24951 .30734 Metetra
.564 .405 .624 r
.24951 .30734 .25483 .35091 .26868 .32875 .26182 .30284 Metetra
.838 .633 .625 r
.26182 .30284 .26868 .32875 .28541 .26837 .27699 .26337 Metetra
.907 .501 .193 r
.27699 .26337 .28541 .26837 .29754 .26544 .2865 .29521 Metetra
.376 .034 .251 r
.2865 .29521 .29754 .26544 .31091 .2456 .29899 .29065 Metetra
.288 0 .283 r
.29899 .29065 .31091 .2456 .32133 .2696 .31218 .27672 Metetra
.995 .814 .549 r
.31218 .27672 .32133 .2696 .32739 .36878 .32859 .2128 Metetra
.168 .034 .442 r
.32859 .2128 .32739 .36878 .33891 .3888 .33629 .28557 Metetra
0 0 .319 r
.33629 .28557 .33891 .3888 .35256 .37399 .3438 .37367 Metetra
.272 .775 .855 r
.3438 .37367 .35256 .37399 .37058 .27123 .35689 .37117 Metetra
.332 .083 .378 r
.35689 .37117 .37058 .27123 .38525 .2258 .37127 .34361 Metetra
.026 0 .285 r
.37127 .34361 .38525 .2258 .39824 .2137 .38773 .26669 Metetra
.38773 .26669 .39824 .2137 .41052 .22082 .40333 .19767 Metetra
.769 .607 .679 r
.40333 .19767 .41052 .22082 .42335 .21606 .41666 .17833 Metetra
0 0 .323 r
.41666 .17833 .42335 .21606 .43653 .20119 .42792 .22215 Metetra
.718 .334 .322 r
.42792 .22215 .43653 .20119 .44881 .22155 .44026 .24401 Metetra
.359 0 .186 r
.44026 .24401 .44881 .22155 .46132 .24436 .45349 .24025 Metetra
.615 .883 .99 r
.45349 .24025 .46132 .24436 .47426 .25879 .46681 .23539 Metetra
.646 .542 .722 r
.46681 .23539 .47426 .25879 .48731 .28423 .48024 .2279 Metetra
.686 .473 .592 r
.48024 .2279 .48731 .28423 .50091 .27941 .49391 .20112 Metetra
.641 .421 .569 r
.49391 .20112 .50091 .27941 .51459 .27457 .50744 .17528 Metetra
.65 .417 .553 r
.50744 .17528 .51459 .27457 .52829 .23828 .52087 .13933 Metetra
.43 .254 .54 r
.52087 .13933 .52829 .23828 .54184 .21137 .53425 .15396 Metetra
.323 .214 .572 r
.53425 .15396 .54184 .21137 .55532 .19016 .5479 .1728 Metetra
0 .132 .673 r
.5479 .1728 .55532 .19016 .56875 .17171 .56179 .18811 Metetra
.564 .137 .189 r
.56179 .18811 .56875 .17171 .58214 .15355 .5758 .19542 Metetra
.472 .148 .335 r
.5758 .19542 .58214 .15355 .59552 .13734 .58984 .19559 Metetra
.444 .149 .369 r
.58984 .19559 .59552 .13734 .60914 .13103 .60388 .19104 Metetra
.442 .149 .371 r
.60388 .19104 .60914 .13103 .62323 .13706 .61798 .18592 Metetra
.428 .123 .345 r
.61798 .18592 .62323 .13706 .63725 .13655 .63215 .18077 Metetra
.358 .06 .315 r
.63215 .18077 .63725 .13655 .65119 .13138 .64617 .17011 Metetra
.179 0 .248 r
.64617 .17011 .65119 .13138 .66519 .12619 .65973 .14887 Metetra
.338 0 .184 r
.65973 .14887 .66519 .12619 .68017 .13837 .67401 .14363 Metetra
.775 .927 .56 r
.67401 .14363 .68017 .13837 .6944 .13314 .68753 .12322 Metetra
.657 .751 .919 r
.68753 .12322 .6944 .13314 .7087 .12788 .70188 .11791 Metetra
.46 .415 .721 r
.02015 .36247 .0267 .38554 .03992 .36857 .03044 .36444 Metetra
.825 .352 .065 r
.03044 .36444 .03992 .36857 .05074 .36743 .03884 .37949 Metetra
.642 .894 .563 r
.03884 .37949 .05074 .36743 .06208 .36325 .05189 .36438 Metetra
.924 .916 .79 r
.05189 .36438 .06208 .36325 .06785 .39864 .06533 .34643 Metetra
.505 .342 .594 r
.06533 .34643 .06785 .39864 .08462 .35692 .07611 .34689 Metetra
.813 .359 0 r
.07611 .34689 .08462 .35692 .09612 .35269 .08465 .36424 Metetra
.772 .394 .34 r
.08465 .36424 .09612 .35269 .10674 .35555 .09288 .38537 Metetra
.09288 .38537 .10674 .35555 .11624 .36787 .10802 .35547 Metetra
.642 .652 .844 r
.10802 .35547 .11624 .36787 .12278 .40534 .11978 .35116 Metetra
.716 .503 .599 r
.11978 .35116 .12278 .40534 .14343 .32915 .13508 .31872 Metetra
.583 .119 0 r
.13508 .31872 .14343 .32915 .15354 .33867 .14478 .33143 Metetra
.655 .778 .939 r
.14478 .33143 .15354 .33867 .16689 .32108 .15666 .32705 Metetra
.882 .533 .381 r
.15666 .32705 .16689 .32108 .1769 .33342 .16314 .3708 Metetra
.642 .311 .396 r
.16314 .3708 .1769 .33342 .18906 .32725 .17287 .38861 Metetra
.775 .756 .241 r
.17287 .38861 .18906 .32725 .19699 .36254 .19356 .30507 Metetra
.136 .063 .502 r
.19356 .30507 .19699 .36254 .20499 .40061 .20243 .33187 Metetra
.541 .354 .576 r
.20243 .33187 .20499 .40061 .22264 .34164 .21468 .32741 Metetra
.904 .706 .624 r
.21468 .32741 .22264 .34164 .23866 .29648 .231 .28045 Metetra
.694 .625 .775 r
.231 .28045 .23866 .29648 .24951 .30734 .24351 .27251 Metetra
.277 .229 .622 r
.24351 .27251 .24951 .30734 .26182 .30284 .25434 .28424 Metetra
0 0 .549 r
.25434 .28424 .26182 .30284 .27699 .26337 .26495 .30067 Metetra
.399 .074 .294 r
.26495 .30067 .27699 .26337 .2865 .29521 .27745 .2961 Metetra
.977 .775 .564 r
.27745 .2961 .2865 .29521 .29899 .29065 .29493 .22642 Metetra
.154 .071 .501 r
.29493 .22642 .29899 .29065 .31218 .27672 .30478 .25695 Metetra
.973 .663 .333 r
.30478 .25695 .31218 .27672 .32859 .2128 .30961 .36692 Metetra
.505 .239 .446 r
.30961 .36692 .32859 .2128 .33629 .28557 .32209 .37171 Metetra
.322 .065 .36 r
.32209 .37171 .33629 .28557 .3438 .37367 .33642 .34779 Metetra
.934 .68 .529 r
.33642 .34779 .3438 .37367 .35689 .37117 .35659 .21676 Metetra
.598 .365 .535 r
.35659 .21676 .35689 .37117 .37127 .34361 .37074 .18422 Metetra
.282 .121 .476 r
.37074 .18422 .37127 .34361 .38773 .26669 .38065 .23795 Metetra
0 0 .362 r
.38065 .23795 .38773 .26669 .40333 .19767 .392 .27089 Metetra
.45 .165 .389 r
.392 .27089 .40333 .19767 .41666 .17833 .40519 .2661 Metetra
.455 .179 .404 r
.40519 .2661 .41666 .17833 .42792 .22215 .41847 .26075 Metetra
0 0 .094 r
.41847 .26075 .42792 .22215 .44026 .24401 .43262 .22821 Metetra
.897 .71 .641 r
.43262 .22821 .44026 .24401 .45349 .24025 .4467 .19224 Metetra
.605 .426 .613 r
.4467 .19224 .45349 .24025 .46681 .23539 .46001 .18195 Metetra
.509 .349 .6 r
.46001 .18195 .46681 .23539 .48024 .2279 .47316 .18215 Metetra
.562 .401 .62 r
.47316 .18215 .48024 .2279 .49391 .20112 .48649 .17718 Metetra
.605 .513 .724 r
.48649 .17718 .49391 .20112 .50744 .17528 .49988 .17217 Metetra
.661 .927 .973 r
.49988 .17217 .50744 .17528 .52087 .13933 .51334 .16583 Metetra
.386 .029 .23 r
.51334 .16583 .52087 .13933 .53425 .15396 .52686 .16233 Metetra
.445 0 0 r
.52686 .16233 .53425 .15396 .5479 .1728 .5405 .16538 Metetra
0 .323 .785 r
.5405 .16538 .5479 .1728 .56179 .18811 .55432 .17286 Metetra
.088 .299 .78 r
.55432 .17286 .56179 .18811 .5758 .19542 .56836 .18258 Metetra
.041 .317 .803 r
.56836 .18258 .5758 .19542 .58984 .19559 .58259 .19163 Metetra
0 .463 .803 r
.58259 .19163 .58984 .19559 .60388 .19104 .59691 .19572 Metetra
.59691 .19572 .60388 .19104 .61798 .18592 .61113 .19056 Metetra
.61113 .19056 .61798 .18592 .63215 .18077 .62542 .18538 Metetra
.62542 .18538 .63215 .18077 .64617 .17011 .63972 .17868 Metetra
.664 .848 .443 r
.63972 .17868 .64617 .17011 .65973 .14887 .65345 .15731 Metetra
.083 0 0 r
.65345 .15731 .65973 .14887 .67401 .14363 .66788 .15203 Metetra
.877 .876 .439 r
.66788 .15203 .67401 .14363 .68753 .12322 .68083 .11771 Metetra
.788 .915 .925 r
.68083 .11771 .68753 .12322 .70188 .11791 .695 .10785 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.25276 .17071 m
.25721 .17554 L
s
[(20)] .24387 .16106 .92124 1 Mshowa
.5007 .07363 m
.50469 .07884 L
s
[(40)] .49274 .0632 .76389 1 Mshowa
.125 Mabswid
.08106 .23795 m
.0839 .24068 L
s
.13703 .21603 m
.13981 .21882 L
s
.19425 .19363 m
.19697 .19647 L
s
.31262 .14728 m
.31522 .15023 L
s
.37386 .1233 m
.3764 .12631 L
s
.43654 .09875 m
.43901 .10182 L
s
.56641 .0479 m
.56872 .05109 L
s
.63371 .02155 m
.63593 .02479 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{433, 351.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001GaP00`40o`000?l0003ooooook;oool0
0?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooook;oool0
0?oooonboooo003ooooo;oooo`800021oooo003ooooo;Oooo`8000000oooo`0000000020oooo003o
oooo:_ooo`<00003oooo0P00083oool00?oooolXoooo0P0000Koool00`000?ooo`00001ooooo003o
oooo9Oooo`<00008oooo00@0003oooooool0001noooo003ooooo8_ooo`<0000;oooo00@0003ooooo
ool0001noooo003ooooo8?ooo`80000>oooo00D0003oooooooooool00000OOooo`00oooooagoool3
00004?ooo`030000oooooooo00;oool00`000?ooooooo`1joooo003ooooo6oooo`80000Coooo00<0
003oooooool00_ooo`030000oooooooo07[oool00?oooolHoooo0`0001Koool00`000?ooooooo`02
oooo00<0003oooooool0NOooo`00oooooaKoool200000_ooo`030000oooooooo01Coool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00oooooa?oool300006oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo003ooooo4?ooo`<0000Noooo00<0003oooooool01?ooo`030000oooooooo
07Ooool00?ooool>oooo0P00027oool00`000?ooooooo`05oooo00<0003oooooool0M_ooo`00oooo
o`_oool300008oooo`030000oooooooo00Goool00`000?ooooooo`1foooo003ooooo2Oooo`80000V
oooo00<0003oooooool01_ooo`030000oooooooo07Goool00?ooool6oooo0`0002Soool00`000?oo
ooooo`06oooo0P0007Koool00?ooool4oooo0P0002_oool00`000?ooooooo`05oooo0`0007Koool0
0=Ooool300000_ooo`030000oooooooo027oool30000;Oooo`030000oooooooo00Soool00`000?oo
ooooo`1coooo003Hoooo00H0003oooooool0003oool0000Ooooo0`00033oool00`000?ooooooo`08
oooo00<0003oooooool0Loooo`00e_ooo`@000001?ooo`000?ooo`0001goool20000<oooo`030000
oooooooo00Woool00`000?ooooooo`1boooo003Foooo00<0003oool000000_ooo`030000oooo0000
01[oool300000_ooo`030000oooooooo033oool00`000?ooooooo`0:oooo00<0003oooooool0LOoo
o`00eoooo`800002oooo00<0003oool000006?ooo`80000hoooo00<0003oooooool02_ooo`030000
oooooooo077oool00=Soool01@000?ooooooooooo`00000Foooo0`0003[oool00`000?ooooooo`0;
oooo00<0003oooooool0L?ooo`00lOooo`80000moooo00<0003oooooool03?ooo`030000oooooooo
06ooool00>koool30000?oooo`030000oooooooo00coool00`000?ooooooo`1_oooo003[oooo0`00
04?oool00`000?ooooooo`0<oooo00<0003oooooool0K_ooo`00jOooo`800016oooo00<0003ooooo
ool03Oooo`030000oooooooo06goool00>Koool30000B?ooo`030000oooooooo00goool00`000?oo
ooooo`1]oooo003Toooo0P0004_oool00`000?ooooooo`0>oooo00<0003oooooool0K?ooo`00hOoo
o`<0001=oooo00<0003oooooool03oooo`030000oooooooo06_oool00=ooool2000000?oool0003o
ool0COooo`030000oooooooo00ooool00`000?ooooooo`1[oooo003Loooo0`0000Coool00`000?oo
ooooo`1;oooo00<0003oooooool04?ooo`030000oooooooo06[oool00=Woool30000EOooo`030000
oooooooo017oool00`000?ooooooo`1Yoooo003Goooo0P0005Soool00`000?ooooooo`0Aoooo00<0
003oooooool0JOooo`00e?ooo`<0001Joooo00<0003oooooool04_ooo`030000oooooooo06Soool0
0=;oool20000GOooo`030000oooooooo01?oool00`000?ooooooo`1Woooo003?oooo0`0005ooool0
0`000?ooooooo`0Aoooo0`0006Woool00<goool20000H_ooo`030000oooooooo01Coool00`000?oo
ooooo`1Voooo003:oooo0`0006Coool00`000?ooooooo`0Eoooo00<0003oooooool0IOooo`00aooo
o`<0001Woooo00<0003oooooool05Oooo`030000oooooooo06Goool00<Goool30000JOooo`030000
oooooooo01Koool00`000?ooooooo`1Toooo0032oooo0`0000?oool00`000?ooooooo`1Voooo00<0
003oooooool05oooo`030000oooooooo06?oool00<3oool20000L?ooo`030000oooooooo01Koool0
0`000?ooooooo`1Soooo002moooo0`0006[oool00`000?ooooooo`04oooo0P0001Woool00`000?oo
ooooo`1Roooo002koooo0P0006coool200001Oooo`030000bN[/000001Woool00`000?ooooooo`1R
oooo002hoooo0`0006koool300000_ooo`800002bN[/00<0003oooooool06?ooo`030000oooooooo
067oool00;Goool30000L?ooo`060000>P=M00000000oooo00001<WZk080000Joooo00<0003ooooo
ool0H?ooo`00/oooo`80001boooo00<0000j0edj0ed00`0000G9j^`200006_ooo`030000oooooooo
063oool00;3oool30000M?ooo`050000>P=M>P=M0000LbUR00800004bN[/0`0001[oool00`000?oo
ooooo`1Ooooo002^oooo0P0007Koool0100003X3GCX3GCX3G@8000001>3PL0000<WZk<WZk0<00002
Z<3[00<0003oooooool06?ooo`030000oooooooo05koool00:_oool30000N?ooo`040000>P=M>P=M
>P=M0P0000;Ph70200000ZS0j`050000Z<3[Z<3[Z<3[000001Woool00`000?ooooooo`1Noooo002Y
oooo0P0000?oool00`000?ooooooo`1coooo0P0000@j0ed01P000>3PL>3PL0000<K]S`0000:X`>/0
1@000:S0jjS0jjS0j`00000Joooo00<0003oooooool0GOooo`00Y_ooo`<0001hoooo0`000003;@0o
0000000000<j0ed010000>3PL>3PL00000;6kHl00`000:S0j`000003Z<3[0P0001[oool00`000?oo
ooooo`1Loooo002Soooo0`0006Soool200003_ooo`<00004;@0o00<0001F02l000000SX3G@030000
h>1`000000?6kHl00`000:S0j`00000300000ZS0j`030000oooooooo01Ooool00`000?ooooooo`1L
oooo002Qoooo0P0004;oool00`000?ooooooo`0Toooo0`000004LBIN0000000000002Oooo`800000
0e/?D00002d0?`03;@0o00@0001F02mF02mF02l2000000?Ph7000036kHl00lK]S`<00006Z<3[00<0
003oooooool05oooo`030000oooooooo05_oool009koool30000A?ooo`030000oooooooo02;oool2
00000W4VGP030000LBINLBIN009a9Uh900000e/?D0030000;@0o;@0o008]03l00`0005H0;eH0;`02
EP0_00@0003Ph7000036kHl300000YZ1]`030000Z<3[Z<3[00BX`>/00`000?ooooooo`0Foooo00<0
003oool00000G?ooo`00W?ooo`800016oooo0`0000;oool00`000?ooooooo`0Loooo0P0000Aa9Uh0
0`00074VGW4VGP03LBIN00<0001]7eQ]7eP00fdOF0030000F`m@F`m@009K3e000`0002d0?bd0?`02
;@0o00H0001F02mF02mF02l0003Ph70300001IZ1]`800005Z<3[0P0001Woool00`000?ooooooo`1J
oooo001^oooo0`0000?oool00`000?ooooooo`0Roooo0`0004Soool300000_ooo`80000Loooo0P00
00Ea9Uh00`00074VGW4VGP03LBIN00<0001]7eQ]7eP00fdOF0050000F`m@F`m@F`m@000000D]03l0
1P0005H0;eH0;eH0;`000>3PL0800006VX6g0P0000:X`>/300000ZS0j`030000oooooooo01Ooool0
0`000?ooooooo`1Ioooo001^oooo00<0003oooooool00_ooo`030000oooo0000027oool20000Booo
o`8000000gXhL@0000000002HPLj00<0003oooooool06?ooo`030000N2EE000000Ea9Uh00`00074V
GW4VGP03LBIN00<0001]7eQ]7eP00VdOF0030000F`m@F`m@009K3e000`0002d0?bd0?`02;@0o00<0
001F02mF02l00UH0;`800002GTNO00<0002JPKNJPKL019Z1]`<00006Z<3[00<0003oooooool05ooo
o`030000oooooooo05Soool006ooool01`000?ooooooooooo`000?ooo`00000Noooo0`0004coool0
100007PcK00007XhL@800003HPLj00<0003oooooool05_ooo`040000N2EEN2EE00001G4VGP030000
LBINLBIN00=a9Uh00`0006dOF6dOF002KAmH00<0001K3e1K3e000U/?D0030000;@0o;@0o008]03l0
0`0005H0;`00000300000ei7W`030000VX6gVX6g00BJPKL00`000;oVP`000006Z<3[00<0003ooooo
ool05oooo`030000oooooooo05Soool006ooool01`000?ooooooooooo`000?ooo`00000Koooo0`00
04ooool00`0007PcK0000002NSQa00<0001R1cYR1cX00V87>P030000oooooooo01Goool0100007PU
EGPUE@0000Aa9Uh00`00074VGW4VGP04LBIN00<0001]7eQ]7eP00VdOF0030000F`m@F`m@009K3e00
0`0002d0?bd0?`02;@0o0P00008E00000`0005i7Wei7W`02GTNO00<0002JPKNJPKL019Z1]`040000
_nJ3_nJ300001JS0j`80000Ioooo00<0003oooooool0Eoooo`00K_ooo`030000oooo000000;oool0
0`000?ooo`00000Ioooo0P0000?oool00`000?ooooooo`1<oooo00@0001h<f`0001j>74200001F87
>P030000oooooooo01?oool01@0007PUEGPUEGPUE@000004LBIN00<0001a9Uia9Uh00g4VGP030000
KAmHKAmH00=]7eP00`0005/?D5/?D002F`m@00D0000]03l]03l]03l000000aD000800004GTNO00<0
002JPKNJPKL00iZ1]`800002_nJ300<0002X`>^X`>/00`0000:X`>/00`000?ooooooo`0Goooo00<0
003oooooool0E_ooo`00Koooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo0`0005Coool2
00000WXhL@030000HPLjHPLj00ER1cX00`000?ooooooo`0Aoooo00D0001h9EEh9EEh9ED000001G4V
GP030000LBINLBIN00=a9Uh00`0006dOF6dOF003KAmH00<0001K3e1K3e000U/?D0040000;@0o;@0o
00000aD000<00005GTNO00L0002JPKNJPKNJPKL0002oiX<000000[oVP`<00005Z<3[00<0003ooooo
ool05oooo`030000oooooooo05Koool008[oool20000E_ooo`030000N3=/0000009j>7400`000687
>V87>P04HPLj00<0001a000000004Oooo`800003N2EE00<0001a9Uia9Uh00g4VGP030000LBINLBIN
00=a9Uh00`0006dOF6dOF003KAmH00<0001K3e1K3e000U/?D0030000;@0o;@0o00@00003RUR@00<0
001NAimNAil00Ui7W`060000VX6gVX6gVX6g0000_nJ30`0000:X`>/00`000:S0jjS0j`04Z<3[00<0
003oooooool05oooo`030000oooooooo05Goool008Ooool30000F?ooo`040000N3=/0000NSQa0P00
00ER1cX01@000740074007400000000?oooo00<0002@8c0000000gPUE@030000LBINLBIN00=a9Uh0
0`00074VGW4VGP03LBIN00<0001]7eQ]7eP00VdOF0030000F`m@F`m@00=K3e00100002d0?`000000
00J:F9000`0005i7Wei7W`02GTNO00<0002JPKNJPKL0100000FX`>/00`000:S0jjS0j`02Z<3[0P00
01[oool00`000?ooooooo`1Doooo0025oooo0P0005_oool0100007PcK00007XhL@800005HPLj00D0
001a001a001a000000003oooo`800004N2EE00<0001a9Uia9Uh00g4VGP030000LBINLBIN00=a9Uh0
0`0006dOF6dOF002KAmH00<0001K3e1K3e000U/?D0040000;@0o000000001hYHT0030000GTNOGTNO
009NAil00`0009Z1]`00000400001JS0j`030000Z<3[Z<3[00800002Z<3[00<0003oooooool05ooo
o`030000oooooooo05Coool008;oool30000G?ooo`060000N3=/N3=/0000NSQa00000f87>PD00003
L@0000<0003oooooool02oooo`030000T2<`000000Ah9ED00`00074VGW4VGP03LBIN00<0001a9Uia
9Uh00g4VGP030000KAmHKAmH009]7eP00`0005/?D5/?D002F`m@00D0000]03l00027Dh`000001XYH
T0030000GTNOGTNO00=NAil200000YeWT@800005Z<3[0`0000FX`>/00`000?ooooooo`0Goooo00<0
003oooooool0Doooo`00Ooooo`<0001Ooooo00<0001h<fah<f`01`0000A^@HX500002oooo`040000
T2<`T2<`000017PUE@030000LBINLBIN00=a9Uh00`00074VGW4VGP03LBIN00<0001]7eQ]7eP00VdO
F0030000F`m@F`m@009K3e0200000XMCS0030000RUR@RUR@00F:F900100005i7Wei7Wei7W`800003
WFNA0P0000:X`>/300000ZS0j`030000Z<3[Z<3[00>X`>/00`000?ooooooo`0Hoooo00<0003ooooo
ool01_ooo`<00003oooo00<0003oooooool0@oooo`00OOooo`80001Roooo00<0001h<fah<f`00P00
00BVJXd00`0006i1RVi1RP03KT6:00<0001B=Y9B=Y800P0000Woool01@00090S<90S<90S<0000004
N2EE00<0001a9Uia9Uh00g4VGP030000LBINLBIN00=a9Uh00`0006dOF6dOF002KAmH00<0001K3e1K
3e000U/?D0800002Qe><00<0002:F92:F9001HYHT0040000GTNO000000001IeWT@@00005Z<3[00<0
002X`>^X`>/00jS0j`80000Ioooo00<0003oooooool01_ooo`030000oooooooo00;oool00`000?oo
o`000014oooo001joooo0`0006?oool01P0007PcK00000000:W]n@0000BVJXd00`0006i1RVi1RP03
KT6:00@0001B=Y9B=Y9B=Y8300001oooo`050000T2<`T2<`T2<`000000Ah9ED00`00074VGW4VGP03
LBIN00<0001a9Uia9Uh00g4VGP030000KAmHKAmH009]7eP00`0005/?D5/?D002F`m@00D00027Dhb7
Dhb7Dh`000001hYHT08000000hmLT@0009eWT@04WFNA0P000003001g0000Z<3[00FX`>/00`000:S0
j`00000200000ZS0j`030000oooooooo01Ooool00`000?ooooooo`06oooo00L0003oooooooooool0
003oool00000A?ooo`00N?ooo`800002oooo00<0003oooooool0HOooo`<000000jW]n@000:IZS@04
YVZ=00<0001^@HY^@HX00fi1RP030000DSJBDSJB009B=Y800`00001Bb0000005oooo00<0002@8c2@
8c000Y0S<0030000N2EEN2EE009h9ED00`00074VGW4VGP03LBIN00<0001a9Uia9Uh00g4VGP050000
KAmHKAmHKAmH000000=K3e0300000hMCS0030000RUR@RUR@00F:F900100008mLTHmLT@0000FMIi42
000000<007L0002X`>/01:S0j`<00006Z<3[00<0003oooooool05oooo`030000oooooooo00Goool0
1`000?ooooooooooo`000?ooo`000014oooo001eoooo0`0000Coool00`000?ooooooo`1Noooo0`00
00>JPkT200001JIZS@030000KT6:KT6:00=^@HX00`00058fTU8fTP02DSJB1@0000;oool200000i0S
<0030000N2EEN2EE00=h9ED00`00074VGW4VGP03LBIN00<0001a9Uia9Uh00W4VGP030000KAmHKAmH
009]7eP00`0005/?D5/?D003000018MCS0030000RUR@RUR@00B:F9001@0008mLTHmLTHmLT@000006
WFNA00D0000007L007L0002X`>/00`0000:X`>/00`000:S0jjS0j`04Z<3[00<0003oooooool05ooo
o`030000oooooooo00Coool00`000?ooo`000002oooo00<0003oool00000A?ooo`00Loooo`800019
oooo00<0003oooooool06Oooo`<00006VX>i0P0000FVJXd00`0006i1RVi1RP03KT6:00<0001B=Y9B
=Y800e8fTP07000005;800005Tc70000oooo000000B@8c000`0007PUEGPUE@03N2EE00<0001a9Uia
9Uh00W4VGP030000LBINLBIN00=a9Uh00`0006dOF6dOF002KAmH1P0000B7Dh`00`0008YHT8YHT004
RUR@00D0002?G96?G96?G94000001YeWT@030000001g001g00800006Z<3[00<0002X`>^X`>/00jS0
j`80000Ioooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`13oooo001`
oooo0`0004[oool200006Oooo`8000000hmVWP0009Z3^@06VX>i0P0000FVJXd00`0006i1RVi1RP03
KT6:00<0001B=Y9B=Y800e8fTP<000025Tc70P0000B@8c000`0007PUEGPUE@03N2EE00<0001a9Uia
9Uh00W4VGP030000LBINLBIN00=a9Uh00`0006dOF6dOF002KAmH1P0000B7Dh`00`0008YHT8YHT004
RUR@00D0002?G96?G96?G94000001YeWT@050000001g001g001g000000JX`>/00`000:S0jjS0j`03
00000ZS0j`030000oooooooo01Koool00`000?ooooooo`1?oooo001]oooo0`0004goool300004?oo
o`P00004SfJN00<0002JPkVJPkT00iZ3^@030000Y6^A000000FVJXd00`0006i1RVi1RP04KT6:00<0
001B=Y9B=Y800e8fTP<000035Tc700D0002@8c2@8c2@8c00000017PUE@030000LBINLBIN00=a9Uh0
0`00074VGW4VGP03LBIN00<0001]7eQ]7eP01@0000:2CXT00`0008MCS8MCS002Qe><00<0002:F92:
F9000hYHT0030000SebASebA00>?G9400`0009eWTIeWT@03WFNA0P0000<007L00`000:S0jjS0j`03
Z<3[0`0000FX`>/00`000?ooooooo`0Doooo0P000003oooo0000oooo04ooool006_oool20000?_oo
o`030000oooooooo00koool0100007<ZH`00000000ooool200001H9IV@030000SfJNSfJN00>?IYh0
0`0009Z3^IZ3^@03VX>i00<0002TJi4000001JIZS@030000KT6:KT6:00A^@HX00`00058fTU8fTP03
DSJB00<000008J`0000011I<a`8000000i0S<00007PUE@03N2EE00<0001a9Uia9Uh00g4VGP030000
LBINLBIN00=a9Uh500001H9>R@030000Qe><Qe><00>7Dh`00`0008YHT8YHT002RUR@00<0002?G96?
G9400hmLT@030000WFNAWFNA00>MIi4600000ZS0j`<00002W8Nk00<0002X`>^X`>/01:S0j`030000
oooooooo01Ooool00`000?ooooooo`1=oooo001Xoooo0`00043oool00`000?ooooooo`0=oooo00<0
001c:V=c:V<00P0000goool2000000>JKI`00022FIT0189IV@030000SfJNSfJN00>?IYh00`0009Z3
^IZ3^@02VX>i00@0002TJi6TJi400005YVZ=00<0001^@HY^@HX016i1RP030000DSJBDSJB00AB=Y83
00000aI<a`0400002U7=0000000017PUE@030000LBINLBIN00=a9Uh00`00074VGW4VGP02LBIN1000
0003O4R80000PTj900B2CXT00`0008MCS8MCS003Qe><00<0002:F92:F9000XYHT0030000SebASebA
00>?G9400`0009eWTIeWT@02WFNA0`0000=fHJd300001Yb7^`030000Z<3[Z<3[00:X`>/200006Ooo
o`030000oooooooo04goool006Koool20000@_ooo`80000?oooo00D0001c:V<0001d;FL000003?oo
o`050000VVfLVVfLVVfL000000F2FIT00`0008mVWXmVWP04SfJN00D0002JPkVJPkVJPkT000000ZA[
T@030000YVZ=YVZ=00BVJXd00`0006i1RVi1RP03KT6:00<0001B=Y9B=Y80158fTP030000YW>J0000
00@FC<L0100000YAc@00000000=h9ED00`00074VGW4VGP03LBIN00<0001a9Uh00000100000=lB8P0
0`00089>RH9>R@03PTj900<00027Dhb7Dh`00hMCS0050000RUR@RUR@RUR@000000J?G9400`0009eW
TIeWT@02WFNA00<0002lQi`0000017IQ[@030000W8NkW8Nk00FLQk/00`000:S0jjS0j`0200000ZS0
j`030000oooooooo01Ooool00`000?ooooooo`1<oooo001Soooo0`0004Coool300003Oooo`040000
LbYSLbYS00000W@]I`030000oooooooo00Soool00`0009Y]W9Y]W003VVfL00<00022FIV2FIT00h9I
V@030000SfJNSfJN00>?IYh0100009Z3^IZ3^@0000BTJi400`000:IZSJIZS@03YVZ=00<0001^@HY^
@HX00fi1RP030000DSJBDSJB00=B=Y8200000ZIcVP8000025Tc700@0000:DLd:DLd:DLd2000000=h
9ED0001a9Uh00g4VGPH00005O4R800<00022CXV2CXT00h9>R@030000Qe><Qe><00>7Dh`0100008YH
T8YHT8YHT0800005SebA00D0002MIi6MIi6MIi4000000[b7W0030000MV6]MV6]00=fHJd00`0009b7
^ib7^`05W8Nk0P0000FX`>/00`000?ooooooo`0Goooo00<0003oooooool0Boooo`00HOooo`800016
oooo00@0002IGHP00000000=oooo00@0001c:V=c:V<00002M2eW00<0003oooooool02?ooo`030000
VVfLVVfL00>JKI`00`00089IVH9IV@03PUVI00<0002?IYj?IYh00hmVWP040000VX>iVX>i00001:A[
T@030000YVZ=YVZ=00>VJXd00`0006i1RVi1RP03KT6:00<0001B=Y9B=Y800e8fTP800004YW>J0P00
00035Tc700002U7=008:DLd:00000XM@R0030000O4R8O4R800=lB8P00`00089>RH9>R@03PTj900<0
0027Dhb7Dh`00hMCS0040000RUR@RUR@RUR@0P0000F?G9401@0009eWTIeWTIeWT@000002_8NL00<0
001fHJefHJd00gIQ[@030000W8NkW8Nk00BLQk/00`000<G`V0000005Z<3[0P0001Soool00`000?oo
ooooo`1;oooo001Noooo0`0000;oool00`000?ooooooo`13oooo00@0002IGHP000000008oooo00D0
003oooooooooool000000g<ZH`040000M2eWM2eW00002Oooo`800005VVfL00<00022FIV2FIT00h9I
V@030000SfJNSfJN00>?IYh00`0009Z3^@000005Y6^A00<0002VJXfVJXd00jIZS@030000KT6:KT6:
00=^@HX00`00058fTU8fTP02DSJB00<0003bjKl000001JIcVPd00005Qe2800<0001lB8QlB8P00ga8
R0030000PTj9PTj900>2CXT00`0008MCS8MCS003Qe><00H0002:F92:F900002;FI400005SebA00@0
002MIi6MIi400003_8NL00<0001fHJefHJd00gIQ[@030000W8NkW8Nk00>LQk/010000<G`V<G`V000
00:X`>/300000ZS0j`030000oooooooo01Koool00`000?ooooooo`1:oooo001Koooo0`0004[oool0
0`0009UMR9UMR00200002?ooo`050000oooooooooooo000000=c:V<0100007@]Ig@]I`0000Woool2
00001IY]W0030000PUVIPUVI00>2FIT00`0008mVWXmVWP04SfJN0P0000FTJi400`000:IZSJIZS@03
YVZ=00<0001^@HY^@HX00fi1RP050000DSJBDSJBDSJB000000?bjKl00`000:IcVZIcVP02YW>J00<0
002GH8jGH8h00iMPSP030000T5R:T5R:00>@F8X00`0008M@R8M@R003Qe2800<0001lB8QlB8P00ga8
R0030000PTj9PTj900>2CXT00`0008MCS8MCS003Qe><00H0002:F92:F900002;FI400005SebA00@0
002MIi6MIi400003_8NL0P0000EfHJd01@0009b7^ib7^ib7^`000003aO2H0`0000JX`>/00`000?oo
ooooo`0Foooo00<0003oooooool0BOooo`00FOooo`80001=oooo00<0002IGHRIGHP00P0000Ooool2
00000oooo`050000LbYSLbYSLbYS000000=d;FL00`000?ooooooo`03oooo00<0003oool000000^Fe
Y0030000VVfLVVfL00:JKI`00`00089IVH9IV@03PUVI00<0002?IYj?IYh018mVWP030000Y6^AY6^A
00BTJi400`000:IZSJIZS@03YVZ=00<0001^@HY^@HX016i1RP040000DSJBDSJB00000o;Y_`030000
YW>JYW>J00:VLiX00`0009MPSYMPSP04Uf2>00<0002@F8Z@F8X00Y1HRP030000Qe28Qe2800>7D8P0
0`0007a8R7a8R003O4R800<00022CXV2CXT00h9>R@030000Qe><Qe><00>7Dh`01P0008YHT8YHT000
08]IT@0000J?G9400`0009eWT@000003_8NL0P0000EfHJd01P0009b7^ib7^ib7^`000<G`V0800002
W8Bi00<0002X`>^X`>/01:S0j`030000oooooooo01Koool00`000?ooooooo`19oooo001Foooo0`00
04koool0100009UMR9UMR9UMR0800007oooo00@0000j03<0003oool200000g<ZH`050000M2eWM2eW
M2eW000000Coool400000^FeY0030000VVfLVVfL00:JKI`00`00089IVH9IV@03PUVI00<0002?IYj?
IYh018mVWP030000Y6^AY6^A00BTJi400`000:IZSJIZS@03YVZ=00<0001^@HY^@HX016i1RP030000
DSJB000000CbjKl00`000:IcVZIcVP02YW>J00<0002GH8jGH8h019MPSP030000T5R:T5R:00:@F8X0
0`0008M@R8M@R003Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900>2CXT00`0008MCS8MCS004
Qe><0P0000:;FI400`0008mLTHmLT@04SebA0P0000BlQi`200001GIQ[@030000W8NkW8Nk00<00005
W8Bi00<0002X`>^X`>/00jS0j`80000Hoooo00<0003oooooool0B?ooo`00E?ooo`80001Aoooo00L0
002IGHRIGHRIGHP000187WT000001_ooo`050000>P0c0000oooo000000Ac:V<01@0007@]Ig@]Ig@]
I`000003oooo0P000003]eEB0000000000;U]J@00`0009Y]W9Y]W002VVfL00<00022FIV2FIT0189I
V@030000SfJNSfJN00:?IYh200001ZA[T@030000YVZ=YVZ=00>VJXd00`0006i1RVi1RP04KT6:0P00
00GbjKl00`000:IcVZIcVP02YW>J00<0002GH8jGH8h019MPSP030000T5R:T5R:00>@F8X00`0008M@
R8M@R002Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900B2CXT00`0008MCS8MCS003Qe><0P00
00:;FI400`0008mLTHmLT@04SebA0P0000BlQi`200001WIQ[@@00006W8Bi00<0002X`>^X`>/00`00
00:X`>/00`000?ooooooo`0Foooo00<0003oooooool0Aoooo`00DOooo`<0001Boooo00<0002IGHRI
GHP00YUMR0030000B1ii000000Goool01P0003X0<cX0<`000?ooo`0000Ac:V<01@0007@]Ig@]Ig@]
I`000002oooo00D000000580002gEE8000000nFeY0030000VVfLVVfL00>JKI`00`00089IVH9IV@03
PUVI00<0002?IYj?IYh00XmVWP800006Y6^A00<0002VJXfVJXd00jIZS@030000KT6:KT6:00A^@HX2
00001O;Y_`030000YW>JYW>J00>VLiX00`0009MPSYMPSP03Uf2>00<0002@F8Z@F8X00i1HRP030000
Qe28Qe2800:7D8P00`0007a8R7a8R003O4R800<00022CXV2CXT0189>R@030000Qe><Qe><00>7Dh`2
00000X]IT@030000SebASebA00B?G9400`000;b7W;b7W003_8NL00<0002lQi`0000017IQ[@800003
9a>300<0002LQ;VLQ;T019b4^@800005Z<3[00<0003oooooool05_ooo`030000oooooooo04Ooool0
04ooool20000EOooo`030000VEf8VEf800:IGHP00`0004PNN@000005oooo00H0000j03<j03<0003o
ool00003LbYS00<0001d;FMd;FL00g@]I`8000001@00DP000;MED[MEDP000003iKFT00<0002JKIbJ
KI`00iY]W0030000PUVIPUVI00>2FIT01`0008mVWXmVWXmVWP000:miU`000006Y6^A00<0002VJXfV
JXd00jIZS@030000KT6:KT6:00A^@HX200001O;Y_`030000YW>JYW>J00>VLiX00`0009MPSYMPSP03
Uf2>00<0002@F8Z@F8X00i1HRP030000Qe28Qe2800:7D8P00`0007a8R7a8R003O4R800<00022CXV2
CXT0189>R@030000Qe><Qe><00>7Dh`01@0008]ITH]ITH]IT@000006SebA00<0002lQiblQi`00kb7
W0040000_8NL0000MV6]100000@W4h<00`0009b4^Ib4^@03W8Bi00<0002lihL000001ZS0j`030000
oooooooo01Koool00`000?ooooooo`16oooo001<oooo0`0004_oool00`000?ooooooo`08oooo00<0
002IGHRIGHP00iUMR0030000B1ii000000Goool0100003X0<cX0<cX0<`800003LbYS00<0001d;FMd
;FL00g@]I`060000001B001B0000]eEB00001>FeY0030000VVfLVVfL00>JKI`00`00089IVH9IV@03
PUVI00L0002?IYj?IYj?IYh0002_NIL000001ZA[T@030000YVZ=YVZ=00>VJXd00`0006i1RVi1RP03
KT6:00<0000h98`h98`00P0000?bjKl00`000:IcVZIcVP03YW>J00<0002GH8jGH8h00iMPSP030000
T5R:T5R:00>@F8X00`0008M@R8M@R002Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900B2CXT0
0`0008MCS8MCS003Qe><00<0002;FI6;FI400X]IT@030000SebASebA00:?G94200001Kb7W0040000
_8NL000000000iURS`0300009a>39a>3008W4h<00`0009b4^Ib4^@03W8Bi00@0002lihNlihL00004
Z<3[0P0001Woool00`000?ooooooo`15oooo0019oooo0`0004koool00`000?ooooooo`08oooo00<0
002IGHRIGHP00iUMR0030000B1ii000000Coool0100003X0<cX0<cX0<`<00003LbYS00<0001d;FMd
;FL00g@]I`030000001B000000:gEE800`000>FeY>FeY003iKFT00<0002JKIbJKI`00YY]W0030000
PUVIPUVI00>2FIT0100008mVWXmVWP0000>_NIL00`000:A[TJA[T@03Y6^A00<0002VJXfVJXd00jIZ
S@030000KT6:KT6:00=^@HX00`0003PTS3PTS002>2B<00D0003bjKobjKobjKl000001:IcVP030000
Uf2>Uf2>00>GH8h00`00091HRY1HRP03T5R:00<00027D8R7D8P00XM@R0030000O4R8O4R800=lB8P0
0`00089>RH9>R@04PTj900<00027Dhb7Dh`00hMCS0030000ReVAReVA00:;FI401`0008mLTHmLTHmL
T@0009e]VP000005_8NL00<0002lQi`0000019URS`0300009a>39a>300<W4h<01@0009b4^Ib4^Ib4
^@000003_>N700<0002X`>^X`>/00P0000:X`>/00`000?ooooooo`0Foooo00<0003oooooool0AOoo
o`00Aoooo`800003oooo00<0003oooooool0B_ooo`80000:oooo00<0002IGHRIGHP00iUMR0040000
B1iiB1ii00000oooo`050000>P0c>P0c00001P1800800003LbYS00<0001d;FMd;FL00g@]I`030000
001B000000:gEE800`000>FeY>FeY003iKFT00<0002JKIbJKI`00YY]W0030000PUVIPUVI00>2FIT0
100008mVWXmVWP0000>_NIL00`000:A[TJA[T@03Y6^A00<0002VJXfVJXd00jIZS@030000KT6:KT6:
009^@HX2000013PTS0050000l^Vol^Vol^Vo000000BVLiX00`0009MPSYMPSP03Uf2>00<0002@F8Z@
F8X00i1HRP030000Qe28Qe2800>7D8P00`0007a8R7a8R003O4R800<00022CXV2CXT00h9>R@030000
Qe><Qe><00:7Dh`2000018]IT@040000SebA000000000ie]VP030000_8NL_8NL00:lQi`200001IUR
S`0300009a>39a>300<W4h<0100009b4^Ib4^@0000BlihL300001JS0j`030000oooooooo01Koool0
0`000?ooooooo`14oooo0014oooo0`0005;oool200002_ooo`030000VEf8VEf800>IGHP0100004PN
NDPNN@0000?oool3000000<604P00000000017<ZH`030000M2eWM2eW00Ad;FL010000;MED[MEDP00
00KU]J@00`0009Y]W9Y]W002VVfL00<00022FIV2FIT0189IV@800004[gVG00<0002TJi6TJi400jA[
T@030000YVZ=YVZ=00>VJXd00`0006i1RVi1RP02KT6:0P0000Dh98`010000?;Y_o;Y_`0000BVLiX0
0`0009MPSYMPSP03Uf2>00<0002@F8Z@F8X00i1HRP030000Qe28Qe2800>7D8P00`0007a8R7a8R003
O4R800<00022CXV2CXT00h9>R@030000Qe><Qe><00:7Dh`2000018]IT@800005WFfJ00<0002lQibl
Qi`00[b7W0800005VF:?00<0000W4h<W4h<00bLCP`050000W8BiW8Bi0000_>N700<00002Z<3[00<0
002X`>^X`>/00jS0j`030000oooooooo01Ooool00`000?ooooooo`13oooo0012oooo0P0005Goool2
00002_ooo`030000VEf8VEf800>IGHP0100004PNNDPNN@0000;oool200000`H0B0800004LbYS00<0
001d;FMd;FL017@]I`040000]eEB]eEB00001^FeY0030000VVfLVVfL00:JKI`00`00089IVH9IV@04
PUVI0P0000B_NIL00`000:A[TJA[T@03Y6^A00<0002VJXfVJXd01:IZS@040000KT6:KT6:00000V8h
R0030000>2B<>2B<008h98`010000?;Y_o;Y_`0000BVLiX00`0009MPSYMPSP03Uf2>00<0002@F8Z@
F8X00i1HRP030000Qe28Qe2800>7D8P00`0007a8R7a8R003O4R800<00022CXV2CXT00h9>R@070000
Qe><Qe><Qe><0000S5ZA000000>;FI4200001Ye]VP030000_8NL_8NL00:lQi`200001IURS`030000
9a>39a>300<W4h<00`0009b4^@00000200001JS0j`030000Z<3[Z<3[00>X`>/200005_ooo`<00015
oooo000ooooo0`0004[oool00`000?ooooooo`0:oooo00<00021?G8000002?ooo`800005VEf800@0
00187WU87WT00002oooo00<0000604P604P00PH0B0800004LbYS00<0001d;FMd;FL017@]I`<00007
iKFT00<0002JKIbJKI`00YY]W0030000PUVIPUVI00B2FIT00`000:miUjmiU`03[gVG00<0002TJi6T
Ji401:A[T@030000YVZ=YVZ=00>VJXd0100006i1RVi1RP00009R>8P00`0003PTS3PTS003>2B<00<0
003bjKl000001:IcVP030000Uf2>Uf2>00>GH8h00`00091HRY1HRP03T5R:00<00027D8R7D8P00hM@
R0030000O4R8O4R800=lB8P00`00089>RH9>R@03PTj900P00027Dhb7Dhb7Dh`0002<FY40002;FI42
000000>>HIT0002MKIX01Ie]VP030000_8NL_8NL00>lQi`00`0009URSiURS`04VF:?00<0000W4h<W
4h<00bLCP`8000000`00OP000:S0j`05Z<3[00<0002X`>/000000P0000:X`>/00`000?ooooooo`0F
oooo00<0003oooooool0@_ooo`00?Oooo`80001=oooo00<0003oooooool02Oooo`8000000h4mLP00
0?ooo`07oooo0P0000FIGHP0100004PNNDPNN@0000;oool00`0000H0B0H0B0021P180P0000Ac:V<0
0`0007@]Ig@]I`03M2eW00@0000001P000000007iKFT00<0002JKIbJKI`00iY]W0030000PUVIPUVI
00>2FIT00`000:miUjmiU`03[gVG00<0002TJi6TJi401:A[T@030000YVZ=YVZ=00>VJXd00`0006i1
RP000003HSR800<0000h98`h98`00cPTS0030000l^Vo000000BVLiX00`0009MPSYMPSP03Uf2>00<0
002@F8Z@F8X00i1HRP030000Qe28Qe2800>7D8P00`0007a8R7a8R003O4R800<00022CXV2CXT00h9>
R@040000Qe><Qe><Qe><100000>>HIT00`0009e]VYe]VP05WFfJ00@0002lQiblQiblQi`200001YUR
S`0300009a>39a>3008W4h<3000000<007h0002X`>/01:S0j`<00005Z<3[00<0003oooooool05ooo
o`030000oooooooo047oool003[oool30000Coooo`800009oooo0`000003PCeb0000oooo00Ooool2
00001IUMR0050000B1iiB1ii0000oooo008000031P180`0000Ac:V<00`0007@]Ig@]I`03M2eW00@0
000001P001P00007iKFT00<0002JKIbJKI`00iY]W0040000PUVIPUVIPUVI0`0000F_NIL00`000:A[
TJA[T@04Y6^A00<0002VJXfVJXd00jIZS@030000KT6:000000=R>8P00`0003PTS3PTS002>2B<00@0
002>F8`000000004YW>J00<0002GH8jGH8h019MPSP030000T5R:T5R:00:@F8X00`0008M@R8M@R003
Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900>2CXT00`0008MCS8MCS002000000>>HIT0002>
HIT018iQV@030000WFfJWFfJ00BMKIX010000;b7W;b7W;b7W0800006VF:?00<0000W4h<000000P00
00>YLiL3000000BX`>/0000000000002Z<3[00<0002X`>^X`>/00jS0j`80000Hoooo00<0003ooooo
ool0@Oooo`00=oooo`<0001Aoooo0`0000Soool4000000>1?G80003oool01oooo`800005VEf800@0
00187WU87WU87WT300000`H0B0030000001L000000Ac:V<00`0007@]Ig@]I`03M2eW00<0000001P0
00000P0000OU]J@00`0009Y]W9Y]W002VVfL00@00022FIT000000002YHZh00<0002_NIN_NIL00jmi
U`030000Y6^AY6^A00BTJi400`000:IZSJIZS@03YVZ=0P0000AR>8P00`0003PTS3PTS002>2B<00@0
002>F8`000000005YW>J00<0002GH8jGH8h00iMPSP030000T5R:T5R:00:@F8X00`0008M@R8M@R003
Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900B2CXT00`0008MCS0000002SV6I00<0002>HIV>
HIT00hiQV@030000WFfJWFfJ00BMKIX010000;b7W;b7W;b7W0<00005VF:?0P000003X6bE0000ZG>G
00BYLiL300001ZS0j`030000Z<3[Z<3[00800002Z<3[00<0003oooooool05_ooo`030000oooooooo
043oool003Goool20000E?ooo`<00008oooo10000003PCeb0000oooo00Ooool200001IUMR0040000
B1iiB1iiB1ii0`0000<604P2000017<ZH`030000M2eWM2eW00Ad;FL01@0000006000099KS@000007
iKFT00@0002JKIbJKIbJKI`300001:F:^0030000[gVG[gVG00>_NIL00`000:A[TJA[T@04Y6^A00<0
002VJXfVJXd00jIZS@800004HSR800D0000h98`h98`h98`000000hiHS0800004YW>J00<0002GH8jG
H8h00iMPSP030000T5R:T5R:00>@F8X00`0008M@R8M@R002Qe2800<0001lB8QlB8P00ga8R0030000
PTj9PTj900B2CXT00`0008MCS0000002SV6I00<0002>HIV>HIT00hiQV@030000WFfJWFfJ00BMKIX0
10000;b7W;b7W;b7W0<00005VF:?00@0002PK9FPK9D00005ZG>G00<0000D38@000001ZS0j`<00005
Z<3[00<0003oooooool05_ooo`030000oooooooo03ooool003;oool30000E_ooo`8000000bLBP000
0?ooo`05oooo00L00034HU@0003iZED00021?G8000002?ooo`800005VEf800@000187WU87WU87WT2
000010H0B0800004LbYS00<0001d;FMd;FL00g@]I`030000000H000000:BFhd200001^FeY0060000
VVfL00000000WN;m00001ZF:^0030000[gVG[gVG00:_NIL00`000:A[TJA[T@04Y6^A00<0002VJXfV
JXd00jIZS@030000HSR8HSR800AR>8P0100003PTS000000000>>F8`200001:IcVP030000Uf2>Uf2>
00>GH8h00`00091HRY1HRP03T5R:00<00027D8R7D8P00XM@R0030000O4R8O4R800=lB8P00`00089>
RH9>R@04PTj90P0000B>HIT00`0008iQVHiQV@02SV6I00<0002MKIZMKIX01Ie]VP040000_8NL0000
UV2@0P0000BIHXl00`000:1/UJ1/U@0200001JUcU`04000050b450b400000ZS0j`<00002Z<3[00<0
002X`>^X`>/00jS0j`030000oooooooo01Koool00`000?ooooooo`0ooooo000`oooo0P0000?oool0
0`000?ooooooo`1Coooo0P0000039a:00000oooo00Coool020000<ARE<ARE0000?VYE@00084mLP00
00Soool200001IUMR0040000B1iiB1iiB1ii0P0000<604P3000017<ZH`030000M2eWM2eW00=d;FL0
0`00000060000003TU^=00<0003U]JCU]J@00nFeY0<00004WN;m00<0002UR[RUR[P00jF:^0030000
[gVG[gVG00>_NIL00`000:A[TJA[T@03Y6^A00<0002VJXfVJXd00jIZS@030000HSR8HSR800AR>8P2
000000>:EH`0002>F8`00hiHS0030000YW>JYW>J00:VLiX00`0009MPSYMPSP03Uf2>00<0002@F8Z@
F8X00i1HRP030000Qe28Qe2800:7D8P00`0007a8R7a8R003O4R800<00022CXV2CXT0189>R@800004
SV6I00<0002>HIV>HIT00XiQV@030000WFfJWFfJ00FMKIX010000;b7W00009IPT0800004VF:?00<0
002PK9FPK9D00P0000FYLiL0100001@<Q1@<Q1@<Q0800005Z<3[00<0002X`>^X`>/00jS0j`80000H
oooo00<0003oooooool0?_ooo`00;Oooo`<0001Joooo00<0003jaY3jaY000P0000Goool00`000<AR
E<ARE00200000X4mLP030000oooooooo00Goool00`000>n^Q`000005VEf800<000187WU87WT00TPN
N@0700001P181P181P180000001L000000Ac:V<00`0007@]Ig@]I`03M2eW0P0000BBFhd2000000CU
]J@0000000000002GCJ80P0000>Mh_d00`000:F:^:F:^003YHZh00<0002_NIN_NIL00jmiU`030000
Y6^AY6^A00>TJi400`000:IZSJIZS@02YVZ=0P0000IR>8P2000000>:EH`0002>F8`00hiHS0030000
YW>JYW>J00:VLiX00`0009MPSYMPSP03Uf2>00<0002@F8Z@F8X00i1HRP030000Qe28Qe2800:7D8P0
0`0007a8R7a8R003O4R800<00022CXV2CXT0189>R@030000SV6ISV6I00>>HIT00`0008iQVHiQV@02
SV6I00<0002MKIZMKIX01Ie]VP040000_8NL0000UV2@0P0000>IHXl200000Z1/U@800005ZG>G00<0
000D38@D38@00Q@<Q0030000Z<3[Z<3[00BX`>/00`000:S0j`00000200000ZS0j`030000oooooooo
01Koool00`000?ooooooo`0moooo000[oooo0P0005goool00`000?[6T?[6T00200001?ooo`060000
a69Da69D0000nJUE00000X4mLP030000oooooooo00Goool00`000>n^Q`000005VEf800<000187WU8
7WT00TPNN@0700001P181P181P180000001L000000Ac:V<00`0007@]Ig@]I`03M2eW0P0000FBFhd2
00000fTkQP050000GCJ8GCJ8GCJ8000000:Mh_d00`000:F:^:F:^003YHZh00<0002_NIN_NIL00jmi
U`030000Y6^AY6^A00>TJi400`000:IZSJIZS@02YVZ=0P0000IR>8P0100008YES8YES00000F>F8`0
1@000:IcVZIcVZIcVP000005Uf2>00<0002@F8Z@F8X00i1HRP030000Qe28Qe2800:7D8P00`0007a8
R7a8R003O4R800<00022CXV2CXT0189>R@030000SV6ISV6I00>>HIT00`0008iQVHiQV@03SV6I00<0
002MKIZMKIX019e]VP030000_8NL000000<00003VF:?0P000005X6bE0000[WbM[WbM000000FYLiL0
0`0001@<Q1@<Q00250b400<0002X`>^X`>/00ZS0j`<00005Z<3[00<0003oooooool05_ooo`030000
oooooooo03goool002Soool30000Goooo`060000n/J@n/J@00009a:000000_ooo`800002a69D00<0
003iZED000000X4mLP030000oooooooo00Goool00`000>n^Q`000005VEf800<000187WU87WT00TPN
N@0700001P181P181P180000001L000000Ac:V<00`0007@]Ig@]I`02M2eW00<0000001P000001I9K
S@030000JC^6JC^6009Y>hH0100005dfR5dfR5dfR0800002WN;m00<0002UR[RUR[P00ZF:^0030000
[gVG[gVG00>_NIL00`000:A[TJA[T@03Y6^A00<0002VJXfVJXd00ZIZS@030000ISR4000000AR>8P0
1@0008YES8YES8YES0000005SUR<00D0002VLiZVLiZVLiX000001IMPSP030000T5R:T5R:00>@F8X0
0`0008M@R8M@R002Qe2800<0001lB8QlB8P00ga8R0030000PTj9PTj900>2CXT200001HiQV@030000
SV6ISV6I00>>HIT00`0009e]VYe]VP04WFfJ0`0000:FH900200009URSiURS`0009MTU0000:1/U@00
00:^O9d00`000:UcUjUcU`03ZG>G00<0000D38@D38@00Q@<Q0030000Z<3[Z<3[00800002Z<3[00<0
002X`>^X`>/01:S0j`030000oooooooo01Koool00`000?ooooooo`0loooo000Uoooo0`0006;oool0
1`000?[6T?[6T00002LBP0000?ooo`02000000I904P00034HU@0003iZED00003PCeb00<0003ooooo
ool01?ooo`030000kjj7000000FIGHP00`0004PNNDPNN@02B1ii0P00008604P200001G<ZH`030000
M2eWM2eW009d;FL300001I9KS@030000JC^6JC^6009Y>hH02@0005dfR5dfR5dfR00003TgY00009gR
o@000004YHZh00<0002_NIN_NIL00jmiU`030000Y6^AY6^A00>TJi401@000:IZSJIZSJIZS@000002
ISR400D0001R>8QR>8QR>8P0000018YES0030000SUR<SUR<00B>F8`010000:IcVZIcVP0000FGH8h0
0`00091HRY1HRP03T5R:00<00027D8R7D8P00XM@R0030000O4R8O4R800AlB8P01`00089>RH9>RH9>
R@0008EIU`000005SV6I00<0002>HIV>HIT00hiQV@040000WFfJWFfJWFfJ0`000003WFfJ0000UV2@
00:FH900200009URSiURS`0009MTU0000:1/U@0000:^O9d00`000:UcUjUcU`03ZG>G00@0000D38@D
38@D38@400001JS0j`030000Z<3[Z<3[00:X`>/200006Oooo`030000oooooooo03_oool002?oool2
0000I?ooo`080000n/J@n/J@n/J@00009a:00000oooo0P000006B@180000a69D0000nJUE00000h4m
LP030000oooooooo00Coool00`000>n^Q`000005VEf800<000187WU87WT00dPNN@0500001P180000
001L000000Ec:V<00`0007@]Ig@]I`02M2eW0`0000FBFhd00`0006TkQVTkQP02JC^600<0001M=XQM
=XP00UdfR0040000>CNT000000001:F:^0030000[gVG[gVG00>_NIL00`000:A[TJA[T@03Y6^A00D0
002VJXfVJXfVJXd000000VHhQ0030000HSR8HSR800800004RUF<00<0002>F8b>F8`018iHS0040000
YW>JYW>J00001IMPSP030000T5R:T5R:00>@F8X00`0008M@R8M@R003Qe2800<0001lB8QlB8P00ga8
R0070000PTj9PTj9PTj90000QEVG000000F>HIT00`0008iQVHiQV@03SV6I100000BMKIX00`0009IP
T9IPT002UV2@00<0002IHXl000000YMTU0800002[WbM00<0002YLiNYLiL00jUcU`@0000019]VTP00
0000O00000FX`>/00`000:S0jjS0j`0200000ZS0j`030000oooooooo01Koool00`000?ooooooo`0k
oooo000Qoooo0P0006Koool01@000?[6T?[6T?[6T00000029a:000<0001P240000000TT0B0040000
nJUEnJUE00000h4mLP030000oooooooo00Coool00`000>n^Q`000005VEf800<000187WU87WT00dPN
N@<000000`00G00007<ZH`04LbYS00<0001d;FMd;FL00W@]I`030000RUVA000000FBFhd00`0006Tk
QVTkQP02JC^600<0001M=XQM=XP00UdfR0040000>CNT000000001:F:^0030000[gVG[gVG00>_NIL0
0`000:A[TJA[T@03Y6^A00D0002VJXfVJXfVJXd000000VHhQ0030000HSR8HSR800800004RUF<00<0
002>F8b>F8`018iHS08000000jIcVP0009MPSP04Uf2>00<0002@F8Z@F8X00i1HRP030000Qe28Qe28
00>7D8P00`0007a8R7a8R003O4R800@00022CXV2CXT00003QEVG00<0002>HIV>HIT00XiQV@030000
SV6ISV6I00:>HIT200001Ye]VP030000UV2@UV2@00>FH90200000iMTU0050000[WbM[WbM[WbM0000
00BYLiL00`0009]VTY]VTP03VfJB00<0000007`000001JS0j`<00005Z<3[00<0003oooooool05_oo
o`030000oooooooo03[oool0027oool20000I_ooo`050000n/J@n/J@n/J@0000008W4X000`000608
@0000002B@1800@0003iZEGiZED00003PCeb00<0003oooooool01?ooo`030000kjj7000000FIGHP0
0`0004PNNDPNN@03B1ii0`000003001L0000LbYS00=c:V<00`0007@]Ig@]I`02M2eW0P000003RUVA
0000TU^=00BBFhd00`0006TkQVTkQP02JC^600<0001M=XQM=XP00UdfR0030000>CNT>CNT00800004
YHZh00<0002_NIN_NIL00ZmiU`030000Y6^AY6^A00>TJi4010000:IZSJIZS@0000=V>8@01@00068h
R00008QCS0000004RUF<00<0002>F8b>F8`018iHS0050000T5Z>0000YW>J000000BGH8h00`00091H
RY1HRP03T5R:00<00027D8R7D8P00hM@R0030000O4R8O4R800=lB8P00`00089>R@000004QEVG00<0
002>HIV>HIT00hiQV@@00002SV6I00<0002MKIZMKIX00ie]VP030000UV2@UV2@00>FH90300000YMT
U0050000[WbM[WbM[WbM000000>YLiL00`0009]VTY]VTP04VfJB00D0000007`007`0002X`>/00`00
00:X`>/00`000:S0jjS0j`03Z<3[0P0001Ooool00`000?ooooooo`0joooo000Qoooo00<0003oool0
0000IOooo`050000n/J@n/J@n/J@0000008W4X0200000dT0B0040000nJUEnJUE00000h4mLP030000
oooooooo00?oool010000>n^Qnn^Q`0000FIGHP00`0004PNNDPNN@03B1ii0`000003001L0000LbYS
00=c:V<00`0007@]Ig@]I`02M2eW00@0002:FI6:FI400005TU^=00<0001Y>hIY>hH00VTkQP030000
GCJ8GCJ8009M=XP01@0003TgY3TgY3TgY0000004YHZh00<0002_NIN_NIL00ZmiU`030000Y6^AY6^A
00BTJi400`000:IZS@000003ISR40P0000:8Dh`00`0008YES8YES002RUF<00<0002>F8b>F8`018iH
S0050000T5Z>0000YW>J000000BGH8h00`00091HRY1HRP03T5R:00<00027D8R7D8P00hM@R0030000
O4R8O4R800=lB8P200001HEIU`040000SV6ISV6ISV6I0`0000F>HIT00`0009e]VYe]VP02WFfJ00<0
002FH92FH90019IPT0050000UfBD0000UfBD000000F^O9d010000:UcU`00000000JKIY8500001JS0
j`030000Z<3[Z<3[00<00002Z<3[00<0003oooooool05Oooo`030000oooooooo03Woool0027oool0
10000?ooooooo`0006?oool00`000?[6T?[6T002n/J@00<0000W4X0W4X000P0000=904P00`000?VY
E@000004PCeb00<0003oooooool00oooo`040000kjj7kjj700001IUMR0030000B1iiB1ii00A87WT2
000000<005`0001c:V<00g<ZH`040000M2eWM2eWM2eW0P0000::FI400`00099KSI9KS@03TU^=00<0
001Y>hIY>hH00VTkQP030000GCJ8GCJ800=M=XP01@0003TgY0000?_8S@000003YHZh00<0002_NIN_
NIL00ZmiU`030000Y6^AY6^A00BTJi400`000:IZS@000003ISR400D00028Dhb8Dhb8Dh`0000018YE
S0030000SUR<SUR<00B>F8`00`00091JSY1JSP0200001IMPSP030000T5R:T5R:00>@F8X00`0008M@
R8M@R002Qe2800<0001lB8QlB8P00ga8R0800005QEVG100000:>HIT00`0008iQVHiQV@03SV6I00<0
002MKIZMKIX00Ye]VP030000UV2@UV2@00BFH900100009MTU9MTU00000J^O9d010000:UcU`000000
00FKIY8010000:MaUZMaUZMaUP800005Z<3[0`0000FX`>/00`000?ooooooo`0Foooo00<0003ooooo
ool0>?ooo`008?ooo`<00002oooo00<0003oooooool0GOooo`040000oooooooo00001?[6T0030000
9a:09a:000800002B@1800@0003iZEGiZED00004PCeb00<0003oooooool00oooo`040000kjj7kjj7
00001YUMR0030000B1iiB1ii00=87WT300001G<ZH`040000M2eW0000000018YIT@030000TU^=TU^=
00>BFhd00`0006TkQVTkQP02JC^600<0001M=XQM=XP00edfR0050000>CNT0000nlR=000000>UR[P0
0`000:miUjmiU`02[gVG00<0002TJi6TJi401:A[T@800002ISR40P0000B8Dh`00`0008YES8YES003
RUF<00<0002>F8b>F8`00hiHS0030000T5Z>T5Z>00800005Uf2>00<0002@F8Z@F8X00i1HRP030000
Qe28Qe2800:7D8P00`0007a8R7a8R002O4R80`0000>5FIL300001HiQV@030000SV6ISV6I00>>HIT0
1`0009e]VYe]VYe]VP0009IQT@000004UV2@00@0002GI9BGI9BGI9@200001JilW@8000000iIPT000
09]VTP04VfJB00@0002WLIJWLIJWLIH300000ZS0j`800002Z<3[00<0002X`>^X`>/01:S0j`030000
oooooooo01?oool30000>_ooo`008?ooo`030000oooooooo00?oool00`000?ooooooo`1Loooo1000
00CjaY00200002LBP2LBP0000?VYE@0004T0B00000;iZED00`00084mLX4mLP02PCeb00<0003ooooo
ool00oooo`040000kjj7kjj700001YUMR0030000B1iiB1ii00=87WT3000017<ZH`D00004RUVA00<0
002BFhfBFhd00i9KS@030000JC^6JC^6009Y>hH00`0005dfR5dfR003GCJ800<0000i=j@000000__8
S@040000YHZhYHZh00001JmiU`030000Y6^AY6^A00>TJi42000000AV>8@00023Ch/00004R5><00<0
002:EHb:EH`00hYES0030000SUR<SUR<00>>F8`01@00091JSY1JSY1JSP000005Uf2>00<0002@F8Z@
F8X00i1HRP030000Qe28Qe2800:7D8P00`0007a8R000000200000WaBU@@00002QEVG00<0002>HIV>
HIT00hiQV@030000SV6ISV6I00>>HIT0100009e]VYe]VP0000:FHI401@0009IPT9IPT9IPT0000003
UfBD00<0002eR:H000001:ilW@800002UV2@00<0002KIY:KIY800i]VTP050000Yg6FYg6FYg6F0000
008]99<200001JS0j`030000Z<3[Z<3[00:X`>/200006?ooo`030000oooooooo03Ooool0023oool0
0`000?ooooooo`04oooo0P0005_oool01@0006HBB`000>R0<@000004n/J@00P0000W4X0W4X00003i
ZED0001904P00002nJUE00<00021?G:1?G800X4mLP030000oooooooo00?oool010000>n^Qnn^Q`00
00JIGHP00`0004PNNDPNN@03B1ii00@0003CV9L0001c:V<300000iEKR0800004RUVA00<0002BFhfB
Fhd00i9KS@030000JC^6JC^6009Y>hH00`0005dfR5dfR003GCJ800<0000i=j@000000__8S@040000
YHZhYHZh00001JmiU`030000Y6^AY6^A00>TJi4300000X=?R`030000R5><R5><00:8Dh`00`0008YE
S8YES003RUF<00<0002>F8b>F8`00hiHS0030000T5Z>T5Z>00:@FXh200000iMPSP030000T5R:T5R:
00>@F8X0100008M@R8M@R8M@R0@00002O5:E0`0000J5FIL00`0008iQVHiQV@02SV6I00<0002>HIV>
HIT00hiQV@040000WFfJWFfJ00000YIQT@080000UV2@UV2@0000TF2D0000UfBD00000[F8YPD00004
UV2@00<0002KIY:KIY800i]VTP050000Yg6FYg6FYg6F000000<]99<00`000:S0jjS0j`03Z<3[00<0
002X`>^X`>/00P0000:X`>/00`000?ooooooo`0Foooo00<0003oooooool0=_ooo`008?ooo`030000
oooooooo00Koool00`000?ooooooo`1;oooo00<0003oooooool02_ooo`040000IQ9;000000001O[6
T00800009a:09a:00000nJUE0000B@1800000_VYE@030000PCebPCeb00:1?G800`000?ooooooo`03
oooo00@0003_[XO_[XL00006VEf800<000187WU87WT00dPNN@040000diRG000000000/>5TP040000
UE^8UE^8UE^80P0000B:FI400`00099KSI9KS@03TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8GCJ8
00AM=XP00`000?_8SO_8S@02nlR=00<0002UR[P000001JmiU`030000Y6^AY6^A00>TJi400`0008=?
Rh=?R`02Pdn;00<00028Dhb8Dh`00XQCS0030000RUF<RUF<00>:EH`00`0008iHS8iHS003SUR<00<0
002@FXj@FXh0191JSP040000Uf2>Uf2>00001I1HRP040000Qe28000000000h1GV0<00002O5:E00<0
0025FIN5FIL018EIU`030000SV6ISV6I00:>HIT00`0008iQVHiQV@04SV6I0P0000>FHI400`0009IP
T0000002TF2D0P0000:eR:H500001IIPT0030000VfJBVfJB00:KIY800`000:MaUZMaUP02Yg6F00D0
000]99<]99<]99<000001JS0j`<00005Z<3[00<0003oooooool05Oooo`030000oooooooo03Koool0
023oool00`000?ooooooo`07oooo00<0003oooooool0BOooo`<0000:oooo0P000003IQ9;00000000
00GjaY00100002LBP2LBP00000;iZED01@000?VYEOVYEOVYE@000005PCeb00<0003oooooool00_oo
o`040000kjj7kjj700001YUMR0030000B1iiB1ii00987WT00`000=>HU`000004`hFB00@0002EFhRE
FhREFhP2000018YIT@030000TU^=TU^=00>BFhd00`0006TkQVTkQP02JC^600<0001M=XQM=XP015df
R0030000nlR=nlR=00?kb8d200001JmiU`030000Y6^AY6^A00:TJi42000018=?R`030000R5><R5><
00:8Dh`00`0008YES8YES003RUF<00<0002>F8b>F8`018iHS0030000T5Z>T5Z>00>@FXh400000i1H
RP@00002P5NH100000ElDYD00`0008EIUhEIU`03QEVG00<0002>HIV>HIT00XiQV@030000SV6ISV6I
00B>HIT200000iIQT@800003TF2D100000BEH9000`0009IPT9IPT004UV2@00D0002KIY:KIY:KIY80
00001JMaUP060000;BBC;BBC;BBC0000Z<3[0`0000:W]n@00`000:S0jjS0j`03Z<3[00<0003ooooo
ool05_ooo`030000oooooooo03Goool0023oool300002?ooo`030000oooooooo04Koool2000000Ba
WlH00016>Yl00009oooo00D0001V4T]V4T]V4T/000001_[6T00300009a:0000000;iZED01@000?VY
EOVYEOVYE@000005PCeb00D0003oooooooooool000000nn^Q`030000VEf8VEf800BIGHP00`0004PN
NDPNN@02B1ii00<0003CV9L000001<>5TP040000UE^8UE^8UE^80P0000B:FI400`00099KSI9KS@03
TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8GCJ800AM=XP200001?_8S@030000YHZh000000B_NIL0
0`000:A[T@00000300001H=?R`030000R5><R5><00:8Dh`00`0008YES8YES003RUF<00<0002>F8b>
F8`018iHS0030000T5Z>T5Z>00>@FXh2000000=E>I<000000000100000:RNZL200000h1GV0030000
O5:EO5:E00=lDYD00`0008EIUhEIU`03QEVG00<0002>HIV>HIT00hiQV@030000SV6ISV6I00>>HIT0
100009IQTIIQTIIQT@800003TF2D0P0000:HHi800`0009EPT9EPT002UF2@00<0002FH92FH90019IP
T0050000VfJBVfJBVfJB000000FWLIH0100002dTTbdTTbdTT`800005YkOT00<0002X`>^X`>/00ZS0
j`<0000Hoooo00<0003oooooool0=?ooo`007oooo`030000oooooooo00[oool00`000?ooooooo`14
oooo00L0002aWlJaWlJaWlH00016>Yl000002?ooo`800003IQ9;00<0003jaY3jaY001?[6T0030000
9a:0000000KiZED00`00084mLX4mLP03PCeb00D0003oooooooooool000000nn^Q`030000VEf8VEf8
00BIGHP00`0004PNNDPNN@02B1ii00<0003CV9L000001<>5TP070000UE^8UE^8UE^80000I5:X0000
00>:FI400`00099KSI9KS@03TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8GCJ800AM=XP900000jmi
U`<00003KCj700<00023Ch^3Ch/00h=?R`030000R5><R5><00:8Dh`00`0008YES8YES003RUF<00<0
002>F8b>F8`018iHS0030000T5Z>T5Z>00>@FXh00`0006@lS0000004ECVC1@0000B0EiP00`0007aB
UGaBU@03O5:E00<00025FIN5FIL00hEIU`030000SV6ISV6I00>>HIT0100008iQVHiQVHiQV@<00000
1YIQT@000000091PU@00095PU0800004V6>B00<0002EH92EH9000iEPT0030000UV2@UV2@00>FH900
100009]VTY]VTP0000JWLIH00`0002dTTbdTT`02;BBC00<0002W]nBW]n@01:Ngi0@00003Z<3[00<0
003oooooool05Oooo`030000oooooooo03Coool001ooool00`000?ooooooo`0;oooo00<0003ooooo
ool0@_ooo`030000/Io6/Io600>aWlH00`0004HjW`000007oooo0P00009V4T/00`000?[6T?[6T005
n/J@00<0000W4X0000001OVYE@030000PCebPCeb00B1?G8200000_ooo`050000kjj7kjj7kjj70000
00JIGHP00`0004PNNDPNN@02B1ii0`0000C3QI800`0009EKR9EKR002UE^80P0000>:FI400`00099K
SI9KS@03TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8GCJ800=M=XP00`0009eVT@000002=QQn00<0
002fOIJfOIH00P000003[gVG00000000009kBH/01@0006dnQfdnQfdnQ`000005Pdn;00<00028Dhb8
Dh`00XQCS0030000RUF<RUF<00>:EH`00`0008iHS8iHS004SUR<00<0002@FXj@FXh00Y1JSP040000
I3b<I3b<00000UDiT`@000000a4a[`0000000004P5NH00<0001lDYElDYD00gaBU@030000QEVGQEVG
00>5FIL00`0008iQVHiQV@03SV6I00D0002>HIV>HIT0002HI9<00`0000:@H9D400001IQSTP030000
UF2@UF2@00>EH902000019IPT0040000VfJBVfJB00001ZMaUP030000;BBC;BBC00<]99<010000:Ng
i:Ngi:Ngi08000000k;=kP000:S0j`04Z<3[00<0003oooooool05_ooo`030000oooooooo03?oool0
01ooool00`000?ooooooo`0<oooo00<0003oooooool0@Oooo`800004/Io600@00016>Ym6>Yl00005
oooo0P0000=V4T/00`000?[6T?[6T005n/J@00<0000W4X0000001OVYE@030000PCebPCeb00B1?G82
00000_ooo`050000kjj7kjj7kjj7000000JIGHP00`0004PNNDPNN@02B1ii0P0000G3QI800`0009EK
R9EKR002UE^80P0000>:FI400`00099KSI9KS@03TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8GCJ8
00=M=XP01P0009eVTIeVT@0003HHOP0000:fOIH3000017]9R`050000KCj7KCj7KCj7000000F3Ch/0
0`0008QCS8QCS002R5><00<0002:EHb:EH`00hYES0030000SUR<SUR<00B>F8`00`00091JSY1JSP02
T5Z>00<0001T?8aT?8`00`0000=E>I<01000014a[`00000000B0EiP00`0007aBUGaBU@03O5:E00<0
0025FIN5FIL018EIU`030000SV6ISV6I00:>HIT6000000B@H9D0000000000003WFRD00<0002HHi:H
Hi800iQSTP030000UF2@UF2@00>EH9000`0009IPT0000003UV2@00@0002KIY:KIY800006Yg6F00<0
000]99<]99<00bdTT`040000YkOT000000001;;=kP030000Z<3[Z<3[00:X`>/200006?ooo`030000
oooooooo03;oool001ooool00`000?ooo`00000=oooo00<0003oooooool0?oooo`030000ikBO0000
00BaWlH00`0004HjWdHjW`0200001?ooo`800003IQ9;00<0003jaY3jaY001O[6T00400009a:00000
00001?VYE@030000PCebPCeb00B1?G800`0005@3@`00000200000nn^Q`030000VEf8VEf800BIGHP0
1`0004PNNDPNNDPNN@000=fNS`000005`hFB00<0002EFhREFhP00YEKR0800003RUVA00<0002BFhfB
Fhd00i9KS@030000JC^6JC^6009Y>hH00`0005dfR5dfR002GCJ800L0002MIY6MIY6MIY40000f67h0
00000[ImUP800005NdV;00D0001]?XM]?XM]?XL000001H=?R`030000R5><R5><00>8Dh`00`0008YE
S8YES002RUF<00<0002>F8b>F8`018iHS0030000T5Z>T5Z>00:@FXh400001EDiT`0400004C6_0000
00001H1GV0030000O5:EO5:E009lDYD00`0008EIUhEIU`04QEVG00@0002>HIV>HIV>HIT300000YQW
U`<000000jEbV@0009eXU003WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@00>EH9000`0009IP
T0000003UV2@00D0002KIY80002MJ9<000001ZMaUP030000;BBC;BBC008]99<200001[;=kP030000
Z<3[Z<3[00800002Z<3[00<0003oooooool05Oooo`030000oooooooo03;oool001ooool200003ooo
o`030000oooooooo03koool010000>NdWnNdW`0000>aWlH01@0004HjWdHjWdHjW`000004oooo0P00
00=V4T/00`000?[6T?[6T005n/J@0P000003UUf<0000nJUE00?iZED00`00084mLX4mLP04PCeb0`00
0003i8QK0000kjj700;_[XL00`0009UMR9UMR004VEf800L000187WU87WU87WT0003MWXl000001L>5
TP030000UE^8UE^800:EFhP200000hYIT@030000TU^=TU^=00BBFhd00`0006TkQVTkQP02JC^600D0
001M=XQM=XQM=XP000000ieVT@800003]WfF00<0002cRJT0000017]9R`050000KCj7KCj7KCj70000
00F3Ch/00`0008QCS8QCS003R5><00<0002:EHb:EH`00XYES0030000SUR<SUR<00B>F8`00`00091J
SP00000200000f@lS0030000ECVCECVC00AE>I<2000000=^AHl0000000000h1GV0030000O5:EO5:E
00=lDYD00`0008EIUhEIU`03QEVG00<0002>HIT000000P000003V6NG0000000000800003YG:I00<0
002MJ9BMJ9@00YeXU0030000V6>BV6>B00>HHi800`0009EPT9EPT003UF2@00@0002FH92FH9000002
UV2@00D0002KIY80002MJ9<000001ZMaUP030000;BBC000000800002002300<0002bcNjbcNh00k;=
kP<00005Z<3[00<0003oooooool05Oooo`030000oooooooo037oool001ooool00`000?ooooooo`0?
oooo00<0003oooooool0?Oooo`040000ikBOikBO00000k6OaP040000ASZOASZOASZO0P0000;oool2
00000fHBB`030000n/J@n/J@00GjaY0200000YIMS0030000nJUEnJUE00;iZED00`00084mLX4mLP04
PCeb00@000253QL000000004kjj700<0002IGHRIGHP019UMR0070000B1iiB1iiB1ii0000gIj?0000
00G3QI800`0009EKR9EKR002UE^80P0000>:FI400`00099KSI9KS@04TU^=00<0001Y>hIY>hH00VTk
QP040000GCJ8GCJ8000019eVT@800003]WfF00<0002cRJT0000017]9R`030000KCj7KCj7009]?XL0
0`0008=?Rh=?R`03Pdn;00<00028Dhb8Dh`00XQCS0030000RUF<RUF<00::EH`00`0008iHS8iHS003
SUR<0`0000:@FXh01@0006@lS6@lS6@lS0000006ECVC00<0001^AHm^AHl00Vi5S`040000P5NHP5NH
00001GaBU@030000QEVGQEVG00:5FIL700000]cJe@030000YG:IYG:I00:ULYT00`0009eXU9eXU002
WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@00>EH9001@0009IPT9IPT9IPT0000002UV2@0P00
0003WFRC0000Yg6F00FWLIH200000YaZU`@00002//g^0`0000:X`>/00`000:S0jjS0j`03Z<3[00<0
003oooooool05_ooo`030000oooooooo033oool001ooool00`000?ooooooo`0@oooo00<0003ooooo
ool0>oooo`030000ikBOikBO00;W]9l010000;6Oa[6OaP0000A6>Yl2000000?oool0000000000fHB
B`030000n/J@n/J@00?jaY0300000iIMS0030000nJUEnJUE00;iZED00`00084mLX4mLP03PCeb0P00
00:53QL00`000>n^Qnn^Q`03kjj700<0002IGHRIGHP00iUMR0040000B1iiB1iiB1ii0`0000G3QI80
0`0009EKR9EKR003UE^800D0002:FI6:FI6:FI4000001Y9KS@030000JC^6JC^6009Y>hH0100005df
R5dfR00000BMIY4200000kImUP030000/hVY000000AkBH/00`0006dnQfdnQ`02KCj700<00023Ch^3
Ch/00h=?R`030000R5><R5><00:8Dh`00`0008YES8YES003RUF<00<0002>F8`000000P000003SUR<
0000T5Z>00:@FXh01@0006@lS6@lS6@lS0000005ECVC00<0001^AHm^AHl00fi5S`@00005O5:E00<0
0025FIL000001@0000BUS;X00`000=cJe@000004YG:I00<0002MJ9BMJ9@00ieXU0030000V6>BV6>B
00:HHi800`0009EPT9EPT003UF2@00D0002FH92FH92FH90000000YIPT08000000ieXT`000:MaUP05
Yg6F00@0002LJYNLJYL00003UV6A0`0000FX`>/00`000:S0jjS0j`02Z<3[0`0001Ooool00`000?oo
ooooo`0`oooo000Noooo00<0003oooooool04_ooo`030000oooooooo03[oool00`000>NdWnNdW`02
ikBO00@0002aWlJaWlH00004ASZO00D0000008`0000008`000000VHBB`L00002Q4f700D0002FGHbF
GHbFGH`000001?VYE@030000PCebPCeb00>1?G8200000XD>5`030000kjj7kjj700?_[XL00`0009UM
R9UMR003VEf800@000187WU87WU87WT300001L>5TP030000UE^8UE^800>EFhP00`0008YITHYIT@02
RUVA00<0002BFhfBFhd00i9KS@030000JC^6JC^6009Y>hH0100005dfR5dfR00000BMIY400`000;Im
U[ImUP03]WfF0P0000AkBH/00`0006dnQfdnQ`02KCj700<00023Ch^3Ch/00h=?R`030000R5><R5><
00:8Dh`00`0008YES8YES003RUF<0P0000B>F8`01000091JSY1JSP0000AT?8`00`0005DiTeDiT`02
ECVC0P0000A^AHl0100007eDUgeDUgeDU`P00002GUNb0P0000NUS;X00`000:EbVJEbV@03YG:I00<0
002MJ9BMJ9@00ieXU0030000V6>BV6>B00>HHi800`0009EPT9EPT002UF2@00<0002FH92FH9000YIP
T0030000UV2@000000:MJ9<00`000:MaUZMaUP04Yg6F00@0002LJYNLJYL00004UV6A0P0000FX`>/5
00000jS0j`030000oooooooo01Goool00`000?ooooooo`0_oooo000Noooo00@0003oool00000000B
oooo00<0003oooooool0>?ooo`030000ikBOikBO00?W]9l2000000>aWlH00016>Yl00dHjW`050000
002<00000000IQ9;008000001MJRW`000;f0TKf0T@000004Q4f700D0002FGHbFGHbFGH`000001?VY
E@030000PCebPCeb00>1?G8500001Nn^Q`030000VEf8VEf800>IGHP0100004PNNDPNNDPNN@<00005
`hFB00<0002EFhREFhP00iEKR0030000RUVARUVA00::FI400`00099KSI9KS@03TU^=00<0001Y>hIY
>hH00VTkQP030000GCJ8000000FMIY400`000;ImU[ImUP03]WfF0P0000AkBH/00`0006dnQfdnQ`02
KCj700<00023Ch^3Ch/00h=?R`030000R5><R5><00:8Dh`00`0008YES8YES00400001HiHS0040000
T5Z>T5Z>00001F@lS0060000ECVCECVC0000NT^=000016i5S`030000OEBGOEBG00=mE9L00`0007IE
WWIEWP03MUFN100000JUS;X200001JEbV@030000WFRDWFRD00>MJ9@00`0009QSTYQSTP03V6>B00<0
002EH92EH9000YEPT0030000UV2@UV2@00>FH90200000ieXT`030000Yg6FYg6F00:WLIH01@0009aZ
UiaZUiaZU`000004UV6A0`0000:X`>/200000ZS0j`030000Z<3[Z<3[00>X`>/00`000?ooooooo`0F
oooo00<0003oooooool0;_ooo`007_ooo`80000Eoooo0P0003Soool00`000>NdWnNdW`02ikBO0P00
0004GD6G0000/Io6000014HjW`040000eZ:O000000000]JRW`050000_H2A_H2A_H2A000000B4CHL0
1@0009IMS9IMS9IMS0000003nJUE00<00021?G:1?G80184mLP050000DQ1L0000]Wl0000000G_[XL0
0`0009UMR9UMR003VEf800D000187WU87WT0003MWXl00P0000G3QI800`0009EKR9EKR003UE^80P00
00>:FI400`00099KSI9KS@03TU^=00<0001Y>hIY>hH00VTkQP030000GCJ8000000>MIY4300001KIm
UP800004NdV;00<0001]?XM]?XL00VdnQ`030000Pdn;Pdn;00>3Ch/00`0008QCS8QCS002R5><0`00
00>:EH`00`0008iHS8iHS004SUR<00<0002@FXh000001F@lS0040000ECVCECVC00000WY;S@030000
KTF?KTF?00800005OEBG00<0001fEIifEIh00gIEWP800002U6jT00<0002US;ZUS;X00ZF<^P030000
`YBX000000FULYT00`0009eXU9eXU003WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@00>EH900
0`0009IPT9IPT003UV2@00D0002MJ9>MJ9>MJ9<000001:MaUP050000W6ZGW6ZGW6ZG000000BFHI40
0`00034ORS4ORP0200001:S0j`030000Z<3[Z<3[00>X`>/200005oooo`030000oooooooo02koool0
01koool00`000?ooooooo`0Foooo00<0003oooooool0=Oooo`030000ikBOikBO00;W]9l2000000AM
@IL0002aWlH00003ASZO0P0000GFXYl01@000;f0TKf0TKf0T@000004Q4f700D0002FGHbFGHbFGH`0
00000oVYE@030000PCebPCeb00B1?G801@00058@G0000;Io00000005kjj700<0002IGHRIGHP00iUM
R0050000B1iiB1ii0000gIj?00<00004`hFB00<0002EFhREFhP00iEKR0800003RUVA00<0002BFhfB
Fhd00i9KS@030000JC^6JC^6009Y>hH300000YeVT@040000V6RJV6RJ00001KImUP800004NdV;00<0
001]?XM]?XL00VdnQ`030000Pdn;Pdn;00>3Ch/00`0008QCS000000300001HYES0030000SUR<SUR<
00B>F8`300001F@lS0030000ECVC000000=jBhd01@0006i5S`0007iBT`000005OEBG00<0001fEIif
EIh00gIEWP050000U6jTU6jTU6jT000000BUS;X00`000<:DZ0000005YG:I00<0002MJ9BMJ9@00ieX
U0030000V6>BV6>B00>HHi800`0009EPT9EPT003UF2@00<0002FH92FH9000YIPT0800003WFRC00<0
002WLIJWLIH00ZMaUP040000W6ZGW6ZG00001IIQT@050000<An:<An:<An:000000FX`>/00`000:S0
j`00000200000ZS0j`030000oooooooo01?oool00`000?ooo`00000_oooo000<oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool05oooo`030000
oooooooo02Ooool00`000?ooooooo`09oooo00<0003W]9oW]9l00nNdW`800002GD6G0P000005ASZO
00000000T6NO000000GFXYl01@000;f0TKf0TKf0T@000004Q4f700D0002FGHbFGHbFGH`000000oVY
E@030000PCebPCeb00B1?G801@00058@G0000;Io00000005kjj700<0002IGHRIGHP00iUMR0050000
B1iiB1ii0000gIj?00<00004`hFB00<0002EFhREFhP00iEKR0030000Lcn3000000::FI400`00099K
SI9KS@03TU^=00<0001Y>hIY>hH00VTkQPD00003V6RJ00<0002fOIJfOIH00kImUP800004NdV;00<0
001]?XM]?XL00VdnQ`030000Pdn;Pdn;00:3Ch/300000hQCS0030000RUF<RUF<00>:EH`00`0008iH
S8iHS004SUR<0`0000ET?8`2000017Y;S@800002OU:C00<0001mE9MmE9L00geDU`030000MUFNMUFN
009fEIh00`0009A^Y9A^Y002U6jT00D0002US;ZUS;ZUS;X000000l:DZ0030000YG:IYG:I00>ULYT0
0`0009eXU9eXU002WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@00>EH9000`0009IPT9IPT002
UV2@00<0002MJ9<000000YeXT`030000Yg6FYg6F00:WLIH0100009aZUiaZU`0000FFHI401@00034O
RS4ORS4ORP000004Z<3[0`0000FX`>/00`000?ooooooo`0Foooo00<0003oooooool0;?ooo`002ooo
o`030000oooo000000Ooool00`000?ooo`000006oooo00<0003oooooool06?ooo`030000oooooooo
02Koool00`000?ooooooo`09oooo00<0003W]9oW]9l00^NdW`@00002GD6G0P0000B@Iil00`000=JR
WmJRW`02eZ:O00D0002mP96mP96mP940000018A=Q`050000UUf<UUf<UUf<000000?iZED00`00084m
LX4mLP03PCeb00<0001B45aB45`00P0000K_[XL00`0009UMR9UMR003VEf800<000187WU87WT00P00
00031@1X0000000000C3QI800`0009EKR9EKR003UE^800<0001c?h<000000XYIT@030000TU^=TU^=
00>BFhd00`0006TkQVTkQP02JC^60`0000FHJ9X00`000;ImU[ImUP03]WfF0P0000AkBH/00`0006dn
QfdnQ`02KCj700<00023Ch/000000P000003Pdn;0000R5><00>8Dh`00`0008YES8YES003RUF<00<0
002>F8b>F8`018iHS0<00005I3b<00<0001jBhejBhd00gY;S@800002OU:C00<0001mE9MmE9L00geD
U`050000MUFNMUFNMUFN000000FDKZ@010000:F<^ZF<^P0000C2U:P00`000:EbVJEbV@03YG:I00<0
002MJ9BMJ9@00YeXU0030000V6>BV6>B00>HHi800`0009EPT9EPT003UF2@00D0002FH92FH92FH900
00000ieXT`030000WFRC000000>WLIH200000YaZU`030000UV6AUV6A00>FHI400`00034ORS4ORP02
<An:00@0002X`>/000000002XI7400<0002X`>^X`>/01:S0j`030000oooooooo01Goool00`000?oo
ooooo`0/oooo0006oooo0`0000;oool00`000?ooo`000009oooo00<0003oooooool00oooo`030000
oooo000001[oool00`000?ooooooo`0Noooo00<0003oooooool01?ooo`80000:oooo00<0003W]9oW
]9l00^NdW`@00002GD6G00<0002@Iin@Iil00i1WW`050000eZ:OeZ:OeZ:O000000BmP9400`0008A=
QhA=Q`02Q4f700D0002FGHbFGHbFGH`000000oVYE@030000PCebPCeb00>1?G800`00058@G58@G002
00001^n^Q`030000VEf8VEf800>IGHP00`0004PNNDPNN@02000000<506P0000000001<>5TP030000
UE^8UE^800>EFhP01P0007<oPg<oP`0008YIT@0000FBFhd00`0006TkQVTkQP02JC^600<0002HNJl0
00001IQXVP030000]WfF]WfF00BfOIH00`0007]9Rg]9R`02NdV;00@0001]?XM]?XM]?XL3000018=?
R`030000R5><R5><00:8Dh`00`0008YES8YES003RUF<00<0002>F8b>F8`018iHS0040000KCn8KCn8
00000f@lS0800005NT^=00D0001nDY=nDY=nDY<000001WeDU`040000MUFN000000001YA^Y0800005
`YBX00<0002ULYVULYT00jEbV@030000WFRDWFRD00:MJ9@00`0009QSTYQSTP03V6>B00<0002EH92E
H9000iEPT0050000UV2@UV2@UV2@000000>MJ9<00`0009eXT`000003Yg6F0P0000:LJYL00`0009IQ
TIIQT@04UV6A00@0000a7hXa7hXa7hX200001J6Aa0040000Z<3[Z<3[Z<3[0`0001Soool00`000?oo
ooooo`0[oooo000;oooo00<0003oool000001oooo`800006oooo0P0001coool00`000?ooooooo`0L
oooo0P0000Goool300002Oooo`030000ikBOikBO00;W]9l00`00091PU@00000200000Ue1U`030000
T6NOT6NO00>@Iil01@000=JRWmJRWmJRW`000004_H2A00<00024CHN4CHL00XA=Q`050000UUf<UUf<
UUf<000000?iZED00`00084mLX4mLP03PCeb00<0001B45aB45`00P0000K_[XL00`0009UMR9UMR003
VEf800H000187WT0003MWXl0000506P200001<>5TP030000UE^8UE^800>EFhP01P0007<oPg<oP`00
08YIT@0000FBFhd00`0006TkQVTkQP0200000YQi[`030000V6RJV6RJ00>HJ9X00`000;ImU[ImUP04
]WfF00<0001kBH]kBH/00W]9R`@000000fdnQ`0008=?R`04Pdn;00<00028Dhb8Dh`00XQCS0030000
RUF<RUF<00>:EH`00`0008iHS8iHS004SUR<00@0001]?hQ]?hP00002I3b<00<0002TJi00000017Y;
S@030000OU:COU:C009nDY<00`0007eDUgeDU`04OEBG0P000003T6BJ0000U6jT00FDKZ@200001L:D
Z0030000YG:IYG:I00>ULYT00`0009eXU9eXU002WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@
00>EH9001@0009IPT9IPT9IPT0000004WFRC00<0002MJ9<000000ZMaUP80000019aZU`00091LT000
00FFHI401@00034ORS4ORS4ORP000007XI740`0000>X`>/00`000?ooooooo`0Foooo00<0003ooooo
ool0:_ooo`002oooo`030000oooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool07?oo
o`030000oooooooo01[oool00`000;56?P000005oooo0`0000Woool00`000>NdWnNdW`02ikBO00<0
002@H9D000000P00009M@IL00`00091WWi1WW`03T6NO00D0003FXYoFXYoFXYl000001;f0T@030000
Q4f7Q4f700:4CHL01@0009IMS9IMS9IMS0000003nJUE00<00021?G:1?G800h4mLP030000DQ1LDQ1L
00800006kjj700<0002IGHRIGHP00iUMR0060000B1ii0000gIj?00001@1X0P0000G3QI800`0009EK
R9EKR002UE^800@0001c?h=c?h=c?h<200001I9KS@<00004V7V_00<0002HJ9ZHJ9X019QXVP030000
]WfF]WfF00>fOIH0100007]9Rg]9Rg]9R`<00003KCj700<00023Ch^3Ch/00h=?R`030000R5><R5><
00:8Dh`00`0008YES8YES003RUF<00<0002>F8b>F8`00hiHS0070000KCn8KCn8KCn80000I3b<0000
00:TJi00100007Y;SGY;SGY;S@800005OU:C00<0001mE9MmE9L00geDU`040000T6BJT6BJ00001YA^
Y0030000`YBX`YBX00C2U:P00`000:EbVJEbV@03YG:I00<0002MJ9BMJ9@00YeXU0030000V6>BV6>B
00>HHi800`0009EPT9EPT003UF2@00<0002FH92FH9000P0000FMJ9<200000ZMaUP80000019aZU`00
091LT00000FFHI400`00034ORS4ORP02<An:00<0002QTLBQTL@00j6Aa0030000bobk000000FX`>/0
0`000?ooooooo`0Eoooo00<0003oooooool0:_ooo`003?ooo`030000oooooooo00Koool300001Ooo
o`030000oooooooo01goool00`000?ooooooo`0Ioooo00<0002aASh000001Oooo`8000000b8@P000
0?ooo`06oooo00<0003W]9oW]9l00nNdW`030000T62E000000800002GD6G00<0002@Iin@Iil0191W
W`030000eZ:O000000FmP9400`0008A=QhA=Q`02Q4f700D0002FGHbFGHbFGH`000000oVYE@030000
PCebPCeb00>1?G800`00058@G58@G00200001^n^Q`030000VEf8VEf800>IGHP01P0004PNN@000=fN
S`0000D0J0800005`hFB00<0002EFhREFhP00YEKR0040000Lcn3Lcn3Lcn30P0000>BFhd3000000=S
>8L00000000019Qi[`030000V6RJV6RJ00>HJ9X00`000;ImU[ImUP03]WfF1000009kBH/01@0006dn
QfdnQfdnQ`000005Pdn;00<00028Dhb8Dh`00XQCS0030000RUF<RUF<00>:EH`00`0008iHS8iHS003
SUR<00@0001]?hQ]?hQ]?hP200000jA[T0060000NT^=NT^=0000ODn?00001GiBT`040000OEBGOEBG
OEBG0P0000>@I9X00`0009A^Y9A^Y003U6jT0P0000K2U:P00`000:EbVJEbV@03YG:I00<0002MJ9BM
J9@00ieXU0030000V6>BV6>B00>HHi800`0009EPT9EPT002UF2@00<0002FH92FH9000P0000JMJ9<0
0`000:MaUP000002Tf6C0P000003T5b@0000UV6A00BFHI400`00034ORS4ORP02<An:00<0002QTLBQ
TL@00Z6Aa0040000bobkbobk00001JS0j`80000Goooo00<0003oooooool0:Oooo`007Oooo`030000
oooooooo01koool00`000?ooooooo`09oooo00<0003oooooool02oooo`050000/DHn/DHn/DHn0000
00Coool2000000<R4800003oool01_ooo`030000ikBOikBO00;W]9l00`00091PUI1PU@0300000ee1
U`030000T6NOT6NO00>@Iil00`000=JRW`000005_H2A00<00024CHN4CHL00XA=Q`050000UUf<UUf<
UUf<000000;iZED00`00084mLX4mLP04PCeb00<0001B45aB45`00P0000K_[XL00`0009UMR9UMR003
VEf800H000187WT0003MWXl0000506P200001L>5TP030000UE^8UE^800:EFhP00`0007<oPg<oP`02
Lcn31000009mB8H0100006<hQ`00000000BHNJl00`0009QXVYQXVP03V6RJ00@0002fOIJfOIJfOIH3
000000>IHi40001kBH/00W]9R`050000KCj7KCj7KCj7000000F3Ch/00`0008QCS8QCS002R5><00<0
002:EHb:EH`00hYES0030000SUR<SUR<00:>F8`00`0006doR6doR002KCn800<0002TJi2TJi000ZA[
T0030000NT^=0000009mChl00`0007iBTgiBT`03OU:C00<0001mE9MmE9L00P0000F@I9X00`0009A^
Y9A^Y002U6jT0`0000G2U:P00`000:EbVJEbV@03YG:I00<0002MJ9BMJ9@00ieXU0030000V6>BV6>B
00>HHi800`0009EPT9EPT003UF2@00@0002FH90000000006WFRC00<0002WLIH000000Y=QT`800000
0i1LT00009IQT@04UV6A00<0000a7hXa7hX00c4ORP040000XI74XI7400001<_l^`030000Z<3[0000
00800002Z<3[00<0003oooooool05Oooo`030000oooooooo02Soool001goool200008?ooo`030000
oooooooo00Soool200002oooo`030000/DHn/DHn00:aASh01`000?ooooooooooo`000<K1?@000002
8Q2000<0003oooooool00oooo`800004ikBO00H0002@H9F@H9D0000:07000003GD6G00<0002@Iin@
Iil00i1WW`030000eZ:O000000FmP9400`0008A=QhA=Q`02Q4f700D0002FGHbFGHbFGH`000000_VY
E@030000PCebPCeb00>1?G801000058@G58@G58@G0800006kjj700<0002IGHRIGHP00iUMR0030000
B1ii0000008000021@1X00<00033QI;3QI800l>5TP030000UE^8UE^800:EFhP00`0007<oPg<oP`02
Lcn300<0001mB8ImB8H00ge8QP8000000iMMR`0009Qi[`03V7V_00<0002HJ9ZHJ9X00iQXVP@00002
]WfF00<0002IHi4000000g]9R`050000KCj7KCj7KCj7000000F3Ch/00`0008QCS8QCS002R5><00<0
002:EHb:EH`018YES0040000SUR<SUR<00000fdoR0800005Y6^@0P0000=mChl00`0007iBTgiBT`03
OU:C0`000003Q5ND0000T6BJ00B@I9X0100009A^Y9A^Y9A^Y0@00005`YBX00<0002ULYVULYT00jEb
V@030000WFRDWFRD00>MJ9@00`0009QSTYQSTP03V6>B00<0002EH92EH9000iEPT08000000iMSTP00
09eXT`05WFRC0`0000:CHI<01000091LT91LT00000FFHI400`00034ORS4ORP03<An:00@0002QTLBQ
TL@00003bobk0`0000FX`>/00`000?ooooooo`0Eoooo00<0003oooooool0:?ooo`007Oooo`030000
oooooooo023oool00`000?ooooooo`06oooo00@0002gP9VgP9T00008oooo0P000003hHQQ0000/DHn
00:aASh01`000?ooooooooooo`000<K1?@0000028Q2000<0003oooooool00oooo`030000ikBOikBO
00?W]9l01P00091PUI1PU@0000X0L00000=M@IL00`00091WWi1WW`03T6NO00<0003FXYl000001Kf0
T@030000Q4f7Q4f700:4CHL01@0009IMS9IMS9IMS0000002nJUE00<00021?G:1?G800h4mLP050000
DQ1LDQ1LDQ1L000000O_[XL00`0009UMR9UMR003VEf80P000003gIj?00000000008506P00`000<>5
T/>5TP03`hFB00<0002EFhREFhP00YEKR0030000Lcn3Lcn3009c?h<00`0007e8QWe8QP03ODR60P00
0003Uef;0000V7V_00>HNJl0100009QXVYQXVYQXVP<00005]WfF00@0002IHi6IHi400002NdV;00D0
001]?XM]?XM]?XL000001H=?R`030000R5><R5><00>8Dh`00`0008YES8YES003RUF<00D0002>F8b>
F8`0001]?hP00P000003Z72C0000Y6^@00BTJi000`0007e?Sge?S`03ODn?00<0001nDY=nDY<00WiB
T`050000Q5NDQ5NDQ5ND000000F@I9X0100009A^Y9A^Y9A^Y0@00006`YBX00<0002ULYVULYT00jEb
V@030000WFRDWFRD00:MJ9@00`0009QSTYQSTP03V6>B00<0002EH92EH9000iEPT08000000iMSTP00
09eXT`05WFRC00<0002WLIH000000Y=QT`040000T5b@T5b@00001YIQT@030000<An:<An:00<a7hX2
00000/_l^`800002XHo200<0002X`>^X`>/00jS0j`80000Goooo00<0003oooooool01oooo`<00002
oooo00<0003oooooool06?ooo`007?ooo`030000oooooooo02;oool00`000?ooooooo`05oooo00@0
002gP9VgP9T00005oooo0`0000CQR64010000;56?[56?P0000?oool00`000<K1?@0000028Q2000<0
003oooooool00_ooo`800004ikBO00L0002@H9F@H9F@H9D0000:070000000ee1U`030000T6NOT6NO
00B@Iil00`000;f0TKf0T@04_H2A00<00024CHN4CHL00XA=Q`050000UUf<UUf<UUf<000000;iZED0
0`00084mLX4mLP03PCeb00D0001B45aB45aB45`000001nn^Q`030000VEf8VEf800>IGHP2000000?M
WXl0000000000PD0J0030000`hFB`hFB00?3QI800`0009EKR9EKR002UE^800<0001c?h=c?h<00W<o
P`030000ODR6ODR600=mB8H200000YMMR`040000V7V_V7V_V7V_100000:HJ9X00`000;ImU[ImUP03
]WfF00L0002IHi6IHi6IHi40001kBH/000000fdnQ`030000Pdn;Pdn;00>3Ch/00`0008QCS8QCS003
R5><00<0002:EHb:EH`00hYES0030000SUR<000000800003Z72C00<0002TJi2TJi000ZA[T0800005
ODn?00D0001nDY=nDY=nDY<0000018AGU0030000T6BJT6BJ00>@I9X00`0009A^Y9A^Y00500001/:D
Z0030000YG:IYG:I00>ULYT00`0009eXU9eXU002WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@
00>EH9001@0009MSTYMSTYMSTP000006WFRC00D0002CHI<0002CHI<000000Y1LT0030000UV6AUV6A
00BFHI400`00034ORS4ORP02<An:1@0000BQSl800`000:S0jjS0j`0300000ZS0j`030000oooooooo
01Coool00`000?ooooooo`08oooo00H0003oooooool0003oool0000Ioooo000Loooo00<0003ooooo
ool08oooo`030000oooooooo00?oool00`000;N0VKN0V@02]h2I00<0003oooooool00P000003YlO`
0000hHQQ00CQR6401@000;56?[56?P000?ooo`03000000?6`Cd0000R48000R8@P0040000oooo0000
00000XYJT`050000ikBOikBOikBO000000>@H9D00`0000X0L0000003GD6G00<0002@Iin@Iil0191W
W`030000_H2A_H2A00BmP9400`0008A=QhA=Q`02Q4f700<0002FGHbFGH`00P0000;iZED00`00084m
LX4mLP03PCeb00D0001B45aB45aB45`000001nn^Q`030000VEf8VEf800>IGHP2000000?MWXl00000
00000PD0J0030000`hFB`hFB00?3QI800`0009EKR9EKR002UE^800<0001c?h=c?h<00W<oP`030000
ODR6ODR600=mB8H200000YMMR`030000V7V_000000800005V6RJ00<0002fOIJfOIH00kImUP040000
VF>AVF>AVF>A0`0000A]?XL00`0008=?Rh=?R`03Pdn;00<00028Dhb8Dh`00XQCS0030000RUF<RUF<
00>:EH`300001ZQ`T`060000Y6^@Y6^@0000N4V<00001Ge?S`040000OU:C000000001HAGU0030000
T6BJT6BJ00>@I9X00`0009A^Y9A^Y00600001L:DZ0030000YG:IYG:I00>ULYT00`0009eXU9eXU002
WFRD00<0002HHi:HHi800iQSTP030000UF2@UF2@00>EH9001@0009MSTYMSTYMSTP000006WFRC00@0
002CHI<000000004T5b@00<0002FHI6FHI400iIQT@030000<An:000000800003IeFY00<0002QSl:Q
Sl801:6?`P800005Z<3[00<0003oooooool05Oooo`030000oooooooo00Goool4000000Coool0003o
ool0000Ioooo000Loooo00<0003oooooool09?ooo`800003oooo00<0002gP9VgP9T00[N0V@<00003
YlO`00<0003QR67QR6401>68H@050000/DHn00000000Y4mU008000000lK1?@00028@P0028Q200P00
00B:FY<010000>NdWnNdW`0000B@H9D0100000X0L0000000009M@IL00`00091WWi1WW`03T6NO0P00
00JmP9400`0008A=QhA=Q`02Q4f700<0002FGHbFGH`00P0000;iZED00`00084mLX4mLP03PCeb00D0
001B45aB45aB45`000001nn^Q`030000VEf8VEf800>IGHP2000000?MWXl0000000000PD0J0030000
`hFB`hFB00?3QI800`0009EKR9EKR002UE^800<0001c?h=c?h<00W<oP`030000ODR6ODR600=mB8H0
0`0009MMRiMMR`0300000YQi[`030000V6RJV6RJ00>HJ9X00`000;ImU[ImUP03]WfF00D0002IHi6I
Hi40001^@hd00P0000A]?XL00`0008=?Rh=?R`03Pdn;00<00028Dhb8Dh`00XQCS0030000RUF<RUF<
00>:EH`300001ZQ`T`030000Y6^@000000=hBH`00`0007e?Sge?S`02ODn?0P0000:>G9800`0008AG
U8AGU003Q5ND00<0002@I9Z@I9X00Y1TVP050000U6jT00000000BcnR00@00005`YBX00<0002ULYVU
LYT00jEbV@030000WFRDWFRD00:MJ9@00`0009QSTYQSTP03V6>B00<0002EH92EH9000YEPT0030000
Uf>BUf>B00:GHi800`0009eXTieXT`04WFRC00@0002CHI>CHI<00004T5b@00<0002FHI6FHI400iIQ
T@800002e9ZG00<0001WEJUWEJT00VMEZ@030000XHo2XHo200:QSl800`000<Ki/@000006Z<3[00<0
003oooooool05Oooo`030000oooooooo00Coool00`000?ooo`000002oooo00<0003oool000006Ooo
o`007?ooo`<0000Voooo00<0003oool000001;N0V@8000000e]2V`000:O7l002YlO`00<0003QR67Q
R6401N68H@040000Y4mUY4mUY4mU0`000005a/4m00008Q208Q20000000J:FY<00`000>NdW`000004
T62E00@0000:070000000002GD6G00<0002@Iin@Iil00i1WW`800006_H2A00<00024CHN4CHL00XA=
Q`030000UUf<UUf<00800002nJUE00<00021?G:1?G800h4mLP050000DQ1LDQ1LDQ1L000000O_[XL0
0`0009UMR9UMR003VEf80P000006gIj?0000PD^700001@1X00001L>5TP030000UE^8UE^800:EFhP0
0`0007<oPg<oP`02Lcn300<0001mB8ImB8H00ge8QP<000000iMMR`0009Qi[`02V7V_00<0002HJ9ZH
J9X00iQXVP030000]WfF]WfF00>fOIH0100009USTIUST@00009^@hd00`0006dnQfdnQ`02KCj700<0
0023Ch^3Ch/00h=?R`030000R5><R5><00:8Dh`00`0008YES8YES003RUF<00<0003?UYT000001ZQ`
T`030000Y6^@000000=hBH`00`0007e?Sge?S`02ODn?00D0002>G9:>G9:>G98000001HAGU0030000
T6BJT6BJ00>@I9X200000T/oXP@00005`YBX00<0002ULYVULYT00jEbV@030000WFRDWFRD00:MJ9@0
0`0009QSTYQSTP03V6>B00<0002EH92EH9000YEPT0030000Uf>BUf>B00:GHi800`0009eXTieXT`04
WFRC00D0002CHI<0002@G90000000i1LT0030000UV6AUV6A00>FHI401@000=BJUmBJUmBJU`000004
IeFY00D0002QSl:QSl:QSl8000000lKi/@040000Z<3[Z<3[Z<3[0`0001Ooool00`000?ooooooo`05
oooo0P0000;oool00`000?ooo`00000Ioooo000Loooo00<0003oooooool09oooo`800004]h2I0P00
009K@Y/2000000>Wao00003QR6401^68H@040000Y4mUY4mUY4mU0`000005a/4m00008Q208Q200000
00J:FY<010000>NdW`00000000>@H9D0100000X0L0X0L000009M@IL00`00091WWi1WW`02T6NO0`00
00JmP9400`0008A=QhA=Q`02Q4f700<0002FGHbFGH`00P0000;iZED00`00084mLX4mLP02PCeb00<0
001B45aB45`00U8@G0030000kjj7kjj700G_[XL00`0009UMR9UMR003VEf80`0000:1BhL0100000D0
J000000000C3QI800`0009EKR9EKR002UE^800<0001c?h=c?h<00W<oP`040000ODR6ODR6ODR60`00
00BGGH/01@0009Qi[iQi[iQi[`000004V6RJ00<0002fOIJfOIH01;ImUP030000VF>A000000=^@hd0
1@0006dnQfdnQfdnQ`000005Pdn;00<00028Dhb8Dh`00XQCS0040000RUF<RUF<RUF<0P0000??UYT0
0`000:Q`TjQ`T`03Z72C0P0000AhBH`01@0007e?Sge?Sge?S`000004SUbB00<00024EiB4Ei@00hAG
U0030000T6BJT6BJ00>@I9X200000T/oXP04000001j[000000001L:DZ0030000YG:IYG:I00>ULYT0
0`0009eXU9eXU002WFRD00<0002HHi:HHi8019QSTP040000UF2@UF2@00001IMSTP030000WFRCWFRC
00>MJ9<01P0009=QTi=QT`00091LT00000>@G9000`0009IQTIIQT@03UV6A00D0003DVYODVYODVYL0
000016MEZ@040000XHo2XHo200001<Ki/@@00003Z<3[00<0003oooooool05Oooo`030000oooooooo
00Goool01@000?ooooooooooo`00000Joooo000Loooo00<0003oooooool09oooo`030000]h2I]h2I
00>gP9T2000015]2V`030000h]76000000GQR6400`000:A?IJA?I@02Y4mU0`000005a/4m00008Q20
8Q20000000N:FY<00`000?SHZP000003T62E00@0000:070:07000002GD6G00@0002@Iin@Iin@Iil2
000000>9EXl0002mP9401Kf0T@030000Q4f7Q4f700:4CHL01@0009IMS9IMS00006TmR@0200001H4m
LP030000DQ1LDQ1L009B45`00`000>n^Qnn^Q`05kjj700<0002IGHRIGHP00iUMR0030000gIj?0000
00:1BhL0100000D0J000000000C3QI800`0009EKR9EKR002UE^800<0001c?h=c?h<00W<oP`@00002
ODR600<0002GGH^GGH/00YMMR`050000V7V_V7V_V7V_000000BHJ9X00`000;ImU[ImUP04]WfF00<0
002IHi4000000fi3S@800002KCj700<00023Ch^3Ch/00h=?R`030000R5><R5><00:8Dh`0100008YE
S8YES00000G?UYT00`000:Q`TjQ`T`03Z72C00<0001hBHahBH`00gQ9S0040000ODn?000000001HiL
TP030000Q5NDQ5ND00>4Ei@00`00091TVY1TVP03T6BJ00<0001;?j9;?j800T/oXP04000001j[0000
00001<:DZ0030000YG:IYG:I00>ULYT00`0009eXU9eXU002WFRD00<0002HHi:HHi8019QSTP040000
UF2@000000001IMSTP030000WFRCWFRC00>MJ9<0100009=QTi=QT`0000:@G9001000091LT91LT000
00BFHI4200000mBJU`030000IeFYIeFY009WEJT01@000:6?`Z6?`P000<Ki/@0300000ZBNc`030000
Z<3[Z<3[00>X`>/00`000?ooooooo`0Boooo100002Goool001_oool00`000?ooooooo`0Xoooo00<0
002gP9VgP9T00kN0V@030000`/8o000000AK@Y/200001N68H@040000Y4mUY4mUY4mU10000005a/4m
00008Q208Q20000000N:FY<00`000?SHZP000003T62E00@0000:070:07000003GD6G00@0002@Iin@
Iil00002REJ?00<0002mP96mP9401;f0T@030000Q4f7Q4f700:4CHL01@0009IMS9IMS00006TmR@02
00001H4mLP050000DQ1LDQ1LDQ1L000000S_[XL00`0009UMR9UMR003VEf800<0003MWXl000000X5;
Q`0400001@1X000000001<>5TP030000UE^8UE^800:EFhP00`0007<oPg<oP`03000017e8QP030000
Uef;Uef;00>GGH/01@0009Qi[iQi[iQi[`000004V6RJ00<0002fOIJfOIH01;ImUP800004KT>=00D0
000X5880001]?XL000001H=?R`030000R5><R5><00:8Dh`400001LnFV@040000Z72CZ72CZ72C0`00
00EhBH`200000Y1NT`030000SUbBSUbB00:>G9800`0008AGU8AGU003Q5ND00<0002@I9Z@I9X00Y1T
VP800003BcnR1@0000C2U:P00`000:EbVJEbV@03YG:I00<0002MJ9BMJ9@00ieXU0030000V6>BV6>B
00>HHi82000000>EHY<0002GHi8019MSTP030000WFRCWFRC00>MJ9<0100009=QT`00000000>@G900
0`00091LT0000004UV6A0P0000?DVYL00`0006MEZFMEZ@03IeFY100000FTW/l00`000:S0jjS0j`03
Z<3[0P0001Koool00`000?ooooooo`0Soooo000Koooo00<0003oooooool09oooo`030000]h2I]h2I
00>gP9T010000<;2?l;2?`0000EK@Y/00`000>68HN68H@02hHQQ00<0002TCfFTCfD00ZA?I@060000
WGf_00000000a/4m00000R8@P0030000RUZCRUZC00F:FY<00`000?SHZP000003T62E00@0000:070:
07000003GD6G00@0002@Iil000000002REJ?00<0002mP96mP9400kf0T@030000Q4f7Q4f700>4CHL0
1@0009IMS9IMS00006TmR@0200001H4mLP050000DQ1LDQ1LDQ1L000000S_[XL00`0009UMR9UMR003
VEf800<0003MWXl000000X5;Q`0400001@1X1@1X00001<>5TP030000UE^8UE^800:EFhP300000W<o
P`030000ODR6ODR6009mB8H00`0009MMRiMMR`04Uef;00@0002HNJnHNJl00005V6RJ00<0002fOIJf
OIH00kImUP800004KT>=00D0000X5880001]?XL000001H=?R`040000R5><R5><R5><0P0000:[Q:/0
0`000<nFVLnFV@03ciJI00@0002XL9>XL9<00002]gbB00@0001hBHahBHahBH`300000i1NT`030000
SUbBSUbB00:>G9800`0008AGU8AGU003Q5ND00<0002@I9Z@I9X00Y1TVP8000000d/oXP0000000002
00000Ymm[@030000`YBX`YBX00?2U:P00`000:EbVJEbV@03YG:I00<0002MJ9BMJ9@00YeXU0030000
V6>BV6>B00>HHi8200000YERT`030000Uf>BUf>B00>GHi801@0009eXTieXTieXT`000002Tf6C0P00
00B@G902000019IQT@030000e9ZGe9ZG00?DVYL0100006MEZFMEZFMEZ@<000000e11X@000:BNc`05
Y9k?00<0002X`>/000000P0000:VZ=P00`000?ooooooo`0Doooo00<0003oooooool08_ooo`006ooo
o`<0000?oooo1P0001;oool00`000;N0VKN0V@03]h2I0P000003`/8o0000Fd:K00AK@Y/00`000>68
HN68H@02hHQQ00<0002TCfFTCfD00ZA?I@040000WGf_00009@]i0P00008R48000`0008YJThYJT`04
RUZC00@0003hf:[hf:X00003T62E00<0000:070:07000P00009M@IL400000XUFS`030000_H2A_H2A
00>mP9400`0008A=QhA=Q`03Q4f700@0002FGH`0001Y?HT300001H4mLP050000DQ1LDQ1LDQ1L0000
00S_[XL00`0009UMR9UMR002VEf800@0003MWXoMWXl00002PD^700@0000506P506P00004`hFB00<0
002EFhP000000`0000Ac?h<00`0007e8QWe8QP02ODR600<0002GGH^GGH/019MMR`040000V7V_V7V_
00001IQXVP030000]WfF]WfF00>fOIH2000016i3S@030000:1B2:1B200800005Pdn;00@00028Dh`0
00000004ZhB[00<0003?UYW?UYT00lnFV@<00002]gbB1P0000F@GY<00`0008iLTXiLTP02SUbB00<0
0024EiB4Ei@00hAGU0040000T6BJT6BJT6BJ1000009Q?8h00`0000`000000002Wgf]0P0000?2U:P0
0`000:EbVJEbV@03YG:I00<0002MJ9BMJ9@00YeXU0030000V6>BV6>B00:HHi8200000iERT`030000
Uf>BUf>B00>GHi801@0009eXTieXTieXT`000002Tf6C0P0000B@G9000`00091LT0000003UV6A00<0
003DVYODVYL00mBJU`040000IeFY000000001511X@030000Y9k?Y9k?00BTW/l200001JJXf0030000
oooooooo01Goool00`000?ooooooo`0Qoooo000Koooo00<0003oooooool03_ooo`800004PENH0P00
013oool00`000;N0VKN0V@04]h2I0P000003`/8o0000Fd:K00AK@Y/00`000>68HN68H@02hHQQ00<0
002TCfFTCfD00ZA?I@040000WGf_00009@]i0P00008R48000`0008YJThYJT`04RUZC00@0003hf:[h
f:X00003T62E00@0000:070:070:0705000000EgBXl00029EXn9EXl000001Kf0T@030000Q4f7Q4f7
00>4CHL0100009IMS00006TmR@<00005PCeb00D0001B45aB45aB45`000002>n^Q`030000VEf8VEf8
00:IGHP010000=fNSmfNS`0000:1BhL0100000D0J0D0J00000?3QI8300000iEKR0030000Lcn3Lcn3
009c?h<00`0007e8QWe8QP02ODR600<0002GGH^GGH/019MMR`8000000iQi[`0009QXVP04V6RJ00<0
002fOIJfOIH00kImUP800005KT>=00<0000X588X588020000003VG^a0000ZhB[00B[Q:/010000<nF
VLnFVLnFV@<000000kMlTP0000000005SEbC00<0002@GY>@GY<00i1NT`030000SUbBSUbB00:>G980
0`0008AGU8AGU003Q5ND00@0002@I9Z@I9Z@I9X20000164lSP<00004Wgf]00@00032U:S2U:P00005
YG:I00<0002MJ9BMJ9@00YeXU0030000V6>B000000800005UF:C00<0002GHi:GHi800iMSTP040000
WFRCWFRCWFRC0`000003SEV?0000T5b@00B@G90200000YIQT@800005e9ZG0P000003_8RN0000D46Q
00A@@J400`000:BNcjBNc`02Y9k?0P0000NVZ=P00`000?ooooooo`0Doooo00<0003oooooool08Ooo
o`006oooo`030000oooooooo00goool00`000>cZbP000005PENH0P0000koool200001[N0V@@00004
Fd:K0P0000?QR6400`000:A?IJA?I@03Y4mU00@0002MOJl0000U2gT200000R8@P0030000RUZCRUZC
00B:FY<2000000?hf:X0002@H9D00Y1PU@0500002P1`2P1`2P1`0000008mDKh2000000EgBXl00029
EXn9EXl000001Kf0T@030000Q4f7Q4f700>4CHL0100009IMS00006TmR@<00004PCeb00@0001B45aB
45aB45`200002>n^Q`050000VEf8VEf8VEf8000000;MWXl01@00085;Qh5;Qh5;Q`0000021@1X1000
0003`hFB0000UE^800>EFhP00`0007<oPg<oP`02Lcn300@0001mB8ImB8ImB8H200001YMMR`800000
0iQi[`0009QXVP04V6RJ00<0002fOIJfOIH00kImUP800005KT>=00<0000X588X58800RPDPP800005
VG^a00<0002[Q:^[Q:/00j^4Z`030000ciJI000000D00002NU2D00<0002=G9>=G9<00XeLT`030000
T5jCT5jC00>@GY<00`0008iLTXiLTP03SUbB00<00024EiB4Ei@00hAGU0050000T6BJ0000LTF<0000
00AQ?8h300001Imm[@<00005YG:I00<0002MJ9BMJ9@0100000:DHY@00`0009ERTiERT`03UF:C00<0
002GHi:GHi800iMSTP050000WFRCWFRC0000T5fA00800002SEV?00<0002@G92@G9000i1LT0030000
UV6AUV6A00800005e9ZG00@0002lR9jlR9h00005D46Q00<0002TW/nTW/l00P0000:XPZ/00`000:JX
f:JXf002YZSH0P000003`nS`0000oooo01Goool00`000?ooooooo`0Poooo000Koooo00<0003ooooo
ool03?ooo`040000k>[:k>[:00001H5GV0800003oooo100000Goool2000000>TY]P0002gP9T01;N0
V@D00004Fd:K0P0000?QR6400`000:A?IJA?I@02Y4mU00D0002MOJnMOJl0000U2gT00P00008R4800
0`0008YJThYJT`04RUZC0P000003n=RZ0000T62E00:@H9D00`0000X0L0X0L0022P1`00H0000mDKh0
0000001gBXl00002REJ?00<0002mP96mP9400kf0T@030000Q4f7Q4f700>4CHL0100009IMS00006Tm
R@<00004PCeb00L0001B45aB45aB45`0000[274000001nn^Q`050000VEf8VEf8VEf8000000;MWXl0
1000085;Qh5;Qh5;Q`@00004`hFB00<0002EFhREFhP00YEKR0030000Lcn3Lcn3009c?h<0100007e8
QWe8QWe8QP800005Uef;0P000003gYnA0000000000FHJ9X010000;ImU[ImU[ImUP8000000gm?S`00
06i3S@04KT>=00<0000X588X58800RPDPP800006VG^a00@0002[Q:^[Q:^[Q:/5000000=V@I00001j
D9@00gY@U0030000SEbCSEbC00:=G9<00`00091NTi1NT`03T5jC00<0002>G9:>G9800hiLTP030000
Q5NDQ5ND00>4Ei@01@00091TVP000795S0000004HCb>00@0000R7Y<000000004Wgf]00<0002EIiX0
000020000003Tf:E0000U6:D00>DHY@00`0009ERTiERT`03UF:C00<0002GHi:GHi800iMSTP060000
WFRCWFRC0000T5fA00000heIS`030000T5b@T5b@00>@G9000`0009IQTIIQT@0200001MBJU`040000
_8RN_8RN00001U11X@800004Z8:[00D0002VZ=RVZ=RVZ=P000000l?Xl0030000oooooooo01Goool0
0`000?ooooooo`0Ooooo000Koooo00<0003oool000003?ooo`040000k>[:k>[:00001X5GV0@00000
1=1K00000<ETElETE`D00003Y:KH00<0002gP9VgP9T00kN0V@D00003Fd:K0`0000;QR6400`000:A?
IJA?I@03Y4mU00D0002MOJnMOJl0000U2gT00P00008R48000`0008YJThYJT`03RUZC00D00039TI/0
003hf:X000000i1PU@0300002P1`2P1`008:07000`0003eA_P000002MdZ?00@00029EXn9EXl00005
_H2A00<00024CHN4CHL00hA=Q`040000UUf<0000JCf90`0000B1?G801000058@G58@G000008[2740
0`000>n^Qnn^Q`05kjj700@0002IGHRIGHP00003gIj?00<00021BhN1BhL00P00008506P00`000<>5
T/>5TP02`hFB00<0002EFhREFhP00YEKR0030000Lcn3Lcn3009c?h<0100007e8QWe8QWe8QP800005
Uef;0P000004gYnA0000V7V_000019QXVP040000]WfF000000000gm?S`030000KT>=KT>=00=^@hd0
0`0002PDPRPDPP02000000=oCXd0000000001IUk/@030000ZhB[0000008000000k:8ZP0006I1T002
IT6@00<0001jD9AjD9@00WY@U0030000SEbCSEbC00>=G9<00`00091NTi1NT`02T5jC00<0002>G9:>
G9800hiLTP030000Q5NDQ5ND00>4Ei@200000W95S0030000HCb>HCb>009Q?8h01000028NT`000000
00BOOJd00`0009EWVYEWVP03UFNJ00<0002CHYFCHYD00i=RU@030000U6:DU6:D00:DHY@00`0009ER
TiERT`03UF:C00<0002GHi:GHi800iMSTP060000WFRCWFRC0000T5fA00000heIS`030000T5b@T5b@
00>@G902000000>FHI40003DVYL01=BJU`030000_8RN_8RN00:lR9h00`000511XE11X@02D46Q0P00
00JXPZ/300001L?Xl0030000oooooooo01Coool00`000?ooooooo`0Ooooo000Joooo0`0000coool0
1@000>cZb^cZb^cZbP000006PENH00<0003@F`3@F`000P0000C5I5L400000jBVf0030000]h2I]h2I
00>gP9T3000000=;9h<0001K@Y/00U]2V`<00002hHQQ00<0002TCfFTCfD00jA?I@8000001Iem[`00
02D;NBD;N@0000028Q2000<0002:FY>:FY<00hYJT`030000bI6K000000800003T62E00<0000:070:
07000PX0L0<00002MdZ?00@00029EXn9EXl00005_H2A00<00024CHN4CHL00hA=Q`030000UUf<0000
00<00005PCeb00<0001B45`000000b/8L@030000kjj7kjj700G_[XL0100009UMR9UMR00000?MWXl3
000000B1BhL0000506P506P200000l>5TP030000UE^8UE^800:EFhP00`0007<oPg<oP`02Lcn300@0
001mB8ImB8ImB8H200001IMMR`800002gYnA0P0000>HJ9X4000017m?S`030000KT>=KT>=00=^@hd5
00000Wm>S@040000VG^aVG^aVG^a100000=7:h/200000fI1T0030000NU2DNU2D009jD9@00`0008eL
TheLT`03SEbC00<0002@GY>@GY<00Y1NT`030000SUbBSUbB00>>G9800`0008AGU8AGU003Q5ND0P00
009bAH`00`00064lSV4lSP02HCb>00@0000R7Y<R7Y<00004Wgf]00<0002EIiZEIiX00iEWVP030000
Tf:ETf:E00>CHYD00`0009ARU9ARU002U6:D00<0002EHY>EHY<00iERT`030000Uf>BUf>B00>GHi80
1@0009eXT`00091MT@000004SEV?00<0002@G92@G9000i1LT0040000UV6A000000001MBJU`030000
_8RN_8RN00:lR9h00`000511X@000002000000>JNJh0002XPZ/01JR2Z`800004`nS`0`0001Ooool0
0`000?ooooooo`0Noooo000Joooo00<0003oooooool02oooo`030000k>[:k>[:00;/j/X00`00085G
V85GV004PENH0`0000K5I5L2000000=H>I80002TY]P00ZBVf0030000]h2I]h2I00>gP9T010000758
T00004/WP`80000025]2V`0004/WP`000=[>D@000>68H@0000FTCfD2000000FMOJl0000U2gTU2gT0
00000R8@P0030000RUZCRUZC00>:FY<00`000<VAVlVAV`0200000i1PU@0300002P1`2P1`00<:0700
1@0007M:SgM:SgM:S`000002REJ?00<0002mP96mP9400kf0T@030000Q4f7Q4f700>4CHL2000000AY
?HT0000000000005PCeb00<0001B45`000000b/8L@800006kjj700<0002IGHP000001@0000>1BhL0
0`0000D0J0D0J00200000l>5TP030000UE^8UE^800:EFhP00`0007<oPg<oP`02Lcn300H0001mB8Im
B8H0002iNhl00005Uef;0P0000;NWi42000000>HJ9X0000000000Y9JR`040000NTN7000000000Wm?
S`030000KT>=KT>=009^@hd200000W57T0040000ReR?0000Odj=100000=`A8d0100004L[RdL[RdL[
R`800003IT6@00<0001jD9AjD9@00WY@U0030000SEbCSEbC00>=G9<00`00091NTi1NT`02T5jC00<0
002>G9:>G9800hiLTP030000Q5NDQ5ND00>4Ei@01@000795S795S795S0000005HCb>00@0000R7Y<0
00000003Wgf]00<0002EIiZEIiX00iEWVP030000Tf:ETf:E00>CHYD00`0009ARU9ARU002U6:D00<0
002EHY>EHY<00iERT`030000Uf>BUf>B00BGHi82000000>@GI40002=FHl00heIS`030000T5b@T5b@
00>@G900100009IQT@00000000GDVYL00`000;b8W[b8WP02_8RN0P0000FJNJh00`000:R2ZjR2Z`03
Z8:[00<0000001d000000`0000>X`>/00`000?ooooooo`0Eoooo00<0003oooooool07Oooo`004ooo
o`030000oooooooo00Coool600001oooo`L00006PENH0P0000K5I5L3000000=H>I80000000000ZBV
f0030000]h2I]h2I00:gP9T2000000=aB900001;9h<00P000005Fd:K0000BbN30000f/iA00800005
Y4mU0`000005WGf_00009@]i9@]i0000008R48000`0008YJThYJT`02RUZC00@00039TI_9TI_9TI/2
00000i1PU@0300002P1`2P1`00<:07001@0007M:SgM:SgM:S`000002REJ?00<0002mP96mP9400kf0
T@030000Q4f7Q4f700>4CHL2000000AY?HT0000000000005PCeb0P0000@[274200001^n^Q`D00002
gIj?00D00021BhN1BhN1BhL000000PD0J0800003`hFB00<0002EFhREFhP00YEKR0030000Lcn3Lcn3
009c?h<01P0007e8QWe8QP000;UkS`0000FGGH/200000mjOT@800004TUZ;00@0001jAhMjAhMjAhL3
000000=^@hd0000000000P0000=aAi000`0008]HS`000003Odj=00<0001`A8e`A8d00W14S@030000
Ab^;Ab^;0097:h/01@0006I1T6I1T6I1T0000004NU2D00<0002=G9>=G9<00heLT`030000T5jCT5jC
00>@GY<00`0008iLTXiLTP02SUbB00<00024EiB4Ei@00XAGU0030000LTF<LTF<009bAH`00`00064l
SV4lSP03HCb>00@0000R7Y<R7Y<00003Wgf]00<0002EIiZEIiX00iEWVP030000Tf:ETf:E00>CHYD0
0`0009ARU9ARU002U6:D00<0002EHY>EHY<019ERT`030000Uf>BUf>B00>GHi84000018eIS`030000
T5b@T5b@00>@G900100009IQT@00000000GDVYL00`000;b8W[b8WP02_8RN00<0002JNJjJNJh019Yi
[P030000Z8:[Z8:[00:XPZ/300000ZS0j`030000Z<3[Z<3[00:X`>/00`000?ooooooo`0Eoooo00<0
003oooooool07Oooo`004_ooo`030000oooo000000Goool00`0007EZ^7EZ^002MFZh0`0000Coool0
0`000:CTT:CTT002000000>CL:L0000000001H5GV0030000oN>N000000K5I5L300000UPiTP040000
Y:KHY:KH00001;N0V@8000000g58T00004/WP`03000000A;9h<0003JcU7JcU4200001JA?I@030000
]gfD000000:MOJl00`0002D;N@0000038Q2000D0002:FY>:FY>:FY<000000lVAV`800003T62E00<0
000:070:07000PX0L0800003MdZ?00@00029EXn9EXl00005_H2A00<00024CHN4CHL00hA=Q`800000
0fTmR@000000000200000h4mLP<00004:`Qa0P0000C_[XL400000ZMfW0030000gIj?000000B1BhL0
1@0000D0J0000?FhRP000003`hFB00<0002EFhREFhP00YEKR0030000Lcn3Lcn3009c?h<01P0007e8
QWe8QP000;UkS`0000BGGH/200001MjOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`02NTN70`00
00=kBHT010000757T757T00000:;F8l00`0007m>SGm>S@02Odj=00D0001`A8e`A8e`A8d0000014L[
R`050000IT6@IT6@IT6@000000AjD9@00`0008eLTheLT`03SEbC00<0002@GY>@GY<00i1NT`030000
SUbBSUbB00:>G9800`0008AGU8AGU002Q5ND00<0001bAHabAH`00W95S0030000HCb>HCb>00=Q?8h0
1000028NTb8NT`0000BOOJd00`0009EWVYEWVP02UFNJ00<0002CHYFCHYD00i=RU@030000U6:DU6:D
00>DHY@00`0009ERTiERT`03UF:C00<0002GHi:GHi800iMSTP040000T5fA0000000018eIS`030000
T5b@T5b@00B@G90400001=BJU`070000_8RN_8RN_8RN0000d:6W000000FJNJh00`000:R2ZjR2Z`02
Z8:[00<0002X`>^X`>/00ZS0j`040000Z<3[Z<3[Z<3[0`0001Ooool00`000?ooooooo`0Loooo000B
oooo00<0003oool000001Oooo`800004MFZh00<0003CFQ0000001P0000>CL:L200001H5GV0040000
oN>NoN>N00001<ETE`8000000jZ7/00005PiTP02F3VB00<0002TY]P000001;N0V@040000LDR@LDR@
00000T/WP`8000000d/WP`000000000200001ZA?I@060000]gfD]gfD0000WGf_00000RD;N@040000
8Q208Q2000000hYJT`030000bI6KbI6K00<00003T62E00L0000:070:070:0700003f_i8000000gM:
S`040000REJ?REJ?00001Kf0T@030000Q4f7Q4f700>4CHL2000000AY?HT00000002UY]L3000000B1
?G80000000000004:`Qa0P000004kjj70000000000000^n^Q`800002YgJL00<0003MWXl00000185;
Q`0300001@1X000000;e^8X010000<>5T/>5TP0000BEFhP00`0007<oPg<oP`02Lcn300<0001mB8H0
00000[UkS`030000Uef;Uef;00:GGH/200001MjOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`02
NTN700<0001kBHUkBHT00g]9R@040000LDN@LDN@00000X]HS`030000Odj=Odj=009oCXd01@000714
SG14SG14S@000005Ab^;00@0001V@I1V@I000004NU2D00<0002=G9>=G9<00heLT`030000T5jCT5jC
00>@GY<00`0008iLTXiLTP02SUbB00@00024EiB4EiB4Ei@200001G95S0030000HCb>HCb>009Q?8h0
1@00028NTb8NTb8NT`000003Wgf]00<0002EIiZEIiX00YEWVP030000Tf:ETf:E00>CHYD00`0009AR
U9ARU003U6:D00<0002EHY>EHY<00iERT`030000Uf>BUf>B00>GHi82000000>?FXl0002=FHl00heI
S`030000T5b@T5b@00B@G902000000>dPId0000000000]BJU`030000_8RN_8RN00:lR9h00`000=2Q
Y`000005VWV^00<0002XPZ^XPZ/00ZR2Z`030000Z<3[Z<3[00:X`>/400000jS0j`030000oooooooo
01Goool00`000?ooooooo`0Koooo000Boooo00<0003oool000001Oooo`800004MFZh00<0003CFQ3C
FQ000]=J40<00004Tg2W0P0000F1EiP010000?gSW_gSWP0000C5I5L010000:Z7/:Z7/00000=H>I80
0`000:BVf0000004]h2I00@0001aB91aB9000002BbN300<0001;9h=;9h<00P000003LkOk0000Y4mU
00FTCfD01P000;MmU;MmU00009em[`00008U2gT01000028@P28@P00000::FY<010000<VAVlVAVlVA
V`8000001HMCS000091PUI1PU@0000022P1`00<0003f_i;f_i800P00009gBXl01@0008UFShUFShUF
S`000004_H2A00<00024CHN4CHL00hA=Q`<000001>blXP000:FVe`00009dA8P3000000>9E8`0000[
27400R/8L@<00003kjj70`0000>WMY`00`000=fNS`000004PD^700<0000506P000000_FhRP040000
`hFB`hFB000019EKR0030000Lcn3Lcn3009c?h<00`0007e8QP000002^G^?00<0002GGH^GGH/00YMM
R`800005gYnA00<0002BFX^BFX/00Y9JR`030000NTN7NTN7009jAhL00`0007]9RG]9R@03NdV900@0
001aAi1aAi000002ReR?00<0001oCXeoCXd00Wm>S@030000L4B=L4B=009`A8d00`0004L[RdL[R`02
Ab^;00D0001V@I1V@I1V@I0000000gY@U0030000SEbCSEbC00>=G9<00`00091NTi1NT`03T5jC00<0
002>G9:>G9800hiLTP050000Q5ND0000NTZ;000000EbAH`00`00064lSV4lSP02HCb>00<0000R7Y<R
7Y<00P0000>OOJd00`0009EWVYEWVP02UFNJ00<0002CHYFCHYD019=RU@030000U6:DU6:D00:DHY@0
0`0009ERTiERT`03UF:C00<0002GHi:GHi800YMSTP050000T5fA0000SeZ?000000B=FHl00`00091L
T91LT004T5b@00L0002dPIfdPId0003DVYL0003DVYL00P0000:lR9h010000=2QYm2QY`0000JJNJh0
10000:R2ZjR2Z`0000:X`>/300000ZS0j`030000Z<3[Z<3[00:X`>/00`000?ooooooo`0Eoooo00<0
003oooooool06oooo`004_ooo`030000oooo000000Coool00`000?ooo`000005MFZh00<0003CFQ3C
FQ000P000003[Xnf0000Tg2W00BCL:L200000h5GV0050000oN>NoN>NoN>N000000?5I5L200000ZZ7
/0070000F3VBF3VBF3VB0000Y:KH000000>gP9T200000W58T0030000BbN3BbN300=;9h<01@0009=R
UP0007>gn`000004Y4mU0P0000:gOI@00`0009em[`0000029@]i00@0000R480R48000002RUZC00@0
0039TI_9TI_9TI/200000XMCS0040000T62E00002P1`0P0000;f_i8200000WM:S`050000REJ?REJ?
REJ?000000BmP9400`0008A=QhA=Q`03Q4f70`0000;/_:82000017A4R0030000REB<000000@00000
0`00D@000000000300001JMfW0030000gIj?000000B1BhL00`0000D0J0000002mKR:00@00033QI;3
QI800004UE^800<0001c?h=c?h<00W<oP`030000ODR6000000:iNhl00`0009MMRiMMR`02Uef;0P00
00GNWi400`00099JRi9JR`02TUZ;00<0001jAhMjAhL00WY7Q`030000NdV9NdV900=kBHT010000757
T757T00000:;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14S@030000Ab^;Ab^;00=7:h/0
100006I1T6I1T00000AjD9@00`0008eLTheLT`02SEbC00<0002@GY>@GY<00i1NT`030000SUbBSUbB
00>>G9801@0008AGU00007Y:R`000005LTF<00<0001Q?8iQ?8h00V4lSP0300008QjC8QjC00<00002
Wgf]00<0002EIiZEIiX00YEWVP030000Tf:ETf:E00BCHYD00`0009ARU9ARU002U6:D00<0002EHY>E
HY<00iERT`030000Uf>BUf>B00:GHi8200000XmJS`030000SEV?SEV?00>=FHl00`00091LT91LT003
T5b@00L0002dPIfdPId0003DVYL0003DVYL00P0000:lR9h01@000=2QYm2QYm2QY`000005VWV^00<0
002XPZ^XPZ/00`0000FX`>/00`000:S0jjS0j`02Z<3[0P0001Ooool00`000?ooooooo`0Joooo000C
oooo00<0003oooooool00oooo`040000oooooooo00000gEZ^08000000m=J400000000002[Xnf00<0
002CL:NCL:L00i=`Y`800003PENH00@0003mhikmhikmhih200000/ETE`050000ZXN`ZXN`ZXN`0000
00AH>I8200000kN0V@050000LDR@LDR@LDR@000000A;9h<200000Y=RUP800004Y4mU0P0000:gOI@0
0`0009em[`0000029@]i00@0000R480R48000002RUZC00@00039TI_9TI_9TI/200000hMCS0D00002
m[nB0P00009gBXl01@0008UFShUFShUFS`000004_H2A00<00024CHN4CHL00hA=Q`<00002k;bR0P00
00AdA8P400000R/8L@030000001A001A0080054200001JMfW0030000gIj?000000B1BhL00`0000D0
J0000002mKR:00@00033QI;3QI800004UE^800<0001c?h=c?h<00W<oP`030000ODR6000000:iNhl0
0`0009MMRiMMR`02Uef;0P0000GNWi400`00099JRi9JR`02TUZ;00<0001jAhMjAhL00WY7Q`030000
NdV9NdV900=kBHT010000757T757T00000:;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14
S@030000Ab^;Ab^;00=7:h/2000000=V@I00001jD9@00gY@U0030000SEbCSEbC00:=G9<00`00091N
Ti1NT`03T5jC00<0002>G9:>G9800hiLTP800002NTZ;00<0001bAHabAH`00g95S0030000HCb>HCb>
00=Q?8h2000000=bBY<0000000000Ymm[@030000UFNJUFNJ00>EIiX00`0009=RUI=RU@03Tf:E00<0
002DHYBDHY@00YARU0030000UF:CUF:C00>EHY<0100009MSTYMSTYMSTP<00002SeZ?00<0002=FHn=
FHl00heIS`030000T5b@T5b@00>@G90010000;B1WKB1W@0000;DVYL300000[b8WP050000d:6Wd:6W
d:6W000000FJNJh00`000:R2Z`000002/7VH00<0002X`>^X`>/01:S0j`040000Z<3[000000000ZS0
j`030000oooooooo01;oool400006oooo`006Oooo`040000oooooooo00000gEZ^0040000hog00000
00001:j?]P040000Tg2WTg2WTg2W0`0000:1EiP00`000?gSW_gSWP02oN>N0P000003aFAG00000000
00>ZQk000`0005PiTUPiTP02F3VB00<0002TY]P000000[N0V@050000LDR@LDR@LDR@000000A;9h<2
00000Y=RUP<00003Y4mU0P0000:gOI@00`0009em[`0000029@]i0P0000058Q200000RUZCRUZC0000
00;9TI/00`0008EDS`000004Qe><00@00027Dh`000000002m[nB0P00009gBXl01@0008UFShUFShUF
S`000004_H2A00<00024CHN4CHL00hA=Q`<00002k;bR0P00009dA8P300000XUDS0040000:`Qa:`Qa
00000`00D@030000SFZV000000JWMY`20000185;Q`0300001@1X000000?e^8X00`000<>5TP000004
UE^800<0001c?h=c?h<00W<oP`800003^G^?00L0002GGH^GGH^GGH/0002`M90000001MjOT@030000
TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`03NTN700<0001kBHUkBHT00W]9R@030000LDN@000000>;F8l0
0`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14S@030000Ab^;Ab^;00=7:h/0100008UFS`000000
00AjD9@00`0008eLTheLT`02SEbC00<0002@GY>@GY<00i1NT`030000SUbBSUbB00>>G98200000WY:
R`030000LTF<LTF<00=bAH`00`00064lSV4lSP03HCb>0P000006LTZC0000HDRN0000Wgf]00001IEW
VP030000Tf:ETf:E00>CHYD00`0009ARU9ARU002U6:D00<0002EHY>EHY<00iERT`040000Uf>BUf>B
Uf>B0P0000>?FXl00`0008eISheIS`03SEV?00<0002@G92@G9000Y1LT0030000]86M]86M00:dPId0
0`000=BJU`000002000000>lR9h0003@XJL00m2QY`030000VWV^VWV^00>JNJh00`000:R2Z`000002
/7VH0P0000>X`>/400001JS0j`030000oooooooo01Coool00`000?ooooooo`0Ioooo000Ioooo00@0
003oooooool00002MFZh100000F^SkH0100009=`Yi=`Yi=`Y`<00002PENH00P0003mhikmhikmhih0
003ObL800035I5L200000jZ7/0030000F3VBF3VB009H>I800`000:BVf0000002]h2I00D0001aB91a
B91aB900000014/WP`8000000i=RUP000000000300000ZA?I@800002]gfD00<0002MOJl000000RD;
N@800000128@P00008YJT`0000?9TI/00`0008EDS`000006Qe><00@0003f_i;f_i;f_i8200000WM:
S`050000REJ?REJ?REJ?000000BmP9400`0008A=QhA=Q`03Q4f70`0000;/_:8400000WA4R0070000
REB<REB<REB<0000:`Qa000000800540100008eZYXeZYP0000JWMY`20000185;Q`800004mKR:00<0
0033QI80000019EKR0030000Lcn3Lcn3009c?h<200000kUkS`040000Uef;Uef;Uef;0`0000GNWi40
0`00099JRi9JR`02TUZ;00<0001jAhMjAhL00gY7Q`030000NdV9NdV900=kBHT200000h]HS`030000
Odj=Odj=009oCXd00`000714SG14S@02L4B=00<00017:h]7:h/00TL[R`030000REJ?REJ?00800004
NU2D00<0002=G9>=G9<00XeLT`030000T5jCT5jC00>@GY<00`0008iLTXiLTP03SUbB00D0001jBX]j
BX]jBX/000001G95S0030000HCb>HCb>00=Q?8h02000079:Tg9:T`000658WP0009mm[@0000FEIiX0
0`0009=RUI=RU@03Tf:E00<0002DHYBDHY@00YARU0030000UF:CUF:C00>EHY<00`0009MSTYMSTP02
000018mJS`030000SEV?SEV?00>=FHl00`00091LT91LT002T5b@00<0002dPIfdPId00[B1W@050000
e9ZG00000000_8fT00800005d:6W00<0002JNJjJNJh00iYi[P800002/7VH00<0001S@YD000000P00
00>X`>/00`000:S0jjS0j`03Z<3[0P0001Koool00`000?ooooooo`0Hoooo000Ioooo0`000004oooo
0000000000000_ooo`030000[Xnf[Xnf00>^SkH0100009=`Yi=`Yi=`Y`<00002PENH00@0003mhikm
hih00003glW20`0000>ZQk0200000UPiTP8000000jBVf0000;N0V@0200000g58T0030000BbN3BbN3
009;9h<01@0009=RUY=RUP000??0V@02000000FmQi/00000002HK9h000000kMmU080000022D;N@00
0?gLP`00028@P00008YJT`0000?9TI/00`0008EDS`000006Qe><00@0003f_i;f_i;f_i8200000WM:
S`050000REJ?REJ?REJ?000000BmP9400`0008A=QhA=Q`03Q4f70P000003k;bR0000000000800004
M4B800L00029E8b9E8b9E8`0000[274000000P00D@040000SFZVSFZV00001ZMfW0800004PD^70P00
00?e^8X2000000?3QI80002EFhP00iEKR0030000Lcn3Lcn3009c?h<200001;UkS`030000Uef;Uef;
00@00004gYnA00<0002BFX^BFX/00Y9JR`030000NTN7NTN700=jAhL00`0007]9RG]9R@03NdV90P00
00>;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14S@030000Ab^;Ab^;0097:h/01@0008UF
ShUFShUFS`000004NU2D00<0002=G9>=G9<00XeLT`030000T5jCT5jC00>@GY<00`0008iLTXiLTP02
SUbB00<0001jBX]jBX/00WY:R`030000LTF<LTF<00=bAH`00`00064lSV4lSP03HCb>00@0001bBY=b
BY<00002HDRN0P0000FEIiX00`0009=RUI=RU@03Tf:E00<0002DHYBDHY@00YARU0030000UF:CUF:C
00BEHY<0100009MSTP00000000B?FXl00`0008eISheIS`03SEV?00D0002@G92@G92@G90000001KB1
W@040000e9ZG0000_8fT0P0000K@XJL00`0009Yi[YYi[P03VWV^00H0002`NIR`NIR`NIP0001S@YD2
00001:S0j`030000Z<3[Z<3[00<00002Z<3[00<0003oooooool05?ooo`030000oooooooo01Ooool0
01Woool01@000?ooooooooooo`000005oooo00<0002^SkJ^SkH00Zj?]P050000Tg2WTg2W0000hk:S
008000001H5GV0000?gSW_gSWP000004glW200<0003ObL8000000jZ7/0800002F3VB0P000003Y:KH
0000]h2I00800003LDR@00@0001;9h=;9h=;9h<200000Y=RUP030000ll2I000000@000000iQ/WP00
0;MmU002]gfD0P0000089@]i0000oMb300008Q200000RUZC00000/VAV`040000QEB?QEB?00001XMC
S0800002m[nB0P0000=gBXl0100008UFShUFS`0000BmP9400`0008A=QhA=Q`03Q4f70`0000;/_:82
000017A4R0030000REB<REB<00:9E8`2000000<00540002=JZH00XeZYP030000YgJLYgJL00BWMY`2
0000185;Q`800003mKR:0P000003`hFB0000UE^800>EFhP00`0007<oPg<oP`02Lcn30P0000BiNhl0
0`0009MMRiMMR`0400001=jOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`03NTN700<0001kBHUk
BHT00g]9R@800003ReR?00<0001oCXeoCXd00Wm>S@030000L4B=L4B=009`A8d00`0004L[RdL[R`02
Ab^;00<00029EXn9EXl00XUFS`050000NU2DNU2DNU2D000000F=G9<00`00091NTi1NT`03T5jC00<0
002>G9:>G9800P0000AjBX/00`000795S795S003LTF<00<0001Q?8iQ?8h00V4lSP050000LTZCLTZC
LTZC0000009QB9h00`0009mm[@000004UFNJ00<0002CHYFCHYD00i=RU@030000U6:DU6:D00:DHY@0
0`0009ERTiERT`04UF:C0P000003U5n@0000SeZ?00>?FXl00`0008eISheIS`03SEV?00D0002@G92@
G92@G90000001KB1W@030000e9ZG000000:lSJ@00`000=2QYm2QY`04d:6W00<0002JNJjJNJh00YYi
[P800003/7VH00@0001S@YES@YD00004Z<3[0`0000FX`>/00`000?ooooooo`0Doooo00<0003ooooo
ool05oooo`006?ooo`030000oooooooo00Soool00`000:j?]Zj?]P02[Xnf00D0002CL:NCL:L0003S
/Z<00P000006PENH0000oN>N0000001W00001]o9`P030000ZXN`000000800002F3VB00D0003kc9D0
0000002gP9T00P0000=aB900100004/WPd/WPd/WP`800002Tf:F00<0003c`9T000000P000004V6bN
0000V6bN00000kMmU080000012D;N@00000004mF^P<00003bI6K00@00025E8n5E8l00006Qe><00H0
003f`YD00000003_f6L00003MdZ?00@00029EXn9EXl00004_H2A00<00024CHN4CHL00`000003jjj?
0000k;bR00;/_:82000017A4R0030000REB<REB<00:9E8`3000018eZYP030000YgJLYgJL00>WMY`0
0`0009mUS@000004PD^70P0000?e^8X4000019EKR0030000Lcn3Lcn3009c?h<00`000;UkSkUkS`03
^G^?00<0002GGH^GGH/00P000003>1Qm0000gYnA00?NWi400`00099JRi9JR`02TUZ;00<0001jAhMj
AhL00gY7Q`030000NdV9NdV900=kBHT00`0008]HSh]HS`02ReR?00<0001oCXeoCXd00Wm>S@030000
L4B=L4B=009`A8d0100004L[RdL[RdL[R`800004REJ?00D0001jD9AjD9AjD9@000001HeLT`030000
T5jCT5jC00>@GY<01@0008iLTP000;1dS`000004NTZ;00<0001bAHabAH`00g95S0030000HCb>HCb>
009Q?8h00`00079:Tg9:T`02LTZC00<0001QB9iQB9h00P0000BEIiX00`0009=RUI=RU@03Tf:E00<0
002DHYBDHY@00iARU0030000UF:CUF:C00>EHY<2000000>DGi00002?FXl018mJS`030000SEV?SEV?
00:=FHl01@00091LT91LT91LT0000005]86M00@0003DVYL0002lSJ@300001]2QY`060000VWV^0000
0000d:bd00001;1iV0050000Hd:E00000000Z<3[00800002Z<3[00<0002X`>^X`>/00jS0j`80000F
oooo00<0003oooooool05_ooo`006?ooo`030000oooooooo00Soool00`000:j?]Zj?]P02[Xnf00D0
002CL:NCL:L0003S/Z<00P000004PENH0000000000000P00I`800004glW21@000004F3VB0000nlbE
nlbE0P000003]h2I0000000000=aB9001@0004/WPd/WPd/WP`000002Tf:F00<0003c`9Wc`9T00`00
00>HK9h010000;MmU;MmU;MmU080000012D;N@00000004mF^P<00003bI6K00@00025E8n5E8l00005
Qe><00L0003f`YGf`YGf`YD0003_f6L000000gM:S`040000REJ?REJ?00001;f0T@<00002Q4f70P00
00C/_:82000017A4R0030000REB<REB<00>9E8`2000018eZYP030000YgJLYgJL00:WMY`0100009mU
SImUS@0000B1BhL200000oFhRP040000XfnF0000000019EKR0030000Lcn3Lcn3009c?h<00`000;Uk
SkUkS`03^G^?00L0002GGH/0002`M900000h67d000001=jOT@030000TUZ;TUZ;00:BFX/00`0007Y7
QgY7Q`03NTN700<0001kBHUkBHT00g]9R@030000ReR?ReR?00:;F8l00`0007m>SGm>S@02Odj=00<0
001`A8e`A8d00W14S@040000Ab^;Ab^;Ab^;0P0000B9EXl200000WY@U0030000SEbCSEbC00>=G9<0
0`00091NTi1NT`03T5jC00D0002>G980002`M8l0000017Y:R`030000LTF<LTF<00=bAH`01@00064l
SV4lSV4lSP000005LTZC00<0001QB9iQB9h00P0000BEIiX00`0009=RUI=RU@03Tf:E00<0002DHYBD
HY@00iARU0030000UF:CUF:C00>EHY<0100009AOT9AOT00000F?FXl00`0008eISheIS`02SEV?00@0
002@G92@G9000007]86M00<0002lSJ@000000/nh``030000d:6Wd:6W00C@XJL200000/2G[@030000
/7VH/7VH00>`NIP00`0006=2UF=2U@0200001:S0j`030000Z<3[Z<3[00<00002WH6d00<0003ooooo
ool05?ooo`030000oooooooo01Goool001Soool00`000?ooooooo`08oooo00<0002^SkJ^SkH00jj?
]P800003hk:S0`000003hk:S0000001W00<006L5000000KR/J@0003``9h0001H>I800002nlbE0`00
0003nlbE0000LDR@009aB9001@0004/WPd/WPd/WP`000002Tf:F00@0003c`9Wc`9Wc`9T200000iQ/
WP040000]gfD]gfD]gfD1000009?E[X300000lVAV`040000QEB?QEB?00001HMCS0040000m/:Em/:E
m/:E0`0000=gBXl01@0008UFShUFS`000;f0T@0400000hA=Q`030000jjj?000000C/_:82000017A4
R0030000REB<REB<00>9E8`00`000;j1TP000004SFZV00D0002WMYbWMYbWMY`000000YmUS@030000
PD^7PD^700:1BhL200000oFhRP040000XfnF0000000019EKR0030000Lcn3Lcn300800006^G^?00L0
002GGH/0002`M900000h67d000001=jOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`03NTN700<0
001kBHUkBHT00g]9R@030000ReR?ReR?00:;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14
S@060000Ab^;Ab^;0000REN?000018UFS`050000S5fF0000NU2D000000F=G9<00`00091NTi1NT`03
T5jC0P0000:`M8l00`0007Y:RgY:R`02NTZ;00<0001bAHabAH`01795S0040000HCb>000000001G9:
T`050000HDRNHDRNHDRN000000BEIiX00`0009=RUI=RU@04Tf:E00<0002DHYBDHY@00YARU0040000
UF:CUF:CUF:C0P0000>DGi000`0008mJShmJS`03SeZ?00<0002=FHn=FHl00XeIS`030000T5b@T5b@
00800006]86M0P0000??^<<200001=2QY`030000`9N]`9N]00;0Ujd00`000;1iV;1iV003/7VH00D0
001S@YES@YES@YD000001:S0j`<00005WH6d00<0003oooooool05?ooo`030000oooooooo01Goool0
01Soool300002Oooo`040000[Xnf[Xnf[Xnf0`0000?S/Z<3000000CS/Z<0000006L006L200000^bm
X`090000h[6Th[6Th[6T0000l<2N0000F3VB000000;kc9D3000000?kc9D0001aB9000W58T0030000
BbN3BbN300800002Tf:F00@0003c`9Wc`9Wc`9T200000iQ/WP040000]gfD]gfD]gfD1@000004CeJj
0000000000000/VAV`050000QEB?QEB?QEB?000000F7Dh`01@000?K2UOK2U@000>oHI`0200000gM:
S`030000REJ?000000800003_H2A00@00024CHN4CHN4CHL300001>blXP800004M4B800<00029E8b9
E8`00hUDS0<00004SFZV00@0002WMYbWMY`00003WfF=00<00021BhN1BhL00X5;Q`030000mKR:mKR:
00;e^8X010000:=_UP00000000BEFhP3000000?][hd0002iNhl01KUkS`030000Uef;000000800000
0cPHO@000=jOT@03gYnA00<0002BFX^BFX/00Y9JR`030000NTN7NTN700=jAhL00`0007]9RG]9R@03
NdV90P0000>;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00g14S@050000Ab^;0000REN?0000
00B9EXl00`0008aMUP000002NU2D00<0002=G9>=G9<00XeLT`030000T5jCT5jC00:@GY<200000k1d
S`030000NTZ;NTZ;009jBX/00`000795S795S004LTF<00@0001Q?8h000000005LTZC00D0001QB9iQ
B9iQB9h000001IEWVP030000Tf:ETf:E00>CHYD00`0009ARU9ARU002U6:D00@0002EHY<000000006
U5n@00<0002?FXn?FXl00XmJS`030000SEV?SEV?00>=FHl01000091LT000000000JdPId200000lnh
``030000d:6W000000?@XJL00`000<2G[L2G[@02`9N]00<0002`NIR`NIP00k1iV0050000Hd:EHd:E
Hd:E000000:X`>/2000000>GKj<0002MPK@01Yf1]0030000oooooooo01Coool00`000?ooooooo`0D
oooo000Hoooo00<0003oooooool02Oooo`060000[Xnf00000000oooo00001>>bX`800002hk:S0`00
00C/_J<010000>:aY>:aY00000;``9h200000o_<U@<000000o_<U@000758T002LDR@00@0001;9h=;
9h<00003Tf:F00@0003c`9Wc`9Wc`9T2000019Q/WP040000]gfD]gfD]gfD1000009?E[X01@000<VA
VlVAVlVAV`000003QEB?00<00027Dhb7Dh`00hMCS0050000m/:Em/:E0000kmQW00800003MdZ?0P00
0003REJ?0000_H2A00>mP940100008A=QhA=QhA=Q`8000000`00L00000000004000017A4R0030000
REB<REB<00>9E8`3000018eZYP030000YgJL000000BOIHd00`00085;Qh5;Q`02PD^700<0003e^8[e
^8X00_FhRP040000XfnFXfnF00000YEKR0<00003kJn=00<0002iNhniNhl01;UkS`030000Uef;0000
008000000cPHO@000=jOT@03gYnA00<0002BFX^BFX/00Y9JR`030000NTN7NTN700=jAhL00`0007]9
RG]9R@03NdV90P0000>;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00g14S@050000Ab^;0000
REN?000000B9EXl01P0008aMUXaMUP0007Y@U00000B=G9<00`00091NT`00000300001;1dS`030000
NTZ;NTZ;009jBX/00`000795S795S004LTF<0P000003Ndf?0000LTZC00AbBY<01@000658WV58WP00
05HgT00200000iEWVP030000Tf:ETf:E00>CHYD0100009ARU9ARU9ARU0<000000ieVT@0009AOT005
U5n@00<0002?FXn?FXl00XmJS`030000SEV?SEV?00>=FHl2000000>BII/0002dPId01KB1W@030000
ckS3ckS300??^<<200000]2QY`030000`9N]`9N]00;0Ujd200001K1iV0030000Hd:EHd:E009S@YD2
000019M_X`030000WH6dWH6d00>MPK@300005Oooo`030000oooooooo01Coool001Soool00`000?oo
ooooo`09oooo0P0000?oool00`000>>bXn>bX`02hk:S00@0003S/Z?S/Z?S/Z<200001NbmX`040000
h[6Th[6T00000_30WP800002nlbE10000003nlbE0000LDR@009aB900100004/WPd/WP`0000:CHYH0
0`000??0VO?0V@02ll2I0P0000BHK9h010000;MmU;MmU;MmU0@00002CeJj00D00039TI_9TI_9TI/0
00000XEDS`030000Qe><Qe><00>7Dh`010000?K2UOK2UOK2U@8000000ljDV@000000000300000XUF
S`030000_H2A_H2A00:mP9400`0008A=QhA=Q`02000000=[>hD0000007000P000003j=5J00000000
00AdA8P00`0008UDS8UDS003REB<1@0000:=JZH3000019mUS@030000PD^7PD^700:1BhL010000?Fh
R_FhR_FhRP800002XfnF0`000003cHf@0000kJn=00?][hd00`000;UkSkUkS`04^G^?00<0002GGH/0
00000P000003>1Qm0000gYnA00?NWi400`00099JRi9JR`02TUZ;00<0001jAhMjAhL00gY7Q`030000
NdV9NdV9009kBHT300000h]HS`030000Odj=Odj=009oCXd00`000714SG14S@03L4B=0P0000:9Ehl0
0`0008UFShUFS`02REJ?00@0002<GIJ<GIJ<GIH200000heLT`<00003^7nE00<0002`M8n`M8l00[1d
S`030000NTZ;NTZ;009jBX/00`000795S795S004LTF<0P00009kCHl00`00079:Tg9:T`02LTZC00P0
001QB9iQB9h0001F=i00000Q6i000002UFNJ00<0002CHYFCHYD00i=RU@040000U6:D0000000019eV
T@030000U5n@U5n@00BDGi000`0008mJShmJS`02SeZ?00<0002=FHn=FHl00heIS`8000000i9UV`00
0;B1W@04]86M00<0003?^<??^<<01<nh``030000d:6W000000800004`9N]00<0002ePYh000001;1i
V0030000Hd:EHd:E009S@YD00`0009M_XiM_X`03UfnS00<0002MPKBMPK@00if1]0<0000Foooo00<0
003oooooool04oooo`006?ooo`030000oooooooo00ooool00`000>>bXn>bX`04hk:S00<0003G`lH0
00001>bmX`050000h[6Th[6Th[6T000000;``9h4000000AL@IP00000001NEJl200000g58T0040000
BbN3BbN300000Y=RUP030000ll2Ill2I00;c`9T300000iQ/WP030000]gfD]gfD00H000000dmF^P00
0<VAV`02bI6K00@00025E8n5E8l00005Qe><00@0003f`YGf`YGf`YD400000gM:S`040000REJ?REJ?
00001;f0T@040000Q4f7Q4f700000V/kQ@8000000i=YWP000>SAFP02000017A4R0030000REB<REB<
00>9E8`200000l:5T`D00004WfF=00L00021BhN1BhN1BhL0003VbKT000000_FhRP030000XfnFXfnF
00:SKiH010000<f=T<f=T00000C][hd00`000;UkSkUkS`04^G^?0P000004/7B@00000000>1Qm0P00
00?NWi400`00099JRi9JR`02TUZ;00<0001jAhMjAhL00gY7Q`030000NdV9NdV9009kBHT3000018]H
S`030000Odj=Odj=009oCXd00`000714SG14S@02L4B=0P0000:9Ehl00`0008UFShUFS`03REJ?00<0
002<GIJ<GIH00P000004SEbC0000000000001KQoU@030000/7B?/7B?00:`M8l00`0007Y:RgY:R`03
NTZ;00<0001bAHabAH`00g95S0050000Ndf?Ndf?Ndf?000000EbBY<200000UHgT00300008A^@0000
00<00003Tf:E10000003ZW>E0000WFJA00BMIY400`0009AOT9AOT003U5n@00<0002?FXn?FXl00XmJ
S`030000SEV?SEV?00>=FHl01000099UVi9UV`0000FdPId00`000<nh`lnh``04ckS300<0003@XJL0
00000P0000?0Ujd010000;F2W[F2WP0000F`NIP01@0006=2UF=2UF=2U@000005UfnS00<0002MPKBM
PK@00Yf1]0D0000Foooo00<0003oooooool04_ooo`005oooo`030000oooooooo013oool00`000>>b
Xn>bX`03hk:S00@0003G`lKG`lH00004k;fS00D0003R/JCR/JCR/J@000000_30WP800003G46H0P00
009NEJl01P000758T758T758T00004/WP`800002Tf:F00<0003c`9Wc`9T00o?0V@800003V6bN00<0
002gOIBgOI@01P000005CeJj0000bI6KbI6K000000>5E8l00`0008MCS8MCS003Qe><00<0003f`YD0
00000`000003cYBI0000MdZ?009gBXl0100008UFShUFS`0000BmP9400`0008A=Q`000003Jc^50P00
0003TfVN0000j=5J00800004M4B800<00029E8b9E8`00hUDS0800005`XFC0`0000BOIHd01@00085;
Qh5;Qh5;Q`000002i/Vi0`0000BSKiH010000<f=T<f=T00000C][hd00`000;UkSkUkS`04^G^?0P00
0003/7B@00000000008h67d01@000=jOTMjOTMjOT@000004TUZ;00<0001jAhMjAhL00gY7Q`030000
NdV9NdV9009kBHT3000018]HS`030000Odj=Odj=009oCXd00`000714SG14S@02L4B=00D00029Ehn9
Ehn9Ehl000001HUFS`030000S5fFS5fF00<00002k/U@00<0002hOiFhOiD00kQoU@030000/7B?/7B?
00>`M8l00`0007Y:RgY:R`02NTZ;00<0001bAHabAH`00W95S0030000Ndf?Ndf?009kCHl00`00079:
Tg9:T`03LTZC0P00009F=i001@00024KT24KT0000<bJX`0500001JYcU@030000WFJAWFJA00:MIY40
0`0009AOT9AOT003U5n@00<0002?FXn?FXl00XmJS`030000SEV?SEV?00>=FHl01@00099UVi9UVi9U
V`000004]86M0P0000K?^<<2000000?1V:h0000000000/2G[@040000]H:N]H:N00001K1iV0030000
Hd:EHd:E009S@YD00`0009M_XiM_X`03UfnS00@0002MPKBMPKBMPK@500005_ooo`030000oooooooo
01;oool001Ooool300004Oooo`050000hk:Shk:Shk:S000000;G`lH00`000>bmXnbmX`02k;fS00D0
003R/JCR/JCR/J@000000o30WP800003G46H0P0000=NEJl01P000758T758T00004/WP`0000>CHYH0
0`000??0VO?0V@03ll2I0P0000>HK9h01@000;MmU;MmU0000?_MOP02000000C>adH0001?E[X00002
bI6K00D00025E8n5E8n5E8l0000018MCS0<000001_K2U@000>oHI`000<jDV@0000=gBXl0100008UF
ShUFS`0000BmP9400`0008A=Q`000003Jc^50`000004j=5J00000000000017A4R0030000REB<REB<
00>9E8`200001L:5T`030000VV6=000000BOIHd01000085;Qh5;Q`0000GVbKT00`000:=_UZ=_UP02
XfnF00<0003=SI0000001Nf_S@030000^G^?^G^?00BiNhl2000000>`M900000000000SPHO@050000
gYnAgYnAgYnA000000BBFX/00`0007Y7QgY7Q`03NTN700<0001kBHUkBHT00W]9R@030000dIRH0000
00B;F8l00`0007m>SGm>S@02Odj=00<0001`A8e`A8d00W14S@050000REN?REN?REN?000000F9EXl0
100008aMUXaMUP0000C^bE000`000;QoUKQoU@03^7nE00<0002`M8n`M8l00k1dS`030000NTZ;NTZ;
009jBX/010000795S795S795S0800004Ndf?00<0001bBY=bBY<00g9:T`050000ESN@ESN@ESN@0000
008Q6i000`000<bJXlbJX`03c9ZS00<0002ZLiFZLiD00jYcU@030000WFJAWFJA00:MIY400`0009AO
T9AOT003U5n@00<0002?FXn?FXl00XmJS`030000SEV?SEV?00:=FHl00`00099UVi9UV`02TVFK00<0
002dPIfdPId00[B1W@800005ckS30P0000;1V:h200000/2G[@040000]H:N]H:N00001K1iV0030000
Hd:EHd:E009S@YD00`0009M_XiM_X`03UfnS00<0002MPKBMPK@00`0000>X`>/00`000?ooooooo`0D
oooo00<0003oooooool04Oooo`005oooo`030000oooooooo017oool010000>>bXn>bX`0000?G`lH0
0`000>bmXnbmX`02k;fS00D0003R/JCR/JCR/J@000001?30WP040000G46HG46HG46H0P0000=NEJl0
1P000758T758T00004/WP`0000:CHYH00`000??0VO?0V@04ll2I0P0000>HK9h01@000;MmU;MmU000
0?_MOP0200000/k7AP800002bI6K00H00025E8n5E8n5E8l00027Dh`400000oK2U@800002cYBI00D0
001gBXmgBXmgBXl000000XUFS`030000_H2A_H2A00:mP9400`0008A=Q`000003Jc^500@0002CJIh0
003XdEX3000017A4R0030000REB<REB<00>9E8`200001L:5T`030000VV6=000000BOIHd01000085;
Qh5;Q`0000CVbKT00`000:=_UZ=_UP03XfnF00<0003=SI0000001Nf_S@030000^G^?^G^?00BiNhl3
000000F?FHd0000h67dh67d000000mjOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`03NTN700<0
001kBHUkBHT00W]9R@030000dIRH000000B;F8l00`0007m>SGm>S@02Odj=00D0001`A8e`A8e`A8d0
000018UGS`030000REJ?REJ?00>9EXl0100008aMUXaMUP0000C^bE000`000;QoUKQoU@03^7nE00<0
002`M8n`M8l00k1dS`030000NTZ;NTZ;009jBX/01P000795S795S00007Q:S@0000AkCHl00`00079:
Tg9:T`03LTZC00<0001F=i1F=i000UHgT00400008A^@8A^@00001<bJX`030000ZW>EZW>E00>ZLiD0
0`0009eVTIeVT@02WFJA00<0002DGi2DGi000iAOT0030000SeZ?SeZ?00:?FXl00`0008eISheIS`02
SEV?00<0002BII^BII/00Y9UV`050000]86M]86M]86M000000:UY]L00`000<nh``00000300001<6H
[P030000`9N]000000>ePYh00`000;1iV;1iV003/7VH00<0001S@YES@YD00V=2U@030000UfnSUfnS
00>GKj<00`0009f1]9f1]00200001:S0j`030000oooooooo01?oool300004_ooo`005oooo`030000
oooooooo01;oool200000mO3aP030000k;fSk;fS00?/_J<01@000>:aY>:aY>:aY0000004l<2N00<0
001L@IQL@IP00Ua1V080000025iE[`000?kNTP000758T00004/WP`0000:CHYH00`000??0VO?0V@03
ll2I0`0000>HK9h01`000;MmU0000?_MOP000:EaV0000002c/M60P000003bI6K0000000000:5E8l3
00000hMCS0040000m/:Em/:Em/:E0P0000;>U9T01@0007M:SgM:SgM:S`000002REJ?00<0002mP96m
P9400[f0T@800004Jc^500<0002CJIh00000100000AdA8P00`0008UDS8UDS003REB<0P0000G2QI<0
0`0009YQS@000004WfF=00<00021BhL000001NK9^@800005XfnF0P0000G][hd00`000;UkSkUkS`04
^G^?0`000005SeV=0000>1Qm>1Qm000000?NWi400`00099JRi9JR`02TUZ;00<0001jAhMjAhL00gY7
Q`030000NdV9NdV9009kBHT00`000=6HV0000004ReR?00<0001oCXeoCXd00Wm>S@030000L4B=L4B=
00800004REN?00<00029EXn9EXl00hUFS`030000S5fFS5fF00800004k/U@00<0002hOiFhOiD00[Qo
U@030000/7B?/7B?00>`M8l00`0007Y:RgY:R`02NTZ;00H0001bAHabAH`0001hBXd00004Ndf?00<0
001bBY=bBY<00W9:T`D000001EHgT000024KT24KT0000004c9ZS00<0002ZLiFZLiD00jYcU@030000
WFJAWFJA00:MIY400`0009AOT9AOT003U5n@00<0002?FXn?FXl00hmJS`040000SEV?SEV?00001I9U
V`060000]86M]86M]86M0000YJKG0`0000>GJI/00`000<6H[/6H[P02`IR^0`0000BePYh00`000;1i
V;1iV002/7VH00<0001S@YES@YD00V=2U@030000UfnSUfnS00>GKj<01@0009f1]0000:S0j`000003
Z<3[0`0001Koool00`000?ooooooo`0@oooo000Goooo00<0003oooooool04_ooo`030000el?6el?6
00;G`lH00`000>bmXnbmX`02k;fS00D0003R/JCR/JCR/J@000001O30WP030000G46HG46H009L@IP2
000000ENEJl000000000001aB9000`0000:CHYH00`000??0VO?0V@03ll2I0`0000>HK9h01`000;Mm
U0000?_MOP000:EaV0000003c/M61P000003QEB?0000Qe><00>7Dh`01P000?K2UOK2U@000>oHI`00
00?>U9T01`0007M:SgM:S`0008UFS`000?CWQ`0200000[f0T@800004Jc^500<0002CJIh000001000
00AdA8P00`0008UDS8UDS003REB<0P0000G2QI<00`0009YQS@000004WfF=00<00021BhL000001>K9
^@030000SV6H000000FSKiH200001Nf_S@030000^G^?^G^?00BiNhl01@000;1dT00008mIS@000002
>1Qm00D0003NWi7NWi7NWi400000199JR`030000NTN7NTN700=jAhL0100007]9RG]9RG]9R@800000
0m6HV00000000003ReR?00<0001oCXeoCXd00Wm>S@050000L4B=0000QeB>000000B9Ehl00`0008UF
ShUFS`03REJ?00@0002<GIH0003^bE0200000nk9D0030000^7nE^7nE00:hOiD00`000;1dSk1dS`03
/7B?00<0001jBX]jBX/00WY:R`030000LTF<0000009hBXd00`0007]=Sg]=S`02Ndf?00<0001bBY=b
BY<00W9:T`<00002UF>D1P0000?<VZ<00`000:YcUJYcU@03ZW>E00<0002MIY6MIY400YeVT@030000
U5n@U5n@00>DGi000`0008mJShmJS`03SeZ?00@0002=FHl000000006TVFK00<0002dPIfdPId00P00
00:DIIT0100009MYViMYV`0000K1V:h200001;F2WP030000/7VH/7VH00:`NIP00`0006=2UF=2U@03
Hd:E00<0002GKj>GKj<00iM_X`8000000jS0j`000000000200000iYh[0030000oooooooo01Coool0
0`000?ooooooo`0?oooo000Goooo00<0003oool000004oooo`050000el?6el?6el?6000000C/_J<0
1@000>:aY>:aY>:aY0000005l<2N00<0001L@IQL@IP00Ua1V08000001EiE[`00000000000758T003
00000Y=RUP030000ll2Ill2I00;c`9T01@000>K[QP00099[XP000002V6bN00D0002gOI@00000002U
LIP010000003c/M60000000000800003QEB?00D00027Dhb7Dhb7Dh`000000oK2U@030000kmQW0000
00?>U9T01@0007M:SgM:S`0008UFS`0200000]nTU0<00004Jc^500<0002CJIjCJIh01@0000AdA8P0
0`0008UDS8UDS003REB<0P0000G2QI<0100009YQS@00000000>OIHd200001NK9^@030000SV6H0000
00FSKiH200001Nf_S@030000^G^?^G^?00BiNhl01@000;1dT00008mIS@000002>1Qm00D0003NWi7N
Wi7NWi400000199JR`030000NTN7NTN700=jAhL0100007]9RG]9RG]9R@8000000m6HV00000000002
000000>;F8l0001oCXd00gm>S@800002QeB>00<00029Ehn9Ehl00XUGS`030000REJ?REJ?00>9EXl0
1@0008aMUP0000000713R`03000000?^bE00002hOiD01;QoU@030000/7B?/7B?00:`M8l00`0007Y:
RgY:R`02NTZ;0P0000=hBXd00`0007]=Sg]=S`02Ndf?00@0001bBY=bBY=bBY<4000019ESU0030000
S5bDS5bD00800002c9ZS00<0002ZLiFZLiD00jYcU@030000WFJAWFJA00:MIY400`0009AOT9AOT003
U5n@00<0002?FXn?FXl00hmJS`8000000i9UVP00099UV`05TVFK00@0002dPIfdPId00003U6FI00@0
002GJI^GJI/00006`IR^0P0000BePYh00`000;1iV;1iV002/7VH00<0001S@YES@YD00f=2U@030000
UfnSUfnS00>GKj<3000000>FK9l0002JN:`019Yh[0030000oooo000001Goool00`000?ooooooo`0>
oooo000Foooo0`0001Goool300001NbmX`050000h[6Th[6Th[6T000000G``9h200000Ua1V0<00000
0eiE[`0000000005000000>CHYH0003c`9T01??0V@030000i^^6i^^600800002V6bN00D0002gOI@0
0000002ULIP00P000003MTnF0000000000@00003QEB?00D00027Dhb7Dhb7Dh`000000oK2U@800005
cYBI00@0001gBXl00029EXl200000mnTU0800004Jc^500D0002CJIh00000002HHi800`0000AdA8P0
0`0008UDS8UDS003REB<0P0000G2QI<00`0009YQSIYQS@03000000>OIHd0000000001>K9^@040000
SV6HSV6H00001J=_UP800006kJn=00<0002iNhniNhl00kUkS`050000/7B@0000SeV=000000<h67d0
10000=jOTMjOT@0000BBFX/00`0007Y7QgY7Q`03NTN700@0001kBHUkBHUkBHT2000000?AV9P00000
00000XmMTP800002Odj=0`0000>7E8h00`0008UGShUGS`02REN?00<00029EXn9EXl00hUFS`060000
S5fF00000000L4>;00000V<kR`800005^7nE00<0002`M8n`M8l00[1dS`040000NTZ;NTZ;NTZ;0P00
00AhBXd00`0007]=Sg]=S`03Ndf?00<0001bBY<00000100000BEHi@01@0008aLU8aLU8aLU0000002
c9ZS00<0002ZLiFZLiD00jYcU@030000WFJAWFJA00:MIY400`0009AOT9AOT004U5n@00<0002?FXn?
FXl00XmJS`8000000i9UVP00099UV`05TVFK00<0002dPId0000019AUV@040000UfVKUfVK00001L6H
[P8000000kF2WP000;F2WP02]H:N00<0002`NIR`NIP00k1iV0030000Hd:EHd:E009S@YD00`0009M_
XiM_X`03UfnS00D0002FK9nFK9nFK9l000001YYh[080000Eoooo00<0003oooooool03_ooo`005_oo
o`030000oooooooo01Ooool00`000>bmXnbmX`02k;fS00D0003R/JCR/JCR/J@000001O30WP060000
i;Z/0000G46H0000^Ifl10000003oN6@0000000000<000000i=RUP000??0V@03ll2I00P0003VjhKV
jhKVjhH0002BJj80002HK9h300000ZEaV0<00003MTnF00<0001fCiH000000hEDS`050000Qe><Qe><
Qe><000000?f`YD200001LjDV@030000MdZ?000000800004gjBD00<0001[>hE[>hD00f/kQ@040000
TfVN000000000YQSTP800004M4B800<00029E8b9E8`00XUDS0030000ReZB000000G2QI<01P0009YQ
SIYQSIYQS@0000efhP800004i/Vi00D0002>HIR>HIR>HIP000001J=_UP030000kJn=kJn=00G][hd0
0`000;UkSkUkS`02^G^?00H0002`M92`M900002?FHd00003>1Qm00@0003NWi7NWi400005TUZ;00<0
001jAhMjAhL00WY7Q`040000NdV9NdV9NdV90P000003dIRH0000000000:?GI84000000=hCI400027
E8h00hMDSP030000REN?REN?00:9Ehl00`0008UFShUFS`03REJ?00H0002<GIH00000001`@h/00003
Hc^;00<0002hOiFhOiD00kQoU@030000/7B?/7B?00:`M8l01P0007Y:R`00000009YST00000AhBXd0
0`0007]=Sg]=S`03Ndf?00<0001bBY<000000P0000:PK9H01@0009ESU9ESU9ESU0000004S5bD00<0
003<VZ<000001JYcU@030000WFJAWFJA00:MIY400`0009AOT9AOT004U5n@00<0002?FXn?FXl00XmJ
S`050000TVFJTVFJTVFJ000000FBII/00`000;B1W@000004U6FI00@0002GJI/000000005`IR^0P00
00:ePYh010000;F2W[F2WP0000F`NIP00`0006=2UF=2U@02Hd:E00<0002GKj>GKj<00YM_X`030000
UVbOUVbO00>FK9l00`0009Yh[9Yh[003VWR/0`0001Goool00`000?ooooooo`0=oooo0005oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool06?oo
o`050000k;fSk;fSk;fS000000?R/J@00`000?30W_30WP03l<2N00<0003T^Z`000000P0000:iWK`2
00000_gQT00700003bn^0000o]jB0000Tf:F000000Cc`9T200000^K[QP040000TV^R0000V6bN1`00
00AfCiH300000hEDS`050000Qe><Qe><Qe><000000;f`YD00`000>oHI`000006cYBI100000COY9@0
0`0006/kQF/kQ@02Jc^500<0002CJIjCJIh00P0000:HHi82000017A4R0030000REB<REB<00:9E8`0
0`0008]JTP000005`XFC00<0002JHHfJHHd00YYQS@0400003GKR3GKR00000nK9^@050000SV6HSV6H
SV6H000000FSKiH00`000>f_SNf_S@05kJn=00<0002iNhniNhl00[UkS`030000/7B@000000:?FHd0
1@0003PHOCPHOCPHO@000002gYnA00<0002BFX^BFX/00i9JR`030000NTN7NTN7009jAhL0100007]9
RG]9RG]9R@8000000m6HV00000000002SefB0P0000AhCI401@0008MDSXMDSXMDSP000005REN?00<0
0029EXn9EXl00XUFS`060000S5fF00000000L4>;00000f<kR`<00003^7nE00@0002`M8n`M8n`M8l3
00000iYST0030000N4Z=N4Z=009hBXd00`0007]=Sg]=S`03Ndf?0P000003_9B_0000000000:PK9H0
1@0009ESU9ESU9ESU0000004S5bD0P000003c9ZS0000ZW>E00>ZLiD00`0009eVTIeVT@03WFJA00<0
002DGi2DGi000iAOT0030000SeZ?SeZ?00800004TVFJ00<0002BII^BII/00i9UV`030000]86M0000
00FDIIT2000000?A/k`00031V:h00/6H[P060000/hNW/hNW0000]H:N00000kF2WP030000/7VH/7VH
00:`NIP00`0006=2UF=2U@03Hd:E00D0002GKj>GKj>GKj<000001II/W`030000VWR/VWR/00:JN:`0
100000006000000001Koool00`000?ooooooo`0<oooo0004oooo00<0003oool000001oooo`030000
oooo000000Goool00`000?ooooooo`0Ioooo0`0000CR/J@00`000?30W_30WP02l<2N00<0003T^ZcT
^Z`00P000003i;Z/0000000000800002oN6@0`000004o]jB0000Tf:F00000o?0V@<00002i^^600<0
002BJj:BJj800`0000:ULIP300001GI?UP800003QEB?00@00027Dhb7Dh`00003m/:E0`0000G>U9T4
00001MnTU0030000Jc^5Jc^5009[>hD0100009=YWY=YWP0000>HHi82000017A4R0030000REB<REB<
00:9E8`00`0008]JTP000005`XFC00<0002JHHfJHHd00iYQS@80000010efhP000>K9^@0000B>HIP0
0`000:=_UZ=_UP03XfnF00<0003][hg][hd01Nf_S@050000^G^?^G^?^G^?000000:`M900100008mI
SHmIS@0000<h67d010000=jOTMjOT@0000FBFX/00`0007Y7QgY7Q`02NTN700@0001kBHUkBHUkBHT2
000000?AV9P0000000000hmMTP030000N4fAN4fA009hCI400`0008MDSXMDSP02QeB>00<00029Ehn9
Ehl00XUGS`030000REJ?REJ?00>9EXl200000W13R`040000Hc^;Hc^;Hc^;0P000006a8bJ00000000
^7nE0000/7B?0`0000FJHi000`0007Q:SGQ:S@02N4Z=00<0001kCHmkCHl00g]=S`8000000kbD[`00
00000002X6bF00D0002EHiBEHiBEHi@000001HaLU0<00005ZW>E00<0002MIY6MIY400YeVT@030000
U5n@U5n@00>DGi0400001I9UVP030000TVFKTVFK00BBII/200001IAUV@040000dK>ldK>l00000/6H
[P050000/hNW/hNW/hNW000000:ePYh010000;F2W[F2WP0000B`NIP00`0006=2UF=2U@03Hd:E00H0
002GKj>GKj<0002?IIh00004UVbO00<0002JN:bJN:`00YYh[0@0000Foooo00<0003oooooool03?oo
o`001?ooo`030000oooo000000Woool00`000?ooooooo`03oooo00<0003oooooool06oooo`030000
h[6Th[6T00;R/J@00`000?30W_30WP02l<2N00@0003T^ZcT^Z`00002i;Z/00<0003Ua;H000001?gQ
T08000000okNTP0000000004ll2I10000003i^^60000000000@00002YG6H00@00011:8a1:8`00004
MTnF0P0000>5E8l0100008MCS8MCS00000?f`YD300001LjDV@030000V6VK000000800004gjBD00<0
001[>hE[>hD00V/kQ@040000TfVN000000000iQSTP800004M4B800D00029E8b9E8b9E8`000000X]J
TP030000`XFC`XFC00?2QI<00`0009YQSIYQS@03VV6=10000003i/Vi0000SV6H00>>HIP00`000:=_
UZ=_UP03XfnF00<0003][hg][hd01Nf_S@050000^G^?^G^?^G^?000000:`M900100008mISHmIS@00
00<h67d01@000=jOTMjOTMjOT@000004TUZ;00<0001jAhMjAhL00WY7Q`040000NdV9NdV900000/jB
U0<00003SefB00<0001hCI5hCI400WQ=T@030000QeB>QeB>00:7E8h00`0008UGShUGS`02REN?00<0
0029EXn9EXl00hUFS`800002L4>;00<0001S>h]S>h/00V<kR`040000a8bJa8bJa8bJ0`0000:MIi<0
0`0009YST9YST003VV>@00<0001hBXehBXd00WQ:S@030000Ndf?Ndf?00=kCHl010000;bD[kbD[`00
00>PK9H00`0009ESU9ESU002UF>D00<0002<G9B<G9@00XaLU0<00005ZW>E00<0002MIY6MIY400YeV
T@030000U5n@U5n@00:DGi0200000X]OV@030000TVFJTVFJ00>BIIX00`00099UVi9UV`04TVFK0P00
00FDIIT01P000=6c_=6c_0000<6H[P0000BcQjL01`000;F2W[F2W[F2WP000;F2WP000004/7VH00<0
001S@YES@YD00f=2U@060000UfnSUfnS0000SfFN000019I/W`030000VWR/VWR/00:JN:`01@000:S0
jjS0jjS0j`00000Eoooo0P0000goool000Coool00`000?ooo`000007oooo0P0000Koool200007Ooo
o`040000h[6Th[6T00001?30WP030000i;Z/i;Z/00?T^Z`010000>G4]^G4]P0000CmhI000`0000l_
[P00000200000o?0V@8000000bddY`000000000200000Y9[XP800003YG6H00@00011:8a1:8`00004
MTnF0P0000>5E8l0100008MCS8MCS00000?f`YD300001LjDV@050000V6VK000090el000000COY9@0
0`0006/kQF/kQ@02Jc^500@0002CJIh000000003V6>B0P0000AdA8P01@0008UDS8UDS8UDS0000002
ReZB00<00032QI?2QI<00l:5T`030000VV6=VV6=00>JHHd200000/>7U0800004SV6H00<0002SKiJS
KiH00Z=_UP800007kJn=00<0002iNhniNhl00P0000:`M900100008mISHmIS@0000<h67d200000]jO
T@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`02NTN700@0001kBHUkBHT00002cY:D0P0000B?GI80
0`0007Q=TGQ=T@02N4fA00<00027E8j7E8h00XMDSP030000REN?REN?00:9Ehl00`0008UFShUFS`03
REJ?0P00009`@h/00`0006<kRf<kR`02Hc^;00D00034S9[4S9[4S9X0000019eWT`030000VV>@VV>@
00>JHi000`0007Q:SGQ:S@02N4Z=00<0001kCHmkCHl00W]=S`050000_9B__9B__9B_000000>PK9H0
0`0009ESU9ESU002UF>D00<0002<G9B<G9@00XaLU0@00004ZW>E00<0002MIY6MIY400YeVT@030000
U5n@000000800004RenI00<0002BIIZBIIX00i9UVP030000TVFKTVFK00BBII/2000019AUV@030000
dK>ldK>l00;A/k`200001;>7Y`030000]H:N]H:N00:ePYh200001;1iV0030000Hd:EHd:E00=S@YD0
0`0009M_X`000002SfFN00<0002FK9nFK9l00iI/W`040000VWR/VWR/00001:S0j`030000oooooooo
013oool3000000?oool0003oool03?ooo`001?ooo`030000oooo000000Ooool00`000?ooooooo`05
oooo00<0003oooooool07?ooo`040000h[6Th[6T00001?30WP030000i;Z/i;Z/00?T^Z`00`000>G4
]P000005oN6@1@0000?c`9T3000000@]=:L0000000000002TV^R0P0000:ULIP200000T4XS0050000
MTnFMTnFMTnF000000;jfWL01P0008EDShEDS`0008MCS00000?f`YD200000WIQ[P030000cYBIcYBI
00;>U9T01@0009QYV`0002@=O0000004gjBD00H0001[>hE[>hE[>hD0002iPYP2000019QSTP800004
M4B800D00029E8b9E8b9E8`000000X]JTP030000`XFC`XFC00?2QI<00`0009YQSIYQS@03VV6=0P00
00?3Qi@00`0008iQV8iQV002SV6H00<0002SKiJSKiH00Z=_UP<00006kJn=00<0002iNhniNhl00P00
00:`M900100008mISHmIS@0000<h67d200000]jOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`02
NTN700@0001kBHUkBHT00002cY:D0P0000B?GI800`0007Q=TGQ=T@02N4fA00<00027E8j7E8h00XMD
SP030000REN?REN?00:9Ehl00`0008UFShUFS`03REJ?0P00009`@h/00`0006<kRf<kR`02Hc^;0P00
00?4S9X01@0009eWTieWTieWT`000005VV>@00<0001hBXehBXd00gQ:S@040000Ndf?Ndf?Ndf?0P00
00:lU:l01@000:1/UZ1/UZ1/UP000004UF>D00<0002<G9B<G9@00XaLU0800002Md^@0`000004ZW>E
0000WFJAWFJA1000009dC9<00`0008]OVH]OV@03RenI00<0002BIIZBIIX00i9UVP030000TVFKTVFK
00:BII/00`0009=TV@000003U6FI00<0003A/kcA/k`00]6c_0800005/hNW00<0002ePYjePYh00[F2
WP800004/7VH00<0001S@YES@YD016=2U@800002SfFN00<0002FK9nFK9l00iI/W`040000VWR/VWR/
00000jS0j`<0000=oooo100000Coool00`000?ooooooo`0;oooo0005oooo00<0003oooooool01_oo
o`<00004oooo00<0003oooooool07_ooo`030000h[6T000000?``9h00`000>Bj[>Bj[003i;Z/00@0
003Ua;KUa;H00004oN6@30000004;CBW0000000000000i9[XP030000YG6HYG6H00800002@BR<00D0
001fCiIfCiIfCiH000000_[JM`060000QEB?QEB?0000Qe><00000oK2U@800002MV6^00D0003>U9W>
U9W>U9T000000YQYV`03000090el000000COY9@01P0006/kQF/kQF/kQ@000;V2V0800004V6>B0P00
00AdA8P0100008UDS8UDS00000>;FY800`000<:5Tl:5T`03`XFC00<0002JHHfJHHd00iYQS@800003
`hND00<0002>HIR>HIP00hiQV0050000XfnFXfnF0000<Q1f00800006kJn=00<0002iNhl000000ZE]
TP030000/7B@000000:?FHd0100003PHOCPHOCPHO@800002gYnA00<0002BFX^BFX/00Y9JR`030000
NTN7NTN700=jAhL00`0007]9R@000002cY:D0P0000B?GI800`0007Q=TGQ=T@02N4fA00<00027E8j7
E8h00XMDSP030000REN?REN?00:9Ehl00`0008UFShUFS`03REJ?00D0001`@h]`@h]`@h/0000016<k
R`030000DU2a000000;4S9X01@0009eWTieWTieWT`000006VV>@00<0001hBXehBXd00WQ:S@060000
Ndf?Ndf?0000TVBI00000[bD[`050000X6bFX6bFX6bF000000BEHi@00`0008aLU8aLU002S5bD00<0
001iCi<000000gM;T0H00005M4bC00<0002;GiV;GiT00h]OV@030000TVFJTVFJ00>BIIX00`00099U
Vi9UV`02TVFK00D0002CI9VCI9T0002DIIT00P0000;A/k`2000000>UQK80002cQjL01;>7Y`030000
]H:N]H:N00>ePYh00`000;1iV;1iV003/7VH00<0001S@YES@YD00f=2U@050000SfFNSfFNSfFN0000
00FFK9l0100009Yh[0000::A``<00003Z<3[00<0003oooooool01oooo`<00008oooo00<0003ooooo
ool02oooo`005Oooo`030000oooooooo01koool200001?30WP030000i;Z/i;Z/00?T^Z`01@000>G4
]^G4]P000?gQT003000000BFM:X00000002LNJ/200000_?0V@8000000o_VY@0002ddY`02000000GV
jhH0002BJj:BJj8000000ZEaV0800002@BR<00H0001fCiIfCiIfCiH0003jfWL200000XEDS`030000
Qe><000000?f`YD200000WIQ[P050000cYBIcYBIcYBI000000:HJI/0100002@=O2@=O00000?OY9@0
1P0006/kQF/kQF/kQ@000;V2V0800004V6>B0P0000AdA8P00`0008UDS8UDS00200000X]JTP030000
`XFC`XFC00?2QI<00`0009YQSIYQS@03VV6=0P0000?3Qi@00`0008iQV8iQV003SV6H00<0002SKiH0
00000S8@MP800006kJn=00<0002iNhl000000ZE]TP800003SeV=00<0000h67dh67d00`0000;NWi40
0`00099JRi9JR`02TUZ;00<0001jAhMjAhL00gY7Q`030000NdV9000000;>TY@200001HmMTP050000
N4fAN4fAN4fA000000B7E8h00`0008UGShUGS`02REN?00<00029EXn9EXl00hUFS`030000L4>;L4>;
009`@h/00`0006<kRf<kR`02Hc^;00D0001BD;400034S9X0000019eWT`030000VV>@VV>@00>JHi00
0`0007Q:SGQ:S@02N4Z=00<0001kCHl000000Y9TV@040000_9B__9B_00000j1/UP030000UF>DUF>D
00:EHi@00`0008aLU8aLU002S5bD00<0001iCi<000000gM;T0030000LDN@LDN@00=aAi000`0007A<
TgA<T`02M4bC00<0002;GiV;GiT00h]OV@030000TVFJTVFJ00>BIIX01@00099UVi9UVi9UV`000003
TfBI0P000004gN;I0000000000000jF5/P030000/hNW/hNW00BcQjL00`000;F2W[F2WP03]H:N00<0
002`NIR`NIP00[1iV0030000Hd:EHd:E009S@YD2000018mUWP030000UVbOUVbO00:FK9l01P0009Yh
[00000000;cf[@0000BX`>/00`000?ooooooo`04oooo0`0000coool00`000?ooooooo`0:oooo000E
oooo00<0003oooooool07oooo`800002l<2N00<0003T^ZcT^Z`00nBj[0050000iLBfiLBf0000oN6@
00800003UWBZ200000?kiZD2000000<00800000000000Y9[XP030000YG6HYG6H00800002@BR<00d0
001fCiIfCiIfCiH0003jfWL0002>HYT00025E8l00027Dh`000000oK2U@050000MV6^MV6^MV6^0000
00?>U9T0100009QYViQYV`00008T3G`01@000=nTU=nTU=nTU0000002Jc^500@0002iPYRiPYP00005
V6>B0P0000AdA8P00`0008UDS8UDS00200000X]JTP030000`XFC`XFC00?2QI<00`0009YQSIYQS@03
VV6=00<00033QiC3Qi@00/>7U0030000SV6HSV6H00>>HIP20000138@MP800005kJn=0P0000>UKI82
00000hmIS@060000>1Qm>1Qm0000/7bJ00000]jOT@030000TUZ;TUZ;00:BFX/00`0007Y7QgY7Q`03
NTN700L0001kBHT0003>TY@0003`beH000001HmMTP050000N4fAN4fAN4fA000000B7E8h00`0008UG
ShUGS`02REN?00<00029EXn9EXl00hUFS`030000L4>;L4>;009`@h/00`0006<kRf<kR`02Hc^;00<0
001BD;4000000P0000BMIi<00`0009YST9YST003VV>@00<0001hBXehBXd00WQ:S@800004TVBI0`00
00>PK9H00`0009ESU9ESU002UF>D00<0002<G9B<G9@00XaLU0040000NDnCNDnC00000WM;T0030000
LDN@LDN@00=aAi000`0007A<TgA<T`03M4bC00<0002;GiV;GiT00X]OV@030000TVFJTVFJ00>BIIX0
1000099UVi9UV`0000>CI9T4000000>>i?`0002UQK801:F5/P030000/hNW/hNW00>cQjL00`000;F2
W[F2WP03]H:N00<0002`NIR`NIP00[1iV0030000Hd:E000000<00005SfFN00<0002FK9nFK9l00iI/
W`800002_?J]00@0002X`>^X`>^X`>/3000000?oool0000000000P0000ooool00`000?ooooooo`0:
oooo000Eoooo0P0002;oool300001>Bj[0060000iLBfiLBfiLBf0000oN6@1@000003UWBZ00000000
00BLNJ/00`000?_VYO_VY@03000000<00800000000000Y9[XP030000YG6H000000800002@BR<00@0
001fCiIfCiIfCiH3000000>>HYT00025E8l00P0000?f`YD300000WIQ[P040000cYBIcYBI000019QY
V`03000090el000000?OY9@0100006/kQF/kQ@0000:iPYP00`0009QSTYQSTP03V6>B0P0000AdA8P0
1@0008UDS00006DoS`000002ReZB00<00032QI?2QI<00l:5T`030000VV6=VV6=00>JHHd00`000<>7
U<>7U002`hND0`0000>>HIP20000138@MP800005kJn=0P0000>UKI82000018mIS@040000>1Qm0000
/7bJ0P000003gYnA0000TUZ;00>BFX/00`0007Y7QgY7Q`03NTN70P0000;>TY@00`000?3;EP000004
SefB0P0000=hCI400`0008MDSXMDSP02QeB>00<00029Ehn9Ehl00XUGS`030000REJ?REJ?00:9EXl2
00001713R`030000Hc^;Hc^;009S>h/01@00059@/@000=2BT@000004WFNC00<0002JHi2JHi000iYS
T0030000N4Z=N4Z=009hBXd20000199TV@<00003X6bF00<0002EHiBEHi@00YESU0030000S5bDS5bD
00:<G9@01`0007U?TgU?TgU?T`0007M;T0000005LDN@00<0001dC9=dC9<00gA<T`030000RenIRenI
00:;GiT00`00099UVY9UVP03TVFJ00<0002BII^BII/01@0000F>i?`00`000:F5/ZF5/P02YHFb00<0
002cQjNcQjL00k>7Y`030000]H:N]H:N00>ePYh200000k1iV0800003Xg:L00<0002?IIj?IIh00hmU
WP030000UVbOUVbO00>FK9l010000;cf[Kcf[Kcf[@@00003Z<3[00<0003oooooool04Oooo`030000
oooooooo00[oool001Goool00`000?ooooooo`0Toooo00D0003T^ZcT^ZcT^Z`000000nG4]P@00004
UWBZ0P0000>LNJ/010000?_VYO_VYO_VY@<00002002000P0002BJj:BJj80002ULIP0001F>I<00002
@BR<00D0001fCiIfCiH0003jfWL00P0000:>HYT300000oK2U@<00002MV6^00@0003>U9W>U9T00004
V6VK00<0000T3G`000000mnTU0040000Jc^5Jc^500000[V2V0030000V6>BV6>B00BHHi800`0007A4
R7A4R002M4B800D00029E8`0001U?hl000000X]JTP800004`XFC00<0002JHHfJHHd00iYQS@030000
`hND`hND00?3Qi@00`000:1WS`0000040000138@MP800004kJn=0P0000BUKI82000018mIS@040000
>1Qm0000/7bJ0P000003gYnA0000TUZ;00>BFX/00`0007Y7QgY7Q`03NTN70P0000;>TY@3000018mM
TP800003N4fA00<00027E8j7E8h00XMDSP030000REN?REN?00:9Ehl00`0008UFShUFS`02REJ?0P00
00A`@h/00`0006<kRf<kR`02Hc^;00<0001BD;4000000]2BT@050000WFNCWFNCWFNC000000FJHi00
0`0007Q:SGQ:S@0300001I9TV@800005X6bF00D0002EHiBEHiBEHi@000001HaLU0040000NDnCNDnC
00000WM;T0030000LDN@LDN@009aAi000`0007A<TgA<T`03M4bC00<0002;GiV;GiT00X]OV@030000
TVFJTVFJ00BBIIX4000000=ZAI<0000l:i<00P0000>>i?`00`000:F5/ZF5/P02YHFb00<0002cQjNc
QjL00k>7Y`030000]H:N]H:N00>ePYh01@000;1iV0000;1iV0000005Xg:L00<0002?IIj?IIh00hmU
WP030000UVbOUVbO00>FK9l010000;cf[@00000000:X`>/00`000:S0jjS0j`02Z<3[00<0003ooooo
ool04Oooo`030000oooooooo00[oool001Goool00`000?ooooooo`0Uoooo00<0003T^Z`000000^G4
]P@00002S:_[00@0002FM:ZFM:ZFM:X200000iaiZ`030000nnJUnnJU00@00002002000P0002BJj:B
Jj80002ULIP0001F>I<00002@BR<00<0001fCiIfCiH00P000004:Q5m0000SV:ISV:I0`0000?f`YD0
0`0005TdRP000002MV6^00@0003>U9W>U9T00004V6VK00@0000T3G`T3G`00002gjBD00<0001[>hD0
00000[V2V0800006V6>B00<0001dA8QdA8P00WA4R0050000REB<0000ICn?000000:;FY8200001<:5
T`030000VV6=VV6=00>JHHd00`000<>7U<>7U003`hND00<0002PIhnPIhl00j1WS`030000<Q1f<Q1f
008b47H010000000H0000>f_S@800006YFfB0P0000B?FHd0100003PHO@000;1lVP8000000mjOT@00
099JR`03TUZ;00<0001jAhMjAhL00gY7Q`800002cY:D0`0000B?GI8300000WQ=T@030000QeB>QeB>
00:7E8h00`0008UGShUGS`02REN?00<00029EXn9EXl00XUFS`800004L4>;00<0001S>h]S>h/00V<k
R`800004d9:A0P000003WFNC0000VV>@00>JHi0400000XmMTP030000TVBITVBI00>BI9T200001J1/
UP050000UF>DUF>DUF>D000000F<G9@01`0007U?TgU?TgU?T`0007M;T0000004LDN@00<0001dC9=d
C9<00gA<T`030000RenIRenI00>;GiT00`00099UVY9UVP03TVFJ0P0000=ZAI<00`0003`[Tc`[T`02
00000XkTo0030000YHFbYHFb00:UQK800`000;>7Yk>7Y`03/hNW00<0002ePYjePYh00kF2WP030000
/7VH/7VH00800005Xg:L00<0002?IIj?IIh00hmUWP030000UVbOUVbO00>FK9l200001:S0j`040000
Z<3[Z<3[Z<3[0`0001;oool00`000?ooooooo`0:oooo000Doooo00<0003oooooool09_ooo`030000
i;Z/0000008000001>G4]P000000000000:<Zn/0100009IdZYIdZYIdZP800003W7V[00<0003kiZD0
00000P000003ikRT0000002000800002TV^R00<0002ULIP000000UHiT`030000@BR<0000009fCiH2
000000@Z4Gd0002>HYV>HYT300000oK2U@060000FCB:FCB:0000MV6^00000/jDV@030000V6VKV6VK
00:HJI/0100002@=O2@=O00000;OY9@00`0006/kQ@000002^H:H0P0000JHHi800`0007A4R7A4R002
M4B80P00009U?hl00`0008]JTX]JTP0200001<:5T`030000VV6=VV6=00>JHHd00`000<>7U<>7U004
`hND00<0002PIhnPIhl00Z1WS`030000<Q1f<Q1f008b47H00`000000H000000300001ZE]TP800004
SeV=00@0000h67d0002`O9X2000000?NWi40002BFX/00i9JR`030000NTN7NTN700=jAhL200000/jB
U08000000iYUT`0008mMTP02SefB0`00009hCI400`0008MDSXMDSP02QeB>00<00029Ehn9Ehl00XUG
S`030000REJ?REJ?00:9EXl200001713R`030000Hc^;Hc^;00=S>h/00`000=2BTM2BT@04d9:A0P00
0003VV>@0000000000800005SefB00<0002BI9VBI9T0199TV@030000X6bFX6bF00>PK9H00`0009ES
U9ESU002UF>D00<0002<G9B<G9@00XaLU0030000NDnCNDnC009iCi<200001757T0030000M4bCM4bC
00=dC9<00`0008]OVH]OV@03RenI00<0002BIIZBIIX00Y9UVP800004JTFC00@0000l:i<l:i<l:i<2
000000>>i?`0002UQK801:F5/P030000/hNW/hNW00:cQjL00`000;F2W[F2WP04]H:N00D0002`NIP0
002HK9h000001:=bW0030000SfFNSfFN00>?IIh00`0009I/WiI/W`02UVbO0`0000BX`>/400000jS0
j`030000oooooooo00ooool00`000?ooooooo`0:oooo000Doooo00<0003oooooool09Oooo`<00004
iLBf00H0003oool00000002<Zn/00002UWBZ00<0003S/Z<000000YaiZ`030000nnJUnnJU00800002
ikRT1@000003TV^R0000000000=F>I<00`00044XS0000002MTnF0P000003:Q5m0000SV:I00:>HYT0
10000?K2UOK2UOK2U@800002FCB:00@0001fHJh0003>U9T2000019QYV`09000090el0000RFFR0000
gjBD0000Jc^5000000:iPYP200001YQSTP030000M4B8M4B8009dA8P200000VDoS`030000ReZBReZB
00800004`XFC00<0002JHHfJHHd00YYQS@800006`hND00<0002PIhnPIhl00Z1WS`030000<Q1f<Q1f
008b47H01P000000H000H00008eKTP0000JUKI800`0008mISHmIS@03SeV=0P0000:`O9X2000000?N
Wi40002BFX/00i9JR`030000NTN7NTN700=jAhL200000/jBU08000000iYUT`0008mMTP02SefB0`00
009hCI400`0008MDSXMDSP02QeB>00<00029Ehn9Ehl00XUGS`070000REJ?REJ?REJ?0000Qe>=0000
00A`@h/00`0006<kRf<kR`03Hc^;00<0003@TY7@TY401M2BT@8000001JI]T@0007m@T7m@T0000004
SefB00<0002BI9VBI9T0199TV@800004X6bF00<0002EHiBEHi@00YESU0030000S5bDS5bD00:<G9@0
0`0007U?TgU?T`02NDnC0P0000AaAi000`0007A<TgA<T`03M4bC00<0002;GiV;GiT00h]OV@030000
TVFJ0000008000000jYeV00006Y5T`03JTFC00@0000l:i<l:i<l:i<200000XkTo0030000YHFbYHFb
00:UQK800`000;>7Yk>7Y`03/hNW00<0002ePYjePYh00kF2WP8000000iQ/WP0000000004Xg:L00<0
002?IIj?IIh018mUWP040000UVbOUVbOUVbO0`0000:X`>/200000ZS0j`030000Z<3[Z<3[00:X`>/0
0`000?ooooooo`0?oooo00<0003oooooool02_ooo`005?ooo`030000oooooooo02;oool300000ooo
o`8000000nG4]P0000000002oooo00<0002<Zn/000000YIdZP030000hk:S000000:LNJ/01@000?_V
Y@000>c4ZP000002ikRT0`000003RXc?0000TV^R00800002ESVC10000003MTnF00000000008Z4Gd0
100008iRVHiRVHiRV@800002m/:E0P00009I=8X2000000AfHJh0000000000004V6VK00T0000T3G`0
0029IJ80003OY9@0001[>hD000000[V2V0800006V6>B0`00009dA8P200000VDoS`030000ReZBReZB
00800004`XFC00<0002JHHfJHHd00YYQS@800006`hND00<0002PIhnPIhl00Z1WS`030000<Q1f<Q1f
008b47H00`000000H0000003SE^B00<0002UKI:UKI800jE]TP030000SeV=SeV=00>?FHd200000[1l
VP040000dY>@00000000199JR`030000NTN7NTN700=jAhL2000000K>TY@0003`beH0002JII<00003
SefB0`00009hCI400`0008MDSXMDSP02QeB>00<00029Ehn9Ehl00XUGS`070000REJ?REJ?REJ?0000
Qe>=000000A`@h/00`0006<kRf<kR`03Hc^;00<0003@TY7@TY401M2BT@040000YVfAYVfA00000Wm@
T0030000SefBSefB00:?GI800`00099TVI9TV@04TVBI0P0000BPK9H00`0009ESU9ESU002UF>D00<0
002<G9B<G9@00XaLU0030000NDnCNDnC00=iCi<00`000757T757T002LDN@00<0001dC9=dC9<017A<
T`040000RenIRenIRenI0`0000BZMIP00`0006Y5TfY5T`02JTFC00T0000l:i<l:i<l:i<0001LKld0
002>i?`000001:F5/P030000/hNW/hNW00>cQjL00`000;F2W[F2WP02]H:N0P0000>HK9h00`000:=b
W:=bW003Xg:L00<0002?IIj?IIh00hmUWP070000UVbOUVbO0000Tf:E0000BC:C00800004Z<3[00@0
002X`>^X`>^X`>/300004?ooo`030000oooooooo00[oool001Coool300008?ooo`800008oooo0P00
00?oool300000YIdZP030000hk:S0000008000001O_VY@000>c4Z^c4ZP000002ikRT2000009F>I<3
000000A1:8`0000000000002:Q5m00<0002>HYV>HYT00XiRV@D00003FCB:00<0001fHJh000000P00
00BHJI/01P0002@=O00008UUXP000=nTU0800002^H:H00<0001nCi0000001YQSTP8000000mnVV@00
0000000200000VDoS`030000ReZBReZB00800004`XFC00<0002JHHfJHHd00YYQS@800006`hND00<0
002PIhnPIhl00Z1WS`<00002<Q1f0P0000B=Fi800`000:E]TZE]TP03YFfB00<0002?FHf?FHd00hmI
S@800002/7bJ00@0003BTi0000000004TUZ;00<0001jAhMjAhL00gY7Q`030000cY:DcY:D00800002
VVFC00@0002?GI:?GI:?GI82000000AY?HT0001hCI400004QeB>00<00029Ehn9Ehl00XUGS`070000
REJ?REJ?REJ?0000Qe>=000000A`@h/00`0006<kRf<kR`03Hc^;00<0003@TY7@TY401M2BT@040000
YVfAYVfA00000Wm@T0030000SefBSefB00:?GI800`00099TVI9TV@04TVBI0P0000BPK9H00`0009ES
U9ESU002UF>D00<0002<G9B<G9@00XaLU0030000NDnCNDnC00=iCi<300000g57T0030000M4bCM4bC
00=dC9<01@0008]OV@00000009]UTP0200001:YeV0030000JTFCJTFC009ZAI<00`0003`[Tc`[T`02
?2^C00@0001LKld000000004YHFb00<0002cQjNcQjL00k>7Y`030000]H:N000000800005V6bN0P00
00BSLY`00`0008mUWXmUWP03SfFN00H0002FK9nFK9l0002CHYD00002BC:C00<0002X`>^X`>/00ZS0
j`@00003Z<3[00<0003oooooool03_ooo`030000oooooooo00Woool001Coool00`000?ooooooo`0M
oooo0`00013oool2000000>FM:X0003S/Z<00^>bX`<00002k<BZ00<0003W^:CW^:@00^NhY0800000
0nNhY@000000000200000UHiT`<00000144XS00000000000008Z4Gd0100008iRVHiRVHiRV@<00002
o]V000@0001I=8YI=8YI=8X5000019QYV`03000090el000000:9IJ8300000[V2V0030000OTn@0000
00JHHi8200000mnVV@800002ICn?00D0002;FY:;FY:;FY8000001<:5T`070000VV6=VV6=VV6=0000
OURK000000K3Qi@00`000:1WSj1WS`02X6N?0P000003XfbC0000000000800004SE^B00<0002UKI:U
KI800jE]TP030000SeV=SeV=00>?FHd200000k1lVP<00004TUZ;00<0001jAhMjAhL00gY7Q`030000
cY:DcY:D00800002VVFC00X0002?GI:?GI80003DViT0001Y?HT0001hCI400004QeB>00<00029Ehn9
Ehl00XUGS`040000REJ?REJ?00000XMCS@030000L4>;L4>;009`@h/00`0006<kRf<kR`03Hc^;00<0
003@TY7@TY401M2BT@040000YVfAYVfA00000Wm@T0030000SefBSefB00:?GI800`00099TVI9TV@03
TVBI00<00034T9l000001:1/UP030000UF>DUF>D00:EHi@00`0008aLU8aLU002S5bD00<0001iCi=i
Ci<00gU?T`040000/GNB/GNB00000W57T0030000M4bCM4bC009dC9<300000i]UTP800004ZWFH00<0
001ZAI=ZAI<00fY5T`050000?2^C?2^C?2^C0000009LKld00`000:F5/ZF5/P03YHFb00@0002cQjNc
QjNcQjL300000iIZWP030000V6bNV6bN00>HK9h00`000:=bW:=bW002Xg:L00<0002?IIj?IIh00hmU
WP060000UVbOUVbO0000Tf:E00000TTbT`030000Z<3[Z<3[00800002X8Nj00<0002X`>^X`>/00ZS0
j`80000?oooo00<0003oooooool02Oooo`005?ooo`030000oooooooo01[oool300004oooo`@00003
hk:S0P0000?/a:X00`000>NhY>NhY002ikRT00<0003W^:GW^:D01000009F>I<2000000=F@Yd00000
00000P00008Z4Gd0100008iRVHiRVHiRV@<00002o]V000@0001I=8YI=8YI=8X5000019QYV`<00002
RFFR0`0000:iPYP00`0007i?T0000005V6>B0P0000GOYYT0100006DoSfDoS`0000>;FY800`000<:5
Tl:5T`02`XFC00H0002JHHfJHHfJHHd0001nF9/200001L>7U0030000X6N?X6N?00:PIhl200000j=/
T`800004SE^B00<0002UKI:UKI800ZE]TP800005SeV=0P0000>`O9X30000199JR`030000NTN7NTN7
00=jAhL00`000<jBU<jBU00200000YYUT`0:0000SefBSefB0000e9^I0000JCf90000N4fA000018MD
SP030000REN?REN?00>9Ehl00`0008UFS`000002Qe>=00<0001`@h]`@h/00W13R`030000Hc^;Hc^;
009S>h/200001m2BT@040000YVfAYVfA00000Wm@T0030000SefBSefB00:?GI800`00099TVI9TV@03
TVBI00<00034T9l000001:1/UP030000UF>DUF>D00:EHi@00`0008aLU8aLU002S5bD00<0001iCi=i
Ci<00WU?T`800003/GNB0`000003M4bC0000000000800005VfFB00<0003BVid000001:YeV0030000
JTFCJTFC009ZAI<00`0003`[Tc`[T`02?2^C00@0001LKld000000004YHFb00<0002cQjL000000P00
00FFJYh00`0009Q/WYQ/WP03V6bN0P0000>SLY`00`0008mUWXmUWP03SfFN00<0002FK9l000000Y=R
U@040000BC:CBC:CBC:C0P0000BPQkX00`000:S0jjS0j`0200000ZS0j`030000oooooooo00coool0
0`000?ooooooo`09oooo000Doooo00<0003oooooool05oooo`<0000Goooo0`0000?S/Z<200000^c4
ZP030000ikRTikRT00;W^:@01P000>NhYNNhYNNhY@000>JeX@800002ESVC0P000003ET:M00000000
00800002:Q5m00L0002>HYV>HYV>HYT0002HJ9P000000_kIP0060000FCB:FCB:FCB:0000Wgj_0`00
00BHJI/200000hUUXP800002^H:H00@0001nCi1nCi000005V6>B0P0000GOYYT0100006DoSfDoS`00
00>;FY800`000<:5Tl:5T`02`XFC00H0002JHHfJHHfJHHd0001nF9/200001L>7U0030000X6N?X6N?
00:PIhl200001:=/T`030000SE^BSE^B00:=Fi801`000:E]TZE]TZE]TP0009EOS`000005SeV=0P00
00>`O9X30000199JR`040000NTN7NTN7NTN70P0000?>TY@200000YYUT`060000SefBSefB0000e9^I
00000VTmR@800004QeB>00<00029Ehn9Ehl00hUGS`030000REJ?000000:7Dhd00`000713Rg13R`02
L4>;00<0001S>h]S>h/00V<kR`030000m/2B000000K@TY4010000:I]TJI]T@00009oD9000`0008mM
TXmMTP02SefB00<0002BI9VBI9T00i9TV@030000a92O000000BPK9H00`0009ESU9ESU002UF>D00<0
002<G9B<G9@00haLU0060000NDnCNDnC0000VVNE00001K5gTP800003Y6bB00<0002KII:KII800i]U
TP030000dY^M000000BZMIP00`0006Y5TfY5T`02JTFC00<0000l:i<l:i<00`00009LKld700000iIZ
WP030000UVZNUVZN00:FJYh00`0009Q/WYQ/WP03V6bN00<0002SLY`000000Z=bW0030000SfFNSfFN
00B?IIh200000i=RU@040000BC:CBC:C00001Z27^P800004Z<3[00<0003oooooool03?ooo`030000
oooooooo00Woool001?oool00`000?ooooooo`0Eoooo0`0001_oool00`000>>bXn>bX`02hk:S00D0
003/a:[/a:[/a:X000001>NhY0040000ikRUikRU00000^JeX@80000015HiT`0000000000009F@Yd3
00000bXAO@060000SV:ISV:I0000V6RH00000_kIP0040000FCB:FCB:FCB:0P000004Wgj_0000^h:F
00000iQYV`<00002RFFR0P0000:iPYP0100007i?T7i?T00000FHHi8200001MnVV@040000ICn?ICn?
00000h]JTP030000`XFC`XFC00;2QI<01@0009YQSIYQS@0008YNV00300001L>7U0030000X6N?X6N?
00:PIhl200001:=/T`030000SE^BSE^B00:=Fi8010000:E]TZE]TP0000:EGhl00`0008mISHmIS@03
SeV=00<0002`O9Z`O9X00[1lVP030000dY>@000000BBFX/0100007Y7Q`00000000G>TY@200000YYU
T`060000SefBSefB0000e9^I00000VTmR@030000N4fA000000B7E8h00`0008UGShUGS`02REN?00<0
0029EXl000000XMCS@030000L4>;L4>;009`@h/00`0006<kRf<kR`02Hc^;00<0003f`98000001]2B
T@030000YVfA000000=oD9000`0008mMTXmMTP02SefB00<0002BI9VBI9T00i9TV@030000a92O0000
00BPK9H00`0009ESU9ESU002UF>D00<0002<G9B<G9@00haLU0030000NDnC000000:JIiD00`000;5g
T[5gTP03/GNB00<0002TK9:TK9800ZA/TP030000VfFBVfFB00>KII800`000=:KW@000004ZWFH00@0
001ZAI=ZAI=ZAI<400000Y=TV08000000ea_c@0008eYY003SFVT00<0002FJYjFJYh00YIZWP030000
UVZNUVZN00:FJYh00`0009Q/WYQ/WP03V6bN00<0002SLY`000000Z=bW0030000SfFNSfFN00B?IIh0
0`0009=RUI=RU@02Tf:E00D00019<Y=9<Y=9<Y<000001:27^P<00004Z<3[0P0000goool00`000?oo
ooooo`09oooo000Coooo0`0001;oool300007_ooo`030000hk:Shk:S00;S/Z<01@000>c4Z^c4Z^c4
ZP000004ikRT00@0003W^:GW^:D00002i[FQ00D0001hJKD000000026IJD00P000004ET:M00000000
00000bXAO@030000SV:I000000800003o]V000@0001I=8YI=8YI=8X2000000FOOZl0002kPYJkPYH0
00000YQYV`<00002RFFR00D0002iPYRiPYRiPYP000000Wi?T0030000V6>BV6>B00>HHi8200001MnV
V@040000ICn?ICn?00000h]JTP030000`XFC`XFC00;2QI<01@0009YQSIYQS@0008YNV00300001L>7
U0030000X6N?X6N?00:PIhl200001:=/T`030000SE^BSE^B00:=Fi8010000:E]TZE]TP0000:EGhl0
0`0008mISHmIS@03SeV=00<0002`O9Z`O9X00[1lVP030000dY>@000000:BFX/600001<jBU0800003
VVFC00H0002?GI:?GI80003DViT00002JCf900<0001hCI40000018MDSP030000REN?REN?00:9Ehl2
00000hMCS@030000L4>;L4>;00=`@h/01`0006<kRf<kRf<kR`000?K0TP000006d9:A00<0002VKI40
00000gm@T0030000SefBSefB00>?GI801@00099TVI9TVI9TV@000002a92O00<0002PK9JPK9H00Z1/
UP030000UF>DUF>D00:EHi@00`0008aLU8aLU003S5bD00<0001iCi<000000YYWU@030000/GNB/GNB
00>aMi800`000:A/TZA/TP03Y6bB00H0002KII:KII:KII800000K]P400000ZYeV0060000JTFC0000
0000U6NL000019=TV08000000ea_c@0008eYY003SFVT00<0002FJYjFJYh00YIZWP030000UVZNUVZN
00:FJYh00`0009Q/WYQ/WP03V6bN00@0002SLYbSLY`00002Xg:L00<0002?IIj?IIh00XmUWP800004
Tf:E00D00019<Y=9<Y=9<Y<000001:27^P<00002Z<3[0P0000:X`>/00`000?ooooooo`0:oooo00<0
003oooooool02Oooo`004oooo`030000oooooooo00ooool300008_ooo`050000hk:Shk:Shk:S0000
00;/a:X00`000>NhY>NhY002ikRT00D0003W^:GW^:GW^:D000000nJeX@<000001hIUY@00000005I2
W@000000L0000003:Q5m00<0002>HYT000000P0000CnfH000`0005TdRUTdRP0200000Ymn[`050000
^h:F^h:F0000V6VK00<00002RFFR00D0002iPYRiPYRiPYP000000Wi?T0030000V6>BV6>B00:HHi82
00001MnVV@800002ICn?00D0002;FY:;FY:;FY8000001<:5T`030000VV6=000000::GYP300001L>7
U0030000X6N?X6N?00:PIhl200001:=/T`030000SE^BSE^B00:=Fi800`000:E]TP000003UEn?00<0
002?FHf?FHd00hmIS@030000/7bJ/7bJ00:`O9X00`000=:CT000000300000m^LT@800004cY:D0P00
00>JII<01P0008mMTXmMTP000=BKV@00009Y?HT00`0007Q=T@000004QeB>00<00029Ehn9Ehl00XUG
S`800003Qe>=00<0001`@h]`@h/00g13R`070000Hc^;Hc^;Hc^;0000m/2B000000K@TY400`000:I]
T@000003Oe2@00<0002?GI:?GI800hmMTP040000TVBITVBITVBI0P000003a92O0000X6bF00BPK9H0
0`0009ESU9ESU002UF>D00<0002<G9B<G9@00XaLU0800004VVNE00<0002aMi:aMi800[5gTP030000
Y6bBY6bB00>TK9801@0009]UTY]UTY]UTP00000206kH00<0002?KZV?KZT0100000>DIi`00`0009=T
V9=TV002TfBH0P000003G6o=0000SFVT00>=JJ@00`0009IZWYIZWP02UVZN00<0002FJYjFJYh00YIZ
WP030000V6bNV6bN00BHK9h01`000:=bW:=bW0000:=bW00008mUWP0400001I=RU@030000BC:CBC:C
0099<Y<00`000:27^Z27^P0600001:S0j`030000oooooooo00[oool00`000?ooooooo`09oooo000C
oooo00<0003oooooool03?ooo`<0000Uoooo00@0003S/Z?S/Z<00003k<BZ00<0003W^:CW^:@00^Nh
Y0040000ikRUikRU00001>JeX@<00002QVFU00D0001F@Yd00000070000000bXAO@050000SV:I0000
V6RH000000CnfH000`0005TdRUTdRP0200000Ymn[`080000^h:F^h:F0000V6VK0000P5JF00000XUU
XP040000^H:H^H:H00000gi?T0030000V6>BV6>B00:HHi8200001MnVV@050000lKnL0000ICn?0000
00>;FY800`000<:5Tl:5T`02`XFC00<0002JHHd000000XYNV0030000lkV>000000G3Qi@00`000:1W
Sj1WS`02X6N?0P0000BSK9<300000XeKTP800004UEn?00<0002?FHf?FHd00hmIS@030000/7bJ/7bJ
00:`O9X01P000=:CT000000009e`W`0000?KW94200001<jBU0800003VVFC00H0002?GI:?GI80003D
ViT00003JCf90P0000B7E8h00`0008UGShUGS`02REN?0P0000>7Dhd00`000713Rg13R`03L4>;00L0
001S>h]S>h]S>h/0003f`98000001]2BT@030000YVfA000000=oD9000`0008mMTXmMTP03SefB00T0
002BI9VBI9VBI9T000063H`00034T9l000001:1/UP030000UF>DUF>D00:EHi@00`0008aLU8aLU002
S5bD00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000:A/TZA/TP03Y6bB00@0002KII:K
II:KII82000000<0K]P0002?KZT00hm^Z@030000U6NLU6NL00:DIi`00`0009=TV9=TV002TfBH00@0
002CHYH000000004SFVT00<0002FJYjFJYh00YIZWP030000UVZNUVZN00>FJYh00`0009Q/WYQ/WP03
V6bN00@0002SLYbSLYbSLY`300000i=QU0030000Tf:ETf:E00>CHYD00`0004TbTdTbT`02BC:C00<0
002PQkZPQkX00P0000>MO[000`000:S0jjS0j`02Z<3[0P0000_oool00`000?ooooooo`09oooo000C
oooo00<0003oooooool02Oooo`<0000Yoooo00<0003S/Z<000000nc4ZP050000ikRTikRTikRT0000
00?W^:D00`000>JeXNJeX@02i[FQ0`000003QVFU00000000008000000`00L00002XAO@02:Q5m00D0
002>HYT0002HJ9P000001?kIP0080000FCB:FCB:0000Hd6B0000Wgj_00000[^2UP<000001H1FUP00
08UUXXUUXP000002^H:H00D0001nCi1nCi1nCi00000019QSTP800005gjJI00D0003a_i`0001U?hl0
00000h]JTP030000`XFC`XFC00;2QI<00`0009YQS@000002RUjH00<0003c^Hh000001L>7U0030000
X6N?X6N?00:PIhl200001J=/T`H00004UEn?00<0002?FHf?FHd00XmIS@030000/7bJ/7bJ00>`O9X0
1P000=:CT000000009e`W`0000?KW94200001<jBU0800003VVFC00<0002?GI8000000mBKV@030000
JCf9JCf900800004QeB>00<00029Ehn9Ehl00XUGS`800003Qe>=00<0001`@h]`@h/00g13R`040000
Hc^;Hc^;00000_K0TP030000d9:Ad9:A00G@TY4200000gm@T0030000SefBSefB00>?GI801000099T
VI9TVI9TV@<000000lB@W`000:1/UP03X6bF00<0002EHiBEHi@00YESU0030000S5bDS5bD00<00005
VVNE00<0002aMi:aMi800[5gTP030000Y6bBY6bB00>TK980100009]UTY]UTY]UTP80000206kH00D0
002?KZV?KZV?KZT000001IAWW0030000TfBHTfBH00:CI9P3000018eYY0030000UVZNUVZN00>FJYh0
0`0009IZWYIZWP02UVZN00<0002HK9jHK9h00iQ/WP070000Xg:LXg:LXg:L0000YG6H000000>CHI@0
0`0009=RUI=RU@03Tf:E00<00019<Y=9<Y<00TTbT`030000X8Nj000000FMO[000`000:S0jjS0j`02
00000ZS0j`030000oooooooo00Woool00`000?ooooooo`08oooo000Coooo00<0003oooooool01ooo
o`80000/oooo0P0000?/a:X00`000>NhY>NhY002ikRT00D0003W^:GW^:GW^:D000001>JeX@800000
0hIUY@0000000002000000AF@Yd0000000000002:Q5m0`000004V6RH0000o]V000000_kIP0080000
FCB:FCB:0000Hd6B0000Wgj_00000[^2UP030000P5JF000000:0EYH01P0008UUXXUUXP000;V2V000
00=nCi001`0009QSTYQSTYQSTP000?WMNP000005gjJI00D0003a_i`0001U?hl000000h]JTP030000
`XFC`XFC00;2QI<200000hYNV0030000lkV>000000G3Qi@00`000:1WSj1WS`02X6N?0P0000FSK9<2
00000YYSS`800004UEn?00@0002?FHf?FHf?FHd200001K1lVP030000dY>@000000:ML9l010000=^L
TM^LTM^LT@800004cY:D0P0000>JII<00`0008mMTP000003e9^I00<0001Y?HUY?HT00P0000B7E8h0
0`0008UGShUGS`02REN?00<00027Dhf7Dhd00XMCS@030000L4>;L4>;00=`@h/0100006<kRf<kR`00
00?f`9800`000=2BTM2BT@04d9:A0P0000=oD9000`0008mMTXmMTP03SefB00D0002BI9VBI9T0002R
K9@0100000BPK9H00`0009ESU9ESU002UF>D0`0000:DHiH00`0009YWUIYWU@03VVNE00<0002aMi:a
Mi800[5gTP030000Y6bBY6bB00>TK980100009]UTY]UTP0000:CHYH00`00001^f0000003SfjY00<0
002DIibDIi`00iAWW0030000TfBHTfBH00:CI9P0100009=RUP00000000>=JJ@00`0009IZWYIZWP03
UVZN00<0002FJYjFJYh00YIZWP030000V6bNV6bN00>HK9h010000:=bW:=bW:=bW0<00003Tf6D00<0
002CHYFCHYD019=RU@030000BC:CBC:C0099<Y<300001Ien/0800004Z<3[00<0003oooooool02Ooo
o`030000oooooooo00Soool001;oool010000?ooo`00000000Coool30000;oooo`050000k<BZk<BZ
k<BZ000000CW^:@01@000>NhYNNhYNNhY@000004i[FQ0`000004m]:X00000000001W1000008Z4Gd2
000000FHJ9P0003nfH3nfH0000000_kIP0090000FCB:FCB:0000Hd6B0000Wgj_0000^h:F00800004
P5JF00<00029IJ:9IJ800`0000=nCi00100009QSTYQSTYQSTP800005gjJI00P0003a_ica_ica_i`0
001U?hl0002;FY8200001<:5T`800002RUjH100000G3Qi@00`000:1WSj1WS`02X6N?0P0000FSK9<2
00000YYSS`800004UEn?00H0002?FHf?FHd0002CJIl00006/7bJ0P0000:ML9l01`000=^LTM^LTM^L
T@0009e]V`000003cY:D0P0000>JII<00`0008mMTP000003e9^I00<0001Y?HUY?HT00P0000B7E8h0
100008UGShUGShUGS`800004Qe>=00<0001`@h]`@h/00g13R`040000Hc^;Hc^;00000oK0TP030000
d9:Ad9:A00C@TY42000017m@T0030000SefBSefB00:?GI801@00099TVI9TV@000:9/U00400001:1/
UP030000UF>DUF>D00<00004U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000:A/
TZA/TP03Y6bB00@0002KII:KII800002Tf:F00<00000K]P0000018m^Z@030000U6NLU6NL00:DIi`0
0`0009=TV9=TV002TfBH00@0002CHYH000000004SFVT00<0002FJYjFJYh00YIZWP030000UVZNUVZN
00:FJYh00`0009Q/WYQ/WP03V6bN00<0002SLYbSLY`00P000003YG6H0000Tf6D00>CHI@00`0009=R
UI=RU@03Tf:E00<00019<Y=9<Y<00`000003RVb[0000WGj`00BMO[0200001:S0j`80000:oooo00<0
003oooooool02?ooo`004_ooo`800003oooo0`0003?oool300001>NhY0050000ikRUikRUikRU0000
00GV]J44000000?]`jT0000006L00`000003o=BH0000:Q5m008000000iQXV0000?kIP00200000_kI
P0090000FCB:FCB:0000Hd6B0000Wgj_0000^h:F00800004P5JF0P000004RFFR0000000000000gi?
T0040000V6>BV6>BV6>B0P0000GOYYT020000?6oW?6oW?6oW00006DoS`0008]JTP@00002`XFC1000
00?g`I400`000<>7U<>7U003`hND00<0002PIhnPIhl00Z1WS`800005XfbC0P0000>JHhl00`0009EO
SiEOS`02UEn?00H0002?FHf?FHd0002CJIl00006/7bJ0P0000:ML9l00`000=^LTM^LT@02000000BM
KI/0003>TYC>TY@200001IYUT`800003e9^I00D0001Y?HUY?HUY?HT0000018MDSP030000REN?0000
00<00004Qe>=00<0001`@h]`@h/00g13R`040000Hc^;Hc^;00000oK0TP030000d9:Ad9:A00C@TY42
000017m@T0030000SefBSefB00:?GI801000099TVI9TV@0000:RK9@:00000YAVVP030000U6>FU6>F
00:DHiH00`0009YWUIYWU@03VVNE00<0002aMi:aMi800k5gTP030000Y6bBY6bB00:TK980100009]U
TY]UTP0000>CHYH2000018m^Z@030000U6NLU6NL00:DIi`00`0009=TV9=TV002TfBH00@0002CHYJC
HYH00004SFVT00<0002FJYjFJYh00YIZWP030000UVZNUVZN00:FJYh00`0009Q/WYQ/WP04V6bN0P00
0004WV^F0000YG6H000019=QU0030000Tf:ETf:E00>CHYD3000018Y/Z`030000WGj`WGj`00:MO[00
0`0000001P000002Z<3[0P0000:X`>/00`000?ooooooo`07oooo00<0003oooooool02?ooo`004_oo
o`030000oooo00000080000hoooo00<0003W^:CW^:@00^NhY0050000ikRUikRUikRU000000CV]J40
20000?KBZ0000?KBZ0000>g3Z@000000I`D000001RXAO@00000009QXV0000?kIP0<000002_kIP000
05TdRUTdRP0006=1TP0009mn[`000;^2UP800003P5JF00@0003Xf6@00029IJ8300000gi?T0060000
V6>BV6>B0000nMej00001MnVV@080000lKnLlKnLlKnL0000ICn?0000ReZB0P0000:iPYT400001OO1
T@030000`hND`hND00?3Qi@00`000:1WSj1WS`02X6N?0P0000FSK9<00`0009YSSiYSS`02VV>?00<0
002EGhnEGhl00YEOS`030000SeV=000000:CJIl00`000;1lV[1lVP04/7bJ0P0000>ML9l01P000=^L
T@00000009e]V`0000;>TY@200001IYUT`<00002e9^I00@0001Y?HUY?HUY?HT7000000EA;HH00000
002<Fi8000000hMCS@030000L4>;L4>;00=`@h/0100006<kRf<kR`0000?f`9800`000=2BTM2BT@04
d9:A0P0000AoD9000`0008mMTXmMTP02SefB00@0002BI9VBI9T00002XVbD0`0000B?JZ@00`0009AV
VYAVVP02U6JJ00<0002DHiJDHiH00YASUP030000VVNEVVNE00>JIiD00`000;5gT[5gTP03/GNB00<0
002TK9:TK9800ZA/TP040000VfFBVfFB00000i=RUP03000006kH000000>?KZT00`0009AWW9AWW002
U6NL00<0002CI9RCI9P00Y=TV0040000Tf:FTf:F000018eYY0030000UVZNUVZN00:FJYh00`0009IZ
WYIZWP02UVZN00<0002HK9jHK9h019Q/WP8000000ii[UP000:EaV00200000i=QU0030000Tf:ETf:E
00>CHYD00`000>6/WP000004RVb[00<0002MO[2MO[000Yen/0D00004Z<3[00<0003oooooool01ooo
o`030000oooooooo00Soool000Soool500001Oooo`80000loooo00D0003W^:CW^:CW^:@000000nNh
Y@030000i[FQi[FQ00;V]J401@000?KBZ?KBZ?KBZ0000002kL>Y2@000003V6RH00000000008k@Jh0
0`000?kIP0000003FCB:00P0001S@I800000002kPYH0001/DZ800002P5JF00<0003Xf6CXf6@01000
00=nCi001P0009QSTYQSTP000?WMNP0000GOYYT01P000?6oW?6oW?6oW00006DoS`<00005^H:I0P00
00Gg`I400`000<>7U<>7U003`hND00<0002PIhnPIhl00Z1WS`800005XfbC00<0002JHhnJHhl00YYS
S`030000UEn?UEn?00:EGhl200000i=YW`030000/7bJ/7bJ00B`O9X00`0009e`Wie`W`02WG2O00<0
003KW94000000Ye]V`030000cY:DcY:D00800005VVFC0`0000;DViT01@0006TmRFTmRFTmR@000002
BRV60P0000=A;HH2000000><Fi800027Dhd00hMCS@030000L4>;L4>;009`@h/0100006<kRf<kR`00
00?f`9800`000=2BTM2BT@04d9:A0P0000AoD9000`0008mMTXmMTP02SefB00<0002BI9T000000j9/
U0<00004SfZT00<0002DIYZDIYX00YAVVP030000U6>FU6>F00>DHiH00`0009YWUIYWU@02VVNE00<0
002aMi:aMi800k5gTP030000Y6bBY6bB00:TK9800`0009]UTP000004Tf:F00<00000K]P000000hm^
Z@030000U6NLU6NL00:DIi`00`0009=TV9=TV002TfBH00D0002CHYJCHYJCHYH000000heYY0030000
UVZNUVZN00:FJYh00`0009IZWYIZWP03UVZN00<0002HK9jHK9h00YQ/WP800002WV^F0P0000:CHI@0
100009=QU9=QU00000BCHYD01@000>6/W^6/W^6/WP000004RVb[00<0002MO[2MO[000P0000>X`>/0
10000:S0jjS0jjS0j`<00008oooo00<0003oooooool02?ooo`002_ooo`030000oooooooo00Koool0
0`000?ooooooo`0koooo0`0000?W^:D00`000>JeXNJeX@03i[FQ00@0003fdZSfdZP00003kL>Y0`00
0003K5RZ0000000000@000001okIP00003]1[S]1[P000?kIP0000003FCB:00<0001S@I8000000`00
0004K5:R0000P5JFP5JF0P000003j=QT0000000000800003OTn@00<0002HHi:HHi800P0000GOYYT0
0`000?6oW?6oW002lKnL1@0000FiPYT200001OO1T@030000`hND`hND00?3Qi@01`000:1WSj1WSj1W
S`00095QUP000005XfbC00<0002JHhnJHhl00YYSS`H00004TfVO00<0002`O9Z`O9X01;1lVP030000
WG2OWG2O00:ML9l00`000=^LT@000002WFfK00<0003>TYC>TY@00`0000BJII<300000]BKV@050000
JCf9JCf9JCf90000009::HH200000e4]QP8000000haKTP0008MCS@03Qe>=00<0001`@h]`@h/00W13
R`030000Hc^;000000Cf`9800`000=2BTM2BT@04d9:A0P0000AoD9000`0008mMTXmMTP02SefB00<0
002BI9T000000j9/U08000000lM;000008mZY002SfZT00<0002DIYZDIYX00YAVVP030000U6>FU6>F
00>DHiH00`0009YWUIYWU@02VVNE00<0002aMi:aMi800k5gTP030000Y6bBY6bB00:TK9800`0009]U
TP000005Tf:F0P0000>?KZT00`0009AWW9AWW002U6NL00<0002CI9RCI9P00Y=TV0030000Tf:FTf:F
00:CHYH0100008eYY8eYY00000FFJYh00`0009IZWYIZWP02UVZN00<0002HK9h000000P0000FNJiH2
00000Y=QU0030000Tf6D000000BCHYD01@000>6/W^6/W^6/WP000004RVb[00@0002MO[2MO[000004
Z<3[100000>X`>/00`000?ooooooo`05oooo00<0003oooooool02?ooo`002_ooo`030000oooooooo
00Ooool20000?Oooo`050000ikRUikRUikRU000000CV]J401@000?KBZ?KBZ?KBZ0000003kL>Y0P00
009/F:X00`0009j8_000000500000S]1[P030000o]V0000000=I=8X00`0006=1TP000003000000A/
DZ800020EYJ0EYH3000000CXf6@0000000000003OTn@00<0002HHi:HHi800P0000GOYYT01P000?6o
W?6oW?6oW0000>:_X@@00005^H:I00<0003g`I7g`I401?O1T@030000`hND`hND00?3Qi@01`000:1W
Sj1WSj1WS`00095QUP000005XfbC00<0002JHhnJHhl00iYSS`800003Xf^B00D0002CJInCJInCJIl0
00001K1lVP030000WG2OWG2O00>ML9l00`000=^LT@000002WFfK00<0003>TYC>TY@00`0000BJII<3
00000]BKV@050000JCf9JCf9JCf90000009::HH200000e4]QP8000000haKTP0008MCS@03Qe>=00<0
001`@h]`@h/00W13R`030000Hc^;000000Gf`9800`000=2BTM2BT@02d9:A00<00021DHl0000017m@
T0030000SefBSefB00>?GI8200000j9/U0040000NTnB0000000018mZY0030000U6JJU6JJ00:DIYX0
0`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000:A/TZA/TP03
Y6bB0P0000FCHYH200000hm^Z@030000U6NLU6NL00>DIi`01@0009=TV9=TV9=TV0000005Tf:F00<0
002=JJ@000001IIZWP030000UVZNUVZN00@00002VFJF00<0002NJiJNJiH00ii[UP800002Tf6D00<0
002CHI@0000019=RU@050000hJbNhJbNhJbN000000B:K:/0100009en/000000000:X`>/200000ZS0
j`030000Z<3[Z<3[00:X`>/00`000?ooooooo`05oooo00<0003oooooool02?ooo`002_ooo`030000
oooooooo00Woool00`000?ooooooo`0koooo00@0003W^:GW^:D00004i[FQ00@0003fdZSfdZP00004
kL>Y0P0000=/F:X2000000?le9P0000000000P00008k@Jh300000eTdRP030000Hd6B000000<00000
0faBXP00081FUP03000000=WAIH0003Xf6@00P0000=nCi001@0009QSTP000?WMNP000005gjJI00H0
003a_ica_ica_i`0003R[j4400001KV2V@030000ml6Aml6A00Cg`I4200001<>7U0070000X6N?X6N?
X6N?0000TF6F000000FSK9<00`0009YSSiYSS`03VV>?0P0000>SJi800`0009=YWi=YW`02TfVO00@0
002`O9Z`O9Z`O9X200001Ie`W`030000fibA000000:MKI/01P000<jBU<jBU00008mMTP0000BJII<0
0`000:F>_@000002e9^I00D0001Y?HUY?HUY?HT000000dXYQP060000DBf6DBf6DBf60000ABF50P00
00B7Dhd00`000713Rg13R`02L4>;00<0001S>h/000001OK0TP030000d9:Ad9:A00;@TY400`00085A
S`000004Oe2@00<0002?GI:?GI800hmMTP800003XVbD00@0001jCi8000000004SfZT00<0002DIYZD
IYX00YAVVP030000U6>FU6>F00:DHiH00`0009YWUIYWU@03VVNE00<0002aMi:aMi800[5gTP030000
Y6bBY6bB00>TK98200001I=RUP800004SfjY00<0002DIibDIi`00YAWW0030000TfBHTfBH00:CI9P0
0`0009=RUY=RUP02Tf:F0P000003SFVT0000UVZN00:FJYh500001IUVUP030000WV^FWV^F00>NJiH2
00000i=QU0800004Tf:E00D0003Q[9kQ[9kQ[9h0000018Y/Z`030000WGj`000000<00004Z<3[00@0
002X`>^X`>^X`>/300001oooo`030000oooooooo00Ooool000[oool00`000?ooooooo`0:oooo00<0
003oooooool0>oooo`030000ikRU000000?V]J401@000?KBZ?KBZ?KBZ0000005kL>Y00H0001/F:Y/
F:Y/F:X0002NR;`300000TTfV0030000>d6^000000800003FCB:00<0001S@I8000000`000003K5:R
0000P5JF00<00002IdFF00<0003Xf6@000000gi?T0060000V6>B00000000EGcL00000mnVV@030000
lKnLlKnL00;a_i`00`000>:_XN:_X@0200001[V2V@@00004ml6A00<00033QiC3Qi@00/>7U0040000
X6N?X6N?00000Y5QUP030000XfbCXfbC00:SK9<200001IYSS`030000Xf^BXf^B00:SJi800`0009=Y
Wi=YW`02TfVO00H0002`O9Z`O9X0001lFIh00005WG2O00<0003KW94000000Ye]V`060000cY:D0000
0000SefB000019YUT`030000YHjm000000;DViT01@0006TmRFTmRFTmR@000003BRV600H0001A;HIA
;HIA;HH000159HD2000018MCS@030000L4>;L4>;00=`@h/200001OK0TP050000d9:Ad9:Ad9:A0000
00:1DHl00`0007m@T7m@T002Oe2@00<0002?GI:?GI800hmMTP030000XVbDXVbD00:RK9@0100007Y?
TP00000000B?JZ@00`0009AVVYAVVP02U6JJ00<0002DHiJDHiH00YASUP030000VVNEVVNE00>JIiD0
0`000;5gT[5gTP02/GNB00<0002TK9:TK9800jA/TP800005Tf:F0`0000>?KZT00`0009AWW9AWW002
U6NL00<0002CI9RCI9P00Y=TV0030000Tf:FTf:F00:CHYH01@0009ASUP00000009IZWP02000019ET
UP030000VFJFVFJF00>IIYH00`0009i[UYi[UP03WV^F0P0000BCHI@200000Y=RU@030000hJbNhJbN
00;Q[9h00`0008Y/ZhY/Z`03RVb[1@0000BX`>/400000jS0j`030000oooooooo00Coool00`000?oo
ooooo`07oooo0009oooo0P0000goool00`000?ooooooo`0joooo0P0000CV]J401@000?KBZ?KBZ?KB
Z0000005kL>Y00<0001/F:Y/F:X00P000004WXRl0000000000000TTfV0030000>d6^000000800003
FCB:00<0001S@I8000000`000003K5:R0000P5JF00<00003IdFF0P0000=nCi001P0009QSTP000000
05Elg00000?OYYT01@000?6oW?6oW?6oW0000003hZnQ0P0000JiPYT00`000?G5W?G5W00300000_O1
T@030000`hND`hND00;3Qi@010000:1WSj1WS`0000:AHIH01`000:=/Tj=/Tj=/T`000<25U0000005
VV>?00<0002SJi:SJi800Z=[TP030000TfVOTfVO00:CJIl01P000;1lV[1lVP0007aIWP0000JML9l2
00000Ye]V`060000cY:D00000000SefB000019YUT`030000YHjm000000;DViT00`0006TmRFTmR@02
JCf900@0001::HI::HH00003DBf600@000159HD000000004Qe>=00<0001`@h]`@h/00g13R`800005
m/2B00D0003@TY7@TY7@TY4000000X5AS`030000Oe2@Oe2@009oD9000`0008mMTXmMTP03SefB00<0
002RK9BRK9@00Z9/U0040000NTnB0000000018mZY0030000U6JJU6JJ00:DIYX00`0009ASUYASUP02
U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000:A/TZA/TP03Y6bB0P0000FCHYH0
0`0009Q_X`000003SfjY00<0002DIibDIi`00YAWW0030000TfBHTfBH00:CI9P00`0009=RUY=RUP02
Tf:F00<0002DHiJDHiH00P000003U6>F0000UFBF00>EI9H00`0009UVUYUVUP03VFJF00<0002NJiJN
JiH00Yi[UP030000U6:D000000FCHI@0100009=RUI=RU@0000GQ[9h0100008Y/ZhY/ZhY/Z`<00000
0iicX@0000000002Z<3[0P0000:X`>/00`000:S0jjS0j`02Z<3[0P0000Goool00`000?ooooooo`07
oooo000Ioooo0P0003_oool00`000>JeXNJeX@02i[FQ00@0003fdZSfdZP00006kL>Y0`0000;W]J00
0`0009j8_0000003BCJH1@0000=I=8X2000000BeRJL00000003jgG`2000000B0EYH0001T@I800004
IdFF0P00009nCi04000000=EO=`0003OYYT00]nVV@050000lKnLlKnLlKnL000000CR[j400`000;V2
VKV2V@03^H:I00D0003eaIceaIceaI`000000UlhR`<00004`hND00@0002PIhl000000002TF6F00@0
002SK9>SK9<00002`8FD00<0002JHhnJHhl00iYSS`030000Xf^BXf^B00:SJi8200000i=YW`030000
/7bJ0000009lFIh00`0009e`Wie`W`04WG2O00H0002MKI^MKI^MKI/0003>TY@2000000>?GI80002J
II<00YYUT`070000YHjmYHjmYHjm0000e9^I000000AY?HT0100004XYQTXYQP0000=A;HH0100004DU
Q@00000000B7Dhd00`000713Rg13R`03L4>;0P0000Gf`98010000=2BTM2BT@0000>1DHl00`0007m@
T7m@T002Oe2@00<0002?GI:?GI800hmMTP030000XVbDXVbD00:RK9@0100007Y?TWY?TP0000B?JZ@0
0`0009AVVYAVVP02U6JJ00<0002DHiJDHiH00YASUP030000VVNEVVNE00>JIiD00`000;5gT[5gTP02
/GNB00<0002TK9:TK9800jA/TP800005Tf:F00<0002HKj<000000hm^Z@030000U6NLU6NL00:DIi`0
0`0009=TV9=TV002TfBH00<0002CHYJCHYH00i=RUP030000U6>FU6>F00:DHiH00`0009ETUYETUP02
UFBF00<0002IIYJIIYH00iUVUP030000WV^FWV^F00:NJiH00`0009ARU0000005Tf6D00@0002CHYFC
HYD00005hJbN00D0002:K:/00000003kf7@00P0000:NLj4300001:S0j`030000Z<3[Z<3[00800002
Z<3[00<0003oooooool00_ooo`030000oooooooo00Ooool001_oool00`000?ooooooo`0ioooo00@0
003V]J7V]J400003m]:X00<0003]`jW]`jT00ng3Z@800004ikFP00<0002NR;`000000TTfV0@00000
0`00J`0005TdRP02FCB:0P000004]HVW00000000n]el1000009T@I800`0006M5UVM5UP02IdFF00<0
001nCi1nCi000`000003:aZ80000000000?OYYT01@000?6oW?6oW?6oW0000003hZnQ0P0000FiPYT0
0`000?G5W?G5W00200000elhR`800004`hND00<0002PIhl000000P000005TF6F0000XfbCXfbC0000
00;0QI@00`0009YSSiYSS`03VV>?00<0002SJi:SJi800Z=[TP@000000i=YW`0000000003O5VN00<0
002ML9nML9l019e`W`070000WFfKWFfKWFfK0000cY:D000000:?GI80100009YUTiYUT`0000BUS[d0
0`000=BKV@000004JCf900<0001::HI::HH00P00009A;HH0100004DUQ@00000000B7Dhd00`000713
Rg13R`03L4>;00<0003f`9;f`9801?K0TP040000d9:Ad9:A0000185AS`050000Oe2@Oe2@Oe2@0000
00F?GI800`000:9/U:9/U002XVbD00<0001jCi9jCi800P0000>?JZ@00`0009AVVYAVVP02U6JJ00<0
002DHiJDHiH00YASUP030000VVNEVVNE00>JIiD00`000;5gT[5gTP03/GNB00<0002TK9:TK9800ZA/
TP030000QUNB000000FCHYH200000hm^Z@030000U6NLU6NL00:DIi`00`0009=TV9=TV002TfBH00<0
002CHYJCHYH00i=RUP030000U6>FU6>F00:DHiH00`0009ETUYETUP02UFBF00<0002IIYJIIYH019UV
UP070000WV^FWV^FWV^F0000U6:D000000FCHI@2000000>CHYD0003Q[9h01>6/WP8000000iUXU`00
0?_HM002000019icX@040000Z<3[Z<3[Z<3[100000BX`>/00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`007?ooo`030000oooooooo03Woool00`000>JeX@000002m]:X00<0003]`jW]`jT00^g3
Z@8000000l:/a0000>NeX004ikFP00@0002NR;`00019=YP3000000<k@Jh0000000000eTdRP800000
0kF9Y`000?[MO00500000VA1TP080000IdFFIdFFIdFF0000im5H0000OTn@0P00008[6XP01@0005El
g0000=nVV@000003lKnL00<0003R[j7R[j400^:_X@800005^H:I00<0003eaIceaI`00P0000=O>8/2
00001<>7U0030000X6N?000000800000195QUP000:=/T`0000?0QI@00`0009YSSiYSS`03VV>?00<0
002SJi:SJi800Z=[TP040000lK:9lK:9lK:90`0000=lFIh00`0009e`Wie`W`04WG2O00<0002MKI^M
KI/00Ye]V`800002SefB00<0002JII<000000P0000>US[d00`000=BKV@000004JCf900<0001::HI:
:HH00P00009A;HH0100004DUQDDUQ@0000B7Dhd00`000713Rg13R`03L4>;00<0003f`9;f`9801OK0
TP800005PE6?00D0001oD91oD91oD90000001HmMTP030000XVbDXVbD00:RK9@00`0007Y?TWY?TP02
00000hmZY0030000U6JJU6JJ00:DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000
/GNB/GNB00>aMi801@000:A/TZA/TZA/TP000002QUNB00<0002CHYJCHYH00i=RUP<00002SfjY00<0
002DIibDIi`00YAWW0030000TfBHTfBH00:CI9P00`0009=RUY=RUP03Tf:F00<0002DHiJDHiH00YAS
UP030000UFBFUFBF00>EI9H00`0009UVUYUVUP03VFJF00@0002NJiJNJiH00003U6:D00<0002CHIBC
HI@00Y=QU0030000Tf:E000000KQ[9h01`0009UXU`000?_HM00009Y^WP000005WW>Q0`0000>X`>/0
0`000:S0jjS0j`02Z<3[0P0000?oool00`000?ooooooo`07oooo000Moooo00<0003oooooool0>?oo
o`800002m]:X0`0000;]`jT01@000<:/a<:/a<:/a0000005ikFP00L0002NR;`00000003_`:40002O
Ok400`0000=I=8X2000000>eRJL0003jgG`0100000=T@I80100006M5UVM5UVM5UPL00002:aZ80P00
0003gjJI0000lKnL00;a_i`00`000>:_XN:_X@02hZnQ0P0000FiPYT00`000?G5W?G5W00200000elh
R`800004`hND0`000003om660000000000800004`8FD00<0002JHhnJHhl00iYSS`030000Xf^BXf^B
00:SJi800`000?6bRO6bR@03lK:900<0001lFIilFIh00WaIWP030000WG2OWG2O00:ML9l00`0009e]
Vie]V`03WFfK0P0000:?GI801@0009YUT`000000I`000003YHjm00<0003DViT0000016TmR@050000
BRV6BRV6BRV60000009A;HH0100004DUQDDUQ@0000B7Dhd00`000713Rg13R`03L4>;00<0003f`9;f
`9801OK0TP800005PE6?00<0001oD91oD9000Wm@T0050000SefBSefBSefB000000FRK9@00`0007Y?
TWY?TP02000018mZY0050000U6JJU6JJU6JJ000000BDHiH00`0009YWUIYWU@03VVNE00<0002aMi:a
Mi800k5gTP050000Y6bBY6bBY6bB000000:6Ei800`0009=RUY=RUP03Tf:F00<0002/MYP000000Xm^
Z@030000U6NLU6NL00>DIi`01@0009=TV9=TV9=TV0000005Tf:F00<0002DHiJDHiH00YASUP030000
UFBFUFBF00>EI9H00`0009UVUYUVUP03VFJF00@0002NJiJNJiH00003U6:D00<0002CHIBCHI@00Y=Q
U0030000Tf:E000000GQ[9h2000000JIJ9L0003kf7@0002JKYh00006WW>Q00<0002X`>^X`>/00ZS0
j`030000Z<3[Z<3[00800002Z<3[00@0003oooooool00009oooo000Noooo0P0003Woool300000_oo
o`<00003`Zc400<0003W]J3W]J000nNeX0030000k]:g000000800002kl2Q1@00009I=8X00`000;F9
YkF9Y`0600000fA1TP040000IdFFIdFFIdFF1@000004im5H0000:aZ8:aZ80P000003gjJI0000lKnL
00;a_i`01`000>:_XN:_XN:_X@0007YHW`000004^H:I00L0003eaIceaIceaI`0002=GI@000000elh
R`030000`hND`hND00;3Qi@200000_oAQP030000KDVF000000G0QI@00`0009YSSiYSS`02VV>?0P00
00BSJi800`000?6bRO6bR@03lK:900<0001lFIilFIh00WaIWP040000WG2OWG2OWG2O0P0000FMKI/2
00000XmMTP8000000`40M00000000003YHjm00<0003DViT0000016TmR@050000BRV6BRV6BRV60000
009A;HH00`0004DUQDDUQ@0300000XMCS@040000L4>;L4>;L4>;0`0000Of`9800`000;^1U0000004
PE6?00<0001oD91oD9000Wm@T0040000SefBSefBSefB0P0000FRK9@0100007Y?TWY?TP0000B?JZ@0
1@0009AVVYAVVYAVVP000005U6>F00<0002JIiFJIiD00YYWU@030000/GNB/GNB00>aMi801@000:A/
TZA/TZA/TP000002QUNB00<0002CHYJCHYH00i=RUP040000[7JH[7JH00000Xm^Z@030000U6NLU6NL
00:DIi`01@0009=TV9=TV9=TV0000005Tf:F00<0002DHiJDHiH00YASUP030000UFBFUFBF00>EI9H0
0`0009UVUYUVUP03VFJF00@0002NJiJNJiH00003U6:D00<0002CHIBCHI@00Y=QU0040000Tf:E0000
00001>6/WP80000019UXU`000?_HM00000:JKYh00`0009icXIicX@03WW>Q00@0002X`>^X`>^X`>/4
00001:S0j`050000oooooooooooo000000Soool0023oool00`000?ooooooo`0loooo00<0002KT/X0
00000/:/a0030000ikFPikFP00?W]J0010000>kB]`00000000?_`:401@0009mo/@00000009mo/@03
00000[F9Y`H00003I46B00@0001WAIIWAIIWAIH3000000Y;=iP0003WdEP0000[6XP0002cP9d0003O
YYT00002lKnL00<0003R[j7R[j400^:_X@030000NURO000000BiPYT010000?G5W?G5W00000:=GI@0
100005lhRelhRelhR`<00002`hND0P0000;odHH00`0006e9UP000005`8FD00<0002JHhnJHhl00YYS
S`800004Xf^B00<0003a/XWa/XT00o6bR@030000O5VNO5VN009lFIh01P0009e`Wie`W`0008YQW000
00FMKI/00`0008mMTP00000200000`40M0800002YHjm00<0003DViT0000016TmR@040000BRV6BRV6
BRV60P000003DBf60000ABF500959HD00`0001@=Q@000005000000AO?i@0000S89@00005m/2B0P00
0003^h6D0000PE6?00>1DHl00`0007m@T7m@T002Oe2@00@0002?GI:?GI:?GI8200001J9/U0040000
NTnBNTnB000018mZY0050000U6JJU6JJU6JJ000000FDHiH00`0009YWUIYWU@03VVNE00<0002aMi:a
Mi800[5gTP050000Y6bBY6bBY6bB000000:6Ei800`0009=RUY=RUP03Tf:F00@0002/MYR/MYP00002
SfjY00<0002DIibDIi`00YAWW0030000TfBHTfBH00:CI9P00`0009=RUY=RUP02Tf:F00<0002DHiJD
HiH00iASUP030000UFBFUFBF00:EI9H00`0009UVUYUVUP03VFJF00@0002NJiJNJiH00003U6:D00<0
002CHIBCHI@00i=QU0@00002hJbN00@0002IIiH0002IJ9L200000iY^WP030000WW>QWW>Q00>NLj44
00000jS0j`040000Z<3[Z<3[Z<3[0`0000;oool00`000?ooooooo`06oooo000Qoooo00<0003ooooo
ool0??ooo`800002`Zc400<0003W]J3W]J000^NeX0030000k]:gk]:g00800003kl2Q00<0002OOk40
00000Ymo/@<000001KF9Y`000000000004EPb@0300000fA1TP040000IdFFIdFFIdFF0P00000300F;
0000BcNH00@000000k>0W@0000000003lKnL00<0003R[j7R[j400^:_X@030000NURO000000BiPYT0
10000?G5W?G5W00000:=GI@0100005lhRelhRelhR`80000016mDXP000000000000?odHH00`0006e9
UP000005`8FD00L0002JHhnJHhnJHhl0003NXiH000001:=[TP030000lK:9lK:900Ca/XT200000WaI
WP030000WG2O000000::HI`00`0009e]Vie]V`03WFfK0P000004PUNF000000000@1d0P000003o]b:
00000000008000000mBKV@0006TmR@03JCf900@0001::HI::HI::HH2000000=A;HH000159HD00dDU
Q@04000050f50000000015loU00300008b2D000000;f`98300000k^1U0030000PE6?PE6?00:1DHl0
0`0007m@T7m@T002Oe2@00@0002?GI:?GI:?GI8200001J9/U0040000NTnBNTnB000018mZY0030000
U6JJU6JJ00:DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi80
10000:A/TZA/TP0000>6Ei800`0009=RUY=RUP03Tf:F00L0002/MYR/MYR/MYP0002?KZT0000019AW
W0030000TfBHTfBH00:CI9P00`0009=RUY=RUP02Tf:F00<0002DHiJDHiH00iASUP030000UFBFUFBF
00:EI9H00`0009UVUYUVUP03VFJF00<0002NJiH0000019ARU0030000Tf6DTf6D00>CHI@00`000<C:
C<C:C002000000GQ[9h0002IIiH0002IJ9L00P0000>JKYh00`0009icXIicX@04WW>Q0P0000BX`>/4
00000jS0j`030000oooo000000Soool002;oool00`000?ooooooo`0loooo0P000003`Zc40000ikFP
00?W]J000`000>kB]`000005kl2Q00D0002OOk6OOk6OOk4000000^;kdP030000]HVW000000800000
1DEPb@0000000?[MO0000002I46B00<0001WAIIWAIH00`00000300F;0000BcNH00@00002/h2M00D0
003a_ica_ica_i`000001>:_X@040000NURONURO00000[V2V@050000mLFLmLFLmLFL000000:=GI@0
0`0005lhRelhR`0300000VmDXP800003om6600<0001]BIH000001L25U0070000VV>?VV>?VV>?0000
gZ>F000000>SJi800`000=:FU@000006lK:91@0000>:HI`00`0009e]Vie]V`03WFfK00@00022EiJ2
EiJ2EiH2000000FoZad0003ng8[ng8X000000Wo8oP800004JCf900@0001::HI::HI::HH2000000=A
;HH000159HD00dDUQ@04000050f50000000015loU00300008b2D8b2D00800002YL?_00D0002kPIBk
PIBkPI@00000185AS`030000Oe2@Oe2@009oD900100008mMTXmMTXmMTP800005XVbD00<0001jCi9j
Ci800P0000>?JZ@00`0009AVVYAVVP02U6JJ00<0002DHiJDHiH00YASUP030000VVNEVVNE00>JIiD0
0`000;5gT[5gTP02/GNB00@0002TK9:TK9800003QUNB00<0002CHYJCHYH00i=RUP070000[7JH[7JH
[7JH0000SfjY000000BDIi`00`0009=TV9=TV002TfBH00<0002CHYJCHYH00i=RUP030000U6>FU6>F
00:DHiH00`0009ETUYETUP02UFBF00<0002IIYJIIYH019UVUP800004U6:D00<0002CHIBCHI@00i=Q
U0030000a<Y<a<Y<00<00003VFNF0`0000>JKYh00`0009icXIicX@04WW>Q0P0000:X`>/200000ZS0
j`030000Z<3[Z<3[00:X`>/00`000?ooo`000008oooo000Soooo00<0003oooooool0??ooo`800004
ikFP00@0003^d[O^d[L00005kl2Q00@0002OOk6OOk400003h__B00D0002eRJL000000029KZh00`00
0005n]el0000I46BI46B0000009WAIH3000000@01H/0001;=iQ;=iP300000k>0W@<00004hZnQ00D0
001jF9mjF9mjF9l000000[V2V@050000mLFLmLFLmLFL000000:=GI@00`0005lhRelhR`0300000VmD
XP030000om66om6600?odHH200001L25U0070000VV>?VV>?VV>?0000gZ>F000000>SJi800`000=:F
U@000006lK:900<0001_@X/000000P0000B:HI`0100009e]Vie]Vie]V`800004PUNF00<0002oZad0
00000okLRP@00004JCf900@0001::HI::HI::HH2000000=A;HH000159HD00dDUQ@04000050f50000
000015loU00700008b2D8b2D8b2D0000YL?_000000BkPI@00`00085ASh5AS`02PE6?00<0001oD91o
D9000Wm@T0030000SefBSefB00<00005XVbD00D0001jCi9jCi9jCi8000000hmZY0030000U6JJU6JJ
00:DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi8010000:A/
TZA/TP0000>6Ei800`0009=RUY=RUP03Tf:F00<0002/MYR/MYP00ZafV0800004U6NL00<0002CI9RC
I9P00Y=TV0030000Tf:FTf:F00>CHYH00`0009ASUYASUP02U6>F00<0002EI9JEI9H00YETUP030000
VFJFVFJF00BIIYH2000019ARU0030000Tf6DTf6D00>CHI@01P000<C:C<C:C0000>6/WP0000>IIiH3
00000iY^WP030000WW>QWW>Q00BNLj40100001LMU`00000000BX`>/010000:S0jjS0jjS0j`@00008
oooo000Toooo0P0003goool00`000>NeX>NeX002ikFP00@0003^d[O^d[L00005kl2Q0P000003Wgna
0000h__B00;Rnm8300000XU^[P8000000`00P@0000000002I46B00<0001WAIIWAIH00`00000400F;
0000BcNHBcNH0`0000BcP9d200001>:_X@050000NURONURONURO000000:iPYT010000?G5W?G5W000
00>=GI@00`0005lhRelhR`0300000VmDXP030000om66om6600?odHH200001L25U0040000VV>?VV>?
00000]jSUP040000Xf^BXf^B00000]:FU@800005lK:900D0001_@X/0002kQid0000018YQW0040000
WFfKWFfKWFfK0P0000B2EiH200001?kLRP0400007QR=0000000016TmR@030000BRV6BRV6009::HH3
000014DUQ@03000050f550f500800004GcnD00@0000S89@S89@S89@200001;^1U0030000PE6?PE6?
00:1DHl00`0007m@T7m@T002Oe2@00H0002?GI:?GI80003][HX00005XVbD00D0001jCi9jCi9jCi80
00000hmZY0030000U6JJU6JJ00:DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000
/GNB/GNB00:aMi8010000:A/TZA/TP0000>6Ei800`0009=RUY=RUP02Tf:F00<0003DUi@000000jaf
V0800004U6NL00<0002CI9RCI9P00Y=TV0030000Tf:FTf:F00>CHYH00`0009ASUYASUP02U6>F00<0
002EI9JEI9H00iETUP030000VFJFVFJF00>IIYH200001IARU0030000Tf6DTf6D00:CHI@01`000<C:
C<C:C<C:C00009UWUP000002VFNF0`0000BJKYh00`0009icXIicX@02WW>Q00D0003oool0000G7IL0
00001:S0j`@00003Z<3[00<0003oooooool01_ooo`009_ooo`030000oooooooo03_oool010000>Ne
X>NeX00000;^d[L00`000>o0XNo0X@04kl2Q0`000004h__B00000000h__B0`000005RFj^00000000
0000002100800002I46B00@0001WAIIWAIH00002WFVE0P00009;=iP00`0008ib/0000004/h2M00<0
002SMj8000000n:_X@050000NURONURONURO000000:iPYT010000?G5W?G5W00000>=GI@0200005lh
RelhR`0009=n^P0006mDXP0000KodHH200001L25U0040000VV>?VV>?00000]jSUP040000Xf^BXf^B
00000]:FU@800005lK:90P0000:kQid00`0008YQW8YQW002RV6L00<0002MKI^MKI/00`0000B2EiH2
000000?ng8X0003ng8X00_kLRP<00004JCf900<0001::HI::HH00TXYQP<00004ABF500<0000D3HDD
3HD00P0000AO?i@00`0002<PU2<PU00300001;^1U0030000PE6?PE6?00:1DHl00`0007m@T7m@T002
Oe2@00H0002?GI:?GI80003][HX00005XVbD00<0001jCi9jCi800WY?TP050000SfZTSfZTSfZT0000
00>DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000:A/
TP000005QUNB00L0002CHYJCHYJCHYH0003DUi@000001:afV0800003U6NL00<0002CI9RCI9P00Y=T
V0030000Tf:FTf:F00>CHYH00`0009ASUYASUP02U6>F00<0002EI9JEI9H00iETUP030000VFJFVFJF
00>IIYH200001IARU0050000Tf6DTf6DTf6D000000;4bT`3000000BIIiH0002IIiJIIiH3000019Y^
WP030000WW>QWW>Q00:NLj400`000?ooooooo`0200000ZS0j`8000000jS0j`000:S0j`03Z<3[0P00
00Soool002Ooool00`000?ooooooo`0joooo0P000005ikFP0000k]:gk]:g000000K_`:47000000CR
nm800029KZj9KZh3000000<00840000000000VA1TP040000IdFFIdFF00000YeYU@800002BcNH00<0
002>L[0000001;>0W@030000XgNR000000;R[j4200000gYHW`030000^H:I000000?eaI`01@0008eM
U8eMU8eMU0000002GcR;00D0002CO[X0001_E:8000001_oAQP030000KDVF000000C0QI@0100009YS
SiYSS`0000;NXiH00`000:=[TP000003dYJE00<0000006L000001?6bR@800002^hNM00<0002:HIb:
HI`00XYQW0060000WFfK00000000_HFH0000189GUPD00002o]b:0`0000AY?HT00`0004XYQTXYQP02
BRV60P000003DBf60000ABF500959HD00`0001@=QA@=Q@0200000eloU0@000000d<[SP0000000004
^h6D00<00021DHn1DHl00X5AS`030000Oe2@Oe2@009oD9001P0008mMTXmMTP000>f]RP0000FRK9@0
0`0007Y?TWY?TP02NTnB00D0002?JZB?JZB?JZ@000000iAVVP030000U6>FU6>F00:DHiH00`0009YW
UIYWU@03VVNE00<0002aMi:aMi800k5gTP800005QUNB00L0002CHYJCHYJCHYH0003DUi@000001:af
V0800004U6NL00D0002CI9RCI9RCI9P000001I=RUP030000U6>FU6>F00:DHiH00`0009ETUYETUP03
UFBF00<0002IIYJIIYH00YUVUP030000UV>D000000FDHY@0100009=QU9=QU9=QU0<000000iUWUP00
09UWUP02VFNF00D0002IIiH0002JKId0000019Y^WP050000WW>QWW>QWW>Q000000Coool300001:S0
j`060000Z<3[00000000oooo00002?ooo`00:?ooo`030000oooooooo03[oool200000nkB]`030000
kl2Qkl2Q00?_`:4200000hQ][@050000=d6`0000h__B000000:9KZh010000>S6]0000000P@800002
I46B00@0001WAIH000000002WFVE0P000005BcNH00000000SW:`000000BcP9d020000:=gXZ=gXP00
0>:_X@000:=gXP00009jF9l00`000;V2V@000003mLFL00L0002=GIB=GIB=GI@0001O>8/000000Y=n
^P040000KeBR0000om660P0000?odHH00`0006e9UP000004`8FD00T0002JHhl0003JWY@0003NXiH0
002SJi8000000m:FU@030000001W000000800002lK:90P0000>kQid200000XYQW0@00002_HFH00@0
0022EiJ2EiJ2EiH2000000FJL:400027F9<0003ng8X00`0000AY?HT00`0004XYQTXYQP02BRV60P00
0003DBf60000ABF500959HD01P0001@=QA@=QA@=Q@0005loU0<0000014d/R00004<[ST<[SP800004
^h6D00<00021DHn1DHl00X5AS`030000Oe2@Oe2@009oD9001P0008mMTXmMTP000>f]RP0000FRK9@0
0`0007Y?TWY?TP03NTnB00@0002?JZB?JZ@00003U6JJ00<0002DHiJDHiH00YASUP030000VVNEVVNE
00>JIiD00`000;5gT[5gTP03/GNB0P0000F6Ei801`0009=RUY=RUY=RUP000=BGU0000005[7JH00<0
002DIibDIi`00YAWW0050000TfBHTfBHTfBH000000FCHYH00`0009ASUYASUP03U6>F00<0002EI9JE
I9H00YETUP030000VFJFVFJF00:IIYH00`0009ISU0000005U6:D00D0002CHIBCHIBCHI@000000iUW
UP030000VFNFVFNF00:IIiH2000000>JKId0002JKYh00iY^WP040000WW>QWW>Q00001_ooo`800002
Z<3[100000Coool00`000?ooooooo`05oooo000Yoooo0P0003_oool2000000?^d[L0003_`:401>o0
X@040000jnK:jnK:00000hQ][@@000001XU^[P000>S6]>S6]0000000P@800003I46B0P0000>MJID2
000000E;=iP00000002>L[0000000k>0W@800002XgNR00D0003R[j40002SMj8000000WYHW`030000
^H:I000000;eaI`00`0008eMU8eMU002SEfD00<0001O>8/000000Y=n^PD0000019Y/W00000000?oA
QP<00004`8FD00H0002JHhl0003JWY@0003NXiH200001=:FU@030000001W001W00D000001TdgUP00
0;^7WK^7W@0008aLT`H00002_HFH00@00022EiJ2EiJ2EiH400000XMHT`<000000mBKV@0006TmR@02
JCf900<0001::HI::HH00TXYQP040000001c000000000dDUQ@04000050f550f550f50P000005VkO[
00000000CBb800000093:hh200001;^1U0030000PE6?PE6?00:1DHl00`0007m@T7m@T002Oe2@00H0
002?GI800000003][HX00005XVbD00<0001jCi9jCi800gY?TP040000SfZTSfZT00000iAVVP030000
U6>FU6>F00:DHiH00`0009YWUIYWU@03VVNE00<0002aMi:aMi800k5gTP<00004QUNB00L0002CHYJC
HYJCHYH0003DUi@000001JafV0030000U6NLU6NL00:DIi`00`0009=TV9=TV002TfBH00<0002CHYJC
HYH00Y=RUP030000U6>FU6>F00>DHiH00`0009ETUYETUP02UFBF00D0002IIYJIIYJIIYH000000YIS
U0030000U6:DU6:D00>DHY@0100009=QU9=QU00000FIIiH0100009UWUYUWUYUWUP800002VVfM00D0
002JKYjJKYjJKYh000000YicX@030000oooooooo00Goool300002?ooo`030000oooooooo00Goool0
02_oool00`000?ooooooo`0joooo0`0000?_`:401@000>_Vb^_Vb^_VbP000003R6f]00H0000g@K00
00000029KZh00002j<Jd1@00009T@I8200000YeYU@030000bK/d000000800002SW:`00L0002cP9fc
P9fcP9d0001/D:0000000Z=gXP030000XgNRXgNR008000000gYHW`0000000003mLFL00<0002=GIB=
GI@00XeMU0050000GcR;00000000Tgjj00D00003VVbL0P000003[WNE0000`8FD00?0QI@200000mZN
U0<00004dYJE00<0000006L006L00P0000=79H<200000[^7W@040000S5bCS5bCS5bC0P000005o/ia
0000_HFH_HFH000000>2EiH0100009Y`X@00000000>7F9<2000000?DViT0001Y?HT00VTmR@030000
BRV6BRV6009::HH010000000L`00000000A59HD0100001@=QA@=QA@=Q@<00003CBb800@00013:hh0
00000004^h6D00<00021DHn1DHl00X5AS`030000Oe2@Oe2@009oD9001P0008mMTP0000000>f]RP00
00FRK9@00`0007Y?TWY?TP02NTnB0`000003SfZT0000U6JJ00:DIYX00`0009ASUYASUP02U6>F00<0
002JIiFJIiD00iYWU@030000/GNB/GNB00>aMi800`000<B7TP000004QUNB00L0002CHYJCHYJCHYH0
003DUi@000001JafV0800003U6NL00<0002CI9RCI9P00Y=TV0030000Tf:FTf:F00>CHYH00`0009AS
UYASUP02U6>F00<0002EI9JEI9H00YETUP050000VFJFVFJFVFJF000000>FHi@00`0009ARU9ARU002
U6:D00@0002CHIBCHI@00005VFNF00@0002IIiJIIiJIIiH200000YY]W@030000VVjNVVjN00:JKYh2
00004oooo`030000oooooooo00Goool002coool00`000?ooooooo`0koooo100000C[i/X01@0008Q]
[HQ][HQ][@000002=d6`0`0000;Xa[@300000YQ^X0040000I46B000000000YeYU@030000bK/d0000
00<000000hib/0000;>0W@02/h2M00<0001/D:0000000Z=gXP060000XgNR0000o>BK0000NURO0P00
00?eaI`00`0008eMU8eMU002SEfD00<0001O>8/000001@000003Sf>K0000VVbL00>JK9`00`000:ig
U@000004`8FD0P0000?JWY@300001=:FU@050000001W0000`8JF000000=79H<01@0004dgUP000;^7
W@000004S5bC0`0000:mQIP01P00089GUX9GUX9GUP0009Y`X@800005QeRC0P0000=Y?HT00`0004XY
QTXYQP03BRV60`0000A59HD0100001@=QA@=QA@=Q@<00003CBb800@00013:hi3:hh00004^h6D00<0
0021DHn1DHl00h5AS`030000Oe2@Oe2@009oD903000000?][HX0002RK9@01:9/U0030000NTnBNTnB
009jCi83000000>?JZ@0002DIYX00YAVVP030000U6>FU6>F00>DHiH00`0009YWUIYWU@03VVNE00<0
002aMi:aMi800[5gTP030000a8NB000000B6Ei801`0009=RUY=RUY=RUP000=BGU0000006[7JH0P00
00:DIi`00`0009=TV9=TV002TfBH00<0002CHYJCHYH00i=RUP030000U6>FU6>F00:DHiH00`0009ET
UYETUP02UFBF00@0002IIYJIIYH00004UV>D00<0002DHYBDHY@00YARU0050000Tf6D0000W6VF0000
00BIIiH0100009UWUYUWUP0000:JKId00`0009Y]W@000004VVjN0P0001?oool00`000?ooooooo`05
oooo000]oooo00<0003oooooool0>_ooo`0400000023000000001>_VbP050000R6f]R6f]R6f]0000
008g@K0300000nS6]0800002V6jP00@0001T@I8000000002WFVE00<00039^c@000000`0000:>L[00
1P000;>0WK>0W@0006a@X00000BSMj800`000?cTVocTV`0300000oG5W0030000SEfDSEfD00:=GI@0
100005lhR`00000000:?Hi/2000000>?Hi/0002JK9`00iY/W0030000[WNE000000C0QI@200000mZN
U0<00004dYJE00D0000006L00030QYH000000dLUP`050000CCNF0000^hNM000000><G9<400000[f5
V0030000PUNFPUNF008000000iY`X@0000000005QeRC0P0000=Y?HT00`0004XYQTXYQP03BRV60`00
00A59HD0100001@=QA@=QA@=Q@<00003CBb800@00013:hi3:hh00004^h6D00<00021DHn1DHl00h5A
S`030000Oe2@Oe2@009oD903000000?][HX0002RK9@01J9/U0060000NTnBNTnBNTnB0000dINH0`00
00BDIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@030000/GNB/GNB00:aMi800`000<B7
TP000004QUNB00L0002CHYJCHYJCHYH0003DUi@000001ZafV0800002U6NL00<0002CI9RCI9P00Y=T
V0030000Tf:FTf:F00>CHYH00`0009ASUYASUP02U6>F00<0002EI9JEI9H00iETUP030000VFJF0000
00BFHi@00`0009ARU9ARU003U6:D0P000003W6VF0000VFNF00>IIiH0100009UWUYUWUP0000>JKId2
000019Y^WP030000oooooooo01;oool00`000?ooooooo`05oooo000^oooo0P0003_oool500000^_V
bP030000R6f]R6f]00:8KJd00`0003M1/3M1/00300000^S6]0040000V6jPV6jPV6jP0`0000>MJID0
0`000<Vk=<Vk=00300000Xib/0060000/h2M00000000K52P00001:=gXP030000o>BK000000<00002
mLFL0P0000B=GI@400000XmSV`040000Sf>KSf>K000019Y/W0030000[WNE000000C0QI@00`000=ZN
U=ZNU002fYjD00<0000006T000001=:FU@800002`8JF00D000179H=79H=79H<000000TdgUP800000
1XaLT`00000000000?k>L@0000>mQIP00`00089GUX9GUP02000000>JL:40000000001HMHT`800004
JCf900<0001::HI::HH00TXYQP030000i:^H000000A59HD0100001@=Q@00000000:mPYD01@0004d/
R4d/R4d/R0000002@b^>0P0000BkPI@00`00085ASh5AS`02PE6?00<0001oD91oD9000Wm@T0<00002
kJf:00<0002RK9BRK9@00j9/U0060000NTnBNTnBNTnB0000dINH0P000003SfZT0000U6JJ00:DIYX0
0`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@050000/GNB/GNB/GNB000000;4Qi800`0008IG
TXIGTP02QUNB00D0002CHYJCHYJCHYH000000]BGU0030000[7JH[7JH00>/MYP01@000:McV00009AW
W0000004TfBH00<0002CHYJCHYH00i=RUP030000U6>FU6>F00:DHiH00`0009ETUYETUP03UFBF0`00
00BFHi@00`0009ARU9ARU003U6:D0P000003W6VF0000VFNF00>IIiH0100009UWUYUWUP0000BJKId0
1@0009Y^WYY^WYY^WP00000Eoooo00<0003oooooool01Oooo`00<?ooo`030000oooooooo03Soool3
00000_ooo`030000jnK:000000B8KJd0100003M1/000000000:`XLP00`000>S6]0000002V6jP0P00
0003WFVE0000WFVE00:MJID01@000<Vk=00000000:b>]`02000000>>L[00002cP9d00P000003K52P
0000XgNR00:SMj801P000?cTVocTV`000>_9/`0000?eaI`2000018eMU0@00005Sf>K0P0000>JK9`0
0`000:igU@00000500001=ZNU0030000001Y001Y00800002dYJE0P0000;0QYH01@0004LUPdLUPdLU
P`000002CCNF10000004Qf:Q0000o/ia00000kf5V0080000PUNFPUNF0000VW2Q0000_HBG00001HMH
T`800004JCf900<0001::HI::HH00TXYQP030000i:^H000000959HD400001;f2U@050000CBb8CBb8
CBb8000000=3:hh200000k^1U0030000PE6?PE6?00:1DHl00`0007m@T7m@T002Oe2@0`0000;][HX0
0`000:9/U:9/U003XVbD00P0001jCi9jCi9jCi80003AUiP0002dNiD200000iAVVP030000U6>FU6>F
00:DHiH00`0009YWUIYWU@03VVNE00D0002aMi:aMi:aMi8000000/B7TP030000QUNBQUNB00:6Ei80
100009=RUY=RUP0000?DUi@00`000:afV:afV003[7JH00H0002WLiRWLiP0002DIi`00003TfBH00<0
002CHYJCHYH00i=RUP030000U6>FU6>F00:DHiH00`0009ETUYETUP03UFBF0`0000BFHi@00`0009AR
U9ARU003U6:D00@0002LJIJLJIH00004VFNF00@0002IIiJIIiH00004VVfM00D0002JKYjJKYjJKYh0
00005Oooo`030000oooooooo00Goool0037oool00`000?ooooooo`0loooo0P000003jnK:0000R6f]
00:8KJd200000k2Qb0800002j<Jd00@0002HKZ0000000005WFVE0P0000>/S[L2000000>>L[00002c
P9d00P000003K52P0000XgNR00:SMj800`000?cTV`000002jlVc1`0000>=GI@400001HmSV`800003
VVbL00D0002^MiF^MiF^MiD000000XEJV0030000fYjDfYjD00;JWY@00`000000J@00J@0500000l26
UP050000AbF3AbF3AbF30000009==iH2000000J4EiD00027HZ40003ncW400003_HFH00P00022EiJ2
EiH0002JL:40002mQ9L00005QeRC0P0000AY?HT0100004XYQTXYQTXYQP8000001>B[V00000000000
00;TZiP00`000;f2UKf2U@02_H:E00<0001=;8Q=;8P00Td/R0070000@b^>@b^>@b^>0000?SnZ0000
00:kPI@00`00085ASh5AS`02PE6?00<0001oD91oD9000Wm@T0800003kJf:00<0002RK9BRK9@00j9/
U0080000NTnBNTnBNTnB0000dINH0000]7^E0P0000>DIYX00`0009ASUYASUP02U6>F00<0002JIiFJ
IiD00iYWU@050000/GNB/GNB/GNB000000;4Qi800`0008IGTXIGTP03QUNB00<0002CHYH000000mBG
U0030000[7JH[7JH00>/MYP00`000:McV:McV00300000i=TV0030000Tf:FTf:F00>CHYH00`0009AS
UYASUP03U6>F00<0002EI9JEI9H00YETUP030000VVND000000BFHi@00`0009ARU9ARU003U6:D00@0
002LJIJLJIH00004VFNF00D0002IIiH0002MKid0000019Y]W@030000VVjN000001Koool00`000?oo
ooooo`05oooo000boooo00<0003oooooool0>oooo`8000001n_VbP0008Q][HQ][@0008jAdP000003
/:7800@0002OR;`0003Xa[@2000000>FL:@0002MJID00ieYU@800004[8jg0P000003SW:`0000/h2M
008000001Fa@X0000:=gXZ=gXP000002o>BK00<0003[bK?[bK<00^_9/`060000C3ZKC3ZK0000Yg:G
00000XeMU0@00005Sf>K0P0000>JK9`01@000:igUJigUJigU@000002QEZH00<0003JWYCJWY@00]ZN
U0060000001Y0000MDfD0000Y6jD0P0000?0QYH00`0004LUPdLUP`02AbF300<0001==iH000000XAG
U@050000Qf:Q0000o/ia000000>mQIP02000089GUX9GUP0009Y`X@000;f4U`0000F7F9<2000016Tm
R@040000BRV6BRV6BRV60`0000GTZiP00`000;f2UKf2U@02_H:E0P0000==;8P01`0004<[ST<[ST<[
SP0003hoZP000002^h6D00<00021DHn1DHl00X5AS`040000Oe2@Oe2@Oe2@0`0000?][HX00`000:9/
U:9/U003XVbD00@0001jCi9jCi800002dINH00@0002dNiFdNiD00003U6JJ00<0002DHiJDHiH00YAS
UP030000VVNEVVNE00>JIiD010000;5gT[5gTP0000?4Qi800`0008IGTXIGTP03QUNB00<0002CHYH0
00000mBGU0030000[7JH[7JH00>/MYP010000:McV00008ULUP800003TfBH00<0002CHYJCHYH00i=R
UP030000U6>FU6>F00>DHiH00`0009ETUYETUP0200000YYWU0030000UV>DUV>D00:FHi@00`0009AR
U9ARU002U6:D00D0002LJIJLJIJLJIH000001IUWUP8000000ie_W@0009Y]W@03VVfM0P0001Soool0
0`000?ooooooo`04oooo000coooo0P0003_oool00`0006mJZ`000004000000>>TM80002`XLP00[2Q
b0030000WhRl000000<000000iI`Y00009eYU@03WFVE0P0000B/S[L00`0006M:V`000002000000CD
f680001/D:000002XgNR00<0003li9/000001N_9/`030000C3ZK000000:WLYL2000000>=GI@00000
00000_G4V@030000Sf>KSf>K00:?Hi/200000iY/W0050000[WNE[WNE[WNE000000:5FYP00`000=ZN
U=ZNU002fYjD00L0000006T0001eCI@0002TKY@000001<26UP030000AbF3AbF300979H<00`0004dg
UP000002Q5NE00@00027HZ4000000004_HFH00P00022EiJ2EiH0002JL:40002mQ9L00005QeRC0P00
00AY?HT00`0004XYQTXYQP0400001NB[V0040000_H:E_H:E_H:E0`0000==;8P01@0004<[ST<[ST<[
SP000002?SnZ00<0002kPI@00000185AS`050000Oe2@00000000dYbL00800003kJf:00<0002RK9BR
K9@00j9/U0040000NTnBNTnB00000]6GV0040000]7^E]7^E00000iAVVP030000U6>FU6>F00:DHiH0
0`0009YWUIYWU@03VVNE00@0002aMi:aMi800003a8NB00<00026Ei:6Ei800hIGTP030000Tf:F0000
00?DUi@00`000:afV:afV003[7JH00<0002WLiP000000XULUP030000TfBHTfBH00:CI9P00`0009=R
UY=RUP03Tf:F00<0002DHiJDHiH00YASUP<00004VVND00<0002FHiBFHi@00YISU0050000U6:DU6:D
U6:D000000BLJIH00`0009UWUYUWUP03VFNF0P000003WFnM0000VVfM00>JKId200006?ooo`030000
oooooooo00Coool003Goool00`000?ooooooo`0ioooo0`0000;oool01P0008jAdXjAdP000;2Qb000
00:OR;`300000YI`Y0030000WFVEWFVE00:MJID300000Zb>]`030000IdZKIdZK00<000002MCHHP00
06a@X6a@X0000:=gXP000?cTV`000005jlVc00<0001<>Y/000000ZMbU`8000000heMU00000000002
mLBI00@0002?Hi^?Hi^?Hi/300000iY/W0060000[WNE[WNE[WNE0000QEZH0P0000CJWY@00`000000
J@000002000000>TKY@00030QYH00l26UP030000AbF3AbF300979H<00`0004dgUP000002Q5NE00@0
0027HZ4000000004_HFH00<00022EiJ2EiH00P0000>mQ9L00`0008MHThMHT`02QeRC0P0000AY?HT0
1`0004XYQP0009UdZ00009eYU@000006i:^H00@0002mPYD0000h88L200000dd/R0030000@b^>@b^>
0093:hh00`0003hoZShoZP0200000X5AS`@00003dYbL0P0000?][HX00`000:9/U:9/U003XVbD00@0
001jCi9jCi800002dINH00D0002dNiFdNiFdNiD000000YAVVP030000U6>FU6>F00:DHiH00`0009YW
UIYWU@03VVNE00@0002aMi:aMi800004a8NB00<00026Ei:6Ei800XIGTP030000Tf:F000000?DUi@0
0`000:afV:afV004[7JH0`0000:9G9H01@0009=TV9=TV9=TV0000005Tf:F00@0002DHiJDHiJDHiH2
000000>RKIH0002JIi@00iYWU0030000UV>DUV>D00>FHi@0100009ARU000000000FLJIH00`0009UW
UYUWUP02VFNF00@0002MKifMKid00004VVfM00<0003oool000005oooo`030000oooooooo00Coool0
03Koool00`000?ooooooo`0hoooo0P0000Coool01`0008jAdP000;2Qb00009n8_0000002jLZf00@0
002FL:BFL:@00004WFVE0`0000:/S[L00`0006M:VfM:V`03000000CDf6800000001/D:02000000?l
i9/0003gfG400P0000C[bK<200000ZMbU`030000n/F>000000800002mLBI00@0002?Hi^?Hi^?Hi/3
00000iY/W0030000[WNE[WNE00H00003fYjD0P000005MDfD00000000Y6jD000000C0QYH00`0004LU
PdLUP`02AbF300<0001==iH000000XAGU@040000Qf:Q000000001;f5V0030000PUNFPUNF00800003
_HBG00<00027F9>7F9<00XMHT`800004JCf90P0000:IM:P00`0009eYU@000006i:^H0`000003>227
0000000000==;8P00`0004<[ST<[SP02@b^>00<0000n?jXn?jX010000003kLR_0000dYbL00?BW9`0
0`000:QaU0000003kJf:00<0002RK9BRK9@00j9/U0040000NTnBNTnB00000]6GV0050000]7^E]7^E
]7^E000000:DIYX00`0009ASUYASUP02U6>F00<0002JIiFJIiD00iYWU@040000/GNB/GNB00001<B7
TP030000QUNBQUNB00:6Ei800`0009=RUP000003e9ND00<0002/MYR/MYP01:afV0<00003REbF0P00
0003TfBH0000Tf:F00BCHYH0100009ASUP00000000>RKIH00`0009YWU9YWU003VVND00<0002FHiBF
Hi@00YISU0050000U6:D0000XVjG000000BLJIH00`0009UWUYUWUP02VFNF00@0002MKifMKid00003
VVfM00D0003oooooooooool000005_ooo`030000oooooooo00Coool003Ooool00`000?ooooooo`0g
oooo00<0003oooooool01?ooo`H00002jLZf0P000003UW2T0000WFVE00>MJID01`0009mo/9mo/000
0:b>]`0006M:V`04000000CDf6800000001/D:0800000n_9/`800002Yg:G00<0003jaHkjaHh00P00
00;ea9T0100008mSVhmSVhmSV`<00003VVbL00<0002^MiF^MiD01P0000?JWY@2000000=eCI@0002K
J9H00P0000C0QYH00`0004LUPdLUP`02AbF300<0001==iH000000hAGU@800005_HFH00<00022EiJ2
EiH00P0000>mQ9L01`0008MHThMHThMHT`000?g3O`000004JCf90P0000:IM:P0100009eYU@000000
00GTZiP3000000<h88L00000000014d/R0050000@b^>@b^>@b^>0000008n?jX00`000>g8[ng8[`02
kLR_00<0003BW9cBW9`00]:LW0030000Z76D000000?][HX00`000:9/U:9/U003XVbD00@0001jCi9j
Ci800002dINH00<0002dNiFdNiD00[AkU@030000U6JJ000000BDHiH00`0009YWUIYWU@04VVNE0P00
00G4Qi800`0008IGTXIGTP02QUNB00<0002CHYH000000mBGU0030000[7JH[7JH00B/MYP00`000:5]
UP000004REbF0`0000>CHYH500001:9]UP030000VVNDVVND00>JIi@00`0009ISU9ISU002UV>D0P00
00:RKYL00`0009aYUYaYUP02W6VF00D0002IIiJIIiJIIiH0000019e_W@030000VVfM000000Goool0
0`000?ooooooo`0Coooo00<0003oooooool01?ooo`00>?ooo`800010oooo0`0000?Yb[H4000019eY
U@090000Wgn`Wgn`0000[8jg0000IdZK0000gK2Y008000001=CHHP00000006a@X0<000000oOIL@00
00000002m=IX00<0003[bK?[bK<00P0000:WLYL010000?[5S_[5SP0000?ea9T0100008mSVhmSVhmS
V`8000000jYiW@0009Y/W002VVbL00@0002^MiD000000002WfbF0P0000?JWY@300000Y]XUP800005
`8JF00L000179H=79H=79H<0001==iH000000hAGU@800005_HFH00<00022EiH000000P0000>mQ9L0
1P0008MHThMHThMHT`000?g3O`L00002VGBX00@0002MJIFMJID00003i:^H0`000005FcJ:0000>227
>227000000A=;8P01`0004<[ST<[ST<[SP0003hoZP000005kLR_00@0003BW9cBW9cBW9`2000000>X
LI@0003][HX00^f]RP030000XVbDXVbD00>RK9@0100007Y?TWY?TP0000;AUiP00`000;AkUKAkU@02
]7^E00<0002DIYX000001IASUP030000VVNEVVNE00>JIiD200001LB7TP030000QUNBQUNB00:6Ei80
0`0009=RUP000004e9ND00<0002/MYR/MYP00jafV0030000XFfF000000F9G9H700000k1kV@030000
XVfFXVfF00:RKIH00`0009YWU9YWU002VVND00<0002FHiBFHi@00`0000>RKYL00`0009aYUYaYUP02
W6VF00D0002IIiJIIiJIIiH0000019e_W@800006oooo00<0003oooooool04oooo`030000oooooooo
00Coool003[oool00`000?ooooooo`0ooooo0P0000;Yb[H400000ieYU@8000000imo/00000000004
000000?M/:T0000_68@00`000003K52P0000WFbI008000000l:=WP000?CFJ002m=IX100000:WLYL0
10000?[5S_[5SP0000?ea9T01P0008mSVhmSVhmSV`0009I]X@800003VVbL00@0002^MiD000000002
WfbF00D0002YMi`00000003JWY@00`0000:KJ9H200001L26UP040000AbF3AbF3AbF30`0000>4EiD2
00001Kf5V0050000PUNF0000VW2Q000000>mQ9L01@0008MHThMHThMHT`000002oL=o00T0002;FiB;
FiB;Fi@0002:GIP0002IM:P000000YeYU@D00004FcJ:00<0000h88L0000014d/R0030000@b^>@b^>
0093:hh200001Ng8[`080000dYbLdYbL0000^H2F0000Z76D00000nf]RP030000XVbDXVbD00>RK9@0
0`0007Y?TP000004dINH00<0002dNiFdNiD00[AkU@030000U6JJ000000BDHiH00`0009YWUIYWU@03
VVNE0P0000G4Qi800`0008IGTXIGTP02QUNB00<0002CHYH000001=BGU0030000[7JH[7JH00>/MYP0
0`000:5]UP000005REbF0P0000BlSJ@200000[1kV@030000XVfFXVfF00:RKIH0100009YWU9YWU9YW
U0@000000jYfV@000:9^U`03XVjG00<0002LJIJLJIH00YaYUP040000VFNFVFNF00001Ie_W@030000
oooooooo00Koool00`000?ooooooo`0Boooo00<0003oooooool01?ooo`00>oooo`030000oooooooo
043oool2000000BINZl0002INZl00003WFVE0P000003Wgn`0000^]AP00<00002gK2Y00<0000_68@0
00000P000003K52P0000WFbI008000001<:=WP000?CFJ?CFJ0D000000jMbU`000?[5SP02n/F>00D0
003ea9Wea9Wea9T000000XmSV`80000019I]X@000:YiW@0000:JK9`010000:igU@00000000:OK9H0
0`000:UgW:UgW00400000i]XUP800005`8JF00<000179H=79H<00TLUP`030000Q5NEQ5NE00:4EiD2
00001Kf5V0040000PUNF000000001;f4U`050000QeRCQeRCQeRC000000;m`gl02@0008]KU8]KU8]K
U00008YMV00009UdZ0000005WFVE0P0000AK=XX00`0003PPQcPPQ`0200000Td/R0030000@b^>@b^>
0093:hh00`000>g8[ng8[`05kLR_0P0000:iP9H00`000:QaU0000003kJf:00<0002RK9BRK9@00j9/
U0030000NTnB000000CAUiP00`000;AkUKAkU@02]7^E00<0002DIYX0000019ASUP030000VVNEVVNE
00>JIiD200001LB7TP030000QUNBQUNB00:6Ei800`0009=RUP000004e9ND00<0002/MYR/MYP00Zaf
V0040000XFfFXFfF00001HULUP030000_8fT_8fT00>lSJ@00`000<JGY`00000200001:9]UP030000
VVND000000800004ZWJI00<0002RKYNRKYL00Z9^U`030000W6VFW6VF00:LJIH00`0009UWUYUWUP02
00000Ye_W@80000:oooo00<0003oooooool04Oooo`030000oooooooo00Coool003coool00`000?oo
ooooo`10oooo00<0002INZl000000YUj[`050000WFVEWFVE0000Wgn`00H00002gK2Y00<0000_68@_
68@010000004WFbI0000000000000oCFJ0<000001:5o[`000:MbU`0000?jaHh01@000?G4VOG4VOG4
V@000002Sf>K00H0002FKJ6FKJ40002ZNId00002VVbL100000:OK9H01@000:UgW:UgW000000f]@02
00000i]XUP<00004`8JF00<000179H=79H<00TLUP`030000Q5NEQ5NE00:4EiD200001Kf5V0040000
PUNF000000001;f4U`050000QeRCQeRCQeRC000000;m`gl02@0008]KU8]KU8]KU00008YMV00009Ud
Z0000005WFVE00<0002BH9<000000e/fRP040000>227>227>22710000093:hh300001ng8[`800002
^H2F00<0002XLI@000000nf]RP030000XVbDXVbD00BRK9@200001=6GV0030000]7^E]7^E00>dNiD2
000019ASUP030000VVNEVVNE00:JIiD300001LB7TP030000QUNBQUNB00>6Ei800`000=BGU=BGU003
e9ND00<0002/MYR/MYP00ZafV0040000XFfFXFfF00001HULUP030000_8fT_8fT00BlSJ@00`000?gN
WogNW`0700000[Z7WP030000ZWJIZWJI00:ZMYT00`000:9^Uj9^U`02XVjG00<0002LJIJLJIH00iaY
UP8000001:AeW`000000000000coool00`000?ooooooo`0Boooo00<0003oooooool00oooo`00?Ooo
o`800010oooo0P0000>INZl01@0009eYUIeYU@0009mo/002000000B6J:X0000000000002gK2Y00<0
000_68@_68@01P000006`XfN0000m=IXm=IX0000e:RZ0P000004XGn_0000Yg:G00000_[5SP030000
mLBImLBI00;ea9T0100008mSVhmSV`0000:FKJ401@000:YiWJYiW@0009Y/W00400000Ym/UP060000
ZGNLZGNL000003Je000019]XUP<00004`8JF00<000179H=79H<00TLUP`030000Q5NEQ5NE00:4EiD2
00001[f5V0<00004_HBG00D00027F9>7F9>7F9<000000_g3O`030000Re^DRe^D00:;Fi@200000YUd
Z0030000WFVEWFVE00:MJID01000099PTi9PT`00009K=XX00`0003PPQcPPQ`02>2271P000004JgS>
0000000000000ng8[`<00003^H2F00<0002XLI@000000nf]RP030000XVbDXVbD00BRK9@200001=6G
V0030000]7^E]7^E00>dNiD2000019ASUP030000VVNE000000800002eI^H00<00034Qi;4Qi800lB7
TP030000QUNBQUNB00>6Ei800`000=BGU=BGU003e9ND00D0002/MYR/MYR/MYP000000j5]UP030000
REbFREbF00:9G9H200001[b=Y0<00003oMjO00<0002jQijjQih00kZ7WP030000ZWJIZWJI00:ZMYT0
0`000:9^Uj9^U`02XVjG00<0002LJIJLJIH00iaYUP@0000?oooo00<0003oooooool04Oooo`030000
oooooooo00?oool003ooool00`000?ooooooo`0moooo0P0000>INZl00`0009eYUIeYU@0400000XIX
ZP800002gK2Y00<0000_68@_68@01P000006`XfN0000m=IXm=IX0000e:RZ0P000004XGn_0000Yg:G
00000_[5SP030000mLBImLBI00;ea9T0100008mSVhmSV`0000:FKJ401@000:YiWJYiW@0009Y/W004
00000im/UP050000ZGNL000003Je000000BKJ9H00`000:A^U0000004`8JF00<000179H=79H<00TLU
P`070000Q5NEQ5NEQ5NE0000cIRO000000JmQIP300001;f4U`050000QeRCQeRCQeRC000000;m`gl0
0`0008]KU8]KU002Re^D0P0000:IM:P00`0009eYUIeYU@02WFVE00L0002BH9>BH9>BH9<0001K=XX0
000013PPQ`800004<R:>00<0001[N<i[N<h01@0000FiP9H00`000:QaU0000004kJf:00<0002RK9BR
K9@00j9/U0800004dINH00<0002dNiFdNiD00[AkU@<00002U6>F10000003[7BE0000eI^H00;EViP0
0`000<B7T/B7TP03a8NB00<00026Ei:6Ei800hIGTP030000e9NDe9ND00?DUi@01@000:afV:afV:af
V0000003XFfF00<00029G9J9G9H00XULUP800006_8fT100000;mgYl00`000;Z7W[Z7WP03^XNN00<0
002ZMYVZMYT00ZYfV@030000XVjGXVjG00>RKYL00`0009aYUYaYUP02W6VF00<0003oooooool04Ooo
o`030000oooooooo013oool00`000?ooooooo`03oooo0010oooo00<0003oooooool0?Oooo`050000
VGZ_VGZ_VGZ_000000:MJID500000hIXZP030000gK2Y0000008_68@500000/:=WP030000m=IX0000
00;DZ:X4000000FWLYL0003jaHkjaHh000001?G4V@040000Sf>KSf>K00000YI]X@030000ZWVMZWVM
00@000000m2V[P0009m/UP02WfbF00D0002YMi`00000=[D0000019]XUP030000Y6jD000000C0QYH0
1@0004LUPdLUPdLUP`000004Q5NE00@0003=V9o=V9l00005_HFH0`0000BmQ9L01@0008MHThMHThMH
T`000002oL=o00<0002;FiB;Fi@00X]KU0800002VGBX00<0002MJIFMJID00YeYU@030000TV2CTV2C
00:BH9<200000SPPQ`@00004<R:>00<0001[N<i[N<h00V]hcP<00005^H2F00<0002XLI@000001>f]
RP030000XVbDXVbD00>RK9@200001=6GV0030000]7^E]7^E00:dNiD00`000?K0T`00000200000m2C
T`030000[7BE000000?EViP00`000<B7T/B7TP04a8NB00<00026Ei:6Ei800XIGTP030000e9NDe9ND
00?DUi@00`000:afV:afV00200001:5]UP040000REbFREbF00000[21XP030000_8fT_8fT00:lSJ@0
2000081HVP0000000:j2Y@000?gNW`0000FjQih00`000:YfVJYfV@02ZWJI00<0002RKYNRKYL00j9^
U`040000W6VFW6VFW6VF0P0001Coool00`000?ooooooo`0?oooo00<0003oooooool00oooo`00@Ooo
o`030000oooooooo03coool01P0009Uj[iUj[iUj[`0009eYU@H00003QVRZ00D0003M/:WM/:T0000_
68@01@0000;2SIh01P000?CFJ0000=BXZP000?oFQP<000001JMbU`000?[5S_[5SP000004mLBI00<0
002?Hi/000000iI]X@030000ZWVMZWVM00@000000m2V[P0009m/UP02WfbF00D0002YMi`00000=[D0
000019]XUP030000Y6jD000000C0QYH01@0004LUPdLUPdLUP`000003Q5NE00D0003=V9o=V9o=V9l0
00001Kf5V0800005_HBG00D00027F9>7F9>7F9<000000_g3O`030000Re^DRe^D00:;Fi@01@0008YM
V00009UdZ0000004WFVE00<0002BH9>BH9<00Y9PT`@000000n^^S`000000000200000c8RSP030000
JgS>JgS>009[N<h300001KV0UP030000Z76D000000C][HX00`000:9/U:9/U003XVbD00<0003AUiSA
UiP00m6GV0030000]7^E]7^E00:dNiD00`000?K0T`000005d9>C00<0002/M9D000001=FKV0030000
a8NBa8NB00?4Qi800`0008IGTXIGTP02QUNB00<0003DUiCDUi@00mBGU0030000[7JH[7JH00800004
XFfF00<00029G9H000000k21XP030000_8fT_8fT00:lSJ@00`00081HVP000003[X:U00<0003mgYl0
00001;Z7WP030000ZWJIZWJI00>ZMYT00`000:9^Uj9^U`02XVjG00@0002LJIH00000000Foooo00<0
003oooooool03oooo`030000oooooooo00?oool004;oool20000?Oooo`050000VGZ_VGZ_0000WFVE
008000001;kAj0000000000000>6J:X2000000?M/:T0000_68@00P000007`XfN00000000`XfN0000
m=IX000000;DZ:X00`000?oFQ_oFQP0300000_[5SP030000mLBImLBI00Cea9T200000iI]X@030000
ZWVMZWVM00@000000m2V[P0009m/UP02WfbF00<0002YMibYMi`00P0000BKJ9H00`000:A^U0000004
`8JF00H000179H=79H<0001mDI<00002Q5NE00D0003=V9o=V9o=V9l000001Kf5V0800005_HBG00@0
0027F9>7F9<00003oL=o00<0002;FiB;Fi@00X]KU0050000RUfH0000VGBX000000BMJID00`00099P
Ti9PT`02TV2C00<0000o8hL000000^^^S`@00003<R:>00<0001[N<i[N<h00V]hcP<00005^H2F00<0
002XLI@000001>f]RP030000XVbDXVbD00>RK9@00`000=6GV=6GV003dINH00<0002dNiFdNiD00[Ak
U@030000m/2C000000K@Ti<200001=FKV0030000a8NBa8NB00?4Qi800`0008IGTXIGTP02QUNB00<0
003DUiCDUi@01=BGU0040000[7JH000000001:5]UP800004/86R00<0002lSJBlSJ@00[b=Y0<00003
[X:U00<0003mgYl000001KZ7WP030000ZWJIZWJI00:ZMYT010000:9^Uj9^Uj9^U`<0000Ioooo00<0
003oooooool03_ooo`030000oooooooo00?oool004Coool00`000?ooooooo`0joooo10000003WFVE
0000000000@00002QVRZ0`000007gK2Y00000000QVNX0000`XfN000000;2SIh00`000?CFJ0000002
e:RZ00<0003oeXKoeXH00`0000;jaHh00`000?G4VOG4V@04mLBI0P0000>FKJ400`000:YiWJYiW@04
000000?@YZh0002OK9H00Ym/UP030000ZGNLZGNL00800004VfRF00<0002TKY@000001<26UP060000
AbF3AbF30000OE6C00000XAGU@050000cIROcIROcIRO000000FmQIP200001Kf4U`040000QeRCQeRC
00000og3O`030000Re^DRe^D00:;Fi@01@0008YMV00009UdZ0000004WFVE00<0002BH9>BH9<00Y9P
T`030000?b>7000000?[[Xl30000138RSP080000JgS>00000000YgnX0000g:>I00001;V0UP800005
kJf:00<0002RK9BRK9@00j9/U0030000dINHdINH00?AUiP00`000;AkUKAkU@02]7^E00<0003f`9<0
00001]2CT`030000eI^HeI^H00?EViP00`000<B7T/B7TP03a8NB00@00026Ei:6Ei:6Ei8200001]BG
U08000000j9_V0000:5]UP03XFfF0P0000B`PJ8010000;b=Y;b=Y;b=Y08000000jAeWP000:j2Y@03
[X:U0P0000FjQih00`000:YfVJYfV@02ZWJI00@0002RKYL00000000Moooo00<0003oooooool03Ooo
o`030000oooooooo00?oool004Goool00`000?ooooooo`0ioooo00H0001`FJQ`FJP0002MJID00002
oooo0`0000:6J:X0100005aC[`000=f`Z@80000018IWZ0000<:=WP0000;2SIh200000mBXZP030000
omJ6omJ600<00002n/F>00<0003ea9Wea9T01?G4V@800003UVfQ00<0002ZNIfZNId00`0000?@YZh0
100009m/UYm/UP0000:YMi`2000019]XUP030000Y6jD000000C0QYH00`0004LUP`000002OE6C00@0
0024EiD000000003cIRO00<0002mQIRmQIP00kf5V0800005_HBG00@00027F9>7F9<00003oL=o00<0
002;FiB;Fi@00X]KU0050000RUfH0000VGBX000000BMJID00`00099PTi9PT`02TV2C00<0000o8hL0
00000n^^S`<00002<R:>100000>WOjP00`000=bSV@000004^H2F0P0000G][HX00`000:9/U:9/U003
XVbD00<0003AUiSAUiP01=6GV0070000]7^E]7^E]7^E0000m/2C000000K@Ti<00`000=FKV=FKV003
eI^H00<00034Qi;4Qi800lB7TP070000QUNBQUNBQUNB0000eZNW000000GDUi@2000000>RKiP0002Q
KIH00j5]UP030000/86R/86R00B`PJ8010000;b=Y;b=Y00000>TMIh010000:j2YJj2YJj2Y@@00003
^XNN00<0002ZMYVZMYT01000023oool00`000?ooooooo`0=oooo00<0003oooooool00_ooo`00A_oo
o`030000oooooooo03Soool01P00071IZ71IZ00009eYU@0000;oool300000XIXZP030000G5>_0000
00<000000hIWZ0000<:=WP03`XfN0P0000?DZ:X00`000?oFQP00000300000_[5SP030000mLBImLBI
00Cea9T200000iI]X@040000ZWVM0000TFBJ0P0000?@YZh0100009m/UYm/UP0000:YMi`2000019]X
UP040000Y6jDY6jD00000l26UP030000AbF30000009mDI<00`0008AGU@000004cIRO00<0002mQIRm
QIP00kf5V0800005_HBG00@00027F9>7F9<00003oL=o00<0002;FiB;Fi@00X]KU0050000RUfH0000
VGBX000000BMJID00`00099PTi9PT`03TV2C0P0000?[[Xl5000000>QOJ`0002WOjP00jMoZ0040000
g:>Ig:>I00001KV0UP030000kJf:kJf:00?][HX00`000:9/U:9/U002XVbD0P0000KAUiP010000;Ak
UKAkU@0000;f`9<00`000=2CTm2CT`04d9>C00<0003EViSEViP00mFKV0030000a8NBa8NB00?4Qi80
1`0008IGTXIGTXIGTP000=JWY`000005e9ND00@0002RKiRRKiP00003XFfF0P0000J`PJ8010000;b=
Y;b=Y00000>TMIh01@000:j2YJj2YJj2Y@000003o]f71P0002Coool00`000?ooooooo`0=oooo00<0
003oooooool00_ooo`00Aoooo`030000oooooooo03Soool01@00071IZ00009eYU@000002oooo1@00
009LDjl4000000>6IjP0000000000/:=WP030000m=IX000000;DZ:X010000?oFQP0001P;P0<00000
0o[5SP000?G4V@06mLBI0P0000BFKJ42000000>AI9X0000000000m2V[P040000WfbFWfbF00000ZUg
W0800004VfRF00@0002TKYBTKYBTKY@2000000?0QYH0000000000geAT`030000Q5NE000000C=V9l0
0`000;f5V;f5V003_HFH0P0000FmQ9L0100008MHThMHT`0000?m`gl00`0008]KU8]KU002Re^D00<0
002:GIP000000P0000BMJID00`00099PTi9PT`03TV2C0P0000?[[Xl200001:5m[0030000YgnXYgnX
00:WOjP010000=bSVMbSV@0000FiP9H00`000>f]R^f]RP03kJf:00<0002RK9BRK9@00Z9/U0030000
lLFS000000GAUiP010000;AkUKAkU@0000;f`9<00`000=2CTm2CT`04d9>C00<0003EViSEViP00mFK
V0030000a8NBa8NB00?4Qi80100008IGTXIGTP0000;FYjL00`000=BGU=BGU003e9ND00@0002RKiRR
KiP00003XFfF0P0000J`PJ800`000;b=Y0000004Y7FN00D0002^PZF^PZF^PZD000000_kMQ`030000
oooooooo02Woool00`000?ooooooo`0<oooo00<0003oooooool00_ooo`00B?ooo`80000hoooo1@00
00?oool4000000ALDjl00030UZc0UZ`500000/:=WP@000000mBXZP000?oFQP05000000?jaHh00000
0000100000;ea9T2000019I]X@8000000i5TVP0000000003d:J^00H0002OK9JOK9JOK9H0002YMi`2
000019]XUP060000Y6jDY6jDY6jD0000fj2F0`0000=mDI<300001<fHW`030000_HFH_HFH00>mQIP2
00001Kf4U`040000QeRCQeRC00000og3O`030000Re^DRe^D00:;Fi@00`0008YMV0000002000019eY
U@030000TV2CTV2C00>BH9<200001>^^S`030000XGf/XGf/00:QOJ`01@000:MoZ:MoZ:MoZ0000003
g:>I00<0002iP9JiP9H00kV0UP030000kJf:kJf:00?][HX00`000:9/U:9/U002XVbD00<0003aaJ<0
00001M6GV0040000]7^E]7^E00000_K0T`030000d9>Cd9>C00C@Ti<00`000=FKV=FKV003eI^H00<0
0034Qi;4Qi800lB7TP040000QUNBQUNB00000]JWY`030000e9NDe9ND00?DUi@010000:9_V:9_V000
00:QKIH010000:MhWjMhW`0000F`PJ800`000;b=Y0000004Y7FN00D0002^PZF^PZF^PZD000000_kM
Q`030000oooooooo02[oool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`00B_ooo`030000
oooooooo03Goool400001?ooo`@0000015aC[`000<2F[<2F[0<0000018e/Z0000<:=W/:=WP800000
0jEoZP000=BXZP02000000PH2h00003Wa;80003jaHh0001S@I<00004WV^F100000BFKJ44000000Gj
g7T0003@YZk@YZh000000im/UP040000ZGNL0000000019]XUP050000Y6jDY6jDY6jD000000;KX9H2
00000geAT`800005cIRO00<0002mQIRmQIP00[f5V0<00005_HBG00@00027F9>7F9<00003oL=o00<0
002;FiB;Fi@00X]KU0030000RUfH000000800004WFVE00<0002BH9>BH9<00i9PT`030000jjj?jjj?
00?[[Xl00`000:5m[:5m[003XGf/00<0002WOjP000001=bSV@030000^H2F^H2F00>iP9H00`000>f]
R^f]RP03kJf:00D0002RK9BRK9BRK9@000000_75X`030000dINHdINH00?AUiP010000;AkUKAkU@00
00?f`9<00`000=2CTm2CT`02d9>C0P0000GEViP00`000<B7T/B7TP03a8NB00@00026Ei:6Ei800002
eZNW00<0003DUiCDUi@00]BGU0030000XVnHXVnH00:RKiP00`000:5]UP000002YgRO00<0002`PJ:`
PJ801;21XP800005Y7FN00<0002^PZD000000_kMQ`030000oooooooo02_oool00`000?ooooooo`0;
oooo00<0003oooooool00_ooo`00Boooo`030000oooooooo03Coool010000?ooo`00000000Coool0
0`0003`hX`00000200001<2F[080000018e/Z0000<:=W/:=WP8000000jEoZP000=BXZP0300000^O4
/P<000000f=1T`0009i[UP05WV^F0`0000>FKJ401P00095TVP0000000?[LN@0000;@YZh01P0009m/
UYm/UYm/UP000:UgW0800004VfRF00D0002TKYBTKYBTKY@000000m^PUP800002OE6C0P0000G=V9l0
0`000;f5V;f5V002_HFH00<0003FX9l000001Kf4U`040000QeRCQeRC00000og3O`030000Re^DRe^D
00>;Fi@010000?VmQ000000000BMJID00`00099PTi9PT`03TV2C00<0003[[Xo[[Xl00n^^S`800004
XGf/0P0000GLXiT00`000;V0U[V0UP03^H2F00<0003][H[][HX00nf]RP050000XVbDXVbDXVbD0000
00;aaJ<00`000=6GV=6GV003dINH00@0002dNiFdNiD00003m/2C00<0003@Ti?@Ti<00]2CT`030000
n=:T000000GEViP00`000<B7T/B7TP03a8NB0P0000?FYjL00`000=BGU=BGU002e9ND00<0002RKiRR
KiP00Z9_V0800003YgRO00<0002`PJ:`PJ801;21XP800005Y7FN00<0002^PZD000000_kMQ`030000
oooooooo02coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`00C?ooo`030000oooooooo
03Goool200001?ooo`050000?3RS000001BQ000000?0UZ`2000000>c`^D0000000000/:=WP030000
YGnZYGnZ00D00002ilBb0`000003Hd6C0000WV^F00BNJiH00`0000d6P0000003000000>FKJ40002A
I9X0100000;@YZh01P0009m/UYm/UYm/UP000:UgW0800004VfRF00<0002TKYBTKY@00P0000?KX9H0
0`000755S@00000300001LfHW`030000_HFH_HFH00:mQIP00`000=JPW`000005_HBG00@00027F9>7
F9<00003oL=o00<0002;FiB;Fi@00h]KU0040000nKf40000000019eYU@030000TV2CTV2C00>BH9<0
0`000>^^Sn^^S`03jjj?0P0000BQOJ`200001MbSV@030000^H2F^H2F00>iP9H00`000>f]R^f]RP03
kJf:00D0002RK9BRK9BRK9@000000_75X`030000dINHdINH00?AUiP00`000;AkU@000004m/2C00<0
003@Ti?@Ti<00]2CT`030000n=:T000000GEViP00`000<B7T/B7TP03a8NB0P0000CFYjL01@000=BG
U=BGU=BGU0000004XVnH0P0000>WN9l00`000;21X[21XP04/86R0P0000FTMIh00`000:j2Y@000002
o]f700<0003oooooool0;Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo001=oooo0P00
03Goool200001?ooo`050000?3RS000001BQ000000?0UZ`00`000;?2iK?2i@02000000?2SIh00000
00000ZEoZP@00004ilBb0P000003Hd6C0000WV^F00BNJiH01@0000d6P00000000=oVf005000000?j
g7T0000000000]2V[P050000WfbFWfbFWfbF000000:YMi`00`0009]XUY]XUP02VfRF00<0002TKYBT
KY@00P0000?KX9H00`000755SG55S@02LDF=00<0003=V9o=V9l00lfHW`040000_HFH_HFH_HFH0P00
00;FX9l00`000;f4Ukf4U`02_HBG00<00027F9<000001?g3O`030000Re^DRe^D00>;Fi@010000?Vm
Q?VmQ00000FMJID00`00099PTi9PT`02TV2C00<0003[[Xo[[Xl01>^^S`030000XGf/XGf/00@00005
g:>I00<0002iP9JiP9H00[V0UP800005kJf:00@0002RK9BRK9@00003lLFS00<0003AUiSAUiP00m6G
V0030000]7^E000000Cf`9<01@000=2CTm2CTm2CT`000002n=:T00<0003EViSEViP00mFKV0030000
a8NBa8NB00?4Qi8200001=JWY`030000e9NDe9ND00800002XVnH0`0000FWN9l00`000;21X[21XP03
/86R0P0000FTMIh01@000:j2Y@000?kMQ`00000aoooo00<0003oooooool02?ooo`030000oooooooo
00;oool004ooool00`000?ooooooo`0boooo0P0000Coool00`0003`hXc`hX`0200000l2F[0800000
1;?2i@0000000<:=WP8000000jEoZP000=V`[`0300001NO4/P030000Hd6C000000FNJiH0100000d6
P000054oWP<000001_kMT@00000000000;^@Z@0000;@YZh01@0009m/UYm/UYm/UP000002ZGNL00<0
002KJ9JKJ9H00Y]XUP030000Y6jDY6jD00800004fj2F00@0001aAHeaAHeaAHd200001<fHW`040000
_HFH_HFH_HFH0P0000;FX9l00`000;f4Ukf4U`02_HBG00<00027F9<000001?g3O`030000Re^DRe^D
00>;Fi@00`000?VmQ?VmQ002000019eYU@030000TV2CTV2C00:BH9<00`000>^^Sn^^S`04jjj?0`00
0004/WVD0000diZH00001MbSV@030000^H2F^H2F00:iP9H200001^f]RP030000XVbD000000CaaJ<0
0`000=6GV=6GV002dINH00<0002dNiD000001?K0T`050000d9>Cd9>Cd9>C000000;hdZ@00`000=FK
V=FKV003eI^H00<00034Qi;4Qi800lB7TP030000eZNWeZNW00?FYjL00`000=BGU=BGU00400000YQ]
X0030000YgROYgRO00>WN9l00`000;21X[21XP02/86R00<0002RLY/000001JAeWP050000[X:U0000
o]f70000037oool00`000?ooooooo`09oooo00<0003oooooool00Oooo`00D?ooo`030000oooooooo
037oool00`000?ooooooo`04oooo00D0000l>:<000005:4000000/2F[08000001;?2i@0000000<:=
WP8000001:EoZP000=V`[mV`[`@00003ilBb00@0001S@I=S@I<00004WV^F00<0000=1X0=1X000P00
0003gnKH0000000000800002^i2Y0P000004d:J^0000WfbFWfbF0P0000:YMi`00`0009]XUY]XUP02
VfRF00H0002TKYBTKY@0003W/I/00003fj2F00@0001aAHeaAHeaAHd200001<fHW`050000_HFH_HFH
_HFH000000?FX9l00`000;f4Ukf4U`02_HBG00<00027F9<000001Og3O`030000Re^DRe^D00:;Fi@0
0`000?VmQ0000002000019eYU@040000TV2CTV2CTV2C0P0000K[[Xl010000;9iU;9iU00000;CVYP0
0`000=bSVMbSV@03g:>I00D0002iP9JiP9JiP9H000000^G;_0030000kJf:kJf:00?][HX00`000:9/
U0000004lLFS00<0003AUiSAUiP00]6GV0030000]7^E000000Cf`9<010000=2CTm2CT`0000?hdZ@0
0`000=FKV=FKV003eI^H00<00034Qi;4Qi800lB7TP030000eZNWeZNW00?FYjL00`000=BGU=BGU002
000019Q]X0030000YgROYgRO00>WN9l00`000;21X[21XP02/86R00<0002RLY/000001ZAeWP030000
o]f7000003?oool00`000?ooooooo`08oooo00<0003oooooool00Oooo`00DOooo`030000oooooooo
033oool00`000?ooooooo`04oooo0P000004oooo00000000`9J/0P000003cK2m0000000000D00002
fK2_0P00009/DJ4200000^O4/P040000Hd6CHd6C00000ii[UP8000023@J000<0001A?ih000001000
00:kT:T2000000C@YZh0002OK9JOK9H200000ZUgW0030000VfRFVfRF00:KJ9H01P000:A^U:A^U000
0>NaV`0000?KX9H010000755SG55SG55S@800005cIRO00@0002mQIP000000003eZ2O00<0002mQ9Nm
Q9L00kf4U`800005oL=o00<0002;FiB;Fi@00X]KU0D00004WFVE00@0002BH9>BH9>BH9<300001^^^
S`030000/WVD000000;CVYP00`000=bSVMbSV@04g:>I00@0002iP9JiP9H00002iL^l00<0003][H[]
[HX00nf]RP800005lLFS00<0003AUiSAUiP00m6GV0800004m/2C00@0003@Ti?@Ti<00004n=:T00<0
003EViSEViP00]FKV0030000a8NBa8NB00;4Qi8200001MJWY`030000e9NDe9ND00800004V6fP00<0
002WN9nWN9l00jMhW`030000/86R/86R00:`PJ800`000:9bV`000006Y7FN00<0003ngHL00000=?oo
o`030000oooooooo00Ooool00`000?ooooooo`01oooo001Boooo0P00033oool00`000?ooooooo`04
oooo0P000004oooo00000000`9J/0P000004cK2m00000000SFbX100000;I/:l200000faAX@800000
1NO4/P0006=1Tf=1T`000003WV^F0P00008=1X000`00054oWP00000300000k^@Z@8000002M2V[P00
09m/UYm/UP000?k?L@000:UgW0000004VfRF00H0002TKYBTKY@0003W/I/00003fj2F00H0001aAHea
AHd0002LO:l00005cIRO00@0002mQIP000000003eZ2O00<0002mQ9NmQ9L00kf4U`800005oL=o00@0
002;FiB;FiB;Fi@3000000?_]9000000000019eYU@050000TV2CTV2C0000m;J700800006jjj?00<0
002bNI@000000m>JV0030000g:>Ig:>I00?LXiT00`000;V0UP000003iL^l00<0003][H[][HX00nf]
RP800005lLFS00<0003AUiSAUiP00m6GV0800004m/2C00@0003@Ti?@Ti<00004n=:T00<0003EViSE
ViP00]FKV0050000a8NBa8NBa8NB000000;Oc/L00`000=JWYmJWY`02eZNW00D0003DUi@0002HKJ00
00001IQ]X0030000YgROYgRO00>WN9l010000;21X[21XP0000>RLY/00`000:AeWZAeWP03Y7FN0P00
03Goool00`000?ooooooo`07oooo00<0003oooooool00Oooo`00E?ooo`030000oooooooo03Coool0
1`000?ooooooooooo`000<2F[0000003cK2m1@0000?I/:l0200006aAXFaAXFaAX@000?7f^P000>O4
/P8000000f=1T`0009i[UP02WV^F0`0000073@J00000DCnNDCnN0000n]ai000000>kT:T2000000S@
YZh0002OK9JOK9H0003ncg40002YMi`200000i]XUP060000Y6jDY6jD0000ik6K00000m^PUP050000
LDF=LDF=0000W7b_00800004cIRO00@0002mQIP000000003eZ2O00<0002mQ9NmQ9L00kf4U`800005
oL=o00@0002;FiB;FiB;Fi@200000^ndT0800004WFVE00<0002BH9<000000_BfQ`<00005jjj?0`00
00?CVYP00`000=bSVMbSV@03g:>I00<0002iP9H000000nG;_0030000kJf:kJf:00?][HX200001O75
X`030000dINHdINH00?AUiP00`000?K0ToK0T`04m/2C0P0000GhdZ@00`000=FKV=FKV003eI^H00<0
0034Qi8000000mo>a`030000eZNWeZNW00?FYjL200000YQ]X0030000V6fPV6fP00:HKJ000`000:Mh
WjMhW`03YgRO00@0002`PJ:`PJ800003XW:K00<0002TMIjTMIh00jAeWP80000foooo00<0003ooooo
ool01_ooo`030000oooooooo007oool005Goool00`000?ooooooo`0goooo100000;=/;d3000000B6
MKT0003I/:oI/:l200000faAX@080000lOJj00000000ilBb0000Hd6C00000ii[UP<0000010d6P000
054oWU4oWP@00002^i2Y0P000008d:J^0000WfbFWfbF0000o/ma0000ZGNL0P0000BKJ9H00`000:A^
U0000002ik6K00@0003KX9KKX9H00002LDF=00@0002LO:l000000004cIRO0`0000CFX9l00`000;f4
Ukf4U`03_HBG0P0000Gm`gl00`0008]KU8]KU00200001>ndT0030000WFVEWFVE00:MJID300000_Bf
Q`<00005jjj?0`0000?CVYP00`000=bSVMbSV@03g:>I0P0000CUbk`00`000>f]R^f]RP03kJf:00<0
003aaJ?aaJ<01?75X`030000dINHdINH00?AUiP00`000?K0ToK0T`04m/2C0P0000GhdZ@00`000=FK
V=FKV003eI^H00<00034Qi8000000mo>a`030000eZNWeZNW00?FYjL200000YQ]X0030000V6fPV6fP
00:HKJ000`000:MhWjMhW`03YgRO00<0002`PJ8000001:9bV`030000Y7FNY7FN00:TMIh20000>?oo
o`030000oooooooo00Goool00`000?ooooooo`01oooo001Foooo00<0003oooooool0=oooo`030000
oooo000000?=/;d3000000B6MKT0003I/:l00003K56Q00T0003am[[am[[am[X0003Wa;80001S@I<0
00000Yi[UP060000`<aA000000003@J000000U4oWP8000001?gLP@000;^@ZK^@Z@8000002=2V[P00
09m/UYm/UP000?k?L@000:UgW0800004VfRF0`0000;W/I/01@000=^PU]^PUP000755S@02000000>L
O:l0000000001<fHW`<00004eZ2O00<0002mQ9NmQ9L00kf4U`800005oL=o00<0002;FiB;Fi@00P00
00C_]9000`0009eYUIeYU@02WFVE0`0000;d]XL300001N^^S`030000]96a000000?CVYP00`000=bS
VMbSV@03g:>I0P0000GUbk`010000>f]R^f]R^f]RP800007lLFS00@0003AUiSAUiSAUiP200001_K0
T`800005n=:T00<0003EViSEViP00mFKV0800004glk700<0003FYjOFYjL00mJWY`050000V6fPV6fP
V6fP000000BHKJ000`000:MhWjMhW`03YgRO00<0002`PJ8000001:9bV`030000Y7FNY7FN00:TMIh2
0000>Oooo`030000oooooooo00Coool00`000?ooooooo`01oooo001Goooo0P0003Ooool010000?oo
ooooo`0000;=/;d3000000>6MKT0003I/:l00P000003K56Q0000lOJj00?am[X3000000QS@I<0002N
JiJNJiH00030c540002KL:02000000AA?ih00000003mg843000000>kT:T0002OKi/00P0000:OK9H0
10000?k?L@000:UgW0800004VfRF0P000004?bbB0000ik6K00000]^PUP050000LDF=00000000W7b_
00800004cIRO0`0000CFX9l00`000;f4Ukf4U`03_HBG0P0000Gm`gl00`0008]KU000000200001>nd
T0H0000018aLT`000?BfQoBfQ`@00002jjj?0`0000:dTK401@000=>JV=>JV=>JV0000002g:>I0`00
00KUbk`010000>f]RP00000000;g_HT200001O75X`040000dINH000000000XYITP030000m/2Cm/2C
00?f`9<00`000?SBY?SBY005n=:T00@0003EViSEViSEViP200001]o>a`040000eZNWeZNWeZNW0P00
00>HKJ000`0009Q]X9Q]X002V6fP00<0002WN9nWN9l01:MhW`800004XW:K00<0002TMIjTMIh00ZAe
WP030000oooooooo03Soool00`000?ooooooo`04oooo00<0003oooooool00Oooo`00FOooo`030000
oooooooo03Ooool300000jk3j@030000QWFi00000080000016aAX@000?7f^_7f^P8000001Kg:i000
000006=1T`000002WV^F00@00030c540002KL:02000000EA?ih000000000002UOJL00P0000:kT:T3
00000Ym/UP030000o/mao/ma00<00004VfRF0P00000;?bbB00000000ik6K0000fj2F0000LDF=0000
Gcb@000000;JX9P010000<fHWlfHWlfHW`<00004eZ2O00<0002mQ9NmQ9L00kf4U`8000000og3O`00
0?g3O`02oL=o00<0002;Fi@000000P0000G_]9001`000:YcUZYcUZYcUP0008aLT`000002m;J71P00
00FdTK4010000=>JV=>JV=>JV0<000000jmhU`000000000200000nG;_0<000001:=_U`000?NmRONm
R@/00002RUVB00@0003f`9?f`9?f`9<400001_SBY0030000eI^H0000008000000f91U0000=o>a`04
glk700<0003FYjL000000P0000BHKJ000`0009Q]X9Q]X002V6fP00<0002WN9nWN9l01:MhW`800004
XW:K00<0002TMIjTMIh00ZAeWP030000oooooooo03Woool00`000?ooooooo`04oooo0@00007oool1
oooo001Joooo00<0003oooooool0=oooo`030000[/?Y[/?Y00:^`nT6000000?am[X0000000000kg:
i080000016=1T`0009i[UYi[UP<00002Vg2P0`0000>UOJL010000?kPT@000;^@Z@<00002WfbF0P00
00;ncg42000019]XUP8000002cl/TP0000000>NaV`000=^PUP000755S@0005llT0000002fZ2H00<0
003=V9o=V9l00`0000GFX9l00`000;f4Ukf4U`03_HBG00D0003m`gl00032VZl000000_g3O`800000
0m6HV@0000000005kkB@00L0002ZLiJZLiJZLiH0002<G9<000000_BfQ`<00002]gnG00<0002dTK6d
TK400kBA/@030000diZHdiZH00?CVYP010000:mhU`00000000;e^HP300001:=_U`030000mkf9mkf9
00800004N4fA00<0001><8a><8`00P0000>:FI8300000gQ<T@T00002MTfC00<0001R@I@000000mo>
a`@00002L5RV00<0002HKJ2HKJ000YQ]X0030000V6fPV6fP00:HKJ000`000:MhWjMhW`04YgRO0P00
00FRLY/010000:AeWZAeWP0003goool00`000?ooooooo`03oooo0@00007oool1oooo001Koooo00<0
003oooooool0=oooo`040000[/?Y[/?Y[/?Y1`000003MMge0000000000>mb^@3000000>NJiH0003b
e;800P0000:KL:0300000jEmY`040000o^2A0000^i2Y0`000003WfbF0000o/ma00800002o/ma00<0
002KJ9JKJ9H00Y]XUP8000000cl/TP000>fdU002000000?KX9H0000000000UllT0030000fZ2HfZ2H
00<000000mZPV00000000005eZ2O00<0002mQ9NmQ9L00kf4U`040000oL=o0000`YZ_0P000004oL=o
00000000dIRI0P0000G_]9000`000:YcUZYcUP02ZW>F0P0000;d]XL300000kMoU`030000]96a]96a
00:dTK400`000=>JV=>JV003diZH00@0002_N9L000000002mKV800<0002]N9T000001:=_U`050000
mkf90000l[VA000000AhCI400`0004h`S4h`S002000018YITP030000N4bAN4bA009hC9400`00060m
T0000004mL6F00D0001fCI=fCI=fCI<000000V91U0@000000mjSUP0000000002L5RV00<0002HKJ2H
KJ000YQ]X0030000V6fPV6fP00>HKJ000`000:MhWjMhW`03YgRO0P0000FRLY/010000:AeWZAeWP00
03koool00`000?ooooooo`02oooo0@00007oool1oooo001Loooo0P0003Soool300000_ooo`X00000
1kg:i0000000000009i[UP000?;D/P02000000>KL:00000000000P0000:UOJL00`000?kPTOkPT@05
000000ROK9H0003ncg400023FiX0003ncg400004VfRF0`0000;]]9@00`000>NaV`00000200000Ull
T0030000fZ2HfZ2H00CJX9P200001MJPW`030000_HBG_HBG00>mQ9L200000/:J[`040000dIRI0000
00000]6HV@030000kkB@kkB@00C_]9000`000:YcUZYcUP02ZW>F0P0000;d]XL300000kMoU`030000
]96a]96a00:dTK400`000=>JV=>JV004diZH00D0003oc800003e^HP000000jehV@040000XfnGXfnG
00000_NmR@030000l[VA000000800002N4fA00H0001><8a><8`0002DHiD00003RUVB00<0001hC95h
C9400gQ<T@800003mL6F0P0000AfCI<01P000691U691U0000=ZVW`0000;NXiH01000071HYW1HYP00
00FHKJ000`0009Q]X9Q]X002V6fP00<0002WN9nWN9l00ZMhW`030000UfVL000000FRLY/010000:Ae
WZAeWP0003koool00`000?ooooooo`02oooo0@00007oool1oooo001Noooo00<0003oooooool0>_oo
o`080000T8W9T8W9T8W90000/I_10000c=i_1P000004WV^F00000000Xh6_1@0000>UOJL00`000?kP
TOkPT@04000000C@YZh0000000000002Pe^J00<0003ncg40000019]XUP<00003kKBD10000003Gcb@
0000000000KJX9P00`000<ZJY@000004eZ2O00<0002mQ9NmQ9L00kf4U`800002`YZ_00@0003AV9WA
V9T00002dIRI00<0003_]93_]9001>ndT0030000ZW>FZW>F00:ZLiH200000_BfQ`<00003]gnG00<0
002dTK6dTK400kBA/@030000diZHdiZH00?CVYP01@000?o<P0000?FiR0000003[GRI00@0002SKiNS
KiL00002mkf900<0003b^I4000000/:9V0<000000dh`S00000000002000018YITP030000N4bAN4bA
009hC94200000oG1UP800004MTfC00H0001R@IAR@I@0003JYYl00002gZ>F00@0001`F:I`F:H00005
V6fP00<0002HKJ2HKJ000YQ]X0030000YgROYgRO00:WN9l0100009MYW9MYW00000BRLY/00`000:Ae
WP000010oooo00D0003oooooooooool000000_ooo`00Goooo`030000oooooooo03[oool00`000929
b@000002/I_100@0003<gVl000000002K8[O0P000004WV^F0000Xh6_Xh6_1@0000>UOJL2000000Gn
h940001jEIX0001jEIX0100000:3FiX3000019]XUP030000]H>O000000?]]9@4000000AO?900002l
dU`00004fZ2H00@0003:VZG:VZD00004eZ2O00<0002mQ9NmQ9L00kf4U`050000`YZ_`YZ_`YZ_0000
00GAV9T00`000>ndT>ndT004kkB@00<0002ZLiJZLiH00ZYcUP070000m;J7m;J7m;J70000mkj<0000
00BgOiL00`000;BA/KBA/@02]96a00<0003CVYSCVYP00m>JV08000000mKTh00000000003[GRI00@0
002SKiNSKiL00002mkf900<0003b^I4000001<:9V08000001?_1Q@000000000000B:FI800`0007Q<
TGQ<T@02N4bA0P0000?e`IH2000017I=T`040000HT6DHT6D00000]ZVW`040000gZ>F000000000W1H
YP030000V6fPV6fP00:HKJ000`0009Q]X9Q]X002V6fP00D0002WN9nWN9nWN9l000000iMYW0030000
XW:KXW:K00:RLY/00`000:AeWP000011oooo00@0003oooooool00002oooo001Poooo00<0003ooooo
ool0>Oooo`030000T8W9000000:aVl4010000<cNK`0002hVU@H00002Xh6_1P0000:UOJL2000000?n
h940001jEIX01P000003Pe^J0000000000@00002VfRF00<0002ePil000000nfdU0<00002Gcb@00<0
002ldU`000001=ZPV0040000bYZUbYZU00001=JPW`030000_HBG_HBG00:mQ9L200001<:J[`030000
dIRIdIRI00;AV9T00`000>ndT>ndT004kkB@00<0002ZLiJZLiH00ZYcUP030000m;J7m;J700800000
0oNnS0000;MoU`03]gnG00<0002dTK6dTK400[BA/@030000diZHdiZH00?CVYP2000000?Fi>000000
00000jehV@040000XfnGXfnG00000_NmR@030000l[VA000000C2RIP010000?_1Q@000?:gSP800004
RUVB00<0001hC95hC9400WQ<T@800002mL6F00<00025Ei<0000017I=T`040000HT6DHT6D00000]ZV
W`8000001Oooo`00071HYW1HYP000004V6fP00<0002HKJ2HKJ000YQ]X0050000YgROYgROYgRO0000
00>GJI`00`000:9bVj9bV`02XW:K00<0002TMIh00000@Oooo`040000oooooooo00000_ooo`00HOoo
o`80000joooo00@0002aVl6aVl6aVl43000000<^9YD0000000001@000003Xh6_0000000000@00002
YGfW0P000004o^2A0000NUFJNUFJ1@000003Pe^J0000@TVb00800002/8BV1P0000;]]9@01@000>Fd
X`0005llT0000002_=9L00<0003JX9SJX9P00]ZPV0030000bYZUbYZU00800004eZ2O00@0002mQ9Nm
Q9NmQ9L200001<:J[`070000dIRIdIRIdIRI0000bHjF000000G_]9000`000:YcUZYcUP02ZW>F00<0
003d]XOd]XL00P0000;g_X`01@000;MoUkMoUkMoU`000004]96a00<0003CVYSCVYP00m>JV0050000
e^CPe^CPe^CP000000>]N9T010000:=_Uj=_U`0000;g_HT200001L:9V0040000nl650000l[N>0P00
00B:FI800`0007Q<TGQ<T@02N4bA00L0003e`IKe`IKe`IH00025Ei<0000017I=T`030000HT6D0000
00?JYYl200000_ooo`030000L5RV000000BHKJ000`0009Q]X9Q]X002V6fP00@0002WN9nWN9l00004
UfVL00<0002RLY^RLY/00j9bV`800012oooo00<0003oool000000_ooo`00Hoooo`030000oooooooo
03Ooool00`000;6K`K6K`@02/I_10P000003;RJE0000i;BT00<000001NBdY0000:>1[j>1[`000002
Xh6_0P000003YGfW0000^YFa00<00002NUFJ100000:3FiX01P000499/P0000000;24YP0000:ePil4
00000^fdU0<000001EllT00000000;cBG0000003fZ2H00@0003:VZG:VZG:VZD200001=JPW`030000
_HBG_HBG00<00004`YZ_00L0003AV9WAV9WAV9T00039SYH000001NndT0030000ZW>FZW>F00:ZLiH0
0`000?BfQoBfQ`0200000_NnS0040000]gnG]gnG]gnG0P0000>dTK400`000=>JV=>JV002diZH00<0
003Fi>3Fi>000P0000B]N9T010000:=_Uj=_U`0000;g_HT200001L:9V0040000nl650000l[N>0P00
00B:FI800`0007Q<TGQ<T@02N4bA00L0003e`IKe`IKe`IH00025Ei<0000017I=T`030000HT6D0000
00?JYYl200000_ooo`030000L5RV000000BHKJ000`0009Q]X9Q]X002V6fP00@0002WN9nWN9l00004
UfVL00<0002RLY^RLY/00j9bV`030000oooooooo04;oool00`000?ooo`000001oooo001Toooo00<0
003oooooool0=_ooo`030000/I_1/I_100:aVl42000000@^9YD0003T]:CT]:@2000000GT]:@0002S
PJnSPJl000000Z>1[`8000000jEmY`000;ZE/@02000000?nh940001jEIX01@000003Pe^J0000@TVb
008000002;24YP000;F3WkF3W`000>jhV@000>;HHPH000001I]]W0000;cBG;cBG0000002fZ2H00@0
003:VZG:VZG:VZD200001=JPW`030000_HBG_HBG00<00004`YZ_00@0003AV9WAV9T00003bHjF00<0
003_]93_]9000^ndT0030000ZW>FZW>F00:ZLiH00`000?BfQoBfQ`0200000_NnS0040000]gnG]gnG
]gnG0`0000>dTK401@000=>JV00000000=KTh002000000>FJI`0002]N9T00jehV@040000XfnGXfnG
00000_NmR@800005`XVH00@0003k`HD0003b]hh2000018YITP030000N4bAN4bA00<00003mL6F00<0
0025Ei<0000017I=T`030000HT6D000000CJYYl010000?ooooooooooo`800004V6fP00<0002HKJ2H
KJ000iQ]X0<00004UfVL00<0002RLY^RLY/00j9bV`030000oooooooo04?oool200000Oooo`00IOoo
o`030000oooooooo03Koool01@000;6K`@00000009KQoP0300000^BdY0040000i;BTi;BT00001:>1
[`<000001ZEmY`0000000>g4Z0000?kPT@8000000oS=WP0000000004000000E2BK800000002`Q:H0
00000[F3W`040000k[RI0000h]QR0P00000403Rm0000000000000Y]]W0030000_=9L000000;JX9P0
1P000<ZJYLZJY@000>^fV`0000CFX9l01`000;f4U`000:1bWP000>ndT0000003`YZ_00@0003AV9WA
V9T00003bHjF00<0003_]93_]9000^ndT0030000ZW>FZW>F00:ZLiH00`000?BfQoBfQ`0200000_Nn
S0030000]gnG]gnG00:gOiL4000000>dTK40000000000`0000>FJI`00`000:ehVJehV@02[GRI00@0
002SKiNSKiL00002mkf90`0000C2RIP010000?_1Q@000?:gSPT00003YL?_0`0000:5Ei<00`0007I=
TgI=T`02MTfC00<0001R@I@000001=ZVW`040000oooooooooooo0P0000BHKJ000`0009Q]X9Q]X003
V6fP0`0000BGJI`00`000:9bVj9bV`03XW:K00<0003oooooool0@oooo`800001oooo001Voooo00<0
003oooooool0=Oooo`P00002i;BT00@0003T]:CT]:@00003Xh6_10000003YGfW0000000000;]a:P3
00000_S=WPX000002KF3W`000>jhV@000>;HHP0004a?]000000h_@0300000Y]]W0<000000mZPV000
0<ZJY@02bYZU00@0003[]Y_[]Y/00003eZ2O00L0002mQ9L0002PLYh0003_]90000000l:J[`030000
dIRI000000C9SYH200001>ndT0050000ZW>FZW>FZW>F000000;d]XL01@000?NnS?NnS?NnS0000004
]gnG0P0000;[[8`200000_ooo`800003UVVL00<0002]N9V]N9T00ZehV@030000XfnG000000;g_HT0
10000?:iT@00000000C2RIP01`000?_1Q@000?:gSP000?FiR@000003oooo0P0000FU`nl200000XEG
T`030000MTfCMTfC00=fCI<200001=ZVW`040000oooooooooooo0P0000FHKJ000`0009Q]X9Q]X002
V6fP00<0002GJI`0000019MYW0030000XW:KXW:K00:RLY/00`000?ooooooo`14oooo0P00007oool0
06Ooool20000>oooo`0<0000i;BTi;BTi;BT0000i;BT0000dKc50000Xh6_0000_I:Z1P0000;]a:P3
00000_S=WPL0000031DBR`0000000;F3W`000>jhV@000>;HHP0004a?]000000h_@800004VffL0P00
0003fZ2H0000bYZU00;:VZD010000>^fVn^fV`0000?FX9l400000^ndT0800003`YZ_0P0000C9SYH3
00000nndT0080000ZW>FZW>F0000i]710000m;J700000oNnS0030000]gnG]gnG00:gOiL01@000>^/
S>^/S>^/S0000003oooo0P0000>FJI`00`000:ehVJehV@02[GRI00<0002SKiL000000_NmR@040000
l[VA000000001<:9V0070000nl650000l[N>0000mKV9000000Goool00`000:G3kjG3k`0300000hEG
T`030000MTfCMTfC00=fCI<200000mZVW`030000oooooooo00?oool2000019Q]X0040000V6fPV6fP
V6fP0P000003UfVL0000UfVL00BGJI`01@000:9bVj9bVj9bV`000012oooo100000?oool006Woool0
0`000?ooooooo`0hoooo00<0003T]:CT]:@00^BdY0030000dKc5dKc5008000000kfBZP000?kIV004
00000ng4Z0<000001?S=WP0000000>K9^@D0000011DBR`000000000000;^^9T4000000A<Ck@00000
00000004VffL100000?:VZD01@000>^fVn^fVn^fV`000002eZ2O0P000006WfjI0000kkB@kkB@0000
kkB@0P000003`YZ_0000000000C9SYH300000nndT0040000ZW>FZW>F00000^KA`@800003mkj<00<0
002gOiNgOiL00[MoU`050000jjb<jjb<jjb<000000?oool200000iIYW0030000[GRI[GRI00:]N9T0
0`000:=_U`000002mkf900@0003b^I4000000004`XVH00L0003k`HD0003b]hh0003e^HT000001_oo
o`8000000oooo`0000000004QENC00<0001fCI=fCI<00WI=T`030000fZJOfZJO00;JYYl00`000?oo
ooooo`03oooo0P0000BHKJ00100009Q]X000000000BGJI`00`0009MYW9MYW002UfVL00D0002RLY^R
LY^RLY/00000?_ooo`@00007oooo001Zoooo00<0003oooooool0>?ooo`040000i;BTi;BT00000m6l
a@050000_I:Z_I:Z0000o]VH00@00003kLBX0P000006n<fN000000000000i/Vi00000^GiZ`800000
1ADBR`00000000000>jhV@02000000?^`:<0002d]Rl00`0000FKKI`300000lZJY@030000jkJKjkJK
00;[]Y/400000Ym^V@070000kkB@kkB@0000kkB@0000UffP00<00003bHjF0`000007Vgnc0000kkB@
kkB@0000ZW>F000000CVdL401@000?NnS?NnS?NnS0000004]gnG00D0003[[8c[[8c[[8`000000ooo
o`800003UVVL00<0002]N9V]N9T00ZehV@030000XfnG000000;g_HT010000?:iT@00000000C2RIP0
1`000?_1Q@000?:gSP000?FiR@00000:oooo00<00025Ei>5Ei<00XEGT`030000MTfCMTfC009fCI<0
0`000=ZVWmZVW`02fZJO00<0003oooooool01?ooo`030000V6fPV6fP00D00005UfVL00<0002GJIbG
JI`00YMYW0040000XW:KXW:K0000>oooo`@0000;oooo001[oooo00<0003oooooool0=oooo`030000
i;BT000000?A_<D010000;fBZ[fBZ[fBZP8000001?C5V`000000000000;]a:P01@000:^8/0000000
0;ZE/@0400000^GiZ`D00002k[RI0P000003k/2S0000000000<00004VffL100000?:VZD010000>^f
Vn^fVn^fV`800002WfjI00@0002OKYVOKYT00002kkB@00<0003_]90000000iM]X0050000bHjFbHjF
bHjF000000BKOk<01@000>ndT0000:YcUP000003i]7100<0003g_Xcg_X`00_NnS0030000]gnG]gnG
00:gOiL01@000>^/S>^/S>^/S0000004oooo00<0002FJIbFJI`00YIYW0070000[GRI[GRI[GRI0000
XfnG000000;g_HT010000?:iT@00000000C2RIP01`000?_1Q@000?:gSP000?FiR@00000:oooo0P00
00>5Ei<0100007I=TgI=TgI=T`800004fZJO00<0003oooooool01?ooo`<000000oooo`0008iXX`02
SVRS00<0002GJIbGJI`00YMYW0030000UfVLUfVL00:GJI`010000:9bVj9bV`0003Ooool400003ooo
o`00K?ooo`80000hoooo00<0003A_<GA_<D00]6la@040000_I:Z_I:Z_I:Z0P000003m<FK00000000
00?]a:P00`000:^8/0000002^YFa0`000003RWBf0000iOV[00@00003k[RI0P000003k/2S00000000
008000000`0h_@0009]]W002VffL100000?:VZD010000>^fVn^fVn^fV`800005WfjI00<0003_]900
00000^ndT0050000UffPUffPUffP000000?9SYH200000i]o/`@00003i]710P0000Cg_X`00`000;Mo
UkMoU`02]gnG00D0003[[8c[[8c[[8`000001?ooo`030000UVVLUVVL00:FJI`01`000:ehVJehVJeh
V@000:=_U`000002mkf900@0003b^I4000000003`XVH00<0003k`HD000000_:gSP030000mKV90000
00[oool01`0007]e`@00000008EGT`0007I=T`02000000>OQKP0003JYYl00]ZVW`030000oooooooo
00[oool0100008iXXhiXX`0000BGJI`00`0009MYW9MYW002UfVL00@0002RLY^RLY/0000doooo0`00
01?oool006koool00`000?ooooooo`0foooo00@0003A_<GA_<D00003_I:Z00<0003nfIP000000_C5
V`8000001>g4Z0000000000000>jUK401P0008Yd]XYd]XYd]P000>GiZ`<00003k[RI1@000005/X:Q
0000000003Rm000000>KKI`400000lZJY@040000jkJKjkJKjkJK0P0000FOKYT300000^ndT0050000
UffPUffPUffP000000?9SYH2000019]o/`<00002i]710P0000Gg_X`00`000;MoUkMoU`02]gnG00D0
003[[8c[[8c[[8`000001?ooo`030000UVVLUVVL00:FJI`00`000:ehVJehV@02[GRI0P0000;g_HT0
1@000?:iT@0009MYW0000002`XVH00<0003k`HD000000_:gSP030000mKV9000000_oool00`0007]e
`G]e`@0300000in5^0050000fZJOfZJOfZJO000000coool0100008iXXhiXX`0000BGJI`00`0009MY
W9MYW002UfVL00@0002RLY^RLY/0000`oooo100001Koool006ooool00`000?ooooooo`0foooo00<0
003A_<D000000kfBZP030000o]VH000000;daI/00`000=NWY@00000200001KZE/@080000RWBfRWBf
0000iOV[0000YGRQ00000njhV@8000000nk0X`0000000002/X:Q00<00000>;d000000i]]W0030000
/XRX000000800002bYZU00@0003[]Y_[]Y_[]Y/2000019m^V@040000omZ<000000000^ndT0050000
UffPUffPUffP000000?9SYH2000019]o/`800003i]710P0000Gg_X`00`000;MoUkMoU`02]gnG00D0
003[[8c[[8c[[8`000001?ooo`030000UVVLUVVL00:FJI`00`000:ehVJehV@02[GRI0P0000;g_HT0
1@000?:iT@0009MYW0000002`XVH00D0003k`HD0003b]hh000000_FiR@030000oooooooo00Woool0
1@0007]e`G]e`G]e`@000005WhFh00@0003JYYoJYYl0000=oooo00<0002>J:<0000019MYW0030000
UfVLUfVL00:GJI`00`000:9bV`00000]oooo100001[oool0073oool00`000?ooooooo`0foooo00<0
002mTZZmTZX00[fBZP800003m<FK00D0003GYjGGYjGGYjD000001KZE/@080000RWBfRWBf0000iOV[
0000YGRQ00000njhV@8000000nk0X`000;:2X@02/X:Q0`0000>KKI`00`000;:8Z0000002000000?:
VZD0003[]Y/00^^fV`030000OUNJ000000BOKYT010000?oJS?oJS00000;_]9001@0009M]X9M]X9M]
X0000003bHjF00<0003h_h`000000i]o/`070000/XJV0000i]710000/XJV000000Gg_X`010000;Mo
UkMoUkMoU`800003jjb<00<0003oooooool00_ooo`800003UVVL00<0002]N9V]N9T00ZehV@090000
mkf9mkf9mkf90000l[VA0000UfVL000000;2RIP01@000?_1Q@000?:gSP000002mKV900<0003ooooo
ool02Oooo`030000NgG1NgG1009kML400`0009n5^9n5^002WhFh00<0003JYYl000003_ooo`030000
SVRS000000BGJI`00`0009MYW9MYW003UfVL0P0002Woool400007_ooo`00LOooo`80000foooo00L0
002mTZZmTZZmTZX0003nfIP000000oC5V`030000ejNUejNU00;GYjD00`000;ZE/KZE/@02^YFa00@0
002:M;H0003?[KL200000ZEhX@030000k[RIk[RI008000000nk0X`000;:2X@02/X:Q0`0000>KKI`0
0`000;:8Z0000002000000?:VZD0003[]Y/00^^fV`030000OUNJ000000BOKYT010000?oJS?oJS000
00;_]9000`0009M]X9M]X002UffP00H00039SYK9SYH0003h_h`00003Vgnc00@0002bQZJbQZH00002
/XJV00<0003g_Xcg_X`01?NnS0080000]gnG]gnG0000e:jb0000jjb<00001Oooo`800003UVVL00<0
002]N9V]N9T00ZehV@090000mkf9mkf9mkf90000l[VA0000UfVL000000;2RIP01`000?_1Q@000?:g
SP000?FiR@00000<oooo00<0001kML5kML400W]e`@030000WhFhWhFh00:OQKP00`000=ZVW`00000?
oooo0P0000BGJI`00`0009MYW9MYW003UfVL0P0002Goool400008_ooo`00Loooo`030000oooooooo
03?oool01`000;fBZ[fBZ[fBZP000?kIV0000002m<FK00<0003GYjGGYjD00mNWY@030000^YFa^YFa
00>jUK42000000K?[KL00000002UN:40003a_YT3000000?^`:<0000000000k:2X@<00002VffL00@0
002bR:P0003W]9l2000000?:VZD0003[]Y/00^^fV`030000OUNJ000000BOKYT00`000?oJS?oJS002
000000?_]900000000000iM]X0030000bHjFbHjF00<00003Vgnc00<0002bQZJbQZH00k:6YP030000
mkj<mkj<00Cg_X`00`000;MoU`000002e:jb00<0003[[8`000001_ooo`050000UVVLUVVLUVVL0000
00B]N9T01P000?NmRONmR@000?:iT@0000:GJI`02P000<:9V<:9V0000?_1Q@000?:gSP000?FiR@00
00goool01@0007]e`G]e`G]e`@000004WhFh00<0003JYYl000003oooo`800005UfVL00<0002GJIbG
JI`00YMYW0030000oooooooo023oool400009_ooo`00M?ooo`030000oooooooo03?oool01P000;fB
Z[fBZP000?kIV00000;daI/00`000=NWYMNWY@02ejNU0P0000FjUK400`000<n]]ln]]`02000000BU
N:40003a_YWa_YT2000000?^`:<0000000001;:2X@800002VffL00<0002bR:P000000`000003bYZU
0000jkJK00;[]Y/00`0007iGVP000003WfjI00D0003ofXcofX`0002kRJ400P000003ikJR0000UffP
00:GKJ000`000<V>U/V>UP0300000i]o/`030000/XJV/XJV00:bQZH0100009]fZ000000000Cg_X`0
0`000;MoU`000002e:jb00<0003[[8`000001_ooo`050000UVVLUVVLUVVL000000B]N9T01P000?Nm
RONmR@000?:iT@0000:GJI`02P000<:9V<:9V0000?_1Q@000?:gSP000?FiR@0000goool01@0007]e
`G]e`G]e`@000005WhFh0P00013oool2000019MYW0040000UfVLUfVLUfVL0P0001ooool30000:_oo
o`00MOooo`030000oooooooo03;oool00`000;fBZ[fBZP0200000oC5V`030000ejNUejNU00;GYjD2
00001;ZE/@<000001Ln]]`0000000:EhX@000003lKjI00@0003^`:<000000004/X:Q0P0000:KKI`2
000000KW]9l000000000003:VZD00002jkJK00@0001nEiYnEiX00003WfjI00@0003ofXcofX`00002
^hVQ00<0003W]Z8000000iM]X0070000bHjF0000n;n<0000lkbC000000:KOk<01@000;:6Y[:6Y[:6
YP000004VgJX00@0003g_Xcg_Xcg_X`200001=B^/P800006oooo00<0002FJIbFJI`00YIYW0050000
[GRI[GRI[GRI000000;g_HT00`000?:iT@000003UfVL00T00032RIP0003k`HD0003b]hh0003e^HT0
00003_ooo`800002NgG100<0002OQKROQKP00Yn5^0030000oooooooo00ooool2000019MYW0040000
UfVL000000007Oooo`@0000]oooo001foooo0P0003;oool01@000;fBZP000?kIV0000002m<FK00<0
003GYjGGYjD00]NWY@050000nMb[00000000^YFa00<000000nRhXP000<n]]`0400000_6nV@030000
k/2Sk/2S00<00003/X:Q0P0000:KKI`2000000?W]9l0000000000P0000?[]Y/2000000=nEiX0002O
KYT00Ym^V@040000omZ<omZ<00000[^9X@<00003UffP00<00039SYH000000P000003lkbC0000Vgnc
00:KOk<010000;:6YP00000000BKMZP3000000?g_X`0000000001=B^/P800007oooo00D0002FJIbF
JIbFJI`000000ZehV@030000cO_U0000008000000o:iT@0009MYW002UfVL00T00032RIP0003k`HD0
003b]hh0003e^HT000004?ooo`<00002WhFh0`0001;oool00`0009MYW9MYW00400006oooo`@0000a
oooo001hoooo00<0003oooooool0;oooo`040000_I:Z0000o]VH100000CGYjD00`000?WLZ`000003
000000?lciD0003X^:800P000004j;fY0000000000000_6nV@040000k/2S0000Vh_20P0000>bPZ42
00000Y]]W0070000ikBO0000l;^H0000oooo000000?[]Y/2000000=nEiX0002OKYT00Ym^V@030000
omZ<000000>kRJ400`000?gGN0000003UffP00@00039SYH0003Q/ZD400000Y]o/`050000/XJV0000
oooo000000>KMZP00`000:ioXZioXP0200001MB^/P800008oooo0P000004UVVL0000[GRI00000lgk
i@8000000o:iT@0009MYW002UfVL00T00032RIP0003k`HD0003b]hh0003e^HT000004_ooo`<0000E
oooo0`0001_oool40000=Oooo`00NOooo`030000oooooooo02koool010000;fBZP00000000?oool0
1@000=NWYMNWYMNWY@000002nMb[0`0000;lciD01@000>RhX^RhXP000>RmZ@0200000o6nV@030000
k/2S000000<00002/X:Q00<0003c`Y/000000Y]]W0070000ikBO0000l;^H0000oooo000000?[]Y/2
000000EnEiX0002OKYVOKYT000000_oJS0040000^hVQ^hVQ00000_gGN00<0000UffPUffPUffP0000
bHjF0000hK:U0000lKnL0000oooo100000;oool01@0009]fZ9]fZ9]fZ0000003[WnR00<0003D[[;D
[[801=B^/P030000oooooooo00Ooool400000/gki@800002]:c@0P0000>GJI`02@000<:9V0000?_1
Q@000?:gSP000?FiR@000014oooo100003Woool007[oool00`000?ooooooo`0^oooo0P0000Goool0
1P000=NWYMNWY@000?WLZ`0000;CYJP010000?c?UOc?U@0000;X^:82000000?X_JT0003a_YT00_6n
V@040000k/2S0000f_WN0P0000:bPZ401@000??2V`0009]]W0000002ikBO0P0000;oool2000000_[
]Y/0002JLjJJLjH0001nEiX0002OKYT0003ofX`000000k^9X@050000oMMhoMMhoMMh000000:GKJ00
10000<V>UP00000000;a_i`01@000?ooooooooooo`000003oooo00D0002KMZRKMZRKMZP000000jio
XP030000e:jbe:jb00CD[[800`000?ooooooo`08oooo1@0000Bd[=0200000iMYW0040000`XVH0000
00000_:gSP030000mKV90000047oool30000?Oooo`00Noooo`80000^oooo0P0000Goool00`000=NW
Y@000002nMb[00H0003CYJSCYJP0003lciD00003j;RR00<0003/_Z<000000P000004lKjI0000k/2S
k/2S100000:bPZ402@000??2V`0009]]W0000>NdW`000?2kV0000002oooo00@0000D>[L000000002
VW>V00L0001nEiX0002OKYT0003ofX`000000k^9X@050000oMMhoMMhoMMh000000:GKJ001P000<V>
UP0000000?6oW00000Soool00`0009]fZ9]fZ002VgJX00D0002^Oj:^Oj:^Oj8000001=B^/P030000
oooooooo00[oool0100000MEd0MEd00000Fd[=00100009MYW9MYW9MYW08000001o_1Q@000?:gS_:g
SP000?FiR@00000moooo1000043oool007goool00`000?ooooooo`0[oooo00<0003oooooool01?oo
o`050000ejNU0000nMb[000000?CYJP00`000?c?U@000003j;RR00D0003/_Z<00000002SP:d00P00
0003k/2S0000000000;oool01@000;:2XK:2X@000??2V`03000000CW]9l0003`^iP00003oooo0`00
00:JLjH01`0007iGVP0009m^V@000?oJS0000003^hVQ00T0003megSmegP0003fdJP0002GKJ000039
SYH00P000003lKnL0000oooo00Ooool00`0009]fZ9]fZ002VgJX00D0002^Oj:^Oj:^Oj8000000]B^
/P80000>oooo0`0000>d[=02000019MYW08000001o_1Q@000?:gS_:gSP000?FiR@00000ioooo1000
04Coool007koool00`000?ooooooo`0boooo00@0003ig:/000000003djFX00<0003lciD000000^Rh
XP040000k;jSk;jS00001:>0[@800003oooo00D0002bPZ6bPZ40003c`Y/00`000004ikBO0000l;^H
00000oooo`800003VW>V00H0001nEiX00000003ofX`00004^hVQ00H0003megSmegP0003fdJP00002
UffP0`000003lKnL0000oooo00Ooool00`0009]fZ9]fZ002VgJX00@0002^Oj:^Oj:^Oj8300004_oo
o`@000000hYPV`0009MYW004UfVL00D0003k`HD0003b]hh000000_FiR@030000oooooooo03?oool4
0000B?ooo`00Ooooo`030000oooooooo037oool2000000Goool0003CYJSCYJP000000_c?U@040000
j;RRj;RR00000^bnX`040000Xh2]Xh2]Xh2]0P0000Coool00`000;:2X@000002ll:K100000;`^iP0
10000?ooooooooooo`800002VW>V1@000003omZ<0000^hVQ00>kRJ400`000?gGN0000002m]6X0P00
0006UffP0000hK:U0000lKnL00002Oooo`050000VgJXVgJXVgJX000000>^Oj8200005?ooo`050000
RV2KRV2KRV2K000000FGJI`01@000?_1Q@000?:gSP000002mKV900<0003oooooool0;oooo`@0001<
oooo0020oooo0P0003Goool01@000=>UZ0000?c?U@000003j;RR00@0003/_Z?/_Z<00002Xh2]0P00
00Goool00`000;:2X@000002ll:K100000;`^iP00`000?ooooooo`02oooo00D0002JLjJJLjH0003o
ool01@0000>kRJ402@000?gGN?gGN0000?KAZ0000?_GW`0009M]X00200000_6oW0030000oooooooo
00Ooool01@0009]fZ9]fZ9]fZ0000002[WnR00<0003oooooool05?ooo`030000RV2KRV2K00::H9/0
0`0009MYW9MYW002UfVL00D0003k`HD0003b]hh000000_FiR@030000oooooooo02_oool40000D?oo
o`00P_ooo`030000oooooooo03;oool01@000=>UZ0000?c?U@000003j;RR00<0003/_Z?/_Z<01000
00Koool300000_?2V`<00002l;^H00<0003oooooool00oooo`050000VW>V00000000oooo00D00003
^hVQ00L0003megSmegP0003fdJP0003keil010000003lKnL0000oooo00Woool01@0009]fZ9]fZ9]f
Z0000002[WnR00<0003oooooool05?ooo`030000RV2KRV2K00::H9/00`0009MYW9MYW002UfVL0P00
0005]j7200000000mKV9000002_oool30000E?ooo`00Poooo`030000oooooooo037oool020000=>U
Z00000000?ooo`000>RhXP0000?/_Z<300001oooo`<00002ll:K0`0000;`^iP00`000?ooooooo`03
oooo0`0000?oool400000k^9X@030000oMMh000000;fdJP00`000?_GW`000003000000?a_i`0003o
ool02Oooo`030000VgJXVgJX00:KMZP200006?ooo`050000RV2KRV2KRV2K000000>GJI`200000[NQ
`P8000000oFiR@000?ooo`0Voooo100005Ooool008Coool00`000?ooooooo`0`oooo0`0000?oool2
00000^bnX`030000oooo000000Woool01@000??2Vo?2V`000>RdWP0200000_2kV0030000oooooooo
00?oool300000oooo`050000oooo0000001o000000:kRJ401`000?gGN0000?KAZ0000?_GW`000002
hK:U0P000003lKnL0000oooo00[oool200000Y]fZ080000Ioooo0P000003RV2K0000UfVL00800005
]j7200<0003e^HT000008oooo`@0001Koooo0025oooo00<0003oooooool0<?ooo`800004oooo00@0
003/_Z?/_Z<0000;oooo00@0003c`Y_c`Y/00002j;BN00@0003`^iS`^iP00006oooo00<0003ooooo
ool01Oooo`800002^hVQ00L0003megP0003fdJP0003keil000000n6bY@030000lKnL000000goool3
00007?ooo`@00006]j7200<0003e^HT000007oooo`@0001Ooooo0026oooo0P00033oool00`000?oo
ooooo`04oooo0P0000coool400000^RdWP040000l;^Hl;^H00001_ooo`030000oooooooo00Goool2
00000[^9X@800002m]6X00<0003keil000000^6bY@040000lKnLlKnL00003oooo`030000oooooooo
01[oool3000000=KJlT0002gXL800kNQ`P040000f<c>000000006oooo`@0001Soooo0028oooo00<0
003oooooool0;Oooo`030000oooooooo00Goool00`000?ooooooo`0>oooo0P0000?`^iP00`000?oo
ooooo`0<oooo0P000004^hVQ0000oMMh00000_KAZ0800003hK:U00<0003a_i`00000;_ooo`040000
Ff_9Ff_900000kNQ`P030000f<c>f<c>0080000Hoooo0`0006Ooool008Woool00`000?ooooooo`0/
oooo00<0003oooooool05_ooo`800002l;^H00<0003oooooool03Oooo`8000000k^9X@0000000002
m]6X00<0003keil000000n6bY@030000lKnL000002koool200000U][b@040000]j72]j7200000mS<
cP030000oooooooo01;oool40000J_ooo`00R_ooo`030000oooooooo02_oool00`000?ooooooo`0G
oooo00@0003`^iS`^iP0000?oooo0P000003^hVQ0000000000@000001oooo`000>6bYN6bY@000?6o
W000000_oooo10000003]j720000f<c>00;Hc<h00`000?ooooooo`0?oooo100006koool008_oool2
0000:oooo`030000oooooooo01Soool300004?ooo`040000^hVQ000000001Oooo`060000hK:UhK:U
0000lKnL0000<?ooo`04000006CH000000000mS<cP030000oooooooo00coool40000L_ooo`00SOoo
o`030000oooooooo02Soool00`000?ooooooo`0Joooo00<0003oooooool03_ooo`030000^hVQ0000
00Ooool200000_6oW0030000oooooooo02ooool2000000D0I=P0003Hc<kHc<h000002_ooo`@0001f
oooo002>oooo00<0003oooooool09oooo`030000oooooooo02_oool300001oooo`8000000o6oW000
0?ooo`0coooo0P000003f<c>0000oooo00Ooool30000N_ooo`00Soooo`030000oooooooo02Koool0
0`000?ooooooo`0[oooo0`0000Soool00`000?6oW000000foooo00<0003oooooool00oooo`@0001m
oooo002@oooo0P0002Koool00`000?ooooooo`0/oooo0P0000Woool20000>?ooo`@00021oooo002B
oooo00<0003oooooool08oooo`030000oooooooo02coool00`000?ooooooo`0noooo100008Goool0
09?oool00`000?ooooooo`0Roooo00<0003oooooool0;?ooo`030000oooooooo03[oool40000ROoo
o`00U?ooo`030000oooooooo027oool00`000?ooooooo`1Uoooo100008goool009Goool200008Ooo
o`030000oooooooo06;oool30000TOooo`00Uoooo`030000oooooooo01koool00`000?ooooooo`1N
oooo100009Coool009Soool00`000?ooooooo`0Moooo00<0003oooooool0F_ooo`@0002Hoooo002I
oooo00<0003oooooool07?ooo`030000oooooooo05Koool40000W?ooo`00V_ooo`80000Loooo00<0
003oooooool0D_ooo`@0002Poooo002Loooo00<0003oooooool06Oooo`030000oooooooo04ooool3
0000Y?ooo`00WOooo`030000oooooooo01Soool00`000?ooooooo`1;oooo10000:Ooool009koool0
0`000?ooooooo`0Goooo00<0003oooooool0Aoooo`@0002[oooo002Ooooo0P0001Ooool00`000?oo
ooooo`13oooo10000:ooool00:7oool00`000?ooooooo`0Doooo00<0003oooooool0?oooo`@0002c
oooo002Roooo00<0003oooooool04oooo`030000oooooooo03_oool40000]oooo`00Xoooo`030000
oooooooo01;oool00`000?ooooooo`0hoooo0`000;_oool00:Coool200004_ooo`030000oooooooo
03Coool40000__ooo`00Y_ooo`030000oooooooo00koool00`000?ooooooo`0aoooo10000<;oool0
0:Ooool00`000?ooooooo`0=oooo00<0003oooooool0;Oooo`@00036oooo002Xoooo00<0003ooooo
ool03?ooo`030000oooooooo02Woool40000b_ooo`00ZOooo`030000oooooooo00_oool00`000?oo
ooooo`0Voooo0`000<koool00:[oool200002oooo`030000oooooooo02;oool40000dOooo`00[?oo
o`030000oooooooo00Soool00`000?ooooooo`0Noooo10000=Goool00:goool00`000?ooooooo`07
oooo00<0003oooooool06_ooo`@0003Ioooo002^oooo00<0003oooooool01_ooo`030000oooooooo
01Koool40000gOooo`00[oooo`800006oooo00<0003oooooool04_ooo`@0003Qoooo002aoooo00<0
003oooooool00oooo`030000oooooooo00ooool30000iOooo`00/_ooo`030000oooooooo00;oool0
0`000?ooooooo`0;oooo10000>Soool00;?oool01@000?ooooooooooo`000009oooo10000>coool0
0;Coool2000000?oool0003oool01?ooo`@0003`oooo002foooo0P000003oooo000000000080003d
oooo002goooo0P000?Soool00?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003o
oooo/_ooo`00oooook;oool00?oooonboooo0000\
\>"],
  ImageRangeCache->{{{0, 432}, {350.125, 0}} -> {-0.0427243, 0.0477383, 
  0.00230398, 0.00230398}}]
}, Open  ]],

Cell[TextData[StyleBox["Zapis danych do pliku"]], "MathCaption"],

Cell[BoxData[
    \(OutName = "\<autoc_\>"<>ToString[T\[LSlash]umik]<>"\<.data\>"; \n
    OutStream = OpenWrite[OutName]; \n
    WriteString[OutStream, 
      "\<Autocorrelation data\n\>"<>ToString[Length[MaxWPasmach]]<>"\< \>"<>
        ToString[
          Length[MaxWPasmach\[LeftDoubleBracket]1\[RightDoubleBracket]]]<>
        "\<\n\>"]; \n
    For[i = 1, i <= Length[MaxWPasmach], \(i++\), \n\t
      For[j = 1, 
        j <= Length[MaxWPasmach\[LeftDoubleBracket]i\[RightDoubleBracket]], 
        \(j++\), \n\t\t
        WriteString[OutStream, 
          N[MaxWPasmach\[LeftDoubleBracket]i, j\[RightDoubleBracket]]]; \n\t\t
        If[j < Length[MaxWPasmach\[LeftDoubleBracket]i\[RightDoubleBracket]], 
          \n\t\t\tWriteString[OutStream, "\< \>"], \n\t\t\t
          WriteString[OutStream, 
            "\< \>"<>
              ToString[SegL\[LeftDoubleBracket]i\[RightDoubleBracket]]<>
              "\<\n\>"]]]]; \nClose[OutStream]; \)], "Input",
  CellLabel->"In[39]:="],

Cell["Odczyt danych z pliku", "MathCaption"],

Cell[BoxData[
    \(InName = "\<D:\source\mtrack\output\>"; \n
    Res = ReadList[InName, \ Number]; \)], "Input",
  CellLabel->"In[376]:="],

Cell[BoxData[
    \(\(CzSeg = 
      \(Pasma\[LeftDoubleBracket]Res\[RightDoubleBracket] + 
          Pasma\[LeftDoubleBracket]Res + 1\[RightDoubleBracket]\)\/2; \)\)], 
  "Input",
  CellLabel->"In[377]:="],

Cell[BoxData[
    \(\(MaksSegAK = Round[CzP\/CzSeg]; \)\)], "Input",
  CellLabel->"In[378]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analiza wynik\[OAcute]w", "Section"],

Cell["Wy\.9cwietlenie wykres\[OAcute]w", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
      Table[CzP\/MaksSegAK\[LeftDoubleBracket]x\[RightDoubleBracket], {x, 
          Length[MaksSegAK]}], PlotRange -> {{0, SegN + 1}, All}, 
      PlotStyle -> RGBColor[0, 0, 1], Frame -> True, Axes -> False]; \)\)], 
  "Input",
  CellLabel->"In[379]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0185185 -0.197182 0.000980206 [
[.18519 -0.0125 -6 -9 ]
[.18519 -0.0125 6 0 ]
[.37037 -0.0125 -6 -9 ]
[.37037 -0.0125 6 0 ]
[.55556 -0.0125 -6 -9 ]
[.55556 -0.0125 6 0 ]
[.74074 -0.0125 -6 -9 ]
[.74074 -0.0125 6 0 ]
[.92593 -0.0125 -6 -9 ]
[.92593 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09688 -18 -4.5 ]
[-0.0125 .09688 0 4.5 ]
[-0.0125 .1949 -18 -4.5 ]
[-0.0125 .1949 0 4.5 ]
[-0.0125 .29292 -18 -4.5 ]
[-0.0125 .29292 0 4.5 ]
[-0.0125 .39094 -18 -4.5 ]
[-0.0125 .39094 0 4.5 ]
[-0.0125 .48896 -18 -4.5 ]
[-0.0125 .48896 0 4.5 ]
[-0.0125 .58698 -18 -4.5 ]
[-0.0125 .58698 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18519 0 m
.18519 .00625 L
s
[(10)] .18519 -0.0125 0 1 Mshowa
.37037 0 m
.37037 .00625 L
s
[(20)] .37037 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(30)] .55556 -0.0125 0 1 Mshowa
.74074 0 m
.74074 .00625 L
s
[(40)] .74074 -0.0125 0 1 Mshowa
.92593 0 m
.92593 .00625 L
s
[(50)] .92593 -0.0125 0 1 Mshowa
.125 Mabswid
.03704 0 m
.03704 .00375 L
s
.07407 0 m
.07407 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.14815 0 m
.14815 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.25926 0 m
.25926 .00375 L
s
.2963 0 m
.2963 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.40741 0 m
.40741 .00375 L
s
.44444 0 m
.44444 .00375 L
s
.48148 0 m
.48148 .00375 L
s
.51852 0 m
.51852 .00375 L
s
.59259 0 m
.59259 .00375 L
s
.62963 0 m
.62963 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7037 0 m
.7037 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81481 0 m
.81481 .00375 L
s
.85185 0 m
.85185 .00375 L
s
.88889 0 m
.88889 .00375 L
s
.96296 0 m
.96296 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09688 m
.00625 .09688 L
s
[(300)] -0.0125 .09688 1 0 Mshowa
0 .1949 m
.00625 .1949 L
s
[(400)] -0.0125 .1949 1 0 Mshowa
0 .29292 m
.00625 .29292 L
s
[(500)] -0.0125 .29292 1 0 Mshowa
0 .39094 m
.00625 .39094 L
s
[(600)] -0.0125 .39094 1 0 Mshowa
0 .48896 m
.00625 .48896 L
s
[(700)] -0.0125 .48896 1 0 Mshowa
0 .58698 m
.00625 .58698 L
s
[(800)] -0.0125 .58698 1 0 Mshowa
.125 Mabswid
0 .01846 m
.00375 .01846 L
s
0 .03807 m
.00375 .03807 L
s
0 .05767 m
.00375 .05767 L
s
0 .07728 m
.00375 .07728 L
s
0 .11648 m
.00375 .11648 L
s
0 .13609 m
.00375 .13609 L
s
0 .15569 m
.00375 .15569 L
s
0 .1753 m
.00375 .1753 L
s
0 .2145 m
.00375 .2145 L
s
0 .23411 m
.00375 .23411 L
s
0 .25371 m
.00375 .25371 L
s
0 .27332 m
.00375 .27332 L
s
0 .31252 m
.00375 .31252 L
s
0 .33213 m
.00375 .33213 L
s
0 .35173 m
.00375 .35173 L
s
0 .37134 m
.00375 .37134 L
s
0 .41055 m
.00375 .41055 L
s
0 .43015 m
.00375 .43015 L
s
0 .44975 m
.00375 .44975 L
s
0 .46936 m
.00375 .46936 L
s
0 .50857 m
.00375 .50857 L
s
0 .52817 m
.00375 .52817 L
s
0 .54777 m
.00375 .54777 L
s
0 .56738 m
.00375 .56738 L
s
0 .60659 m
.00375 .60659 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.18519 .61178 m
.18519 .61803 L
s
.37037 .61178 m
.37037 .61803 L
s
.55556 .61178 m
.55556 .61803 L
s
.74074 .61178 m
.74074 .61803 L
s
.92593 .61178 m
.92593 .61803 L
s
.125 Mabswid
.03704 .61428 m
.03704 .61803 L
s
.07407 .61428 m
.07407 .61803 L
s
.11111 .61428 m
.11111 .61803 L
s
.14815 .61428 m
.14815 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.25926 .61428 m
.25926 .61803 L
s
.2963 .61428 m
.2963 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.40741 .61428 m
.40741 .61803 L
s
.44444 .61428 m
.44444 .61803 L
s
.48148 .61428 m
.48148 .61803 L
s
.51852 .61428 m
.51852 .61803 L
s
.59259 .61428 m
.59259 .61803 L
s
.62963 .61428 m
.62963 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.7037 .61428 m
.7037 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.81481 .61428 m
.81481 .61803 L
s
.85185 .61428 m
.85185 .61803 L
s
.88889 .61428 m
.88889 .61803 L
s
.96296 .61428 m
.96296 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09688 m
1 .09688 L
s
.99375 .1949 m
1 .1949 L
s
.99375 .29292 m
1 .29292 L
s
.99375 .39094 m
1 .39094 L
s
.99375 .48896 m
1 .48896 L
s
.99375 .58698 m
1 .58698 L
s
.125 Mabswid
.99625 .01846 m
1 .01846 L
s
.99625 .03807 m
1 .03807 L
s
.99625 .05767 m
1 .05767 L
s
.99625 .07728 m
1 .07728 L
s
.99625 .11648 m
1 .11648 L
s
.99625 .13609 m
1 .13609 L
s
.99625 .15569 m
1 .15569 L
s
.99625 .1753 m
1 .1753 L
s
.99625 .2145 m
1 .2145 L
s
.99625 .23411 m
1 .23411 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27332 m
1 .27332 L
s
.99625 .31252 m
1 .31252 L
s
.99625 .33213 m
1 .33213 L
s
.99625 .35173 m
1 .35173 L
s
.99625 .37134 m
1 .37134 L
s
.99625 .41055 m
1 .41055 L
s
.99625 .43015 m
1 .43015 L
s
.99625 .44975 m
1 .44975 L
s
.99625 .46936 m
1 .46936 L
s
.99625 .50857 m
1 .50857 L
s
.99625 .52817 m
1 .52817 L
s
.99625 .54777 m
1 .54777 L
s
.99625 .56738 m
1 .56738 L
s
.99625 .60659 m
1 .60659 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.008 w
.01852 .22661 Mdot
.03704 .2531 Mdot
.05556 .22661 Mdot
.07407 .12066 Mdot
.09259 .22661 Mdot
.11111 .30546 Mdot
.12963 .22661 Mdot
.14815 .22661 Mdot
.16667 .12066 Mdot
.18519 .22661 Mdot
.2037 .2531 Mdot
.22222 .22661 Mdot
.24074 .12066 Mdot
.25926 .22661 Mdot
.27778 .30546 Mdot
.2963 .22661 Mdot
.31481 .12066 Mdot
.33333 .22661 Mdot
.35185 .43851 Mdot
.37037 .22661 Mdot
.38889 .12066 Mdot
.40741 .22661 Mdot
.42593 .43851 Mdot
.44444 .47824 Mdot
.46296 .40319 Mdot
.48148 .32998 Mdot
.5 .27268 Mdot
.51852 .30546 Mdot
.53704 .43851 Mdot
.55556 .37159 Mdot
.57407 .40319 Mdot
.59259 .32998 Mdot
.61111 .04033 Mdot
.62963 .30546 Mdot
.64815 .22661 Mdot
.66667 .2531 Mdot
.68519 .30546 Mdot
.7037 .40319 Mdot
.72222 .40319 Mdot
.74074 .47824 Mdot
.75926 .54811 Mdot
.77778 .60332 Mdot
.7963 .47824 Mdot
.81481 .47824 Mdot
.83333 .06965 Mdot
.85185 .2531 Mdot
.87037 .22661 Mdot
.88889 .01472 Mdot
.90741 .43851 Mdot
.92593 .22661 Mdot
.94444 .60332 Mdot
.96296 .22661 Mdot
.98148 .22661 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[379]:=",
  ImageSize->{425, 262.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Y00011QP00`40o`000?l0003ooooooj[oool0
05coool500000_ooo`030000oooooooo047oool300000oooo`030000oooooooo047oool200001?oo
o`030000oooooooo04;oool300000_ooo`030000oooooooo04?oool00`000?ooooooo`02oooo00<0
003oooooool06_ooo`00G_ooo`070000oooooooooooo0000oooo000004;oool00`000?ooooooo`02
oooo00<0003oool00000A?ooo`060000oooooooo0000oooo0000A?ooo`060000oooooooo0000oooo
0000@oooo`030000oooo000000;oool00`000?ooo`00000Koooo001Noooo00L0003oooooooooool0
003oool00000@oooo`070000oooooooooooo0000oooo000004?oool01`000?ooooooooooo`000?oo
o`000012oooo10000004oooo0000oooo0000AOooo`060000oooooooo0000oooo00006oooo`00G_oo
o`070000oooooooooooo0000oooo000004?oool01`000?ooooooooooo`000?ooo`000014oooo00H0
003oooooool0003oool00012oooo00<0003oool000000_ooo`030000oooo000004?oool200000ooo
o`030000oooo000001_oool005koool01`000?ooooooooooo`000?ooo`000012oooo00<0003oool0
00000_ooo`030000oooo000004;oool00`000?ooo`000002oooo00<0003oool00000@oooo`800002
oooo00<0003oool00000@oooo`030000oooooooo00;oool00`000?ooo`00000Koooo001Moooo0P00
00Coool00`000?ooooooo`12oooo00<0003oooooool00_ooo`030000oooooooo04;oool00`000?oo
ooooo`02oooo00<0003oooooool0@oooo`050000oooooooooooo000004Coool300000oooo`030000
oooooooo01[oool00?oooonZoooo003oooooZ_ooo`00oooooj[oool00?oooonZoooo003oooooZ_oo
o`00oooooj[oool00?oooonZoooo000Gooooo`0009800001oooo000Goooo00<0003oooooool03?oo
o`030000oooooooo00_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00_oool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00_oool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00_oool00`000?ooooooo`0<oooo0@00
007oool001Ooool00`000?ooooooo`17oooo00<0003oooooool0Aoooo`030000oooooooo04Ooool0
0`000?ooooooo`17oooo00<0003oooooool0B?ooo`030000oooooooo01[oool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooof;oool00`00ooooooooo`0Yoooo0@00007oool001Ooool0
0`000?ooooooo`3oooooHOooo`<00?lZoooo0@00007oool001Ooool20000ooooof?oool00`00oooo
ooooo`0Xoooo0P00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0
003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo0P000?;oool00`00ooooooooo`2Hoooo0P00007oool001Ooool0
0`000?ooooooo`3`oooo0`00oi[oool100000Oooo`005oooo`030000oooooooo0?7oool00`00oooo
ooooo`2Ioooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0
003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`80003oooooS_ooo`800001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo00<0003oooooool0oooood_oool00`00ooooooooo`10oooo0@00
007oool001Ooool00`000?ooooooo`3oooooB_ooo`<00?m1oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooBoooo`03003ooooooooo043oool100000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool20000ooooohkoool200000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003ooooo
ool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool0
0`000?ooooooo`3oooooS_ooo`400001oooo0004oooo0P0000Coool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo0?oooon>oooo0@00007oool000Koool01P000?ooooooo`00
0?ooo`0000;oool00`000?ooo`000006oooo00<0003oooooool0ooooohkoool100000Oooo`001Ooo
o`070000oooooooooooo0000oooo000000;oool00`000?ooo`000006oooo0`000?oooon<oooo0`00
007oool000Koool01P000?ooooooo`000?ooo`0000;oool00`000?ooo`000006oooo00<0003ooooo
ool0ooooohkoool100000Oooo`001?ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0
003oool000001_ooo`030000oooooooo0?oooon>oooo0@00007oool000Goool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003ooooo
ool0ooooohkoool100000Oooo`005oooo`80000Koooo00<00?ooooooool08_ooo`03003ooooooooo
01_oool00`00ooooooooo`0Koooo00<00?ooooooool06_ooo`03003ooooooooo0?7oool200000Ooo
o`005oooo`030000oooooooo01Woool3003o8_ooo`<00?lKoooo0`00oa_oool3003o6_ooo`<00?oc
oooo0@00007oool001Ooool00`000?ooooooo`0Joooo00<00?ooooooool08_ooo`03003ooooooooo
01_oool00`00ooooooooo`0Koooo00<00?ooooooool06_ooo`03003ooooooooo0?;oool100000Ooo
o`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_oo
o`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo
0?oooon>oooo0@00007oool001Ooool20000ooooohkoool200000Oooo`005oooo`030000oooooooo
0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0
003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool20000ooooohkoool2
00000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000
oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool20000ooooohkoool200000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo0005oooo0`0000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo0?oooon>oooo0@00007oool000Koool01P000?ooooooo`000?ooo`00
00;oool00`000?ooo`000006oooo00<0003oooooool0ooooohkoool100000Oooo`001?ooo`@00000
1?ooo`000?ooo`0000;oool00`000?ooo`000006oooo0`000?oooon<oooo0`00007oool000Coool0
0`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`3o
ooooS_ooo`400001oooo0005oooo0P0000;oool00`000?ooo`000002oooo00<0003oool000001_oo
o`030000oooooooo0?oooon>oooo0@00007oool000Koool01@000?ooooooooooo`000004oooo00<0
003oooooool01Oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000
oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000G
oooo0P000?oooon>oooo0P00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool00`000?ooooooo`04oooo00<00?ooooooool03?ooo`03003ooooooooo00coool0
0`00ooooooooo`0<oooo00<00?ooooooool01?ooo`03003ooooooooo00coool00`00ooooooooo`0<
oooo00<00?ooooooool02oooo`03003ooooooooo00coool00`00ooooooooo`0<oooo00<00?oooooo
ool03?ooo`03003ooooooooo00coool00`00ooooooooo`1Moooo00<00?ooooooool0E_ooo`03003o
oooooooo01?oool00`00ooooooooo`0<oooo00<00?ooooooool01Oooo`03003ooooooooo00Coool1
00000Oooo`005oooo`030000oooooooo00?oool3003o3?ooo`<00?l<oooo0`00o`coool3003o1?oo
o`<00?l<oooo0`00o`coool3003o2oooo`<00?l<oooo0`00o`coool3003o3?ooo`<00?l<oooo0`00
oegoool3003oE_ooo`<00?lCoooo0`00o`coool3003o1Oooo`<00?l5oooo0@00007oool001Ooool0
0`000?ooooooo`04oooo00<00?ooooooool03?ooo`03003ooooooooo00coool00`00ooooooooo`0<
oooo00<00?ooooooool01?ooo`03003ooooooooo00coool00`00ooooooooo`0<oooo00<00?oooooo
ool02oooo`03003ooooooooo00coool00`00ooooooooo`0<oooo00<00?ooooooool03?ooo`03003o
oooooooo00coool00`00ooooooooo`1Moooo00<00?ooooooool0E_ooo`03003ooooooooo01?oool0
0`00ooooooooo`0<oooo00<00?ooooooool01Oooo`03003ooooooooo00Coool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool20000ooooohkoool200000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003ooooo
ool02oooo`03003ooooooooo043oool00`00ooooooooo`2goooo00<00?ooooooool0Aoooo`03003o
oooooooo03Soool100000Oooo`005oooo`030000oooooooo00[oool3003o@?ooo`<00?ngoooo0`00
odOoool3003o>Oooo`400001oooo000Goooo0P0000coool00`00ooooooooo`10oooo00<00?oooooo
ool0]oooo`03003ooooooooo04Ooool00`00ooooooooo`0goooo0P00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0<Goool0
0`00ooooooooo`35oooo0@00007oool001Ooool20000aOooo`<00?o5oooo0P00007oool001Ooool0
0`000?ooooooo`35oooo00<00?ooooooool0aOooo`400001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`001Ooo
o`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
0?oooon>oooo0@00007oool000Coool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000000Koool00`000?ooooooo`3oooooS_ooo`400001oooo0006oooo00H0003oooooool0003o
ool00002oooo00<0003oool000001_ooo`<0003oooooS?ooo`<00001oooo0004oooo0P0000?oool0
0`000?ooo`000002oooo00<0003oool000001_ooo`030000oooooooo0?oooon>oooo0@00007oool0
00Coool00`000?ooooooo`02oooo00<0003oool000000_ooo`030000oooo000000Koool00`000?oo
ooooo`3oooooS_ooo`400001oooo0004oooo0`0000?oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`0Yoooo00<0
0?ooooooool0@?ooo`03003ooooooooo05goool00`00ooooooooo`0Zoooo00<00?ooooooool04ooo
o`03003ooooooooo07_oool100000Oooo`005oooo`030000oooooooo02Soool3003o@?ooo`<00?mM
oooo0`00ob[oool3003o4oooo`<00?mloooo0@00007oool001Ooool00`000?ooooooo`0Yoooo00<0
0?ooooooool0@?ooo`03003ooooooooo05goool00`00ooooooooo`0Zoooo00<00?ooooooool04ooo
o`03003ooooooooo07_oool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool20000ooooohkoool200000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo00<0003oooooool0_Oooo`03003ooooooooo02[oool00`00oooo
ooooo`2Poooo0@00007oool001Ooool00`000?ooooooo`2loooo0`00ob[oool3003oXOooo`400001
oooo000Goooo0P000;koool00`00ooooooooo`0Zoooo00<00?ooooooool0Woooo`800001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`80003oooooS_ooo`800001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003ooooo
ool0foooo`03003ooooooooo0:ooool100000Oooo`005oooo`80003Koooo0`00ojooool200000Ooo
o`005oooo`030000oooooooo0=_oool00`00ooooooooo`2_oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo0004oooo0P0000Coool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
0?oooon>oooo0@00007oool000Coool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000000Koool00`000?ooooooo`3oooooS_ooo`400001oooo0004oooo00<0003oool000000_oo
o`030000oooo000000;oool00`000?ooo`000006oooo0`000?oooon<oooo0`00007oool000Coool2
00000oooo`030000oooo000000;oool00`000?ooo`000006oooo00<0003oooooool0ooooohkoool1
00000Oooo`001?ooo`030000oooooooo00;oool00`000?ooo`000002oooo00<0003oool000001_oo
o`030000oooooooo0?oooon>oooo0@00007oool000Goool200000oooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo
0;Koool00`00ooooooooo`0Zoooo00<00?ooooooool0<?ooo`03003ooooooooo00Goool00`00oooo
ooooo`1/oooo0@00007oool001Ooool00`000?ooooooo`2eoooo0`00ob[oool3003o<?ooo`<00?l5
oooo0`00ofgoool100000Oooo`005oooo`030000oooooooo0;Koool00`00ooooooooo`0Zoooo00<0
0?ooooooool0<?ooo`03003ooooooooo00Goool00`00ooooooooo`1/oooo0@00007oool001Ooool2
0000ooooohkoool200000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool0
0`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Ooo
o`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_oo
o`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo
0?oooon>oooo0@00007oool001Ooool20000ooooohkoool200000Oooo`005oooo`030000oooooooo
0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0
003oooooool0R_ooo`03003ooooooooo01[oool00`00ooooooooo`0Zoooo00<00?ooooooool0TOoo
o`03003ooooooooo02;oool100000Oooo`005oooo`030000oooooooo08Woool3003o6_ooo`<00?lZ
oooo0`00oi7oool3003o8oooo`400001oooo000Goooo00<0003oooooool0R_ooo`03003ooooooooo
01[oool00`00ooooooooo`0Zoooo00<00?ooooooool0TOooo`03003ooooooooo02;oool100000Ooo
o`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_oo
o`400001oooo000Goooo0P000?oooon>oooo0P00007oool001Ooool00`000?ooooooo`3oooooS_oo
o`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo
0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0
003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo0P000?oooon>oooo0P00007oool0
01Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool1
00000Oooo`005oooo`030000oooooooo0:ooool00`00ooooooooo`1coooo00<00?ooooooool05?oo
o`03003ooooooooo00Coool00`00ooooooooo`17oooo0@00007oool001Ooool00`000?ooooooo`2^
oooo0`00og?oool3003o5?ooo`<00?l4oooo0`00odSoool100000Oooo`005oooo`030000oooooooo
0:ooool00`00ooooooooo`1coooo00<00?ooooooool05?ooo`03003ooooooooo00Coool00`00oooo
ooooo`17oooo0@00007oool000Goool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`3oooooS_ooo`400001oooo0005oooo00L0003oooooooooool0
003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`3oooooS_ooo`400001oooo0005
oooo00L0003oooooooooool0003oool000000_ooo`030000oooo000000Koool30000ooooohcoool3
00000Oooo`001_ooo`060000oooooooo0000oooo00000_ooo`030000oooo000000Koool00`000?oo
ooooo`3oooooS_ooo`400001oooo0004oooo00<0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`000006oooo00<0003oooooool0ooooohkoool100000Oooo`001?ooo`<00003oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`3oooooS_ooo`400001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`80003oooooS_ooo`800001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`80003oooooS_ooo`800001
oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>
oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003ooooo
ool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool0
0`000?ooooooo`3oooooS_ooo`400001oooo000Goooo0P000?ooool_oooo00<00?ooooooool0G?oo
o`800001oooo000Goooo00<0003oooooool0ooooobgoool3003oG_ooo`400001oooo000Goooo00<0
003oooooool0ooooobkoool00`00ooooooooo`1Moooo0@00007oool001Ooool00`000?ooooooo`3o
ooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000
oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`80003oooooS_ooo`800001oooo000G
oooo00<0003oooooool0ooooohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00
007oool001Ooool00`000?ooooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0oooo
ohkoool100000Oooo`005oooo`030000oooooooo0?oooon>oooo0@00007oool000Goool00`000?oo
ooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`3oooooS_oo
o`400001oooo0004oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000006
oooo00<0003oooooool0ooooohkoool100000Oooo`001?ooo`030000oooo000000;oool00`000?oo
o`000002oooo00<0003oool000001_ooo`<0003oooooS?ooo`<00001oooo0005oooo00L0003ooooo
ooooool0003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`3oooooS_ooo`400001
oooo0004oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000006oooo00<0
003oooooool0ooooohkoool100000Oooo`001Oooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`030000oooooooo0?oooon>oooo0@00007oool001Ooool00`000?oo
ooooo`3oooooS_ooo`400001oooo000Goooo00<0003oooooool0ooooohkoool100000Oooo`005ooo
o`030000oooooooo0?ooooleoooo00<00?ooooooool0@?ooo`03003ooooooooo01?oool100000Ooo
o`005oooo`030000oooooooo0?ooooldoooo0`00od3oool3003o5?ooo`400001oooo000Goooo0P00
0?oooolfoooo00<00?ooooooool0@?ooo`03003ooooooooo01;oool200000Oooo`005oooo`030000
oooooooo0?oooon>oooo0@00007oool001Ooool00`000?ooooooo`17oooo00<0003oooooool0Aooo
o`030000oooooooo04Ooool00`000?ooooooo`17oooo00<0003oooooool0B?ooo`030000oooooooo
01[oool100000Oooo`005oooo`030000oooooooo00coool00`000?ooooooo`0;oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0;oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0;
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0;oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0;oooo00<0003oooooool03?ooo`400001oooo000Gooooo`0009800001oooo0000
\
\>"],
  ImageRangeCache->{{{0, 424}, {261.563, 0}} -> {-3.12297, 165.485, 0.134814, 
  2.54697}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Analiza pojedynczych ramek sygna\[LSlash]u"], "Section"],

Cell[TextData[{
  "Znalezienie maksimum lokalnego funkcji autokorelacji \
po\[LSlash]o\:017conego najbli\:017cej ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f\_0\)]]],
  " wyznaczonej w segmencie"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TabFreq = {}; \nTabVal = {}; \nprevloc = 0; \nk = 1; \n
    For[i = 1, i <= Length[T\[LSlash]AutoK], \(i++\), \n\t
      If[SegPoints\[LeftDoubleBracket]i\[RightDoubleBracket] == 1, \(k++\)]; 
      \n\tAKVal = 
        Max[T\[LSlash]AutoK\[LeftDoubleBracket]i\[RightDoubleBracket]]; \n\t
      loc = \(initloc = 
          MaksSegAK\[LeftDoubleBracket]k\[RightDoubleBracket]\); \n\t
      While[T\[LSlash]AutoK\[LeftDoubleBracket]i, loc\[RightDoubleBracket] < 
            T\[LSlash]AutoK\[LeftDoubleBracket]i, 
              loc + 1\[RightDoubleBracket] || 
          T\[LSlash]AutoK\[LeftDoubleBracket]i, loc\[RightDoubleBracket] < 
            T\[LSlash]AutoK\[LeftDoubleBracket]i, 
              loc - 1\[RightDoubleBracket], \n\t\t
        If[T\[LSlash]AutoK\[LeftDoubleBracket]i, 
              loc + 1\[RightDoubleBracket] > 
            T\[LSlash]AutoK\[LeftDoubleBracket]i, 
              loc - 1\[RightDoubleBracket], \(loc++\), \(loc--\)]]; \n\t
      ToF = {T\[LSlash]AutoK\[LeftDoubleBracket]i, 
            loc - 1\[RightDoubleBracket], 
          T\[LSlash]AutoK\[LeftDoubleBracket]i, loc\[RightDoubleBracket], 
          T\[LSlash]AutoK\[LeftDoubleBracket]i, 
            loc + 1\[RightDoubleBracket]}; \n\t
      If[SegMeas\[LeftDoubleBracket]i\[RightDoubleBracket] < 1 && 
          \((loc\/initloc > \@2\%12 || loc\/initloc < \@\(2\^\(-1\)\)\%12)\), 
        loc = prevloc]; \n\tprevloc = loc; \n\t
      poly = \(-Fit[ToF, {1, x, x\^2}, x]\); \n\t
      korekta = 
        x /. \(FindMinimum[poly, {x, 1}]\)\[LeftDoubleBracket]2
            \[RightDoubleBracket]; \n\tacloc = loc + korekta - 2; \n\t
      AppendTo[TabFreq, CzP\/acloc]; \n]; \)], "Input",
  CellLabel->"In[380]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Part::"partw"\), \( : \ \), 
        "\<\"Part \\!\\(TraditionalForm\\`1919\\) of \\!\\(TraditionalForm\\`\
\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\)\\) does not exist.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Part::"partw"\), \( : \ \), 
        "\<\"Part \\!\\(TraditionalForm\\`1920\\) of \\!\\(TraditionalForm\\`\
\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\)\\) does not exist.\"\>"}], 
      TraditionalForm]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[TabFreq, PlotJoined -> False, 
      PlotStyle -> {RGBColor[0, 0, 1], PointSize[0.005]}, Frame -> True, 
      Axes -> False]; \)\)], "Input",
  CellLabel->"In[381]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000496032 0.0147151 0.000593449 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.27183 -0.0125 -9 -9 ]
[.27183 -0.0125 9 0 ]
[.51984 -0.0125 -12 -9 ]
[.51984 -0.0125 12 0 ]
[.76786 -0.0125 -12 -9 ]
[.76786 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1334 -18 -4.5 ]
[-0.0125 .1334 0 4.5 ]
[-0.0125 .25209 -18 -4.5 ]
[-0.0125 .25209 0 4.5 ]
[-0.0125 .37078 -18 -4.5 ]
[-0.0125 .37078 0 4.5 ]
[-0.0125 .48947 -18 -4.5 ]
[-0.0125 .48947 0 4.5 ]
[-0.0125 .60816 -24 -4.5 ]
[-0.0125 .60816 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.27183 0 m
.27183 .00625 L
s
[(500)] .27183 -0.0125 0 1 Mshowa
.51984 0 m
.51984 .00625 L
s
[(1000)] .51984 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(1500)] .76786 -0.0125 0 1 Mshowa
.125 Mabswid
.07341 0 m
.07341 .00375 L
s
.12302 0 m
.12302 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.37103 0 m
.37103 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.56944 0 m
.56944 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66865 0 m
.66865 .00375 L
s
.71825 0 m
.71825 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.86706 0 m
.86706 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.96627 0 m
.96627 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1334 m
.00625 .1334 L
s
[(200)] -0.0125 .1334 1 0 Mshowa
0 .25209 m
.00625 .25209 L
s
[(400)] -0.0125 .25209 1 0 Mshowa
0 .37078 m
.00625 .37078 L
s
[(600)] -0.0125 .37078 1 0 Mshowa
0 .48947 m
.00625 .48947 L
s
[(800)] -0.0125 .48947 1 0 Mshowa
0 .60816 m
.00625 .60816 L
s
[(1000)] -0.0125 .60816 1 0 Mshowa
.125 Mabswid
0 .04439 m
.00375 .04439 L
s
0 .07406 m
.00375 .07406 L
s
0 .10373 m
.00375 .10373 L
s
0 .16308 m
.00375 .16308 L
s
0 .19275 m
.00375 .19275 L
s
0 .22242 m
.00375 .22242 L
s
0 .28177 m
.00375 .28177 L
s
0 .31144 m
.00375 .31144 L
s
0 .34111 m
.00375 .34111 L
s
0 .40046 m
.00375 .40046 L
s
0 .43013 m
.00375 .43013 L
s
0 .4598 m
.00375 .4598 L
s
0 .51915 m
.00375 .51915 L
s
0 .54882 m
.00375 .54882 L
s
0 .57849 m
.00375 .57849 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.27183 .61178 m
.27183 .61803 L
s
.51984 .61178 m
.51984 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.125 Mabswid
.07341 .61428 m
.07341 .61803 L
s
.12302 .61428 m
.12302 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.37103 .61428 m
.37103 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.56944 .61428 m
.56944 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.66865 .61428 m
.66865 .61803 L
s
.71825 .61428 m
.71825 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.86706 .61428 m
.86706 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.96627 .61428 m
.96627 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1334 m
1 .1334 L
s
.99375 .25209 m
1 .25209 L
s
.99375 .37078 m
1 .37078 L
s
.99375 .48947 m
1 .48947 L
s
.99375 .60816 m
1 .60816 L
s
.125 Mabswid
.99625 .04439 m
1 .04439 L
s
.99625 .07406 m
1 .07406 L
s
.99625 .10373 m
1 .10373 L
s
.99625 .16308 m
1 .16308 L
s
.99625 .19275 m
1 .19275 L
s
.99625 .22242 m
1 .22242 L
s
.99625 .28177 m
1 .28177 L
s
.99625 .31144 m
1 .31144 L
s
.99625 .34111 m
1 .34111 L
s
.99625 .40046 m
1 .40046 L
s
.99625 .43013 m
1 .43013 L
s
.99625 .4598 m
1 .4598 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54882 m
1 .54882 L
s
.99625 .57849 m
1 .57849 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.0253 .26569 Mdot
.02579 .26813 Mdot
.02629 .26677 Mdot
.02679 .2674 Mdot
.02728 .26457 Mdot
.02778 .26455 Mdot
.02827 .27214 Mdot
.02877 .27152 Mdot
.02927 .27207 Mdot
.02976 .27095 Mdot
.03026 .25537 Mdot
.03075 .25989 Mdot
.03125 .26912 Mdot
.03175 .27089 Mdot
.03224 .2725 Mdot
.03274 .27407 Mdot
.03323 .27509 Mdot
.03373 .27563 Mdot
.03423 .27574 Mdot
.03472 .27538 Mdot
.03522 .275 Mdot
.03571 .27489 Mdot
.03621 .27471 Mdot
.03671 .27491 Mdot
.0372 .27518 Mdot
.0377 .27514 Mdot
.03819 .275 Mdot
.03869 .27492 Mdot
.03919 .27482 Mdot
.03968 .27475 Mdot
.04018 .27456 Mdot
.04067 .27438 Mdot
.04117 .27433 Mdot
.04167 .27421 Mdot
.04216 .27399 Mdot
.04266 .27399 Mdot
.04315 .27414 Mdot
.04365 .27419 Mdot
.04415 .27427 Mdot
.04464 .2745 Mdot
.04514 .27452 Mdot
.04563 .27451 Mdot
.04613 .27468 Mdot
.04663 .27494 Mdot
.04712 .27529 Mdot
.04762 .27551 Mdot
.04812 .27568 Mdot
.04861 .27597 Mdot
.04911 .27638 Mdot
.0496 .27665 Mdot
.0501 .27675 Mdot
.0506 .27687 Mdot
.05109 .277 Mdot
.05159 .2769 Mdot
.05208 .27675 Mdot
.05258 .27675 Mdot
.05308 .27688 Mdot
.05357 .27696 Mdot
.05407 .27687 Mdot
.05456 .27676 Mdot
.05506 .2767 Mdot
.05556 .27671 Mdot
.05605 .27658 Mdot
.05655 .27632 Mdot
.05704 .27591 Mdot
.05754 .27539 Mdot
.05804 .27497 Mdot
.05853 .2746 Mdot
.05903 .27408 Mdot
.05952 .27332 Mdot
.06002 .27224 Mdot
.06052 .27119 Mdot
.06101 .27074 Mdot
.06151 .27155 Mdot
.062 .27245 Mdot
.0625 .27331 Mdot
.063 .27409 Mdot
.06349 .27477 Mdot
.06399 .27527 Mdot
.06448 .27563 Mdot
.06498 .27593 Mdot
.06548 .27645 Mdot
.06597 .27724 Mdot
.06647 .2782 Mdot
.06696 .27841 Mdot
.06746 .27787 Mdot
.06796 .27772 Mdot
.06845 .27759 Mdot
.06895 .27736 Mdot
.06944 .27773 Mdot
.06994 .27828 Mdot
.07044 .27813 Mdot
.07093 .27756 Mdot
.07143 .27751 Mdot
.07192 .27788 Mdot
.07242 .27789 Mdot
.07292 .27752 Mdot
.07341 .27701 Mdot
.07391 .27643 Mdot
.0744 .276 Mdot
.0749 .27549 Mdot
.0754 .27485 Mdot
.07589 .27433 Mdot
.07639 .27423 Mdot
.07688 .27402 Mdot
.07738 .27375 Mdot
.07788 .27336 Mdot
.07837 .27276 Mdot
.07887 .2721 Mdot
.07937 .27187 Mdot
.07986 .27221 Mdot
.08036 .27318 Mdot
.08085 .27432 Mdot
.08135 .27513 Mdot
.08185 .27552 Mdot
.08234 .27575 Mdot
.08284 .27591 Mdot
.08333 .27615 Mdot
.08383 .2767 Mdot
.08433 .2776 Mdot
.08482 .27819 Mdot
.08532 .27806 Mdot
.08581 .27785 Mdot
.08631 .27762 Mdot
.08681 .27747 Mdot
.0873 .27778 Mdot
.0878 .27808 Mdot
.08829 .2779 Mdot
.08879 .27762 Mdot
.08929 .27766 Mdot
.08978 .27786 Mdot
.09028 .27793 Mdot
.09077 .27738 Mdot
.09127 .27656 Mdot
.09177 .27588 Mdot
.09226 .27518 Mdot
.09276 .27462 Mdot
.09325 .27423 Mdot
.09375 .27373 Mdot
.09425 .27362 Mdot
.09474 .27346 Mdot
.09524 .2732 Mdot
.09573 .27291 Mdot
.09623 .27268 Mdot
.09673 .27242 Mdot
.09722 .27213 Mdot
.09772 .27241 Mdot
.09821 .27318 Mdot
.09871 .27439 Mdot
.09921 .27512 Mdot
.0997 .27528 Mdot
.1002 .27537 Mdot
.10069 .27549 Mdot
.10119 .27569 Mdot
.10169 .27601 Mdot
.10218 .27648 Mdot
.10268 .27711 Mdot
.10317 .2781 Mdot
.10367 .27798 Mdot
.10417 .27748 Mdot
.10466 .27745 Mdot
.10516 .27775 Mdot
.10565 .27793 Mdot
.10615 .27796 Mdot
.10665 .27759 Mdot
.10714 .27757 Mdot
.10764 .27816 Mdot
.10813 .2783 Mdot
.10863 .27715 Mdot
.10913 .27653 Mdot
.10962 .27651 Mdot
.11012 .27652 Mdot
.11062 .27618 Mdot
.11111 .27594 Mdot
.11161 .27564 Mdot
.1121 .27522 Mdot
.1126 .27484 Mdot
.1131 .27475 Mdot
.11359 .27502 Mdot
.11409 .27548 Mdot
.11458 .27601 Mdot
.11508 .2764 Mdot
.11558 .27657 Mdot
.11607 .27679 Mdot
.11657 .27693 Mdot
.11706 .27679 Mdot
.11756 .27671 Mdot
.11806 .27686 Mdot
.11855 .27718 Mdot
.11905 .27773 Mdot
.11954 .27826 Mdot
.12004 .2787 Mdot
.12054 .27847 Mdot
.12103 .27837 Mdot
.12153 .27863 Mdot
.12202 .27846 Mdot
.12252 .27788 Mdot
.12302 .27773 Mdot
.12351 .27755 Mdot
.12401 .27703 Mdot
.1245 .27638 Mdot
.125 .27583 Mdot
.1255 .27613 Mdot
.12599 .2771 Mdot
.12649 .27731 Mdot
.12698 .27675 Mdot
.12748 .27633 Mdot
.12798 .27959 Mdot
.12847 .28118 Mdot
.12897 .30688 Mdot
.12946 .30865 Mdot
.12996 .30865 Mdot
.13046 .30877 Mdot
.13095 .30893 Mdot
.13145 .30985 Mdot
.13194 .30984 Mdot
.13244 .31017 Mdot
.13294 .30967 Mdot
.13343 .31002 Mdot
.13393 .30926 Mdot
.13442 .30987 Mdot
.13492 .31003 Mdot
.13542 .3095 Mdot
.13591 .30828 Mdot
.13641 .3099 Mdot
.1369 .30835 Mdot
.1374 .3085 Mdot
.1379 .30975 Mdot
.13839 .30966 Mdot
.13889 .31002 Mdot
.13938 .31074 Mdot
.13988 .31053 Mdot
.14038 .31078 Mdot
.14087 .31085 Mdot
.14137 .31077 Mdot
.14187 .30994 Mdot
.14236 .30965 Mdot
.14286 .31029 Mdot
.14335 .30995 Mdot
.14385 .31017 Mdot
.14435 .31551 Mdot
.14484 .31462 Mdot
.14534 .26771 Mdot
.14583 .27277 Mdot
.14633 .27507 Mdot
.14683 .27608 Mdot
.14732 .27677 Mdot
.14782 .2769 Mdot
.14831 .27704 Mdot
.14881 .27703 Mdot
.14931 .27719 Mdot
.1498 .27725 Mdot
.1503 .27776 Mdot
.15079 .27772 Mdot
.15129 .27799 Mdot
.15179 .27812 Mdot
.15228 .27838 Mdot
.15278 .27806 Mdot
.15327 .27794 Mdot
.15377 .27768 Mdot
.15427 .27744 Mdot
.15476 .27757 Mdot
.15526 .2784 Mdot
.15575 .27833 Mdot
.15625 .27744 Mdot
.15675 .2776 Mdot
.15724 .27835 Mdot
.15774 .27806 Mdot
.15823 .27736 Mdot
.15873 .21905 Mdot
.15923 .21928 Mdot
.15972 .21086 Mdot
.16022 .20624 Mdot
.16071 .20721 Mdot
.16121 .20854 Mdot
.16171 .20994 Mdot
.1622 .21014 Mdot
.1627 .21053 Mdot
.16319 .21062 Mdot
.16369 .21058 Mdot
.16419 .21056 Mdot
.16468 .21041 Mdot
.16518 .21059 Mdot
.16567 .21072 Mdot
.16617 .21111 Mdot
.16667 .21066 Mdot
.16716 .21122 Mdot
.16766 .21111 Mdot
.16815 .2111 Mdot
.16865 .21073 Mdot
.16915 .27784 Mdot
.16964 .27735 Mdot
.17014 .27795 Mdot
.17063 .27755 Mdot
.17113 .27663 Mdot
.17163 .27634 Mdot
.17212 .27122 Mdot
.17262 .26883 Mdot
.17312 .26993 Mdot
.17361 .27394 Mdot
.17411 .27131 Mdot
.1746 .26993 Mdot
.1751 .27044 Mdot
.1756 .27428 Mdot
.17609 .27561 Mdot
.17659 .27554 Mdot
.17708 .27624 Mdot
.17758 .27638 Mdot
.17808 .27663 Mdot
.17857 .27681 Mdot
.17907 .27681 Mdot
.17956 .27685 Mdot
.18006 .27655 Mdot
.18056 .27702 Mdot
.18105 .27721 Mdot
.18155 .27792 Mdot
.18204 .27805 Mdot
.18254 .27697 Mdot
.18304 .27636 Mdot
.18353 .27681 Mdot
.18403 .27664 Mdot
.18452 .27631 Mdot
.18502 .27591 Mdot
.18552 .27714 Mdot
.18601 .27471 Mdot
.18651 .27394 Mdot
.187 .27473 Mdot
.1875 .27706 Mdot
.188 .27706 Mdot
.18849 .27638 Mdot
.18899 .27661 Mdot
.18948 .34309 Mdot
.18998 .34516 Mdot
.19048 .34422 Mdot
.19097 .34546 Mdot
.19147 .34491 Mdot
.19196 .34582 Mdot
.19246 .34551 Mdot
.19296 .34617 Mdot
.19345 .3462 Mdot
.19395 .34552 Mdot
.19444 .34614 Mdot
.19494 .34525 Mdot
.19544 .34664 Mdot
.19593 .34575 Mdot
.19643 .25117 Mdot
.19692 .2588 Mdot
.19742 .26589 Mdot
.19792 .26726 Mdot
.19841 .27003 Mdot
.19891 .2711 Mdot
.1994 .27217 Mdot
.1999 .27415 Mdot
.2004 .27588 Mdot
.20089 .27812 Mdot
.20139 .27604 Mdot
.20188 .27547 Mdot
.20238 .28446 Mdot
.20288 .26758 Mdot
.20337 .27133 Mdot
.20387 .27438 Mdot
.20437 .2754 Mdot
.20486 .27563 Mdot
.20536 .27599 Mdot
.20585 .27596 Mdot
.20635 .27596 Mdot
.20685 .27572 Mdot
.20734 .27563 Mdot
.20784 .27632 Mdot
.20833 .27578 Mdot
.20883 .27651 Mdot
.20933 .27607 Mdot
.20982 .27578 Mdot
.21032 .27484 Mdot
.21081 .2741 Mdot
.21131 .27471 Mdot
.21181 .27593 Mdot
.2123 .27579 Mdot
.2128 .27658 Mdot
.21329 .27541 Mdot
.21379 .27587 Mdot
.21429 .21455 Mdot
.21478 .21319 Mdot
.21528 .21337 Mdot
.21577 .21468 Mdot
.21627 .21244 Mdot
.21677 .20662 Mdot
.21726 .20707 Mdot
.21776 .20867 Mdot
.21825 .20983 Mdot
.21875 .21009 Mdot
.21925 .21031 Mdot
.21974 .21017 Mdot
.22024 .21026 Mdot
.22073 .21029 Mdot
.22123 .21054 Mdot
.22173 .21042 Mdot
.22222 .21015 Mdot
.22272 .21084 Mdot
.22321 .21046 Mdot
.22371 .21047 Mdot
.22421 .27416 Mdot
.2247 .27935 Mdot
.2252 .2781 Mdot
.22569 .28093 Mdot
.22619 .27649 Mdot
.22669 .27668 Mdot
.22718 .27474 Mdot
.22768 .27246 Mdot
.22817 .27173 Mdot
.22867 .27223 Mdot
.22917 .27296 Mdot
.22966 .27604 Mdot
.23016 .27171 Mdot
.23065 .27116 Mdot
.23115 .27345 Mdot
.23165 .27466 Mdot
.23214 .27538 Mdot
.23264 .27592 Mdot
.23313 .27652 Mdot
.23363 .27604 Mdot
.23413 .27588 Mdot
.23462 .27625 Mdot
.23512 .27597 Mdot
.23562 .27627 Mdot
.23611 .27635 Mdot
.23661 .27739 Mdot
.2371 .27683 Mdot
.2376 .27682 Mdot
.2381 .27623 Mdot
.23859 .27554 Mdot
.23909 .27582 Mdot
.23958 .27635 Mdot
.24008 .27594 Mdot
.24058 .27559 Mdot
.24107 .27495 Mdot
.24157 .27514 Mdot
.24206 .27612 Mdot
.24256 .27581 Mdot
.24306 .28374 Mdot
.24355 .3069 Mdot
.24405 .30604 Mdot
.24454 .30672 Mdot
.24504 .30691 Mdot
.24554 .30802 Mdot
.24603 .30887 Mdot
.24653 .3094 Mdot
.24702 .30917 Mdot
.24752 .30882 Mdot
.24802 .30906 Mdot
.24851 .30917 Mdot
.24901 .30924 Mdot
.2495 .30952 Mdot
.25 .31059 Mdot
.2505 .31009 Mdot
.25099 .30727 Mdot
.25149 .30734 Mdot
.25198 .3086 Mdot
.25248 .3076 Mdot
.25298 .30664 Mdot
.25347 .30265 Mdot
.25397 .30361 Mdot
.25446 .30799 Mdot
.25496 .30845 Mdot
.25546 .30645 Mdot
.25595 .30358 Mdot
.25645 .28427 Mdot
.25694 .27072 Mdot
.25744 .27072 Mdot
.25794 .27372 Mdot
.25843 .27496 Mdot
.25893 .27522 Mdot
.25942 .27575 Mdot
.25992 .27577 Mdot
.26042 .27675 Mdot
.26091 .27613 Mdot
.26141 .27635 Mdot
.2619 .27672 Mdot
.2624 .27589 Mdot
.2629 .27649 Mdot
.26339 .18617 Mdot
.26389 .18489 Mdot
.26438 .19687 Mdot
.26488 .21592 Mdot
.26538 .21699 Mdot
.26587 .21584 Mdot
.26637 .21496 Mdot
.26687 .21536 Mdot
.26736 .21468 Mdot
.26786 .21211 Mdot
.26835 .20959 Mdot
.26885 .21198 Mdot
.26935 .21651 Mdot
.26984 .21618 Mdot
.27034 .21616 Mdot
.27083 .20925 Mdot
.27133 .20566 Mdot
.27183 .2085 Mdot
.27232 .20967 Mdot
.27282 .21002 Mdot
.27331 .2105 Mdot
.27381 .21039 Mdot
.27431 .21008 Mdot
.2748 .21005 Mdot
.2753 .2103 Mdot
.27579 .21033 Mdot
.27629 .21018 Mdot
.27679 .21003 Mdot
.27728 .21063 Mdot
.27778 .20986 Mdot
.27827 .20953 Mdot
.27877 .20966 Mdot
.27927 .2773 Mdot
.27976 .27953 Mdot
.28026 .27885 Mdot
.28075 .27461 Mdot
.28125 .27394 Mdot
.28175 .27328 Mdot
.28224 .27314 Mdot
.28274 .27187 Mdot
.28323 .27084 Mdot
.28373 .27351 Mdot
.28423 .27506 Mdot
.28472 .27527 Mdot
.28522 .27508 Mdot
.28571 .27564 Mdot
.28621 .27599 Mdot
.28671 .27661 Mdot
.2872 .2763 Mdot
.2877 .27643 Mdot
.28819 .27682 Mdot
.28869 .2773 Mdot
.28919 .27778 Mdot
.28968 .27867 Mdot
.29018 .27852 Mdot
.29067 .27755 Mdot
.29117 .27822 Mdot
.29167 .27722 Mdot
.29216 .27683 Mdot
.29266 .27715 Mdot
.29315 .27649 Mdot
.29365 .27612 Mdot
.29415 .27561 Mdot
.29464 .2761 Mdot
.29514 .27707 Mdot
.29563 .27656 Mdot
.29613 .31111 Mdot
.29663 .33115 Mdot
.29712 .33705 Mdot
.29762 .34535 Mdot
.29812 .34464 Mdot
.29861 .34434 Mdot
.29911 .34467 Mdot
.2996 .34495 Mdot
.3001 .34521 Mdot
.3006 .34686 Mdot
.30109 .34666 Mdot
.30159 .34696 Mdot
.30208 .34726 Mdot
.30258 .34718 Mdot
.30308 .34702 Mdot
.30357 .34783 Mdot
.30407 .25911 Mdot
.30456 .25646 Mdot
.30506 .25718 Mdot
.30556 .25652 Mdot
.30605 .25848 Mdot
.30655 .25544 Mdot
.30704 .25772 Mdot
.30754 .26324 Mdot
.30804 .25708 Mdot
.30853 .28007 Mdot
.30903 .27999 Mdot
.30952 .28394 Mdot
.31002 .27213 Mdot
.31052 .27403 Mdot
.31101 .27546 Mdot
.31151 .27458 Mdot
.312 .27492 Mdot
.3125 .27447 Mdot
.313 .27459 Mdot
.31349 .27477 Mdot
.31399 .2744 Mdot
.31448 .2752 Mdot
.31498 .27577 Mdot
.31548 .27556 Mdot
.31597 .27582 Mdot
.31647 .27667 Mdot
.31696 .20681 Mdot
.31746 .20848 Mdot
.31796 .20997 Mdot
.31845 .21219 Mdot
.31895 .21348 Mdot
.31944 .21357 Mdot
.31994 .21213 Mdot
.32044 .212 Mdot
.32093 .21362 Mdot
.32143 .21381 Mdot
.32192 .21384 Mdot
.32242 .214 Mdot
.32292 .21488 Mdot
.32341 .21467 Mdot
.32391 .21507 Mdot
.3244 .21709 Mdot
.3249 .21316 Mdot
.3254 .2064 Mdot
.32589 .20798 Mdot
.32639 .2091 Mdot
.32688 .20971 Mdot
.32738 .21048 Mdot
.32788 .21055 Mdot
.32837 .21034 Mdot
.32887 .21039 Mdot
.32937 .21148 Mdot
.32986 .21175 Mdot
.33036 .27221 Mdot
.33085 .27383 Mdot
.33135 .27657 Mdot
.33185 .27575 Mdot
.33234 .27557 Mdot
.33284 .27586 Mdot
.33333 .27726 Mdot
.33383 .27769 Mdot
.33433 .27675 Mdot
.33482 .27487 Mdot
.33532 .27551 Mdot
.33581 .277 Mdot
.33631 .27539 Mdot
.33681 .27457 Mdot
.3373 .27113 Mdot
.3378 .27214 Mdot
.33829 .27335 Mdot
.33879 .27395 Mdot
.33929 .27476 Mdot
.33978 .27541 Mdot
.34028 .27602 Mdot
.34077 .27685 Mdot
.34127 .27724 Mdot
.34177 .27715 Mdot
.34226 .2772 Mdot
.34276 .2767 Mdot
.34325 .27659 Mdot
.34375 .27704 Mdot
.34425 .27653 Mdot
.34474 .27602 Mdot
.34524 .27626 Mdot
.34573 .2763 Mdot
.34623 .40319 Mdot
.34673 .40078 Mdot
.34722 .39351 Mdot
.34772 .39092 Mdot
.34821 .38388 Mdot
.34871 .39079 Mdot
.34921 .38544 Mdot
.3497 .39138 Mdot
.3502 .38851 Mdot
.35069 .389 Mdot
.35119 .3931 Mdot
.35169 .40023 Mdot
.35218 .40355 Mdot
.35268 .4063 Mdot
.35317 .40716 Mdot
.35367 .40791 Mdot
.35417 .40896 Mdot
.35466 .4089 Mdot
.35516 .40854 Mdot
.35565 .40876 Mdot
.35615 .40965 Mdot
.35665 .41079 Mdot
.35714 .41113 Mdot
.35764 .41035 Mdot
.35813 .40916 Mdot
.35863 .412 Mdot
.35913 .41321 Mdot
.35962 .41004 Mdot
.36012 .27628 Mdot
.36062 .27484 Mdot
.36111 .27276 Mdot
.36161 .27599 Mdot
.3621 .27602 Mdot
.3626 .27653 Mdot
.3631 .2762 Mdot
.36359 .27712 Mdot
.36409 .2776 Mdot
.36458 .27655 Mdot
.36508 .27603 Mdot
.36558 .2758 Mdot
.36607 .27585 Mdot
.36657 .27586 Mdot
.36706 .27608 Mdot
.36756 .27661 Mdot
.36806 .27714 Mdot
.36855 .27719 Mdot
.36905 .27689 Mdot
.36954 .2767 Mdot
.37004 .27661 Mdot
.37054 .27739 Mdot
.37103 .27789 Mdot
.37153 .2151 Mdot
.37202 .21531 Mdot
.37252 .21423 Mdot
.37302 .21178 Mdot
.37351 .2117 Mdot
.37401 .21292 Mdot
.3745 .21454 Mdot
.375 .21614 Mdot
.3755 .21267 Mdot
.37599 .21104 Mdot
.37649 .21112 Mdot
.37698 .21149 Mdot
.37748 .21145 Mdot
.37798 .21115 Mdot
.37847 .20965 Mdot
.37897 .20938 Mdot
.37946 .20997 Mdot
.37996 .20792 Mdot
.38046 .20775 Mdot
.38095 .20771 Mdot
.38145 .20842 Mdot
.38194 .20886 Mdot
.38244 .2093 Mdot
.38294 .21 Mdot
.38343 .20985 Mdot
.38393 .20979 Mdot
.38442 .21038 Mdot
.38492 .21028 Mdot
.38542 .2102 Mdot
.38591 .21008 Mdot
.38641 .21059 Mdot
.3869 .21046 Mdot
.3874 .20887 Mdot
.3879 .20863 Mdot
.38839 .20978 Mdot
.38889 .27547 Mdot
.38938 .2732 Mdot
.38988 .27488 Mdot
.39038 .27471 Mdot
.39087 .2759 Mdot
.39137 .2748 Mdot
.39187 .27741 Mdot
.39236 .27391 Mdot
.39286 .27426 Mdot
.39335 .27473 Mdot
.39385 .27539 Mdot
.39435 .27538 Mdot
.39484 .276 Mdot
.39534 .27661 Mdot
.39583 .27668 Mdot
.39633 .27721 Mdot
.39683 .27737 Mdot
.39732 .27738 Mdot
.39782 .27752 Mdot
.39831 .27801 Mdot
.39881 .36523 Mdot
.39931 .37026 Mdot
.3998 .39485 Mdot
.4003 .40739 Mdot
.40079 .40886 Mdot
.40129 .40768 Mdot
.40179 .4037 Mdot
.40228 .38374 Mdot
.40278 .38397 Mdot
.40327 .38903 Mdot
.40377 .37627 Mdot
.40427 .3786 Mdot
.40476 .38922 Mdot
.40526 .39858 Mdot
.40575 .38344 Mdot
.40625 .40641 Mdot
.40675 .40201 Mdot
.40724 .4028 Mdot
.40774 .40542 Mdot
.40823 .40685 Mdot
.40873 .40795 Mdot
.40923 .40845 Mdot
.40972 .40872 Mdot
.41022 .40829 Mdot
.41071 .40875 Mdot
.41121 .40918 Mdot
.41171 .40899 Mdot
.4122 .40892 Mdot
.4127 .40917 Mdot
.41319 .41011 Mdot
.41369 .41293 Mdot
.41419 .41278 Mdot
.41468 .41114 Mdot
.41518 .41057 Mdot
.41567 .40884 Mdot
.41617 .40985 Mdot
.41667 .40961 Mdot
.41716 .40956 Mdot
.41766 .41102 Mdot
.41815 .41079 Mdot
.41865 .41267 Mdot
.41915 .41068 Mdot
.41964 .41269 Mdot
.42014 .43171 Mdot
.42063 .4427 Mdot
.42113 .44596 Mdot
.42163 .44587 Mdot
.42212 .44636 Mdot
.42262 .45007 Mdot
.42312 .45289 Mdot
.42361 .45534 Mdot
.42411 .45523 Mdot
.4246 .45589 Mdot
.4251 .45441 Mdot
.4256 .45343 Mdot
.42609 .45476 Mdot
.42659 .45399 Mdot
.42708 .45243 Mdot
.42758 .4466 Mdot
.42808 .43874 Mdot
.42857 .4388 Mdot
.42907 .44036 Mdot
.42956 .4438 Mdot
.43006 .44275 Mdot
.43056 .44382 Mdot
.43105 .44361 Mdot
.43155 .44771 Mdot
.43204 .44757 Mdot
.43254 .45006 Mdot
.43304 .45473 Mdot
.43353 .45602 Mdot
.43403 .45887 Mdot
.43452 .4599 Mdot
.43502 .46289 Mdot
.43552 .4625 Mdot
.43601 .43697 Mdot
.43651 .36686 Mdot
.437 .36566 Mdot
.4375 .36774 Mdot
.438 .36627 Mdot
.43849 .36372 Mdot
.43899 .36692 Mdot
.43948 .36673 Mdot
.43998 .36634 Mdot
.44048 .36943 Mdot
.44097 .37002 Mdot
.44147 .37141 Mdot
.44196 .37067 Mdot
.44246 .37015 Mdot
.44296 .36954 Mdot
.44345 .38235 Mdot
.44395 .38011 Mdot
.44444 .38002 Mdot
.44494 .37982 Mdot
.44544 .37939 Mdot
.44593 .37483 Mdot
.44643 .38882 Mdot
.44692 .39328 Mdot
.44742 .40423 Mdot
.44792 .40541 Mdot
.44841 .40565 Mdot
.44891 .40816 Mdot
.4494 .40938 Mdot
.4499 .4053 Mdot
.4504 .40494 Mdot
.45089 .4065 Mdot
.45139 .40608 Mdot
.45188 .40703 Mdot
.45238 .40603 Mdot
.45288 .40581 Mdot
.45337 .40681 Mdot
.45387 .40477 Mdot
.45437 .40608 Mdot
.45486 .40535 Mdot
.45536 .40336 Mdot
.45585 .40462 Mdot
.45635 .40594 Mdot
.45685 .40923 Mdot
.45734 .40926 Mdot
.45784 .40769 Mdot
.45833 .40319 Mdot
.45883 .40805 Mdot
.45933 .41128 Mdot
.45982 .40896 Mdot
.46032 .40757 Mdot
.46081 .4095 Mdot
.46131 .40682 Mdot
.46181 .40103 Mdot
.4623 .35377 Mdot
.4628 .35297 Mdot
.46329 .34992 Mdot
.46379 .34906 Mdot
.46429 .34773 Mdot
.46478 .34583 Mdot
.46528 .3469 Mdot
.46577 .34693 Mdot
.46627 .34809 Mdot
.46677 .34773 Mdot
.46726 .34632 Mdot
.46776 .34788 Mdot
.46825 .34913 Mdot
.46875 .3518 Mdot
.46925 .35218 Mdot
.46974 .35204 Mdot
.47024 .35358 Mdot
.47073 .34774 Mdot
.47123 .3538 Mdot
.47173 .34965 Mdot
.47222 .35127 Mdot
.47272 .35328 Mdot
.47321 .34892 Mdot
.47371 .35047 Mdot
.47421 .35435 Mdot
.4747 .34958 Mdot
.4752 .34721 Mdot
.47569 .3625 Mdot
.47619 .36257 Mdot
.47669 .36408 Mdot
.47718 .36306 Mdot
.47768 .3626 Mdot
.47817 .36437 Mdot
.47867 .36355 Mdot
.47917 .36305 Mdot
.47966 .3638 Mdot
.48016 .36482 Mdot
.48065 .36343 Mdot
.48115 .36466 Mdot
.48165 .36629 Mdot
.48214 .36251 Mdot
.48264 .36292 Mdot
.48313 .36382 Mdot
.48363 .3647 Mdot
.48413 .36591 Mdot
.48462 .36744 Mdot
.48512 .36407 Mdot
.48562 .36428 Mdot
.48611 .36567 Mdot
.48661 .36484 Mdot
.4871 .36182 Mdot
.4876 .36547 Mdot
.4881 .36217 Mdot
.48859 .31427 Mdot
.48909 .31146 Mdot
.48958 .30931 Mdot
.49008 .30826 Mdot
.49058 .30874 Mdot
.49107 .30979 Mdot
.49157 .30888 Mdot
.49206 .3083 Mdot
.49256 .30927 Mdot
.49306 .30928 Mdot
.49355 .3095 Mdot
.49405 .31074 Mdot
.49454 .31135 Mdot
.49504 .31164 Mdot
.49554 .31097 Mdot
.49603 .31005 Mdot
.49653 .30939 Mdot
.49702 .30899 Mdot
.49752 .30899 Mdot
.49802 .31087 Mdot
.49851 .31199 Mdot
.49901 .31103 Mdot
.4995 .30969 Mdot
.5 .30943 Mdot
.5005 .30949 Mdot
.50099 .30945 Mdot
.50149 .31739 Mdot
.50198 .31708 Mdot
.50248 .34262 Mdot
.50298 .34456 Mdot
.50347 .34439 Mdot
.50397 .3445 Mdot
.50446 .34397 Mdot
.50496 .34307 Mdot
.50546 .34319 Mdot
.50595 .34332 Mdot
.50645 .4268 Mdot
.50694 .4121 Mdot
.50744 .40903 Mdot
.50794 .41451 Mdot
.50843 .41448 Mdot
.50893 .41641 Mdot
.50942 .41291 Mdot
.50992 .41348 Mdot
.51042 .40623 Mdot
.51091 .4121 Mdot
.51141 .41027 Mdot
.5119 .4142 Mdot
.5124 .41385 Mdot
.5129 .41373 Mdot
.51339 .41112 Mdot
.51389 .41293 Mdot
.51438 .41542 Mdot
.51488 .41403 Mdot
.51538 .39847 Mdot
.51587 .4024 Mdot
.51637 .40213 Mdot
.51687 .40503 Mdot
.51736 .40464 Mdot
.51786 .40397 Mdot
.51835 .40527 Mdot
.51885 .40661 Mdot
.51935 .40462 Mdot
.51984 .40506 Mdot
.52034 .40579 Mdot
.52083 .40586 Mdot
.52133 .40656 Mdot
.52183 .40695 Mdot
.52232 .40654 Mdot
.52282 .40858 Mdot
.52331 .40654 Mdot
.52381 .40041 Mdot
.52431 .40623 Mdot
.5248 .40332 Mdot
.5253 .40126 Mdot
.52579 .40506 Mdot
.52629 .40654 Mdot
.52679 .40739 Mdot
.52728 .40632 Mdot
.52778 .40696 Mdot
.52827 .41015 Mdot
.52877 .41097 Mdot
.52927 .4241 Mdot
.52976 .44223 Mdot
.53026 .45079 Mdot
.53075 .45048 Mdot
.53125 .4507 Mdot
.53175 .45125 Mdot
.53224 .45046 Mdot
.53274 .45446 Mdot
.53323 .45392 Mdot
.53373 .45477 Mdot
.53423 .45608 Mdot
.53472 .45463 Mdot
.53522 .45437 Mdot
.53571 .45449 Mdot
.53621 .45337 Mdot
.53671 .45322 Mdot
.5372 .379 Mdot
.5377 .45443 Mdot
.53819 .4527 Mdot
.53869 .45231 Mdot
.53919 .44942 Mdot
.53968 .44677 Mdot
.54018 .44218 Mdot
.54067 .44546 Mdot
.54117 .45104 Mdot
.54167 .45722 Mdot
.54216 .37906 Mdot
.54266 .37494 Mdot
.54315 .38133 Mdot
.54365 .31109 Mdot
.54415 .30908 Mdot
.54464 .44474 Mdot
.54514 .44195 Mdot
.54563 .44163 Mdot
.54613 .43642 Mdot
.54663 .37631 Mdot
.54712 .3711 Mdot
.54762 .37282 Mdot
.54812 .36785 Mdot
.54861 .36649 Mdot
.54911 .3668 Mdot
.5496 .36832 Mdot
.5501 .36744 Mdot
.5506 .36696 Mdot
.55109 .36885 Mdot
.55159 .36941 Mdot
.55208 .36888 Mdot
.55258 .36722 Mdot
.55308 .369 Mdot
.55357 .36886 Mdot
.55407 .37005 Mdot
.55456 .37258 Mdot
.55506 .37212 Mdot
.55556 .3708 Mdot
.55605 .37972 Mdot
.55655 .3774 Mdot
.55704 .37704 Mdot
.55754 .38013 Mdot
.55804 .36969 Mdot
.55853 .38746 Mdot
.55903 .37303 Mdot
.55952 .38664 Mdot
.56002 .39332 Mdot
.56052 .40095 Mdot
.56101 .404 Mdot
.56151 .39515 Mdot
.562 .39565 Mdot
.5625 .40759 Mdot
.563 .40954 Mdot
.56349 .40552 Mdot
.56399 .40714 Mdot
.56448 .40775 Mdot
.56498 .40863 Mdot
.56548 .41096 Mdot
.56597 .41226 Mdot
.56647 .4063 Mdot
.56696 .41613 Mdot
.56746 .41565 Mdot
.56796 .40919 Mdot
.56845 .40596 Mdot
.56895 .35364 Mdot
.56944 .35016 Mdot
.56994 .35014 Mdot
.57044 .34603 Mdot
.57093 .34803 Mdot
.57143 .34639 Mdot
.57192 .34946 Mdot
.57242 .34982 Mdot
.57292 .35166 Mdot
.57341 .34905 Mdot
.57391 .35347 Mdot
.5744 .35191 Mdot
.5749 .34842 Mdot
.5754 .34671 Mdot
.57589 .34605 Mdot
.57639 .34693 Mdot
.57688 .34586 Mdot
.57738 .34757 Mdot
.57788 .34904 Mdot
.57837 .3542 Mdot
.57887 .35216 Mdot
.57937 .35035 Mdot
.57986 .35125 Mdot
.58036 .35303 Mdot
.58085 .35386 Mdot
.58135 .35183 Mdot
.58185 .34936 Mdot
.58234 .36364 Mdot
.58284 .36407 Mdot
.58333 .36279 Mdot
.58383 .36216 Mdot
.58433 .3624 Mdot
.58482 .36237 Mdot
.58532 .36272 Mdot
.58581 .36254 Mdot
.58631 .36255 Mdot
.58681 .36353 Mdot
.5873 .36369 Mdot
.5878 .36349 Mdot
.58829 .3637 Mdot
.58879 .36341 Mdot
.58929 .36277 Mdot
.58978 .36431 Mdot
.59028 .36452 Mdot
.59077 .36292 Mdot
.59127 .36365 Mdot
.59177 .36518 Mdot
.59226 .36349 Mdot
.59276 .36383 Mdot
.59325 .36448 Mdot
.59375 .36224 Mdot
.59425 .15537 Mdot
.59474 .15653 Mdot
.59524 .15724 Mdot
.59573 .15738 Mdot
.59623 .15831 Mdot
.59673 .15857 Mdot
.59722 .15935 Mdot
.59772 .16 Mdot
.59821 .16121 Mdot
.59871 .1613 Mdot
.59921 .16144 Mdot
.5997 .16178 Mdot
.6002 .16182 Mdot
.60069 .16182 Mdot
.60119 .16184 Mdot
.60169 .16205 Mdot
.60218 .31093 Mdot
.60268 .31404 Mdot
.60317 .31339 Mdot
.60367 .30431 Mdot
.60417 .30455 Mdot
.60466 .30856 Mdot
.60516 .30992 Mdot
.60565 .3075 Mdot
.60615 .30717 Mdot
.60665 .30556 Mdot
.60714 .31049 Mdot
.60764 .31252 Mdot
.60813 .32818 Mdot
.60863 .32508 Mdot
.60913 .34185 Mdot
.60962 .34315 Mdot
.61012 .34424 Mdot
.61062 .34337 Mdot
.61111 .34295 Mdot
.61161 .34344 Mdot
.6121 .34479 Mdot
.6126 .25316 Mdot
.6131 .2524 Mdot
.61359 .25319 Mdot
.61409 .25202 Mdot
.61458 .25101 Mdot
.61508 .25127 Mdot
.61558 .25585 Mdot
.61607 .2561 Mdot
.61657 .25501 Mdot
.61706 .25886 Mdot
.61756 .26136 Mdot
.61806 .2608 Mdot
.61855 .25937 Mdot
.61905 .26119 Mdot
.61954 .26089 Mdot
.62004 .25617 Mdot
.62054 .25774 Mdot
.62103 .25611 Mdot
.62153 .25751 Mdot
.62202 .25709 Mdot
.62252 .25807 Mdot
.62302 .26188 Mdot
.62351 .26824 Mdot
.62401 .2713 Mdot
.6245 .27415 Mdot
.625 .27471 Mdot
.6255 .27571 Mdot
.62599 .27508 Mdot
.62649 .27486 Mdot
.62698 .27529 Mdot
.62748 .27684 Mdot
.62798 .27677 Mdot
.62847 .27728 Mdot
.62897 .27726 Mdot
.62946 .27773 Mdot
.62996 .27677 Mdot
.63046 .27413 Mdot
.63095 .27542 Mdot
.63145 .27479 Mdot
.63194 .27494 Mdot
.63244 .27522 Mdot
.63294 .27495 Mdot
.63343 .2787 Mdot
.63393 .27697 Mdot
.63442 .2739 Mdot
.63492 .27602 Mdot
.63542 .27631 Mdot
.63591 .29963 Mdot
.63641 .30479 Mdot
.6369 .30476 Mdot
.6374 .30619 Mdot
.6379 .30743 Mdot
.63839 .30725 Mdot
.63889 .3092 Mdot
.63938 .30977 Mdot
.63988 .30933 Mdot
.64038 .30914 Mdot
.64087 .30953 Mdot
.64137 .30941 Mdot
.64187 .31063 Mdot
.64236 .31148 Mdot
.64286 .3115 Mdot
.64335 .30891 Mdot
.64385 .30862 Mdot
.64435 .30935 Mdot
.64484 .30949 Mdot
.64534 .30906 Mdot
.64583 .30949 Mdot
.64633 .31048 Mdot
.64683 .31023 Mdot
.64732 .30969 Mdot
.64782 .31067 Mdot
.64831 .3088 Mdot
.64881 .31645 Mdot
.64931 .33442 Mdot
.6498 .34232 Mdot
.6503 .34427 Mdot
.65079 .34363 Mdot
.65129 .34356 Mdot
.65179 .34365 Mdot
.65228 .34395 Mdot
.65278 .34451 Mdot
.65327 .34428 Mdot
.65377 .34355 Mdot
.65427 .34423 Mdot
.65476 .3445 Mdot
.65526 .34465 Mdot
.65575 .34478 Mdot
.65625 .34466 Mdot
.65675 .34426 Mdot
.65724 .34449 Mdot
.65774 .34567 Mdot
.65823 .3444 Mdot
.65873 .34394 Mdot
.65923 .33795 Mdot
.65972 .34585 Mdot
.66022 .34421 Mdot
.66071 .34415 Mdot
.66121 .34478 Mdot
.66171 .34509 Mdot
.6622 .34507 Mdot
.6627 .34434 Mdot
.66319 .34323 Mdot
.66369 .36549 Mdot
.66419 .36008 Mdot
.66468 .36205 Mdot
.66518 .36536 Mdot
.66567 .36282 Mdot
.66617 .36122 Mdot
.66667 .36481 Mdot
.66716 .36593 Mdot
.66766 .3651 Mdot
.66815 .36543 Mdot
.66865 .36563 Mdot
.66915 .36628 Mdot
.66964 .3678 Mdot
.67014 .36902 Mdot
.67063 .36665 Mdot
.67113 .36534 Mdot
.67163 .36452 Mdot
.67212 .36395 Mdot
.67262 .36508 Mdot
.67312 .36459 Mdot
.67361 .36115 Mdot
.67411 .36489 Mdot
.6746 .36493 Mdot
.6751 .36401 Mdot
.6756 .36547 Mdot
.67609 .37572 Mdot
.67659 .39419 Mdot
.67708 .39669 Mdot
.67758 .40402 Mdot
.67808 .40364 Mdot
.67857 .40587 Mdot
.67907 .40649 Mdot
.67956 .40458 Mdot
.68006 .40817 Mdot
.68056 .4042 Mdot
.68105 .40515 Mdot
.68155 .4087 Mdot
.68204 .40813 Mdot
.68254 .40899 Mdot
.68304 .40954 Mdot
.68353 .4087 Mdot
.68403 .40902 Mdot
.68452 .40587 Mdot
.68502 .41054 Mdot
.68552 .41133 Mdot
.68601 .40997 Mdot
.68651 .40656 Mdot
.687 .40743 Mdot
.6875 .40866 Mdot
.688 .40755 Mdot
.68849 .40767 Mdot
.68899 .41169 Mdot
.68948 .41847 Mdot
.68998 .43584 Mdot
.69048 .44362 Mdot
.69097 .4449 Mdot
.69147 .44035 Mdot
.69196 .44024 Mdot
.69246 .44159 Mdot
.69296 .44822 Mdot
.69345 .45217 Mdot
.69395 .45387 Mdot
.69444 .45579 Mdot
.69494 .45445 Mdot
.69544 .45427 Mdot
.69593 .45362 Mdot
.69643 .4521 Mdot
.69692 .45189 Mdot
.69742 .4519 Mdot
.69792 .45353 Mdot
.69841 .45445 Mdot
.69891 .45447 Mdot
.6994 .45473 Mdot
.6999 .45272 Mdot
.7004 .45338 Mdot
.70089 .45458 Mdot
.70139 .45164 Mdot
.70188 .44656 Mdot
.70238 .44964 Mdot
.70288 .45666 Mdot
.70337 .46975 Mdot
.70387 .49272 Mdot
.70437 .4977 Mdot
.70486 .49835 Mdot
.70536 .49912 Mdot
.70585 .49624 Mdot
.70635 .49591 Mdot
.70685 .50198 Mdot
.70734 .50209 Mdot
.70784 .50134 Mdot
.70833 .50441 Mdot
.70883 .50737 Mdot
.70933 .50783 Mdot
.70982 .50932 Mdot
.71032 .51371 Mdot
.71081 .50249 Mdot
.71131 .50258 Mdot
.71181 .50371 Mdot
.7123 .50328 Mdot
.7128 .50311 Mdot
.71329 .50407 Mdot
.71379 .49745 Mdot
.71429 .48154 Mdot
.71478 .4833 Mdot
.71528 .48714 Mdot
.71577 .4831 Mdot
.71627 .49422 Mdot
.71677 .52784 Mdot
.71726 .53512 Mdot
.71776 .53507 Mdot
.71825 .53494 Mdot
.71875 .53689 Mdot
.71925 .53744 Mdot
.71974 .53938 Mdot
.72024 .53798 Mdot
.72073 .53742 Mdot
.72123 .5396 Mdot
.72173 .54013 Mdot
.72222 .53926 Mdot
.72272 .53945 Mdot
.72321 .54067 Mdot
.72371 .54208 Mdot
.72421 .53911 Mdot
.7247 .5378 Mdot
.7252 .53855 Mdot
.72569 .5406 Mdot
.72619 .53759 Mdot
.72669 .53648 Mdot
.72718 .36444 Mdot
.72768 .36779 Mdot
.72817 .37316 Mdot
.72867 .36684 Mdot
.72917 .36707 Mdot
.72966 .36752 Mdot
.73016 .36707 Mdot
.73065 .53877 Mdot
.73115 .5418 Mdot
.73165 .54273 Mdot
.73214 .40274 Mdot
.73264 .40591 Mdot
.73313 .40639 Mdot
.73363 .4076 Mdot
.73413 .40825 Mdot
.73462 .40901 Mdot
.73512 .40877 Mdot
.73562 .41007 Mdot
.73611 .41074 Mdot
.73661 .4094 Mdot
.7371 .41021 Mdot
.7376 .41027 Mdot
.7381 .40958 Mdot
.73859 .4115 Mdot
.73909 .41236 Mdot
.73958 .41046 Mdot
.74008 .41115 Mdot
.74058 .41474 Mdot
.74107 .41299 Mdot
.74157 .41221 Mdot
.74206 .41261 Mdot
.74256 .41146 Mdot
.74306 .41437 Mdot
.74355 .41384 Mdot
.74405 .41239 Mdot
.74454 .17376 Mdot
.74504 .17843 Mdot
.74554 .17868 Mdot
.74603 .1785 Mdot
.74653 .17877 Mdot
.74702 .17919 Mdot
.74752 .17942 Mdot
.74802 .17954 Mdot
.74851 .17982 Mdot
.74901 .17998 Mdot
.7495 .17946 Mdot
.75 .17926 Mdot
.7505 .2855 Mdot
.75099 .28813 Mdot
.75149 .28753 Mdot
.75198 .35788 Mdot
.75248 .36015 Mdot
.75298 .28558 Mdot
.75347 .28818 Mdot
.75397 .27906 Mdot
.75446 .27447 Mdot
.75496 .29116 Mdot
.75546 .28859 Mdot
.75595 .27489 Mdot
.75645 .27693 Mdot
.75694 .27438 Mdot
.75744 .2748 Mdot
.75794 .27726 Mdot
.75843 .27615 Mdot
.75893 .27767 Mdot
.75942 .27483 Mdot
.75992 .27543 Mdot
.76042 .27652 Mdot
.76091 .27639 Mdot
.76141 .27752 Mdot
.7619 .27768 Mdot
.7624 .27799 Mdot
.7629 .278 Mdot
.76339 .27823 Mdot
.76389 .27784 Mdot
.76438 .27813 Mdot
.76488 .27761 Mdot
.76538 .27807 Mdot
.76587 .27792 Mdot
.76637 .27672 Mdot
.76687 .27699 Mdot
.76736 .27741 Mdot
.76786 .27681 Mdot
.76835 .27726 Mdot
.76885 .27726 Mdot
.76935 .27626 Mdot
.76984 .2761 Mdot
.77034 .27758 Mdot
.77083 .2771 Mdot
.77133 .27733 Mdot
.77183 .27783 Mdot
.77232 .27792 Mdot
.77282 .27906 Mdot
.77331 .28001 Mdot
.77381 .2785 Mdot
.77431 .2778 Mdot
.7748 .2778 Mdot
.7753 .27796 Mdot
.77579 .27823 Mdot
.77629 .27818 Mdot
.77679 .27805 Mdot
.77728 .27782 Mdot
.77778 .27789 Mdot
.77827 .27843 Mdot
.77877 .27853 Mdot
.77927 .27772 Mdot
.77976 .27873 Mdot
.78026 .27787 Mdot
.78075 .27725 Mdot
.78125 .14625 Mdot
.78175 .1463 Mdot
.78224 .14633 Mdot
.78274 .14619 Mdot
.78323 .14585 Mdot
.78373 .14591 Mdot
.78423 .14645 Mdot
.78472 .1461 Mdot
.78522 .14594 Mdot
.78571 .14622 Mdot
.78621 .14633 Mdot
.78671 .14654 Mdot
.7872 .14661 Mdot
.7877 .1465 Mdot
.78819 .14594 Mdot
.78869 .14581 Mdot
.78919 .14593 Mdot
.78968 .14621 Mdot
.79018 .14626 Mdot
.79067 .14611 Mdot
.79117 .14616 Mdot
.79167 .40819 Mdot
.79216 .40786 Mdot
.79266 .40859 Mdot
.79315 .40899 Mdot
.79365 .40999 Mdot
.79415 .41371 Mdot
.79464 .41329 Mdot
.79514 .41116 Mdot
.79563 .41099 Mdot
.79613 .41219 Mdot
.79663 .41654 Mdot
.79712 .40596 Mdot
.79762 .41857 Mdot
.79812 .4155 Mdot
.79861 .27737 Mdot
.79911 .27745 Mdot
.7996 .27763 Mdot
.8001 .27815 Mdot
.8006 .27961 Mdot
.80109 .27723 Mdot
.80159 .27404 Mdot
.80208 .27195 Mdot
.80258 .27213 Mdot
.80308 .27092 Mdot
.80357 .27152 Mdot
.80407 .27269 Mdot
.80456 .27399 Mdot
.80506 .27411 Mdot
.80556 .27643 Mdot
.80605 .27589 Mdot
.80655 .27582 Mdot
.80704 .2778 Mdot
.80754 .2749 Mdot
.80804 .27662 Mdot
.80853 .27375 Mdot
.80903 .27723 Mdot
.80952 .28167 Mdot
.81002 .2795 Mdot
.81052 .28111 Mdot
.81101 .2815 Mdot
.81151 .28062 Mdot
.812 .27805 Mdot
.8125 .27657 Mdot
.813 .27555 Mdot
.81349 .27303 Mdot
.81399 .26934 Mdot
.81448 .27085 Mdot
.81498 .28025 Mdot
.81548 .2552 Mdot
.81597 .26833 Mdot
.81647 .27362 Mdot
.81696 .27568 Mdot
.81746 .27657 Mdot
.81796 .27726 Mdot
.81845 .27816 Mdot
.81895 .2782 Mdot
.81944 .27818 Mdot
.81994 .278 Mdot
.82044 .27825 Mdot
.82093 .27815 Mdot
.82143 .27828 Mdot
.82192 .2787 Mdot
.82242 .2793 Mdot
.82292 .27845 Mdot
.82341 .27759 Mdot
.82391 .42702 Mdot
.8244 .42191 Mdot
.8249 .42206 Mdot
.8254 .42922 Mdot
.82589 .42419 Mdot
.82639 .42266 Mdot
.82688 .4257 Mdot
.82738 .4241 Mdot
.82788 .42971 Mdot
.82837 .42542 Mdot
.82887 .42031 Mdot
.82937 .42655 Mdot
.82986 .41744 Mdot
.83036 .42462 Mdot
.83085 .427 Mdot
.83135 .42331 Mdot
.83185 .4281 Mdot
.83234 .41829 Mdot
.83284 .42252 Mdot
.83333 .53761 Mdot
.83383 .53846 Mdot
.83433 .53892 Mdot
.83482 .5389 Mdot
.83532 .53872 Mdot
.83581 .53913 Mdot
.83631 .53908 Mdot
.83681 .53876 Mdot
.8373 .5392 Mdot
.8378 .53993 Mdot
.83829 .54083 Mdot
.83879 .5428 Mdot
.83929 .54351 Mdot
.83978 .54378 Mdot
.84028 .5435 Mdot
.84077 .27803 Mdot
.84127 .27766 Mdot
.84177 .27751 Mdot
.84226 .27711 Mdot
.84276 .2768 Mdot
.84325 .27668 Mdot
.84375 .2766 Mdot
.84425 .27717 Mdot
.84474 .27762 Mdot
.84524 .27774 Mdot
.84573 .27829 Mdot
.84623 .2787 Mdot
.84673 .27713 Mdot
.84722 .27572 Mdot
.84772 .27621 Mdot
.84821 .27646 Mdot
.84871 .27646 Mdot
.84921 .27703 Mdot
.8497 .27807 Mdot
.8502 .27912 Mdot
.85069 .27945 Mdot
.85119 .27891 Mdot
.85169 .27876 Mdot
.85218 .27876 Mdot
.85268 .27799 Mdot
.85317 .27735 Mdot
.85367 .27752 Mdot
.85417 .27831 Mdot
.85466 .27896 Mdot
.85516 .27899 Mdot
.85565 .2789 Mdot
.85615 .27852 Mdot
.85665 .27732 Mdot
.85714 .27637 Mdot
.85764 .27638 Mdot
.85813 .27696 Mdot
.85863 .27757 Mdot
.85913 .27743 Mdot
.85962 .27789 Mdot
.86012 .27894 Mdot
.86062 .27944 Mdot
.86111 .27998 Mdot
.86161 .2797 Mdot
.8621 .27986 Mdot
.8626 .27781 Mdot
.8631 .27623 Mdot
.86359 .27511 Mdot
.86409 .27587 Mdot
.86458 .27692 Mdot
.86508 .27774 Mdot
.86558 .27819 Mdot
.86607 .27865 Mdot
.86657 .27865 Mdot
.86706 .27873 Mdot
.86756 .27876 Mdot
.86806 .27826 Mdot
.86855 .27593 Mdot
.86905 .27364 Mdot
.86954 .27361 Mdot
.87004 .27473 Mdot
.87054 .27534 Mdot
.87103 .27555 Mdot
.87153 .27572 Mdot
.87202 .27593 Mdot
.87252 .27616 Mdot
.87302 .27611 Mdot
.87351 .27604 Mdot
.87401 .27645 Mdot
.8745 .27676 Mdot
.875 .2769 Mdot
.8755 .27708 Mdot
.87599 .27695 Mdot
.87649 .27647 Mdot
.87698 .27604 Mdot
.87748 .27615 Mdot
.87798 .27664 Mdot
.87847 .27657 Mdot
.87897 .27608 Mdot
.87946 .27603 Mdot
.87996 .27611 Mdot
.88046 .27578 Mdot
.88095 .27621 Mdot
.88145 .27678 Mdot
.88194 .27673 Mdot
.88244 .27643 Mdot
.88294 .27614 Mdot
.88343 .27605 Mdot
.88393 .2764 Mdot
.88442 .27713 Mdot
.88492 .2769 Mdot
.88542 .27654 Mdot
.88591 .2767 Mdot
.88641 .27635 Mdot
.8869 .27623 Mdot
.8874 .27642 Mdot
.8879 .27635 Mdot
.88839 .27626 Mdot
.88889 .27643 Mdot
.88938 .27655 Mdot
.88988 .27657 Mdot
.89038 .27658 Mdot
.89087 .27665 Mdot
.89137 .27673 Mdot
.89187 .27678 Mdot
.89236 .27686 Mdot
.89286 .27659 Mdot
.89335 .27642 Mdot
.89385 .27637 Mdot
.89435 .27649 Mdot
.89484 .27683 Mdot
.89534 .27709 Mdot
.89583 .27705 Mdot
.89633 .27695 Mdot
.89683 .27712 Mdot
.89732 .27695 Mdot
.89782 .27654 Mdot
.89831 .2763 Mdot
.89881 .27667 Mdot
.89931 .2768 Mdot
.8998 .27691 Mdot
.9003 .27678 Mdot
.90079 .2765 Mdot
.90129 .27655 Mdot
.90179 .27687 Mdot
.90228 .27693 Mdot
.90278 .27664 Mdot
.90327 .27622 Mdot
.90377 .27558 Mdot
.90427 .27511 Mdot
.90476 .27512 Mdot
.90526 .27562 Mdot
.90575 .27631 Mdot
.90625 .2767 Mdot
.90675 .27726 Mdot
.90724 .27753 Mdot
.90774 .27747 Mdot
.90823 .27708 Mdot
.90873 .27708 Mdot
.90923 .27664 Mdot
.90972 .27638 Mdot
.91022 .27663 Mdot
.91071 .277 Mdot
.91121 .27782 Mdot
.91171 .2778 Mdot
.9122 .2784 Mdot
.9127 .27781 Mdot
.91319 .27728 Mdot
.91369 .27675 Mdot
.91419 .27638 Mdot
.91468 .27688 Mdot
.91518 .27639 Mdot
.91567 .27651 Mdot
.91617 .27523 Mdot
.91667 .27612 Mdot
.91716 .27686 Mdot
.91766 .27647 Mdot
.91815 .27646 Mdot
.91865 .27666 Mdot
.91915 .27719 Mdot
.91964 .27741 Mdot
.92014 .27738 Mdot
.92063 .27688 Mdot
.92113 .27671 Mdot
.92163 .27665 Mdot
.92212 .27642 Mdot
.92262 .27633 Mdot
.92312 .27669 Mdot
.92361 .27766 Mdot
.92411 .27844 Mdot
.9246 .27817 Mdot
.9251 .27749 Mdot
.9256 .27711 Mdot
.92609 .27585 Mdot
.92659 .27583 Mdot
.92708 .27629 Mdot
.92758 .27653 Mdot
.92808 .27651 Mdot
.92857 .27616 Mdot
.92907 .27685 Mdot
.92956 .27652 Mdot
.93006 .27622 Mdot
.93056 .27622 Mdot
.93105 .2772 Mdot
.93155 .27795 Mdot
.93204 .27803 Mdot
.93254 .27679 Mdot
.93304 .2767 Mdot
.93353 .27681 Mdot
.93403 .27679 Mdot
.93452 .27666 Mdot
.93502 .27688 Mdot
.93552 .27662 Mdot
.93601 .27582 Mdot
.93651 .27534 Mdot
.937 .2754 Mdot
.9375 .2761 Mdot
.938 .27577 Mdot
.93849 .27609 Mdot
.93899 .27644 Mdot
.93948 .27663 Mdot
.93998 .27631 Mdot
.94048 .27604 Mdot
.94097 .27854 Mdot
.94147 .27764 Mdot
.94196 .27646 Mdot
.94246 .27738 Mdot
.94296 .27734 Mdot
.94345 .2764 Mdot
.94395 .27675 Mdot
.94444 .27617 Mdot
.94494 .27626 Mdot
.94544 .27565 Mdot
.94593 .27569 Mdot
.94643 .27628 Mdot
.94692 .27727 Mdot
.94742 .27694 Mdot
.94792 .27688 Mdot
.94841 .27651 Mdot
.94891 .27555 Mdot
.9494 .27637 Mdot
.9499 .27662 Mdot
.9504 .27628 Mdot
.95089 .27621 Mdot
.95139 .27563 Mdot
.95188 .27576 Mdot
.95238 .27608 Mdot
.95288 .27697 Mdot
.95337 .27681 Mdot
.95387 .27671 Mdot
.95437 .27731 Mdot
.95486 .27725 Mdot
.95536 .27739 Mdot
.95585 .27749 Mdot
.95635 .27602 Mdot
.95685 .27631 Mdot
.95734 .27786 Mdot
.95784 .28001 Mdot
.95833 .27823 Mdot
.95883 .27662 Mdot
.95933 .27768 Mdot
.95982 .2776 Mdot
.96032 .27844 Mdot
.96081 .27843 Mdot
.96131 .27741 Mdot
.96181 .27821 Mdot
.9623 .27733 Mdot
.9628 .27641 Mdot
.96329 .27709 Mdot
.96379 .27646 Mdot
.96429 .27588 Mdot
.96478 .27649 Mdot
.96528 .27685 Mdot
.96577 .27702 Mdot
.96627 .27777 Mdot
.96677 .27841 Mdot
.96726 .2768 Mdot
.96776 .27524 Mdot
.96825 .27605 Mdot
.96875 .27646 Mdot
.96925 .27578 Mdot
.96974 .27652 Mdot
.97024 .27661 Mdot
.97073 .27751 Mdot
.97123 .27723 Mdot
.97173 .27665 Mdot
.97222 .27545 Mdot
.97272 .27555 Mdot
.97321 .27747 Mdot
.97371 .27849 Mdot
.97421 .27832 Mdot
.9747 .27901 Mdot
.9752 .27917 Mdot
.97569 .27852 Mdot
.97619 .27863 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[381]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo000Poooo00<0003oooooool0>Oooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool0;oooo`D00002oooo00<0003oooooool00_ooo`030000oooooooo00;oool0
0`000?ooooooo`0/oooo1@0000;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000
oooooooo03Coool001ooool00`000?ooo`00000ioooo00<0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`00000boooo00L0003oooooooooool0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`00000_oooo00L0003oooooooooool0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`00000eoooo000Ooooo00<0003oool00000>oooo`060000oooooooo0000oooo
00000_ooo`030000oooo000003;oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
00000_ooo`030000oooo000002ooool00`000?ooooooo`03oooo00H0003oooooool0003oool00002
oooo00<0003oool00000=Oooo`007oooo`030000oooo000003Woool200000oooo`030000oooo0000
00;oool00`000?ooo`00000boooo00L0003oooooooooool0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`00000_oooo00@0003oooooooooool200000oooo`030000oooo000000;oool0
0`000?ooo`00000eoooo000Ooooo00<0003oool00000>Oooo`030000oooooooo00;oool00`000?oo
o`000002oooo00<0003oool00000<_ooo`070000oooooooooooo0000oooo000000;oool00`000?oo
o`000002oooo00<0003oool00000;oooo`050000oooooooooooo000000Coool00`000?ooo`000002
oooo00<0003oool00000=Oooo`008?ooo`030000oooooooo03Soool300000oooo`030000oooooooo
00;oool00`000?ooooooo`0`oooo0P0000Coool00`000?ooooooo`02oooo00<0003oooooool00_oo
o`030000oooooooo02goool200000oooo`<00003oooo00<0003oooooool00_ooo`030000oooooooo
03Coool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`006ooo
ool0000500000Oooo`006oooo`030000oooooooo00?oool00`000?ooooooo`0:oooo00<0003ooooo
ool02_ooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00[oool00`000?ooooooo`0:oooo00<0003oooooool02_ooo`030000oooooooo00[oool0
0`000?ooooooo`0:oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02_ooo`030000oooooooo00[oool00`000?ooooooo`0:oooo00<0003ooooo
ool02_ooo`030000oooooooo00[oool00`000?ooooooo`0:oooo00<0003oooooool01Oooo`400001
oooo000Eoooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`0moooo00<0
003oooooool0?_ooo`030000oooooooo03goool00`000?ooooooo`0ioooo0@00007oool001Coool0
0`000?ooo`000004oooo00<0003oooooool0ooooo`7oool100000Oooo`005?ooo`030000oooo0000
00Coool20000ooooo`7oool200000Oooo`005?ooo`030000oooo000000Coool00`000?ooooooo`3o
oooo0Oooo`400001oooo000Doooo00<0003oool000001?ooo`030000oooooooo0?ooool1oooo0@00
007oool001Goool00`000?ooooooo`03oooo00<0003oooooool0ooooo`7oool100000Oooo`006ooo
o`030000oooooooo0?ooool1oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001
oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`80003ooooo0Oooo`800001
oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000oooooooo0?ooool1
oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003ooooo
ool0ooooo`7oool100000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool001_oool0
0`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool100000Ooo
o`006oooo`80003ooooo0Oooo`800001oooo000Koooo00<0003oooooool0ooooo`7oool100000Ooo
o`006oooo`030000oooooooo0?ooool1oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Ooo
o`400001oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000oooooooo
0?ooool1oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0
003oooooool0ooooo`7oool100000Oooo`006oooo`80003ooooo0Oooo`800001oooo000Koooo00<0
003oooooool0ooooo`7oool100000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool0
01_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool1
00000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool000[oool300000oooo`030000
oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0ooooo`7oool100000Oooo`002_oo
o`030000oooooooo00;oool00`000?ooo`000002oooo00<0003oool000001?ooo`030000oooooooo
0?ooool1oooo0@00007oool000_oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
00001?ooo`80003ooooo0Oooo`800001oooo000;oooo00L0003oooooooooool0003oool000000_oo
o`030000oooo000000Coool00`000?ooooooo`3ooooo0Oooo`400001oooo000:oooo00<0003oool0
00000_ooo`030000oooo000000;oool00`000?ooo`000004oooo00<0003oooooool0aoooo`@00?le
oooo0@00007oool000_oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
00?oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003oooooool0Uoooo`03003o
oooooooo06Koool100000Oooo`006oooo`030000oooooooo09Ooool2003oIoooo`400001oooo000K
oooo00<0003oooooool0V?ooo`800?mVoooo0@00007oool001_oool20000ooooo`7oool200000Ooo
o`006oooo`030000oooooooo0?ooool1oooo0@00007oool001_oool00`000?ooooooo`2noooo00<0
0?ooooooool0?oooo`400001oooo000Koooo00<0003oooooool0__ooo`03003ooooooooo03ooool1
00000Oooo`006oooo`030000oooooooo0;ooool00`00ooooooooo`0noooo0@00007oool001_oool0
0`000?ooooooo`11oooo00<00?ooooooool0_?ooo`400001oooo000Koooo00<0003oooooool0oooo
o`7oool100000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool001_oool20000@_oo
o`03003ooooooooo0;_oool200000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool0
01_oool00`000?ooooooo`13oooo00<00?ooooooool0^_ooo`400001oooo000Koooo00<0003ooooo
ool09_ooo`03003ooooooooo00coool00`00ooooooooo`0:oooo0P00o`03oooo003ooooo00Soool0
0`00ooooo`00o`0=oooo0`00oikoool100000Oooo`006oooo`030000oooooooo02Koool3003o2ooo
o`@00?l:oooo1000o`Woool4003o2_ooo`D00?nNoooo0@00007oool001_oool00`000?ooooooo`0d
oooo0P00o`_oool3003o2oooo`<00?l;oooo0P00oj7oool100000Oooo`006oooo`030000oooooooo
02Koool00`00ooooooooo`3Goooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001
oooo000Koooo0P000?ooool1oooo0P00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001
oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000oooooooo0?ooool1
oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000;oooo0`0000;oool0
0`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo0?ooool1oooo0@00007oool0
00coool01P000?ooooooo`000?ooo`0000;oool00`000?ooo`000004oooo00<0003oooooool0<?oo
o`03003ooooooooo06Woool00`00ooooooooo`1Qoooo0@00007oool000[oool4000000Coool0003o
ool00002oooo00<0003oool000001?ooo`800005oooo00<00?ooooooool0AOooo`03003ooooooooo
04goool2003o<_ooo`03003ooooooooo02coool200000Oooo`002_ooo`030000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool000001?ooo`030000oooooooo033oool00`00ooooooooo`0I
oooo0P00odkoool3003oHOooo`400001oooo000;oooo0P0000;oool00`000?ooo`000002oooo00<0
003oool000001?ooo`030000oooooooo00Goool00`00ooooooooo`14oooo00<00?ooooooool0C_oo
o`800?mQoooo0@00007oool000coool01@000?ooooooooooo`000004oooo00<0003oooooool00ooo
o`030000oooooooo00?oool2003o:oooo`03003ooooooooo0<goool100000Oooo`006oooo`030000
oooooooo00?oool3003o1_ooo`03003ooooooooo01?oool00`00ooooooooo`04oooo0P00o`Goool2
003o1oooo`03003ooooooooo00?oool00`00ooooooooo`04oooo00<00?ooooooool02oooo`03003o
oooooooo04Soool00`00ooooooooo`0[oooo00@00?ooooooool00?l_oooo0@00007oool001_oool0
0`000?ooooooo`04oooo1P00o`;oool2003o0_ooo`<00?l2oooo0P00o`?oool00`00ooooooooo`05
oooo0P00o`Koool01000ooooooooo`00o`;oool4003o0oooo`<00?l00oooo`00ooooo`03oooo00<0
0?ooooooool00oooo`800?l5oooo0P00o`?oool4003o1?ooo`03003ooooooooo00Goool2003o>ooo
o`<00?lOoooo0P00o`[oool5003o3?ooo`800?lPoooo0@00007oool001_oool00`000?ooooooo`05
oooo0P00o`;oool8003o00?oool00?l00?l02`00o`Coool4003o0_ooo`H00?l2oooo1000o`;oool6
003o0oooo`800?l3oooo00<00?ooool00?l00P00o`?oool3003o0oooo`@00?l3oooo1000o`Coool3
003o>_ooo`@00?lNoooo1`00o`Coool7003o1?ooob@00?l5oooo0@00007oool001_oool00`000?oo
ooooo`0Noooo00<00?ooooooool05_ooo`03003ooooooooo00_oool00`00ooooooooo`05oooo00<0
0?ooooooool0L?ooo`03003ooooooooo00;oool00`00ooooooooo`04oooo00<00?ooooooool00P00
o`03oooo003ooooo00Goool01000ooooo`00o`00oaSoool00`00ooooooooo`02oooo00<00?oooooo
ool00oooo`400001oooo000Koooo0P0003;oool00`00ooooooooo`08oooo00@00?ooooooool00?l=
oooo00<00?ooooooool0Koooo`800?lnoooo0P00007oool001_oool00`000?ooooooo`30oooo0P00
ockoool100000Oooo`006oooo`030000oooooooo0<7oool00`00ooooooooo`0loooo0@00007oool0
01_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003oooooool0X_ooo`03003o
oooooooo05_oool100000Oooo`006oooo`030000oooooooo03koool2003oFOooo`800?l7oooo00<0
0?ooooooool0Foooo`400001oooo000Koooo00<0003oooooool07_ooo`D00?lIoooo1000occoool4
003o2_ooo`03003ooooooooo00goool00`00ooooooooo`05oooo1000oe[oool100000Oooo`006ooo
o`030000oooooooo01ooool4003o6oooo`03003ooooooooo00Woool00`00ooooooooo`0_oooo0`00
o`_oool00`00ooooooooo`0<oooo0P00o`Soool3003oF_ooo`400001oooo000Koooo0P0002?oool0
0`00ooooooooo`1Foooo00D00?ooooooooooool00?l06Oooo`03003ooooooooo00Woool00`00oooo
ooooo`1Goooo0P00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0
003oooooool0Voooo`03003ooooooooo06;oool100000Oooo`006oooo`030000oooooooo09_oool0
0`00ooooooooo`1Roooo0@00007oool001_oool00`000?ooooooo`1:oooo00<00?ooooooool0/ooo
o`400001oooo000Koooo00<0003oooooool0YOooo`03003ooooooooo05Soool100000Oooo`006ooo
o`030000oooooooo04[oool00`00ooooooooo`1Koooo00<00?ooooooool0EOooo`400001oooo000K
oooo00<0003oooooool0;_ooo`03003ooooooooo01Woool00`00ooooooooo`0boooo0P00oa[oool0
0`00ooooooooo`07oooo1@00oeKoool100000Oooo`006oooo`80000_oooo0P00oa[oool2003o:Ooo
o`@00?l6oooo00<00?ooooooool03oooo`<00?l8oooo00<00?ooooooool01oooo`@00?mEoooo0P00
007oool001_oool00`000?ooooooo`1eoooo1000oaOoool5003oJoooo`400001oooo000Koooo00<0
003oooooool0MOooo`@00?lGoooo00@00?ooool00?l00?m/oooo0@00007oool001_oool00`000?oo
ooooo`30oooo00<00?ooooooool0?Oooo`400001oooo000Koooo00<0003oooooool0N?ooo`@00?lH
oooo1000oa7oool2003o00?oool00?ooool04_ooo`03003ooooooooo03goool100000Oooo`002_oo
o`800004oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`1Toooo00<0
0?ooooooool01oooo`800?l8oooo1000o`ooool2003o1oooo`@00?lAoooo1000o`coool2003oAOoo
o`400001oooo000:oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000004
oooo00<0003oooooool0I?ooo`03003ooooooooo00Ooool3003o6_ooo`@00?lKoooo0P00o`koool0
0`00ooooooooo`13oooo0@00007oool000[oool00`000?ooo`000002oooo00<0003oool000000_oo
o`030000oooo000000Coool20000L?ooo`800?lIoooo0P00o`03oooo003o003o02_oool00`00oooo
ooooo`12oooo0P00007oool000[oool200000oooo`030000oooo000000;oool00`000?ooo`000004
oooo00<0003oooooool0IOooo`800?lQoooo0P00o`04oooo003ooooo003o7_ooo`03003ooooooooo
057oool100000Oooo`002_ooo`030000oooooooo00;oool00`000?ooo`000002oooo00<0003oool0
00001?ooo`030000oooooooo073oool00`00ooooooooo`0Goooo00@00?ooooooool00?mboooo0@00
007oool000_oool200000oooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003ooooo
ool0Eoooo`03003ooooooooo00_oool2003o9oooo`03003ooooooooo06ooool100000Oooo`006ooo
o`030000oooooooo05Soool00`00ooooooooo`0:oooo0P00o`[oool00`00ooooooooo`0Joooo00<0
0?ooooooool0Koooo`400001oooo000Koooo00<0003oooooool0Eoooo`800?lHoooo00<00?oooooo
ool06_ooo`03003ooooooooo01_oool00`00ooooooooo`1Aoooo0@00007oool001_oool00`000?oo
ooooo`1Toooo00<00?ooooooool09oooo`800?lLoooo00<00?ooooooool0DOooo`400001oooo000K
oooo00<0003oooooool0Eoooo`800?l=oooo00<00?ooooooool03?ooo`03003ooooooooo00[oool2
003o00?oool00?ooool01oooo`03003ooooooooo06ooool100000Oooo`006oooo`80001Hoooo0P00
o`coool2003o2_ooo`@00?l>oooo0`00o`Soool3003o7?ooo`800?l<oooo00<00?ooooooool03_oo
o`03003ooooooooo033oool200000Oooo`006oooo`030000oooooooo05Soool3003o2_ooo`D00?l7
oooo1000o`_oool2003o00?oool00?l00?l00P00o`Soool2003o7?ooo`<00?l;oooo0P00o`goool2
003o=?ooo`400001oooo000Koooo00<0003oooooool0FOooo`800?l=oooo0`00o`Woool00`00oooo
ooooo`09oooo0`00o`?oool00`00ooooooooo`06oooo0P00oagoool3003o2oooo`<00?l<oooo00<0
0?ooooooool0<_ooo`400001oooo000Koooo00<0003oooooool0P?ooo`<00?l=oooo00<00?oooooo
ool0:_ooo`800?l<oooo0P00o`Ooool00`00ooooooooo`0Yoooo0@00007oool001_oool00`000?oo
ooooo`2`oooo00<00?ooooooool06Oooo`03003ooooooooo00Goool2003o:_ooo`400001oooo000K
oooo00<0003oooooool0Q_ooo`03003ooooooooo04[oool3003o:_ooo`400001oooo000Koooo00<0
003oooooool0P?ooo`03003ooooooooo053oool3003o:_ooo`400001oooo000Koooo00<0003ooooo
ool0J_ooo`03003ooooooooo06Koool2003o:oooo`400001oooo000Koooo0P0008_oool00`00oooo
ooooo`0Soooo00<00?ooooooool0C?ooo`800001oooo000Koooo00<0003oooooool0K?ooo`03003o
oooo003o047oool00`00ooooooooo`1=oooo0@00007oool001_oool00`000?ooooooo`1Zoooo00@0
0?ooool00?l00?lHoooo00<00?ooooooool00P00obGoool00`00ooooooooo`1=oooo0@00007oool0
01_oool00`000?ooooooo`1Zoooo00@00?ooool00?l00?lKoooo0P00obGoool2003o00?oool00?oo
ool0Boooo`400001oooo000Koooo00<0003oooooool0J_ooo`04003ooooooooo003o6?ooo`800?l0
0oooo`00ooooo`0Voooo0`00odcoool100000Oooo`006oooo`030000oooooooo06[oool4003o6Ooo
o`800?lXoooo0`00odcoool100000Oooo`006oooo`030000oooooooo06goool00`00ooooooooo`0I
oooo00<00?ooooooool09oooo`03003ooooooooo04[oool100000Oooo`006oooo`80001_oooo00<0
0?ooooooool0S_ooo`800001oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006ooo
o`030000oooooooo0;?oool00`00ooooooooo`1:oooo0@00007oool001_oool00`000?ooooooo`3o
oooo0Oooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000
oooooooo0;Koool00`00ooooooooo`17oooo0@00007oool000_oool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`2foooo00<00?ooooooool0Aooo
o`400001oooo000:oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000004
oooo00<0003oooooool0]_ooo`03003ooooooooo04Ooool100000Oooo`002_ooo`030000oooo0000
00;oool00`000?ooo`000002oooo00<0003oool000001?ooo`80002doooo00D00?ooooooooooool0
0?l0Aoooo`800001oooo000;oooo00L0003oooooooooool0003oool000000_ooo`030000oooo0000
00Coool00`000?ooooooo`2coooo0P00o`03oooo003ooooo04Soool100000Oooo`002_ooo`030000
oooo000000;oool00`000?ooo`000002oooo00<0003oool000001?ooo`030000oooooooo0;Coool0
0`00ooooooooo`19oooo0@00007oool000_oool00`000?ooooooo`02oooo00<0003oooooool00_oo
o`030000oooooooo00?oool00`000?ooooooo`2eoooo0P00odWoool100000Oooo`006oooo`030000
oooooooo0;Goool00`00ooooooooo`18oooo0@00007oool001_oool00`000?ooooooo`2eoooo00<0
0?ooooooool0B?ooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006ooo
o`030000oooooooo0?ooool1oooo0@00007oool001_oool20000ooooo`7oool200000Oooo`006ooo
o`030000oooooooo0;Ooool00`00ooooooooo`16oooo0@00007oool001_oool00`000?ooooooo`3o
oooo0Oooo`400001oooo000Koooo00<0003oooooool0]oooo`03003ooooo003o04Koool100000Ooo
o`006oooo`030000oooooooo0;Ooool4003o6_ooo`800?lYoooo0@00007oool001_oool00`000?oo
ooooo`2ioooo0`00oa[oool2003o:?ooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool1
00000Oooo`006oooo`80003ooooo0Oooo`800001oooo000Koooo00<0003oooooool0ooooo`7oool1
00000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool001_oool00`000?ooooooo`3o
oooo0Oooo`400001oooo000Koooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000
oooooooo0?ooool1oooo0@00007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000K
oooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`80003ooooo0Oooo`800001oooo000K
oooo00<0003oooooool0ooooo`7oool100000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00
007oool001_oool00`000?ooooooo`3ooooo0Oooo`400001oooo000Koooo00<0003oooooool0oooo
o`7oool100000Oooo`006oooo`030000oooooooo0?ooool1oooo0@00007oool000Coool500000_oo
o`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo
0?ooool1oooo0@00007oool000Koool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
00000_ooo`030000oooo000000Coool00`000?ooooooo`3ooooo0Oooo`400001oooo0006oooo00L0
003oooooooooool0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000004oooo0P00
0?ooool1oooo0P00007oool000Koool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
00000_ooo`030000oooo000000Coool00`000?ooooooo`03oooo00<0003oooooool02_ooo`030000
oooooooo00[oool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`0:oooo00<0003oooooool02_ooo`030000oooooooo00[oool00`000?ooooooo`0:
oooo00<0003oooooool02_ooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00[oool00`000?ooooooo`0:oooo00<0003oooooool02_ooo`030000
oooooooo00[oool00`000?ooooooo`0:oooo00<0003oooooool02_ooo`030000oooooooo00Goool1
00000Oooo`001_ooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0
003oool000001?ooool0000500000Oooo`001Oooo`800004oooo00<0003oooooool00_ooo`030000
oooooooo00;oool00`000?ooooooo`3ooooo2Oooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-259.57, -111.728, 7.76498, 
  6.49033}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wykres por\[OAcute]wnawczy z danymi MIDI", "Section"],

Cell["Przygotowanie wykresu", "MathCaption"],

Cell[BoxData[
    \(Wykresy = {}; \n
    For[i = 1, i <= Length[TabFreq], \(i++\), \n\t
      AppendTo[Wykresy, 
        Graphics[{RGBColor[0, 0, 1], PointSize[0.004], 
            Point[{\(i*Skok\)\/CzP, 
                TabFreq\[LeftDoubleBracket]i\[RightDoubleBracket]}]}]]]; \)], 
  "Input",
  CellLabel->"In[382]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{Graph, Wykresy}, Frame -> True, Axes -> False]; \)\)], "Input",
  CellLabel->"In[383]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.109375 0.0147151 0.000593461 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.24256 -0.0125 -3 -9 ]
[.24256 -0.0125 3 0 ]
[.46131 -0.0125 -3 -9 ]
[.46131 -0.0125 3 0 ]
[.68006 -0.0125 -3 -9 ]
[.68006 -0.0125 3 0 ]
[.89881 -0.0125 -3 -9 ]
[.89881 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13341 -18 -4.5 ]
[-0.0125 .13341 0 4.5 ]
[-0.0125 .2521 -18 -4.5 ]
[-0.0125 .2521 0 4.5 ]
[-0.0125 .37079 -18 -4.5 ]
[-0.0125 .37079 0 4.5 ]
[-0.0125 .48948 -18 -4.5 ]
[-0.0125 .48948 0 4.5 ]
[-0.0125 .60818 -24 -4.5 ]
[-0.0125 .60818 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.24256 0 m
.24256 .00625 L
s
[(2)] .24256 -0.0125 0 1 Mshowa
.46131 0 m
.46131 .00625 L
s
[(4)] .46131 -0.0125 0 1 Mshowa
.68006 0 m
.68006 .00625 L
s
[(6)] .68006 -0.0125 0 1 Mshowa
.89881 0 m
.89881 .00625 L
s
[(8)] .89881 -0.0125 0 1 Mshowa
.125 Mabswid
.0785 0 m
.0785 .00375 L
s
.13318 0 m
.13318 .00375 L
s
.18787 0 m
.18787 .00375 L
s
.29725 0 m
.29725 .00375 L
s
.35193 0 m
.35193 .00375 L
s
.40662 0 m
.40662 .00375 L
s
.516 0 m
.516 .00375 L
s
.57068 0 m
.57068 .00375 L
s
.62537 0 m
.62537 .00375 L
s
.73475 0 m
.73475 .00375 L
s
.78943 0 m
.78943 .00375 L
s
.84412 0 m
.84412 .00375 L
s
.9535 0 m
.9535 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13341 m
.00625 .13341 L
s
[(200)] -0.0125 .13341 1 0 Mshowa
0 .2521 m
.00625 .2521 L
s
[(400)] -0.0125 .2521 1 0 Mshowa
0 .37079 m
.00625 .37079 L
s
[(600)] -0.0125 .37079 1 0 Mshowa
0 .48948 m
.00625 .48948 L
s
[(800)] -0.0125 .48948 1 0 Mshowa
0 .60818 m
.00625 .60818 L
s
[(1000)] -0.0125 .60818 1 0 Mshowa
.125 Mabswid
0 .04439 m
.00375 .04439 L
s
0 .07406 m
.00375 .07406 L
s
0 .10373 m
.00375 .10373 L
s
0 .16308 m
.00375 .16308 L
s
0 .19275 m
.00375 .19275 L
s
0 .22243 m
.00375 .22243 L
s
0 .28177 m
.00375 .28177 L
s
0 .31145 m
.00375 .31145 L
s
0 .34112 m
.00375 .34112 L
s
0 .40046 m
.00375 .40046 L
s
0 .43014 m
.00375 .43014 L
s
0 .45981 m
.00375 .45981 L
s
0 .51916 m
.00375 .51916 L
s
0 .54883 m
.00375 .54883 L
s
0 .5785 m
.00375 .5785 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.24256 .61178 m
.24256 .61803 L
s
.46131 .61178 m
.46131 .61803 L
s
.68006 .61178 m
.68006 .61803 L
s
.89881 .61178 m
.89881 .61803 L
s
.125 Mabswid
.0785 .61428 m
.0785 .61803 L
s
.13318 .61428 m
.13318 .61803 L
s
.18787 .61428 m
.18787 .61803 L
s
.29725 .61428 m
.29725 .61803 L
s
.35193 .61428 m
.35193 .61803 L
s
.40662 .61428 m
.40662 .61803 L
s
.516 .61428 m
.516 .61803 L
s
.57068 .61428 m
.57068 .61803 L
s
.62537 .61428 m
.62537 .61803 L
s
.73475 .61428 m
.73475 .61803 L
s
.78943 .61428 m
.78943 .61803 L
s
.84412 .61428 m
.84412 .61803 L
s
.9535 .61428 m
.9535 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13341 m
1 .13341 L
s
.99375 .2521 m
1 .2521 L
s
.99375 .37079 m
1 .37079 L
s
.99375 .48948 m
1 .48948 L
s
.99375 .60818 m
1 .60818 L
s
.125 Mabswid
.99625 .04439 m
1 .04439 L
s
.99625 .07406 m
1 .07406 L
s
.99625 .10373 m
1 .10373 L
s
.99625 .16308 m
1 .16308 L
s
.99625 .19275 m
1 .19275 L
s
.99625 .22243 m
1 .22243 L
s
.99625 .28177 m
1 .28177 L
s
.99625 .31145 m
1 .31145 L
s
.99625 .34112 m
1 .34112 L
s
.99625 .40046 m
1 .40046 L
s
.99625 .43014 m
1 .43014 L
s
.99625 .45981 m
1 .45981 L
s
.99625 .51916 m
1 .51916 L
s
.99625 .54883 m
1 .54883 L
s
.99625 .5785 m
1 .5785 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
.02381 .27584 m
.12845 .27584 L
s
.12845 .30782 m
.14524 .30782 L
s
.14524 .27584 m
.15816 .27584 L
s
.15816 .21034 m
.17108 .21034 L
s
.17108 .27584 m
.18787 .27584 L
s
.18787 .34371 m
.19691 .34371 L
s
.19691 .27584 m
.20983 .27584 L
s
.20983 .21034 m
.22275 .21034 L
s
.22275 .27584 m
.24213 .27584 L
s
.24213 .30782 m
.25505 .30782 L
s
.25505 .27584 m
.26409 .27584 L
s
.26409 .21034 m
.27701 .21034 L
s
.27701 .27584 m
.2938 .27584 L
s
.2938 .34371 m
.30284 .34371 L
s
.30284 .27584 m
.31706 .27584 L
s
.31706 .21034 m
.32997 .21034 L
s
.32997 .27584 m
.34289 .27584 L
s
.34289 .40596 m
.35969 .40596 L
s
.35969 .27584 m
.3739 .27584 L
s
.3739 .21034 m
.38681 .21034 L
s
.38681 .27584 m
.39973 .27584 L
s
.39973 .40596 m
.41782 .40596 L
s
.41782 .45387 m
.4372 .45387 L
s
.4372 .36327 m
.44624 .36327 L
s
.44624 .40596 m
.46045 .40596 L
s
.46045 .34371 m
.47466 .34371 L
s
.47466 .36327 m
.48758 .36327 L
s
.48758 .30782 m
.50179 .30782 L
s
.50179 .34371 m
.50954 .34371 L
s
.50954 .40596 m
.53021 .40596 L
s
.53021 .45387 m
.54442 .45387 L
s
.54442 .36327 m
.55734 .36327 L
s
.55734 .40596 m
.56767 .40596 L
s
.56767 .34371 m
.58059 .34371 L
s
.58059 .36327 m
.59609 .36327 L
s
.59609 .30782 m
.6103 .30782 L
s
.6103 .34371 m
.61418 .34371 L
s
.61418 .27584 m
.63614 .27584 L
s
.63614 .30782 m
.64906 .30782 L
s
.64906 .34371 m
.66197 .34371 L
s
.66197 .36327 m
.67489 .36327 L
s
.67489 .40596 m
.6891 .40596 L
s
.6891 .45387 m
.70331 .45387 L
s
.70331 .50765 m
.71623 .50765 L
s
.71623 .53696 m
.73173 .53696 L
s
.73173 .40596 m
.74594 .40596 L
s
.74594 .34371 m
.74982 .34371 L
s
.74982 .27584 m
.7679 .27584 L
s
.7679 .53696 m
.78987 .53696 L
s
.78987 .40596 m
.79632 .40596 L
s
.79632 .34371 m
.80278 .34371 L
s
.80278 .27584 m
.82087 .27584 L
s
.82087 .53696 m
.84025 .53696 L
s
.84025 .27584 m
.96943 .27584 L
s
0 0 1 r
.0253 .26569 Mdot
.02579 .26814 Mdot
.02629 .26677 Mdot
.02679 .2674 Mdot
.02728 .26457 Mdot
.02778 .26456 Mdot
.02827 .27215 Mdot
.02877 .27152 Mdot
.02927 .27208 Mdot
.02976 .27095 Mdot
.03026 .25538 Mdot
.03075 .25989 Mdot
.03125 .26913 Mdot
.03175 .2709 Mdot
.03224 .2725 Mdot
.03274 .27407 Mdot
.03323 .2751 Mdot
.03373 .27563 Mdot
.03423 .27575 Mdot
.03472 .27539 Mdot
.03522 .27501 Mdot
.03571 .27489 Mdot
.03621 .27472 Mdot
.03671 .27491 Mdot
.0372 .27518 Mdot
.0377 .27514 Mdot
.03819 .27501 Mdot
.03869 .27492 Mdot
.03919 .27483 Mdot
.03968 .27476 Mdot
.04018 .27456 Mdot
.04067 .27438 Mdot
.04117 .27434 Mdot
.04167 .27421 Mdot
.04216 .274 Mdot
.04266 .27399 Mdot
.04315 .27414 Mdot
.04365 .2742 Mdot
.04415 .27428 Mdot
.04464 .2745 Mdot
.04514 .27452 Mdot
.04563 .27452 Mdot
.04613 .27468 Mdot
.04663 .27494 Mdot
.04712 .27529 Mdot
.04762 .27552 Mdot
.04812 .27568 Mdot
.04861 .27598 Mdot
.04911 .27638 Mdot
.0496 .27665 Mdot
.0501 .27676 Mdot
.0506 .27688 Mdot
.05109 .277 Mdot
.05159 .27691 Mdot
.05208 .27675 Mdot
.05258 .27676 Mdot
.05308 .27688 Mdot
.05357 .27696 Mdot
.05407 .27688 Mdot
.05456 .27676 Mdot
.05506 .2767 Mdot
.05556 .27671 Mdot
.05605 .27659 Mdot
.05655 .27633 Mdot
.05704 .27591 Mdot
.05754 .27539 Mdot
.05804 .27498 Mdot
.05853 .2746 Mdot
.05903 .27408 Mdot
.05952 .27332 Mdot
.06002 .27224 Mdot
.06052 .2712 Mdot
.06101 .27075 Mdot
.06151 .27155 Mdot
.062 .27245 Mdot
.0625 .27332 Mdot
.063 .27409 Mdot
.06349 .27478 Mdot
.06399 .27528 Mdot
.06448 .27564 Mdot
.06498 .27594 Mdot
.06548 .27646 Mdot
.06597 .27724 Mdot
.06647 .2782 Mdot
.06696 .27842 Mdot
.06746 .27787 Mdot
.06796 .27772 Mdot
.06845 .27759 Mdot
.06895 .27737 Mdot
.06944 .27773 Mdot
.06994 .27828 Mdot
.07044 .27814 Mdot
.07093 .27757 Mdot
.07143 .27751 Mdot
.07192 .27789 Mdot
.07242 .27789 Mdot
.07292 .27753 Mdot
.07341 .27701 Mdot
.07391 .27644 Mdot
.0744 .27601 Mdot
.0749 .27549 Mdot
.0754 .27486 Mdot
.07589 .27433 Mdot
.07639 .27424 Mdot
.07688 .27402 Mdot
.07738 .27375 Mdot
.07788 .27337 Mdot
.07837 .27276 Mdot
.07887 .27211 Mdot
.07937 .27188 Mdot
.07986 .27222 Mdot
.08036 .27319 Mdot
.08085 .27433 Mdot
.08135 .27514 Mdot
.08185 .27552 Mdot
.08234 .27575 Mdot
.08284 .27592 Mdot
.08333 .27615 Mdot
.08383 .2767 Mdot
.08433 .2776 Mdot
.08482 .2782 Mdot
.08532 .27806 Mdot
.08581 .27786 Mdot
.08631 .27763 Mdot
.08681 .27748 Mdot
.0873 .27778 Mdot
.0878 .27809 Mdot
.08829 .2779 Mdot
.08879 .27762 Mdot
.08929 .27766 Mdot
.08978 .27786 Mdot
.09028 .27794 Mdot
.09077 .27739 Mdot
.09127 .27656 Mdot
.09177 .27588 Mdot
.09226 .27518 Mdot
.09276 .27463 Mdot
.09325 .27423 Mdot
.09375 .27374 Mdot
.09425 .27362 Mdot
.09474 .27347 Mdot
.09524 .27321 Mdot
.09573 .27291 Mdot
.09623 .27269 Mdot
.09673 .27242 Mdot
.09722 .27214 Mdot
.09772 .27242 Mdot
.09821 .27319 Mdot
.09871 .27439 Mdot
.09921 .27512 Mdot
.0997 .27529 Mdot
.1002 .27538 Mdot
.10069 .2755 Mdot
.10119 .27569 Mdot
.10169 .27602 Mdot
.10218 .27649 Mdot
.10268 .27712 Mdot
.10317 .2781 Mdot
.10367 .27799 Mdot
.10417 .27749 Mdot
.10466 .27746 Mdot
.10516 .27776 Mdot
.10565 .27794 Mdot
.10615 .27796 Mdot
.10665 .2776 Mdot
.10714 .27757 Mdot
.10764 .27816 Mdot
.10813 .2783 Mdot
.10863 .27716 Mdot
.10913 .27654 Mdot
.10962 .27652 Mdot
.11012 .27653 Mdot
.11062 .27619 Mdot
.11111 .27595 Mdot
.11161 .27564 Mdot
.1121 .27522 Mdot
.1126 .27484 Mdot
.1131 .27476 Mdot
.11359 .27502 Mdot
.11409 .27549 Mdot
.11458 .27601 Mdot
.11508 .2764 Mdot
.11558 .27658 Mdot
.11607 .27679 Mdot
.11657 .27693 Mdot
.11706 .2768 Mdot
.11756 .27671 Mdot
.11806 .27687 Mdot
.11855 .27719 Mdot
.11905 .27774 Mdot
.11954 .27826 Mdot
.12004 .27871 Mdot
.12054 .27848 Mdot
.12103 .27837 Mdot
.12153 .27864 Mdot
.12202 .27846 Mdot
.12252 .27789 Mdot
.12302 .27774 Mdot
.12351 .27756 Mdot
.12401 .27704 Mdot
.1245 .27639 Mdot
.125 .27583 Mdot
.1255 .27613 Mdot
.12599 .27711 Mdot
.12649 .27732 Mdot
.12698 .27676 Mdot
.12748 .27634 Mdot
.12798 .2796 Mdot
.12847 .28119 Mdot
.12897 .30689 Mdot
.12946 .30866 Mdot
.12996 .30866 Mdot
.13046 .30878 Mdot
.13095 .30893 Mdot
.13145 .30986 Mdot
.13194 .30984 Mdot
.13244 .31018 Mdot
.13294 .30968 Mdot
.13343 .31003 Mdot
.13393 .30927 Mdot
.13442 .30988 Mdot
.13492 .31004 Mdot
.13542 .30951 Mdot
.13591 .30829 Mdot
.13641 .30991 Mdot
.1369 .30836 Mdot
.1374 .30851 Mdot
.1379 .30975 Mdot
.13839 .30966 Mdot
.13889 .31003 Mdot
.13938 .31075 Mdot
.13988 .31054 Mdot
.14038 .31078 Mdot
.14087 .31085 Mdot
.14137 .31078 Mdot
.14187 .30994 Mdot
.14236 .30966 Mdot
.14286 .31029 Mdot
.14335 .30996 Mdot
.14385 .31018 Mdot
.14435 .31551 Mdot
.14484 .31462 Mdot
.14534 .26771 Mdot
.14583 .27278 Mdot
.14633 .27507 Mdot
.14683 .27609 Mdot
.14732 .27677 Mdot
.14782 .2769 Mdot
.14831 .27705 Mdot
.14881 .27703 Mdot
.14931 .27719 Mdot
.1498 .27725 Mdot
.1503 .27776 Mdot
.15079 .27773 Mdot
.15129 .27799 Mdot
.15179 .27813 Mdot
.15228 .27838 Mdot
.15278 .27807 Mdot
.15327 .27794 Mdot
.15377 .27769 Mdot
.15427 .27745 Mdot
.15476 .27757 Mdot
.15526 .27841 Mdot
.15575 .27834 Mdot
.15625 .27745 Mdot
.15675 .27761 Mdot
.15724 .27836 Mdot
.15774 .27807 Mdot
.15823 .27737 Mdot
.15873 .21905 Mdot
.15923 .21928 Mdot
.15972 .21086 Mdot
.16022 .20624 Mdot
.16071 .20722 Mdot
.16121 .20855 Mdot
.16171 .20994 Mdot
.1622 .21014 Mdot
.1627 .21053 Mdot
.16319 .21062 Mdot
.16369 .21058 Mdot
.16419 .21056 Mdot
.16468 .21042 Mdot
.16518 .21059 Mdot
.16567 .21072 Mdot
.16617 .21111 Mdot
.16667 .21067 Mdot
.16716 .21122 Mdot
.16766 .21111 Mdot
.16815 .21111 Mdot
.16865 .21073 Mdot
.16915 .27785 Mdot
.16964 .27736 Mdot
.17014 .27796 Mdot
.17063 .27755 Mdot
.17113 .27663 Mdot
.17163 .27635 Mdot
.17212 .27122 Mdot
.17262 .26883 Mdot
.17312 .26994 Mdot
.17361 .27394 Mdot
.17411 .27132 Mdot
.1746 .26993 Mdot
.1751 .27044 Mdot
.1756 .27428 Mdot
.17609 .27561 Mdot
.17659 .27555 Mdot
.17708 .27625 Mdot
.17758 .27639 Mdot
.17808 .27664 Mdot
.17857 .27682 Mdot
.17907 .27682 Mdot
.17956 .27685 Mdot
.18006 .27655 Mdot
.18056 .27702 Mdot
.18105 .27722 Mdot
.18155 .27793 Mdot
.18204 .27806 Mdot
.18254 .27698 Mdot
.18304 .27637 Mdot
.18353 .27682 Mdot
.18403 .27665 Mdot
.18452 .27631 Mdot
.18502 .27592 Mdot
.18552 .27715 Mdot
.18601 .27472 Mdot
.18651 .27395 Mdot
.187 .27473 Mdot
.1875 .27707 Mdot
.188 .27706 Mdot
.18849 .27639 Mdot
.18899 .27662 Mdot
.18948 .3431 Mdot
.18998 .34516 Mdot
.19048 .34423 Mdot
.19097 .34547 Mdot
.19147 .34492 Mdot
.19196 .34583 Mdot
.19246 .34552 Mdot
.19296 .34618 Mdot
.19345 .34621 Mdot
.19395 .34553 Mdot
.19444 .34614 Mdot
.19494 .34526 Mdot
.19544 .34665 Mdot
.19593 .34576 Mdot
.19643 .25118 Mdot
.19692 .25881 Mdot
.19742 .26589 Mdot
.19792 .26726 Mdot
.19841 .27004 Mdot
.19891 .27111 Mdot
.1994 .27217 Mdot
.1999 .27416 Mdot
.2004 .27588 Mdot
.20089 .27812 Mdot
.20139 .27605 Mdot
.20188 .27548 Mdot
.20238 .28447 Mdot
.20288 .26758 Mdot
.20337 .27134 Mdot
.20387 .27438 Mdot
.20437 .27541 Mdot
.20486 .27564 Mdot
.20536 .27599 Mdot
.20585 .27597 Mdot
.20635 .27597 Mdot
.20685 .27573 Mdot
.20734 .27564 Mdot
.20784 .27633 Mdot
.20833 .27579 Mdot
.20883 .27651 Mdot
.20933 .27607 Mdot
.20982 .27578 Mdot
.21032 .27484 Mdot
.21081 .27411 Mdot
.21131 .27471 Mdot
.21181 .27593 Mdot
.2123 .2758 Mdot
.2128 .27658 Mdot
.21329 .27542 Mdot
.21379 .27588 Mdot
.21429 .21455 Mdot
.21478 .21319 Mdot
.21528 .21337 Mdot
.21577 .21468 Mdot
.21627 .21244 Mdot
.21677 .20662 Mdot
.21726 .20708 Mdot
.21776 .20867 Mdot
.21825 .20983 Mdot
.21875 .21009 Mdot
.21925 .21032 Mdot
.21974 .21017 Mdot
.22024 .21026 Mdot
.22073 .2103 Mdot
.22123 .21054 Mdot
.22173 .21042 Mdot
.22222 .21015 Mdot
.22272 .21084 Mdot
.22321 .21046 Mdot
.22371 .21047 Mdot
.22421 .27417 Mdot
.2247 .27936 Mdot
.2252 .2781 Mdot
.22569 .28093 Mdot
.22619 .27649 Mdot
.22669 .27668 Mdot
.22718 .27474 Mdot
.22768 .27246 Mdot
.22817 .27174 Mdot
.22867 .27224 Mdot
.22917 .27297 Mdot
.22966 .27605 Mdot
.23016 .27172 Mdot
.23065 .27116 Mdot
.23115 .27346 Mdot
.23165 .27466 Mdot
.23214 .27538 Mdot
.23264 .27593 Mdot
.23313 .27652 Mdot
.23363 .27604 Mdot
.23413 .27589 Mdot
.23462 .27626 Mdot
.23512 .27598 Mdot
.23562 .27628 Mdot
.23611 .27636 Mdot
.23661 .2774 Mdot
.2371 .27683 Mdot
.2376 .27683 Mdot
.2381 .27624 Mdot
.23859 .27554 Mdot
.23909 .27583 Mdot
.23958 .27635 Mdot
.24008 .27595 Mdot
.24058 .2756 Mdot
.24107 .27495 Mdot
.24157 .27515 Mdot
.24206 .27613 Mdot
.24256 .27582 Mdot
.24306 .28374 Mdot
.24355 .30691 Mdot
.24405 .30604 Mdot
.24454 .30673 Mdot
.24504 .30692 Mdot
.24554 .30803 Mdot
.24603 .30887 Mdot
.24653 .3094 Mdot
.24702 .30917 Mdot
.24752 .30882 Mdot
.24802 .30906 Mdot
.24851 .30917 Mdot
.24901 .30925 Mdot
.2495 .30953 Mdot
.25 .3106 Mdot
.2505 .3101 Mdot
.25099 .30728 Mdot
.25149 .30735 Mdot
.25198 .30861 Mdot
.25248 .3076 Mdot
.25298 .30664 Mdot
.25347 .30265 Mdot
.25397 .30361 Mdot
.25446 .30799 Mdot
.25496 .30846 Mdot
.25546 .30646 Mdot
.25595 .30358 Mdot
.25645 .28427 Mdot
.25694 .27073 Mdot
.25744 .27073 Mdot
.25794 .27373 Mdot
.25843 .27497 Mdot
.25893 .27522 Mdot
.25942 .27575 Mdot
.25992 .27578 Mdot
.26042 .27675 Mdot
.26091 .27613 Mdot
.26141 .27636 Mdot
.2619 .27673 Mdot
.2624 .2759 Mdot
.2629 .27649 Mdot
.26339 .18617 Mdot
.26389 .18489 Mdot
.26438 .19688 Mdot
.26488 .21593 Mdot
.26538 .21699 Mdot
.26587 .21584 Mdot
.26637 .21496 Mdot
.26687 .21536 Mdot
.26736 .21469 Mdot
.26786 .21211 Mdot
.26835 .20959 Mdot
.26885 .21198 Mdot
.26935 .21652 Mdot
.26984 .21618 Mdot
.27034 .21617 Mdot
.27083 .20926 Mdot
.27133 .20567 Mdot
.27183 .20851 Mdot
.27232 .20967 Mdot
.27282 .21003 Mdot
.27331 .2105 Mdot
.27381 .21039 Mdot
.27431 .21008 Mdot
.2748 .21006 Mdot
.2753 .21031 Mdot
.27579 .21033 Mdot
.27629 .21018 Mdot
.27679 .21003 Mdot
.27728 .21063 Mdot
.27778 .20986 Mdot
.27827 .20953 Mdot
.27877 .20966 Mdot
.27927 .2773 Mdot
.27976 .27953 Mdot
.28026 .27886 Mdot
.28075 .27461 Mdot
.28125 .27395 Mdot
.28175 .27328 Mdot
.28224 .27315 Mdot
.28274 .27187 Mdot
.28323 .27084 Mdot
.28373 .27352 Mdot
.28423 .27506 Mdot
.28472 .27528 Mdot
.28522 .27508 Mdot
.28571 .27565 Mdot
.28621 .276 Mdot
.28671 .27662 Mdot
.2872 .2763 Mdot
.2877 .27644 Mdot
.28819 .27683 Mdot
.28869 .27731 Mdot
.28919 .27779 Mdot
.28968 .27868 Mdot
.29018 .27852 Mdot
.29067 .27756 Mdot
.29117 .27822 Mdot
.29167 .27722 Mdot
.29216 .27683 Mdot
.29266 .27715 Mdot
.29315 .27649 Mdot
.29365 .27613 Mdot
.29415 .27562 Mdot
.29464 .27611 Mdot
.29514 .27707 Mdot
.29563 .27657 Mdot
.29613 .31111 Mdot
.29663 .33116 Mdot
.29712 .33706 Mdot
.29762 .34536 Mdot
.29812 .34465 Mdot
.29861 .34435 Mdot
.29911 .34467 Mdot
.2996 .34496 Mdot
.3001 .34522 Mdot
.3006 .34687 Mdot
.30109 .34666 Mdot
.30159 .34697 Mdot
.30208 .34727 Mdot
.30258 .34719 Mdot
.30308 .34703 Mdot
.30357 .34784 Mdot
.30407 .25911 Mdot
.30456 .25646 Mdot
.30506 .25719 Mdot
.30556 .25652 Mdot
.30605 .25849 Mdot
.30655 .25545 Mdot
.30704 .25772 Mdot
.30754 .26324 Mdot
.30804 .25709 Mdot
.30853 .28008 Mdot
.30903 .28 Mdot
.30952 .28395 Mdot
.31002 .27213 Mdot
.31052 .27404 Mdot
.31101 .27546 Mdot
.31151 .27458 Mdot
.312 .27492 Mdot
.3125 .27448 Mdot
.313 .27459 Mdot
.31349 .27477 Mdot
.31399 .27441 Mdot
.31448 .2752 Mdot
.31498 .27577 Mdot
.31548 .27557 Mdot
.31597 .27583 Mdot
.31647 .27667 Mdot
.31696 .20682 Mdot
.31746 .20848 Mdot
.31796 .20997 Mdot
.31845 .21219 Mdot
.31895 .21349 Mdot
.31944 .21357 Mdot
.31994 .21214 Mdot
.32044 .212 Mdot
.32093 .21363 Mdot
.32143 .21381 Mdot
.32192 .21385 Mdot
.32242 .21401 Mdot
.32292 .21489 Mdot
.32341 .21467 Mdot
.32391 .21507 Mdot
.3244 .21709 Mdot
.3249 .21316 Mdot
.3254 .2064 Mdot
.32589 .20798 Mdot
.32639 .2091 Mdot
.32688 .20971 Mdot
.32738 .21049 Mdot
.32788 .21055 Mdot
.32837 .21034 Mdot
.32887 .2104 Mdot
.32937 .21148 Mdot
.32986 .21176 Mdot
.33036 .27222 Mdot
.33085 .27384 Mdot
.33135 .27658 Mdot
.33185 .27576 Mdot
.33234 .27557 Mdot
.33284 .27586 Mdot
.33333 .27726 Mdot
.33383 .2777 Mdot
.33433 .27676 Mdot
.33482 .27488 Mdot
.33532 .27552 Mdot
.33581 .27701 Mdot
.33631 .2754 Mdot
.33681 .27457 Mdot
.3373 .27113 Mdot
.3378 .27215 Mdot
.33829 .27336 Mdot
.33879 .27395 Mdot
.33929 .27477 Mdot
.33978 .27542 Mdot
.34028 .27603 Mdot
.34077 .27685 Mdot
.34127 .27724 Mdot
.34177 .27715 Mdot
.34226 .2772 Mdot
.34276 .2767 Mdot
.34325 .27659 Mdot
.34375 .27704 Mdot
.34425 .27653 Mdot
.34474 .27602 Mdot
.34524 .27626 Mdot
.34573 .2763 Mdot
.34623 .40319 Mdot
.34673 .40079 Mdot
.34722 .39351 Mdot
.34772 .39093 Mdot
.34821 .38388 Mdot
.34871 .3908 Mdot
.34921 .38545 Mdot
.3497 .39138 Mdot
.3502 .38852 Mdot
.35069 .38901 Mdot
.35119 .3931 Mdot
.35169 .40024 Mdot
.35218 .40356 Mdot
.35268 .40631 Mdot
.35317 .40717 Mdot
.35367 .40791 Mdot
.35417 .40896 Mdot
.35466 .40891 Mdot
.35516 .40855 Mdot
.35565 .40877 Mdot
.35615 .40965 Mdot
.35665 .4108 Mdot
.35714 .41113 Mdot
.35764 .41036 Mdot
.35813 .40916 Mdot
.35863 .41201 Mdot
.35913 .41322 Mdot
.35962 .41005 Mdot
.36012 .27628 Mdot
.36062 .27485 Mdot
.36111 .27276 Mdot
.36161 .276 Mdot
.3621 .27603 Mdot
.3626 .27654 Mdot
.3631 .27621 Mdot
.36359 .27712 Mdot
.36409 .2776 Mdot
.36458 .27656 Mdot
.36508 .27603 Mdot
.36558 .2758 Mdot
.36607 .27586 Mdot
.36657 .27586 Mdot
.36706 .27608 Mdot
.36756 .27662 Mdot
.36806 .27715 Mdot
.36855 .2772 Mdot
.36905 .2769 Mdot
.36954 .27671 Mdot
.37004 .27661 Mdot
.37054 .2774 Mdot
.37103 .2779 Mdot
.37153 .21511 Mdot
.37202 .21531 Mdot
.37252 .21424 Mdot
.37302 .21179 Mdot
.37351 .2117 Mdot
.37401 .21292 Mdot
.3745 .21455 Mdot
.375 .21615 Mdot
.3755 .21267 Mdot
.37599 .21104 Mdot
.37649 .21112 Mdot
.37698 .21149 Mdot
.37748 .21146 Mdot
.37798 .21116 Mdot
.37847 .20965 Mdot
.37897 .20939 Mdot
.37946 .20997 Mdot
.37996 .20792 Mdot
.38046 .20776 Mdot
.38095 .20771 Mdot
.38145 .20843 Mdot
.38194 .20887 Mdot
.38244 .20931 Mdot
.38294 .21001 Mdot
.38343 .20985 Mdot
.38393 .20979 Mdot
.38442 .21038 Mdot
.38492 .21029 Mdot
.38542 .2102 Mdot
.38591 .21009 Mdot
.38641 .2106 Mdot
.3869 .21047 Mdot
.3874 .20887 Mdot
.3879 .20864 Mdot
.38839 .20978 Mdot
.38889 .27547 Mdot
.38938 .27321 Mdot
.38988 .27488 Mdot
.39038 .27471 Mdot
.39087 .2759 Mdot
.39137 .27481 Mdot
.39187 .27742 Mdot
.39236 .27392 Mdot
.39286 .27427 Mdot
.39335 .27474 Mdot
.39385 .2754 Mdot
.39435 .27539 Mdot
.39484 .27601 Mdot
.39534 .27661 Mdot
.39583 .27668 Mdot
.39633 .27722 Mdot
.39683 .27738 Mdot
.39732 .27739 Mdot
.39782 .27752 Mdot
.39831 .27801 Mdot
.39881 .36524 Mdot
.39931 .37027 Mdot
.3998 .39486 Mdot
.4003 .4074 Mdot
.40079 .40887 Mdot
.40129 .40769 Mdot
.40179 .40371 Mdot
.40228 .38375 Mdot
.40278 .38398 Mdot
.40327 .38904 Mdot
.40377 .37628 Mdot
.40427 .37861 Mdot
.40476 .38923 Mdot
.40526 .39859 Mdot
.40575 .38345 Mdot
.40625 .40642 Mdot
.40675 .40201 Mdot
.40724 .40281 Mdot
.40774 .40542 Mdot
.40823 .40686 Mdot
.40873 .40795 Mdot
.40923 .40846 Mdot
.40972 .40873 Mdot
.41022 .4083 Mdot
.41071 .40876 Mdot
.41121 .40919 Mdot
.41171 .409 Mdot
.4122 .40893 Mdot
.4127 .40918 Mdot
.41319 .41012 Mdot
.41369 .41294 Mdot
.41419 .41279 Mdot
.41468 .41115 Mdot
.41518 .41058 Mdot
.41567 .40885 Mdot
.41617 .40986 Mdot
.41667 .40962 Mdot
.41716 .40956 Mdot
.41766 .41103 Mdot
.41815 .4108 Mdot
.41865 .41268 Mdot
.41915 .41069 Mdot
.41964 .4127 Mdot
.42014 .43172 Mdot
.42063 .44271 Mdot
.42113 .44597 Mdot
.42163 .44588 Mdot
.42212 .44637 Mdot
.42262 .45008 Mdot
.42312 .4529 Mdot
.42361 .45535 Mdot
.42411 .45524 Mdot
.4246 .4559 Mdot
.4251 .45442 Mdot
.4256 .45344 Mdot
.42609 .45477 Mdot
.42659 .454 Mdot
.42708 .45244 Mdot
.42758 .44661 Mdot
.42808 .43875 Mdot
.42857 .43881 Mdot
.42907 .44037 Mdot
.42956 .44381 Mdot
.43006 .44276 Mdot
.43056 .44383 Mdot
.43105 .44362 Mdot
.43155 .44772 Mdot
.43204 .44758 Mdot
.43254 .45007 Mdot
.43304 .45474 Mdot
.43353 .45603 Mdot
.43403 .45888 Mdot
.43452 .45991 Mdot
.43502 .4629 Mdot
.43552 .46251 Mdot
.43601 .43698 Mdot
.43651 .36687 Mdot
.437 .36566 Mdot
.4375 .36774 Mdot
.438 .36627 Mdot
.43849 .36373 Mdot
.43899 .36693 Mdot
.43948 .36674 Mdot
.43998 .36634 Mdot
.44048 .36943 Mdot
.44097 .37003 Mdot
.44147 .37142 Mdot
.44196 .37068 Mdot
.44246 .37016 Mdot
.44296 .36955 Mdot
.44345 .38235 Mdot
.44395 .38012 Mdot
.44444 .38003 Mdot
.44494 .37982 Mdot
.44544 .3794 Mdot
.44593 .37484 Mdot
.44643 .38883 Mdot
.44692 .39329 Mdot
.44742 .40424 Mdot
.44792 .40542 Mdot
.44841 .40566 Mdot
.44891 .40817 Mdot
.4494 .40938 Mdot
.4499 .40531 Mdot
.4504 .40495 Mdot
.45089 .40651 Mdot
.45139 .40608 Mdot
.45188 .40704 Mdot
.45238 .40604 Mdot
.45288 .40581 Mdot
.45337 .40682 Mdot
.45387 .40478 Mdot
.45437 .40609 Mdot
.45486 .40536 Mdot
.45536 .40336 Mdot
.45585 .40463 Mdot
.45635 .40595 Mdot
.45685 .40924 Mdot
.45734 .40926 Mdot
.45784 .4077 Mdot
.45833 .4032 Mdot
.45883 .40806 Mdot
.45933 .41129 Mdot
.45982 .40897 Mdot
.46032 .40757 Mdot
.46081 .40951 Mdot
.46131 .40682 Mdot
.46181 .40103 Mdot
.4623 .35377 Mdot
.4628 .35298 Mdot
.46329 .34993 Mdot
.46379 .34907 Mdot
.46429 .34774 Mdot
.46478 .34583 Mdot
.46528 .34691 Mdot
.46577 .34693 Mdot
.46627 .3481 Mdot
.46677 .34773 Mdot
.46726 .34633 Mdot
.46776 .34789 Mdot
.46825 .34914 Mdot
.46875 .35181 Mdot
.46925 .35219 Mdot
.46974 .35204 Mdot
.47024 .35359 Mdot
.47073 .34775 Mdot
.47123 .3538 Mdot
.47173 .34965 Mdot
.47222 .35128 Mdot
.47272 .35329 Mdot
.47321 .34893 Mdot
.47371 .35048 Mdot
.47421 .35436 Mdot
.4747 .34959 Mdot
.4752 .34722 Mdot
.47569 .3625 Mdot
.47619 .36258 Mdot
.47669 .36409 Mdot
.47718 .36307 Mdot
.47768 .36261 Mdot
.47817 .36438 Mdot
.47867 .36356 Mdot
.47917 .36306 Mdot
.47966 .36381 Mdot
.48016 .36483 Mdot
.48065 .36344 Mdot
.48115 .36466 Mdot
.48165 .36629 Mdot
.48214 .36251 Mdot
.48264 .36292 Mdot
.48313 .36382 Mdot
.48363 .36471 Mdot
.48413 .36592 Mdot
.48462 .36744 Mdot
.48512 .36407 Mdot
.48562 .36428 Mdot
.48611 .36568 Mdot
.48661 .36485 Mdot
.4871 .36183 Mdot
.4876 .36548 Mdot
.4881 .36218 Mdot
.48859 .31428 Mdot
.48909 .31146 Mdot
.48958 .30932 Mdot
.49008 .30826 Mdot
.49058 .30875 Mdot
.49107 .30979 Mdot
.49157 .30889 Mdot
.49206 .3083 Mdot
.49256 .30928 Mdot
.49306 .30929 Mdot
.49355 .30951 Mdot
.49405 .31074 Mdot
.49454 .31136 Mdot
.49504 .31164 Mdot
.49554 .31098 Mdot
.49603 .31006 Mdot
.49653 .3094 Mdot
.49702 .309 Mdot
.49752 .309 Mdot
.49802 .31088 Mdot
.49851 .31199 Mdot
.49901 .31104 Mdot
.4995 .3097 Mdot
.5 .30943 Mdot
.5005 .3095 Mdot
.50099 .30945 Mdot
.50149 .3174 Mdot
.50198 .31709 Mdot
.50248 .34263 Mdot
.50298 .34457 Mdot
.50347 .34439 Mdot
.50397 .34451 Mdot
.50446 .34398 Mdot
.50496 .34307 Mdot
.50546 .34319 Mdot
.50595 .34333 Mdot
.50645 .42681 Mdot
.50694 .41211 Mdot
.50744 .40904 Mdot
.50794 .41452 Mdot
.50843 .41449 Mdot
.50893 .41642 Mdot
.50942 .41292 Mdot
.50992 .41349 Mdot
.51042 .40624 Mdot
.51091 .41211 Mdot
.51141 .41027 Mdot
.5119 .41421 Mdot
.5124 .41386 Mdot
.5129 .41373 Mdot
.51339 .41112 Mdot
.51389 .41293 Mdot
.51438 .41543 Mdot
.51488 .41404 Mdot
.51538 .39848 Mdot
.51587 .4024 Mdot
.51637 .40214 Mdot
.51687 .40504 Mdot
.51736 .40465 Mdot
.51786 .40397 Mdot
.51835 .40528 Mdot
.51885 .40662 Mdot
.51935 .40463 Mdot
.51984 .40507 Mdot
.52034 .4058 Mdot
.52083 .40587 Mdot
.52133 .40657 Mdot
.52183 .40695 Mdot
.52232 .40655 Mdot
.52282 .40859 Mdot
.52331 .40655 Mdot
.52381 .40041 Mdot
.52431 .40624 Mdot
.5248 .40333 Mdot
.5253 .40127 Mdot
.52579 .40507 Mdot
.52629 .40655 Mdot
.52679 .40739 Mdot
.52728 .40633 Mdot
.52778 .40697 Mdot
.52827 .41016 Mdot
.52877 .41098 Mdot
.52927 .42411 Mdot
.52976 .44224 Mdot
.53026 .4508 Mdot
.53075 .45049 Mdot
.53125 .45071 Mdot
.53175 .45126 Mdot
.53224 .45047 Mdot
.53274 .45447 Mdot
.53323 .45393 Mdot
.53373 .45478 Mdot
.53423 .45609 Mdot
.53472 .45464 Mdot
.53522 .45437 Mdot
.53571 .4545 Mdot
.53621 .45338 Mdot
.53671 .45323 Mdot
.5372 .379 Mdot
.5377 .45444 Mdot
.53819 .45271 Mdot
.53869 .45232 Mdot
.53919 .44943 Mdot
.53968 .44678 Mdot
.54018 .44219 Mdot
.54067 .44547 Mdot
.54117 .45105 Mdot
.54167 .45723 Mdot
.54216 .37907 Mdot
.54266 .37495 Mdot
.54315 .38134 Mdot
.54365 .3111 Mdot
.54415 .30909 Mdot
.54464 .44475 Mdot
.54514 .44196 Mdot
.54563 .44164 Mdot
.54613 .43643 Mdot
.54663 .37632 Mdot
.54712 .37111 Mdot
.54762 .37282 Mdot
.54812 .36785 Mdot
.54861 .3665 Mdot
.54911 .36681 Mdot
.5496 .36833 Mdot
.5501 .36745 Mdot
.5506 .36697 Mdot
.55109 .36886 Mdot
.55159 .36942 Mdot
.55208 .36889 Mdot
.55258 .36723 Mdot
.55308 .369 Mdot
.55357 .36887 Mdot
.55407 .37006 Mdot
.55456 .37259 Mdot
.55506 .37212 Mdot
.55556 .37081 Mdot
.55605 .37973 Mdot
.55655 .3774 Mdot
.55704 .37704 Mdot
.55754 .38013 Mdot
.55804 .3697 Mdot
.55853 .38746 Mdot
.55903 .37304 Mdot
.55952 .38665 Mdot
.56002 .39333 Mdot
.56052 .40096 Mdot
.56101 .404 Mdot
.56151 .39516 Mdot
.562 .39566 Mdot
.5625 .4076 Mdot
.563 .40955 Mdot
.56349 .40553 Mdot
.56399 .40715 Mdot
.56448 .40776 Mdot
.56498 .40864 Mdot
.56548 .41096 Mdot
.56597 .41227 Mdot
.56647 .4063 Mdot
.56696 .41614 Mdot
.56746 .41566 Mdot
.56796 .4092 Mdot
.56845 .40597 Mdot
.56895 .35365 Mdot
.56944 .35017 Mdot
.56994 .35015 Mdot
.57044 .34604 Mdot
.57093 .34803 Mdot
.57143 .3464 Mdot
.57192 .34947 Mdot
.57242 .34982 Mdot
.57292 .35167 Mdot
.57341 .34905 Mdot
.57391 .35347 Mdot
.5744 .35191 Mdot
.5749 .34843 Mdot
.5754 .34671 Mdot
.57589 .34606 Mdot
.57639 .34694 Mdot
.57688 .34587 Mdot
.57738 .34758 Mdot
.57788 .34904 Mdot
.57837 .35421 Mdot
.57887 .35216 Mdot
.57937 .35035 Mdot
.57986 .35126 Mdot
.58036 .35303 Mdot
.58085 .35387 Mdot
.58135 .35183 Mdot
.58185 .34937 Mdot
.58234 .36364 Mdot
.58284 .36408 Mdot
.58333 .3628 Mdot
.58383 .36216 Mdot
.58433 .3624 Mdot
.58482 .36238 Mdot
.58532 .36273 Mdot
.58581 .36254 Mdot
.58631 .36256 Mdot
.58681 .36354 Mdot
.5873 .3637 Mdot
.5878 .3635 Mdot
.58829 .36371 Mdot
.58879 .36342 Mdot
.58929 .36277 Mdot
.58978 .36431 Mdot
.59028 .36452 Mdot
.59077 .36293 Mdot
.59127 .36366 Mdot
.59177 .36519 Mdot
.59226 .3635 Mdot
.59276 .36383 Mdot
.59325 .36449 Mdot
.59375 .36225 Mdot
.59425 .15538 Mdot
.59474 .15653 Mdot
.59524 .15724 Mdot
.59573 .15738 Mdot
.59623 .15832 Mdot
.59673 .15858 Mdot
.59722 .15935 Mdot
.59772 .16 Mdot
.59821 .16121 Mdot
.59871 .1613 Mdot
.59921 .16144 Mdot
.5997 .16178 Mdot
.6002 .16183 Mdot
.60069 .16182 Mdot
.60119 .16184 Mdot
.60169 .16205 Mdot
.60218 .31094 Mdot
.60268 .31404 Mdot
.60317 .31339 Mdot
.60367 .30431 Mdot
.60417 .30456 Mdot
.60466 .30856 Mdot
.60516 .30993 Mdot
.60565 .30751 Mdot
.60615 .30717 Mdot
.60665 .30557 Mdot
.60714 .31049 Mdot
.60764 .31253 Mdot
.60813 .32818 Mdot
.60863 .32508 Mdot
.60913 .34186 Mdot
.60962 .34315 Mdot
.61012 .34424 Mdot
.61062 .34337 Mdot
.61111 .34296 Mdot
.61161 .34345 Mdot
.6121 .3448 Mdot
.6126 .25316 Mdot
.6131 .2524 Mdot
.61359 .25319 Mdot
.61409 .25203 Mdot
.61458 .25102 Mdot
.61508 .25128 Mdot
.61558 .25585 Mdot
.61607 .25611 Mdot
.61657 .25501 Mdot
.61706 .25886 Mdot
.61756 .26136 Mdot
.61806 .2608 Mdot
.61855 .25937 Mdot
.61905 .2612 Mdot
.61954 .2609 Mdot
.62004 .25617 Mdot
.62054 .25774 Mdot
.62103 .25611 Mdot
.62153 .25752 Mdot
.62202 .2571 Mdot
.62252 .25807 Mdot
.62302 .26188 Mdot
.62351 .26825 Mdot
.62401 .27131 Mdot
.6245 .27415 Mdot
.625 .27471 Mdot
.6255 .27571 Mdot
.62599 .27508 Mdot
.62649 .27486 Mdot
.62698 .27529 Mdot
.62748 .27685 Mdot
.62798 .27678 Mdot
.62847 .27729 Mdot
.62897 .27726 Mdot
.62946 .27774 Mdot
.62996 .27677 Mdot
.63046 .27413 Mdot
.63095 .27543 Mdot
.63145 .2748 Mdot
.63194 .27494 Mdot
.63244 .27522 Mdot
.63294 .27495 Mdot
.63343 .27871 Mdot
.63393 .27698 Mdot
.63442 .2739 Mdot
.63492 .27603 Mdot
.63542 .27632 Mdot
.63591 .29964 Mdot
.63641 .3048 Mdot
.6369 .30477 Mdot
.6374 .3062 Mdot
.6379 .30744 Mdot
.63839 .30726 Mdot
.63889 .30921 Mdot
.63938 .30978 Mdot
.63988 .30933 Mdot
.64038 .30914 Mdot
.64087 .30954 Mdot
.64137 .30942 Mdot
.64187 .31064 Mdot
.64236 .31149 Mdot
.64286 .3115 Mdot
.64335 .30892 Mdot
.64385 .30863 Mdot
.64435 .30936 Mdot
.64484 .3095 Mdot
.64534 .30906 Mdot
.64583 .30949 Mdot
.64633 .31049 Mdot
.64683 .31024 Mdot
.64732 .3097 Mdot
.64782 .31067 Mdot
.64831 .30881 Mdot
.64881 .31645 Mdot
.64931 .33442 Mdot
.6498 .34233 Mdot
.6503 .34428 Mdot
.65079 .34364 Mdot
.65129 .34357 Mdot
.65179 .34365 Mdot
.65228 .34396 Mdot
.65278 .34452 Mdot
.65327 .34429 Mdot
.65377 .34356 Mdot
.65427 .34424 Mdot
.65476 .34451 Mdot
.65526 .34466 Mdot
.65575 .34479 Mdot
.65625 .34467 Mdot
.65675 .34427 Mdot
.65724 .34449 Mdot
.65774 .34568 Mdot
.65823 .3444 Mdot
.65873 .34395 Mdot
.65923 .33796 Mdot
.65972 .34585 Mdot
.66022 .34422 Mdot
.66071 .34416 Mdot
.66121 .34479 Mdot
.66171 .34509 Mdot
.6622 .34507 Mdot
.6627 .34435 Mdot
.66319 .34324 Mdot
.66369 .36549 Mdot
.66419 .36009 Mdot
.66468 .36205 Mdot
.66518 .36537 Mdot
.66567 .36282 Mdot
.66617 .36123 Mdot
.66667 .36482 Mdot
.66716 .36594 Mdot
.66766 .36511 Mdot
.66815 .36543 Mdot
.66865 .36564 Mdot
.66915 .36629 Mdot
.66964 .36781 Mdot
.67014 .36902 Mdot
.67063 .36666 Mdot
.67113 .36534 Mdot
.67163 .36453 Mdot
.67212 .36396 Mdot
.67262 .36509 Mdot
.67312 .36459 Mdot
.67361 .36115 Mdot
.67411 .3649 Mdot
.6746 .36494 Mdot
.6751 .36402 Mdot
.6756 .36548 Mdot
.67609 .37572 Mdot
.67659 .3942 Mdot
.67708 .3967 Mdot
.67758 .40403 Mdot
.67808 .40364 Mdot
.67857 .40588 Mdot
.67907 .4065 Mdot
.67956 .40459 Mdot
.68006 .40818 Mdot
.68056 .40421 Mdot
.68105 .40515 Mdot
.68155 .4087 Mdot
.68204 .40814 Mdot
.68254 .40899 Mdot
.68304 .40955 Mdot
.68353 .40871 Mdot
.68403 .40903 Mdot
.68452 .40587 Mdot
.68502 .41055 Mdot
.68552 .41134 Mdot
.68601 .40998 Mdot
.68651 .40656 Mdot
.687 .40744 Mdot
.6875 .40867 Mdot
.688 .40756 Mdot
.68849 .40768 Mdot
.68899 .4117 Mdot
.68948 .41848 Mdot
.68998 .43585 Mdot
.69048 .44363 Mdot
.69097 .44491 Mdot
.69147 .44036 Mdot
.69196 .44024 Mdot
.69246 .4416 Mdot
.69296 .44823 Mdot
.69345 .45218 Mdot
.69395 .45388 Mdot
.69444 .4558 Mdot
.69494 .45446 Mdot
.69544 .45428 Mdot
.69593 .45363 Mdot
.69643 .45211 Mdot
.69692 .4519 Mdot
.69742 .45191 Mdot
.69792 .45354 Mdot
.69841 .45445 Mdot
.69891 .45448 Mdot
.6994 .45474 Mdot
.6999 .45273 Mdot
.7004 .45339 Mdot
.70089 .45459 Mdot
.70139 .45165 Mdot
.70188 .44657 Mdot
.70238 .44965 Mdot
.70288 .45667 Mdot
.70337 .46976 Mdot
.70387 .49273 Mdot
.70437 .49771 Mdot
.70486 .49836 Mdot
.70536 .49913 Mdot
.70585 .49625 Mdot
.70635 .49592 Mdot
.70685 .50199 Mdot
.70734 .5021 Mdot
.70784 .50135 Mdot
.70833 .50443 Mdot
.70883 .50738 Mdot
.70933 .50784 Mdot
.70982 .50933 Mdot
.71032 .51372 Mdot
.71081 .5025 Mdot
.71131 .50259 Mdot
.71181 .50372 Mdot
.7123 .50329 Mdot
.7128 .50312 Mdot
.71329 .50408 Mdot
.71379 .49746 Mdot
.71429 .48155 Mdot
.71478 .48331 Mdot
.71528 .48715 Mdot
.71577 .48311 Mdot
.71627 .49423 Mdot
.71677 .52785 Mdot
.71726 .53513 Mdot
.71776 .53508 Mdot
.71825 .53495 Mdot
.71875 .5369 Mdot
.71925 .53745 Mdot
.71974 .5394 Mdot
.72024 .53799 Mdot
.72073 .53743 Mdot
.72123 .53961 Mdot
.72173 .54014 Mdot
.72222 .53927 Mdot
.72272 .53946 Mdot
.72321 .54068 Mdot
.72371 .54209 Mdot
.72421 .53913 Mdot
.7247 .53781 Mdot
.7252 .53856 Mdot
.72569 .54061 Mdot
.72619 .5376 Mdot
.72669 .5365 Mdot
.72718 .36445 Mdot
.72768 .3678 Mdot
.72817 .37317 Mdot
.72867 .36685 Mdot
.72917 .36708 Mdot
.72966 .36753 Mdot
.73016 .36708 Mdot
.73065 .53878 Mdot
.73115 .54181 Mdot
.73165 .54274 Mdot
.73214 .40275 Mdot
.73264 .40592 Mdot
.73313 .4064 Mdot
.73363 .4076 Mdot
.73413 .40826 Mdot
.73462 .40902 Mdot
.73512 .40878 Mdot
.73562 .41008 Mdot
.73611 .41075 Mdot
.73661 .40941 Mdot
.7371 .41022 Mdot
.7376 .41028 Mdot
.7381 .40958 Mdot
.73859 .41151 Mdot
.73909 .41236 Mdot
.73958 .41047 Mdot
.74008 .41116 Mdot
.74058 .41475 Mdot
.74107 .413 Mdot
.74157 .41222 Mdot
.74206 .41261 Mdot
.74256 .41147 Mdot
.74306 .41438 Mdot
.74355 .41385 Mdot
.74405 .4124 Mdot
.74454 .17376 Mdot
.74504 .17843 Mdot
.74554 .17868 Mdot
.74603 .17851 Mdot
.74653 .17877 Mdot
.74702 .17919 Mdot
.74752 .17943 Mdot
.74802 .17954 Mdot
.74851 .17982 Mdot
.74901 .17998 Mdot
.7495 .17947 Mdot
.75 .17926 Mdot
.7505 .28551 Mdot
.75099 .28814 Mdot
.75149 .28753 Mdot
.75198 .35789 Mdot
.75248 .36016 Mdot
.75298 .28559 Mdot
.75347 .28819 Mdot
.75397 .27906 Mdot
.75446 .27447 Mdot
.75496 .29116 Mdot
.75546 .2886 Mdot
.75595 .27489 Mdot
.75645 .27693 Mdot
.75694 .27439 Mdot
.75744 .27481 Mdot
.75794 .27726 Mdot
.75843 .27615 Mdot
.75893 .27768 Mdot
.75942 .27483 Mdot
.75992 .27544 Mdot
.76042 .27653 Mdot
.76091 .2764 Mdot
.76141 .27752 Mdot
.7619 .27769 Mdot
.7624 .27799 Mdot
.7629 .278 Mdot
.76339 .27823 Mdot
.76389 .27785 Mdot
.76438 .27813 Mdot
.76488 .27761 Mdot
.76538 .27807 Mdot
.76587 .27793 Mdot
.76637 .27673 Mdot
.76687 .277 Mdot
.76736 .27741 Mdot
.76786 .27682 Mdot
.76835 .27726 Mdot
.76885 .27726 Mdot
.76935 .27627 Mdot
.76984 .2761 Mdot
.77034 .27759 Mdot
.77083 .2771 Mdot
.77133 .27733 Mdot
.77183 .27784 Mdot
.77232 .27793 Mdot
.77282 .27907 Mdot
.77331 .28001 Mdot
.77381 .2785 Mdot
.77431 .27781 Mdot
.7748 .27781 Mdot
.7753 .27796 Mdot
.77579 .27824 Mdot
.77629 .27819 Mdot
.77679 .27805 Mdot
.77728 .27783 Mdot
.77778 .2779 Mdot
.77827 .27843 Mdot
.77877 .27853 Mdot
.77927 .27773 Mdot
.77976 .27873 Mdot
.78026 .27788 Mdot
.78075 .27725 Mdot
.78125 .14625 Mdot
.78175 .1463 Mdot
.78224 .14633 Mdot
.78274 .14619 Mdot
.78323 .14585 Mdot
.78373 .14592 Mdot
.78423 .14646 Mdot
.78472 .1461 Mdot
.78522 .14594 Mdot
.78571 .14622 Mdot
.78621 .14633 Mdot
.78671 .14654 Mdot
.7872 .14662 Mdot
.7877 .1465 Mdot
.78819 .14594 Mdot
.78869 .14581 Mdot
.78919 .14594 Mdot
.78968 .14621 Mdot
.79018 .14627 Mdot
.79067 .14611 Mdot
.79117 .14616 Mdot
.79167 .4082 Mdot
.79216 .40787 Mdot
.79266 .4086 Mdot
.79315 .409 Mdot
.79365 .41 Mdot
.79415 .41372 Mdot
.79464 .4133 Mdot
.79514 .41117 Mdot
.79563 .411 Mdot
.79613 .4122 Mdot
.79663 .41655 Mdot
.79712 .40597 Mdot
.79762 .41857 Mdot
.79812 .41551 Mdot
.79861 .27738 Mdot
.79911 .27745 Mdot
.7996 .27764 Mdot
.8001 .27816 Mdot
.8006 .27962 Mdot
.80109 .27724 Mdot
.80159 .27405 Mdot
.80208 .27196 Mdot
.80258 .27214 Mdot
.80308 .27093 Mdot
.80357 .27153 Mdot
.80407 .27269 Mdot
.80456 .274 Mdot
.80506 .27412 Mdot
.80556 .27643 Mdot
.80605 .2759 Mdot
.80655 .27582 Mdot
.80704 .27781 Mdot
.80754 .27491 Mdot
.80804 .27662 Mdot
.80853 .27376 Mdot
.80903 .27723 Mdot
.80952 .28168 Mdot
.81002 .2795 Mdot
.81052 .28112 Mdot
.81101 .2815 Mdot
.81151 .28062 Mdot
.812 .27805 Mdot
.8125 .27658 Mdot
.813 .27555 Mdot
.81349 .27304 Mdot
.81399 .26934 Mdot
.81448 .27086 Mdot
.81498 .28025 Mdot
.81548 .25521 Mdot
.81597 .26834 Mdot
.81647 .27362 Mdot
.81696 .27568 Mdot
.81746 .27657 Mdot
.81796 .27727 Mdot
.81845 .27817 Mdot
.81895 .2782 Mdot
.81944 .27818 Mdot
.81994 .27801 Mdot
.82044 .27825 Mdot
.82093 .27816 Mdot
.82143 .27828 Mdot
.82192 .2787 Mdot
.82242 .27931 Mdot
.82292 .27845 Mdot
.82341 .27759 Mdot
.82391 .42702 Mdot
.8244 .42192 Mdot
.8249 .42207 Mdot
.8254 .42923 Mdot
.82589 .4242 Mdot
.82639 .42267 Mdot
.82688 .42571 Mdot
.82738 .42411 Mdot
.82788 .42972 Mdot
.82837 .42542 Mdot
.82887 .42031 Mdot
.82937 .42656 Mdot
.82986 .41745 Mdot
.83036 .42463 Mdot
.83085 .42701 Mdot
.83135 .42332 Mdot
.83185 .42811 Mdot
.83234 .4183 Mdot
.83284 .42253 Mdot
.83333 .53762 Mdot
.83383 .53847 Mdot
.83433 .53893 Mdot
.83482 .53891 Mdot
.83532 .53873 Mdot
.83581 .53914 Mdot
.83631 .53909 Mdot
.83681 .53877 Mdot
.8373 .53921 Mdot
.8378 .53994 Mdot
.83829 .54084 Mdot
.83879 .54281 Mdot
.83929 .54352 Mdot
.83978 .54379 Mdot
.84028 .54351 Mdot
.84077 .27803 Mdot
.84127 .27766 Mdot
.84177 .27751 Mdot
.84226 .27712 Mdot
.84276 .2768 Mdot
.84325 .27669 Mdot
.84375 .27661 Mdot
.84425 .27717 Mdot
.84474 .27762 Mdot
.84524 .27775 Mdot
.84573 .27829 Mdot
.84623 .27871 Mdot
.84673 .27713 Mdot
.84722 .27572 Mdot
.84772 .27622 Mdot
.84821 .27646 Mdot
.84871 .27647 Mdot
.84921 .27704 Mdot
.8497 .27808 Mdot
.8502 .27912 Mdot
.85069 .27946 Mdot
.85119 .27892 Mdot
.85169 .27876 Mdot
.85218 .27877 Mdot
.85268 .27799 Mdot
.85317 .27736 Mdot
.85367 .27752 Mdot
.85417 .27831 Mdot
.85466 .27897 Mdot
.85516 .279 Mdot
.85565 .27891 Mdot
.85615 .27853 Mdot
.85665 .27732 Mdot
.85714 .27638 Mdot
.85764 .27638 Mdot
.85813 .27696 Mdot
.85863 .27758 Mdot
.85913 .27743 Mdot
.85962 .2779 Mdot
.86012 .27895 Mdot
.86062 .27944 Mdot
.86111 .27998 Mdot
.86161 .27971 Mdot
.8621 .27987 Mdot
.8626 .27781 Mdot
.8631 .27624 Mdot
.86359 .27512 Mdot
.86409 .27588 Mdot
.86458 .27693 Mdot
.86508 .27775 Mdot
.86558 .2782 Mdot
.86607 .27866 Mdot
.86657 .27865 Mdot
.86706 .27874 Mdot
.86756 .27876 Mdot
.86806 .27827 Mdot
.86855 .27593 Mdot
.86905 .27364 Mdot
.86954 .27361 Mdot
.87004 .27473 Mdot
.87054 .27535 Mdot
.87103 .27556 Mdot
.87153 .27572 Mdot
.87202 .27593 Mdot
.87252 .27617 Mdot
.87302 .27611 Mdot
.87351 .27605 Mdot
.87401 .27645 Mdot
.8745 .27676 Mdot
.875 .27691 Mdot
.8755 .27709 Mdot
.87599 .27696 Mdot
.87649 .27648 Mdot
.87698 .27604 Mdot
.87748 .27616 Mdot
.87798 .27664 Mdot
.87847 .27658 Mdot
.87897 .27609 Mdot
.87946 .27604 Mdot
.87996 .27612 Mdot
.88046 .27579 Mdot
.88095 .27622 Mdot
.88145 .27678 Mdot
.88194 .27673 Mdot
.88244 .27643 Mdot
.88294 .27614 Mdot
.88343 .27606 Mdot
.88393 .2764 Mdot
.88442 .27714 Mdot
.88492 .27691 Mdot
.88542 .27655 Mdot
.88591 .27671 Mdot
.88641 .27635 Mdot
.8869 .27623 Mdot
.8874 .27642 Mdot
.8879 .27635 Mdot
.88839 .27626 Mdot
.88889 .27643 Mdot
.88938 .27655 Mdot
.88988 .27657 Mdot
.89038 .27659 Mdot
.89087 .27666 Mdot
.89137 .27673 Mdot
.89187 .27678 Mdot
.89236 .27687 Mdot
.89286 .2766 Mdot
.89335 .27643 Mdot
.89385 .27637 Mdot
.89435 .2765 Mdot
.89484 .27684 Mdot
.89534 .2771 Mdot
.89583 .27705 Mdot
.89633 .27695 Mdot
.89683 .27713 Mdot
.89732 .27695 Mdot
.89782 .27655 Mdot
.89831 .27631 Mdot
.89881 .27668 Mdot
.89931 .27681 Mdot
.8998 .27691 Mdot
.9003 .27679 Mdot
.90079 .27651 Mdot
.90129 .27656 Mdot
.90179 .27688 Mdot
.90228 .27694 Mdot
.90278 .27664 Mdot
.90327 .27623 Mdot
.90377 .27559 Mdot
.90427 .27511 Mdot
.90476 .27513 Mdot
.90526 .27562 Mdot
.90575 .27631 Mdot
.90625 .27671 Mdot
.90675 .27726 Mdot
.90724 .27753 Mdot
.90774 .27747 Mdot
.90823 .27709 Mdot
.90873 .27708 Mdot
.90923 .27665 Mdot
.90972 .27638 Mdot
.91022 .27664 Mdot
.91071 .277 Mdot
.91121 .27782 Mdot
.91171 .27781 Mdot
.9122 .2784 Mdot
.9127 .27782 Mdot
.91319 .27729 Mdot
.91369 .27675 Mdot
.91419 .27639 Mdot
.91468 .27689 Mdot
.91518 .2764 Mdot
.91567 .27652 Mdot
.91617 .27524 Mdot
.91667 .27613 Mdot
.91716 .27687 Mdot
.91766 .27648 Mdot
.91815 .27647 Mdot
.91865 .27667 Mdot
.91915 .2772 Mdot
.91964 .27742 Mdot
.92014 .27739 Mdot
.92063 .27689 Mdot
.92113 .27672 Mdot
.92163 .27665 Mdot
.92212 .27642 Mdot
.92262 .27633 Mdot
.92312 .27669 Mdot
.92361 .27767 Mdot
.92411 .27845 Mdot
.9246 .27818 Mdot
.9251 .2775 Mdot
.9256 .27712 Mdot
.92609 .27585 Mdot
.92659 .27583 Mdot
.92708 .27629 Mdot
.92758 .27654 Mdot
.92808 .27651 Mdot
.92857 .27617 Mdot
.92907 .27685 Mdot
.92956 .27652 Mdot
.93006 .27623 Mdot
.93056 .27622 Mdot
.93105 .2772 Mdot
.93155 .27796 Mdot
.93204 .27803 Mdot
.93254 .27679 Mdot
.93304 .27671 Mdot
.93353 .27682 Mdot
.93403 .2768 Mdot
.93452 .27666 Mdot
.93502 .27689 Mdot
.93552 .27662 Mdot
.93601 .27582 Mdot
.93651 .27534 Mdot
.937 .27541 Mdot
.9375 .27611 Mdot
.938 .27578 Mdot
.93849 .2761 Mdot
.93899 .27645 Mdot
.93948 .27664 Mdot
.93998 .27631 Mdot
.94048 .27605 Mdot
.94097 .27855 Mdot
.94147 .27765 Mdot
.94196 .27647 Mdot
.94246 .27739 Mdot
.94296 .27735 Mdot
.94345 .27641 Mdot
.94395 .27675 Mdot
.94444 .27618 Mdot
.94494 .27626 Mdot
.94544 .27566 Mdot
.94593 .27569 Mdot
.94643 .27629 Mdot
.94692 .27728 Mdot
.94742 .27695 Mdot
.94792 .27688 Mdot
.94841 .27652 Mdot
.94891 .27556 Mdot
.9494 .27637 Mdot
.9499 .27663 Mdot
.9504 .27629 Mdot
.95089 .27622 Mdot
.95139 .27564 Mdot
.95188 .27576 Mdot
.95238 .27609 Mdot
.95288 .27698 Mdot
.95337 .27682 Mdot
.95387 .27672 Mdot
.95437 .27731 Mdot
.95486 .27726 Mdot
.95536 .2774 Mdot
.95585 .2775 Mdot
.95635 .27603 Mdot
.95685 .27632 Mdot
.95734 .27787 Mdot
.95784 .28002 Mdot
.95833 .27824 Mdot
.95883 .27663 Mdot
.95933 .27769 Mdot
.95982 .2776 Mdot
.96032 .27845 Mdot
.96081 .27843 Mdot
.96131 .27742 Mdot
.96181 .27822 Mdot
.9623 .27734 Mdot
.9628 .27642 Mdot
.96329 .2771 Mdot
.96379 .27647 Mdot
.96429 .27588 Mdot
.96478 .27649 Mdot
.96528 .27686 Mdot
.96577 .27702 Mdot
.96627 .27777 Mdot
.96677 .27842 Mdot
.96726 .27681 Mdot
.96776 .27525 Mdot
.96825 .27605 Mdot
.96875 .27646 Mdot
.96925 .27579 Mdot
.96974 .27652 Mdot
.97024 .27661 Mdot
.97073 .27751 Mdot
.97123 .27724 Mdot
.97173 .27665 Mdot
.97222 .27546 Mdot
.97272 .27556 Mdot
.97321 .27748 Mdot
.97371 .2785 Mdot
.97421 .27832 Mdot
.9747 .27902 Mdot
.9752 .27917 Mdot
.97569 .27853 Mdot
.97619 .27864 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[383]:=",
  ImageSize->{433, 267.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a00012aP00`40o`000?l0003ooooook;oool0
0?oooonboooo000Voooo00<0003oooooool0E?ooo`<0001Foooo0`0005Coool20000Eoooo`030000
oooooooo02Soool002Goool00`000?ooo`00001Eoooo00<0003oooooool0Eoooo`030000oooooooo
05?oool00`000?ooo`00001Eoooo00<0003oool00000:Oooo`009Oooo`030000oooo000005Koool0
0`000?ooooooo`1Doooo100005Coool00`000?ooo`00001Eoooo00<0003oool00000:Oooo`009Ooo
o`030000oooo000005Koool00`000?ooooooo`1Doooo00<0003oool00000EOooo`80001Goooo00<0
003oooooool0:?ooo`009Oooo`030000oooo000005Goool00`000?ooo`00001Foooo0P0005Goool0
0`000?ooooooo`1Eoooo00<0003oool00000:Oooo`009_ooo`030000oooooooo05Goool00`000?oo
ooooo`1Foooo00<0003oooooool0E?ooo`80001Foooo00<0003oooooool0:?ooo`00oooook;oool0
0?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooook;oool0
0?oooonboooo000Mooooo`0009@00001oooo000Moooo00<0003oooooool01_ooo`030000oooooooo
01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?oo
ooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0
003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04ooo
o`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo
01?oool00`000?ooooooo`0Coooo00<0003oooooool03oooo`400001oooo000Moooo00<0003ooooo
ool01_ooo`030000oooooooo05Goool00`000?ooooooo`1Eoooo00<0003oooooool0EOooo`030000
oooooooo05Koool00`000?ooooooo`0Uoooo0@00007oool001Goool00`000?ooooooo`05oooo00<0
003oooooool0oooooi3oool100000Oooo`005?ooo`030000oooo000000Koool00`000?ooooooo`3o
ooooT?ooo`400001oooo000Doooo00<0003oool000001_ooo`<0003oooooS_ooo`<00001oooo000D
oooo00<0003oool000001_ooo`030000oooooooo0?oooon@oooo0@00007oool001Coool00`000?oo
o`000006oooo00<0003oooooool0oooooi3oool100000Oooo`005Oooo`030000oooooooo00Goool0
0`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Ooo
o`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?oo
o`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo
0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool0
01goool20000oooooi3oool200000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool0
01goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool1
00000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3o
ooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000
oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000M
oooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00
007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo0P000?oooon@oooo0P00
007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooo
oi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?oo
ooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Ooo
o`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001
oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@
oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003ooooo
ool0oooooi3oool100000Oooo`007Oooo`80003oooooT?ooo`800001oooo000Moooo00<0003ooooo
ool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool0
0`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Ooo
o`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?oo
o`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo
0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000:oooo0`00
00?oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo0?oooon@oooo0@00
007oool000[oool00`000?ooooooo`02oooo00<0003oool000000_ooo`030000oooo000000Koool0
0`000?ooooooo`3oooooT?ooo`400001oooo000;oooo00L0003oooooooooool0003oool000000_oo
o`030000oooo000000Koool30000ooooohkoool300000Oooo`002oooo`070000oooooooooooo0000
oooo000000;oool00`000?ooo`000006oooo00<0003oooooool0oooooi3oool100000Oooo`002_oo
o`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001_ooo`030000oooooooo
0?oooon@oooo0@00007oool000_oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooo
oi3oool100000Oooo`007Oooo`030000oooooooo0?oooolhoooo1@00oe?oool100000Oooo`007Ooo
o`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001
oooo000Moooo00<0003oooooool0k?ooo`03003ooooooooo0:3oool100000Oooo`007Oooo`030000
oooooooo0>coool00`00ooooooooo`2Poooo0@00007oool001goool00`000?ooooooo`3/oooo0P00
oj7oool100000Oooo`007Oooo`030000oooooooo0>goool3003oWoooo`400001oooo000Moooo0P00
0?oooon@oooo0P00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool0
01goool00`000?ooooooo`3ooooo:Oooo`03003ooooooooo06Coool100000Oooo`007Oooo`030000
oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3ooooo:Oooo`<00?mToooo0@00
007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0Iooo
o`03003ooooooooo0?oooolVoooo0@00007oool001goool00`000?ooooooo`1Voooo00<00?oooooo
ool0ooooobOoool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool0
0`000?ooooooo`3oooooT?ooo`400001oooo000Moooo0P000?oooon@oooo0P00007oool001goool0
0`000?ooooooo`1Woooo00<00?ooooooool0ooooobKoool100000Oooo`007Oooo`030000oooooooo
0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo03goool00`00ooooooooo`0D
oooo00<00?ooooooool04oooo`03003ooooooooo00ooool01000ooooooooo`00oaKoool00`00oooo
ooooo`3foooo0@00007oool001goool00`000?ooooooo`0moooo0P00oaGoool3003o4Oooo`H00?l>
oooo00@00?ooooooooooool2003o4oooo`D00?oeoooo0@00007oool001goool00`000?ooooooo`0l
oooo00?o00000?l00?l00P00o`03o`00oooooooo00goool2o`0000@00?oo00000?l00?l@oooo00?o
00000?l00?l00`00o`ooool01?l00000ool00?l000800?lAoooo0`00o`03o`00003o003o0?Koool1
00000Oooo`007Oooo`030000oooooooo05?oool00`00ooooooooo`0Boooo00<00?ooooooool04_oo
o`<00?lBoooo0P00oo_oool100000Oooo`007Oooo`030000oooooooo06Ooool3003o5Oooo`03003o
oooooooo013oool2003onoooo`400001oooo000Moooo00<0003oooooool0??ooo`03003ooooooooo
0?oooomAoooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo0P00
0?oooon@oooo0P00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool0
01goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool1
00000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3o
ooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000
oooooooo0?oooon@oooo0@00007oool000_oool300000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool0oooooi3oool100000Oooo`003?ooo`060000oooooooo0000oooo
00000_ooo`030000oooo000000Koool00`000?ooooooo`1;oooo00<00?ooooooool0YOooo`800?nJ
oooo0@00007oool000[oool4000000Coool0003oool00002oooo00<0003oool000001_ooo`<0003c
oooo00<00?ooool00?l0Uoooo`<00001oooo000:oooo00<0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`000006oooo00<0003oooooool02?ooo`03003ooooooooo06coool2003oNooo
o`04003ooooo003o003oCOooo`03003ooooooooo04Ooool100000Oooo`002oooo`800002oooo00<0
003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`09oooo00<00?ooooooool0@?oo
o`03003ooooooooo02Soool2003oO?ooo`<00?nGoooo0@00007oool000coool01@000?oooooooooo
o`000004oooo00<0003oooooool01Oooo`030000oooooooo0?Goool3003oUoooo`400001oooo000M
oooo00<0003oooooool01oooo`03003ooooooooo06koool00`00ooooooooo`3ooooo5Oooo`400001
oooo000Moooo00<0003oooooool01_ooo`800?m4oooo00<00?ooooooool0oooood7oool100000Ooo
o`007Oooo`030000oooooooo00Ooool00`00ooooo`00o`0]oooo00<00?ooooooool02?ooo`03003o
oooooooo00Woool00`00ooooooooo`2Voooo00<00?ooooooool0B_ooo`800?m9oooo0@00007oool0
01goool00`000?ooooooo`08oooo0P00o`[oool2003o1_ooo`03003ooooooooo00Coool00`00oooo
ooooo`0Loooo0P00o`Soool3003o2Oooo`800?l:oooo00<00?ooooooool01oooo`03003ooooooooo
00Soool00`00ooooooooo`05oooo00@00?ooooooool00?mcoooo00<00?ooooooool0A?ooo`800?l3
oooo00<00?ooooooool0B?ooo`400001oooo000Moooo00<0003oooooool02Oooo`03003ooooo003o
00@00?l4oooo0`00o`Coool3003o1?ooo`<00?l5oooo00<00?ooooooool02_ooo`03003ooooooooo
00Soool2003o0oooo`800?l4oooo0P00o`;oool00`00ooooooooo`03oooo1000o`Woool00`00oooo
ooooo`06oooo0`00o`Woool3003o1_ooo`@00?l8oooo00<00?ooooooool02?ooo`<00?mLoooo1@00
obooool3003o4?ooo`@00?l00oooo`00o`00o`0Doooo0P00oc?oool100000Oooo`007Oooo`030000
oooooooo00[oool3003o0_ooo`H00?l00oooo`00o`00o`02oooo00<00?ooooooool00P00o`;oool0
0`00ooooooooo`03003o00?oool00?l00?l00`00o`04oooo003o003o003o1_ooo`<00?l7oooo00<0
0?ooool00?l01@00o`Coool6003o1?ooo`P00?l5oooo0`00o`Koool00`00ooooo`00o`04003o1_oo
o`<00?l5oooo1`00o`Coool5003o1oooo`@00?mKoooo1@00oc3oool3003o00Coool00?l00?l00?l3
oooo00<00?ooooooool01Oooo`05003ooooo003o003ooooo00<00?l9oooo0`00o`05oooo003o003o
003ooooo02d00?l:oooo0@00007oool001goool00`000?ooooooo`06oooo4Ol000@00?l3o`001000
o`Co0003003o0ol000<00?l00ol00000ooooo`05oooo0_l000@00?l3oooo0P00o`?o0002003o0_l0
00?oool00ol00000ool00003o`001?ooo`03o`00003oo`0000?o00000`00ool00?l00004oooo1Ol0
00Coool00ol00000ool00002o`000P00o`04o`00oooooooooooo1_l000Coool2o`0000<00?oo003o
00000_l000Goool2o`0000D00?oo003o00000?oo00001?ooo`;o00001@00ool00000o`00ool0001E
oooo1_l000800?l2o`00;Oooo`03o`00003oo`0000@00?l00ol00000o`00o`03003o1_ooo`800?l0
1?l00000ool00000o`;o0003003o1_ooo`04003oo`00003oo`002000o`oo0003003o0_l000<00?l2
o`0000<00?oo003o00000P00o`Co0004003o00?o00000?l00?l00`00o`Soool100000Oooo`007Ooo
o`030000oooooooo033oool00`00ooooooooo`0Toooo00<00?ooooooool07oooo`03003ooooooooo
0;Soool00`00ooooooooo`0;oooo0P00o`03oooo003ooooo013oool2003o9Oooo`03003ooooooooo
00koool100000Oooo`007Oooo`80001?oooo00<00?ooooooool03Oooo`03003ooooooooo00?oool0
0`00ooooooooo`0Boooo00<00?ooooooool0oooooa?oool200000Oooo`007Oooo`030000oooooooo
0?ooool/oooo0P00of;oool100000Oooo`007Oooo`030000oooooooo0?ooool/oooo0`00of7oool1
00000Oooo`007Oooo`030000oooooooo0?ooool]oooo00<00?ooooooool0H?ooo`400001oooo000M
oooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00
007oool001goool00`000?ooooooo`3loooo00<00?ooooooool0T?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo06;oool2003oRoooo`800?nN
oooo0@00007oool001goool00`000?ooooooo`0`oooo00<00?ooooooool0:oooo`800?l2oooo0P00
ohgoool00`00ooooooooo`09oooo00<00?ooooooool0Soooo`400001oooo000Moooo00<0003ooooo
ool0<?ooo`D00?lZoooo1@00oekoool5003o4?ooo`03003ooooooooo01Koool00`00ooooooooo`0:
oooo1@00ohgoool100000Oooo`007Oooo`030000oooooooo033oool00ol00000o`00o`04003o00?o
003oooooool09?ooo`?o00000`00ool00?l0000@oooo00<00?ooooooool0B_ooo`H00?l00ol00?oo
ooooo`0=oooo00<00?ooooooool04oooo`;o0003003o00?o003oooooool02?ooo`06o`00003o003o
o`00003oo`00S?ooo`400001oooo000Moooo0P000<;oool00`00ooooooooo`0[oooo00<00?ooool0
0?l0W?ooo`800001oooo000Moooo00<0003oooooool0=_ooo`800?o:oooo00<00?ooooooool0R_oo
o`400001oooo000Moooo00<0003oooooool0a_ooo`800?o7oooo0@00007oool001goool00`000?oo
ooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Ooo
o`030000oooooooo0?7oool00`00ooooooooo`2Koooo0@00007oool001goool00`000?ooooooo`3a
oooo00<00?ooooooool0Voooo`400001oooo000Moooo00<0003oooooool0M?ooo`03003ooooooooo
0?oooolIoooo0@00007oool001goool00`000?ooooooo`3ooooo0oooo`03003ooooooooo08[oool1
00000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`1d
oooo00<00?ooooooool0Soooo`03003ooooooooo08Koool100000Oooo`007Oooo`030000oooooooo
0?;oool00`00ooooooooo`2Joooo0@00007oool001goool20000B_ooo`03003ooooooooo02Woool0
0`00ooooooooo`1?oooo0P00obWoool2003o3_ooo`H00?n6oooo0P00007oool001goool00`000?oo
ooooo`18oooo00Go00000?l00?l00?oo00009_ooo`05o`00003o003o003oo`0003koool2o`000P00
o`?o000:oooo00@00?oo003o003o000Foooo00?o00000?oo00000P00o`03o`00oooooooo00Woool0
0ol00000ool0000=oooo00?o00000?l00?l00`00ob7oool3o`004Oooo`Co001>oooo0@00007oool0
01goool00`000?ooooooo`1foooo0P00ocooool6003o9Oooo`@00?nYoooo0@00007oool001goool0
0`000?ooooooo`2goooo00<00?ooool00?l00`00obGoool2003o0_ooo`800?nWoooo0@00007oool0
01goool00`000?ooooooo`2goooo00<00?ooool00?l00P00obGoool00`00ooooo`00o`03003oZ?oo
o`400001oooo000Moooo00<0003oooooool0^oooo`03003ooooooooo0=7oool100000Oooo`007Ooo
o`030000oooooooo0?ooool/oooo00<00?ooooooool0HOooo`400001oooo000Moooo00<0003ooooo
ool0ooooo`Woool2003o0_ooo`03003ooooooooo01coool00`00ooooooooo`1Qoooo0@00007oool0
01goool00`000?ooooooo`2]oooo00<00?ooooooool03?ooo`H00?lUoooo1@00oacoool00`00oooo
ooooo`02003oP_ooo`400001oooo000Moooo00<0003oooooool0WOooo`03003ooooooooo00coool3
003o0_l000_oool00ol00000o`00o`03003o5_ooo`03o`00003oo`0000?o0008oooo1?l000800?l2
o`006Oooo`03o`00003o003o00<00?lDoooo00<00?ooooooool0Joooo`400001oooo000:oooo0P00
00Coool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo0:coool2003o4_oo
o`03003ooooooooo01Koool3003o;_ooo`03003ooooooooo01Coool2003oK?ooo`400001oooo000:
oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000006oooo00<0003ooooo
ool0WOooo`03003ooooooooo00koool2003o:Oooo`D00?naoooo0@00007oool000[oool00`000?oo
o`000002oooo00<0003oool000000_ooo`030000oooo000000Koool30000fOooo`03003ooooooooo
00800?m4oooo00<00?ooooooool0J?ooo`<00001oooo000:oooo0P0000?oool00`000?ooo`000002
oooo00<0003oool000001_ooo`030000oooooooo09ooool00`00ooooooooo`0>oooo00<00?oooooo
ool09?ooo`800?ldoooo00<00?ooooooool0Ooooo`400001oooo000:oooo00<0003oooooool00_oo
o`030000oooo000000;oool00`000?ooo`000006oooo00<0003oooooool0Woooo`03003ooooooooo
03?oool00`00ooooo`00o`04oooo0P00ok7oool100000Oooo`002oooo`800003oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`2_oooo0P00obKoool00`00ooooooooo`02
oooo0P00ok7oool100000Oooo`007Oooo`030000oooooooo08Woool00`00ooooooooo`0Boooo0`00
o`koool00`00ooooooooo`3Moooo0@00007oool001goool00`000?ooooooo`29oooo00<00?oooooo
ool0ooooo`Coool100000Oooo`007Oooo`030000oooooooo08Woool2003o5?ooo`03003ooooooooo
00koool00`00ooooooooo`0Zoooo0P00ok3oool100000Oooo`007Oooo`030000oooooooo08Soool2
003o5Oooo`03003ooooooooo0>goool100000Oooo`007Oooo`030000oooooooo08Soool00`00oooo
o`00o`0Uoooo00<00?ooooooool0:oooo`03003ooooooooo0:koool100000Oooo`007Oooo`030000
oooooooo09goool00`00ooooooooo`0noooo0P00obgoool00`00ooooooooo`1ooooo0@00007oool0
01goool00`000?ooooooo`2Poooo00<00?ooooooool0:Oooo`03003ooooooooo03koool00`00oooo
ooooo`1ooooo0@00007oool001goool00`000?ooooooo`28oooo00<00?ooool00?l0:oooo`03003o
oooooooo01Koool2003o3Oooo`03003ooooooooo0:koool100000Oooo`007Oooo`800029oooo00<0
0?ooool00?l04oooo`03003ooooo003o01?oool2003o5_ooo`05003ooooooooooooo003o03coool0
0`00ooooooooo`0Coooo00<00?ooooooool0J?ooo`800001oooo000Moooo00<0003oooooool0R_oo
o`03003ooooooooo01?oool2003o3oooo`@00?lEoooo00<00?ooooooool00P00o`03oooo003o003o
00coool4003o:oooo`@00?lBoooo0P00oaSoool00`00ooooooooo`1?oooo0@00007oool001goool0
0`000?ooooooo`27oooo1?l000800?l00ol00?ooooooo`0>oooo00<00?oo003o00000P00o`03o`00
003oo`0000[oool01Ol00000o`00o`00ool00002003o4oooo`?o0005003o00?o003oooooool02?oo
o`;o0002003o00?o003oooooool0:?ooo`;o0005003o4?ooo`03o`00003oo`0000Co000Aoooo0P00
o`03o`00oooooooo04ooool100000Oooo`007Oooo`030000oooooooo08_oool3003o5?ooo`@00?l;
oooo00<00?ooooooool00`00oa;oool3003o1Oooo`03003ooooooooo00_oool3003o;Oooo`<00?lB
oooo0`00oaGoool2003oDOooo`400001oooo000Moooo00<0003oooooool0SOooo`03003ooooooooo
01?oool00`00ooooo`00o`0Soooo0`00oaCoool00`00ooooooooo`0_oooo00<00?ooooooool04Ooo
o`<00?lCoooo0P00oe7oool100000Oooo`007Oooo`030000oooooooo0<Woool01000ooooo`00o`00
oaCoool00`00ooooooooo`13oooo0P00oaGoool00`00ooooooooo`1>oooo0@00007oool001goool0
0`000?ooooooo`39oooo00<00?ooooooool0A_ooo`03003ooooooooo02Soool2003o3?ooo`800?m2
oooo0@00007oool001goool00`000?ooooooo`3oooooBoooo`03003ooooooooo04;oool100000Ooo
o`007Oooo`030000oooooooo0?oooom9oooo0P00o`03oooo003o003o04;oool100000Oooo`007Ooo
o`030000oooooooo0=7oool00`00ooooooooo`1eoooo0`00od?oool100000Oooo`007Oooo`030000
oooooooo0<Soool00`00ooooooooo`1moooo00@00?ooool00?l00?m3oooo0@00007oool001goool0
0`000?ooooooo`3oooooB_ooo`800?m4oooo0@00007oool001goool20000Yoooo`03003ooooooooo
0>Goool200000Oooo`007Oooo`030000oooooooo0?oooolCoooo00<00?ooooooool0N_ooo`400001
oooo000Moooo00<0003oooooool0[?ooo`03003ooooooooo02Woool00`00ooooooooo`2doooo0@00
007oool001goool00`000?ooooooo`2Yoooo00<00?ooooooool0Ioooo`03003ooooooooo07Woool1
00000Oooo`007Oooo`030000oooooooo0:Koool01@00ooooooooooooo`00o`0Woooo00L00?oooooo
ooooool00?ooool00?l0>Oooo`800?mkoooo0@00007oool001goool00`000?ooooooo`2Voooo00<0
0?ooooooool00P00ob_oool00`00ooooo`00o`0joooo00<00?ooooooool0NOooo`400001oooo000M
oooo00<0003oooooool0Y_ooo`03003ooooooooo00800?l[oooo00<00?ooooooool0>_ooo`05003o
oooooooooooo003o07Ooool100000Oooo`007Oooo`030000oooooooo0:Ooool01@00oooooooooooo
o`00o`0Voooo0P00o`03oooo003o003o043oool00`00ooooooooo`1eoooo0@00007oool001goool0
0`000?ooooooo`2Woooo0P00obWoool01000ooooo`00o`00ockoool4003oMoooo`400001oooo000M
oooo00<0003oooooool0YOooo`;o0002003o0_l00003003oo`00o`0002Coool01?l00000o`00o`00
o`?o000ioooo0_l000@00?l00ol00?ooooooo`1doooo0@00007oool001goool00`000?ooooooo`3F
oooo00<00?ooooooool0?_ooo`03003ooooooooo07Goool100000Oooo`007Oooo`030000oooooooo
0:_oool00`00ooooooooo`3Qoooo0@00007oool001goool20000[Oooo`03003ooooooooo0=ooool2
00000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3o
ooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooaWoool00`00ooooooooo`1doooo0@00
007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooo
oi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?oo
ooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooagoool2003oLOooo`400001
oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`002oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo0?oooolMoooo00<00?oooooo
ool0L?ooo`400001oooo000:oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?oo
o`000006oooo00<0003oooooool0oooooi3oool100000Oooo`002_ooo`030000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool000001_ooo`<0003ooooo6Oooo`03003ooooooooo07;oool3
00000Oooo`002oooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`000006oooo00<0
003oooooool0oooooakoool00`00ooooooooo`1_oooo0@00007oool000[oool00`000?ooo`000002
oooo00<0003oool000000_ooo`030000oooo000000Koool00`000?ooooooo`3ooooo6Oooo`800?l2
oooo00<00?ooooooool0L?ooo`400001oooo000;oooo00<0003oooooool00_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool0oooooaWoool00`00ooooooooo`1doooo0@00
007oool001goool00`000?ooooooo`3ooooo6_ooo`03003ooooo003o07?oool100000Oooo`007Ooo
o`030000oooooooo0?oooolKoooo0`00og;oool100000Oooo`007Oooo`030000oooooooo0?oooolK
oooo00<00?ooooooool0L_ooo`400001oooo000Moooo00<0003oooooool0oooooaWoool2o`0000@0
0?oo003o003o001aoooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000M
oooo00<0003oooooool0oooooa_oool00`00ooooooooo`1boooo0@00007oool001goool00`000?oo
ooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Ooo
o`80003oooooT?ooo`800001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Ooo
o`030000oooooooo0?oooolNoooo00<00?ooooooool0Koooo`400001oooo000Moooo00<0003ooooo
ool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool0
0`000?ooooooo`3ooooo7_ooo`800?m`oooo0@00007oool001goool00`000?ooooooo`3ooooo7ooo
o`@00?lZoooo00<00?ooooooool0@?ooo`400001oooo000Moooo00<0003oooooool0oooooakoool0
1?l00000o`00o`00o`;o00000`00ooooooooo`0<oooo2_l000_oool5o`000`00o`03o`00oooooooo
03goool100000Oooo`007Oooo`030000oooooooo0?oooolQoooo0P00o`03oooo003ooooo02Woool0
0`00ooooooooo`0noooo0@00007oool001goool00`000?ooooooo`3oooooCoooo`800?looooo0@00
007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooo
oi3oool100000Oooo`007Oooo`80003oooooT?ooo`800001oooo000Moooo00<0003oooooool0oooo
oi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?oo
ooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Ooo
o`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001
oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@
oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003ooooo
ool0oooooi3oool100000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool2
0000oooooi3oool200000Oooo`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool0
0`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Ooo
o`007Oooo`030000oooooooo0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?oo
o`400001oooo000Moooo00<0003oooooool0oooooi3oool100000Oooo`007Oooo`030000oooooooo
0?oooon@oooo0@00007oool001goool00`000?ooooooo`3oooooT?ooo`400001oooo000Moooo00<0
003oooooool0oooooi3oool100000Oooo`001?ooo`D00002oooo00<0003oooooool00_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool0oooooi3oool100000Oooo`001_oo
o`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001_oo
o`030000oooooooo0?oooon@oooo0@00007oool000Koool01`000?ooooooooooo`000?ooo`000002
oooo00<0003oool000000_ooo`030000oooo000000Koool30000ooooohkoool300000Oooo`001_oo
o`070000oooooooooooo0000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001_oo
o`030000oooooooo00Koool00`000?ooooooo`1Eoooo00<0003oooooool0EOooo`030000oooooooo
05Goool00`000?ooooooo`1Foooo00<0003oooooool09Oooo`400001oooo0006oooo00L0003ooooo
ooooool0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000006oooo00<0003ooooo
ool01_ooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000
oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool0
0`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0C
oooo00<0003oooooool04oooo`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0003ooooo
ool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool03oooo`400001
oooo0005oooo0P0000Coool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo
00Gooooo0000U000007oool00?oooonboooo003ooooo/_ooo`00\
\>"],
  ImageRangeCache->{{{0, 432}, {266.5, 0}} -> {-0.876729, -89.7122, 
  0.0226963, 4.18293}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Analiza b\[LSlash]\:0119d\[OAcute]w"], "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\[LSlash]\[SHacek]d = B\[LSlash]\[SHacek]dProc[TabFreq]\)], "Input",
  CellLabel->"In[385]:="],

Cell[BoxData[
    \(TraditionalForm\`89.21875`\)], "Output",
  CellLabel->"Out[385]="]
}, Open  ]],

Cell[BoxData[
    \(\(B\[LSlash]\:0119dzik[\([2]\)] = 0; \)\)], "Input",
  CellLabel->"In[216]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Abs[B\[LSlash]\:0119dzik]]\)], "Input",
  CellLabel->"In[217]:="],

Cell[BoxData[
    \(TraditionalForm\`76.7747621989994133`\)], "Output",
  CellLabel->"Out[217]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[B\[LSlash]\:0119dzik, PlotRange -> All, 
      PlotStyle -> RGBColor[1, 0, 0]]; \)\)], "Input",
  CellLabel->"In[218]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.023313 0.000496549 0.600868 5.60724e-006 [
[.27159 .58837 -9 -9 ]
[.27159 .58837 9 0 ]
[.51986 .58837 -12 -9 ]
[.51986 .58837 12 0 ]
[.76814 .58837 -12 -9 ]
[.76814 .58837 12 0 ]
[.01081 .04014 -42 -4.5 ]
[.01081 .04014 0 4.5 ]
[.01081 .15229 -36 -4.5 ]
[.01081 .15229 0 4.5 ]
[.01081 .26443 -36 -4.5 ]
[.01081 .26443 0 4.5 ]
[.01081 .37658 -36 -4.5 ]
[.01081 .37658 0 4.5 ]
[.01081 .48872 -36 -4.5 ]
[.01081 .48872 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.27159 .60087 m
.27159 .60712 L
s
[(500)] .27159 .58837 0 1 Mshowa
.51986 .60087 m
.51986 .60712 L
s
[(1000)] .51986 .58837 0 1 Mshowa
.76814 .60087 m
.76814 .60712 L
s
[(1500)] .76814 .58837 0 1 Mshowa
.125 Mabswid
.07297 .60087 m
.07297 .60462 L
s
.12262 .60087 m
.12262 .60462 L
s
.17228 .60087 m
.17228 .60462 L
s
.22193 .60087 m
.22193 .60462 L
s
.32124 .60087 m
.32124 .60462 L
s
.3709 .60087 m
.3709 .60462 L
s
.42055 .60087 m
.42055 .60462 L
s
.47021 .60087 m
.47021 .60462 L
s
.56952 .60087 m
.56952 .60462 L
s
.61917 .60087 m
.61917 .60462 L
s
.66883 .60087 m
.66883 .60462 L
s
.71848 .60087 m
.71848 .60462 L
s
.81779 .60087 m
.81779 .60462 L
s
.86745 .60087 m
.86745 .60462 L
s
.9171 .60087 m
.9171 .60462 L
s
.96676 .60087 m
.96676 .60462 L
s
.25 Mabswid
0 .60087 m
1 .60087 L
s
.02331 .04014 m
.02956 .04014 L
s
[(-100000)] .01081 .04014 1 0 Mshowa
.02331 .15229 m
.02956 .15229 L
s
[(-80000)] .01081 .15229 1 0 Mshowa
.02331 .26443 m
.02956 .26443 L
s
[(-60000)] .01081 .26443 1 0 Mshowa
.02331 .37658 m
.02956 .37658 L
s
[(-40000)] .01081 .37658 1 0 Mshowa
.02331 .48872 m
.02956 .48872 L
s
[(-20000)] .01081 .48872 1 0 Mshowa
.125 Mabswid
.02331 .06818 m
.02706 .06818 L
s
.02331 .09622 m
.02706 .09622 L
s
.02331 .12425 m
.02706 .12425 L
s
.02331 .18033 m
.02706 .18033 L
s
.02331 .20836 m
.02706 .20836 L
s
.02331 .2364 m
.02706 .2364 L
s
.02331 .29247 m
.02706 .29247 L
s
.02331 .32051 m
.02706 .32051 L
s
.02331 .34854 m
.02706 .34854 L
s
.02331 .40461 m
.02706 .40461 L
s
.02331 .43265 m
.02706 .43265 L
s
.02331 .46069 m
.02706 .46069 L
s
.02331 .51676 m
.02706 .51676 L
s
.02331 .5448 m
.02706 .5448 L
s
.02331 .57283 m
.02706 .57283 L
s
.02331 .01211 m
.02706 .01211 L
s
.25 Mabswid
.02331 0 m
.02331 .61803 L
s
1 0 0 r
.008 w
.02381 .01472 Mdot
.02431 .60087 Mdot
.0248 .60096 Mdot
.0253 .60094 Mdot
.0258 .60095 Mdot
.02629 .60095 Mdot
.02679 .60097 Mdot
.02729 .60097 Mdot
.02778 .6009 Mdot
.02828 .60091 Mdot
.02878 .6009 Mdot
.02927 .60091 Mdot
.02977 .60106 Mdot
.03026 .60102 Mdot
.03076 .60093 Mdot
.03126 .60091 Mdot
.03175 .6009 Mdot
.03225 .60088 Mdot
.03275 .60088 Mdot
.03324 .60087 Mdot
.03374 .60087 Mdot
.03424 .60087 Mdot
.03473 .60088 Mdot
.03523 .60088 Mdot
.03573 .60088 Mdot
.03622 .60088 Mdot
.03672 .60087 Mdot
.03722 .60087 Mdot
.03771 .60088 Mdot
.03821 .60088 Mdot
.03871 .60088 Mdot
.0392 .60088 Mdot
.0397 .60088 Mdot
.0402 .60088 Mdot
.04069 .60088 Mdot
.04119 .60088 Mdot
.04169 .60089 Mdot
.04218 .60089 Mdot
.04268 .60088 Mdot
.04317 .60088 Mdot
.04367 .60088 Mdot
.04417 .60088 Mdot
.04466 .60088 Mdot
.04516 .60088 Mdot
.04566 .60088 Mdot
.04615 .60088 Mdot
.04665 .60087 Mdot
.04715 .60087 Mdot
.04764 .60087 Mdot
.04814 .60087 Mdot
.04864 .60086 Mdot
.04913 .60086 Mdot
.04963 .60086 Mdot
.05013 .60086 Mdot
.05062 .60086 Mdot
.05112 .60086 Mdot
.05162 .60086 Mdot
.05211 .60086 Mdot
.05261 .60086 Mdot
.05311 .60086 Mdot
.0536 .60086 Mdot
.0541 .60086 Mdot
.0546 .60086 Mdot
.05509 .60086 Mdot
.05559 .60086 Mdot
.05609 .60086 Mdot
.05658 .60087 Mdot
.05708 .60087 Mdot
.05757 .60088 Mdot
.05807 .60088 Mdot
.05857 .60088 Mdot
.05906 .60089 Mdot
.05956 .6009 Mdot
.06006 .60091 Mdot
.06055 .60092 Mdot
.06105 .60091 Mdot
.06155 .6009 Mdot
.06204 .60089 Mdot
.06254 .60088 Mdot
.06304 .60088 Mdot
.06353 .60087 Mdot
.06403 .60087 Mdot
.06453 .60087 Mdot
.06502 .60086 Mdot
.06552 .60086 Mdot
.06602 .60085 Mdot
.06651 .60084 Mdot
.06701 .60085 Mdot
.06751 .60085 Mdot
.068 .60085 Mdot
.0685 .60085 Mdot
.069 .60085 Mdot
.06949 .60085 Mdot
.06999 .60085 Mdot
.07049 .60085 Mdot
.07098 .60085 Mdot
.07148 .60085 Mdot
.07197 .60085 Mdot
.07247 .60085 Mdot
.07297 .60086 Mdot
.07346 .60086 Mdot
.07396 .60087 Mdot
.07446 .60087 Mdot
.07495 .60088 Mdot
.07545 .60088 Mdot
.07595 .60088 Mdot
.07644 .60089 Mdot
.07694 .60089 Mdot
.07744 .60089 Mdot
.07793 .6009 Mdot
.07843 .6009 Mdot
.07893 .60091 Mdot
.07942 .6009 Mdot
.07992 .60089 Mdot
.08042 .60088 Mdot
.08091 .60087 Mdot
.08141 .60087 Mdot
.08191 .60087 Mdot
.0824 .60087 Mdot
.0829 .60087 Mdot
.0834 .60086 Mdot
.08389 .60085 Mdot
.08439 .60085 Mdot
.08489 .60085 Mdot
.08538 .60085 Mdot
.08588 .60085 Mdot
.08637 .60085 Mdot
.08687 .60085 Mdot
.08737 .60085 Mdot
.08786 .60085 Mdot
.08836 .60085 Mdot
.08886 .60085 Mdot
.08935 .60085 Mdot
.08985 .60085 Mdot
.09035 .60085 Mdot
.09084 .60086 Mdot
.09134 .60087 Mdot
.09184 .60087 Mdot
.09233 .60088 Mdot
.09283 .60088 Mdot
.09333 .60089 Mdot
.09382 .60089 Mdot
.09432 .60089 Mdot
.09482 .60089 Mdot
.09531 .6009 Mdot
.09581 .6009 Mdot
.09631 .6009 Mdot
.0968 .6009 Mdot
.0973 .6009 Mdot
.0978 .60089 Mdot
.09829 .60088 Mdot
.09879 .60088 Mdot
.09928 .60087 Mdot
.09978 .60087 Mdot
.10028 .60087 Mdot
.10077 .60087 Mdot
.10127 .60087 Mdot
.10177 .60086 Mdot
.10226 .60086 Mdot
.10276 .60085 Mdot
.10326 .60085 Mdot
.10375 .60085 Mdot
.10425 .60085 Mdot
.10475 .60085 Mdot
.10524 .60085 Mdot
.10574 .60085 Mdot
.10624 .60085 Mdot
.10673 .60085 Mdot
.10723 .60085 Mdot
.10773 .60084 Mdot
.10822 .60086 Mdot
.10872 .60086 Mdot
.10922 .60086 Mdot
.10971 .60086 Mdot
.11021 .60086 Mdot
.11071 .60087 Mdot
.1112 .60087 Mdot
.1117 .60087 Mdot
.1122 .60088 Mdot
.11269 .60088 Mdot
.11319 .60088 Mdot
.11368 .60087 Mdot
.11418 .60087 Mdot
.11468 .60086 Mdot
.11517 .60086 Mdot
.11567 .60086 Mdot
.11617 .60086 Mdot
.11666 .60086 Mdot
.11716 .60086 Mdot
.11766 .60086 Mdot
.11815 .60086 Mdot
.11865 .60085 Mdot
.11915 .60085 Mdot
.11964 .60084 Mdot
.12014 .60084 Mdot
.12064 .60084 Mdot
.12113 .60084 Mdot
.12163 .60084 Mdot
.12213 .60085 Mdot
.12262 .60085 Mdot
.12312 .60085 Mdot
.12362 .60086 Mdot
.12411 .60086 Mdot
.12461 .60087 Mdot
.12511 .60087 Mdot
.1256 .60086 Mdot
.1261 .60085 Mdot
.1266 .60086 Mdot
.12709 .60086 Mdot
.12759 .60083 Mdot
.12808 .60112 Mdot
.12858 .60088 Mdot
.12908 .60086 Mdot
.12957 .60086 Mdot
.13007 .60086 Mdot
.13057 .60086 Mdot
.13106 .60085 Mdot
.13156 .60085 Mdot
.13206 .60085 Mdot
.13255 .60085 Mdot
.13305 .60085 Mdot
.13355 .60085 Mdot
.13404 .60085 Mdot
.13454 .60085 Mdot
.13504 .60085 Mdot
.13553 .60086 Mdot
.13603 .60085 Mdot
.13653 .60086 Mdot
.13702 .60086 Mdot
.13752 .60085 Mdot
.13802 .60085 Mdot
.13851 .60085 Mdot
.13901 .60084 Mdot
.13951 .60084 Mdot
.14 .60084 Mdot
.1405 .60084 Mdot
.141 .60084 Mdot
.14149 .60085 Mdot
.14199 .60085 Mdot
.14248 .60084 Mdot
.14298 .60085 Mdot
.14348 .60085 Mdot
.14397 .6008 Mdot
.14447 .6008 Mdot
.14497 .60095 Mdot
.14546 .6009 Mdot
.14596 .60088 Mdot
.14646 .60087 Mdot
.14695 .60086 Mdot
.14745 .60086 Mdot
.14795 .60086 Mdot
.14844 .60086 Mdot
.14894 .60086 Mdot
.14944 .60085 Mdot
.14993 .60085 Mdot
.15043 .60085 Mdot
.15093 .60085 Mdot
.15142 .60085 Mdot
.15192 .60084 Mdot
.15242 .60085 Mdot
.15291 .60085 Mdot
.15341 .60085 Mdot
.15391 .60085 Mdot
.1544 .60085 Mdot
.1549 .60084 Mdot
.1554 .60084 Mdot
.15589 .60085 Mdot
.15639 .60085 Mdot
.15688 .60084 Mdot
.15738 .60085 Mdot
.15788 .60023 Mdot
.15837 .60079 Mdot
.15887 .60078 Mdot
.15937 .60086 Mdot
.15986 .60091 Mdot
.16036 .6009 Mdot
.16086 .60089 Mdot
.16135 .60087 Mdot
.16185 .60087 Mdot
.16235 .60087 Mdot
.16284 .60087 Mdot
.16334 .60087 Mdot
.16384 .60087 Mdot
.16433 .60087 Mdot
.16483 .60087 Mdot
.16533 .60086 Mdot
.16582 .60086 Mdot
.16632 .60087 Mdot
.16682 .60086 Mdot
.16731 .60086 Mdot
.16781 .60086 Mdot
.16831 .60086 Mdot
.1688 .60023 Mdot
.1693 .60024 Mdot
.16979 .60023 Mdot
.17029 .60023 Mdot
.17079 .60086 Mdot
.17128 .60086 Mdot
.17178 .60091 Mdot
.17228 .60093 Mdot
.17277 .60092 Mdot
.17327 .60089 Mdot
.17377 .60091 Mdot
.17426 .60092 Mdot
.17476 .60092 Mdot
.17526 .60088 Mdot
.17575 .60087 Mdot
.17625 .60087 Mdot
.17675 .60086 Mdot
.17724 .60086 Mdot
.17774 .60086 Mdot
.17824 .60086 Mdot
.17873 .60086 Mdot
.17923 .60086 Mdot
.17973 .60086 Mdot
.18022 .60086 Mdot
.18072 .60086 Mdot
.18122 .60085 Mdot
.18171 .60085 Mdot
.18221 .60086 Mdot
.18271 .60086 Mdot
.1832 .60086 Mdot
.1837 .60086 Mdot
.18419 .60086 Mdot
.18469 .60087 Mdot
.18519 .60086 Mdot
.18568 .60088 Mdot
.18618 .60089 Mdot
.18668 .60088 Mdot
.18717 .60086 Mdot
.18767 .6015 Mdot
.18817 .6015 Mdot
.18866 .6015 Mdot
.18916 .60087 Mdot
.18966 .60085 Mdot
.19015 .60086 Mdot
.19065 .60085 Mdot
.19115 .60086 Mdot
.19164 .60085 Mdot
.19214 .60085 Mdot
.19264 .60084 Mdot
.19313 .60084 Mdot
.19363 .60085 Mdot
.19413 .60085 Mdot
.19462 .60085 Mdot
.19512 .60084 Mdot
.19562 .60085 Mdot
.19611 .60174 Mdot
.19661 .60103 Mdot
.19711 .60096 Mdot
.1976 .60095 Mdot
.1981 .60092 Mdot
.19859 .60091 Mdot
.19909 .6009 Mdot
.19959 .60088 Mdot
.20008 .60087 Mdot
.20058 .60085 Mdot
.20108 .60087 Mdot
.20157 .60087 Mdot
.20207 .60079 Mdot
.20257 .60095 Mdot
.20306 .60091 Mdot
.20356 .60088 Mdot
.20406 .60087 Mdot
.20455 .60087 Mdot
.20505 .60087 Mdot
.20555 .60087 Mdot
.20604 .60087 Mdot
.20654 .60087 Mdot
.20704 .60087 Mdot
.20753 .60086 Mdot
.20803 .60087 Mdot
.20853 .60086 Mdot
.20902 .60087 Mdot
.20952 .60087 Mdot
.21002 .60026 Mdot
.21051 .60027 Mdot
.21101 .60026 Mdot
.21151 .60025 Mdot
.212 .60025 Mdot
.2125 .60024 Mdot
.21299 .60025 Mdot
.21349 .60025 Mdot
.21399 .60083 Mdot
.21448 .60084 Mdot
.21498 .60084 Mdot
.21548 .60083 Mdot
.21597 .60085 Mdot
.21647 .6009 Mdot
.21697 .6009 Mdot
.21746 .60088 Mdot
.21796 .60087 Mdot
.21846 .60087 Mdot
.21895 .60087 Mdot
.21945 .60087 Mdot
.21995 .60087 Mdot
.22044 .60087 Mdot
.22094 .60087 Mdot
.22144 .60087 Mdot
.22193 .60087 Mdot
.22243 .60086 Mdot
.22293 .60149 Mdot
.22342 .60149 Mdot
.22392 .60088 Mdot
.22442 .60084 Mdot
.22491 .60085 Mdot
.22541 .60082 Mdot
.2259 .60086 Mdot
.2264 .60086 Mdot
.2269 .60088 Mdot
.22739 .6009 Mdot
.22789 .60091 Mdot
.22839 .6009 Mdot
.22888 .6009 Mdot
.22938 .60087 Mdot
.22988 .60091 Mdot
.23037 .60091 Mdot
.23087 .60089 Mdot
.23137 .60088 Mdot
.23186 .60087 Mdot
.23236 .60087 Mdot
.23286 .60086 Mdot
.23335 .60087 Mdot
.23385 .60087 Mdot
.23435 .60086 Mdot
.23484 .60087 Mdot
.23534 .60086 Mdot
.23584 .60086 Mdot
.23633 .60085 Mdot
.23683 .60086 Mdot
.23733 .60086 Mdot
.23782 .60086 Mdot
.23832 .60087 Mdot
.23882 .60087 Mdot
.23931 .60086 Mdot
.23981 .60087 Mdot
.2403 .60087 Mdot
.2408 .60088 Mdot
.2413 .60087 Mdot
.24179 .60087 Mdot
.24229 .60117 Mdot
.24279 .6011 Mdot
.24328 .60088 Mdot
.24378 .60089 Mdot
.24428 .60088 Mdot
.24477 .60088 Mdot
.24527 .60087 Mdot
.24577 .60086 Mdot
.24626 .60085 Mdot
.24676 .60086 Mdot
.24726 .60086 Mdot
.24775 .60086 Mdot
.24825 .60086 Mdot
.24875 .60085 Mdot
.24924 .60085 Mdot
.24974 .60084 Mdot
.25024 .60085 Mdot
.25073 .60087 Mdot
.25123 .60087 Mdot
.25173 .60086 Mdot
.25222 .60087 Mdot
.25272 .60088 Mdot
.25322 .60092 Mdot
.25371 .60091 Mdot
.25421 .60087 Mdot
.2547 .60086 Mdot
.2552 .60058 Mdot
.2557 .60061 Mdot
.25619 .60079 Mdot
.25669 .60092 Mdot
.25719 .60092 Mdot
.25768 .60089 Mdot
.25818 .60088 Mdot
.25868 .60087 Mdot
.25917 .60087 Mdot
.25967 .60087 Mdot
.26017 .60086 Mdot
.26066 .60087 Mdot
.26116 .60086 Mdot
.26166 .60086 Mdot
.26215 .60087 Mdot
.26265 .60086 Mdot
.26315 .60172 Mdot
.26364 .60173 Mdot
.26414 .601 Mdot
.26464 .60082 Mdot
.26513 .60081 Mdot
.26563 .60082 Mdot
.26613 .60082 Mdot
.26662 .60082 Mdot
.26712 .60083 Mdot
.26762 .60085 Mdot
.26811 .60088 Mdot
.26861 .60085 Mdot
.2691 .60081 Mdot
.2696 .60081 Mdot
.2701 .60081 Mdot
.27059 .60088 Mdot
.27109 .60091 Mdot
.27159 .60089 Mdot
.27208 .60087 Mdot
.27258 .60087 Mdot
.27308 .60087 Mdot
.27357 .60087 Mdot
.27407 .60087 Mdot
.27457 .60087 Mdot
.27506 .60087 Mdot
.27556 .60087 Mdot
.27606 .60087 Mdot
.27655 .60087 Mdot
.27705 .60148 Mdot
.27755 .60149 Mdot
.27804 .60149 Mdot
.27854 .60149 Mdot
.27904 .60085 Mdot
.27953 .60083 Mdot
.28003 .60084 Mdot
.28053 .60088 Mdot
.28102 .60089 Mdot
.28152 .60089 Mdot
.28201 .60089 Mdot
.28251 .60091 Mdot
.28301 .60092 Mdot
.2835 .60089 Mdot
.284 .60088 Mdot
.2845 .60087 Mdot
.28499 .60088 Mdot
.28549 .60087 Mdot
.28599 .60087 Mdot
.28648 .60086 Mdot
.28698 .60086 Mdot
.28748 .60086 Mdot
.28797 .60086 Mdot
.28847 .60085 Mdot
.28897 .60085 Mdot
.28946 .60084 Mdot
.28996 .60084 Mdot
.29046 .60085 Mdot
.29095 .60085 Mdot
.29145 .60086 Mdot
.29195 .60086 Mdot
.29244 .60086 Mdot
.29294 .60086 Mdot
.29344 .60087 Mdot
.29393 .60151 Mdot
.29443 .60151 Mdot
.29493 .6015 Mdot
.29542 .6015 Mdot
.29592 .60118 Mdot
.29641 .60099 Mdot
.29691 .60093 Mdot
.29741 .60085 Mdot
.2979 .60086 Mdot
.2984 .60086 Mdot
.2989 .60086 Mdot
.29939 .60086 Mdot
.29989 .60085 Mdot
.30039 .60084 Mdot
.30088 .60084 Mdot
.30138 .60084 Mdot
.30188 .60083 Mdot
.30237 .60084 Mdot
.30287 .6002 Mdot
.30337 .60019 Mdot
.30386 .60103 Mdot
.30436 .60105 Mdot
.30486 .60104 Mdot
.30535 .60105 Mdot
.30585 .60103 Mdot
.30635 .60106 Mdot
.30684 .60104 Mdot
.30734 .60099 Mdot
.30784 .60105 Mdot
.30833 .60083 Mdot
.30883 .60083 Mdot
.30933 .60079 Mdot
.30982 .6009 Mdot
.31032 .60089 Mdot
.31081 .60087 Mdot
.31131 .60088 Mdot
.31181 .60088 Mdot
.3123 .60088 Mdot
.3128 .60088 Mdot
.3133 .60088 Mdot
.31379 .60088 Mdot
.31429 .60087 Mdot
.31479 .60087 Mdot
.31528 .60087 Mdot
.31578 .60087 Mdot
.31628 .60086 Mdot
.31677 .60152 Mdot
.31727 .60089 Mdot
.31777 .60087 Mdot
.31826 .60085 Mdot
.31876 .60084 Mdot
.31926 .60084 Mdot
.31975 .60085 Mdot
.32025 .60085 Mdot
.32075 .60084 Mdot
.32124 .60084 Mdot
.32174 .60084 Mdot
.32224 .60083 Mdot
.32273 .60083 Mdot
.32323 .60083 Mdot
.32373 .60082 Mdot
.32422 .6008 Mdot
.32472 .60084 Mdot
.32521 .60091 Mdot
.32571 .60089 Mdot
.32621 .60088 Mdot
.3267 .60087 Mdot
.3272 .60087 Mdot
.3277 .60087 Mdot
.32819 .60087 Mdot
.32869 .60087 Mdot
.32919 .60086 Mdot
.32968 .60085 Mdot
.33018 .6009 Mdot
.33068 .60089 Mdot
.33117 .60086 Mdot
.33167 .60087 Mdot
.33217 .60087 Mdot
.33266 .60087 Mdot
.33316 .60085 Mdot
.33366 .60085 Mdot
.33415 .60086 Mdot
.33465 .60088 Mdot
.33515 .60087 Mdot
.33564 .60086 Mdot
.33614 .60087 Mdot
.33664 .60088 Mdot
.33713 .60091 Mdot
.33763 .6009 Mdot
.33813 .60089 Mdot
.33862 .60089 Mdot
.33912 .60088 Mdot
.33961 .60087 Mdot
.34011 .60087 Mdot
.34061 .60086 Mdot
.3411 .60086 Mdot
.3416 .60086 Mdot
.3421 .60086 Mdot
.34259 .60086 Mdot
.34309 .60209 Mdot
.34359 .60209 Mdot
.34408 .60209 Mdot
.34458 .6021 Mdot
.34508 .60209 Mdot
.34557 .60209 Mdot
.34607 .60089 Mdot
.34657 .60092 Mdot
.34706 .60099 Mdot
.34756 .60101 Mdot
.34806 .60108 Mdot
.34855 .60101 Mdot
.34905 .60106 Mdot
.34955 .60101 Mdot
.35004 .60103 Mdot
.35054 .60103 Mdot
.35104 .60099 Mdot
.35153 .60092 Mdot
.35203 .60089 Mdot
.35252 .60087 Mdot
.35302 .60086 Mdot
.35352 .60085 Mdot
.35401 .60084 Mdot
.35451 .60084 Mdot
.35501 .60084 Mdot
.3555 .60084 Mdot
.356 .60083 Mdot
.3565 .60082 Mdot
.35699 .60082 Mdot
.35749 .60083 Mdot
.35799 .60084 Mdot
.35848 .60081 Mdot
.35898 .6008 Mdot
.35948 .60083 Mdot
.35997 .60086 Mdot
.36047 .60088 Mdot
.36097 .6009 Mdot
.36146 .60087 Mdot
.36196 .60087 Mdot
.36246 .60086 Mdot
.36295 .60086 Mdot
.36345 .60086 Mdot
.36395 .60085 Mdot
.36444 .60086 Mdot
.36494 .60087 Mdot
.36544 .60087 Mdot
.36593 .60087 Mdot
.36643 .60087 Mdot
.36692 .60087 Mdot
.36742 .60086 Mdot
.36792 .60086 Mdot
.36841 .60086 Mdot
.36891 .60086 Mdot
.36941 .60086 Mdot
.3699 .60086 Mdot
.3704 .60085 Mdot
.3709 .60085 Mdot
.37139 .60144 Mdot
.37189 .60144 Mdot
.37239 .60145 Mdot
.37288 .60147 Mdot
.37338 .60147 Mdot
.37388 .60084 Mdot
.37437 .60083 Mdot
.37487 .60081 Mdot
.37537 .60085 Mdot
.37586 .60086 Mdot
.37636 .60086 Mdot
.37686 .60086 Mdot
.37735 .60086 Mdot
.37785 .60086 Mdot
.37835 .60087 Mdot
.37884 .60088 Mdot
.37934 .60087 Mdot
.37984 .60089 Mdot
.38033 .60089 Mdot
.38083 .60089 Mdot
.38132 .60089 Mdot
.38182 .60088 Mdot
.38232 .60088 Mdot
.38281 .60087 Mdot
.38331 .60087 Mdot
.38381 .60087 Mdot
.3843 .60087 Mdot
.3848 .60087 Mdot
.3853 .60087 Mdot
.38579 .60087 Mdot
.38629 .60087 Mdot
.38679 .60149 Mdot
.38728 .6015 Mdot
.38778 .6015 Mdot
.38828 .60149 Mdot
.38877 .60087 Mdot
.38927 .60089 Mdot
.38977 .60088 Mdot
.39026 .60088 Mdot
.39076 .60087 Mdot
.39126 .60088 Mdot
.39175 .60085 Mdot
.39225 .60089 Mdot
.39275 .60088 Mdot
.39324 .60088 Mdot
.39374 .60087 Mdot
.39424 .60087 Mdot
.39473 .60087 Mdot
.39523 .60086 Mdot
.39572 .60086 Mdot
.39622 .60086 Mdot
.39672 .60085 Mdot
.39721 .60085 Mdot
.39771 .60085 Mdot
.39821 .60085 Mdot
.3987 .60002 Mdot
.3992 .59998 Mdot
.3997 .60097 Mdot
.40019 .60085 Mdot
.40069 .60084 Mdot
.40119 .60085 Mdot
.40168 .60089 Mdot
.40218 .60108 Mdot
.40268 .60108 Mdot
.40317 .60103 Mdot
.40367 .60115 Mdot
.40417 .60113 Mdot
.40466 .60103 Mdot
.40516 .60094 Mdot
.40566 .60108 Mdot
.40615 .60086 Mdot
.40665 .60091 Mdot
.40715 .6009 Mdot
.40764 .60087 Mdot
.40814 .60086 Mdot
.40863 .60085 Mdot
.40913 .60084 Mdot
.40963 .60084 Mdot
.41012 .60085 Mdot
.41062 .60084 Mdot
.41112 .60084 Mdot
.41161 .60084 Mdot
.41211 .60084 Mdot
.41261 .60084 Mdot
.4131 .60083 Mdot
.4136 .6008 Mdot
.4141 .6008 Mdot
.41459 .60082 Mdot
.41509 .60082 Mdot
.41559 .60084 Mdot
.41608 .60083 Mdot
.41658 .60083 Mdot
.41708 .60083 Mdot
.41757 .60082 Mdot
.41807 .60128 Mdot
.41857 .60126 Mdot
.41906 .60128 Mdot
.41956 .60126 Mdot
.42006 .60108 Mdot
.42055 .60097 Mdot
.42105 .60094 Mdot
.42155 .60094 Mdot
.42204 .60094 Mdot
.42254 .6009 Mdot
.42303 .60088 Mdot
.42353 .60085 Mdot
.42403 .60086 Mdot
.42452 .60085 Mdot
.42502 .60086 Mdot
.42552 .60087 Mdot
.42601 .60086 Mdot
.42651 .60087 Mdot
.42701 .60088 Mdot
.4275 .60094 Mdot
.428 .60101 Mdot
.4285 .60101 Mdot
.42899 .601 Mdot
.42949 .60096 Mdot
.42999 .60097 Mdot
.43048 .60096 Mdot
.43098 .60097 Mdot
.43148 .60093 Mdot
.43197 .60093 Mdot
.43247 .6009 Mdot
.43297 .60086 Mdot
.43346 .60085 Mdot
.43396 .60082 Mdot
.43446 .60081 Mdot
.43495 .60078 Mdot
.43545 .60079 Mdot
.43595 .60103 Mdot
.43644 .60169 Mdot
.43694 .6017 Mdot
.43743 .60083 Mdot
.43793 .60084 Mdot
.43843 .60086 Mdot
.43892 .60083 Mdot
.43942 .60084 Mdot
.43992 .60084 Mdot
.44041 .60081 Mdot
.44091 .6008 Mdot
.44141 .60079 Mdot
.4419 .6008 Mdot
.4424 .6008 Mdot
.4429 .60081 Mdot
.44339 .60069 Mdot
.44389 .60071 Mdot
.44439 .60071 Mdot
.44488 .60071 Mdot
.44538 .60072 Mdot
.44588 .60076 Mdot
.44637 .60103 Mdot
.44687 .60099 Mdot
.44737 .60088 Mdot
.44786 .60087 Mdot
.44836 .60087 Mdot
.44886 .60085 Mdot
.44935 .60084 Mdot
.44985 .60087 Mdot
.45035 .60088 Mdot
.45084 .60086 Mdot
.45134 .60087 Mdot
.45183 .60086 Mdot
.45233 .60087 Mdot
.45283 .60087 Mdot
.45332 .60086 Mdot
.45382 .60088 Mdot
.45432 .60087 Mdot
.45481 .60087 Mdot
.45531 .60089 Mdot
.45581 .60088 Mdot
.4563 .60087 Mdot
.4568 .60084 Mdot
.4573 .60084 Mdot
.45779 .60085 Mdot
.45829 .60089 Mdot
.45879 .60085 Mdot
.45928 .60082 Mdot
.45978 .60084 Mdot
.46028 .60085 Mdot
.46077 .60025 Mdot
.46127 .60027 Mdot
.46177 .60033 Mdot
.46226 .60077 Mdot
.46276 .60078 Mdot
.46326 .60081 Mdot
.46375 .60082 Mdot
.46425 .60083 Mdot
.46475 .60085 Mdot
.46524 .60084 Mdot
.46574 .60084 Mdot
.46623 .60083 Mdot
.46673 .60083 Mdot
.46723 .60084 Mdot
.46772 .60083 Mdot
.46822 .60082 Mdot
.46872 .60079 Mdot
.46921 .60079 Mdot
.46971 .60079 Mdot
.47021 .60077 Mdot
.4707 .60083 Mdot
.4712 .60077 Mdot
.4717 .60081 Mdot
.47219 .6008 Mdot
.47269 .60078 Mdot
.47319 .60082 Mdot
.47368 .6008 Mdot
.47418 .60077 Mdot
.47468 .601 Mdot
.47517 .60102 Mdot
.47567 .60088 Mdot
.47617 .60087 Mdot
.47666 .60086 Mdot
.47716 .60087 Mdot
.47766 .60087 Mdot
.47815 .60086 Mdot
.47865 .60087 Mdot
.47914 .60087 Mdot
.47964 .60086 Mdot
.48014 .60085 Mdot
.48063 .60087 Mdot
.48113 .60086 Mdot
.48163 .60084 Mdot
.48212 .60088 Mdot
.48262 .60087 Mdot
.48312 .60086 Mdot
.48361 .60085 Mdot
.48411 .60084 Mdot
.48461 .60083 Mdot
.4851 .60086 Mdot
.4856 .60086 Mdot
.4861 .60085 Mdot
.48659 .60085 Mdot
.48709 .60088 Mdot
.48759 .60032 Mdot
.48808 .60035 Mdot
.48858 .60081 Mdot
.48908 .60083 Mdot
.48957 .60085 Mdot
.49007 .60086 Mdot
.49057 .60086 Mdot
.49106 .60085 Mdot
.49156 .60086 Mdot
.49206 .60086 Mdot
.49255 .60085 Mdot
.49305 .60085 Mdot
.49354 .60085 Mdot
.49404 .60084 Mdot
.49454 .60083 Mdot
.49503 .60083 Mdot
.49553 .60084 Mdot
.49603 .60085 Mdot
.49652 .60085 Mdot
.49702 .60086 Mdot
.49752 .60086 Mdot
.49801 .60084 Mdot
.49851 .60083 Mdot
.49901 .60084 Mdot
.4995 .60085 Mdot
.5 .60085 Mdot
.5005 .60085 Mdot
.50099 .60085 Mdot
.50149 .60078 Mdot
.50199 .60112 Mdot
.50248 .60088 Mdot
.50298 .60086 Mdot
.50348 .60086 Mdot
.50397 .60086 Mdot
.50447 .60087 Mdot
.50497 .60087 Mdot
.50546 .60087 Mdot
.50596 .60087 Mdot
.50646 .60008 Mdot
.50695 .60022 Mdot
.50745 .60025 Mdot
.50794 .6002 Mdot
.50844 .6002 Mdot
.50894 .60018 Mdot
.50943 .60021 Mdot
.50993 .6008 Mdot
.51043 .60087 Mdot
.51092 .60081 Mdot
.51142 .60083 Mdot
.51192 .60079 Mdot
.51241 .60079 Mdot
.51291 .60079 Mdot
.51341 .60082 Mdot
.5139 .6008 Mdot
.5144 .60078 Mdot
.5149 .60079 Mdot
.51539 .60094 Mdot
.51589 .6009 Mdot
.51639 .6009 Mdot
.51688 .60088 Mdot
.51738 .60088 Mdot
.51788 .60089 Mdot
.51837 .60087 Mdot
.51887 .60086 Mdot
.51937 .60088 Mdot
.51986 .60088 Mdot
.52036 .60087 Mdot
.52086 .60087 Mdot
.52135 .60086 Mdot
.52185 .60086 Mdot
.52234 .60086 Mdot
.52284 .60084 Mdot
.52334 .60086 Mdot
.52383 .60092 Mdot
.52433 .60087 Mdot
.52483 .60089 Mdot
.52532 .60091 Mdot
.52582 .60088 Mdot
.52632 .60086 Mdot
.52681 .60085 Mdot
.52731 .60086 Mdot
.52781 .60086 Mdot
.5283 .60083 Mdot
.5288 .60082 Mdot
.5293 .6007 Mdot
.52979 .60053 Mdot
.53029 .6009 Mdot
.53079 .6009 Mdot
.53128 .6009 Mdot
.53178 .60089 Mdot
.53228 .6009 Mdot
.53277 .60086 Mdot
.53327 .60087 Mdot
.53377 .60086 Mdot
.53426 .60085 Mdot
.53476 .60086 Mdot
.53525 .60086 Mdot
.53575 .60086 Mdot
.53625 .60087 Mdot
.53674 .60087 Mdot
.53724 .60158 Mdot
.53774 .60086 Mdot
.53823 .60088 Mdot
.53873 .60088 Mdot
.53923 .60091 Mdot
.53972 .60094 Mdot
.54022 .60098 Mdot
.54072 .60095 Mdot
.54121 .60089 Mdot
.54171 .60084 Mdot
.54221 .60158 Mdot
.5427 .60161 Mdot
.5432 .60155 Mdot
.5437 .60222 Mdot
.54419 .60224 Mdot
.54469 .6001 Mdot
.54519 .60012 Mdot
.54568 .60013 Mdot
.54618 .60018 Mdot
.54668 .60075 Mdot
.54717 .60079 Mdot
.54767 .60078 Mdot
.54817 .60083 Mdot
.54866 .60084 Mdot
.54916 .60083 Mdot
.54965 .60082 Mdot
.55015 .60083 Mdot
.55065 .60083 Mdot
.55114 .60082 Mdot
.55164 .60081 Mdot
.55214 .60082 Mdot
.55263 .60083 Mdot
.55313 .60081 Mdot
.55363 .60082 Mdot
.55412 .6008 Mdot
.55462 .60078 Mdot
.55512 .60078 Mdot
.55561 .6008 Mdot
.55611 .60071 Mdot
.55661 .60073 Mdot
.5571 .60074 Mdot
.5576 .60111 Mdot
.5581 .60121 Mdot
.55859 .60104 Mdot
.55909 .60118 Mdot
.55959 .60105 Mdot
.56008 .60099 Mdot
.56058 .60092 Mdot
.56108 .60089 Mdot
.56157 .60097 Mdot
.56207 .60097 Mdot
.56257 .60085 Mdot
.56306 .60083 Mdot
.56356 .60087 Mdot
.56405 .60086 Mdot
.56455 .60085 Mdot
.56505 .60084 Mdot
.56554 .60082 Mdot
.56604 .60081 Mdot
.56654 .60087 Mdot
.56703 .60077 Mdot
.56753 .60078 Mdot
.56803 .60025 Mdot
.56852 .60028 Mdot
.56902 .60077 Mdot
.56952 .60081 Mdot
.57001 .60081 Mdot
.57051 .60085 Mdot
.57101 .60083 Mdot
.5715 .60084 Mdot
.572 .60081 Mdot
.5725 .60081 Mdot
.57299 .60079 Mdot
.57349 .60082 Mdot
.57399 .60078 Mdot
.57448 .60079 Mdot
.57498 .60082 Mdot
.57548 .60084 Mdot
.57597 .60085 Mdot
.57647 .60084 Mdot
.57697 .60085 Mdot
.57746 .60083 Mdot
.57796 .60082 Mdot
.57845 .60077 Mdot
.57895 .60079 Mdot
.57945 .60081 Mdot
.57994 .6008 Mdot
.58044 .60078 Mdot
.58094 .60096 Mdot
.58143 .60098 Mdot
.58193 .601 Mdot
.58243 .60086 Mdot
.58292 .60086 Mdot
.58342 .60087 Mdot
.58392 .60088 Mdot
.58441 .60088 Mdot
.58491 .60088 Mdot
.58541 .60087 Mdot
.5859 .60088 Mdot
.5864 .60088 Mdot
.5869 .60087 Mdot
.58739 .60086 Mdot
.58789 .60087 Mdot
.58839 .60086 Mdot
.58888 .60087 Mdot
.58938 .60087 Mdot
.58988 .60086 Mdot
.59037 .60086 Mdot
.59087 .60087 Mdot
.59137 .60086 Mdot
.59186 .60085 Mdot
.59236 .60087 Mdot
.59285 .60086 Mdot
.59335 .60086 Mdot
.59385 .60088 Mdot
.59434 .60283 Mdot
.59484 .60282 Mdot
.59534 .60281 Mdot
.59583 .60281 Mdot
.59633 .60228 Mdot
.59683 .60228 Mdot
.59732 .60227 Mdot
.59782 .60226 Mdot
.59832 .60225 Mdot
.59881 .60225 Mdot
.59931 .60225 Mdot
.59981 .60225 Mdot
.6003 .60225 Mdot
.6008 .60225 Mdot
.6013 .60225 Mdot
.60179 .60225 Mdot
.60229 .60084 Mdot
.60279 .60081 Mdot
.60328 .60082 Mdot
.60378 .6009 Mdot
.60428 .6009 Mdot
.60477 .60086 Mdot
.60527 .60085 Mdot
.60576 .60087 Mdot
.60626 .60087 Mdot
.60676 .60089 Mdot
.60725 .60084 Mdot
.60775 .60082 Mdot
.60825 .60068 Mdot
.60874 .60071 Mdot
.60924 .60055 Mdot
.60974 .60053 Mdot
.61023 .60052 Mdot
.61073 .60087 Mdot
.61123 .60088 Mdot
.61172 .60087 Mdot
.61222 .60086 Mdot
.61272 .60172 Mdot
.61321 .60173 Mdot
.61371 .60172 Mdot
.61421 .60173 Mdot
.6147 .6011 Mdot
.6152 .6011 Mdot
.6157 .60106 Mdot
.61619 .60105 Mdot
.61669 .60107 Mdot
.61719 .60103 Mdot
.61768 .60101 Mdot
.61818 .60101 Mdot
.61868 .60102 Mdot
.61917 .60101 Mdot
.61967 .60101 Mdot
.62016 .60105 Mdot
.62066 .60104 Mdot
.62116 .60105 Mdot
.62165 .60104 Mdot
.62215 .60105 Mdot
.62265 .60104 Mdot
.62314 .601 Mdot
.62364 .60094 Mdot
.62414 .60091 Mdot
.62463 .60088 Mdot
.62513 .60088 Mdot
.62563 .60087 Mdot
.62612 .60088 Mdot
.62662 .60088 Mdot
.62712 .60087 Mdot
.62761 .60086 Mdot
.62811 .60086 Mdot
.62861 .60085 Mdot
.6291 .60085 Mdot
.6296 .60085 Mdot
.6301 .60086 Mdot
.63059 .60088 Mdot
.63109 .60087 Mdot
.63159 .60088 Mdot
.63208 .60088 Mdot
.63258 .60087 Mdot
.63308 .60088 Mdot
.63357 .60084 Mdot
.63407 .60086 Mdot
.63456 .60089 Mdot
.63506 .60087 Mdot
.63556 .60086 Mdot
.63605 .60064 Mdot
.63655 .6009 Mdot
.63705 .6009 Mdot
.63754 .60088 Mdot
.63804 .60087 Mdot
.63854 .60087 Mdot
.63903 .60086 Mdot
.63953 .60085 Mdot
.64003 .60085 Mdot
.64052 .60086 Mdot
.64102 .60085 Mdot
.64152 .60085 Mdot
.64201 .60084 Mdot
.64251 .60083 Mdot
.64301 .60083 Mdot
.6435 .60086 Mdot
.644 .60086 Mdot
.6445 .60085 Mdot
.64499 .60085 Mdot
.64549 .60086 Mdot
.64599 .60085 Mdot
.64648 .60084 Mdot
.64698 .60085 Mdot
.64748 .60085 Mdot
.64797 .60084 Mdot
.64847 .60086 Mdot
.64896 .60079 Mdot
.64946 .60096 Mdot
.64996 .60088 Mdot
.65045 .60086 Mdot
.65095 .60087 Mdot
.65145 .60087 Mdot
.65194 .60087 Mdot
.65244 .60087 Mdot
.65294 .60086 Mdot
.65343 .60086 Mdot
.65393 .60087 Mdot
.65443 .60086 Mdot
.65492 .60086 Mdot
.65542 .60086 Mdot
.65592 .60086 Mdot
.65641 .60086 Mdot
.65691 .60086 Mdot
.65741 .60086 Mdot
.6579 .60085 Mdot
.6584 .60086 Mdot
.6589 .60087 Mdot
.65939 .60092 Mdot
.65989 .60085 Mdot
.66039 .60086 Mdot
.66088 .60086 Mdot
.66138 .60086 Mdot
.66187 .60086 Mdot
.66237 .60104 Mdot
.66287 .60105 Mdot
.66336 .60106 Mdot
.66386 .60085 Mdot
.66436 .6009 Mdot
.66485 .60088 Mdot
.66535 .60085 Mdot
.66585 .60087 Mdot
.66634 .60089 Mdot
.66684 .60085 Mdot
.66734 .60084 Mdot
.66783 .60085 Mdot
.66833 .60085 Mdot
.66883 .60085 Mdot
.66932 .60084 Mdot
.66982 .60083 Mdot
.67032 .60081 Mdot
.67081 .60084 Mdot
.67131 .60085 Mdot
.67181 .60086 Mdot
.6723 .60086 Mdot
.6728 .60085 Mdot
.6733 .60086 Mdot
.67379 .60089 Mdot
.67429 .60085 Mdot
.67479 .60085 Mdot
.67528 .60126 Mdot
.67578 .60125 Mdot
.67627 .60115 Mdot
.67677 .60098 Mdot
.67727 .60096 Mdot
.67776 .60089 Mdot
.67826 .60089 Mdot
.67876 .60087 Mdot
.67925 .60086 Mdot
.67975 .60088 Mdot
.68025 .60085 Mdot
.68074 .60088 Mdot
.68124 .60088 Mdot
.68174 .60084 Mdot
.68223 .60085 Mdot
.68273 .60084 Mdot
.68323 .60083 Mdot
.68372 .60084 Mdot
.68422 .60084 Mdot
.68472 .60087 Mdot
.68521 .60082 Mdot
.68571 .60082 Mdot
.68621 .60083 Mdot
.6867 .60086 Mdot
.6872 .60085 Mdot
.6877 .60084 Mdot
.68819 .60085 Mdot
.68869 .60085 Mdot
.68919 .60081 Mdot
.68968 .6012 Mdot
.69018 .60104 Mdot
.69067 .60097 Mdot
.69117 .60095 Mdot
.69167 .601 Mdot
.69216 .601 Mdot
.69266 .60098 Mdot
.69316 .60092 Mdot
.69365 .60088 Mdot
.69415 .60087 Mdot
.69465 .60085 Mdot
.69514 .60086 Mdot
.69564 .60086 Mdot
.69614 .60087 Mdot
.69663 .60088 Mdot
.69713 .60089 Mdot
.69763 .60089 Mdot
.69812 .60087 Mdot
.69862 .60086 Mdot
.69912 .60086 Mdot
.69961 .60086 Mdot
.70011 .60088 Mdot
.70061 .60087 Mdot
.7011 .60086 Mdot
.7016 .60089 Mdot
.7021 .60094 Mdot
.70259 .60091 Mdot
.70309 .60084 Mdot
.70359 .60123 Mdot
.70408 .60101 Mdot
.70458 .60096 Mdot
.70507 .60096 Mdot
.70557 .60095 Mdot
.70607 .60098 Mdot
.70656 .60098 Mdot
.70706 .60092 Mdot
.70756 .60092 Mdot
.70805 .60093 Mdot
.70855 .6009 Mdot
.70905 .60087 Mdot
.70954 .60087 Mdot
.71004 .60085 Mdot
.71054 .60081 Mdot
.71103 .60092 Mdot
.71153 .60092 Mdot
.71203 .60091 Mdot
.71252 .60091 Mdot
.71302 .60091 Mdot
.71352 .6009 Mdot
.71401 .60096 Mdot
.71451 .60111 Mdot
.71501 .6011 Mdot
.7155 .60106 Mdot
.716 .6011 Mdot
.7165 .60127 Mdot
.71699 .60095 Mdot
.71749 .60089 Mdot
.71799 .60089 Mdot
.71848 .60089 Mdot
.71898 .60087 Mdot
.71947 .60086 Mdot
.71997 .60085 Mdot
.72047 .60086 Mdot
.72096 .60086 Mdot
.72146 .60084 Mdot
.72196 .60084 Mdot
.72245 .60085 Mdot
.72295 .60084 Mdot
.72345 .60083 Mdot
.72394 .60082 Mdot
.72444 .60085 Mdot
.72494 .60086 Mdot
.72543 .60085 Mdot
.72593 .60083 Mdot
.72643 .60086 Mdot
.72692 .60087 Mdot
.72742 .6025 Mdot
.72792 .60247 Mdot
.72841 .60242 Mdot
.72891 .60248 Mdot
.72941 .60247 Mdot
.7299 .60247 Mdot
.7304 .60247 Mdot
.7309 .60085 Mdot
.73139 .60082 Mdot
.73189 .60081 Mdot
.73238 .6009 Mdot
.73288 .60087 Mdot
.73338 .60086 Mdot
.73387 .60085 Mdot
.73437 .60085 Mdot
.73487 .60084 Mdot
.73536 .60084 Mdot
.73586 .60083 Mdot
.73636 .60082 Mdot
.73685 .60084 Mdot
.73735 .60083 Mdot
.73785 .60083 Mdot
.73834 .60083 Mdot
.73884 .60082 Mdot
.73934 .60081 Mdot
.73983 .60083 Mdot
.74033 .60082 Mdot
.74083 .60079 Mdot
.74132 .6008 Mdot
.74182 .60081 Mdot
.74232 .60081 Mdot
.74281 .60082 Mdot
.74331 .60079 Mdot
.74381 .60079 Mdot
.7443 .60081 Mdot
.7448 .60306 Mdot
.7453 .60302 Mdot
.74579 .60302 Mdot
.74629 .60243 Mdot
.74678 .60243 Mdot
.74728 .60242 Mdot
.74778 .60242 Mdot
.74827 .60242 Mdot
.74877 .60242 Mdot
.74927 .60242 Mdot
.74976 .60242 Mdot
.75026 .60178 Mdot
.75076 .60078 Mdot
.75125 .60075 Mdot
.75175 .60076 Mdot
.75225 .60009 Mdot
.75274 .60007 Mdot
.75324 .60078 Mdot
.75374 .60075 Mdot
.75423 .60084 Mdot
.75473 .60088 Mdot
.75523 .60072 Mdot
.75572 .60075 Mdot
.75622 .60088 Mdot
.75672 .60086 Mdot
.75721 .60088 Mdot
.75771 .60088 Mdot
.75821 .60085 Mdot
.7587 .60087 Mdot
.7592 .60085 Mdot
.7597 .60088 Mdot
.76019 .60087 Mdot
.76069 .60086 Mdot
.76118 .60086 Mdot
.76168 .60085 Mdot
.76218 .60085 Mdot
.76267 .60085 Mdot
.76317 .60085 Mdot
.76367 .60085 Mdot
.76416 .60085 Mdot
.76466 .60085 Mdot
.76516 .60085 Mdot
.76565 .60085 Mdot
.76615 .60085 Mdot
.76665 .60086 Mdot
.76714 .60086 Mdot
.76764 .60085 Mdot
.76814 .59576 Mdot
.76863 .6006 Mdot
.76913 .60087 Mdot
.76963 .60089 Mdot
.77012 .60077 Mdot
.77062 .60092 Mdot
.77112 .60095 Mdot
.77161 .60092 Mdot
.77211 .60085 Mdot
.77261 .60089 Mdot
.7731 .60083 Mdot
.7736 .60052 Mdot
.7741 .60081 Mdot
.77459 .60084 Mdot
.77509 .60083 Mdot
.77558 .60082 Mdot
.77608 .60082 Mdot
.77658 .60082 Mdot
.77707 .60083 Mdot
.77757 .60083 Mdot
.77807 .60084 Mdot
.77856 .60082 Mdot
.77906 .60082 Mdot
.77956 .60084 Mdot
.78005 .60081 Mdot
.78055 .60083 Mdot
.78105 .60084 Mdot
.78154 .60082 Mdot
.78204 .60207 Mdot
.78254 .6021 Mdot
.78303 .60216 Mdot
.78353 .60212 Mdot
.78403 .60213 Mdot
.78452 .6022 Mdot
.78502 .60215 Mdot
.78552 .60085 Mdot
.78601 .60086 Mdot
.78651 .60084 Mdot
.78701 .60084 Mdot
.7875 .60092 Mdot
.788 .60207 Mdot
.78849 .60213 Mdot
.78899 .60211 Mdot
.78949 .60209 Mdot
.78998 .60207 Mdot
.79048 .60083 Mdot
.79098 .60084 Mdot
.79147 .60085 Mdot
.79197 .60085 Mdot
.79247 .60085 Mdot
.79296 .60084 Mdot
.79346 .60084 Mdot
.79396 .60083 Mdot
.79445 .60079 Mdot
.79495 .6008 Mdot
.79545 .60082 Mdot
.79594 .60082 Mdot
.79644 .60081 Mdot
.79694 .60018 Mdot
.79743 .60028 Mdot
.79793 .60016 Mdot
.79843 .60019 Mdot
.79892 .6015 Mdot
.79942 .60149 Mdot
.79992 .60149 Mdot
.80041 .60149 Mdot
.80091 .60147 Mdot
.80141 .6015 Mdot
.8019 .60153 Mdot
.8024 .60155 Mdot
.80289 .60154 Mdot
.80339 .60091 Mdot
.80389 .60091 Mdot
.80438 .6009 Mdot
.80488 .60089 Mdot
.80538 .60088 Mdot
.80587 .60086 Mdot
.80637 .60087 Mdot
.80687 .60087 Mdot
.80736 .60085 Mdot
.80786 .60088 Mdot
.80836 .60086 Mdot
.80885 .60089 Mdot
.80935 .60086 Mdot
.80985 .60081 Mdot
.81034 .60083 Mdot
.81084 .60082 Mdot
.81134 .60081 Mdot
.81183 .60082 Mdot
.81233 .60085 Mdot
.81283 .60086 Mdot
.81332 .60087 Mdot
.81382 .60089 Mdot
.81432 .60093 Mdot
.81481 .60092 Mdot
.81531 .60083 Mdot
.81581 .60106 Mdot
.8163 .60094 Mdot
.8168 .60089 Mdot
.81729 .60087 Mdot
.81779 .60086 Mdot
.81829 .60085 Mdot
.81878 .60085 Mdot
.81928 .60085 Mdot
.81978 .60085 Mdot
.82027 .60085 Mdot
.82077 .60085 Mdot
.82127 .60331 Mdot
.82176 .60331 Mdot
.82226 .60331 Mdot
.82276 .6033 Mdot
.82325 .60331 Mdot
.82375 .60332 Mdot
.82425 .60191 Mdot
.82474 .60196 Mdot
.82524 .60195 Mdot
.82574 .60189 Mdot
.82623 .60193 Mdot
.82673 .60195 Mdot
.82723 .60192 Mdot
.82772 .60193 Mdot
.82822 .60188 Mdot
.82872 .60192 Mdot
.82921 .60197 Mdot
.82971 .60191 Mdot
.83021 .602 Mdot
.8307 .60193 Mdot
.8312 .60191 Mdot
.83169 .60194 Mdot
.83219 .6019 Mdot
.83269 .60199 Mdot
.83318 .60195 Mdot
.83368 .60086 Mdot
.83418 .60085 Mdot
.83467 .60085 Mdot
.83517 .60085 Mdot
.83567 .60085 Mdot
.83616 .60085 Mdot
.83666 .60085 Mdot
.83716 .60085 Mdot
.83765 .60085 Mdot
.83815 .60084 Mdot
.83865 .60083 Mdot
.83914 .60081 Mdot
.83964 .60081 Mdot
.84014 .6008 Mdot
.84063 .59834 Mdot
.84113 .60085 Mdot
.84163 .60085 Mdot
.84212 .60085 Mdot
.84262 .60086 Mdot
.84312 .60086 Mdot
.84361 .60086 Mdot
.84411 .60086 Mdot
.8446 .60086 Mdot
.8451 .60085 Mdot
.8456 .60085 Mdot
.84609 .60085 Mdot
.84659 .60084 Mdot
.84709 .60086 Mdot
.84758 .60087 Mdot
.84808 .60086 Mdot
.84858 .60086 Mdot
.84907 .60086 Mdot
.84957 .60086 Mdot
.85007 .60085 Mdot
.85056 .60084 Mdot
.85106 .60083 Mdot
.85156 .60084 Mdot
.85205 .60084 Mdot
.85255 .60084 Mdot
.85305 .60085 Mdot
.85354 .60085 Mdot
.85404 .60085 Mdot
.85454 .60084 Mdot
.85503 .60084 Mdot
.85553 .60084 Mdot
.85603 .60084 Mdot
.85652 .60084 Mdot
.85702 .60085 Mdot
.85752 .60086 Mdot
.85801 .60086 Mdot
.85851 .60086 Mdot
.859 .60085 Mdot
.8595 .60085 Mdot
.86 .60085 Mdot
.86049 .60084 Mdot
.86099 .60083 Mdot
.86149 .60083 Mdot
.86198 .60083 Mdot
.86248 .60083 Mdot
.86298 .60085 Mdot
.86347 .60086 Mdot
.86397 .60088 Mdot
.86447 .60087 Mdot
.86496 .60086 Mdot
.86546 .60085 Mdot
.86596 .60085 Mdot
.86645 .60084 Mdot
.86695 .60084 Mdot
.86745 .60084 Mdot
.86794 .60084 Mdot
.86844 .60085 Mdot
.86894 .60087 Mdot
.86943 .60089 Mdot
.86993 .60089 Mdot
.87043 .60088 Mdot
.87092 .60087 Mdot
.87142 .60087 Mdot
.87192 .60087 Mdot
.87241 .60087 Mdot
.87291 .60087 Mdot
.8734 .60087 Mdot
.8739 .60087 Mdot
.8744 .60086 Mdot
.87489 .60086 Mdot
.87539 .60086 Mdot
.87589 .60086 Mdot
.87638 .60086 Mdot
.87688 .60086 Mdot
.87738 .60087 Mdot
.87787 .60087 Mdot
.87837 .60086 Mdot
.87887 .60086 Mdot
.87936 .60087 Mdot
.87986 .60087 Mdot
.88036 .60087 Mdot
.88085 .60087 Mdot
.88135 .60086 Mdot
.88185 .60086 Mdot
.88234 .60086 Mdot
.88284 .60086 Mdot
.88334 .60087 Mdot
.88383 .60087 Mdot
.88433 .60086 Mdot
.88483 .60086 Mdot
.88532 .60086 Mdot
.88582 .60086 Mdot
.88632 .60086 Mdot
.88681 .60086 Mdot
.88731 .60086 Mdot
.8878 .60086 Mdot
.8883 .60086 Mdot
.8888 .60086 Mdot
.88929 .60086 Mdot
.88979 .60086 Mdot
.89029 .60086 Mdot
.89078 .60086 Mdot
.89128 .60086 Mdot
.89178 .60086 Mdot
.89227 .60086 Mdot
.89277 .60086 Mdot
.89327 .60086 Mdot
.89376 .60086 Mdot
.89426 .60086 Mdot
.89476 .60086 Mdot
.89525 .60086 Mdot
.89575 .60086 Mdot
.89625 .60086 Mdot
.89674 .60086 Mdot
.89724 .60086 Mdot
.89774 .60086 Mdot
.89823 .60086 Mdot
.89873 .60086 Mdot
.89923 .60086 Mdot
.89972 .60086 Mdot
.90022 .60086 Mdot
.90072 .60086 Mdot
.90121 .60086 Mdot
.90171 .60086 Mdot
.9022 .60086 Mdot
.9027 .60086 Mdot
.9032 .60086 Mdot
.90369 .60086 Mdot
.90419 .60087 Mdot
.90469 .60088 Mdot
.90518 .60088 Mdot
.90568 .60087 Mdot
.90618 .60086 Mdot
.90667 .60086 Mdot
.90717 .60085 Mdot
.90767 .60085 Mdot
.90816 .60085 Mdot
.90866 .60086 Mdot
.90916 .60086 Mdot
.90965 .60086 Mdot
.91015 .60086 Mdot
.91065 .60086 Mdot
.91114 .60086 Mdot
.91164 .60085 Mdot
.91214 .60085 Mdot
.91263 .60084 Mdot
.91313 .60085 Mdot
.91363 .60085 Mdot
.91412 .60086 Mdot
.91462 .60086 Mdot
.91511 .60086 Mdot
.91561 .60086 Mdot
.91611 .60086 Mdot
.9166 .60087 Mdot
.9171 .60087 Mdot
.9176 .60086 Mdot
.91809 .60086 Mdot
.91859 .60086 Mdot
.91909 .60086 Mdot
.91958 .60086 Mdot
.92008 .60085 Mdot
.92058 .60085 Mdot
.92107 .60086 Mdot
.92157 .60086 Mdot
.92207 .60086 Mdot
.92256 .60086 Mdot
.92306 .60086 Mdot
.92356 .60086 Mdot
.92405 .60085 Mdot
.92455 .60084 Mdot
.92505 .60085 Mdot
.92554 .60085 Mdot
.92604 .60086 Mdot
.92654 .60087 Mdot
.92703 .60087 Mdot
.92753 .60086 Mdot
.92803 .60086 Mdot
.92852 .60086 Mdot
.92902 .60087 Mdot
.92951 .60086 Mdot
.93001 .60086 Mdot
.93051 .60086 Mdot
.931 .60086 Mdot
.9315 .60086 Mdot
.932 .60085 Mdot
.93249 .60085 Mdot
.93299 .60086 Mdot
.93349 .60086 Mdot
.93398 .60086 Mdot
.93448 .60086 Mdot
.93498 .60086 Mdot
.93547 .60086 Mdot
.93597 .60086 Mdot
.93647 .60087 Mdot
.93696 .60087 Mdot
.93746 .60087 Mdot
.93796 .60087 Mdot
.93845 .60087 Mdot
.93895 .60087 Mdot
.93945 .60086 Mdot
.93994 .60086 Mdot
.94044 .60086 Mdot
.94094 .60087 Mdot
.94143 .60084 Mdot
.94193 .60085 Mdot
.94243 .60086 Mdot
.94292 .60085 Mdot
.94342 .60085 Mdot
.94391 .60086 Mdot
.94441 .60086 Mdot
.94491 .60087 Mdot
.9454 .60086 Mdot
.9459 .60087 Mdot
.9464 .60087 Mdot
.94689 .60086 Mdot
.94739 .60085 Mdot
.94789 .60086 Mdot
.94838 .60086 Mdot
.94888 .60086 Mdot
.94938 .60087 Mdot
.94987 .60086 Mdot
.95037 .60086 Mdot
.95087 .60086 Mdot
.95136 .60086 Mdot
.95186 .60087 Mdot
.95236 .60087 Mdot
.95285 .60087 Mdot
.95335 .60086 Mdot
.95385 .60086 Mdot
.95434 .60086 Mdot
.95484 .60085 Mdot
.95534 .60085 Mdot
.95583 .60085 Mdot
.95633 .60085 Mdot
.95683 .60087 Mdot
.95732 .60086 Mdot
.95782 .60085 Mdot
.95831 .60083 Mdot
.95881 .60085 Mdot
.95931 .60086 Mdot
.9598 .60085 Mdot
.9603 .60085 Mdot
.9608 .60084 Mdot
.96129 .60084 Mdot
.96179 .60085 Mdot
.96229 .60085 Mdot
.96278 .60085 Mdot
.96328 .60086 Mdot
.96378 .60086 Mdot
.96427 .60086 Mdot
.96477 .60087 Mdot
.96527 .60086 Mdot
.96576 .60086 Mdot
.96626 .60086 Mdot
.96676 .60085 Mdot
.96725 .60084 Mdot
.96775 .60086 Mdot
.96825 .60087 Mdot
.96874 .60087 Mdot
.96924 .60086 Mdot
.96974 .60087 Mdot
.97023 .60086 Mdot
.97073 .60086 Mdot
.97122 .60085 Mdot
.97172 .60086 Mdot
.97222 .60086 Mdot
.97271 .60087 Mdot
.97321 .60087 Mdot
.97371 .60085 Mdot
.9742 .60084 Mdot
.9747 .60084 Mdot
.9752 .60084 Mdot
.97569 .60084 Mdot
.97619 .60084 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[218]:=",
  ImageSize->{433, 267.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a00012aP00`40o`000?l0003ooooook;oool0
0?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooook;oool0
0?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo000^oooo00<0003oooooool0oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000
o`0000000?oooon1oooo000^oooo0ol00?oooon1oooo000^oooo00<0003o003oool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool000coool500000_ooo`030000oooooooo
00;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo00<0003oooooool0oooooh7oool000koool01`000?ooooooooooo`000?ooo`000002
oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool0
00001Oooo`030000oooooooo0?oooon1oooo0008oooo0`0000?oool01`000?ooooooooooo`000?oo
o`000002oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0
003oool000001Oooo`@0003oooooP?ooo`003_ooo`070000oooooooooooo0000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000005
oooo00<0003oooooool0oooooh7oool000koool01`000?ooooooooooo`000?ooo`000002oooo00<0
003oool000000_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001Ooo
o`030000oooooooo0?oooon1oooo000=oooo0P0000Coool00`000?ooooooo`02oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool30000oooooh7oool002koool00`000?ooooooo`3oooooPOoo
o`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`<0003oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo0`000?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOoo
o`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`004oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0oooo
oh7oool001;oool00`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool000001Oooo`030000oooooooo0?oooon1oooo000=oooo0`00
00;oool00`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?oo
o`000002oooo00<0003oool000001Oooo`@0003oooooP?ooo`004oooo`070000oooooooooooo0000
oooo000000;oool00`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000Goool0
0`000?ooooooo`3oooooPOooo`004_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0
003oool000000_ooo`030000oooo000000;oool00`000?ooo`000005oooo00<0003oooooool0oooo
oh7oool001?oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOoo
o`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`<0003oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?oo
ooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo0`000?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool30000oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`030000oooooooo0?oooon1oooo000Boooo0P0000Coool00`000?ooooooo`02oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0oooooh7oool0
01;oool00`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?oo
o`000002oooo00<0003oool000001Oooo`030000oooooooo0?oooon1oooo000=oooo0`0000;oool0
0`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000;oool00`000?ooo`000002
oooo00<0003oool000001Oooo`@0003oooooP?ooo`004_ooo`800003oooo00<0003oool000000_oo
o`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001Oooo`030000oooooooo
0?oooon1oooo000Boooo00<0003oooooool00_ooo`030000oooo000000;oool00`000?ooo`000002
oooo00<0003oool000000_ooo`030000oooo000000Goool00`000?ooooooo`3oooooPOooo`004ooo
o`800003oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool30000oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?oo
ooooo`3oooooPOooo`00;_ooo`<0003oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo0`00
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOoo
o`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`004oooo`<00002oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo0?oooon1oooo000Doooo00H0003oooooool0003oool00002oooo00<0003oool000000_oo
o`030000oooo000000;oool00`000?ooo`000005oooo00<0003oooooool0oooooh7oool000goool3
00000_ooo`@000001?ooo`000?ooo`0000;oool00`000?ooo`000002oooo00<0003oool000000_oo
o`030000oooo000000Goool40000oooooh3oool001;oool00`000?ooo`000002oooo00<0003oool0
00000_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001Oooo`030000
oooooooo0?oooon1oooo000Coooo0P0000;oool00`000?ooo`000002oooo00<0003oool000000_oo
o`030000oooo000000;oool00`000?ooo`000005oooo00<0003oooooool0oooooh7oool001Coool0
1@000?ooooooooooo`000004oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?oo
ooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`<0003oooooPOooo`00;_ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo0`000?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool30000oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000Boooo0`0000?oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool0oooooh7oool001;oool00`000?ooooooo`02oooo00<0003oool000000_ooo`030000oooo0000
00;oool00`000?ooo`000002oooo00<0003oool000001Oooo`030000oooooooo0?oooon1oooo000=
oooo0`0000?oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo000000;oool00`000?ooo`000005oooo10000?oooon0oooo000Coooo00L0003oooooooooool0
003oool000000_ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0003oool000001Ooo
o`030000oooooooo0?oooon1oooo000Boooo00<0003oool000000_ooo`030000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool000000_ooo`030000oooo000000Goool00`000?ooooooo`3o
ooooPOooo`004oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool00_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1
oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_oo
o`<0003oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooo
oh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^
oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000
oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3o
ooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo0`000?oooon1oooo000^oooo00<0
003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo
0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool00`000?ooooooo`3oooooPOoo
o`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo05[oool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo053oool500000_ooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo00<0003oooooool0C_ooo`D00002oooo00<0003oooooool00_ooo`030000oooooooo
00;oool00`000?ooooooo`1Coooo000^oooo00<0003oooooool0FOooo`030000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool00000Doooo`070000oooooooooooo0000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool00000DOooo`070000oooooooooooo0000oooo000000;oool0
0`000?ooo`000002oooo00<0003oool00000E?ooo`00;_ooo`<0001Koooo00H0003oooooool0003o
ool00002oooo00<0003oool00000Doooo`070000oooooooooooo0000oooo000000;oool00`000?oo
o`000002oooo00<0003oool00000DOooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`00
00;oool00`000?ooo`00001Doooo000^oooo00<0003oooooool0FOooo`800003oooo00<0003oool0
00000_ooo`030000oooo000005?oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
00000_ooo`030000oooo0000057oool010000?ooooooooooo`800003oooo00<0003oool000000_oo
o`030000oooo000005Coool002koool00`000?ooooooo`1Ioooo00<0003oooooool00_ooo`030000
oooo000000;oool00`000?ooo`00001Coooo00L0003oooooooooool0003oool000000_ooo`030000
oooo000000;oool00`000?ooo`00001Aoooo00D0003oooooooooool000001?ooo`030000oooo0000
00;oool00`000?ooo`00001Doooo000^oooo00<0003oooooool0FOooo`<00003oooo00<0003ooooo
ool00_ooo`030000oooooooo057oool200001?ooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool0Coooo`800003oooo0`0000?oool00`000?ooooooo`02oooo00<0003ooooo
ool0Doooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003oooooool0oooooh7oool0
02koool00`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0
003oooooool0ooooobCoool00ol00?ooooooo`1Joooo000^oooo00<0003oooooool0ooooob?oool3
o`006oooo`03o`00oooooooo03goool002koool00`000?l00?l0001lo`0000?ooooo003o00002?l0
0003ooooo`00o`0005Go0003oooo>Ol00003ooooo`00o`0000_o00000oooool00?l00004o`0000?o
oooo003o00001_l000Cooolio`002_ooo`009Oooo`T0003oo`00Nol000T0000002koool00`000?l0
0?l0003oo`00Mol000[oool002koool00`000?ooooooo`0Aoooo00<0003oooooool04Oooo`030000
oooooooo013oool00`000?ooooooo`03oooo0_l00003ooooo`00oooo00Woool00ol00?ooooooo`0=
oooo00Go003oooooool0003oool00_l000Goool2o`001oooo`03o`00oooo000000Ooool2o`002Ooo
o`030000o`00oooo00Coool00ol00?ooooooo`09oooo0_l000Goool00ol00?ooooooo`0;oooo00<0
003oooooool04?ooo`030000oooooooo00Coool01?l00?ooool00?l000Coool00ol00?ooooooo`02
oooo00<0003oooooool01oooo`?o0004oooo00?o003oool000004oooo`040000ooooo`00o`001?oo
o`03o`00oooooooo00?oool00ol00?ooooooo`02oooo00Co0000003oooooool2o`001Oooo`?o0006
oooo00<0003oooooool00oooo`Co0002oooo0ol000Goool00`000?l00?l00004o`003?ooo`030000
oooooooo017oool00`000?ooooooo`0@oooo00<0003oooooool03?ooo`00;_ooo`030000oooooooo
05ooool00`000?ooooooo`1Ooooo00<0003oooooool0Goooo`030000oooooooo05[oool002koool0
0`000?ooooooo`3oooooPOooo`00;_ooo`030000oooooooo0?oooon1oooo000^oooo00<0003ooooo
ool0oooooh7oool002koool00`000?ooooooo`3oooooPOooo`00oooook;oool00?oooonboooo003o
oooo/_ooo`00oooook;oool00?oooonboooo003ooooo/_ooo`00oooook;oool00?oooonboooo003o
oooo/_ooo`00oooook;oool00?oooonboooo0000\
\>"],
  ImageRangeCache->{{{0, 432}, {266.5, 0}} -> {-239.729, -112324, 5.10808, 
  452.346}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->"RulerBar",
WindowSize->{762, 559},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 107, 2, 96, "Title"],
Cell[1841, 55, 78, 0, 37, "Subsubsection"],

Cell[CellGroupData[{
Cell[1944, 59, 32, 0, 85, "Section"],

Cell[CellGroupData[{
Cell[2001, 63, 41, 0, 40, "Subsection"],
Cell[2045, 65, 75, 0, 31, "MathCaption"],
Cell[2123, 67, 80, 2, 30, "Input"],
Cell[2206, 71, 46, 0, 31, "MathCaption"],
Cell[2255, 73, 93, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2385, 80, 57, 0, 40, "Subsection"],
Cell[2445, 82, 106, 2, 30, "Input"],
Cell[2554, 86, 127, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2718, 94, 76, 0, 40, "Subsection"],
Cell[2797, 96, 120, 2, 31, "MathCaption"],
Cell[2920, 100, 162, 5, 30, "Input"],
Cell[3085, 107, 83, 1, 31, "MathCaption"],
Cell[3171, 110, 163, 5, 30, "Input"],
Cell[3337, 117, 44, 0, 31, "MathCaption"],
Cell[3384, 119, 272, 8, 50, "Input"],
Cell[3659, 129, 113, 2, 31, "MathCaption"],
Cell[3775, 133, 172, 5, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3984, 143, 55, 0, 40, "Subsection"],
Cell[4042, 145, 46, 0, 31, "MathCaption"],
Cell[4091, 147, 131, 3, 67, "Input"],
Cell[4225, 152, 105, 2, 31, "MathCaption"],
Cell[4333, 156, 100, 2, 36, "Input"],
Cell[4436, 160, 53, 0, 31, "MathCaption"],
Cell[4492, 162, 147, 4, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4688, 172, 76, 0, 85, "Section"],
Cell[4767, 174, 54, 0, 31, "MathCaption"],
Cell[4824, 176, 719, 14, 255, "Input"],
Cell[5546, 192, 65, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5636, 196, 614, 10, 250, "Input"],
Cell[6253, 208, 295, 7, 28, "Message"]
}, Open  ]],
Cell[6563, 218, 75, 0, 31, "MathCaption"],
Cell[6641, 220, 301, 6, 150, "Input"],
Cell[6945, 228, 66, 0, 31, "MathCaption"],
Cell[7014, 230, 654, 13, 250, "Input"],
Cell[7671, 245, 113, 2, 31, "MathCaption"],
Cell[7787, 249, 551, 10, 168, "Input"],
Cell[8341, 261, 88, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[8454, 266, 377, 7, 247, "Input"],
Cell[8834, 275, 288, 6, 28, "Message"]
}, Open  ]],
Cell[9137, 284, 115, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[9277, 290, 986, 19, 285, "Input"],
Cell[10266, 311, 290, 6, 28, "Message"]
}, Open  ]],
Cell[10571, 320, 53, 0, 31, "MathCaption"],
Cell[10627, 322, 1083, 21, 273, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11747, 348, 29, 0, 85, "Section"],
Cell[11779, 350, 117, 2, 31, "MathCaption"],
Cell[11899, 354, 86, 2, 30, "Input"],
Cell[11988, 358, 75, 0, 31, "MathCaption"],
Cell[12066, 360, 86, 2, 30, "Input"],
Cell[12155, 364, 128, 2, 31, "MathCaption"],
Cell[12286, 368, 133, 3, 30, "Input"],
Cell[12422, 373, 228, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12687, 382, 56, 0, 85, "Section"],
Cell[12746, 384, 400, 8, 73, "Input"],

Cell[CellGroupData[{
Cell[13171, 396, 169, 3, 30, "Input"],
Cell[13343, 401, 149885, 3744, 276, 34955, 2320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163265, 4150, 2728, 51, 370, "Input"],
Cell[165996, 4203, 288, 6, 28, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166321, 4214, 169, 3, 30, "Input"],
Cell[166493, 4219, 122672, 3408, 276, 34955, 2320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[289180, 7630, 43, 0, 31, "MathCaption"],
Cell[289226, 7632, 95, 2, 33, "Input"],
Cell[289324, 7636, 40, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[289389, 7640, 178, 3, 50, "Input"],
Cell[289570, 7645, 238962, 4515, 272, 26134, 1882, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[528547, 12163, 47, 0, 31, "MathCaption"],
Cell[528597, 12165, 178, 4, 30, "Input"],
Cell[528778, 12171, 57, 0, 31, "MathCaption"],
Cell[528838, 12173, 264, 5, 30, "Input"],
Cell[529105, 12180, 334, 7, 110, "Input"],
Cell[529442, 12189, 72, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[529539, 12193, 180, 4, 52, "Input"],
Cell[529722, 12199, 78, 2, 24, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[529849, 12207, 65, 0, 85, "Section"],
Cell[529917, 12209, 107, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[530049, 12215, 967, 20, 306, "Input"],
Cell[531019, 12237, 268, 6, 28, "Message"]
}, Open  ]],
Cell[531302, 12246, 70, 0, 31, "MathCaption"],
Cell[531375, 12248, 95, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[531507, 12255, 39, 0, 85, "Section"],
Cell[531549, 12257, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[531656, 12262, 312, 6, 150, "Input"],
Cell[531971, 12270, 289, 6, 28, "Message"],
Cell[532263, 12278, 290, 6, 28, "Message"]
}, Open  ]],
Cell[532568, 12287, 130, 2, 31, "MathCaption"],
Cell[532701, 12291, 99, 2, 30, "Input"],
Cell[532803, 12295, 151, 2, 31, "MathCaption"],
Cell[532957, 12299, 107, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[533089, 12305, 87, 2, 30, "Input"],
Cell[533179, 12309, 437603, 8432, 360, 221259, 5756, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[970797, 20744, 64, 0, 31, "MathCaption"],
Cell[970864, 20746, 984, 20, 230, "Input"],
Cell[971851, 20768, 44, 0, 31, "MathCaption"],
Cell[971898, 20770, 140, 3, 50, "Input"],
Cell[972041, 20775, 206, 5, 42, "Input"],
Cell[972250, 20782, 94, 2, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[972381, 20789, 42, 0, 85, "Section"],
Cell[972426, 20791, 55, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[972506, 20795, 287, 6, 66, "Input"],
Cell[972796, 20803, 24944, 732, 271, 6207, 495, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[997789, 21541, 71, 0, 85, "Section"],
Cell[997863, 21543, 224, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[998112, 21553, 1722, 31, 401, "Input"],
Cell[999837, 21586, 268, 6, 28, "Message"],
Cell[1000108, 21594, 268, 6, 28, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000413, 21605, 199, 4, 50, "Input"],
Cell[1000615, 21611, 56230, 2461, 186, 40176, 2258, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1056894, 24078, 59, 0, 85, "Section"],
Cell[1056956, 24080, 44, 0, 31, "MathCaption"],
Cell[1057003, 24082, 321, 8, 105, "Input"],

Cell[CellGroupData[{
Cell[1057349, 24094, 117, 2, 30, "Input"],
Cell[1057469, 24098, 64042, 2690, 276, 41933, 2412, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1121560, 26794, 64, 0, 85, "Section"],

Cell[CellGroupData[{
Cell[1121649, 26798, 115, 2, 30, "Input"],
Cell[1121767, 26802, 86, 2, 24, "Output"]
}, Open  ]],
Cell[1121868, 26807, 98, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[1121991, 26813, 90, 2, 30, "Input"],
Cell[1122084, 26817, 97, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1122218, 26824, 152, 3, 30, "Input"],
Cell[1122373, 26829, 53291, 2296, 276, 38893, 2113, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

