(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3361410,      75451]*)
(*NotebookOutlinePosition[   3362059,      75474]*)
(*  CellTagsIndexPosition[   3362015,      75470]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pitch tracking based on short-time processing", "Title"],

Cell[CellGroupData[{

Cell["Include libraries", "Section"],

Cell[BoxData[{
    \(<< Miscellaneous`Audio`\), 
    \(<< SignalProcessing`Master`\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Signal Processing Function Definitions", "Section"],

Cell[CellGroupData[{

Cell["Windowing", "Subsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Windowing", "=", 
        RowBox[{"Function", "[", 
          RowBox[{"z", ",", "\n", "\t\t", 
            RowBox[{
              RowBox[{"window", "=", 
                RowBox[{"N", "[", 
                  RowBox[{"Table", "[", 
                    RowBox[{
                      RowBox[{"DiscreteWindow", "[", 
                        RowBox[{
                          StyleBox["Blackman",
                            FontColor->RGBColor[1, 0, 0]], ",", "WindowSize", 
                          ",", "winn"}], "]"}], ",", 
                      \({winn, 0, WindowSize - 1}\)}], "]"}], "]"}]}], ";", 
              "\n", "\t\t", \(output = {}\), ";", "\n", "\t\t", 
              \(For[winx = 1, \ winx <= Length[window], \(winx++\), \n\t\t\t
                output = 
                  Append[output, 
                    z\[LeftDoubleBracket]winx\[RightDoubleBracket]*
                      window\[LeftDoubleBracket]winx\[RightDoubleBracket]]]
                \), ";", "\n", "\t\t", "output"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spectrum calculation", "Subsection"],

Cell[BoxData[
    \(\(Spectrum = Function[specx, Abs[Fourier[Windowing[specx]]]]; \)\)], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cepstrum calculation", "Subsection"],

Cell[BoxData[
    \(\(Cepstrum = 
      Function[cepsx, \n\t\tcepsy = Log[Spectrum[cepsx]]; \n\t\t
        cepsy = Flatten[{
              Table[cepsy\[LeftDoubleBracket]cepsn\[RightDoubleBracket], {
                  cepsn, \ WindowSize/2 + 1, \ WindowSize}], \n\t\t\t\t
              Table[cepsy\[LeftDoubleBracket]cepsn\[RightDoubleBracket], {
                  cepsn, \ WindowSize/2}]}]; \n\t\tAbs[Fourier[cepsy]]\n\t]; 
    \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pitch tracking procedure", "Subsection"],

Cell[BoxData[
    \(\(Track = 
      Function[trackdata, \ntrackminceps = Floor[SmpRate/MaxPitch]; \n
        trackmaxceps = Ceiling[SmpRate/MinPitch]; \ntrackCepsPack = {}; \n\t\t
        For[trackx = 1, trackx <= Length[trackdata] - WindowSize*Overlap, 
          trackx = trackx + WindowSize - WindowSize*Overlap, \n\t\t\t
          trackblock = {}; \n\t\t\t
          For[tracky = 0, tracky < WindowSize, \(tracky++\), \n\t\t\t\t
            If[trackx + tracky > Length[trackdata], \n\t\t\t\t\t
              trackblock = Append[trackblock, 0], \n\t\t\t\t\t
              trackblock = 
                Append[trackblock, 
                  trackdata
                    \[LeftDoubleBracket]trackx + tracky
                      \[RightDoubleBracket]]]]; \n\t\t\t
          trackCeps = Cepstrum[trackblock]; \n\t\t\t
          trackCeps = 
            Table[trackCeps\[LeftDoubleBracket]tracki\[RightDoubleBracket], {
                tracki, trackminceps, \ trackmaxceps}]; \n\t\t\t
          trackCepsPack = Append[trackCepsPack, trackCeps]; \n\t\t]; \n\t\t\ 
        trackCepsPack\n]; \)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Signal acquisition", "Section"],

Cell[BoxData[
    \(\(SetDirectory["\<D:\\Mathematica\\Data\\\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"snd", "=", 
        RowBox[{"ReadSoundfile", "[", 
          RowBox[{
            StyleBox["\"\<square.wav\>\"",
              FontColor->GrayLevel[0]], 
            StyleBox[",",
              FontColor->GrayLevel[0]], " ", \(PrintHeader -> True\)}], 
          "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("Format: "\[InvisibleSpace]"Microsoft PCM WAVE RIFF"\),
      SequenceForm[ "Format: ", "Microsoft PCM WAVE RIFF"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Duration: "\[InvisibleSpace]7.71151927437641759`
        \[InvisibleSpace]" seconds"\),
      SequenceForm[ "Duration: ", 7.7115192743764176, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Channels: "\[InvisibleSpace]1\),
      SequenceForm[ "Channels: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Sampling rate: "\[InvisibleSpace]22050\),
      SequenceForm[ "Sampling rate: ", 22050],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Bits per sample: "\[InvisibleSpace]16\),
      SequenceForm[ "Bits per sample: ", 16],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Data size: "\[InvisibleSpace]340078\[InvisibleSpace]" bytes"\),
      SequenceForm[ "Data size: ", 340078, " bytes"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of samples: "\[InvisibleSpace]170039\),
      SequenceForm[ "Number of samples: ", 170039],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Additional Definitions", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{"SmpRate", "=", 
        StyleBox["22050",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"WindowSize", "=", 
        StyleBox["1024",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"Overlap", "=", 
        StyleBox[\(1\/2\),
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"MinPitch", "=", 
        StyleBox["200",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"MaxPitch", "=", 
        StyleBox["2000",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input"]
}, Open  ]],

Cell["Computations", "Section"],

Cell[CellGroupData[{

Cell["Temporary calculations", "Section"],

Cell[BoxData[
    \(\(res = Track[snd]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[res, \ PlotRange -> {5, 25}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.13993 .20196 -11.949 -9 ]
[.13993 .20196 .05101 0 ]
[.26378 .15323 -11.4486 -9 ]
[.26378 .15323 .55139 0 ]
[.39379 .1021 -10.9482 -9 ]
[.39379 .1021 1.05177 0 ]
[.53041 .04839 -10.4479 -9 ]
[.53041 .04839 1.55215 0 ]
[.67417 -0.00808 -14.9212 -9 ]
[.67417 -0.00808 3.0788 0 ]
[.79819 .1441 0 -6.11633 ]
[.79819 .1441 18 2.88367 ]
[.88401 .27552 0 -5.99172 ]
[.88401 .27552 18 3.00828 ]
[.95959 .39127 0 -5.88495 ]
[.95959 .39127 18 3.11505 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -12 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -12 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.14917 .21128 m
.15379 .21594 L
s
[(20)] .13993 .20196 .9915 1 Mshowa
.2726 .16294 m
.27702 .1678 L
s
[(40)] .26378 .15323 .9081 1 Mshowa
.40214 .11222 m
.40631 .11729 L
s
[(60)] .39379 .1021 .82471 1 Mshowa
.53823 .05894 m
.54213 .06421 L
s
[(80)] .53041 .04839 .74131 1 Mshowa
.68138 .00288 m
.68499 .00836 L
s
[(100)] .67417 -0.00808 .65791 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.0896 .2346 m
.09243 .23734 L
s
.11921 .22301 m
.12201 .22578 L
s
.17948 .19941 m
.18222 .20223 L
s
.21015 .1874 m
.21286 .19025 L
s
.24119 .17525 m
.24387 .17813 L
s
.3044 .15049 m
.30701 .15344 L
s
.33658 .13789 m
.33916 .14087 L
s
.36916 .12514 m
.3717 .12814 L
s
.43553 .09915 m
.43799 .10222 L
s
.46933 .08591 m
.47176 .08901 L
s
.50356 .07251 m
.50595 .07564 L
s
.57333 .04519 m
.57563 .04838 L
s
.60889 .03127 m
.61114 .03449 L
s
.6449 .01716 m
.64711 .02042 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78584 .14853 m
.77966 .15075 L
s
[(100)] .79819 .1441 -1 .35919 Mshowa
.87155 .27965 m
.86533 .28171 L
s
[(200)] .88401 .27552 -1 .33149 Mshowa
.94705 .39513 m
.94078 .39706 L
s
[(300)] .95959 .39127 -1 .30777 Mshowa
.125 Mabswid
.70844 .03014 m
.70476 .03155 L
s
.72861 .06099 m
.72493 .06238 L
s
.74821 .09098 m
.74452 .09235 L
s
.76728 .12015 m
.76359 .1215 L
s
.8039 .17616 m
.80018 .17747 L
s
.82148 .20305 m
.81776 .20434 L
s
.8386 .22925 m
.83488 .23052 L
s
.85529 .25477 m
.85156 .25603 L
s
.88741 .3039 m
.88367 .30512 L
s
.90287 .32755 m
.89912 .32876 L
s
.91796 .35063 m
.91421 .35182 L
s
.93268 .37315 m
.92892 .37432 L
s
.96109 .4166 m
.95732 .41774 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(5)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(15)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(20)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(25)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .907 r
.40437 .59809 .40529 .59895 .4104 .59741 .40948 .59655 Metetra
.664 .741 .907 r
.40948 .59655 .4104 .59741 .41552 .59587 .4146 .59501 Metetra
.664 .741 .907 r
.4146 .59501 .41552 .59587 .42065 .59433 .41974 .59347 Metetra
.664 .741 .907 r
.41974 .59347 .42065 .59433 .42579 .59278 .42488 .59192 Metetra
.664 .741 .907 r
.42488 .59192 .42579 .59278 .43094 .59123 .43003 .59037 Metetra
.664 .741 .907 r
.43003 .59037 .43094 .59123 .4361 .58968 .43519 .58881 Metetra
.664 .741 .907 r
.43519 .58881 .4361 .58968 .44126 .58812 .44036 .58726 Metetra
.664 .741 .907 r
.44036 .58726 .44126 .58812 .44644 .58657 .44554 .5857 Metetra
.664 .741 .907 r
.44554 .5857 .44644 .58657 .45163 .58501 .45073 .58413 Metetra
.664 .741 .907 r
.45073 .58413 .45163 .58501 .45683 .58344 .45593 .58257 Metetra
.664 .741 .907 r
.45593 .58257 .45683 .58344 .46204 .58187 .46114 .581 Metetra
.664 .741 .907 r
.46114 .581 .46204 .58187 .46726 .5803 .46636 .57943 Metetra
.664 .741 .907 r
.46636 .57943 .46726 .5803 .47249 .57873 .47159 .57785 Metetra
.664 .741 .907 r
.47159 .57785 .47249 .57873 .47773 .57715 .47683 .57627 Metetra
.664 .741 .907 r
.47683 .57627 .47773 .57715 .48297 .57558 .48209 .57469 Metetra
.664 .741 .907 r
.48209 .57469 .48297 .57558 .48823 .57399 .48735 .57311 Metetra
.664 .741 .907 r
.48735 .57311 .48823 .57399 .4935 .57241 .49262 .57152 Metetra
.664 .741 .907 r
.49262 .57152 .4935 .57241 .49878 .57082 .4979 .56993 Metetra
.664 .741 .907 r
.4979 .56993 .49878 .57082 .50407 .56923 .50319 .56834 Metetra
.664 .741 .907 r
.50319 .56834 .50407 .56923 .50937 .56763 .50849 .56674 Metetra
.664 .741 .907 r
.50849 .56674 .50937 .56763 .51468 .56604 .5138 .56514 Metetra
.664 .741 .907 r
.5138 .56514 .51468 .56604 .52 .56443 .51913 .56354 Metetra
.664 .741 .907 r
.51913 .56354 .52 .56443 .52533 .56283 .52446 .56194 Metetra
.664 .741 .907 r
.52446 .56194 .52533 .56283 .53067 .56122 .5298 .56033 Metetra
.664 .741 .907 r
.5298 .56033 .53067 .56122 .53602 .55961 .53515 .55871 Metetra
.664 .741 .907 r
.53515 .55871 .53602 .55961 .54139 .558 .54052 .5571 Metetra
.664 .741 .907 r
.54052 .5571 .54139 .558 .54676 .55638 .54589 .55548 Metetra
.664 .741 .907 r
.54589 .55548 .54676 .55638 .55214 .55477 .55128 .55386 Metetra
.664 .741 .907 r
.55128 .55386 .55214 .55477 .55753 .55314 .55667 .55224 Metetra
.664 .741 .907 r
.55667 .55224 .55753 .55314 .56294 .55152 .56208 .55061 Metetra
.664 .741 .907 r
.56208 .55061 .56294 .55152 .56835 .54989 .56749 .54898 Metetra
.664 .741 .907 r
.56749 .54898 .56835 .54989 .57378 .54826 .57292 .54734 Metetra
.664 .741 .907 r
.57292 .54734 .57378 .54826 .57921 .54662 .57836 .54571 Metetra
.664 .741 .907 r
.57836 .54571 .57921 .54662 .58466 .54498 .58381 .54407 Metetra
.664 .741 .907 r
.58381 .54407 .58466 .54498 .59011 .54334 .58927 .54242 Metetra
.664 .741 .907 r
.58927 .54242 .59011 .54334 .59558 .54169 .59474 .54078 Metetra
.664 .741 .907 r
.59474 .54078 .59558 .54169 .60106 .54005 .60022 .53913 Metetra
.664 .741 .907 r
.60022 .53913 .60106 .54005 .60655 .53839 .60571 .53747 Metetra
.664 .741 .907 r
.60571 .53747 .60655 .53839 .61205 .53674 .61121 .53582 Metetra
.664 .741 .907 r
.61121 .53582 .61205 .53674 .61756 .53508 .61672 .53416 Metetra
.664 .741 .907 r
.61672 .53416 .61756 .53508 .62308 .53342 .62225 .53249 Metetra
.664 .741 .907 r
.62225 .53249 .62308 .53342 .62861 .53176 .62778 .53083 Metetra
.664 .741 .907 r
.62778 .53083 .62861 .53176 .63416 .53009 .63333 .52916 Metetra
.664 .741 .907 r
.63333 .52916 .63416 .53009 .63971 .52842 .63888 .52748 Metetra
.664 .741 .907 r
.63888 .52748 .63971 .52842 .64528 .52674 .64445 .52581 Metetra
.664 .741 .907 r
.64445 .52581 .64528 .52674 .65085 .52506 .65003 .52413 Metetra
.664 .741 .907 r
.65003 .52413 .65085 .52506 .65644 .52338 .65562 .52244 Metetra
.664 .741 .907 r
.65562 .52244 .65644 .52338 .66204 .5217 .66122 .52076 Metetra
.664 .741 .907 r
.66122 .52076 .66204 .5217 .66765 .52001 .66683 .51907 Metetra
.664 .741 .907 r
.66683 .51907 .66765 .52001 .67327 .51832 .67246 .51738 Metetra
.664 .741 .907 r
.67246 .51738 .67327 .51832 .6789 .51663 .67809 .51568 Metetra
.664 .741 .907 r
.67809 .51568 .6789 .51663 .68455 .51493 .68374 .51398 Metetra
.664 .741 .907 r
.68374 .51398 .68455 .51493 .6902 .51323 .68939 .51228 Metetra
.664 .741 .907 r
.68939 .51228 .6902 .51323 .69587 .51152 .69506 .51057 Metetra
.664 .741 .907 r
.69506 .51057 .69587 .51152 .70154 .50981 .70074 .50886 Metetra
.664 .741 .907 r
.70074 .50886 .70154 .50981 .70723 .5081 .70643 .50715 Metetra
.664 .741 .907 r
.70643 .50715 .70723 .5081 .71293 .50639 .71214 .50543 Metetra
.664 .741 .907 r
.71214 .50543 .71293 .50639 .71864 .50467 .71785 .50371 Metetra
.664 .741 .907 r
.71785 .50371 .71864 .50467 .72437 .50295 .72357 .50198 Metetra
.664 .741 .907 r
.72357 .50198 .72437 .50295 .7301 .50122 .72931 .50026 Metetra
.664 .741 .907 r
.72931 .50026 .7301 .50122 .73585 .49949 .73506 .49853 Metetra
.664 .741 .907 r
.73506 .49853 .73585 .49949 .74161 .49776 .74082 .49679 Metetra
.664 .741 .907 r
.74082 .49679 .74161 .49776 .74738 .49602 .74659 .49505 Metetra
.664 .741 .907 r
.74659 .49505 .74738 .49602 .75316 .49428 .75238 .49331 Metetra
.664 .741 .907 r
.75238 .49331 .75316 .49428 .75895 .49254 .75817 .49157 Metetra
.664 .741 .907 r
.75817 .49157 .75895 .49254 .76475 .49079 .76398 .48982 Metetra
.664 .741 .907 r
.76398 .48982 .76475 .49079 .77057 .48905 .7698 .48807 Metetra
.664 .741 .907 r
.7698 .48807 .77057 .48905 .7764 .48729 .77563 .48631 Metetra
.664 .741 .907 r
.77563 .48631 .7764 .48729 .78224 .48553 .78147 .48455 Metetra
.664 .741 .907 r
.78147 .48455 .78224 .48553 .78809 .48377 .78732 .48279 Metetra
.664 .741 .907 r
.78732 .48279 .78809 .48377 .79395 .48201 .79319 .48102 Metetra
.664 .741 .907 r
.79319 .48102 .79395 .48201 .79983 .48024 .79907 .47925 Metetra
.664 .741 .907 r
.79907 .47925 .79983 .48024 .80572 .47847 .80496 .47748 Metetra
.664 .741 .907 r
.80496 .47748 .80572 .47847 .81162 .4767 .81086 .4757 Metetra
.664 .741 .907 r
.81086 .4757 .81162 .4767 .81753 .47492 .81677 .47392 Metetra
.664 .741 .907 r
.81677 .47392 .81753 .47492 .82345 .47313 .8227 .47214 Metetra
.664 .741 .907 r
.8227 .47214 .82345 .47313 .82939 .47135 .82864 .47035 Metetra
.664 .741 .907 r
.82864 .47035 .82939 .47135 .83534 .46956 .83459 .46856 Metetra
.664 .741 .907 r
.83459 .46856 .83534 .46956 .8413 .46777 .84055 .46676 Metetra
.664 .741 .907 r
.84055 .46676 .8413 .46777 .84727 .46597 .84653 .46496 Metetra
.664 .741 .907 r
.84653 .46496 .84727 .46597 .85325 .46417 .85252 .46316 Metetra
.664 .741 .907 r
.85252 .46316 .85325 .46417 .85925 .46236 .85852 .46136 Metetra
.664 .741 .907 r
.85852 .46136 .85925 .46236 .86526 .46056 .86453 .45955 Metetra
.664 .741 .907 r
.86453 .45955 .86526 .46056 .87128 .45874 .87055 .45773 Metetra
.664 .741 .907 r
.87055 .45773 .87128 .45874 .87732 .45693 .87659 .45591 Metetra
.664 .741 .907 r
.87659 .45591 .87732 .45693 .88336 .45511 .88264 .45409 Metetra
.664 .741 .907 r
.88264 .45409 .88336 .45511 .88942 .45329 .8887 .45227 Metetra
.664 .741 .907 r
.8887 .45227 .88942 .45329 .89549 .45146 .89478 .45044 Metetra
.664 .741 .907 r
.89478 .45044 .89549 .45146 .90158 .44963 .90086 .44861 Metetra
.664 .741 .907 r
.90086 .44861 .90158 .44963 .90767 .44779 .90696 .44677 Metetra
.664 .741 .907 r
.90696 .44677 .90767 .44779 .91378 .44596 .91307 .44493 Metetra
.664 .741 .907 r
.91307 .44493 .91378 .44596 .91991 .44411 .9192 .44308 Metetra
.664 .741 .907 r
.9192 .44308 .91991 .44411 .92604 .44227 .92534 .44124 Metetra
.664 .741 .907 r
.92534 .44124 .92604 .44227 .93219 .44042 .93149 .43938 Metetra
.664 .741 .907 r
.93149 .43938 .93219 .44042 .93835 .43856 .93765 .43753 Metetra
.664 .741 .907 r
.93765 .43753 .93835 .43856 .94452 .43671 .94383 .43567 Metetra
.664 .741 .907 r
.94383 .43567 .94452 .43671 .95071 .43485 .95002 .43381 Metetra
.664 .741 .907 r
.95002 .43381 .95071 .43485 .95691 .43298 .95622 .43194 Metetra
.664 .741 .907 r
.95622 .43194 .95691 .43298 .96312 .43111 .96244 .43007 Metetra
.664 .741 .907 r
.96244 .43007 .96312 .43111 .96935 .42924 .96866 .42819 Metetra
.664 .741 .907 r
.40345 .59723 .40437 .59809 .40948 .59655 .40857 .59569 Metetra
.664 .741 .907 r
.40857 .59569 .40948 .59655 .4146 .59501 .41369 .59415 Metetra
.664 .741 .907 r
.41369 .59415 .4146 .59501 .41974 .59347 .41882 .5926 Metetra
.664 .741 .907 r
.41882 .5926 .41974 .59347 .42488 .59192 .42397 .59105 Metetra
.664 .741 .907 r
.42397 .59105 .42488 .59192 .43003 .59037 .42912 .5895 Metetra
.664 .741 .907 r
.42912 .5895 .43003 .59037 .43519 .58881 .43428 .58794 Metetra
.664 .741 .907 r
.43428 .58794 .43519 .58881 .44036 .58726 .43945 .58639 Metetra
.664 .741 .907 r
.43945 .58639 .44036 .58726 .44554 .5857 .44464 .58482 Metetra
.664 .741 .907 r
.44464 .58482 .44554 .5857 .45073 .58413 .44983 .58326 Metetra
.664 .741 .907 r
.44983 .58326 .45073 .58413 .45593 .58257 .45503 .58169 Metetra
.664 .741 .907 r
.45503 .58169 .45593 .58257 .46114 .581 .46024 .58012 Metetra
.664 .741 .907 r
.46024 .58012 .46114 .581 .46636 .57943 .46547 .57855 Metetra
.664 .741 .907 r
.46547 .57855 .46636 .57943 .47159 .57785 .4707 .57697 Metetra
.664 .741 .907 r
.4707 .57697 .47159 .57785 .47683 .57627 .47594 .57539 Metetra
.664 .741 .907 r
.47594 .57539 .47683 .57627 .48209 .57469 .48119 .57381 Metetra
.664 .741 .907 r
.48119 .57381 .48209 .57469 .48735 .57311 .48646 .57222 Metetra
.664 .741 .907 r
.48646 .57222 .48735 .57311 .49262 .57152 .49173 .57064 Metetra
.664 .741 .907 r
.49173 .57064 .49262 .57152 .4979 .56993 .49701 .56904 Metetra
.664 .741 .907 r
.49701 .56904 .4979 .56993 .50319 .56834 .50231 .56745 Metetra
.664 .741 .907 r
.50231 .56745 .50319 .56834 .50849 .56674 .50761 .56585 Metetra
.664 .741 .907 r
.50761 .56585 .50849 .56674 .5138 .56514 .51292 .56425 Metetra
.664 .741 .907 r
.51292 .56425 .5138 .56514 .51913 .56354 .51825 .56265 Metetra
.664 .741 .907 r
.51825 .56265 .51913 .56354 .52446 .56194 .52358 .56104 Metetra
.664 .741 .907 r
.52358 .56104 .52446 .56194 .5298 .56033 .52893 .55943 Metetra
.664 .741 .907 r
.52893 .55943 .5298 .56033 .53515 .55871 .53428 .55781 Metetra
.664 .741 .907 r
.53428 .55781 .53515 .55871 .54052 .5571 .53965 .5562 Metetra
.664 .741 .907 r
.53965 .5562 .54052 .5571 .54589 .55548 .54503 .55458 Metetra
.664 .741 .907 r
.54503 .55458 .54589 .55548 .55128 .55386 .55041 .55295 Metetra
.664 .741 .907 r
.55041 .55295 .55128 .55386 .55667 .55224 .55581 .55133 Metetra
.664 .741 .907 r
.55581 .55133 .55667 .55224 .56208 .55061 .56122 .5497 Metetra
.664 .741 .907 r
.56122 .5497 .56208 .55061 .56749 .54898 .56664 .54807 Metetra
.664 .741 .907 r
.56664 .54807 .56749 .54898 .57292 .54734 .57207 .54643 Metetra
.664 .741 .907 r
.57207 .54643 .57292 .54734 .57836 .54571 .57751 .54479 Metetra
.664 .741 .907 r
.57751 .54479 .57836 .54571 .58381 .54407 .58296 .54315 Metetra
.664 .741 .907 r
.58296 .54315 .58381 .54407 .58927 .54242 .58842 .5415 Metetra
.664 .741 .907 r
.58842 .5415 .58927 .54242 .59474 .54078 .59389 .53986 Metetra
.664 .741 .907 r
.59389 .53986 .59474 .54078 .60022 .53913 .59937 .5382 Metetra
.664 .741 .907 r
.59937 .5382 .60022 .53913 .60571 .53747 .60486 .53655 Metetra
.664 .741 .907 r
.60486 .53655 .60571 .53747 .61121 .53582 .61037 .53489 Metetra
.664 .741 .907 r
.61037 .53489 .61121 .53582 .61672 .53416 .61588 .53323 Metetra
.664 .741 .907 r
.61588 .53323 .61672 .53416 .62225 .53249 .62141 .53156 Metetra
.664 .741 .907 r
.62141 .53156 .62225 .53249 .62778 .53083 .62695 .5299 Metetra
.664 .741 .907 r
.62695 .5299 .62778 .53083 .63333 .52916 .6325 .52822 Metetra
.664 .741 .907 r
.6325 .52822 .63333 .52916 .63888 .52748 .63805 .52655 Metetra
.664 .741 .907 r
.63805 .52655 .63888 .52748 .64445 .52581 .64362 .52487 Metetra
.664 .741 .907 r
.64362 .52487 .64445 .52581 .65003 .52413 .64921 .52319 Metetra
.664 .741 .907 r
.64921 .52319 .65003 .52413 .65562 .52244 .6548 .5215 Metetra
.664 .741 .907 r
.6548 .5215 .65562 .52244 .66122 .52076 .6604 .51982 Metetra
.664 .741 .907 r
.6604 .51982 .66122 .52076 .66683 .51907 .66601 .51812 Metetra
.664 .741 .907 r
.66601 .51812 .66683 .51907 .67246 .51738 .67164 .51643 Metetra
.664 .741 .907 r
.67164 .51643 .67246 .51738 .67809 .51568 .67728 .51473 Metetra
.664 .741 .907 r
.67728 .51473 .67809 .51568 .68374 .51398 .68293 .51303 Metetra
.664 .741 .907 r
.68293 .51303 .68374 .51398 .68939 .51228 .68858 .51132 Metetra
.664 .741 .907 r
.68858 .51132 .68939 .51228 .69506 .51057 .69426 .50962 Metetra
.664 .741 .907 r
.69426 .50962 .69506 .51057 .70074 .50886 .69994 .5079 Metetra
.664 .741 .907 r
.69994 .5079 .70074 .50886 .70643 .50715 .70563 .50619 Metetra
.664 .741 .907 r
.70563 .50619 .70643 .50715 .71214 .50543 .71134 .50447 Metetra
.664 .741 .907 r
.71134 .50447 .71214 .50543 .71785 .50371 .71705 .50275 Metetra
.664 .741 .907 r
.71705 .50275 .71785 .50371 .72357 .50198 .72278 .50102 Metetra
.664 .741 .907 r
.72278 .50102 .72357 .50198 .72931 .50026 .72852 .49929 Metetra
.664 .741 .907 r
.72852 .49929 .72931 .50026 .73506 .49853 .73427 .49756 Metetra
.664 .741 .907 r
.73427 .49756 .73506 .49853 .74082 .49679 .74003 .49582 Metetra
.664 .741 .907 r
.74003 .49582 .74082 .49679 .74659 .49505 .74581 .49408 Metetra
.664 .741 .907 r
.74581 .49408 .74659 .49505 .75238 .49331 .75159 .49234 Metetra
.664 .741 .907 r
.75159 .49234 .75238 .49331 .75817 .49157 .75739 .49059 Metetra
.664 .741 .907 r
.75739 .49059 .75817 .49157 .76398 .48982 .7632 .48884 Metetra
.664 .741 .907 r
.7632 .48884 .76398 .48982 .7698 .48807 .76902 .48709 Metetra
.664 .741 .907 r
.76902 .48709 .7698 .48807 .77563 .48631 .77486 .48533 Metetra
.664 .741 .907 r
.77486 .48533 .77563 .48631 .78147 .48455 .7807 .48357 Metetra
.664 .741 .907 r
.7807 .48357 .78147 .48455 .78732 .48279 .78656 .48181 Metetra
.664 .741 .907 r
.78656 .48181 .78732 .48279 .79319 .48102 .79243 .48004 Metetra
.664 .741 .907 r
.79243 .48004 .79319 .48102 .79907 .47925 .79831 .47827 Metetra
.664 .741 .907 r
.79831 .47827 .79907 .47925 .80496 .47748 .8042 .47649 Metetra
.664 .741 .907 r
.8042 .47649 .80496 .47748 .81086 .4757 .8101 .47471 Metetra
.664 .741 .907 r
.8101 .47471 .81086 .4757 .81677 .47392 .81602 .47293 Metetra
.664 .741 .907 r
.81602 .47293 .81677 .47392 .8227 .47214 .82195 .47114 Metetra
.664 .741 .907 r
.82195 .47114 .8227 .47214 .82864 .47035 .82789 .46935 Metetra
.664 .741 .907 r
.82789 .46935 .82864 .47035 .83459 .46856 .83384 .46756 Metetra
.664 .741 .907 r
.83384 .46756 .83459 .46856 .84055 .46676 .83981 .46576 Metetra
.664 .741 .907 r
.83981 .46576 .84055 .46676 .84653 .46496 .84579 .46396 Metetra
.664 .741 .907 r
.84579 .46396 .84653 .46496 .85252 .46316 .85178 .46215 Metetra
.664 .741 .907 r
.85178 .46215 .85252 .46316 .85852 .46136 .85778 .46035 Metetra
.664 .741 .907 r
.85778 .46035 .85852 .46136 .86453 .45955 .86379 .45853 Metetra
.664 .741 .907 r
.86379 .45853 .86453 .45955 .87055 .45773 .86982 .45672 Metetra
.664 .741 .907 r
.86982 .45672 .87055 .45773 .87659 .45591 .87586 .4549 Metetra
.664 .741 .907 r
.87586 .4549 .87659 .45591 .88264 .45409 .88191 .45307 Metetra
.664 .741 .907 r
.88191 .45307 .88264 .45409 .8887 .45227 .88798 .45125 Metetra
.664 .741 .907 r
.88798 .45125 .8887 .45227 .89478 .45044 .89406 .44942 Metetra
.664 .741 .907 r
.89406 .44942 .89478 .45044 .90086 .44861 .90015 .44758 Metetra
.664 .741 .907 r
.90015 .44758 .90086 .44861 .90696 .44677 .90625 .44574 Metetra
.664 .741 .907 r
.90625 .44574 .90696 .44677 .91307 .44493 .91236 .4439 Metetra
.664 .741 .907 r
.91236 .4439 .91307 .44493 .9192 .44308 .91849 .44205 Metetra
.664 .741 .907 r
.91849 .44205 .9192 .44308 .92534 .44124 .92463 .4402 Metetra
.664 .741 .907 r
.92463 .4402 .92534 .44124 .93149 .43938 .93079 .43835 Metetra
.664 .741 .907 r
.93079 .43835 .93149 .43938 .93765 .43753 .93695 .43649 Metetra
.664 .741 .907 r
.93695 .43649 .93765 .43753 .94383 .43567 .94313 .43463 Metetra
.664 .741 .907 r
.94313 .43463 .94383 .43567 .95002 .43381 .94932 .43276 Metetra
.664 .741 .907 r
.94932 .43276 .95002 .43381 .95622 .43194 .95553 .4309 Metetra
.664 .741 .907 r
.95553 .4309 .95622 .43194 .96244 .43007 .96175 .42902 Metetra
.664 .741 .907 r
.96175 .42902 .96244 .43007 .96866 .42819 .96798 .42714 Metetra
.664 .741 .907 r
.40253 .59637 .40345 .59723 .40857 .59569 .40765 .59483 Metetra
.664 .741 .907 r
.40765 .59483 .40857 .59569 .41369 .59415 .41277 .59329 Metetra
.664 .741 .907 r
.41277 .59329 .41369 .59415 .41882 .5926 .41791 .59174 Metetra
.664 .741 .907 r
.41791 .59174 .41882 .5926 .42397 .59105 .42305 .59019 Metetra
.664 .741 .907 r
.42305 .59019 .42397 .59105 .42912 .5895 .42821 .58863 Metetra
.664 .741 .907 r
.42821 .58863 .42912 .5895 .43428 .58794 .43337 .58708 Metetra
.664 .741 .907 r
.43337 .58708 .43428 .58794 .43945 .58639 .43855 .58552 Metetra
.664 .741 .907 r
.43855 .58552 .43945 .58639 .44464 .58482 .44373 .58395 Metetra
.664 .741 .907 r
.44373 .58395 .44464 .58482 .44983 .58326 .44893 .58239 Metetra
.664 .741 .907 r
.44893 .58239 .44983 .58326 .45503 .58169 .45413 .58082 Metetra
.664 .741 .907 r
.45413 .58082 .45503 .58169 .46024 .58012 .45935 .57925 Metetra
.664 .741 .907 r
.45935 .57925 .46024 .58012 .46547 .57855 .46457 .57767 Metetra
.664 .741 .907 r
.46457 .57767 .46547 .57855 .4707 .57697 .4698 .57609 Metetra
.664 .741 .907 r
.4698 .57609 .4707 .57697 .47594 .57539 .47505 .57451 Metetra
.664 .741 .907 r
.47505 .57451 .47594 .57539 .48119 .57381 .4803 .57293 Metetra
.664 .741 .907 r
.4803 .57293 .48119 .57381 .48646 .57222 .48557 .57134 Metetra
.664 .741 .907 r
.48557 .57134 .48646 .57222 .49173 .57064 .49084 .56975 Metetra
.664 .741 .907 r
.49084 .56975 .49173 .57064 .49701 .56904 .49613 .56815 Metetra
.664 .741 .907 r
.49613 .56815 .49701 .56904 .50231 .56745 .50142 .56656 Metetra
.664 .741 .907 r
.50142 .56656 .50231 .56745 .50761 .56585 .50673 .56496 Metetra
.664 .741 .907 r
.50673 .56496 .50761 .56585 .51292 .56425 .51205 .56336 Metetra
.664 .741 .907 r
.51205 .56336 .51292 .56425 .51825 .56265 .51737 .56175 Metetra
.664 .741 .907 r
.51737 .56175 .51825 .56265 .52358 .56104 .52271 .56014 Metetra
.664 .741 .907 r
.52271 .56014 .52358 .56104 .52893 .55943 .52806 .55853 Metetra
.664 .741 .907 r
.52806 .55853 .52893 .55943 .53428 .55781 .53341 .55691 Metetra
.664 .741 .907 r
.53341 .55691 .53428 .55781 .53965 .5562 .53878 .55529 Metetra
.664 .741 .907 r
.53878 .55529 .53965 .5562 .54503 .55458 .54416 .55367 Metetra
.664 .741 .907 r
.54416 .55367 .54503 .55458 .55041 .55295 .54955 .55205 Metetra
.664 .741 .907 r
.54955 .55205 .55041 .55295 .55581 .55133 .55495 .55042 Metetra
.664 .741 .907 r
.55495 .55042 .55581 .55133 .56122 .5497 .56036 .54879 Metetra
.664 .741 .907 r
.56036 .54879 .56122 .5497 .56664 .54807 .56578 .54715 Metetra
.664 .741 .907 r
.56578 .54715 .56664 .54807 .57207 .54643 .57121 .54552 Metetra
.664 .741 .907 r
.57121 .54552 .57207 .54643 .57751 .54479 .57665 .54388 Metetra
.664 .741 .907 r
.57665 .54388 .57751 .54479 .58296 .54315 .5821 .54223 Metetra
.664 .741 .907 r
.5821 .54223 .58296 .54315 .58842 .5415 .58757 .54059 Metetra
.664 .741 .907 r
.58757 .54059 .58842 .5415 .59389 .53986 .59304 .53893 Metetra
.664 .741 .907 r
.59304 .53893 .59389 .53986 .59937 .5382 .59853 .53728 Metetra
.664 .741 .907 r
.59853 .53728 .59937 .5382 .60486 .53655 .60402 .53562 Metetra
.664 .741 .907 r
.60402 .53562 .60486 .53655 .61037 .53489 .60953 .53396 Metetra
.194 .513 .914 r
.60953 .53396 .61037 .53489 .61588 .53323 .61515 .53619 Metetra
.316 .031 .311 r
.61515 .53619 .61588 .53323 .62141 .53156 .62057 .53063 Metetra
.664 .741 .907 r
.62057 .53063 .62141 .53156 .62695 .5299 .62611 .52896 Metetra
.664 .741 .907 r
.62611 .52896 .62695 .5299 .6325 .52822 .63166 .52729 Metetra
.664 .741 .907 r
.63166 .52729 .6325 .52822 .63805 .52655 .63722 .52561 Metetra
.664 .741 .907 r
.63722 .52561 .63805 .52655 .64362 .52487 .6428 .52393 Metetra
.664 .741 .907 r
.6428 .52393 .64362 .52487 .64921 .52319 .64838 .52225 Metetra
.664 .741 .907 r
.64838 .52225 .64921 .52319 .6548 .5215 .65397 .52056 Metetra
.664 .741 .907 r
.65397 .52056 .6548 .5215 .6604 .51982 .65958 .51887 Metetra
.664 .741 .907 r
.65958 .51887 .6604 .51982 .66601 .51812 .6652 .51718 Metetra
.664 .741 .907 r
.6652 .51718 .66601 .51812 .67164 .51643 .67082 .51548 Metetra
.664 .741 .907 r
.67082 .51548 .67164 .51643 .67728 .51473 .67646 .51378 Metetra
.664 .741 .907 r
.67646 .51378 .67728 .51473 .68293 .51303 .68211 .51208 Metetra
.664 .741 .907 r
.68211 .51208 .68293 .51303 .68858 .51132 .68778 .51037 Metetra
.664 .741 .907 r
.68778 .51037 .68858 .51132 .69426 .50962 .69345 .50866 Metetra
.664 .741 .907 r
.69345 .50866 .69426 .50962 .69994 .5079 .69913 .50695 Metetra
.664 .741 .907 r
.69913 .50695 .69994 .5079 .70563 .50619 .70483 .50523 Metetra
.664 .741 .907 r
.70483 .50523 .70563 .50619 .71134 .50447 .71054 .50351 Metetra
.664 .741 .907 r
.71054 .50351 .71134 .50447 .71705 .50275 .71626 .50178 Metetra
.664 .741 .907 r
.71626 .50178 .71705 .50275 .72278 .50102 .72199 .50006 Metetra
.664 .741 .907 r
.72199 .50006 .72278 .50102 .72852 .49929 .72773 .49833 Metetra
.664 .741 .907 r
.72773 .49833 .72852 .49929 .73427 .49756 .73348 .49659 Metetra
.664 .741 .907 r
.73348 .49659 .73427 .49756 .74003 .49582 .73925 .49485 Metetra
.664 .741 .907 r
.73925 .49485 .74003 .49582 .74581 .49408 .74502 .49311 Metetra
.664 .741 .907 r
.74502 .49311 .74581 .49408 .75159 .49234 .75081 .49137 Metetra
.664 .741 .907 r
.75081 .49137 .75159 .49234 .75739 .49059 .75661 .48962 Metetra
.664 .741 .907 r
.75661 .48962 .75739 .49059 .7632 .48884 .76242 .48786 Metetra
.664 .741 .907 r
.76242 .48786 .7632 .48884 .76902 .48709 .76825 .48611 Metetra
.664 .741 .907 r
.76825 .48611 .76902 .48709 .77486 .48533 .77408 .48435 Metetra
.664 .741 .907 r
.77408 .48435 .77486 .48533 .7807 .48357 .77993 .48259 Metetra
.664 .741 .907 r
.77993 .48259 .7807 .48357 .78656 .48181 .78579 .48082 Metetra
.664 .741 .907 r
.78579 .48082 .78656 .48181 .79243 .48004 .79166 .47905 Metetra
.664 .741 .907 r
.79166 .47905 .79243 .48004 .79831 .47827 .79754 .47728 Metetra
.664 .741 .907 r
.79754 .47728 .79831 .47827 .8042 .47649 .80344 .4755 Metetra
.664 .741 .907 r
.80344 .4755 .8042 .47649 .8101 .47471 .80935 .47372 Metetra
.664 .741 .907 r
.80935 .47372 .8101 .47471 .81602 .47293 .81527 .47193 Metetra
.664 .741 .907 r
.81527 .47193 .81602 .47293 .82195 .47114 .8212 .47014 Metetra
.664 .741 .907 r
.8212 .47014 .82195 .47114 .82789 .46935 .82714 .46835 Metetra
.664 .741 .907 r
.82714 .46835 .82789 .46935 .83384 .46756 .8331 .46656 Metetra
.664 .741 .907 r
.8331 .46656 .83384 .46756 .83981 .46576 .83907 .46476 Metetra
.664 .741 .907 r
.83907 .46476 .83981 .46576 .84579 .46396 .84505 .46295 Metetra
.664 .741 .907 r
.84505 .46295 .84579 .46396 .85178 .46215 .85104 .46115 Metetra
.664 .741 .907 r
.85104 .46115 .85178 .46215 .85778 .46035 .85704 .45934 Metetra
.664 .741 .907 r
.85704 .45934 .85778 .46035 .86379 .45853 .86306 .45752 Metetra
.664 .741 .907 r
.86306 .45752 .86379 .45853 .86982 .45672 .86909 .4557 Metetra
.664 .741 .907 r
.86909 .4557 .86982 .45672 .87586 .4549 .87513 .45388 Metetra
.664 .741 .907 r
.87513 .45388 .87586 .4549 .88191 .45307 .88119 .45206 Metetra
.664 .741 .907 r
.88119 .45206 .88191 .45307 .88798 .45125 .88726 .45023 Metetra
.664 .741 .907 r
.88726 .45023 .88798 .45125 .89406 .44942 .89334 .44839 Metetra
.664 .741 .907 r
.89334 .44839 .89406 .44942 .90015 .44758 .89943 .44656 Metetra
.664 .741 .907 r
.89943 .44656 .90015 .44758 .90625 .44574 .90553 .44472 Metetra
.664 .741 .907 r
.90553 .44472 .90625 .44574 .91236 .4439 .91165 .44287 Metetra
.664 .741 .907 r
.91165 .44287 .91236 .4439 .91849 .44205 .91778 .44102 Metetra
.664 .741 .907 r
.91778 .44102 .91849 .44205 .92463 .4402 .92393 .43917 Metetra
.664 .741 .907 r
.92393 .43917 .92463 .4402 .93079 .43835 .93008 .43731 Metetra
.664 .741 .907 r
.93008 .43731 .93079 .43835 .93695 .43649 .93625 .43545 Metetra
.664 .741 .907 r
.93625 .43545 .93695 .43649 .94313 .43463 .94243 .43359 Metetra
.664 .741 .907 r
.94243 .43359 .94313 .43463 .94932 .43276 .94863 .43172 Metetra
.664 .741 .907 r
.94863 .43172 .94932 .43276 .95553 .4309 .95484 .42985 Metetra
.664 .741 .907 r
.95484 .42985 .95553 .4309 .96175 .42902 .96106 .42797 Metetra
.664 .741 .907 r
.96106 .42797 .96175 .42902 .96798 .42714 .96729 .4261 Metetra
.664 .741 .907 r
.40161 .59551 .40253 .59637 .40765 .59483 .40673 .59397 Metetra
.664 .741 .907 r
.40673 .59397 .40765 .59483 .41277 .59329 .41186 .59242 Metetra
.664 .741 .907 r
.41186 .59242 .41277 .59329 .41791 .59174 .41699 .59087 Metetra
.664 .741 .907 r
.41699 .59087 .41791 .59174 .42305 .59019 .42214 .58932 Metetra
.664 .741 .907 r
.42214 .58932 .42305 .59019 .42821 .58863 .4273 .58776 Metetra
.664 .741 .907 r
.4273 .58776 .42821 .58863 .43337 .58708 .43246 .58621 Metetra
.664 .741 .907 r
.43246 .58621 .43337 .58708 .43855 .58552 .43764 .58464 Metetra
.664 .741 .907 r
.43764 .58464 .43855 .58552 .44373 .58395 .44283 .58308 Metetra
.664 .741 .907 r
.44283 .58308 .44373 .58395 .44893 .58239 .44802 .58151 Metetra
.664 .741 .907 r
.44802 .58151 .44893 .58239 .45413 .58082 .45323 .57994 Metetra
.664 .741 .907 r
.45323 .57994 .45413 .58082 .45935 .57925 .45845 .57837 Metetra
.664 .741 .907 r
.45845 .57837 .45935 .57925 .46457 .57767 .46367 .57679 Metetra
.664 .741 .907 r
.46367 .57679 .46457 .57767 .4698 .57609 .46891 .57521 Metetra
.664 .741 .907 r
.46891 .57521 .4698 .57609 .47505 .57451 .47415 .57363 Metetra
.941 .584 .301 r
.47415 .57363 .47505 .57451 .4803 .57293 .47914 .59264 Metetra
.438 .239 .511 r
.47914 .59264 .4803 .57293 .48557 .57134 .48468 .57045 Metetra
.664 .741 .907 r
.48468 .57045 .48557 .57134 .49084 .56975 .48996 .56886 Metetra
.664 .741 .907 r
.48996 .56886 .49084 .56975 .49613 .56815 .49524 .56726 Metetra
.664 .741 .907 r
.49524 .56726 .49613 .56815 .50142 .56656 .50054 .56567 Metetra
.664 .741 .907 r
.50054 .56567 .50142 .56656 .50673 .56496 .50585 .56406 Metetra
.664 .741 .907 r
.50585 .56406 .50673 .56496 .51205 .56336 .51117 .56246 Metetra
.664 .741 .907 r
.51117 .56246 .51205 .56336 .51737 .56175 .51649 .56085 Metetra
.664 .741 .907 r
.51649 .56085 .51737 .56175 .52271 .56014 .52183 .55924 Metetra
.664 .741 .907 r
.52183 .55924 .52271 .56014 .52806 .55853 .52718 .55763 Metetra
.664 .741 .907 r
.52718 .55763 .52806 .55853 .53341 .55691 .53254 .55601 Metetra
.664 .741 .907 r
.53254 .55601 .53341 .55691 .53878 .55529 .53791 .55439 Metetra
.664 .741 .907 r
.53791 .55439 .53878 .55529 .54416 .55367 .54329 .55277 Metetra
.664 .741 .907 r
.54329 .55277 .54416 .55367 .54955 .55205 .54868 .55114 Metetra
.664 .741 .907 r
.54868 .55114 .54955 .55205 .55495 .55042 .55408 .54951 Metetra
.664 .741 .907 r
.55408 .54951 .55495 .55042 .56036 .54879 .5595 .54788 Metetra
.664 .741 .907 r
.5595 .54788 .56036 .54879 .56578 .54715 .56492 .54624 Metetra
.664 .741 .907 r
.56492 .54624 .56578 .54715 .57121 .54552 .57035 .5446 Metetra
.664 .741 .907 r
.57035 .5446 .57121 .54552 .57665 .54388 .5758 .54296 Metetra
.664 .741 .907 r
.5758 .54296 .57665 .54388 .5821 .54223 .58125 .54131 Metetra
.664 .741 .907 r
.58125 .54131 .5821 .54223 .58757 .54059 .58672 .53967 Metetra
.664 .741 .907 r
.58672 .53967 .58757 .54059 .59304 .53893 .59219 .53801 Metetra
.664 .741 .907 r
.59219 .53801 .59304 .53893 .59853 .53728 .59768 .53636 Metetra
.664 .741 .907 r
.59768 .53636 .59853 .53728 .60402 .53562 .60318 .5347 Metetra
.664 .741 .907 r
.60318 .5347 .60402 .53562 .60953 .53396 .60869 .53304 Metetra
.962 .673 .441 r
.60869 .53304 .60953 .53396 .61515 .53619 .61776 .66469 Metetra
.473 .287 .547 r
.61776 .66469 .61515 .53619 .62057 .53063 .62011 .54311 Metetra
.435 .228 .498 r
.62011 .54311 .62057 .53063 .62611 .52896 .62528 .52803 Metetra
.664 .741 .907 r
.62528 .52803 .62611 .52896 .63166 .52729 .63083 .52636 Metetra
.664 .741 .907 r
.63083 .52636 .63166 .52729 .63722 .52561 .63639 .52468 Metetra
.664 .741 .907 r
.63639 .52468 .63722 .52561 .6428 .52393 .64197 .52299 Metetra
.664 .741 .907 r
.64197 .52299 .6428 .52393 .64838 .52225 .64755 .52131 Metetra
.664 .741 .907 r
.64755 .52131 .64838 .52225 .65397 .52056 .65315 .51962 Metetra
.664 .741 .907 r
.65315 .51962 .65397 .52056 .65958 .51887 .65876 .51793 Metetra
.664 .741 .907 r
.65876 .51793 .65958 .51887 .6652 .51718 .66438 .51623 Metetra
.664 .741 .907 r
.66438 .51623 .6652 .51718 .67082 .51548 .67001 .51453 Metetra
.664 .741 .907 r
.67001 .51453 .67082 .51548 .67646 .51378 .67565 .51283 Metetra
.664 .741 .907 r
.67565 .51283 .67646 .51378 .68211 .51208 .6813 .51113 Metetra
.664 .741 .907 r
.6813 .51113 .68211 .51208 .68778 .51037 .68697 .50942 Metetra
.664 .741 .907 r
.68697 .50942 .68778 .51037 .69345 .50866 .69264 .50771 Metetra
.664 .741 .907 r
.69264 .50771 .69345 .50866 .69913 .50695 .69833 .50599 Metetra
.664 .741 .907 r
.69833 .50599 .69913 .50695 .70483 .50523 .70403 .50427 Metetra
.664 .741 .907 r
.70403 .50427 .70483 .50523 .71054 .50351 .70974 .50255 Metetra
.664 .741 .907 r
.70974 .50255 .71054 .50351 .71626 .50178 .71546 .50082 Metetra
.664 .741 .907 r
.71546 .50082 .71626 .50178 .72199 .50006 .72119 .49909 Metetra
.664 .741 .907 r
.72119 .49909 .72199 .50006 .72773 .49833 .72693 .49736 Metetra
.664 .741 .907 r
.72693 .49736 .72773 .49833 .73348 .49659 .73269 .49562 Metetra
.664 .741 .907 r
.73269 .49562 .73348 .49659 .73925 .49485 .73846 .49388 Metetra
.664 .741 .907 r
.73846 .49388 .73925 .49485 .74502 .49311 .74424 .49214 Metetra
.664 .741 .907 r
.74424 .49214 .74502 .49311 .75081 .49137 .75003 .49039 Metetra
.664 .741 .907 r
.75003 .49039 .75081 .49137 .75661 .48962 .75583 .48864 Metetra
.664 .741 .907 r
.75583 .48864 .75661 .48962 .76242 .48786 .76164 .48689 Metetra
.664 .741 .907 r
.76164 .48689 .76242 .48786 .76825 .48611 .76747 .48513 Metetra
.664 .741 .907 r
.76747 .48513 .76825 .48611 .77408 .48435 .77331 .48337 Metetra
.664 .741 .907 r
.77331 .48337 .77408 .48435 .77993 .48259 .77916 .4816 Metetra
.664 .741 .907 r
.77916 .4816 .77993 .48259 .78579 .48082 .78502 .47983 Metetra
.664 .741 .907 r
.78502 .47983 .78579 .48082 .79166 .47905 .79089 .47806 Metetra
.664 .741 .907 r
.79089 .47806 .79166 .47905 .79754 .47728 .79678 .47628 Metetra
.664 .741 .907 r
.79678 .47628 .79754 .47728 .80344 .4755 .80268 .47451 Metetra
.664 .741 .907 r
.80268 .47451 .80344 .4755 .80935 .47372 .80859 .47272 Metetra
.664 .741 .907 r
.80859 .47272 .80935 .47372 .81527 .47193 .81451 .47094 Metetra
.664 .741 .907 r
.81451 .47094 .81527 .47193 .8212 .47014 .82044 .46914 Metetra
.664 .741 .907 r
.82044 .46914 .8212 .47014 .82714 .46835 .82639 .46735 Metetra
.664 .741 .907 r
.82639 .46735 .82714 .46835 .8331 .46656 .83235 .46555 Metetra
.664 .741 .907 r
.83235 .46555 .8331 .46656 .83907 .46476 .83832 .46375 Metetra
.664 .741 .907 r
.83832 .46375 .83907 .46476 .84505 .46295 .8443 .46195 Metetra
.664 .741 .907 r
.8443 .46195 .84505 .46295 .85104 .46115 .8503 .46014 Metetra
.664 .741 .907 r
.8503 .46014 .85104 .46115 .85704 .45934 .85631 .45832 Metetra
.664 .741 .907 r
.85631 .45832 .85704 .45934 .86306 .45752 .86233 .45651 Metetra
.664 .741 .907 r
.86233 .45651 .86306 .45752 .86909 .4557 .86836 .45469 Metetra
.664 .741 .907 r
.86836 .45469 .86909 .4557 .87513 .45388 .8744 .45286 Metetra
.664 .741 .907 r
.8744 .45286 .87513 .45388 .88119 .45206 .88046 .45104 Metetra
.664 .741 .907 r
.88046 .45104 .88119 .45206 .88726 .45023 .88653 .4492 Metetra
.664 .741 .907 r
.88653 .4492 .88726 .45023 .89334 .44839 .89262 .44737 Metetra
.664 .741 .907 r
.89262 .44737 .89334 .44839 .89943 .44656 .89871 .44553 Metetra
.247 .517 .91 r
.89871 .44553 .89943 .44656 .90553 .44472 .90534 .44816 Metetra
.89 .554 .405 r
.90534 .44816 .90553 .44472 .91165 .44287 .91667 .49029 Metetra
.474 .288 .548 r
.91667 .49029 .91165 .44287 .91778 .44102 .91707 .43999 Metetra
.664 .741 .907 r
.91707 .43999 .91778 .44102 .92393 .43917 .92322 .43814 Metetra
.664 .741 .907 r
.92322 .43814 .92393 .43917 .93008 .43731 .92938 .43628 Metetra
.664 .741 .907 r
.92938 .43628 .93008 .43731 .93625 .43545 .93555 .43442 Metetra
.664 .741 .907 r
.93555 .43442 .93625 .43545 .94243 .43359 .94174 .43255 Metetra
.664 .741 .907 r
.94174 .43255 .94243 .43359 .94863 .43172 .94793 .43068 Metetra
.664 .741 .907 r
.94793 .43068 .94863 .43172 .95484 .42985 .95415 .4288 Metetra
.664 .741 .907 r
.95415 .4288 .95484 .42985 .96106 .42797 .96037 .42693 Metetra
.664 .741 .907 r
.96037 .42693 .96106 .42797 .96729 .4261 .96661 .42505 Metetra
.664 .741 .907 r
.40069 .59465 .40161 .59551 .40673 .59397 .40581 .59311 Metetra
.664 .741 .907 r
.40581 .59311 .40673 .59397 .41186 .59242 .41094 .59156 Metetra
.664 .741 .907 r
.41094 .59156 .41186 .59242 .41699 .59087 .41608 .59001 Metetra
.664 .741 .907 r
.41608 .59001 .41699 .59087 .42214 .58932 .42123 .58845 Metetra
.664 .741 .907 r
.42123 .58845 .42214 .58932 .4273 .58776 .42638 .5869 Metetra
.664 .741 .907 r
.42638 .5869 .4273 .58776 .43246 .58621 .43155 .58534 Metetra
.664 .741 .907 r
.43155 .58534 .43246 .58621 .43764 .58464 .43673 .58377 Metetra
.664 .741 .907 r
.43673 .58377 .43764 .58464 .44283 .58308 .44192 .58221 Metetra
.664 .741 .907 r
.44192 .58221 .44283 .58308 .44802 .58151 .44712 .58064 Metetra
.664 .741 .907 r
.44712 .58064 .44802 .58151 .45323 .57994 .45233 .57906 Metetra
.664 .741 .907 r
.45233 .57906 .45323 .57994 .45845 .57837 .45754 .57749 Metetra
.664 .741 .907 r
.45754 .57749 .45845 .57837 .46367 .57679 .46277 .57591 Metetra
.664 .741 .907 r
.46277 .57591 .46367 .57679 .46891 .57521 .46801 .57433 Metetra
.664 .741 .907 r
.46801 .57433 .46891 .57521 .47415 .57363 .47326 .57274 Metetra
.664 .741 .907 r
.47326 .57274 .47415 .57363 .47914 .59264 .47852 .57116 Metetra
.583 .391 .587 r
.47852 .57116 .47914 .59264 .48468 .57045 .48379 .56956 Metetra
.664 .741 .907 r
.48379 .56956 .48468 .57045 .48996 .56886 .48907 .56797 Metetra
.664 .741 .907 r
.48907 .56797 .48996 .56886 .49524 .56726 .49436 .56637 Metetra
.664 .741 .907 r
.49436 .56637 .49524 .56726 .50054 .56567 .49965 .56477 Metetra
.664 .741 .907 r
.49965 .56477 .50054 .56567 .50585 .56406 .50496 .56317 Metetra
.664 .741 .907 r
.50496 .56317 .50585 .56406 .51117 .56246 .51028 .56156 Metetra
.664 .741 .907 r
.51028 .56156 .51117 .56246 .51649 .56085 .51561 .55995 Metetra
.664 .741 .907 r
.51561 .55995 .51649 .56085 .52183 .55924 .52096 .55834 Metetra
.664 .741 .907 r
.52096 .55834 .52183 .55924 .52718 .55763 .52631 .55673 Metetra
.664 .741 .907 r
.52631 .55673 .52718 .55763 .53254 .55601 .53167 .55511 Metetra
.664 .741 .907 r
.53167 .55511 .53254 .55601 .53791 .55439 .53704 .55349 Metetra
.664 .741 .907 r
.53704 .55349 .53791 .55439 .54329 .55277 .54242 .55186 Metetra
.664 .741 .907 r
.54242 .55186 .54329 .55277 .54868 .55114 .54782 .55023 Metetra
.664 .741 .907 r
.54782 .55023 .54868 .55114 .55408 .54951 .55322 .5486 Metetra
.664 .741 .907 r
.55322 .5486 .55408 .54951 .5595 .54788 .55863 .54697 Metetra
.664 .741 .907 r
.55863 .54697 .5595 .54788 .56492 .54624 .56406 .54533 Metetra
.664 .741 .907 r
.56406 .54533 .56492 .54624 .57035 .5446 .56949 .54369 Metetra
.664 .741 .907 r
.56949 .54369 .57035 .5446 .5758 .54296 .57494 .54204 Metetra
.664 .741 .907 r
.57494 .54204 .5758 .54296 .58125 .54131 .5804 .54039 Metetra
.664 .741 .907 r
.5804 .54039 .58125 .54131 .58672 .53967 .58586 .53874 Metetra
.664 .741 .907 r
.58586 .53874 .58672 .53967 .59219 .53801 .59134 .53709 Metetra
.664 .741 .907 r
.59134 .53709 .59219 .53801 .59768 .53636 .59683 .53543 Metetra
.664 .741 .907 r
.59683 .53543 .59768 .53636 .60318 .5347 .60233 .53377 Metetra
.664 .741 .907 r
.60233 .53377 .60318 .5347 .60869 .53304 .60784 .53211 Metetra
.961 .679 .453 r
.60784 .53211 .60869 .53304 .61776 .66469 .6191 .74775 Metetra
.247 .113 .493 r
.6191 .74775 .61776 .66469 .62011 .54311 .61966 .55612 Metetra
.273 .102 .458 r
.61966 .55612 .62011 .54311 .62528 .52803 .62444 .5271 Metetra
.664 .741 .907 r
.62444 .5271 .62528 .52803 .63083 .52636 .63 .52542 Metetra
.664 .741 .907 r
.63 .52542 .63083 .52636 .63639 .52468 .63556 .52374 Metetra
.664 .741 .907 r
.63556 .52374 .63639 .52468 .64197 .52299 .64114 .52206 Metetra
.664 .741 .907 r
.64114 .52206 .64197 .52299 .64755 .52131 .64673 .52037 Metetra
.664 .741 .907 r
.64673 .52037 .64755 .52131 .65315 .51962 .65232 .51868 Metetra
.664 .741 .907 r
.65232 .51868 .65315 .51962 .65876 .51793 .65793 .51698 Metetra
.664 .741 .907 r
.65793 .51698 .65876 .51793 .66438 .51623 .66356 .51529 Metetra
.664 .741 .907 r
.66356 .51529 .66438 .51623 .67001 .51453 .66919 .51359 Metetra
.664 .741 .907 r
.66919 .51359 .67001 .51453 .67565 .51283 .67483 .51188 Metetra
.664 .741 .907 r
.67483 .51188 .67565 .51283 .6813 .51113 .68049 .51017 Metetra
.664 .741 .907 r
.68049 .51017 .6813 .51113 .68697 .50942 .68615 .50846 Metetra
.664 .741 .907 r
.68615 .50846 .68697 .50942 .69264 .50771 .69183 .50675 Metetra
.664 .741 .907 r
.69183 .50675 .69264 .50771 .69833 .50599 .69752 .50503 Metetra
.664 .741 .907 r
.69752 .50503 .69833 .50599 .70403 .50427 .70322 .50331 Metetra
.664 .741 .907 r
.70322 .50331 .70403 .50427 .70974 .50255 .70893 .50159 Metetra
.664 .741 .907 r
.70893 .50159 .70974 .50255 .71546 .50082 .71466 .49986 Metetra
.664 .741 .907 r
.71466 .49986 .71546 .50082 .72119 .49909 .72039 .49813 Metetra
.664 .741 .907 r
.72039 .49813 .72119 .49909 .72693 .49736 .72614 .49639 Metetra
.664 .741 .907 r
.72614 .49639 .72693 .49736 .73269 .49562 .7319 .49465 Metetra
.664 .741 .907 r
.7319 .49465 .73269 .49562 .73846 .49388 .73767 .49291 Metetra
.664 .741 .907 r
.73767 .49291 .73846 .49388 .74424 .49214 .74345 .49116 Metetra
.664 .741 .907 r
.74345 .49116 .74424 .49214 .75003 .49039 .74924 .48942 Metetra
.664 .741 .907 r
.74924 .48942 .75003 .49039 .75583 .48864 .75505 .48766 Metetra
.664 .741 .907 r
.75505 .48766 .75583 .48864 .76164 .48689 .76086 .48591 Metetra
.664 .741 .907 r
.76086 .48591 .76164 .48689 .76747 .48513 .76669 .48415 Metetra
.664 .741 .907 r
.76669 .48415 .76747 .48513 .77331 .48337 .77253 .48238 Metetra
.664 .741 .907 r
.77253 .48238 .77331 .48337 .77916 .4816 .77839 .48062 Metetra
.664 .741 .907 r
.77839 .48062 .77916 .4816 .78502 .47983 .78425 .47884 Metetra
.664 .741 .907 r
.78425 .47884 .78502 .47983 .79089 .47806 .79013 .47707 Metetra
.664 .741 .907 r
.79013 .47707 .79089 .47806 .79678 .47628 .79602 .47529 Metetra
.664 .741 .907 r
.79602 .47529 .79678 .47628 .80268 .47451 .80192 .47351 Metetra
.664 .741 .907 r
.80192 .47351 .80268 .47451 .80859 .47272 .80783 .47173 Metetra
.664 .741 .907 r
.80783 .47173 .80859 .47272 .81451 .47094 .81375 .46994 Metetra
.664 .741 .907 r
.81375 .46994 .81451 .47094 .82044 .46914 .81969 .46814 Metetra
.664 .741 .907 r
.81969 .46814 .82044 .46914 .82639 .46735 .82564 .46635 Metetra
.664 .741 .907 r
.82564 .46635 .82639 .46735 .83235 .46555 .8316 .46455 Metetra
.664 .741 .907 r
.8316 .46455 .83235 .46555 .83832 .46375 .83757 .46275 Metetra
.664 .741 .907 r
.83757 .46275 .83832 .46375 .8443 .46195 .84356 .46094 Metetra
.664 .741 .907 r
.84356 .46094 .8443 .46195 .8503 .46014 .84956 .45913 Metetra
.664 .741 .907 r
.84956 .45913 .8503 .46014 .85631 .45832 .85557 .45731 Metetra
.664 .741 .907 r
.85557 .45731 .85631 .45832 .86233 .45651 .86159 .45549 Metetra
.664 .741 .907 r
.86159 .45549 .86233 .45651 .86836 .45469 .86763 .45367 Metetra
.664 .741 .907 r
.86763 .45367 .86836 .45469 .8744 .45286 .87367 .45185 Metetra
.664 .741 .907 r
.87367 .45185 .8744 .45286 .88046 .45104 .87974 .45002 Metetra
.664 .741 .907 r
.87974 .45002 .88046 .45104 .88653 .4492 .88581 .44818 Metetra
.664 .741 .907 r
.88581 .44818 .88653 .4492 .89262 .44737 .89189 .44634 Metetra
.664 .741 .907 r
.89189 .44634 .89262 .44737 .89871 .44553 .89799 .4445 Metetra
.925 .558 .139 r
.89799 .4445 .89871 .44553 .90534 .44816 .90867 .48199 Metetra
.758 .492 .53 r
.90867 .48199 .90534 .44816 .91667 .49029 .92887 .59867 Metetra
.427 .26 .55 r
.92887 .59867 .91667 .49029 .91707 .43999 .91636 .43896 Metetra
.664 .741 .907 r
.91636 .43896 .91707 .43999 .92322 .43814 .92251 .4371 Metetra
.664 .741 .907 r
.92251 .4371 .92322 .43814 .92938 .43628 .92867 .43524 Metetra
.664 .741 .907 r
.92867 .43524 .92938 .43628 .93555 .43442 .93485 .43337 Metetra
.664 .741 .907 r
.93485 .43337 .93555 .43442 .94174 .43255 .94104 .43151 Metetra
.664 .741 .907 r
.94104 .43151 .94174 .43255 .94793 .43068 .94724 .42963 Metetra
.664 .741 .907 r
.94724 .42963 .94793 .43068 .95415 .4288 .95345 .42776 Metetra
.664 .741 .907 r
.95345 .42776 .95415 .4288 .96037 .42693 .95968 .42588 Metetra
.664 .741 .907 r
.95968 .42588 .96037 .42693 .96661 .42505 .96592 .42399 Metetra
.664 .741 .907 r
.39977 .59379 .40069 .59465 .40581 .59311 .40489 .59224 Metetra
.664 .741 .907 r
.40489 .59224 .40581 .59311 .41094 .59156 .41002 .59069 Metetra
.664 .741 .907 r
.41002 .59069 .41094 .59156 .41608 .59001 .41516 .58914 Metetra
.664 .741 .907 r
.41516 .58914 .41608 .59001 .42123 .58845 .42031 .58759 Metetra
.664 .741 .907 r
.42031 .58759 .42123 .58845 .42638 .5869 .42547 .58603 Metetra
.664 .741 .907 r
.42547 .58603 .42638 .5869 .43155 .58534 .43064 .58446 Metetra
.664 .741 .907 r
.43064 .58446 .43155 .58534 .43673 .58377 .43582 .5829 Metetra
.664 .741 .907 r
.43582 .5829 .43673 .58377 .44192 .58221 .44101 .58133 Metetra
.664 .741 .907 r
.44101 .58133 .44192 .58221 .44712 .58064 .44621 .57976 Metetra
.664 .741 .907 r
.44621 .57976 .44712 .58064 .45233 .57906 .45142 .57818 Metetra
.664 .741 .907 r
.45142 .57818 .45233 .57906 .45754 .57749 .45664 .57661 Metetra
.664 .741 .907 r
.45664 .57661 .45754 .57749 .46277 .57591 .46187 .57503 Metetra
.664 .741 .907 r
.46187 .57503 .46277 .57591 .46801 .57433 .46711 .57344 Metetra
.664 .741 .907 r
.46711 .57344 .46801 .57433 .47326 .57274 .47236 .57186 Metetra
.664 .741 .907 r
.47236 .57186 .47326 .57274 .47852 .57116 .47762 .57027 Metetra
.664 .741 .907 r
.47762 .57027 .47852 .57116 .48379 .56956 .48289 .56868 Metetra
.664 .741 .907 r
.48289 .56868 .48379 .56956 .48907 .56797 .48818 .56708 Metetra
.664 .741 .907 r
.48818 .56708 .48907 .56797 .49436 .56637 .49347 .56548 Metetra
.664 .741 .907 r
.49347 .56548 .49436 .56637 .49965 .56477 .49877 .56388 Metetra
.664 .741 .907 r
.49877 .56388 .49965 .56477 .50496 .56317 .50408 .56227 Metetra
.664 .741 .907 r
.50408 .56227 .50496 .56317 .51028 .56156 .5094 .56067 Metetra
.664 .741 .907 r
.5094 .56067 .51028 .56156 .51561 .55995 .51473 .55906 Metetra
.664 .741 .907 r
.51473 .55906 .51561 .55995 .52096 .55834 .52008 .55744 Metetra
.664 .741 .907 r
.52008 .55744 .52096 .55834 .52631 .55673 .52543 .55582 Metetra
.664 .741 .907 r
.52543 .55582 .52631 .55673 .53167 .55511 .53079 .5542 Metetra
.664 .741 .907 r
.53079 .5542 .53167 .55511 .53704 .55349 .53617 .55258 Metetra
.664 .741 .907 r
.53617 .55258 .53704 .55349 .54242 .55186 .54155 .55095 Metetra
.664 .741 .907 r
.54155 .55095 .54242 .55186 .54782 .55023 .54695 .54932 Metetra
.664 .741 .907 r
.54695 .54932 .54782 .55023 .55322 .5486 .55235 .54769 Metetra
.664 .741 .907 r
.55235 .54769 .55322 .5486 .55863 .54697 .55777 .54605 Metetra
.664 .741 .907 r
.55777 .54605 .55863 .54697 .56406 .54533 .5632 .54441 Metetra
.664 .741 .907 r
.5632 .54441 .56406 .54533 .56949 .54369 .56863 .54277 Metetra
.664 .741 .907 r
.56863 .54277 .56949 .54369 .57494 .54204 .57408 .54112 Metetra
.664 .741 .907 r
.57408 .54112 .57494 .54204 .5804 .54039 .57954 .53947 Metetra
.664 .741 .907 r
.57954 .53947 .5804 .54039 .58586 .53874 .58501 .53782 Metetra
.664 .741 .907 r
.58501 .53782 .58586 .53874 .59134 .53709 .59049 .53617 Metetra
.664 .741 .907 r
.59049 .53617 .59134 .53709 .59683 .53543 .59598 .53451 Metetra
.664 .741 .907 r
.59598 .53451 .59683 .53543 .60233 .53377 .60149 .53284 Metetra
.664 .741 .907 r
.60149 .53284 .60233 .53377 .60784 .53211 .607 .53118 Metetra
.961 .679 .453 r
.607 .53118 .60784 .53211 .6191 .74775 .61821 .74689 Metetra
.96 .699 .495 r
.61821 .74689 .6191 .74775 .61966 .55612 .61958 .58267 Metetra
.291 .134 .488 r
.61958 .58267 .61966 .55612 .62444 .5271 .6236 .52616 Metetra
.664 .741 .907 r
.6236 .52616 .62444 .5271 .63 .52542 .62916 .52448 Metetra
.664 .741 .907 r
.62916 .52448 .63 .52542 .63556 .52374 .63473 .5228 Metetra
.664 .741 .907 r
.63473 .5228 .63556 .52374 .64114 .52206 .64031 .52111 Metetra
.664 .741 .907 r
.64031 .52111 .64114 .52206 .64673 .52037 .6459 .51943 Metetra
.664 .741 .907 r
.6459 .51943 .64673 .52037 .65232 .51868 .6515 .51773 Metetra
.664 .741 .907 r
.6515 .51773 .65232 .51868 .65793 .51698 .65711 .51604 Metetra
.664 .741 .907 r
.65711 .51604 .65793 .51698 .66356 .51529 .66273 .51434 Metetra
.664 .741 .907 r
.66273 .51434 .66356 .51529 .66919 .51359 .66837 .51264 Metetra
.664 .741 .907 r
.66837 .51264 .66919 .51359 .67483 .51188 .67402 .51093 Metetra
.664 .741 .907 r
.67402 .51093 .67483 .51188 .68049 .51017 .67967 .50922 Metetra
.664 .741 .907 r
.67967 .50922 .68049 .51017 .68615 .50846 .68534 .50751 Metetra
.664 .741 .907 r
.68534 .50751 .68615 .50846 .69183 .50675 .69102 .50579 Metetra
.664 .741 .907 r
.69102 .50579 .69183 .50675 .69752 .50503 .69671 .50407 Metetra
.664 .741 .907 r
.69671 .50407 .69752 .50503 .70322 .50331 .70242 .50235 Metetra
.664 .741 .907 r
.70242 .50235 .70322 .50331 .70893 .50159 .70813 .50062 Metetra
.664 .741 .907 r
.70813 .50062 .70893 .50159 .71466 .49986 .71386 .49889 Metetra
.664 .741 .907 r
.71386 .49889 .71466 .49986 .72039 .49813 .71959 .49716 Metetra
.664 .741 .907 r
.71959 .49716 .72039 .49813 .72614 .49639 .72534 .49542 Metetra
.664 .741 .907 r
.72534 .49542 .72614 .49639 .7319 .49465 .7311 .49368 Metetra
.664 .741 .907 r
.7311 .49368 .7319 .49465 .73767 .49291 .73688 .49194 Metetra
.664 .741 .907 r
.73688 .49194 .73767 .49291 .74345 .49116 .74266 .49019 Metetra
.664 .741 .907 r
.74266 .49019 .74345 .49116 .74924 .48942 .74846 .48844 Metetra
.664 .741 .907 r
.74846 .48844 .74924 .48942 .75505 .48766 .75426 .48668 Metetra
.664 .741 .907 r
.75426 .48668 .75505 .48766 .76086 .48591 .76008 .48492 Metetra
.664 .741 .907 r
.76008 .48492 .76086 .48591 .76669 .48415 .76592 .48316 Metetra
.664 .741 .907 r
.76592 .48316 .76669 .48415 .77253 .48238 .77176 .4814 Metetra
.664 .741 .907 r
.77176 .4814 .77253 .48238 .77839 .48062 .77761 .47963 Metetra
.664 .741 .907 r
.77761 .47963 .77839 .48062 .78425 .47884 .78348 .47786 Metetra
.664 .741 .907 r
.78348 .47786 .78425 .47884 .79013 .47707 .78936 .47608 Metetra
.664 .741 .907 r
.78936 .47608 .79013 .47707 .79602 .47529 .79525 .4743 Metetra
.664 .741 .907 r
.79525 .4743 .79602 .47529 .80192 .47351 .80115 .47252 Metetra
.664 .741 .907 r
.80115 .47252 .80192 .47351 .80783 .47173 .80707 .47073 Metetra
.664 .741 .907 r
.80707 .47073 .80783 .47173 .81375 .46994 .813 .46894 Metetra
.664 .741 .907 r
.813 .46894 .81375 .46994 .81969 .46814 .81894 .46714 Metetra
.664 .741 .907 r
.81894 .46714 .81969 .46814 .82564 .46635 .82489 .46535 Metetra
.664 .741 .907 r
.82489 .46535 .82564 .46635 .8316 .46455 .83085 .46354 Metetra
.664 .741 .907 r
.83085 .46354 .8316 .46455 .83757 .46275 .83683 .46174 Metetra
.664 .741 .907 r
.83683 .46174 .83757 .46275 .84356 .46094 .84282 .45993 Metetra
.664 .741 .907 r
.84282 .45993 .84356 .46094 .84956 .45913 .84882 .45812 Metetra
.664 .741 .907 r
.84882 .45812 .84956 .45913 .85557 .45731 .85483 .4563 Metetra
.664 .741 .907 r
.85483 .4563 .85557 .45731 .86159 .45549 .86086 .45448 Metetra
.664 .741 .907 r
.86086 .45448 .86159 .45549 .86763 .45367 .86689 .45265 Metetra
.664 .741 .907 r
.86689 .45265 .86763 .45367 .87367 .45185 .87294 .45083 Metetra
.664 .741 .907 r
.87294 .45083 .87367 .45185 .87974 .45002 .87901 .44899 Metetra
.664 .741 .907 r
.87901 .44899 .87974 .45002 .88581 .44818 .88508 .44716 Metetra
.664 .741 .907 r
.88508 .44716 .88581 .44818 .89189 .44634 .89117 .44532 Metetra
.664 .741 .907 r
.89117 .44532 .89189 .44634 .89799 .4445 .89727 .44347 Metetra
.945 .595 .2 r
.89727 .44347 .89799 .4445 .90867 .48199 .90965 .49566 Metetra
.541 .316 .522 r
.90965 .49566 .90867 .48199 .92887 .59867 .91559 .49136 Metetra
.614 .4 .567 r
.91559 .49136 .92887 .59867 .91636 .43896 .91565 .43792 Metetra
.664 .741 .907 r
.91565 .43792 .91636 .43896 .92251 .4371 .9218 .43606 Metetra
.664 .741 .907 r
.9218 .43606 .92251 .4371 .92867 .43524 .92797 .4342 Metetra
.664 .741 .907 r
.92797 .4342 .92867 .43524 .93485 .43337 .93415 .43233 Metetra
.664 .741 .907 r
.93415 .43233 .93485 .43337 .94104 .43151 .94034 .43046 Metetra
.664 .741 .907 r
.94034 .43046 .94104 .43151 .94724 .42963 .94654 .42859 Metetra
.664 .741 .907 r
.94654 .42859 .94724 .42963 .95345 .42776 .95276 .42671 Metetra
.664 .741 .907 r
.95276 .42671 .95345 .42776 .95968 .42588 .95899 .42483 Metetra
.664 .741 .907 r
.95899 .42483 .95968 .42588 .96592 .42399 .96523 .42294 Metetra
.664 .741 .907 r
.39884 .59293 .39977 .59379 .40489 .59224 .40397 .59138 Metetra
.664 .741 .907 r
.40397 .59138 .40489 .59224 .41002 .59069 .4091 .58983 Metetra
.664 .741 .907 r
.4091 .58983 .41002 .59069 .41516 .58914 .41424 .58827 Metetra
.664 .741 .907 r
.41424 .58827 .41516 .58914 .42031 .58759 .41939 .58672 Metetra
.664 .741 .907 r
.41939 .58672 .42031 .58759 .42547 .58603 .42456 .58515 Metetra
.664 .741 .907 r
.42456 .58515 .42547 .58603 .43064 .58446 .42973 .58359 Metetra
.664 .741 .907 r
.42973 .58359 .43064 .58446 .43582 .5829 .43491 .58202 Metetra
.664 .741 .907 r
.43491 .58202 .43582 .5829 .44101 .58133 .4401 .58045 Metetra
.664 .741 .907 r
.4401 .58045 .44101 .58133 .44621 .57976 .44531 .57888 Metetra
.664 .741 .907 r
.44531 .57888 .44621 .57976 .45142 .57818 .45052 .57731 Metetra
.664 .741 .907 r
.45052 .57731 .45142 .57818 .45664 .57661 .45574 .57573 Metetra
.664 .741 .907 r
.45574 .57573 .45664 .57661 .46187 .57503 .46097 .57414 Metetra
.664 .741 .907 r
.46097 .57414 .46187 .57503 .46711 .57344 .46621 .57256 Metetra
.664 .741 .907 r
.46621 .57256 .46711 .57344 .47236 .57186 .47147 .57097 Metetra
.664 .741 .907 r
.47147 .57097 .47236 .57186 .47762 .57027 .47673 .56938 Metetra
.664 .741 .907 r
.47673 .56938 .47762 .57027 .48289 .56868 .482 .56779 Metetra
.664 .741 .907 r
.482 .56779 .48289 .56868 .48818 .56708 .48728 .56619 Metetra
.664 .741 .907 r
.48728 .56619 .48818 .56708 .49347 .56548 .49258 .56459 Metetra
.664 .741 .907 r
.49258 .56459 .49347 .56548 .49877 .56388 .49788 .56298 Metetra
.664 .741 .907 r
.49788 .56298 .49877 .56388 .50408 .56227 .50319 .56138 Metetra
.664 .741 .907 r
.50319 .56138 .50408 .56227 .5094 .56067 .50852 .55977 Metetra
.664 .741 .907 r
.50852 .55977 .5094 .56067 .51473 .55906 .51385 .55816 Metetra
.664 .741 .907 r
.51385 .55816 .51473 .55906 .52008 .55744 .5192 .55654 Metetra
.664 .741 .907 r
.5192 .55654 .52008 .55744 .52543 .55582 .52455 .55492 Metetra
.664 .741 .907 r
.52455 .55492 .52543 .55582 .53079 .5542 .52992 .5533 Metetra
.664 .741 .907 r
.52992 .5533 .53079 .5542 .53617 .55258 .5353 .55167 Metetra
.664 .741 .907 r
.5353 .55167 .53617 .55258 .54155 .55095 .54068 .55004 Metetra
.664 .741 .907 r
.54068 .55004 .54155 .55095 .54695 .54932 .54608 .54841 Metetra
.664 .741 .907 r
.54608 .54841 .54695 .54932 .55235 .54769 .55149 .54678 Metetra
.664 .741 .907 r
.55149 .54678 .55235 .54769 .55777 .54605 .55691 .54514 Metetra
.664 .741 .907 r
.55691 .54514 .55777 .54605 .5632 .54441 .56233 .5435 Metetra
.664 .741 .907 r
.56233 .5435 .5632 .54441 .56863 .54277 .56777 .54185 Metetra
.664 .741 .907 r
.56777 .54185 .56863 .54277 .57408 .54112 .57322 .5402 Metetra
.664 .741 .907 r
.57322 .5402 .57408 .54112 .57954 .53947 .57869 .53855 Metetra
.664 .741 .907 r
.57869 .53855 .57954 .53947 .58501 .53782 .58416 .5369 Metetra
.664 .741 .907 r
.58416 .5369 .58501 .53782 .59049 .53617 .58964 .53524 Metetra
.664 .741 .907 r
.58964 .53524 .59049 .53617 .59598 .53451 .59513 .53358 Metetra
.664 .741 .907 r
.59513 .53358 .59598 .53451 .60149 .53284 .60064 .53192 Metetra
.664 .741 .907 r
.60064 .53192 .60149 .53284 .607 .53118 .60615 .53025 Metetra
.961 .679 .453 r
.60615 .53025 .607 .53118 .61821 .74689 .61731 .74602 Metetra
.96 .698 .495 r
.61731 .74602 .61821 .74689 .61958 .58267 .61864 .57851 Metetra
.896 .656 .568 r
.61864 .57851 .61958 .58267 .6236 .52616 .62276 .52523 Metetra
.664 .741 .907 r
.62276 .52523 .6236 .52616 .62916 .52448 .62832 .52354 Metetra
.664 .741 .907 r
.62832 .52354 .62916 .52448 .63473 .5228 .63389 .52186 Metetra
.664 .741 .907 r
.63389 .52186 .63473 .5228 .64031 .52111 .63948 .52017 Metetra
.664 .741 .907 r
.63948 .52017 .64031 .52111 .6459 .51943 .64507 .51848 Metetra
.664 .741 .907 r
.64507 .51848 .6459 .51943 .6515 .51773 .65067 .51679 Metetra
.664 .741 .907 r
.65067 .51679 .6515 .51773 .65711 .51604 .65629 .51509 Metetra
.664 .741 .907 r
.65629 .51509 .65711 .51604 .66273 .51434 .66191 .51339 Metetra
.664 .741 .907 r
.66191 .51339 .66273 .51434 .66837 .51264 .66755 .51168 Metetra
.664 .741 .907 r
.66755 .51168 .66837 .51264 .67402 .51093 .6732 .50998 Metetra
.664 .741 .907 r
.6732 .50998 .67402 .51093 .67967 .50922 .67886 .50827 Metetra
.664 .741 .907 r
.67886 .50827 .67967 .50922 .68534 .50751 .68453 .50655 Metetra
.664 .741 .907 r
.68453 .50655 .68534 .50751 .69102 .50579 .69021 .50483 Metetra
.664 .741 .907 r
.69021 .50483 .69102 .50579 .69671 .50407 .69591 .50311 Metetra
.664 .741 .907 r
.69591 .50311 .69671 .50407 .70242 .50235 .70161 .50139 Metetra
.664 .741 .907 r
.70161 .50139 .70242 .50235 .70813 .50062 .70733 .49966 Metetra
.664 .741 .907 r
.70733 .49966 .70813 .50062 .71386 .49889 .71306 .49793 Metetra
.664 .741 .907 r
.71306 .49793 .71386 .49889 .71959 .49716 .7188 .49619 Metetra
.664 .741 .907 r
.7188 .49619 .71959 .49716 .72534 .49542 .72455 .49445 Metetra
.664 .741 .907 r
.72455 .49445 .72534 .49542 .7311 .49368 .73031 .49271 Metetra
.664 .741 .907 r
.73031 .49271 .7311 .49368 .73688 .49194 .73609 .49096 Metetra
.664 .741 .907 r
.73609 .49096 .73688 .49194 .74266 .49019 .74187 .48921 Metetra
.664 .741 .907 r
.74187 .48921 .74266 .49019 .74846 .48844 .74767 .48746 Metetra
.664 .741 .907 r
.74767 .48746 .74846 .48844 .75426 .48668 .75348 .4857 Metetra
.664 .741 .907 r
.75348 .4857 .75426 .48668 .76008 .48492 .7593 .48394 Metetra
.664 .741 .907 r
.7593 .48394 .76008 .48492 .76592 .48316 .76514 .48218 Metetra
.664 .741 .907 r
.76514 .48218 .76592 .48316 .77176 .4814 .77098 .48041 Metetra
.664 .741 .907 r
.77098 .48041 .77176 .4814 .77761 .47963 .77684 .47864 Metetra
.664 .741 .907 r
.77684 .47864 .77761 .47963 .78348 .47786 .78271 .47687 Metetra
.664 .741 .907 r
.78271 .47687 .78348 .47786 .78936 .47608 .78859 .47509 Metetra
.664 .741 .907 r
.78859 .47509 .78936 .47608 .79525 .4743 .79448 .47331 Metetra
.664 .741 .907 r
.79448 .47331 .79525 .4743 .80115 .47252 .80039 .47152 Metetra
.664 .741 .907 r
.80039 .47152 .80115 .47252 .80707 .47073 .80631 .46973 Metetra
.664 .741 .907 r
.80631 .46973 .80707 .47073 .813 .46894 .81224 .46794 Metetra
.664 .741 .907 r
.81224 .46794 .813 .46894 .81894 .46714 .81818 .46614 Metetra
.664 .741 .907 r
.81818 .46614 .81894 .46714 .82489 .46535 .82413 .46434 Metetra
.664 .741 .907 r
.82413 .46434 .82489 .46535 .83085 .46354 .8301 .46254 Metetra
.664 .741 .907 r
.8301 .46254 .83085 .46354 .83683 .46174 .83608 .46073 Metetra
.664 .741 .907 r
.83608 .46073 .83683 .46174 .84282 .45993 .84207 .45892 Metetra
.664 .741 .907 r
.84207 .45892 .84282 .45993 .84882 .45812 .84807 .4571 Metetra
.664 .741 .907 r
.84807 .4571 .84882 .45812 .85483 .4563 .85409 .45528 Metetra
.664 .741 .907 r
.85409 .45528 .85483 .4563 .86086 .45448 .86012 .45346 Metetra
.664 .741 .907 r
.86012 .45346 .86086 .45448 .86689 .45265 .86616 .45163 Metetra
.664 .741 .907 r
.86616 .45163 .86689 .45265 .87294 .45083 .87221 .4498 Metetra
.664 .741 .907 r
.87221 .4498 .87294 .45083 .87901 .44899 .87828 .44797 Metetra
.664 .741 .907 r
.87828 .44797 .87901 .44899 .88508 .44716 .88436 .44613 Metetra
.664 .741 .907 r
.88436 .44613 .88508 .44716 .89117 .44532 .89045 .44429 Metetra
.664 .741 .907 r
.89045 .44429 .89117 .44532 .89727 .44347 .89655 .44244 Metetra
.95 .604 .217 r
.89655 .44244 .89727 .44347 .90965 .49566 .90968 .50118 Metetra
.835 .517 .451 r
.90968 .50118 .90965 .49566 .91559 .49136 .92058 .53886 Metetra
.343 .195 .531 r
.92058 .53886 .91559 .49136 .91565 .43792 .91494 .43688 Metetra
.664 .741 .907 r
.91494 .43688 .91565 .43792 .9218 .43606 .92109 .43502 Metetra
.664 .741 .907 r
.92109 .43502 .9218 .43606 .92797 .4342 .92726 .43316 Metetra
.664 .741 .907 r
.92726 .43316 .92797 .4342 .93415 .43233 .93344 .43129 Metetra
.664 .741 .907 r
.93344 .43129 .93415 .43233 .94034 .43046 .93964 .42942 Metetra
.664 .741 .907 r
.93964 .42942 .94034 .43046 .94654 .42859 .94584 .42754 Metetra
.664 .741 .907 r
.94584 .42754 .94654 .42859 .95276 .42671 .95206 .42566 Metetra
.664 .741 .907 r
.95206 .42566 .95276 .42671 .95899 .42483 .9583 .42378 Metetra
.664 .741 .907 r
.9583 .42378 .95899 .42483 .96523 .42294 .96454 .42189 Metetra
.664 .741 .907 r
.39792 .59207 .39884 .59293 .40397 .59138 .40304 .59052 Metetra
.664 .741 .907 r
.40304 .59052 .40397 .59138 .4091 .58983 .40818 .58896 Metetra
.664 .741 .907 r
.40818 .58896 .4091 .58983 .41424 .58827 .41332 .58741 Metetra
.664 .741 .907 r
.41332 .58741 .41424 .58827 .41939 .58672 .41848 .58585 Metetra
.664 .741 .907 r
.41848 .58585 .41939 .58672 .42456 .58515 .42364 .58428 Metetra
.664 .741 .907 r
.42364 .58428 .42456 .58515 .42973 .58359 .42882 .58272 Metetra
.664 .741 .907 r
.42882 .58272 .42973 .58359 .43491 .58202 .434 .58115 Metetra
.664 .741 .907 r
.434 .58115 .43491 .58202 .4401 .58045 .43919 .57958 Metetra
.664 .741 .907 r
.43919 .57958 .4401 .58045 .44531 .57888 .4444 .578 Metetra
.664 .741 .907 r
.4444 .578 .44531 .57888 .45052 .57731 .44961 .57643 Metetra
.664 .741 .907 r
.44961 .57643 .45052 .57731 .45574 .57573 .45484 .57484 Metetra
.664 .741 .907 r
.45484 .57484 .45574 .57573 .46097 .57414 .46007 .57326 Metetra
.664 .741 .907 r
.46007 .57326 .46097 .57414 .46621 .57256 .46531 .57167 Metetra
.664 .741 .907 r
.46531 .57167 .46621 .57256 .47147 .57097 .47057 .57008 Metetra
.664 .741 .907 r
.47057 .57008 .47147 .57097 .47673 .56938 .47583 .56849 Metetra
.664 .741 .907 r
.47583 .56849 .47673 .56938 .482 .56779 .48111 .5669 Metetra
.664 .741 .907 r
.48111 .5669 .482 .56779 .48728 .56619 .48639 .5653 Metetra
.664 .741 .907 r
.48639 .5653 .48728 .56619 .49258 .56459 .49169 .56369 Metetra
.664 .741 .907 r
.49169 .56369 .49258 .56459 .49788 .56298 .49699 .56209 Metetra
.664 .741 .907 r
.49699 .56209 .49788 .56298 .50319 .56138 .50231 .56048 Metetra
.664 .741 .907 r
.50231 .56048 .50319 .56138 .50852 .55977 .50763 .55887 Metetra
.664 .741 .907 r
.50763 .55887 .50852 .55977 .51385 .55816 .51297 .55725 Metetra
.664 .741 .907 r
.51297 .55725 .51385 .55816 .5192 .55654 .51832 .55564 Metetra
.664 .741 .907 r
.51832 .55564 .5192 .55654 .52455 .55492 .52368 .55402 Metetra
.664 .741 .907 r
.52368 .55402 .52455 .55492 .52992 .5533 .52904 .55239 Metetra
.664 .741 .907 r
.52904 .55239 .52992 .5533 .5353 .55167 .53442 .55076 Metetra
.664 .741 .907 r
.53442 .55076 .5353 .55167 .54068 .55004 .53981 .54913 Metetra
.664 .741 .907 r
.53981 .54913 .54068 .55004 .54608 .54841 .54521 .5475 Metetra
.664 .741 .907 r
.54521 .5475 .54608 .54841 .55149 .54678 .55062 .54586 Metetra
.664 .741 .907 r
.55062 .54586 .55149 .54678 .55691 .54514 .55604 .54422 Metetra
.664 .741 .907 r
.55604 .54422 .55691 .54514 .56233 .5435 .56147 .54258 Metetra
.664 .741 .907 r
.56147 .54258 .56233 .5435 .56777 .54185 .56691 .54093 Metetra
.664 .741 .907 r
.56691 .54093 .56777 .54185 .57322 .5402 .57237 .53928 Metetra
.664 .741 .907 r
.57237 .53928 .57322 .5402 .57869 .53855 .57783 .53763 Metetra
.664 .741 .907 r
.57783 .53763 .57869 .53855 .58416 .5369 .5833 .53597 Metetra
.664 .741 .907 r
.5833 .53597 .58416 .5369 .58964 .53524 .58879 .53431 Metetra
.664 .741 .907 r
.58879 .53431 .58964 .53524 .59513 .53358 .59428 .53265 Metetra
.664 .741 .907 r
.59428 .53265 .59513 .53358 .60064 .53192 .59979 .53099 Metetra
.664 .741 .907 r
.59979 .53099 .60064 .53192 .60615 .53025 .60531 .52932 Metetra
.961 .679 .453 r
.60531 .52932 .60615 .53025 .61731 .74602 .61642 .74515 Metetra
.96 .698 .493 r
.61642 .74515 .61731 .74602 .61864 .57851 .6175 .56704 Metetra
.776 .548 .589 r
.6175 .56704 .61864 .57851 .62276 .52523 .62193 .52429 Metetra
.664 .741 .907 r
.62193 .52429 .62276 .52523 .62832 .52354 .62749 .52261 Metetra
.664 .741 .907 r
.62749 .52261 .62832 .52354 .63389 .52186 .63306 .52092 Metetra
.664 .741 .907 r
.63306 .52092 .63389 .52186 .63948 .52017 .63864 .51923 Metetra
.664 .741 .907 r
.63864 .51923 .63948 .52017 .64507 .51848 .64424 .51754 Metetra
.664 .741 .907 r
.64424 .51754 .64507 .51848 .65067 .51679 .64984 .51584 Metetra
.664 .741 .907 r
.64984 .51584 .65067 .51679 .65629 .51509 .65546 .51414 Metetra
.664 .741 .907 r
.65546 .51414 .65629 .51509 .66191 .51339 .66109 .51244 Metetra
.664 .741 .907 r
.66109 .51244 .66191 .51339 .66755 .51168 .66673 .51073 Metetra
.664 .741 .907 r
.66673 .51073 .66755 .51168 .6732 .50998 .67238 .50902 Metetra
.664 .741 .907 r
.67238 .50902 .6732 .50998 .67886 .50827 .67804 .50731 Metetra
.664 .741 .907 r
.67804 .50731 .67886 .50827 .68453 .50655 .68371 .50559 Metetra
.664 .741 .907 r
.68371 .50559 .68453 .50655 .69021 .50483 .6894 .50387 Metetra
.664 .741 .907 r
.6894 .50387 .69021 .50483 .69591 .50311 .6951 .50215 Metetra
.664 .741 .907 r
.6951 .50215 .69591 .50311 .70161 .50139 .7008 .50042 Metetra
.664 .741 .907 r
.7008 .50042 .70161 .50139 .70733 .49966 .70652 .49869 Metetra
.664 .741 .907 r
.70652 .49869 .70733 .49966 .71306 .49793 .71225 .49696 Metetra
.664 .741 .907 r
.71225 .49696 .71306 .49793 .7188 .49619 .718 .49522 Metetra
.664 .741 .907 r
.718 .49522 .7188 .49619 .72455 .49445 .72375 .49348 Metetra
.664 .741 .907 r
.72375 .49348 .72455 .49445 .73031 .49271 .72952 .49173 Metetra
.664 .741 .907 r
.72952 .49173 .73031 .49271 .73609 .49096 .73529 .48999 Metetra
.664 .741 .907 r
.73529 .48999 .73609 .49096 .74187 .48921 .74108 .48824 Metetra
.664 .741 .907 r
.74108 .48824 .74187 .48921 .74767 .48746 .74688 .48648 Metetra
.664 .741 .907 r
.74688 .48648 .74767 .48746 .75348 .4857 .7527 .48472 Metetra
.664 .741 .907 r
.7527 .48472 .75348 .4857 .7593 .48394 .75852 .48296 Metetra
.664 .741 .907 r
.75852 .48296 .7593 .48394 .76514 .48218 .76436 .48119 Metetra
.664 .741 .907 r
.76436 .48119 .76514 .48218 .77098 .48041 .77021 .47942 Metetra
.664 .741 .907 r
.77021 .47942 .77098 .48041 .77684 .47864 .77607 .47765 Metetra
.664 .741 .907 r
.77607 .47765 .77684 .47864 .78271 .47687 .78194 .47587 Metetra
.664 .741 .907 r
.78194 .47587 .78271 .47687 .78859 .47509 .78782 .47409 Metetra
.664 .741 .907 r
.78782 .47409 .78859 .47509 .79448 .47331 .79372 .47231 Metetra
.664 .741 .907 r
.79372 .47231 .79448 .47331 .80039 .47152 .79963 .47052 Metetra
.664 .741 .907 r
.79963 .47052 .80039 .47152 .80631 .46973 .80555 .46873 Metetra
.664 .741 .907 r
.80555 .46873 .80631 .46973 .81224 .46794 .81148 .46694 Metetra
.664 .741 .907 r
.81148 .46694 .81224 .46794 .81818 .46614 .81742 .46514 Metetra
.664 .741 .907 r
.81742 .46514 .81818 .46614 .82413 .46434 .82338 .46333 Metetra
.664 .741 .907 r
.82338 .46333 .82413 .46434 .8301 .46254 .82935 .46153 Metetra
.664 .741 .907 r
.82935 .46153 .8301 .46254 .83608 .46073 .83533 .45972 Metetra
.664 .741 .907 r
.83533 .45972 .83608 .46073 .84207 .45892 .84132 .45791 Metetra
.664 .741 .907 r
.84132 .45791 .84207 .45892 .84807 .4571 .84733 .45609 Metetra
.664 .741 .907 r
.84733 .45609 .84807 .4571 .85409 .45528 .85335 .45427 Metetra
.664 .741 .907 r
.85335 .45427 .85409 .45528 .86012 .45346 .85938 .45244 Metetra
.664 .741 .907 r
.85938 .45244 .86012 .45346 .86616 .45163 .86542 .45061 Metetra
.664 .741 .907 r
.86542 .45061 .86616 .45163 .87221 .4498 .87148 .44878 Metetra
.664 .741 .907 r
.87148 .44878 .87221 .4498 .87828 .44797 .87755 .44695 Metetra
.664 .741 .907 r
.87755 .44695 .87828 .44797 .88436 .44613 .88363 .44511 Metetra
.664 .741 .907 r
.88363 .44511 .88436 .44613 .89045 .44429 .88972 .44326 Metetra
.664 .741 .907 r
.88972 .44326 .89045 .44429 .89655 .44244 .89583 .44141 Metetra
.853 .45 0 r
.89583 .44141 .89655 .44244 .90968 .50118 .90469 .46331 Metetra
.379 .241 .564 r
.90469 .46331 .90968 .50118 .92058 .53886 .91965 .5361 Metetra
.972 .688 .432 r
.91965 .5361 .92058 .53886 .91494 .43688 .91423 .43585 Metetra
.664 .741 .907 r
.91423 .43585 .91494 .43688 .92109 .43502 .92038 .43398 Metetra
.664 .741 .907 r
.92038 .43398 .92109 .43502 .92726 .43316 .92656 .43212 Metetra
.664 .741 .907 r
.92656 .43212 .92726 .43316 .93344 .43129 .93274 .43025 Metetra
.664 .741 .907 r
.93274 .43025 .93344 .43129 .93964 .42942 .93894 .42837 Metetra
.664 .741 .907 r
.93894 .42837 .93964 .42942 .94584 .42754 .94515 .42649 Metetra
.664 .741 .907 r
.94515 .42649 .94584 .42754 .95206 .42566 .95137 .42461 Metetra
.664 .741 .907 r
.95137 .42461 .95206 .42566 .9583 .42378 .9576 .42272 Metetra
.664 .741 .907 r
.9576 .42272 .9583 .42378 .96454 .42189 .96385 .42083 Metetra
.664 .741 .907 r
.39699 .5912 .39792 .59207 .40304 .59052 .40212 .58965 Metetra
.664 .741 .907 r
.40212 .58965 .40304 .59052 .40818 .58896 .40726 .58809 Metetra
.664 .741 .907 r
.40726 .58809 .40818 .58896 .41332 .58741 .4124 .58654 Metetra
.664 .741 .907 r
.4124 .58654 .41332 .58741 .41848 .58585 .41756 .58497 Metetra
.664 .741 .907 r
.41756 .58497 .41848 .58585 .42364 .58428 .42272 .58341 Metetra
.664 .741 .907 r
.42272 .58341 .42364 .58428 .42882 .58272 .4279 .58184 Metetra
.664 .741 .907 r
.4279 .58184 .42882 .58272 .434 .58115 .43309 .58027 Metetra
.664 .741 .907 r
.43309 .58027 .434 .58115 .43919 .57958 .43828 .5787 Metetra
.664 .741 .907 r
.43828 .5787 .43919 .57958 .4444 .578 .44349 .57712 Metetra
.664 .741 .907 r
.44349 .57712 .4444 .578 .44961 .57643 .4487 .57554 Metetra
.664 .741 .907 r
.4487 .57554 .44961 .57643 .45484 .57484 .45393 .57396 Metetra
.664 .741 .907 r
.45393 .57396 .45484 .57484 .46007 .57326 .45917 .57238 Metetra
.664 .741 .907 r
.45917 .57238 .46007 .57326 .46531 .57167 .46441 .57079 Metetra
.664 .741 .907 r
.46441 .57079 .46531 .57167 .47057 .57008 .46967 .5692 Metetra
.664 .741 .907 r
.46967 .5692 .47057 .57008 .47583 .56849 .47494 .5676 Metetra
.664 .741 .907 r
.47494 .5676 .47583 .56849 .48111 .5669 .48021 .566 Metetra
.664 .741 .907 r
.48021 .566 .48111 .5669 .48639 .5653 .4855 .5644 Metetra
.664 .741 .907 r
.4855 .5644 .48639 .5653 .49169 .56369 .4908 .5628 Metetra
.664 .741 .907 r
.4908 .5628 .49169 .56369 .49699 .56209 .4961 .56119 Metetra
.664 .741 .907 r
.4961 .56119 .49699 .56209 .50231 .56048 .50142 .55958 Metetra
.664 .741 .907 r
.50142 .55958 .50231 .56048 .50763 .55887 .50675 .55797 Metetra
.664 .741 .907 r
.50675 .55797 .50763 .55887 .51297 .55725 .51209 .55635 Metetra
.664 .741 .907 r
.51209 .55635 .51297 .55725 .51832 .55564 .51744 .55473 Metetra
.664 .741 .907 r
.51744 .55473 .51832 .55564 .52368 .55402 .5228 .55311 Metetra
.664 .741 .907 r
.5228 .55311 .52368 .55402 .52904 .55239 .52817 .55148 Metetra
.664 .741 .907 r
.52817 .55148 .52904 .55239 .53442 .55076 .53355 .54986 Metetra
.664 .741 .907 r
.53355 .54986 .53442 .55076 .53981 .54913 .53894 .54822 Metetra
.664 .741 .907 r
.53894 .54822 .53981 .54913 .54521 .5475 .54434 .54659 Metetra
.664 .741 .907 r
.54434 .54659 .54521 .5475 .55062 .54586 .54975 .54495 Metetra
.664 .741 .907 r
.54975 .54495 .55062 .54586 .55604 .54422 .55517 .54331 Metetra
.664 .741 .907 r
.55517 .54331 .55604 .54422 .56147 .54258 .56061 .54166 Metetra
.664 .741 .907 r
.56061 .54166 .56147 .54258 .56691 .54093 .56605 .54001 Metetra
.664 .741 .907 r
.56605 .54001 .56691 .54093 .57237 .53928 .57151 .53836 Metetra
.664 .741 .907 r
.57151 .53836 .57237 .53928 .57783 .53763 .57697 .53671 Metetra
.664 .741 .907 r
.57697 .53671 .57783 .53763 .5833 .53597 .58245 .53505 Metetra
.664 .741 .907 r
.58245 .53505 .5833 .53597 .58879 .53431 .58793 .53339 Metetra
.664 .741 .907 r
.58793 .53339 .58879 .53431 .59428 .53265 .59343 .53172 Metetra
.664 .741 .907 r
.59343 .53172 .59428 .53265 .59979 .53099 .59894 .53006 Metetra
.931 .549 .203 r
.59894 .53006 .59979 .53099 .60531 .52932 .60495 .54878 Metetra
.861 .591 .529 r
.60495 .54878 .60531 .52932 .61642 .74515 .61552 .74429 Metetra
.96 .697 .491 r
.61552 .74429 .61642 .74515 .6175 .56704 .61605 .54424 Metetra
.648 .439 .587 r
.61605 .54424 .6175 .56704 .62193 .52429 .62109 .52335 Metetra
.664 .741 .907 r
.62109 .52335 .62193 .52429 .62749 .52261 .62665 .52167 Metetra
.664 .741 .907 r
.62665 .52167 .62749 .52261 .63306 .52092 .63222 .51998 Metetra
.664 .741 .907 r
.63222 .51998 .63306 .52092 .63864 .51923 .63781 .51829 Metetra
.664 .741 .907 r
.63781 .51829 .63864 .51923 .64424 .51754 .64341 .51659 Metetra
.664 .741 .907 r
.64341 .51659 .64424 .51754 .64984 .51584 .64901 .51489 Metetra
.664 .741 .907 r
.64901 .51489 .64984 .51584 .65546 .51414 .65463 .51319 Metetra
.664 .741 .907 r
.65463 .51319 .65546 .51414 .66109 .51244 .66026 .51149 Metetra
.664 .741 .907 r
.66026 .51149 .66109 .51244 .66673 .51073 .66591 .50978 Metetra
.664 .741 .907 r
.66591 .50978 .66673 .51073 .67238 .50902 .67156 .50807 Metetra
.664 .741 .907 r
.67156 .50807 .67238 .50902 .67804 .50731 .67722 .50635 Metetra
.664 .741 .907 r
.67722 .50635 .67804 .50731 .68371 .50559 .6829 .50463 Metetra
.664 .741 .907 r
.6829 .50463 .68371 .50559 .6894 .50387 .68859 .50291 Metetra
.664 .741 .907 r
.68859 .50291 .6894 .50387 .6951 .50215 .69429 .50119 Metetra
.664 .741 .907 r
.69429 .50119 .6951 .50215 .7008 .50042 .7 .49946 Metetra
.664 .741 .907 r
.7 .49946 .7008 .50042 .70652 .49869 .70572 .49773 Metetra
.664 .741 .907 r
.70572 .49773 .70652 .49869 .71225 .49696 .71145 .49599 Metetra
.664 .741 .907 r
.71145 .49599 .71225 .49696 .718 .49522 .7172 .49425 Metetra
.664 .741 .907 r
.7172 .49425 .718 .49522 .72375 .49348 .72295 .49251 Metetra
.664 .741 .907 r
.72295 .49251 .72375 .49348 .72952 .49173 .72872 .49076 Metetra
.664 .741 .907 r
.72872 .49076 .72952 .49173 .73529 .48999 .7345 .48901 Metetra
.664 .741 .907 r
.7345 .48901 .73529 .48999 .74108 .48824 .74029 .48726 Metetra
.664 .741 .907 r
.74029 .48726 .74108 .48824 .74688 .48648 .7461 .4855 Metetra
.664 .741 .907 r
.7461 .4855 .74688 .48648 .7527 .48472 .75191 .48374 Metetra
.664 .741 .907 r
.75191 .48374 .7527 .48472 .75852 .48296 .75774 .48197 Metetra
.664 .741 .907 r
.75774 .48197 .75852 .48296 .76436 .48119 .76358 .48021 Metetra
.664 .741 .907 r
.76358 .48021 .76436 .48119 .77021 .47942 .76943 .47844 Metetra
.664 .741 .907 r
.76943 .47844 .77021 .47942 .77607 .47765 .77529 .47666 Metetra
.664 .741 .907 r
.77529 .47666 .77607 .47765 .78194 .47587 .78116 .47488 Metetra
.664 .741 .907 r
.78116 .47488 .78194 .47587 .78782 .47409 .78705 .4731 Metetra
.664 .741 .907 r
.78705 .4731 .78782 .47409 .79372 .47231 .79295 .47131 Metetra
.664 .741 .907 r
.79295 .47131 .79372 .47231 .79963 .47052 .79886 .46952 Metetra
.664 .741 .907 r
.79886 .46952 .79963 .47052 .80555 .46873 .80478 .46773 Metetra
.664 .741 .907 r
.80478 .46773 .80555 .46873 .81148 .46694 .81072 .46593 Metetra
.664 .741 .907 r
.81072 .46593 .81148 .46694 .81742 .46514 .81667 .46413 Metetra
.664 .741 .907 r
.81667 .46413 .81742 .46514 .82338 .46333 .82263 .46233 Metetra
.664 .741 .907 r
.82263 .46233 .82338 .46333 .82935 .46153 .8286 .46052 Metetra
.664 .741 .907 r
.8286 .46052 .82935 .46153 .83533 .45972 .83458 .45871 Metetra
.664 .741 .907 r
.83458 .45871 .83533 .45972 .84132 .45791 .84058 .45689 Metetra
.664 .741 .907 r
.84058 .45689 .84132 .45791 .84733 .45609 .84659 .45507 Metetra
.664 .741 .907 r
.84659 .45507 .84733 .45609 .85335 .45427 .85261 .45325 Metetra
.664 .741 .907 r
.85261 .45325 .85335 .45427 .85938 .45244 .85864 .45142 Metetra
.664 .741 .907 r
.85864 .45142 .85938 .45244 .86542 .45061 .86469 .44959 Metetra
.664 .741 .907 r
.86469 .44959 .86542 .45061 .87148 .44878 .87075 .44776 Metetra
.664 .741 .907 r
.87075 .44776 .87148 .44878 .87755 .44695 .87682 .44592 Metetra
.664 .741 .907 r
.87682 .44592 .87755 .44695 .88363 .44511 .8829 .44408 Metetra
0 .305 .797 r
.8829 .44408 .88363 .44511 .88972 .44326 .88976 .44907 Metetra
.414 .182 .451 r
.88976 .44907 .88972 .44326 .89583 .44141 .89511 .44038 Metetra
.664 .741 .907 r
.89511 .44038 .89583 .44141 .90469 .46331 .90123 .43853 Metetra
.343 .222 .567 r
.90123 .43853 .90469 .46331 .91965 .5361 .914 .49318 Metetra
.673 .446 .569 r
.914 .49318 .91965 .5361 .91423 .43585 .91351 .43481 Metetra
.664 .741 .907 r
.91351 .43481 .91423 .43585 .92038 .43398 .91967 .43294 Metetra
.664 .741 .907 r
.91967 .43294 .92038 .43398 .92656 .43212 .92585 .43107 Metetra
.664 .741 .907 r
.92585 .43107 .92656 .43212 .93274 .43025 .93203 .4292 Metetra
.664 .741 .907 r
.93203 .4292 .93274 .43025 .93894 .42837 .93823 .42732 Metetra
.664 .741 .907 r
.93823 .42732 .93894 .42837 .94515 .42649 .94445 .42544 Metetra
.664 .741 .907 r
.94445 .42544 .94515 .42649 .95137 .42461 .95067 .42356 Metetra
.664 .741 .907 r
.95067 .42356 .95137 .42461 .9576 .42272 .95691 .42167 Metetra
.664 .741 .907 r
.95691 .42167 .9576 .42272 .96385 .42083 .96316 .41978 Metetra
.664 .741 .907 r
.39607 .59034 .39699 .5912 .40212 .58965 .40119 .58878 Metetra
.664 .741 .907 r
.40119 .58878 .40212 .58965 .40726 .58809 .40633 .58723 Metetra
.664 .741 .907 r
.40633 .58723 .40726 .58809 .4124 .58654 .41148 .58567 Metetra
.664 .741 .907 r
.41148 .58567 .4124 .58654 .41756 .58497 .41664 .5841 Metetra
.664 .741 .907 r
.41664 .5841 .41756 .58497 .42272 .58341 .42181 .58254 Metetra
.664 .741 .907 r
.42181 .58254 .42272 .58341 .4279 .58184 .42699 .58097 Metetra
.664 .741 .907 r
.42699 .58097 .4279 .58184 .43309 .58027 .43217 .5794 Metetra
.664 .741 .907 r
.43217 .5794 .43309 .58027 .43828 .5787 .43737 .57782 Metetra
.664 .741 .907 r
.43737 .57782 .43828 .5787 .44349 .57712 .44258 .57624 Metetra
.664 .741 .907 r
.44258 .57624 .44349 .57712 .4487 .57554 .4478 .57466 Metetra
.664 .741 .907 r
.4478 .57466 .4487 .57554 .45393 .57396 .45302 .57308 Metetra
.664 .741 .907 r
.45302 .57308 .45393 .57396 .45917 .57238 .45826 .57149 Metetra
.664 .741 .907 r
.45826 .57149 .45917 .57238 .46441 .57079 .46351 .5699 Metetra
.664 .741 .907 r
.46351 .5699 .46441 .57079 .46967 .5692 .46877 .56831 Metetra
.664 .741 .907 r
.46877 .56831 .46967 .5692 .47494 .5676 .47404 .56671 Metetra
.664 .741 .907 r
.47404 .56671 .47494 .5676 .48021 .566 .47932 .56511 Metetra
.664 .741 .907 r
.47932 .56511 .48021 .566 .4855 .5644 .48461 .56351 Metetra
.664 .741 .907 r
.48461 .56351 .4855 .5644 .4908 .5628 .4899 .5619 Metetra
.664 .741 .907 r
.4899 .5619 .4908 .5628 .4961 .56119 .49521 .56029 Metetra
.664 .741 .907 r
.49521 .56029 .4961 .56119 .50142 .55958 .50053 .55868 Metetra
.664 .741 .907 r
.50053 .55868 .50142 .55958 .50675 .55797 .50586 .55707 Metetra
.664 .741 .907 r
.50586 .55707 .50675 .55797 .51209 .55635 .5112 .55545 Metetra
.664 .741 .907 r
.5112 .55545 .51209 .55635 .51744 .55473 .51656 .55383 Metetra
.664 .741 .907 r
.51656 .55383 .51744 .55473 .5228 .55311 .52192 .5522 Metetra
.664 .741 .907 r
.52192 .5522 .5228 .55311 .52817 .55148 .52729 .55058 Metetra
.664 .741 .907 r
.52729 .55058 .52817 .55148 .53355 .54986 .53267 .54895 Metetra
.664 .741 .907 r
.53267 .54895 .53355 .54986 .53894 .54822 .53806 .54731 Metetra
.664 .741 .907 r
.53806 .54731 .53894 .54822 .54434 .54659 .54347 .54567 Metetra
.664 .741 .907 r
.54347 .54567 .54434 .54659 .54975 .54495 .54888 .54403 Metetra
.664 .741 .907 r
.54888 .54403 .54975 .54495 .55517 .54331 .55431 .54239 Metetra
.664 .741 .907 r
.55431 .54239 .55517 .54331 .56061 .54166 .55974 .54074 Metetra
.664 .741 .907 r
.55974 .54074 .56061 .54166 .56605 .54001 .56519 .53909 Metetra
.664 .741 .907 r
.56519 .53909 .56605 .54001 .57151 .53836 .57064 .53744 Metetra
.664 .741 .907 r
.57064 .53744 .57151 .53836 .57697 .53671 .57611 .53578 Metetra
.664 .741 .907 r
.57611 .53578 .57697 .53671 .58245 .53505 .58159 .53412 Metetra
.664 .741 .907 r
.58159 .53412 .58245 .53505 .58793 .53339 .58708 .53246 Metetra
.664 .741 .907 r
.58708 .53246 .58793 .53339 .59343 .53172 .59258 .53079 Metetra
.664 .741 .907 r
.59258 .53079 .59343 .53172 .59894 .53006 .59809 .52912 Metetra
.961 .66 .413 r
.59809 .52912 .59894 .53006 .60495 .54878 .60528 .5985 Metetra
.736 .49 .557 r
.60528 .5985 .60495 .54878 .61552 .74429 .61462 .74342 Metetra
.96 .696 .489 r
.61462 .74342 .61552 .74429 .61605 .54424 .61469 .52409 Metetra
.583 .392 .588 r
.61469 .52409 .61605 .54424 .62109 .52335 .62024 .52241 Metetra
.664 .741 .907 r
.62024 .52241 .62109 .52335 .62665 .52167 .62581 .52072 Metetra
.664 .741 .907 r
.62581 .52072 .62665 .52167 .63222 .51998 .63139 .51904 Metetra
.664 .741 .907 r
.63139 .51904 .63222 .51998 .63781 .51829 .63698 .51734 Metetra
.664 .741 .907 r
.63698 .51734 .63781 .51829 .64341 .51659 .64257 .51565 Metetra
.664 .741 .907 r
.64257 .51565 .64341 .51659 .64901 .51489 .64819 .51395 Metetra
.664 .741 .907 r
.64819 .51395 .64901 .51489 .65463 .51319 .65381 .51224 Metetra
.664 .741 .907 r
.65381 .51224 .65463 .51319 .66026 .51149 .65944 .51054 Metetra
.664 .741 .907 r
.65944 .51054 .66026 .51149 .66591 .50978 .66508 .50883 Metetra
.664 .741 .907 r
.66508 .50883 .66591 .50978 .67156 .50807 .67074 .50711 Metetra
.664 .741 .907 r
.67074 .50711 .67156 .50807 .67722 .50635 .67641 .50539 Metetra
.664 .741 .907 r
.67641 .50539 .67722 .50635 .6829 .50463 .68208 .50367 Metetra
.664 .741 .907 r
.68208 .50367 .6829 .50463 .68859 .50291 .68777 .50195 Metetra
.664 .741 .907 r
.68777 .50195 .68859 .50291 .69429 .50119 .69348 .50022 Metetra
.664 .741 .907 r
.69348 .50022 .69429 .50119 .7 .49946 .69919 .49849 Metetra
.664 .741 .907 r
.69919 .49849 .7 .49946 .70572 .49773 .70491 .49676 Metetra
.664 .741 .907 r
.70491 .49676 .70572 .49773 .71145 .49599 .71065 .49502 Metetra
.664 .741 .907 r
.71065 .49502 .71145 .49599 .7172 .49425 .71639 .49328 Metetra
.664 .741 .907 r
.71639 .49328 .7172 .49425 .72295 .49251 .72215 .49153 Metetra
.664 .741 .907 r
.72215 .49153 .72295 .49251 .72872 .49076 .72792 .48978 Metetra
.664 .741 .907 r
.72792 .48978 .72872 .49076 .7345 .48901 .73371 .48803 Metetra
.664 .741 .907 r
.73371 .48803 .7345 .48901 .74029 .48726 .7395 .48628 Metetra
.664 .741 .907 r
.7395 .48628 .74029 .48726 .7461 .4855 .74531 .48452 Metetra
.664 .741 .907 r
.74531 .48452 .7461 .4855 .75191 .48374 .75112 .48276 Metetra
.664 .741 .907 r
.75112 .48276 .75191 .48374 .75774 .48197 .75695 .48099 Metetra
.664 .741 .907 r
.75695 .48099 .75774 .48197 .76358 .48021 .76279 .47922 Metetra
.664 .741 .907 r
.76279 .47922 .76358 .48021 .76943 .47844 .76865 .47745 Metetra
.664 .741 .907 r
.76865 .47745 .76943 .47844 .77529 .47666 .77451 .47567 Metetra
.664 .741 .907 r
.77451 .47567 .77529 .47666 .78116 .47488 .78039 .47389 Metetra
.664 .741 .907 r
.78039 .47389 .78116 .47488 .78705 .4731 .78628 .4721 Metetra
.664 .741 .907 r
.78628 .4721 .78705 .4731 .79295 .47131 .79218 .47032 Metetra
.664 .741 .907 r
.79218 .47032 .79295 .47131 .79886 .46952 .79809 .46852 Metetra
.664 .741 .907 r
.79809 .46852 .79886 .46952 .80478 .46773 .80402 .46673 Metetra
.664 .741 .907 r
.80402 .46673 .80478 .46773 .81072 .46593 .80996 .46493 Metetra
.664 .741 .907 r
.80996 .46493 .81072 .46593 .81667 .46413 .81591 .46313 Metetra
.664 .741 .907 r
.81591 .46313 .81667 .46413 .82263 .46233 .82187 .46132 Metetra
.664 .741 .907 r
.82187 .46132 .82263 .46233 .8286 .46052 .82784 .45951 Metetra
.664 .741 .907 r
.82784 .45951 .8286 .46052 .83458 .45871 .83383 .4577 Metetra
.664 .741 .907 r
.83383 .4577 .83458 .45871 .84058 .45689 .83983 .45588 Metetra
.664 .741 .907 r
.83983 .45588 .84058 .45689 .84659 .45507 .84584 .45406 Metetra
.664 .741 .907 r
.84584 .45406 .84659 .45507 .85261 .45325 .85187 .45223 Metetra
.664 .741 .907 r
.85187 .45223 .85261 .45325 .85864 .45142 .8579 .4504 Metetra
.664 .741 .907 r
.8579 .4504 .85864 .45142 .86469 .44959 .86395 .44857 Metetra
.664 .741 .907 r
.86395 .44857 .86469 .44959 .87075 .44776 .87001 .44673 Metetra
.664 .741 .907 r
.87001 .44673 .87075 .44776 .87682 .44592 .87609 .44489 Metetra
.664 .741 .907 r
.87609 .44489 .87682 .44592 .8829 .44408 .88217 .44305 Metetra
.664 .741 .907 r
.88217 .44305 .8829 .44408 .88976 .44907 .88827 .4412 Metetra
.599 .433 .628 r
.88827 .4412 .88976 .44907 .89511 .44038 .89439 .43935 Metetra
.664 .741 .907 r
.89439 .43935 .89511 .44038 .90123 .43853 .90051 .43749 Metetra
0 .291 .789 r
.90051 .43749 .90123 .43853 .914 .49318 .90748 .44272 Metetra
.589 .385 .573 r
.90748 .44272 .914 .49318 .91351 .43481 .9128 .43377 Metetra
.664 .741 .907 r
.9128 .43377 .91351 .43481 .91967 .43294 .91896 .4319 Metetra
.664 .741 .907 r
.91896 .4319 .91967 .43294 .92585 .43107 .92514 .43003 Metetra
.664 .741 .907 r
.92514 .43003 .92585 .43107 .93203 .4292 .93133 .42815 Metetra
.664 .741 .907 r
.93133 .42815 .93203 .4292 .93823 .42732 .93753 .42628 Metetra
.664 .741 .907 r
.93753 .42628 .93823 .42732 .94445 .42544 .94375 .42439 Metetra
.664 .741 .907 r
.94375 .42439 .94445 .42544 .95067 .42356 .94997 .4225 Metetra
.664 .741 .907 r
.94997 .4225 .95067 .42356 .95691 .42167 .95622 .42061 Metetra
.664 .741 .907 r
.95622 .42061 .95691 .42167 .96316 .41978 .96247 .41872 Metetra
.664 .741 .907 r
.39514 .58947 .39607 .59034 .40119 .58878 .40027 .58791 Metetra
.664 .741 .907 r
.40027 .58791 .40119 .58878 .40633 .58723 .40541 .58636 Metetra
.664 .741 .907 r
.40541 .58636 .40633 .58723 .41148 .58567 .41056 .58479 Metetra
.664 .741 .907 r
.41056 .58479 .41148 .58567 .41664 .5841 .41572 .58323 Metetra
.664 .741 .907 r
.41572 .58323 .41664 .5841 .42181 .58254 .42089 .58166 Metetra
.664 .741 .907 r
.42089 .58166 .42181 .58254 .42699 .58097 .42607 .58009 Metetra
.664 .741 .907 r
.42607 .58009 .42699 .58097 .43217 .5794 .43126 .57852 Metetra
.664 .741 .907 r
.43126 .57852 .43217 .5794 .43737 .57782 .43646 .57694 Metetra
.664 .741 .907 r
.43646 .57694 .43737 .57782 .44258 .57624 .44167 .57536 Metetra
.664 .741 .907 r
.44167 .57536 .44258 .57624 .4478 .57466 .44689 .57378 Metetra
.664 .741 .907 r
.44689 .57378 .4478 .57466 .45302 .57308 .45212 .57219 Metetra
.664 .741 .907 r
.45212 .57219 .45302 .57308 .45826 .57149 .45736 .5706 Metetra
.664 .741 .907 r
.45736 .5706 .45826 .57149 .46351 .5699 .46261 .56901 Metetra
.947 .612 .355 r
.46261 .56901 .46351 .5699 .46877 .56831 .46744 .59308 Metetra
.528 .315 .534 r
.46744 .59308 .46877 .56831 .47404 .56671 .47288 .58282 Metetra
.43 .227 .501 r
.47288 .58282 .47404 .56671 .47932 .56511 .47842 .56422 Metetra
.664 .741 .907 r
.47842 .56422 .47932 .56511 .48461 .56351 .48371 .56261 Metetra
.664 .741 .907 r
.48371 .56261 .48461 .56351 .4899 .5619 .48901 .56101 Metetra
.664 .741 .907 r
.48901 .56101 .4899 .5619 .49521 .56029 .49432 .5594 Metetra
.664 .741 .907 r
.49432 .5594 .49521 .56029 .50053 .55868 .49964 .55778 Metetra
.664 .741 .907 r
.49964 .55778 .50053 .55868 .50586 .55707 .50498 .55617 Metetra
.664 .741 .907 r
.50498 .55617 .50586 .55707 .5112 .55545 .51032 .55455 Metetra
.664 .741 .907 r
.51032 .55455 .5112 .55545 .51656 .55383 .51567 .55292 Metetra
.664 .741 .907 r
.51567 .55292 .51656 .55383 .52192 .5522 .52104 .5513 Metetra
.664 .741 .907 r
.52104 .5513 .52192 .5522 .52729 .55058 .52641 .54967 Metetra
.664 .741 .907 r
.52641 .54967 .52729 .55058 .53267 .54895 .53179 .54803 Metetra
.664 .741 .907 r
.53179 .54803 .53267 .54895 .53806 .54731 .53719 .5464 Metetra
.664 .741 .907 r
.53719 .5464 .53806 .54731 .54347 .54567 .5426 .54476 Metetra
.664 .741 .907 r
.5426 .54476 .54347 .54567 .54888 .54403 .54801 .54312 Metetra
.664 .741 .907 r
.54801 .54312 .54888 .54403 .55431 .54239 .55344 .54147 Metetra
.664 .741 .907 r
.55344 .54147 .55431 .54239 .55974 .54074 .55888 .53982 Metetra
.664 .741 .907 r
.55888 .53982 .55974 .54074 .56519 .53909 .56432 .53817 Metetra
.664 .741 .907 r
.56432 .53817 .56519 .53909 .57064 .53744 .56978 .53652 Metetra
.664 .741 .907 r
.56978 .53652 .57064 .53744 .57611 .53578 .57525 .53486 Metetra
.664 .741 .907 r
.57525 .53486 .57611 .53578 .58159 .53412 .58073 .5332 Metetra
.664 .741 .907 r
.58073 .5332 .58159 .53412 .58708 .53246 .58622 .53153 Metetra
.664 .741 .907 r
.58622 .53153 .58708 .53246 .59258 .53079 .59173 .52986 Metetra
.664 .741 .907 r
.59173 .52986 .59258 .53079 .59809 .52912 .59724 .52819 Metetra
.961 .661 .415 r
.59724 .52819 .59809 .52912 .60528 .5985 .60446 .59962 Metetra
.932 .629 .446 r
.60446 .59962 .60528 .5985 .61462 .74342 .61166 .65973 Metetra
.693 .464 .572 r
.61166 .65973 .61462 .74342 .61469 .52409 .61385 .52316 Metetra
.664 .741 .907 r
.61385 .52316 .61469 .52409 .62024 .52241 .6194 .52147 Metetra
.664 .741 .907 r
.6194 .52147 .62024 .52241 .62581 .52072 .62497 .51978 Metetra
.664 .741 .907 r
.62497 .51978 .62581 .52072 .63139 .51904 .63055 .51809 Metetra
.664 .741 .907 r
.63055 .51809 .63139 .51904 .63698 .51734 .63614 .5164 Metetra
.664 .741 .907 r
.63614 .5164 .63698 .51734 .64257 .51565 .64174 .5147 Metetra
.664 .741 .907 r
.64174 .5147 .64257 .51565 .64819 .51395 .64735 .513 Metetra
.664 .741 .907 r
.64735 .513 .64819 .51395 .65381 .51224 .65298 .51129 Metetra
.664 .741 .907 r
.65298 .51129 .65381 .51224 .65944 .51054 .65861 .50958 Metetra
.664 .741 .907 r
.65861 .50958 .65944 .51054 .66508 .50883 .66426 .50787 Metetra
.664 .741 .907 r
.66426 .50787 .66508 .50883 .67074 .50711 .66992 .50615 Metetra
.664 .741 .907 r
.66992 .50615 .67074 .50711 .67641 .50539 .67559 .50444 Metetra
.664 .741 .907 r
.67559 .50444 .67641 .50539 .68208 .50367 .68127 .50271 Metetra
.664 .741 .907 r
.68127 .50271 .68208 .50367 .68777 .50195 .68696 .50099 Metetra
.664 .741 .907 r
.68696 .50099 .68777 .50195 .69348 .50022 .69266 .49926 Metetra
.664 .741 .907 r
.69266 .49926 .69348 .50022 .69919 .49849 .69838 .49752 Metetra
.664 .741 .907 r
.69838 .49752 .69919 .49849 .70491 .49676 .7041 .49579 Metetra
.664 .741 .907 r
.7041 .49579 .70491 .49676 .71065 .49502 .70984 .49405 Metetra
.664 .741 .907 r
.70984 .49405 .71065 .49502 .71639 .49328 .71559 .49231 Metetra
.664 .741 .907 r
.71559 .49231 .71639 .49328 .72215 .49153 .72135 .49056 Metetra
.664 .741 .907 r
.72135 .49056 .72215 .49153 .72792 .48978 .72713 .48881 Metetra
.664 .741 .907 r
.72713 .48881 .72792 .48978 .73371 .48803 .73291 .48705 Metetra
.664 .741 .907 r
.73291 .48705 .73371 .48803 .7395 .48628 .73871 .4853 Metetra
.664 .741 .907 r
.73871 .4853 .7395 .48628 .74531 .48452 .74452 .48354 Metetra
.664 .741 .907 r
.74452 .48354 .74531 .48452 .75112 .48276 .75034 .48177 Metetra
.664 .741 .907 r
.75034 .48177 .75112 .48276 .75695 .48099 .75617 .48 Metetra
.664 .741 .907 r
.75617 .48 .75695 .48099 .76279 .47922 .76201 .47823 Metetra
.664 .741 .907 r
.76201 .47823 .76279 .47922 .76865 .47745 .76787 .47645 Metetra
.664 .741 .907 r
.76787 .47645 .76865 .47745 .77451 .47567 .77374 .47468 Metetra
.664 .741 .907 r
.77374 .47468 .77451 .47567 .78039 .47389 .77962 .47289 Metetra
.664 .741 .907 r
.77962 .47289 .78039 .47389 .78628 .4721 .78551 .47111 Metetra
.664 .741 .907 r
.78551 .47111 .78628 .4721 .79218 .47032 .79141 .46932 Metetra
.664 .741 .907 r
.79141 .46932 .79218 .47032 .79809 .46852 .79733 .46752 Metetra
.664 .741 .907 r
.79733 .46752 .79809 .46852 .80402 .46673 .80326 .46573 Metetra
.664 .741 .907 r
.80326 .46573 .80402 .46673 .80996 .46493 .8092 .46392 Metetra
.664 .741 .907 r
.8092 .46392 .80996 .46493 .81591 .46313 .81515 .46212 Metetra
.664 .741 .907 r
.81515 .46212 .81591 .46313 .82187 .46132 .82111 .46031 Metetra
.664 .741 .907 r
.82111 .46031 .82187 .46132 .82784 .45951 .82709 .4585 Metetra
.664 .741 .907 r
.82709 .4585 .82784 .45951 .83383 .4577 .83308 .45668 Metetra
.664 .741 .907 r
.83308 .45668 .83383 .4577 .83983 .45588 .83908 .45486 Metetra
.664 .741 .907 r
.83908 .45486 .83983 .45588 .84584 .45406 .8451 .45304 Metetra
.664 .741 .907 r
.8451 .45304 .84584 .45406 .85187 .45223 .85112 .45121 Metetra
.664 .741 .907 r
.85112 .45121 .85187 .45223 .8579 .4504 .85716 .44938 Metetra
.664 .741 .907 r
.85716 .44938 .8579 .4504 .86395 .44857 .86321 .44755 Metetra
.664 .741 .907 r
.86321 .44755 .86395 .44857 .87001 .44673 .86928 .44571 Metetra
.664 .741 .907 r
.86928 .44571 .87001 .44673 .87609 .44489 .87535 .44386 Metetra
.664 .741 .907 r
.87535 .44386 .87609 .44489 .88217 .44305 .88144 .44202 Metetra
.664 .741 .907 r
.88144 .44202 .88217 .44305 .88827 .4412 .88755 .44017 Metetra
.664 .741 .907 r
.88755 .44017 .88827 .4412 .89439 .43935 .89366 .43831 Metetra
.664 .741 .907 r
.89366 .43831 .89439 .43935 .90051 .43749 .89979 .43646 Metetra
.664 .741 .907 r
.89979 .43646 .90051 .43749 .90748 .44272 .90593 .43459 Metetra
.598 .431 .626 r
.90593 .43459 .90748 .44272 .9128 .43377 .91208 .43273 Metetra
.664 .741 .907 r
.91208 .43273 .9128 .43377 .91896 .4319 .91825 .43086 Metetra
.664 .741 .907 r
.91825 .43086 .91896 .4319 .92514 .43003 .92443 .42898 Metetra
.664 .741 .907 r
.92443 .42898 .92514 .43003 .93133 .42815 .93062 .42711 Metetra
.664 .741 .907 r
.93062 .42711 .93133 .42815 .93753 .42628 .93683 .42523 Metetra
.664 .741 .907 r
.93683 .42523 .93753 .42628 .94375 .42439 .94304 .42334 Metetra
.664 .741 .907 r
.94304 .42334 .94375 .42439 .94997 .4225 .94928 .42145 Metetra
.664 .741 .907 r
.94928 .42145 .94997 .4225 .95622 .42061 .95552 .41956 Metetra
.664 .741 .907 r
.95552 .41956 .95622 .42061 .96247 .41872 .96178 .41766 Metetra
.664 .741 .907 r
.39421 .5886 .39514 .58947 .40027 .58791 .39934 .58705 Metetra
.664 .741 .907 r
.39934 .58705 .40027 .58791 .40541 .58636 .40448 .58548 Metetra
.664 .741 .907 r
.40448 .58548 .40541 .58636 .41056 .58479 .40964 .58392 Metetra
.664 .741 .907 r
.40964 .58392 .41056 .58479 .41572 .58323 .4148 .58236 Metetra
.664 .741 .907 r
.4148 .58236 .41572 .58323 .42089 .58166 .41997 .58079 Metetra
.664 .741 .907 r
.41997 .58079 .42089 .58166 .42607 .58009 .42515 .57921 Metetra
.664 .741 .907 r
.42515 .57921 .42607 .58009 .43126 .57852 .43034 .57764 Metetra
.664 .741 .907 r
.43034 .57764 .43126 .57852 .43646 .57694 .43555 .57606 Metetra
.664 .741 .907 r
.43555 .57606 .43646 .57694 .44167 .57536 .44076 .57448 Metetra
.664 .741 .907 r
.44076 .57448 .44167 .57536 .44689 .57378 .44598 .57289 Metetra
.664 .741 .907 r
.44598 .57289 .44689 .57378 .45212 .57219 .45121 .57131 Metetra
.664 .741 .907 r
.45121 .57131 .45212 .57219 .45736 .5706 .45645 .56972 Metetra
.664 .741 .907 r
.45645 .56972 .45736 .5706 .46261 .56901 .4617 .56812 Metetra
.95 .654 .443 r
.4617 .56812 .46261 .56901 .46744 .59308 .4661 .61709 Metetra
.239 .083 .457 r
.4661 .61709 .46744 .59308 .47288 .58282 .47224 .56493 Metetra
.584 .394 .591 r
.47224 .56493 .47288 .58282 .47842 .56422 .47752 .56332 Metetra
.664 .741 .907 r
.47752 .56332 .47842 .56422 .48371 .56261 .48281 .56172 Metetra
.664 .741 .907 r
.48281 .56172 .48371 .56261 .48901 .56101 .48812 .56011 Metetra
.664 .741 .907 r
.48812 .56011 .48901 .56101 .49432 .5594 .49343 .5585 Metetra
.664 .741 .907 r
.49343 .5585 .49432 .5594 .49964 .55778 .49875 .55688 Metetra
.664 .741 .907 r
.49875 .55688 .49964 .55778 .50498 .55617 .50409 .55526 Metetra
.664 .741 .907 r
.50409 .55526 .50498 .55617 .51032 .55455 .50943 .55364 Metetra
.664 .741 .907 r
.50943 .55364 .51032 .55455 .51567 .55292 .51479 .55202 Metetra
.664 .741 .907 r
.51479 .55202 .51567 .55292 .52104 .5513 .52015 .55039 Metetra
.664 .741 .907 r
.52015 .55039 .52104 .5513 .52641 .54967 .52553 .54876 Metetra
.664 .741 .907 r
.52553 .54876 .52641 .54967 .53179 .54803 .53092 .54712 Metetra
.664 .741 .907 r
.53092 .54712 .53179 .54803 .53719 .5464 .53631 .54548 Metetra
.664 .741 .907 r
.53631 .54548 .53719 .5464 .5426 .54476 .54172 .54384 Metetra
.664 .741 .907 r
.54172 .54384 .5426 .54476 .54801 .54312 .54714 .5422 Metetra
.664 .741 .907 r
.54714 .5422 .54801 .54312 .55344 .54147 .55257 .54055 Metetra
.664 .741 .907 r
.55257 .54055 .55344 .54147 .55888 .53982 .55801 .5389 Metetra
.664 .741 .907 r
.55801 .5389 .55888 .53982 .56432 .53817 .56346 .53725 Metetra
.664 .741 .907 r
.56346 .53725 .56432 .53817 .56978 .53652 .56892 .53559 Metetra
.664 .741 .907 r
.56892 .53559 .56978 .53652 .57525 .53486 .57439 .53393 Metetra
.664 .741 .907 r
.57439 .53393 .57525 .53486 .58073 .5332 .57987 .53227 Metetra
.664 .741 .907 r
.57987 .53227 .58073 .5332 .58622 .53153 .58537 .5306 Metetra
.664 .741 .907 r
.58537 .5306 .58622 .53153 .59173 .52986 .59087 .52893 Metetra
.664 .741 .907 r
.59087 .52893 .59173 .52986 .59724 .52819 .59639 .52726 Metetra
.664 .741 .907 r
.59639 .52726 .59724 .52819 .60446 .59962 .60191 .52558 Metetra
.459 .283 .555 r
.60191 .52558 .60446 .59962 .61166 .65973 .60941 .60324 Metetra
.68 .456 .574 r
.60941 .60324 .61166 .65973 .61385 .52316 .613 .52222 Metetra
.664 .741 .907 r
.613 .52222 .61385 .52316 .6194 .52147 .61856 .52053 Metetra
.664 .741 .907 r
.61856 .52053 .6194 .52147 .62497 .51978 .62413 .51884 Metetra
.664 .741 .907 r
.62413 .51884 .62497 .51978 .63055 .51809 .62971 .51715 Metetra
.664 .741 .907 r
.62971 .51715 .63055 .51809 .63614 .5164 .6353 .51545 Metetra
.664 .741 .907 r
.6353 .51545 .63614 .5164 .64174 .5147 .64091 .51375 Metetra
.664 .741 .907 r
.64091 .51375 .64174 .5147 .64735 .513 .64652 .51205 Metetra
.664 .741 .907 r
.64652 .51205 .64735 .513 .65298 .51129 .65215 .51034 Metetra
.664 .741 .907 r
.65215 .51034 .65298 .51129 .65861 .50958 .65779 .50863 Metetra
.664 .741 .907 r
.65779 .50863 .65861 .50958 .66426 .50787 .66344 .50691 Metetra
.664 .741 .907 r
.66344 .50691 .66426 .50787 .66992 .50615 .6691 .5052 Metetra
.664 .741 .907 r
.6691 .5052 .66992 .50615 .67559 .50444 .67477 .50348 Metetra
.664 .741 .907 r
.67477 .50348 .67559 .50444 .68127 .50271 .68045 .50175 Metetra
.664 .741 .907 r
.68045 .50175 .68127 .50271 .68696 .50099 .68614 .50002 Metetra
.664 .741 .907 r
.68614 .50002 .68696 .50099 .69266 .49926 .69185 .49829 Metetra
.664 .741 .907 r
.69185 .49829 .69266 .49926 .69838 .49752 .69757 .49656 Metetra
.664 .741 .907 r
.69757 .49656 .69838 .49752 .7041 .49579 .7033 .49482 Metetra
.664 .741 .907 r
.7033 .49482 .7041 .49579 .70984 .49405 .70904 .49308 Metetra
.664 .741 .907 r
.70904 .49308 .70984 .49405 .71559 .49231 .71479 .49133 Metetra
.664 .741 .907 r
.71479 .49133 .71559 .49231 .72135 .49056 .72055 .48958 Metetra
.664 .741 .907 r
.72055 .48958 .72135 .49056 .72713 .48881 .72633 .48783 Metetra
.516 .679 .939 r
.72633 .48783 .72713 .48881 .73291 .48705 .73223 .48788 Metetra
.73223 .48788 .73291 .48705 .73871 .4853 .73791 .48431 Metetra
.664 .741 .907 r
.73791 .48431 .73871 .4853 .74452 .48354 .74373 .48255 Metetra
.664 .741 .907 r
.74373 .48255 .74452 .48354 .75034 .48177 .74955 .48078 Metetra
.664 .741 .907 r
.74955 .48078 .75034 .48177 .75617 .48 .75538 .47901 Metetra
.664 .741 .907 r
.75538 .47901 .75617 .48 .76201 .47823 .76123 .47724 Metetra
.664 .741 .907 r
.76123 .47724 .76201 .47823 .76787 .47645 .76709 .47546 Metetra
.664 .741 .907 r
.76709 .47546 .76787 .47645 .77374 .47468 .77296 .47368 Metetra
.664 .741 .907 r
.77296 .47368 .77374 .47468 .77962 .47289 .77884 .4719 Metetra
.664 .741 .907 r
.77884 .4719 .77962 .47289 .78551 .47111 .78473 .47011 Metetra
.664 .741 .907 r
.78473 .47011 .78551 .47111 .79141 .46932 .79064 .46832 Metetra
.664 .741 .907 r
.79064 .46832 .79141 .46932 .79733 .46752 .79656 .46652 Metetra
.664 .741 .907 r
.79656 .46652 .79733 .46752 .80326 .46573 .80249 .46472 Metetra
.664 .741 .907 r
.80249 .46472 .80326 .46573 .8092 .46392 .80843 .46292 Metetra
.664 .741 .907 r
.80843 .46292 .8092 .46392 .81515 .46212 .81439 .46111 Metetra
.664 .741 .907 r
.81439 .46111 .81515 .46212 .82111 .46031 .82036 .4593 Metetra
.664 .741 .907 r
.82036 .4593 .82111 .46031 .82709 .4585 .82634 .45749 Metetra
.664 .741 .907 r
.82634 .45749 .82709 .4585 .83308 .45668 .83233 .45567 Metetra
.664 .741 .907 r
.83233 .45567 .83308 .45668 .83908 .45486 .83833 .45385 Metetra
.664 .741 .907 r
.83833 .45385 .83908 .45486 .8451 .45304 .84435 .45202 Metetra
.664 .741 .907 r
.84435 .45202 .8451 .45304 .85112 .45121 .85038 .45019 Metetra
.664 .741 .907 r
.85038 .45019 .85112 .45121 .85716 .44938 .85642 .44836 Metetra
.664 .741 .907 r
.85642 .44836 .85716 .44938 .86321 .44755 .86248 .44652 Metetra
.664 .741 .907 r
.86248 .44652 .86321 .44755 .86928 .44571 .86854 .44468 Metetra
.664 .741 .907 r
.86854 .44468 .86928 .44571 .87535 .44386 .87462 .44283 Metetra
.664 .741 .907 r
.87462 .44283 .87535 .44386 .88144 .44202 .88071 .44099 Metetra
.664 .741 .907 r
.88071 .44099 .88144 .44202 .88755 .44017 .88682 .43913 Metetra
.664 .741 .907 r
.88682 .43913 .88755 .44017 .89366 .43831 .89294 .43728 Metetra
.664 .741 .907 r
.89294 .43728 .89366 .43831 .89979 .43646 .89907 .43542 Metetra
.607 .716 .922 r
.89907 .43542 .89979 .43646 .90593 .43459 .90531 .4344 Metetra
.622 .942 .951 r
.90531 .4344 .90593 .43459 .91208 .43273 .91137 .43169 Metetra
.664 .741 .907 r
.91137 .43169 .91208 .43273 .91825 .43086 .91754 .42981 Metetra
.664 .741 .907 r
.91754 .42981 .91825 .43086 .92443 .42898 .92372 .42794 Metetra
.664 .741 .907 r
.92372 .42794 .92443 .42898 .93062 .42711 .92991 .42606 Metetra
.664 .741 .907 r
.92991 .42606 .93062 .42711 .93683 .42523 .93612 .42417 Metetra
.664 .741 .907 r
.93612 .42417 .93683 .42523 .94304 .42334 .94234 .42229 Metetra
.664 .741 .907 r
.94234 .42229 .94304 .42334 .94928 .42145 .94858 .4204 Metetra
.664 .741 .907 r
.94858 .4204 .94928 .42145 .95552 .41956 .95482 .4185 Metetra
.664 .741 .907 r
.95482 .4185 .95552 .41956 .96178 .41766 .96109 .4166 Metetra
.664 .741 .907 r
.39328 .58773 .39421 .5886 .39934 .58705 .39841 .58618 Metetra
.664 .741 .907 r
.39841 .58618 .39934 .58705 .40448 .58548 .40356 .58461 Metetra
.664 .741 .907 r
.40356 .58461 .40448 .58548 .40964 .58392 .40871 .58305 Metetra
.664 .741 .907 r
.40871 .58305 .40964 .58392 .4148 .58236 .41388 .58148 Metetra
.664 .741 .907 r
.41388 .58148 .4148 .58236 .41997 .58079 .41905 .57991 Metetra
.664 .741 .907 r
.41905 .57991 .41997 .58079 .42515 .57921 .42423 .57834 Metetra
.664 .741 .907 r
.42423 .57834 .42515 .57921 .43034 .57764 .42943 .57676 Metetra
.664 .741 .907 r
.42943 .57676 .43034 .57764 .43555 .57606 .43463 .57518 Metetra
.664 .741 .907 r
.43463 .57518 .43555 .57606 .44076 .57448 .43984 .5736 Metetra
.664 .741 .907 r
.43984 .5736 .44076 .57448 .44598 .57289 .44507 .57201 Metetra
.664 .741 .907 r
.44507 .57201 .44598 .57289 .45121 .57131 .4503 .57042 Metetra
.664 .741 .907 r
.4503 .57042 .45121 .57131 .45645 .56972 .45555 .56883 Metetra
.664 .741 .907 r
.45555 .56883 .45645 .56972 .4617 .56812 .4608 .56723 Metetra
.95 .656 .446 r
.4608 .56723 .4617 .56812 .4661 .61709 .46515 .61827 Metetra
.972 .749 .543 r
.46515 .61827 .4661 .61709 .47224 .56493 .47134 .56403 Metetra
.664 .741 .907 r
.47134 .56403 .47224 .56493 .47752 .56332 .47662 .56243 Metetra
.664 .741 .907 r
.47662 .56243 .47752 .56332 .48281 .56172 .48192 .56082 Metetra
.664 .741 .907 r
.48192 .56082 .48281 .56172 .48812 .56011 .48722 .55921 Metetra
.664 .741 .907 r
.48722 .55921 .48812 .56011 .49343 .5585 .49254 .5576 Metetra
.664 .741 .907 r
.49254 .5576 .49343 .5585 .49875 .55688 .49786 .55598 Metetra
.664 .741 .907 r
.49786 .55598 .49875 .55688 .50409 .55526 .5032 .55436 Metetra
.664 .741 .907 r
.5032 .55436 .50409 .55526 .50943 .55364 .50855 .55274 Metetra
.664 .741 .907 r
.50855 .55274 .50943 .55364 .51479 .55202 .5139 .55111 Metetra
.664 .741 .907 r
.5139 .55111 .51479 .55202 .52015 .55039 .51927 .54948 Metetra
.664 .741 .907 r
.51927 .54948 .52015 .55039 .52553 .54876 .52465 .54785 Metetra
.664 .741 .907 r
.52465 .54785 .52553 .54876 .53092 .54712 .53004 .54621 Metetra
.664 .741 .907 r
.53004 .54621 .53092 .54712 .53631 .54548 .53544 .54457 Metetra
.664 .741 .907 r
.53544 .54457 .53631 .54548 .54172 .54384 .54085 .54293 Metetra
.664 .741 .907 r
.54085 .54293 .54172 .54384 .54714 .5422 .54627 .54128 Metetra
.664 .741 .907 r
.54627 .54128 .54714 .5422 .55257 .54055 .5517 .53963 Metetra
.664 .741 .907 r
.5517 .53963 .55257 .54055 .55801 .5389 .55714 .53798 Metetra
.664 .741 .907 r
.55714 .53798 .55801 .5389 .56346 .53725 .56259 .53632 Metetra
.664 .741 .907 r
.56259 .53632 .56346 .53725 .56892 .53559 .56806 .53467 Metetra
.664 .741 .907 r
.56806 .53467 .56892 .53559 .57439 .53393 .57353 .533 Metetra
.664 .741 .907 r
.57353 .533 .57439 .53393 .57987 .53227 .57902 .53134 Metetra
.664 .741 .907 r
.57902 .53134 .57987 .53227 .58537 .5306 .58451 .52967 Metetra
.664 .741 .907 r
.58451 .52967 .58537 .5306 .59087 .52893 .59002 .528 Metetra
.664 .741 .907 r
.59002 .528 .59087 .52893 .59639 .52726 .59554 .52632 Metetra
.664 .741 .907 r
.59554 .52632 .59639 .52726 .60191 .52558 .60106 .52464 Metetra
.856 .418 0 r
.60106 .52464 .60191 .52558 .60941 .60324 .60694 .53655 Metetra
.577 .375 .57 r
.60694 .53655 .60941 .60324 .613 .52222 .61247 .53349 Metetra
.428 .217 .49 r
.61247 .53349 .613 .52222 .61856 .52053 .61772 .51959 Metetra
.664 .741 .907 r
.61772 .51959 .61856 .52053 .62413 .51884 .62329 .5179 Metetra
.664 .741 .907 r
.62329 .5179 .62413 .51884 .62971 .51715 .62887 .5162 Metetra
.664 .741 .907 r
.62887 .5162 .62971 .51715 .6353 .51545 .63447 .5145 Metetra
.664 .741 .907 r
.63447 .5145 .6353 .51545 .64091 .51375 .64007 .5128 Metetra
.664 .741 .907 r
.64007 .5128 .64091 .51375 .64652 .51205 .64569 .51109 Metetra
.664 .741 .907 r
.64569 .51109 .64652 .51205 .65215 .51034 .65132 .50938 Metetra
.664 .741 .907 r
.65132 .50938 .65215 .51034 .65779 .50863 .65696 .50767 Metetra
.664 .741 .907 r
.65696 .50767 .65779 .50863 .66344 .50691 .66261 .50596 Metetra
.664 .741 .907 r
.66261 .50596 .66344 .50691 .6691 .5052 .66827 .50424 Metetra
.664 .741 .907 r
.66827 .50424 .6691 .5052 .67477 .50348 .67395 .50251 Metetra
.664 .741 .907 r
.67395 .50251 .67477 .50348 .68045 .50175 .67963 .50079 Metetra
.664 .741 .907 r
.67963 .50079 .68045 .50175 .68614 .50002 .68533 .49906 Metetra
.664 .741 .907 r
.68533 .49906 .68614 .50002 .69185 .49829 .69104 .49732 Metetra
.664 .741 .907 r
.69104 .49732 .69185 .49829 .69757 .49656 .69676 .49559 Metetra
.664 .741 .907 r
.69676 .49559 .69757 .49656 .7033 .49482 .70249 .49385 Metetra
.664 .741 .907 r
.70249 .49385 .7033 .49482 .70904 .49308 .70823 .4921 Metetra
.664 .741 .907 r
.70823 .4921 .70904 .49308 .71479 .49133 .71399 .49036 Metetra
.664 .741 .907 r
.71399 .49036 .71479 .49133 .72055 .48958 .71975 .48861 Metetra
.664 .741 .907 r
.71975 .48861 .72055 .48958 .72633 .48783 .72553 .48685 Metetra
.664 .741 .907 r
.72553 .48685 .72633 .48783 .73223 .48788 .73132 .48509 Metetra
.633 .538 .729 r
.73132 .48509 .73223 .48788 .73791 .48431 .73712 .48333 Metetra
.664 .741 .907 r
.73712 .48333 .73791 .48431 .74373 .48255 .74293 .48157 Metetra
.664 .741 .907 r
.74293 .48157 .74373 .48255 .74955 .48078 .74876 .4798 Metetra
.664 .741 .907 r
.74876 .4798 .74955 .48078 .75538 .47901 .7546 .47803 Metetra
.664 .741 .907 r
.7546 .47803 .75538 .47901 .76123 .47724 .76044 .47625 Metetra
.664 .741 .907 r
.76044 .47625 .76123 .47724 .76709 .47546 .76631 .47447 Metetra
.664 .741 .907 r
.76631 .47447 .76709 .47546 .77296 .47368 .77218 .47269 Metetra
.664 .741 .907 r
.77218 .47269 .77296 .47368 .77884 .4719 .77806 .4709 Metetra
.664 .741 .907 r
.77806 .4709 .77884 .4719 .78473 .47011 .78396 .46911 Metetra
.664 .741 .907 r
.78396 .46911 .78473 .47011 .79064 .46832 .78987 .46732 Metetra
.664 .741 .907 r
.78987 .46732 .79064 .46832 .79656 .46652 .79579 .46552 Metetra
.664 .741 .907 r
.79579 .46552 .79656 .46652 .80249 .46472 .80172 .46372 Metetra
.664 .741 .907 r
.80172 .46372 .80249 .46472 .80843 .46292 .80767 .46191 Metetra
.664 .741 .907 r
.80767 .46191 .80843 .46292 .81439 .46111 .81363 .4601 Metetra
.664 .741 .907 r
.81363 .4601 .81439 .46111 .82036 .4593 .8196 .45829 Metetra
.664 .741 .907 r
.8196 .45829 .82036 .4593 .82634 .45749 .82558 .45647 Metetra
.664 .741 .907 r
.82558 .45647 .82634 .45749 .83233 .45567 .83157 .45465 Metetra
.664 .741 .907 r
.83157 .45465 .83233 .45567 .83833 .45385 .83758 .45283 Metetra
.664 .741 .907 r
.83758 .45283 .83833 .45385 .84435 .45202 .8436 .451 Metetra
.664 .741 .907 r
.8436 .451 .84435 .45202 .85038 .45019 .84963 .44917 Metetra
.664 .741 .907 r
.84963 .44917 .85038 .45019 .85642 .44836 .85568 .44733 Metetra
.664 .741 .907 r
.85568 .44733 .85642 .44836 .86248 .44652 .86174 .44549 Metetra
.664 .741 .907 r
.86174 .44549 .86248 .44652 .86854 .44468 .86781 .44365 Metetra
.664 .741 .907 r
.86781 .44365 .86854 .44468 .87462 .44283 .87389 .4418 Metetra
.664 .741 .907 r
.87389 .4418 .87462 .44283 .88071 .44099 .87998 .43995 Metetra
.664 .741 .907 r
.87998 .43995 .88071 .44099 .88682 .43913 .88609 .4381 Metetra
.664 .741 .907 r
.88609 .4381 .88682 .43913 .89294 .43728 .89221 .43624 Metetra
.664 .741 .907 r
.89221 .43624 .89294 .43728 .89907 .43542 .89834 .43438 Metetra
.664 .741 .907 r
.89834 .43438 .89907 .43542 .90531 .4344 .90449 .43251 Metetra
.651 .613 .798 r
.90449 .43251 .90531 .4344 .91137 .43169 .91065 .43064 Metetra
.664 .741 .907 r
.91065 .43064 .91137 .43169 .91754 .42981 .91682 .42877 Metetra
.664 .741 .907 r
.91682 .42877 .91754 .42981 .92372 .42794 .92301 .42689 Metetra
.664 .741 .907 r
.92301 .42689 .92372 .42794 .92991 .42606 .92921 .42501 Metetra
.664 .741 .907 r
.92921 .42501 .92991 .42606 .93612 .42417 .93542 .42312 Metetra
.664 .741 .907 r
.93542 .42312 .93612 .42417 .94234 .42229 .94164 .42123 Metetra
.664 .741 .907 r
.94164 .42123 .94234 .42229 .94858 .4204 .94788 .41934 Metetra
.664 .741 .907 r
.94788 .41934 .94858 .4204 .95482 .4185 .95413 .41744 Metetra
.664 .741 .907 r
.95413 .41744 .95482 .4185 .96109 .4166 .96039 .41554 Metetra
.664 .741 .907 r
.39235 .58687 .39328 .58773 .39841 .58618 .39749 .5853 Metetra
.664 .741 .907 r
.39749 .5853 .39841 .58618 .40356 .58461 .40263 .58374 Metetra
.664 .741 .907 r
.40263 .58374 .40356 .58461 .40871 .58305 .40779 .58217 Metetra
.664 .741 .907 r
.40779 .58217 .40871 .58305 .41388 .58148 .41295 .5806 Metetra
.664 .741 .907 r
.41295 .5806 .41388 .58148 .41905 .57991 .41813 .57903 Metetra
.664 .741 .907 r
.41813 .57903 .41905 .57991 .42423 .57834 .42331 .57746 Metetra
.664 .741 .907 r
.42331 .57746 .42423 .57834 .42943 .57676 .42851 .57588 Metetra
.664 .741 .907 r
.42851 .57588 .42943 .57676 .43463 .57518 .43371 .5743 Metetra
.664 .741 .907 r
.43371 .5743 .43463 .57518 .43984 .5736 .43893 .57271 Metetra
.664 .741 .907 r
.43893 .57271 .43984 .5736 .44507 .57201 .44416 .57112 Metetra
.664 .741 .907 r
.44416 .57112 .44507 .57201 .4503 .57042 .44939 .56953 Metetra
.664 .741 .907 r
.44939 .56953 .4503 .57042 .45555 .56883 .45464 .56794 Metetra
.664 .741 .907 r
.45464 .56794 .45555 .56883 .4608 .56723 .45989 .56634 Metetra
.664 .741 .907 r
.45989 .56634 .4608 .56723 .46515 .61827 .46516 .56474 Metetra
.576 .375 .571 r
.46516 .56474 .46515 .61827 .47134 .56403 .47044 .56314 Metetra
.664 .741 .907 r
.47044 .56314 .47134 .56403 .47662 .56243 .47572 .56153 Metetra
.664 .741 .907 r
.47572 .56153 .47662 .56243 .48192 .56082 .48102 .55992 Metetra
.664 .741 .907 r
.48102 .55992 .48192 .56082 .48722 .55921 .48633 .55831 Metetra
.664 .741 .907 r
.48633 .55831 .48722 .55921 .49254 .5576 .49164 .55669 Metetra
.664 .741 .907 r
.49164 .55669 .49254 .5576 .49786 .55598 .49697 .55508 Metetra
.664 .741 .907 r
.49697 .55508 .49786 .55598 .5032 .55436 .50231 .55345 Metetra
.664 .741 .907 r
.50231 .55345 .5032 .55436 .50855 .55274 .50766 .55183 Metetra
.664 .741 .907 r
.50766 .55183 .50855 .55274 .5139 .55111 .51302 .5502 Metetra
.664 .741 .907 r
.51302 .5502 .5139 .55111 .51927 .54948 .51839 .54857 Metetra
.664 .741 .907 r
.51839 .54857 .51927 .54948 .52465 .54785 .52377 .54693 Metetra
.664 .741 .907 r
.52377 .54693 .52465 .54785 .53004 .54621 .52916 .5453 Metetra
.664 .741 .907 r
.52916 .5453 .53004 .54621 .53544 .54457 .53456 .54365 Metetra
.664 .741 .907 r
.53456 .54365 .53544 .54457 .54085 .54293 .53997 .54201 Metetra
.664 .741 .907 r
.53997 .54201 .54085 .54293 .54627 .54128 .54539 .54036 Metetra
.664 .741 .907 r
.54539 .54036 .54627 .54128 .5517 .53963 .55083 .53871 Metetra
.664 .741 .907 r
.55083 .53871 .5517 .53963 .55714 .53798 .55627 .53706 Metetra
.664 .741 .907 r
.55627 .53706 .55714 .53798 .56259 .53632 .56173 .5354 Metetra
.664 .741 .907 r
.56173 .5354 .56259 .53632 .56806 .53467 .56719 .53374 Metetra
.664 .741 .907 r
.56719 .53374 .56806 .53467 .57353 .533 .57267 .53208 Metetra
.664 .741 .907 r
.57267 .53208 .57353 .533 .57902 .53134 .57816 .53041 Metetra
.664 .741 .907 r
.57816 .53041 .57902 .53134 .58451 .52967 .58365 .52874 Metetra
.664 .741 .907 r
.58365 .52874 .58451 .52967 .59002 .528 .58916 .52706 Metetra
.664 .741 .907 r
.58916 .52706 .59002 .528 .59554 .52632 .59468 .52539 Metetra
.664 .741 .907 r
.59468 .52539 .59554 .52632 .60106 .52464 .60021 .52371 Metetra
.664 .741 .907 r
.60021 .52371 .60106 .52464 .60694 .53655 .60575 .52202 Metetra
.586 .401 .597 r
.60575 .52202 .60694 .53655 .61247 .53349 .61131 .52033 Metetra
.588 .405 .601 r
.61131 .52033 .61247 .53349 .61772 .51959 .61687 .51864 Metetra
.664 .741 .907 r
.61687 .51864 .61772 .51959 .62329 .5179 .62245 .51695 Metetra
.664 .741 .907 r
.62245 .51695 .62329 .5179 .62887 .5162 .62803 .51525 Metetra
.664 .741 .907 r
.62803 .51525 .62887 .5162 .63447 .5145 .63363 .51355 Metetra
.664 .741 .907 r
.63363 .51355 .63447 .5145 .64007 .5128 .63924 .51185 Metetra
.664 .741 .907 r
.63924 .51185 .64007 .5128 .64569 .51109 .64486 .51014 Metetra
.664 .741 .907 r
.64486 .51014 .64569 .51109 .65132 .50938 .65049 .50843 Metetra
.664 .741 .907 r
.65049 .50843 .65132 .50938 .65696 .50767 .65613 .50672 Metetra
.664 .741 .907 r
.65613 .50672 .65696 .50767 .66261 .50596 .66178 .505 Metetra
.664 .741 .907 r
.66178 .505 .66261 .50596 .66827 .50424 .66745 .50328 Metetra
.664 .741 .907 r
.66745 .50328 .66827 .50424 .67395 .50251 .67312 .50155 Metetra
.664 .741 .907 r
.67312 .50155 .67395 .50251 .67963 .50079 .67881 .49982 Metetra
.664 .741 .907 r
.67881 .49982 .67963 .50079 .68533 .49906 .68451 .49809 Metetra
.664 .741 .907 r
.68451 .49809 .68533 .49906 .69104 .49732 .69022 .49636 Metetra
.664 .741 .907 r
.69022 .49636 .69104 .49732 .69676 .49559 .69594 .49462 Metetra
.664 .741 .907 r
.69594 .49462 .69676 .49559 .70249 .49385 .70168 .49288 Metetra
.664 .741 .907 r
.70168 .49288 .70249 .49385 .70823 .4921 .70742 .49113 Metetra
.664 .741 .907 r
.70742 .49113 .70823 .4921 .71399 .49036 .71318 .48938 Metetra
.664 .741 .907 r
.71318 .48938 .71399 .49036 .71975 .48861 .71895 .48763 Metetra
.664 .741 .907 r
.71895 .48763 .71975 .48861 .72553 .48685 .72473 .48587 Metetra
.664 .741 .907 r
.72473 .48587 .72553 .48685 .73132 .48509 .73052 .48411 Metetra
.664 .741 .907 r
.73052 .48411 .73132 .48509 .73712 .48333 .73633 .48235 Metetra
.664 .741 .907 r
.73633 .48235 .73712 .48333 .74293 .48157 .74214 .48058 Metetra
.664 .741 .907 r
.74214 .48058 .74293 .48157 .74876 .4798 .74797 .47881 Metetra
.664 .741 .907 r
.74797 .47881 .74876 .4798 .7546 .47803 .75381 .47704 Metetra
.664 .741 .907 r
.75381 .47704 .7546 .47803 .76044 .47625 .75966 .47526 Metetra
.664 .741 .907 r
.75966 .47526 .76044 .47625 .76631 .47447 .76552 .47348 Metetra
.664 .741 .907 r
.76552 .47348 .76631 .47447 .77218 .47269 .7714 .47169 Metetra
.664 .741 .907 r
.7714 .47169 .77218 .47269 .77806 .4709 .77729 .4699 Metetra
.664 .741 .907 r
.77729 .4699 .77806 .4709 .78396 .46911 .78319 .46811 Metetra
.664 .741 .907 r
.78319 .46811 .78396 .46911 .78987 .46732 .7891 .46631 Metetra
.664 .741 .907 r
.7891 .46631 .78987 .46732 .79579 .46552 .79502 .46451 Metetra
.664 .741 .907 r
.79502 .46451 .79579 .46552 .80172 .46372 .80096 .46271 Metetra
.664 .741 .907 r
.80096 .46271 .80172 .46372 .80767 .46191 .80691 .4609 Metetra
.664 .741 .907 r
.80691 .4609 .80767 .46191 .81363 .4601 .81287 .45909 Metetra
.664 .741 .907 r
.81287 .45909 .81363 .4601 .8196 .45829 .81884 .45728 Metetra
.664 .741 .907 r
.81884 .45728 .8196 .45829 .82558 .45647 .82482 .45546 Metetra
.664 .741 .907 r
.82482 .45546 .82558 .45647 .83157 .45465 .83082 .45364 Metetra
.664 .741 .907 r
.83082 .45364 .83157 .45465 .83758 .45283 .83683 .45181 Metetra
.664 .741 .907 r
.83683 .45181 .83758 .45283 .8436 .451 .84285 .44998 Metetra
.664 .741 .907 r
.84285 .44998 .8436 .451 .84963 .44917 .84889 .44815 Metetra
.664 .741 .907 r
.84889 .44815 .84963 .44917 .85568 .44733 .85494 .44631 Metetra
.664 .741 .907 r
.85494 .44631 .85568 .44733 .86174 .44549 .861 .44447 Metetra
.664 .741 .907 r
.861 .44447 .86174 .44549 .86781 .44365 .86707 .44262 Metetra
.664 .741 .907 r
.86707 .44262 .86781 .44365 .87389 .4418 .87315 .44077 Metetra
.664 .741 .907 r
.87315 .44077 .87389 .4418 .87998 .43995 .87925 .43892 Metetra
.664 .741 .907 r
.87925 .43892 .87998 .43995 .88609 .4381 .88536 .43706 Metetra
.664 .741 .907 r
.88536 .43706 .88609 .4381 .89221 .43624 .89149 .4352 Metetra
.664 .741 .907 r
.89149 .4352 .89221 .43624 .89834 .43438 .89762 .43334 Metetra
.664 .741 .907 r
.89762 .43334 .89834 .43438 .90449 .43251 .90377 .43147 Metetra
.664 .741 .907 r
.90377 .43147 .90449 .43251 .91065 .43064 .90993 .4296 Metetra
.664 .741 .907 r
.90993 .4296 .91065 .43064 .91682 .42877 .91611 .42772 Metetra
.664 .741 .907 r
.91611 .42772 .91682 .42877 .92301 .42689 .9223 .42584 Metetra
.664 .741 .907 r
.9223 .42584 .92301 .42689 .92921 .42501 .9285 .42396 Metetra
.664 .741 .907 r
.9285 .42396 .92921 .42501 .93542 .42312 .93471 .42207 Metetra
.664 .741 .907 r
.93471 .42207 .93542 .42312 .94164 .42123 .94094 .42018 Metetra
.664 .741 .907 r
.94094 .42018 .94164 .42123 .94788 .41934 .94718 .41828 Metetra
.664 .741 .907 r
.94718 .41828 .94788 .41934 .95413 .41744 .95343 .41638 Metetra
.664 .741 .907 r
.95343 .41638 .95413 .41744 .96039 .41554 .9597 .41448 Metetra
.664 .741 .907 r
.39142 .586 .39235 .58687 .39749 .5853 .39656 .58443 Metetra
.664 .741 .907 r
.39656 .58443 .39749 .5853 .40263 .58374 .4017 .58287 Metetra
.664 .741 .907 r
.4017 .58287 .40263 .58374 .40779 .58217 .40686 .5813 Metetra
.664 .741 .907 r
.40686 .5813 .40779 .58217 .41295 .5806 .41203 .57973 Metetra
.664 .741 .907 r
.41203 .57973 .41295 .5806 .41813 .57903 .41721 .57815 Metetra
.664 .741 .907 r
.41721 .57815 .41813 .57903 .42331 .57746 .42239 .57658 Metetra
.664 .741 .907 r
.42239 .57658 .42331 .57746 .42851 .57588 .42759 .575 Metetra
.664 .741 .907 r
.42759 .575 .42851 .57588 .43371 .5743 .4328 .57341 Metetra
.664 .741 .907 r
.4328 .57341 .43371 .5743 .43893 .57271 .43802 .57183 Metetra
.664 .741 .907 r
.43802 .57183 .43893 .57271 .44416 .57112 .44324 .57024 Metetra
.664 .741 .907 r
.44324 .57024 .44416 .57112 .44939 .56953 .44848 .56864 Metetra
.664 .741 .907 r
.44848 .56864 .44939 .56953 .45464 .56794 .45373 .56705 Metetra
.664 .741 .907 r
.45373 .56705 .45464 .56794 .45989 .56634 .45899 .56545 Metetra
.664 .741 .907 r
.45899 .56545 .45989 .56634 .46516 .56474 .46425 .56385 Metetra
.664 .741 .907 r
.46425 .56385 .46516 .56474 .47044 .56314 .46953 .56224 Metetra
.664 .741 .907 r
.46953 .56224 .47044 .56314 .47572 .56153 .47482 .56063 Metetra
.664 .741 .907 r
.47482 .56063 .47572 .56153 .48102 .55992 .48012 .55902 Metetra
.664 .741 .907 r
.48012 .55902 .48102 .55992 .48633 .55831 .48543 .55741 Metetra
.664 .741 .907 r
.48543 .55741 .48633 .55831 .49164 .55669 .49075 .55579 Metetra
.664 .741 .907 r
.49075 .55579 .49164 .55669 .49697 .55508 .49608 .55417 Metetra
.664 .741 .907 r
.49608 .55417 .49697 .55508 .50231 .55345 .50142 .55255 Metetra
.664 .741 .907 r
.50142 .55255 .50231 .55345 .50766 .55183 .50677 .55092 Metetra
.664 .741 .907 r
.50677 .55092 .50766 .55183 .51302 .5502 .51213 .54929 Metetra
.664 .741 .907 r
.51213 .54929 .51302 .5502 .51839 .54857 .5175 .54766 Metetra
.664 .741 .907 r
.5175 .54766 .51839 .54857 .52377 .54693 .52289 .54602 Metetra
.664 .741 .907 r
.52289 .54602 .52377 .54693 .52916 .5453 .52828 .54438 Metetra
.664 .741 .907 r
.52828 .54438 .52916 .5453 .53456 .54365 .53368 .54274 Metetra
.664 .741 .907 r
.53368 .54274 .53456 .54365 .53997 .54201 .5391 .54109 Metetra
.664 .741 .907 r
.5391 .54109 .53997 .54201 .54539 .54036 .54452 .53944 Metetra
.664 .741 .907 r
.54452 .53944 .54539 .54036 .55083 .53871 .54996 .53779 Metetra
.664 .741 .907 r
.54996 .53779 .55083 .53871 .55627 .53706 .5554 .53613 Metetra
.664 .741 .907 r
.5554 .53613 .55627 .53706 .56173 .5354 .56086 .53447 Metetra
.664 .741 .907 r
.56086 .53447 .56173 .5354 .56719 .53374 .56633 .53281 Metetra
.664 .741 .907 r
.56633 .53281 .56719 .53374 .57267 .53208 .5718 .53115 Metetra
.664 .741 .907 r
.5718 .53115 .57267 .53208 .57816 .53041 .57729 .52948 Metetra
.664 .741 .907 r
.57729 .52948 .57816 .53041 .58365 .52874 .58279 .5278 Metetra
.664 .741 .907 r
.58279 .5278 .58365 .52874 .58916 .52706 .5883 .52613 Metetra
.664 .741 .907 r
.5883 .52613 .58916 .52706 .59468 .52539 .59383 .52445 Metetra
.664 .741 .907 r
.59383 .52445 .59468 .52539 .60021 .52371 .59936 .52277 Metetra
.664 .741 .907 r
.59936 .52277 .60021 .52371 .60575 .52202 .6049 .52108 Metetra
.664 .741 .907 r
.6049 .52108 .60575 .52202 .61131 .52033 .61046 .51939 Metetra
.664 .741 .907 r
.61046 .51939 .61131 .52033 .61687 .51864 .61602 .5177 Metetra
.664 .741 .907 r
.61602 .5177 .61687 .51864 .62245 .51695 .6216 .516 Metetra
.664 .741 .907 r
.6216 .516 .62245 .51695 .62803 .51525 .62719 .5143 Metetra
.664 .741 .907 r
.62719 .5143 .62803 .51525 .63363 .51355 .63279 .5126 Metetra
.664 .741 .907 r
.63279 .5126 .63363 .51355 .63924 .51185 .6384 .5109 Metetra
.664 .741 .907 r
.6384 .5109 .63924 .51185 .64486 .51014 .64402 .50919 Metetra
.664 .741 .907 r
.64402 .50919 .64486 .51014 .65049 .50843 .64966 .50747 Metetra
.664 .741 .907 r
.64966 .50747 .65049 .50843 .65613 .50672 .6553 .50576 Metetra
.664 .741 .907 r
.6553 .50576 .65613 .50672 .66178 .505 .66096 .50404 Metetra
.664 .741 .907 r
.66096 .50404 .66178 .505 .66745 .50328 .66662 .50231 Metetra
.664 .741 .907 r
.66662 .50231 .66745 .50328 .67312 .50155 .6723 .50059 Metetra
.664 .741 .907 r
.6723 .50059 .67312 .50155 .67881 .49982 .67799 .49886 Metetra
.664 .741 .907 r
.67799 .49886 .67881 .49982 .68451 .49809 .68369 .49712 Metetra
.664 .741 .907 r
.68369 .49712 .68451 .49809 .69022 .49636 .68941 .49539 Metetra
.664 .741 .907 r
.68941 .49539 .69022 .49636 .69594 .49462 .69513 .49365 Metetra
.664 .741 .907 r
.69513 .49365 .69594 .49462 .70168 .49288 .70087 .4919 Metetra
.664 .741 .907 r
.70087 .4919 .70168 .49288 .70742 .49113 .70661 .49015 Metetra
.664 .741 .907 r
.70661 .49015 .70742 .49113 .71318 .48938 .71237 .4884 Metetra
.664 .741 .907 r
.71237 .4884 .71318 .48938 .71895 .48763 .71815 .48665 Metetra
.664 .741 .907 r
.71815 .48665 .71895 .48763 .72473 .48587 .72393 .48489 Metetra
.664 .741 .907 r
.72393 .48489 .72473 .48587 .73052 .48411 .72972 .48313 Metetra
.664 .741 .907 r
.72972 .48313 .73052 .48411 .73633 .48235 .73553 .48136 Metetra
.664 .741 .907 r
.73553 .48136 .73633 .48235 .74214 .48058 .74135 .47959 Metetra
.664 .741 .907 r
.74135 .47959 .74214 .48058 .74797 .47881 .74718 .47782 Metetra
.664 .741 .907 r
.74718 .47782 .74797 .47881 .75381 .47704 .75302 .47604 Metetra
.664 .741 .907 r
.75302 .47604 .75381 .47704 .75966 .47526 .75887 .47426 Metetra
.664 .741 .907 r
.75887 .47426 .75966 .47526 .76552 .47348 .76474 .47248 Metetra
.664 .741 .907 r
.76474 .47248 .76552 .47348 .7714 .47169 .77062 .47069 Metetra
.664 .741 .907 r
.77062 .47069 .7714 .47169 .77729 .4699 .77651 .4689 Metetra
.664 .741 .907 r
.77651 .4689 .77729 .4699 .78319 .46811 .78241 .46711 Metetra
.664 .741 .907 r
.78241 .46711 .78319 .46811 .7891 .46631 .78832 .46531 Metetra
.664 .741 .907 r
.78832 .46531 .7891 .46631 .79502 .46451 .79425 .46351 Metetra
.664 .741 .907 r
.79425 .46351 .79502 .46451 .80096 .46271 .80019 .4617 Metetra
.664 .741 .907 r
.80019 .4617 .80096 .46271 .80691 .4609 .80614 .45989 Metetra
.664 .741 .907 r
.80614 .45989 .80691 .4609 .81287 .45909 .8121 .45808 Metetra
.664 .741 .907 r
.8121 .45808 .81287 .45909 .81884 .45728 .81808 .45626 Metetra
.664 .741 .907 r
.81808 .45626 .81884 .45728 .82482 .45546 .82407 .45444 Metetra
.664 .741 .907 r
.82407 .45444 .82482 .45546 .83082 .45364 .83007 .45262 Metetra
.664 .741 .907 r
.83007 .45262 .83082 .45364 .83683 .45181 .83608 .45079 Metetra
.664 .741 .907 r
.83608 .45079 .83683 .45181 .84285 .44998 .8421 .44896 Metetra
.664 .741 .907 r
.8421 .44896 .84285 .44998 .84889 .44815 .84814 .44712 Metetra
.664 .741 .907 r
.84814 .44712 .84889 .44815 .85494 .44631 .85419 .44528 Metetra
.664 .741 .907 r
.85419 .44528 .85494 .44631 .861 .44447 .86025 .44344 Metetra
.664 .741 .907 r
.86025 .44344 .861 .44447 .86707 .44262 .86633 .44159 Metetra
.664 .741 .907 r
.86633 .44159 .86707 .44262 .87315 .44077 .87242 .43974 Metetra
.664 .741 .907 r
.87242 .43974 .87315 .44077 .87925 .43892 .87852 .43788 Metetra
.664 .741 .907 r
.87852 .43788 .87925 .43892 .88536 .43706 .88463 .43603 Metetra
.664 .741 .907 r
.88463 .43603 .88536 .43706 .89149 .4352 .89076 .43416 Metetra
.664 .741 .907 r
.89076 .43416 .89149 .4352 .89762 .43334 .8969 .4323 Metetra
.664 .741 .907 r
.8969 .4323 .89762 .43334 .90377 .43147 .90305 .43043 Metetra
.664 .741 .907 r
.90305 .43043 .90377 .43147 .90993 .4296 .90921 .42855 Metetra
.664 .741 .907 r
.90921 .42855 .90993 .4296 .91611 .42772 .91539 .42667 Metetra
.664 .741 .907 r
.91539 .42667 .91611 .42772 .9223 .42584 .92158 .42479 Metetra
.664 .741 .907 r
.92158 .42479 .9223 .42584 .9285 .42396 .92779 .4229 Metetra
.664 .741 .907 r
.92779 .4229 .9285 .42396 .93471 .42207 .934 .42101 Metetra
.664 .741 .907 r
.934 .42101 .93471 .42207 .94094 .42018 .94023 .41912 Metetra
.664 .741 .907 r
.94023 .41912 .94094 .42018 .94718 .41828 .94648 .41722 Metetra
.664 .741 .907 r
.94648 .41722 .94718 .41828 .95343 .41638 .95273 .41532 Metetra
.664 .741 .907 r
.95273 .41532 .95343 .41638 .9597 .41448 .959 .41341 Metetra
.664 .741 .907 r
.39049 .58512 .39142 .586 .39656 .58443 .39563 .58356 Metetra
.664 .741 .907 r
.39563 .58356 .39656 .58443 .4017 .58287 .40077 .58199 Metetra
.664 .741 .907 r
.40077 .58199 .4017 .58287 .40686 .5813 .40593 .58042 Metetra
.664 .741 .907 r
.40593 .58042 .40686 .5813 .41203 .57973 .4111 .57885 Metetra
.664 .741 .907 r
.4111 .57885 .41203 .57973 .41721 .57815 .41628 .57727 Metetra
.664 .741 .907 r
.41628 .57727 .41721 .57815 .42239 .57658 .42147 .5757 Metetra
.664 .741 .907 r
.42147 .5757 .42239 .57658 .42759 .575 .42667 .57411 Metetra
.664 .741 .907 r
.42667 .57411 .42759 .575 .4328 .57341 .43188 .57253 Metetra
.664 .741 .907 r
.43188 .57253 .4328 .57341 .43802 .57183 .4371 .57094 Metetra
.664 .741 .907 r
.4371 .57094 .43802 .57183 .44324 .57024 .44233 .56935 Metetra
.664 .741 .907 r
.44233 .56935 .44324 .57024 .44848 .56864 .44757 .56775 Metetra
.664 .741 .907 r
.44757 .56775 .44848 .56864 .45373 .56705 .45282 .56616 Metetra
.664 .741 .907 r
.45282 .56616 .45373 .56705 .45899 .56545 .45808 .56456 Metetra
.664 .741 .907 r
.45808 .56456 .45899 .56545 .46425 .56385 .46335 .56295 Metetra
.664 .741 .907 r
.46335 .56295 .46425 .56385 .46953 .56224 .46863 .56135 Metetra
.664 .741 .907 r
.46863 .56135 .46953 .56224 .47482 .56063 .47392 .55974 Metetra
.664 .741 .907 r
.47392 .55974 .47482 .56063 .48012 .55902 .47922 .55812 Metetra
.664 .741 .907 r
.47922 .55812 .48012 .55902 .48543 .55741 .48453 .55651 Metetra
.664 .741 .907 r
.48453 .55651 .48543 .55741 .49075 .55579 .48985 .55489 Metetra
.664 .741 .907 r
.48985 .55489 .49075 .55579 .49608 .55417 .49519 .55327 Metetra
.664 .741 .907 r
.49519 .55327 .49608 .55417 .50142 .55255 .50053 .55164 Metetra
.664 .741 .907 r
.50053 .55164 .50142 .55255 .50677 .55092 .50588 .55001 Metetra
.664 .741 .907 r
.50588 .55001 .50677 .55092 .51213 .54929 .51124 .54838 Metetra
.664 .741 .907 r
.51124 .54838 .51213 .54929 .5175 .54766 .51662 .54674 Metetra
.664 .741 .907 r
.51662 .54674 .5175 .54766 .52289 .54602 .522 .54511 Metetra
.664 .741 .907 r
.522 .54511 .52289 .54602 .52828 .54438 .5274 .54346 Metetra
.664 .741 .907 r
.5274 .54346 .52828 .54438 .53368 .54274 .5328 .54182 Metetra
.664 .741 .907 r
.5328 .54182 .53368 .54274 .5391 .54109 .53822 .54017 Metetra
.664 .741 .907 r
.53822 .54017 .5391 .54109 .54452 .53944 .54365 .53852 Metetra
.664 .741 .907 r
.54365 .53852 .54452 .53944 .54996 .53779 .54908 .53687 Metetra
.664 .741 .907 r
.54908 .53687 .54996 .53779 .5554 .53613 .55453 .53521 Metetra
.664 .741 .907 r
.55453 .53521 .5554 .53613 .56086 .53447 .55999 .53355 Metetra
.664 .741 .907 r
.55999 .53355 .56086 .53447 .56633 .53281 .56546 .53188 Metetra
.664 .741 .907 r
.56546 .53188 .56633 .53281 .5718 .53115 .57094 .53022 Metetra
.664 .741 .907 r
.57094 .53022 .5718 .53115 .57729 .52948 .57643 .52854 Metetra
.664 .741 .907 r
.57643 .52854 .57729 .52948 .58279 .5278 .58193 .52687 Metetra
.664 .741 .907 r
.58193 .52687 .58279 .5278 .5883 .52613 .58745 .52519 Metetra
.664 .741 .907 r
.58745 .52519 .5883 .52613 .59383 .52445 .59297 .52351 Metetra
.664 .741 .907 r
.59297 .52351 .59383 .52445 .59936 .52277 .59851 .52183 Metetra
.664 .741 .907 r
.59851 .52183 .59936 .52277 .6049 .52108 .60405 .52014 Metetra
.664 .741 .907 r
.60405 .52014 .6049 .52108 .61046 .51939 .60961 .51845 Metetra
.664 .741 .907 r
.60961 .51845 .61046 .51939 .61602 .5177 .61518 .51675 Metetra
.664 .741 .907 r
.61518 .51675 .61602 .5177 .6216 .516 .62076 .51506 Metetra
.664 .741 .907 r
.62076 .51506 .6216 .516 .62719 .5143 .62635 .51336 Metetra
.664 .741 .907 r
.62635 .51336 .62719 .5143 .63279 .5126 .63195 .51165 Metetra
.664 .741 .907 r
.63195 .51165 .63279 .5126 .6384 .5109 .63756 .50994 Metetra
.664 .741 .907 r
.63756 .50994 .6384 .5109 .64402 .50919 .64319 .50823 Metetra
.664 .741 .907 r
.64319 .50823 .64402 .50919 .64966 .50747 .64882 .50652 Metetra
.664 .741 .907 r
.64882 .50652 .64966 .50747 .6553 .50576 .65447 .5048 Metetra
.664 .741 .907 r
.65447 .5048 .6553 .50576 .66096 .50404 .66013 .50308 Metetra
.664 .741 .907 r
.66013 .50308 .66096 .50404 .66662 .50231 .6658 .50135 Metetra
.664 .741 .907 r
.6658 .50135 .66662 .50231 .6723 .50059 .67148 .49962 Metetra
.664 .741 .907 r
.67148 .49962 .6723 .50059 .67799 .49886 .67717 .49789 Metetra
.664 .741 .907 r
.67717 .49789 .67799 .49886 .68369 .49712 .68287 .49616 Metetra
.664 .741 .907 r
.68287 .49616 .68369 .49712 .68941 .49539 .68859 .49442 Metetra
.664 .741 .907 r
.68859 .49442 .68941 .49539 .69513 .49365 .69432 .49267 Metetra
.664 .741 .907 r
.69432 .49267 .69513 .49365 .70087 .4919 .70006 .49093 Metetra
.664 .741 .907 r
.70006 .49093 .70087 .4919 .70661 .49015 .70581 .48918 Metetra
.664 .741 .907 r
.70581 .48918 .70661 .49015 .71237 .4884 .71157 .48742 Metetra
.664 .741 .907 r
.71157 .48742 .71237 .4884 .71815 .48665 .71734 .48567 Metetra
.664 .741 .907 r
.71734 .48567 .71815 .48665 .72393 .48489 .72313 .48391 Metetra
.664 .741 .907 r
.72313 .48391 .72393 .48489 .72972 .48313 .72892 .48214 Metetra
.664 .741 .907 r
.72892 .48214 .72972 .48313 .73553 .48136 .73473 .48038 Metetra
.664 .741 .907 r
.73473 .48038 .73553 .48136 .74135 .47959 .74055 .47861 Metetra
.664 .741 .907 r
.74055 .47861 .74135 .47959 .74718 .47782 .74639 .47683 Metetra
.664 .741 .907 r
.74639 .47683 .74718 .47782 .75302 .47604 .75223 .47505 Metetra
.664 .741 .907 r
.75223 .47505 .75302 .47604 .75887 .47426 .75809 .47327 Metetra
.664 .741 .907 r
.75809 .47327 .75887 .47426 .76474 .47248 .76396 .47148 Metetra
.664 .741 .907 r
.76396 .47148 .76474 .47248 .77062 .47069 .76984 .46969 Metetra
.664 .741 .907 r
.76984 .46969 .77062 .47069 .77651 .4689 .77573 .4679 Metetra
.664 .741 .907 r
.77573 .4679 .77651 .4689 .78241 .46711 .78163 .46611 Metetra
.664 .741 .907 r
.78163 .46611 .78241 .46711 .78832 .46531 .78755 .4643 Metetra
.664 .741 .907 r
.78755 .4643 .78832 .46531 .79425 .46351 .79348 .4625 Metetra
.664 .741 .907 r
.79348 .4625 .79425 .46351 .80019 .4617 .79942 .46069 Metetra
.664 .741 .907 r
.79942 .46069 .80019 .4617 .80614 .45989 .80537 .45888 Metetra
.664 .741 .907 r
.80537 .45888 .80614 .45989 .8121 .45808 .81134 .45707 Metetra
.664 .741 .907 r
.81134 .45707 .8121 .45808 .81808 .45626 .81732 .45525 Metetra
.664 .741 .907 r
.81732 .45525 .81808 .45626 .82407 .45444 .82331 .45342 Metetra
.664 .741 .907 r
.82331 .45342 .82407 .45444 .83007 .45262 .82931 .4516 Metetra
.664 .741 .907 r
.82931 .4516 .83007 .45262 .83608 .45079 .83533 .44977 Metetra
.664 .741 .907 r
.83533 .44977 .83608 .45079 .8421 .44896 .84135 .44793 Metetra
.664 .741 .907 r
.84135 .44793 .8421 .44896 .84814 .44712 .84739 .4461 Metetra
.664 .741 .907 r
.84739 .4461 .84814 .44712 .85419 .44528 .85345 .44425 Metetra
.664 .741 .907 r
.85345 .44425 .85419 .44528 .86025 .44344 .85951 .44241 Metetra
.664 .741 .907 r
.85951 .44241 .86025 .44344 .86633 .44159 .86559 .44056 Metetra
.664 .741 .907 r
.86559 .44056 .86633 .44159 .87242 .43974 .87168 .43871 Metetra
.664 .741 .907 r
.87168 .43871 .87242 .43974 .87852 .43788 .87778 .43685 Metetra
.664 .741 .907 r
.87778 .43685 .87852 .43788 .88463 .43603 .8839 .43499 Metetra
.664 .741 .907 r
.8839 .43499 .88463 .43603 .89076 .43416 .89003 .43312 Metetra
.664 .741 .907 r
.89003 .43312 .89076 .43416 .8969 .4323 .89617 .43125 Metetra
.664 .741 .907 r
.89617 .43125 .8969 .4323 .90305 .43043 .90233 .42938 Metetra
.664 .741 .907 r
.90233 .42938 .90305 .43043 .90921 .42855 .90849 .4275 Metetra
.664 .741 .907 r
.90849 .4275 .90921 .42855 .91539 .42667 .91467 .42562 Metetra
.664 .741 .907 r
.91467 .42562 .91539 .42667 .92158 .42479 .92087 .42374 Metetra
.664 .741 .907 r
.92087 .42374 .92158 .42479 .92779 .4229 .92707 .42185 Metetra
.664 .741 .907 r
.92707 .42185 .92779 .4229 .934 .42101 .93329 .41996 Metetra
.664 .741 .907 r
.93329 .41996 .934 .42101 .94023 .41912 .93953 .41806 Metetra
.664 .741 .907 r
.93953 .41806 .94023 .41912 .94648 .41722 .94577 .41616 Metetra
.664 .741 .907 r
.94577 .41616 .94648 .41722 .95273 .41532 .95203 .41426 Metetra
.664 .741 .907 r
.95203 .41426 .95273 .41532 .959 .41341 .95831 .41235 Metetra
.664 .741 .907 r
.38955 .58425 .39049 .58512 .39563 .58356 .39469 .58269 Metetra
.664 .741 .907 r
.39469 .58269 .39563 .58356 .40077 .58199 .39985 .58112 Metetra
.664 .741 .907 r
.39985 .58112 .40077 .58199 .40593 .58042 .40501 .57955 Metetra
.664 .741 .907 r
.40501 .57955 .40593 .58042 .4111 .57885 .41018 .57797 Metetra
.664 .741 .907 r
.41018 .57797 .4111 .57885 .41628 .57727 .41536 .57639 Metetra
.664 .741 .907 r
.41536 .57639 .41628 .57727 .42147 .5757 .42055 .57481 Metetra
.664 .741 .907 r
.42055 .57481 .42147 .5757 .42667 .57411 .42575 .57323 Metetra
.664 .741 .907 r
.42575 .57323 .42667 .57411 .43188 .57253 .43096 .57164 Metetra
.664 .741 .907 r
.43096 .57164 .43188 .57253 .4371 .57094 .43618 .57005 Metetra
.664 .741 .907 r
.43618 .57005 .4371 .57094 .44233 .56935 .44142 .56846 Metetra
.664 .741 .907 r
.44142 .56846 .44233 .56935 .44757 .56775 .44666 .56686 Metetra
.664 .741 .907 r
.44666 .56686 .44757 .56775 .45282 .56616 .45191 .56526 Metetra
.664 .741 .907 r
.45191 .56526 .45282 .56616 .45808 .56456 .45717 .56366 Metetra
.664 .741 .907 r
.45717 .56366 .45808 .56456 .46335 .56295 .46244 .56206 Metetra
.664 .741 .907 r
.46244 .56206 .46335 .56295 .46863 .56135 .46772 .56045 Metetra
.664 .741 .907 r
.46772 .56045 .46863 .56135 .47392 .55974 .47302 .55884 Metetra
.664 .741 .907 r
.47302 .55884 .47392 .55974 .47922 .55812 .47832 .55722 Metetra
.664 .741 .907 r
.47832 .55722 .47922 .55812 .48453 .55651 .48363 .5556 Metetra
.664 .741 .907 r
.48363 .5556 .48453 .55651 .48985 .55489 .48896 .55398 Metetra
.664 .741 .907 r
.48896 .55398 .48985 .55489 .49519 .55327 .49429 .55236 Metetra
.664 .741 .907 r
.49429 .55236 .49519 .55327 .50053 .55164 .49964 .55073 Metetra
.664 .741 .907 r
.49964 .55073 .50053 .55164 .50588 .55001 .50499 .5491 Metetra
.664 .741 .907 r
.50499 .5491 .50588 .55001 .51124 .54838 .51036 .54747 Metetra
.664 .741 .907 r
.51036 .54747 .51124 .54838 .51662 .54674 .51573 .54583 Metetra
.664 .741 .907 r
.51573 .54583 .51662 .54674 .522 .54511 .52112 .54419 Metetra
.664 .741 .907 r
.52112 .54419 .522 .54511 .5274 .54346 .52651 .54255 Metetra
.664 .741 .907 r
.52651 .54255 .5274 .54346 .5328 .54182 .53192 .5409 Metetra
.664 .741 .907 r
.53192 .5409 .5328 .54182 .53822 .54017 .53734 .53925 Metetra
.664 .741 .907 r
.53734 .53925 .53822 .54017 .54365 .53852 .54277 .5376 Metetra
.664 .741 .907 r
.54277 .5376 .54365 .53852 .54908 .53687 .54821 .53594 Metetra
.664 .741 .907 r
.54821 .53594 .54908 .53687 .55453 .53521 .55366 .53428 Metetra
.664 .741 .907 r
.55366 .53428 .55453 .53521 .55999 .53355 .55912 .53262 Metetra
.664 .741 .907 r
.55912 .53262 .55999 .53355 .56546 .53188 .56459 .53095 Metetra
.664 .741 .907 r
.56459 .53095 .56546 .53188 .57094 .53022 .57007 .52928 Metetra
.664 .741 .907 r
.57007 .52928 .57094 .53022 .57643 .52854 .57557 .52761 Metetra
.664 .741 .907 r
.57557 .52761 .57643 .52854 .58193 .52687 .58107 .52593 Metetra
.664 .741 .907 r
.58107 .52593 .58193 .52687 .58745 .52519 .58659 .52426 Metetra
.664 .741 .907 r
.58659 .52426 .58745 .52519 .59297 .52351 .59211 .52257 Metetra
.664 .741 .907 r
.59211 .52257 .59297 .52351 .59851 .52183 .59765 .52089 Metetra
.664 .741 .907 r
.59765 .52089 .59851 .52183 .60405 .52014 .6032 .5192 Metetra
.664 .741 .907 r
.6032 .5192 .60405 .52014 .60961 .51845 .60876 .5175 Metetra
.664 .741 .907 r
.60876 .5175 .60961 .51845 .61518 .51675 .61433 .51581 Metetra
.664 .741 .907 r
.61433 .51581 .61518 .51675 .62076 .51506 .61991 .51411 Metetra
.664 .741 .907 r
.61991 .51411 .62076 .51506 .62635 .51336 .62551 .51241 Metetra
.664 .741 .907 r
.62551 .51241 .62635 .51336 .63195 .51165 .63111 .5107 Metetra
.664 .741 .907 r
.63111 .5107 .63195 .51165 .63756 .50994 .63672 .50899 Metetra
.664 .741 .907 r
.63672 .50899 .63756 .50994 .64319 .50823 .64235 .50728 Metetra
.664 .741 .907 r
.64235 .50728 .64319 .50823 .64882 .50652 .64799 .50556 Metetra
.664 .741 .907 r
.64799 .50556 .64882 .50652 .65447 .5048 .65364 .50384 Metetra
.664 .741 .907 r
.65364 .50384 .65447 .5048 .66013 .50308 .6593 .50212 Metetra
.664 .741 .907 r
.6593 .50212 .66013 .50308 .6658 .50135 .66497 .50039 Metetra
.664 .741 .907 r
.66497 .50039 .6658 .50135 .67148 .49962 .67065 .49866 Metetra
.664 .741 .907 r
.67065 .49866 .67148 .49962 .67717 .49789 .67635 .49692 Metetra
.664 .741 .907 r
.67635 .49692 .67717 .49789 .68287 .49616 .68205 .49519 Metetra
.664 .741 .907 r
.68205 .49519 .68287 .49616 .68859 .49442 .68777 .49345 Metetra
.664 .741 .907 r
.68777 .49345 .68859 .49442 .69432 .49267 .6935 .4917 Metetra
.664 .741 .907 r
.6935 .4917 .69432 .49267 .70006 .49093 .69924 .48995 Metetra
.664 .741 .907 r
.69924 .48995 .70006 .49093 .70581 .48918 .705 .4882 Metetra
.664 .741 .907 r
.705 .4882 .70581 .48918 .71157 .48742 .71076 .48645 Metetra
.664 .741 .907 r
.71076 .48645 .71157 .48742 .71734 .48567 .71654 .48469 Metetra
.664 .741 .907 r
.71654 .48469 .71734 .48567 .72313 .48391 .72232 .48292 Metetra
.664 .741 .907 r
.72232 .48292 .72313 .48391 .72892 .48214 .72812 .48116 Metetra
.664 .741 .907 r
.72812 .48116 .72892 .48214 .73473 .48038 .73393 .47939 Metetra
.664 .741 .907 r
.73393 .47939 .73473 .48038 .74055 .47861 .73976 .47762 Metetra
.664 .741 .907 r
.73976 .47762 .74055 .47861 .74639 .47683 .74559 .47584 Metetra
.664 .741 .907 r
.74559 .47584 .74639 .47683 .75223 .47505 .75144 .47406 Metetra
.664 .741 .907 r
.75144 .47406 .75223 .47505 .75809 .47327 .7573 .47227 Metetra
.664 .741 .907 r
.7573 .47227 .75809 .47327 .76396 .47148 .76317 .47049 Metetra
.664 .741 .907 r
.76317 .47049 .76396 .47148 .76984 .46969 .76905 .4687 Metetra
.664 .741 .907 r
.76905 .4687 .76984 .46969 .77573 .4679 .77495 .4669 Metetra
.664 .741 .907 r
.77495 .4669 .77573 .4679 .78163 .46611 .78086 .4651 Metetra
.664 .741 .907 r
.78086 .4651 .78163 .46611 .78755 .4643 .78678 .4633 Metetra
.664 .741 .907 r
.78678 .4633 .78755 .4643 .79348 .4625 .79271 .46149 Metetra
.664 .741 .907 r
.79271 .46149 .79348 .4625 .79942 .46069 .79865 .45968 Metetra
.664 .741 .907 r
.79865 .45968 .79942 .46069 .80537 .45888 .80461 .45787 Metetra
.664 .741 .907 r
.80461 .45787 .80537 .45888 .81134 .45707 .81057 .45605 Metetra
.664 .741 .907 r
.81057 .45605 .81134 .45707 .81732 .45525 .81656 .45423 Metetra
.664 .741 .907 r
.81656 .45423 .81732 .45525 .82331 .45342 .82255 .45241 Metetra
.664 .741 .907 r
.82255 .45241 .82331 .45342 .82931 .4516 .82855 .45058 Metetra
.664 .741 .907 r
.82855 .45058 .82931 .4516 .83533 .44977 .83457 .44875 Metetra
.664 .741 .907 r
.83457 .44875 .83533 .44977 .84135 .44793 .8406 .44691 Metetra
.664 .741 .907 r
.8406 .44691 .84135 .44793 .84739 .4461 .84665 .44507 Metetra
.664 .741 .907 r
.84665 .44507 .84739 .4461 .85345 .44425 .8527 .44322 Metetra
.664 .741 .907 r
.8527 .44322 .85345 .44425 .85951 .44241 .85877 .44138 Metetra
.664 .741 .907 r
.85877 .44138 .85951 .44241 .86559 .44056 .86485 .43953 Metetra
.664 .741 .907 r
.86485 .43953 .86559 .44056 .87168 .43871 .87094 .43767 Metetra
.664 .741 .907 r
.87094 .43767 .87168 .43871 .87778 .43685 .87705 .43581 Metetra
.664 .741 .907 r
.87705 .43581 .87778 .43685 .8839 .43499 .88317 .43395 Metetra
.664 .741 .907 r
.88317 .43395 .8839 .43499 .89003 .43312 .8893 .43208 Metetra
.664 .741 .907 r
.8893 .43208 .89003 .43312 .89617 .43125 .89545 .43021 Metetra
.664 .741 .907 r
.89545 .43021 .89617 .43125 .90233 .42938 .9016 .42833 Metetra
.664 .741 .907 r
.9016 .42833 .90233 .42938 .90849 .4275 .90777 .42646 Metetra
.664 .741 .907 r
.90777 .42646 .90849 .4275 .91467 .42562 .91396 .42457 Metetra
.664 .741 .907 r
.91396 .42457 .91467 .42562 .92087 .42374 .92015 .42269 Metetra
.664 .741 .907 r
.92015 .42269 .92087 .42374 .92707 .42185 .92636 .42079 Metetra
.664 .741 .907 r
.92636 .42079 .92707 .42185 .93329 .41996 .93259 .4189 Metetra
.664 .741 .907 r
.93259 .4189 .93329 .41996 .93953 .41806 .93882 .417 Metetra
.664 .741 .907 r
.93882 .417 .93953 .41806 .94577 .41616 .94507 .4151 Metetra
.664 .741 .907 r
.94507 .4151 .94577 .41616 .95203 .41426 .95133 .41319 Metetra
.664 .741 .907 r
.95133 .41319 .95203 .41426 .95831 .41235 .95761 .41128 Metetra
.664 .741 .907 r
.38862 .58338 .38955 .58425 .39469 .58269 .39376 .58181 Metetra
.664 .741 .907 r
.39376 .58181 .39469 .58269 .39985 .58112 .39891 .58024 Metetra
.664 .741 .907 r
.39891 .58024 .39985 .58112 .40501 .57955 .40408 .57867 Metetra
.664 .741 .907 r
.40408 .57867 .40501 .57955 .41018 .57797 .40925 .57709 Metetra
.664 .741 .907 r
.40925 .57709 .41018 .57797 .41536 .57639 .41443 .57551 Metetra
.664 .741 .907 r
.41443 .57551 .41536 .57639 .42055 .57481 .41963 .57393 Metetra
.664 .741 .907 r
.41963 .57393 .42055 .57481 .42575 .57323 .42483 .57235 Metetra
.664 .741 .907 r
.42483 .57235 .42575 .57323 .43096 .57164 .43004 .57076 Metetra
.664 .741 .907 r
.43004 .57076 .43096 .57164 .43618 .57005 .43527 .56916 Metetra
.664 .741 .907 r
.43527 .56916 .43618 .57005 .44142 .56846 .4405 .56757 Metetra
.664 .741 .907 r
.4405 .56757 .44142 .56846 .44666 .56686 .44574 .56597 Metetra
.664 .741 .907 r
.44574 .56597 .44666 .56686 .45191 .56526 .451 .56437 Metetra
.664 .741 .907 r
.451 .56437 .45191 .56526 .45717 .56366 .45626 .56277 Metetra
.664 .741 .907 r
.45626 .56277 .45717 .56366 .46244 .56206 .46153 .56116 Metetra
.664 .741 .907 r
.46153 .56116 .46244 .56206 .46772 .56045 .46682 .55955 Metetra
.664 .741 .907 r
.46682 .55955 .46772 .56045 .47302 .55884 .47211 .55794 Metetra
.664 .741 .907 r
.47211 .55794 .47302 .55884 .47832 .55722 .47742 .55632 Metetra
.664 .741 .907 r
.47742 .55632 .47832 .55722 .48363 .5556 .48273 .5547 Metetra
.664 .741 .907 r
.48273 .5547 .48363 .5556 .48896 .55398 .48806 .55308 Metetra
.664 .741 .907 r
.48806 .55308 .48896 .55398 .49429 .55236 .49339 .55145 Metetra
.664 .741 .907 r
.49339 .55145 .49429 .55236 .49964 .55073 .49874 .54982 Metetra
.664 .741 .907 r
.49874 .54982 .49964 .55073 .50499 .5491 .5041 .54819 Metetra
.664 .741 .907 r
.5041 .54819 .50499 .5491 .51036 .54747 .50947 .54656 Metetra
.664 .741 .907 r
.50947 .54656 .51036 .54747 .51573 .54583 .51484 .54492 Metetra
.664 .741 .907 r
.51484 .54492 .51573 .54583 .52112 .54419 .52023 .54327 Metetra
.664 .741 .907 r
.52023 .54327 .52112 .54419 .52651 .54255 .52563 .54163 Metetra
.664 .741 .907 r
.52563 .54163 .52651 .54255 .53192 .5409 .53104 .53998 Metetra
.664 .741 .907 r
.53104 .53998 .53192 .5409 .53734 .53925 .53646 .53833 Metetra
.664 .741 .907 r
.53646 .53833 .53734 .53925 .54277 .5376 .54189 .53667 Metetra
.664 .741 .907 r
.54189 .53667 .54277 .5376 .54821 .53594 .54733 .53502 Metetra
.664 .741 .907 r
.54733 .53502 .54821 .53594 .55366 .53428 .55279 .53336 Metetra
.664 .741 .907 r
.55279 .53336 .55366 .53428 .55912 .53262 .55825 .53169 Metetra
.664 .741 .907 r
.55825 .53169 .55912 .53262 .56459 .53095 .56372 .53002 Metetra
.664 .741 .907 r
.56372 .53002 .56459 .53095 .57007 .52928 .56921 .52835 Metetra
.664 .741 .907 r
.56921 .52835 .57007 .52928 .57557 .52761 .5747 .52668 Metetra
.664 .741 .907 r
.5747 .52668 .57557 .52761 .58107 .52593 .58021 .525 Metetra
.664 .741 .907 r
.58021 .525 .58107 .52593 .58659 .52426 .58573 .52332 Metetra
.664 .741 .907 r
.58573 .52332 .58659 .52426 .59211 .52257 .59126 .52163 Metetra
.664 .741 .907 r
.59126 .52163 .59211 .52257 .59765 .52089 .5968 .51994 Metetra
.664 .741 .907 r
.5968 .51994 .59765 .52089 .6032 .5192 .60235 .51825 Metetra
.664 .741 .907 r
.60235 .51825 .6032 .5192 .60876 .5175 .60791 .51656 Metetra
.664 .741 .907 r
.60791 .51656 .60876 .5175 .61433 .51581 .61348 .51486 Metetra
.664 .741 .907 r
.61348 .51486 .61433 .51581 .61991 .51411 .61907 .51316 Metetra
.664 .741 .907 r
.61907 .51316 .61991 .51411 .62551 .51241 .62466 .51145 Metetra
.664 .741 .907 r
.62466 .51145 .62551 .51241 .63111 .5107 .63027 .50975 Metetra
.664 .741 .907 r
.63027 .50975 .63111 .5107 .63672 .50899 .63588 .50803 Metetra
.664 .741 .907 r
.63588 .50803 .63672 .50899 .64235 .50728 .64151 .50632 Metetra
.664 .741 .907 r
.64151 .50632 .64235 .50728 .64799 .50556 .64715 .5046 Metetra
.664 .741 .907 r
.64715 .5046 .64799 .50556 .65364 .50384 .65281 .50288 Metetra
.664 .741 .907 r
.65281 .50288 .65364 .50384 .6593 .50212 .65847 .50115 Metetra
.664 .741 .907 r
.65847 .50115 .6593 .50212 .66497 .50039 .66414 .49942 Metetra
.664 .741 .907 r
.66414 .49942 .66497 .50039 .67065 .49866 .66983 .49769 Metetra
.664 .741 .907 r
.66983 .49769 .67065 .49866 .67635 .49692 .67553 .49596 Metetra
.664 .741 .907 r
.67553 .49596 .67635 .49692 .68205 .49519 .68123 .49422 Metetra
.664 .741 .907 r
.68123 .49422 .68205 .49519 .68777 .49345 .68695 .49247 Metetra
.664 .741 .907 r
.68695 .49247 .68777 .49345 .6935 .4917 .69269 .49073 Metetra
.664 .741 .907 r
.69269 .49073 .6935 .4917 .69924 .48995 .69843 .48898 Metetra
.664 .741 .907 r
.69843 .48898 .69924 .48995 .705 .4882 .70418 .48722 Metetra
.664 .741 .907 r
.70418 .48722 .705 .4882 .71076 .48645 .70995 .48546 Metetra
.664 .741 .907 r
.70995 .48546 .71076 .48645 .71654 .48469 .71573 .4837 Metetra
.664 .741 .907 r
.71573 .4837 .71654 .48469 .72232 .48292 .72152 .48194 Metetra
.664 .741 .907 r
.72152 .48194 .72232 .48292 .72812 .48116 .72732 .48017 Metetra
.664 .741 .907 r
.72732 .48017 .72812 .48116 .73393 .47939 .73314 .4784 Metetra
.664 .741 .907 r
.73314 .4784 .73393 .47939 .73976 .47762 .73896 .47663 Metetra
.664 .741 .907 r
.73896 .47663 .73976 .47762 .74559 .47584 .7448 .47485 Metetra
.664 .741 .907 r
.7448 .47485 .74559 .47584 .75144 .47406 .75065 .47306 Metetra
.664 .741 .907 r
.75065 .47306 .75144 .47406 .7573 .47227 .75651 .47128 Metetra
.664 .741 .907 r
.75651 .47128 .7573 .47227 .76317 .47049 .76238 .46949 Metetra
.664 .741 .907 r
.76238 .46949 .76317 .47049 .76905 .4687 .76827 .46769 Metetra
.664 .741 .907 r
.76827 .46769 .76905 .4687 .77495 .4669 .77417 .4659 Metetra
.664 .741 .907 r
.77417 .4659 .77495 .4669 .78086 .4651 .78008 .4641 Metetra
.664 .741 .907 r
.78008 .4641 .78086 .4651 .78678 .4633 .786 .46229 Metetra
.664 .741 .907 r
.786 .46229 .78678 .4633 .79271 .46149 .79193 .46048 Metetra
.664 .741 .907 r
.79193 .46048 .79271 .46149 .79865 .45968 .79788 .45867 Metetra
.664 .741 .907 r
.79788 .45867 .79865 .45968 .80461 .45787 .80384 .45686 Metetra
.664 .741 .907 r
.80384 .45686 .80461 .45787 .81057 .45605 .80981 .45504 Metetra
.664 .741 .907 r
.80981 .45504 .81057 .45605 .81656 .45423 .81579 .45321 Metetra
.664 .741 .907 r
.81579 .45321 .81656 .45423 .82255 .45241 .82179 .45139 Metetra
.664 .741 .907 r
.82179 .45139 .82255 .45241 .82855 .45058 .8278 .44956 Metetra
.664 .741 .907 r
.8278 .44956 .82855 .45058 .83457 .44875 .83382 .44772 Metetra
.664 .741 .907 r
.83382 .44772 .83457 .44875 .8406 .44691 .83985 .44588 Metetra
.664 .741 .907 r
.83985 .44588 .8406 .44691 .84665 .44507 .8459 .44404 Metetra
.664 .741 .907 r
.8459 .44404 .84665 .44507 .8527 .44322 .85195 .44219 Metetra
.664 .741 .907 r
.85195 .44219 .8527 .44322 .85877 .44138 .85803 .44034 Metetra
.664 .741 .907 r
.85803 .44034 .85877 .44138 .86485 .43953 .86411 .43849 Metetra
.664 .741 .907 r
.86411 .43849 .86485 .43953 .87094 .43767 .87021 .43663 Metetra
.664 .741 .907 r
.87021 .43663 .87094 .43767 .87705 .43581 .87631 .43477 Metetra
.664 .741 .907 r
.87631 .43477 .87705 .43581 .88317 .43395 .88244 .43291 Metetra
.664 .741 .907 r
.88244 .43291 .88317 .43395 .8893 .43208 .88857 .43104 Metetra
.664 .741 .907 r
.88857 .43104 .8893 .43208 .89545 .43021 .89472 .42916 Metetra
.664 .741 .907 r
.89472 .42916 .89545 .43021 .9016 .42833 .90088 .42729 Metetra
.664 .741 .907 r
.90088 .42729 .9016 .42833 .90777 .42646 .90705 .42541 Metetra
.664 .741 .907 r
.90705 .42541 .90777 .42646 .91396 .42457 .91324 .42352 Metetra
.664 .741 .907 r
.91324 .42352 .91396 .42457 .92015 .42269 .91944 .42163 Metetra
.664 .741 .907 r
.91944 .42163 .92015 .42269 .92636 .42079 .92565 .41974 Metetra
.664 .741 .907 r
.92565 .41974 .92636 .42079 .93259 .4189 .93188 .41784 Metetra
.664 .741 .907 r
.93188 .41784 .93259 .4189 .93882 .417 .93811 .41594 Metetra
.664 .741 .907 r
.93811 .41594 .93882 .417 .94507 .4151 .94437 .41404 Metetra
.664 .741 .907 r
.94437 .41404 .94507 .4151 .95133 .41319 .95063 .41213 Metetra
.664 .741 .907 r
.95063 .41213 .95133 .41319 .95761 .41128 .95691 .41021 Metetra
.664 .741 .907 r
.38768 .58251 .38862 .58338 .39376 .58181 .39283 .58094 Metetra
.664 .741 .907 r
.39283 .58094 .39376 .58181 .39891 .58024 .39798 .57936 Metetra
.664 .741 .907 r
.39798 .57936 .39891 .58024 .40408 .57867 .40315 .57779 Metetra
.664 .741 .907 r
.40315 .57779 .40408 .57867 .40925 .57709 .40832 .57621 Metetra
.664 .741 .907 r
.40832 .57621 .40925 .57709 .41443 .57551 .41351 .57463 Metetra
.664 .741 .907 r
.41351 .57463 .41443 .57551 .41963 .57393 .4187 .57305 Metetra
.664 .741 .907 r
.4187 .57305 .41963 .57393 .42483 .57235 .42391 .57146 Metetra
.664 .741 .907 r
.42391 .57146 .42483 .57235 .43004 .57076 .42912 .56987 Metetra
.664 .741 .907 r
.42912 .56987 .43004 .57076 .43527 .56916 .43435 .56828 Metetra
.664 .741 .907 r
.43435 .56828 .43527 .56916 .4405 .56757 .43958 .56668 Metetra
.664 .741 .907 r
.43958 .56668 .4405 .56757 .44574 .56597 .44483 .56508 Metetra
.664 .741 .907 r
.44483 .56508 .44574 .56597 .451 .56437 .45008 .56348 Metetra
.664 .741 .907 r
.45008 .56348 .451 .56437 .45626 .56277 .45535 .56187 Metetra
.664 .741 .907 r
.45535 .56187 .45626 .56277 .46153 .56116 .46063 .56026 Metetra
.95 .636 .401 r
.46063 .56026 .46153 .56116 .46682 .55955 .46531 .59337 Metetra
.441 .248 .521 r
.46531 .59337 .46682 .55955 .47211 .55794 .47121 .55704 Metetra
.664 .741 .907 r
.47121 .55704 .47211 .55794 .47742 .55632 .47652 .55542 Metetra
.664 .741 .907 r
.47652 .55542 .47742 .55632 .48273 .5547 .48183 .5538 Metetra
.664 .741 .907 r
.48183 .5538 .48273 .5547 .48806 .55308 .48716 .55217 Metetra
.664 .741 .907 r
.48716 .55217 .48806 .55308 .49339 .55145 .4925 .55054 Metetra
.664 .741 .907 r
.4925 .55054 .49339 .55145 .49874 .54982 .49785 .54891 Metetra
.664 .741 .907 r
.49785 .54891 .49874 .54982 .5041 .54819 .50321 .54728 Metetra
.664 .741 .907 r
.50321 .54728 .5041 .54819 .50947 .54656 .50857 .54564 Metetra
.664 .741 .907 r
.50857 .54564 .50947 .54656 .51484 .54492 .51395 .544 Metetra
.664 .741 .907 r
.51395 .544 .51484 .54492 .52023 .54327 .51935 .54236 Metetra
.664 .741 .907 r
.51935 .54236 .52023 .54327 .52563 .54163 .52475 .54071 Metetra
.664 .741 .907 r
.52475 .54071 .52563 .54163 .53104 .53998 .53016 .53906 Metetra
.664 .741 .907 r
.53016 .53906 .53104 .53998 .53646 .53833 .53558 .53741 Metetra
.664 .741 .907 r
.53558 .53741 .53646 .53833 .54189 .53667 .54101 .53575 Metetra
.664 .741 .907 r
.54101 .53575 .54189 .53667 .54733 .53502 .54646 .53409 Metetra
.664 .741 .907 r
.54646 .53409 .54733 .53502 .55279 .53336 .55191 .53243 Metetra
.664 .741 .907 r
.55191 .53243 .55279 .53336 .55825 .53169 .55738 .53076 Metetra
.664 .741 .907 r
.55738 .53076 .55825 .53169 .56372 .53002 .56285 .52909 Metetra
.664 .741 .907 r
.56285 .52909 .56372 .53002 .56921 .52835 .56834 .52742 Metetra
.664 .741 .907 r
.56834 .52742 .56921 .52835 .5747 .52668 .57384 .52574 Metetra
.664 .741 .907 r
.57384 .52574 .5747 .52668 .58021 .525 .57935 .52406 Metetra
.664 .741 .907 r
.57935 .52406 .58021 .525 .58573 .52332 .58487 .52238 Metetra
.664 .741 .907 r
.58487 .52238 .58573 .52332 .59126 .52163 .5904 .52069 Metetra
.664 .741 .907 r
.5904 .52069 .59126 .52163 .5968 .51994 .59594 .519 Metetra
.134 .476 .896 r
.59594 .519 .5968 .51994 .60235 .51825 .60159 .52154 Metetra
.322 .044 .326 r
.60159 .52154 .60235 .51825 .60791 .51656 .60706 .51561 Metetra
.664 .741 .907 r
.60706 .51561 .60791 .51656 .61348 .51486 .61263 .51391 Metetra
.664 .741 .907 r
.61263 .51391 .61348 .51486 .61907 .51316 .61822 .51221 Metetra
.664 .741 .907 r
.61822 .51221 .61907 .51316 .62466 .51145 .62382 .5105 Metetra
.664 .741 .907 r
.62382 .5105 .62466 .51145 .63027 .50975 .62942 .50879 Metetra
.664 .741 .907 r
.62942 .50879 .63027 .50975 .63588 .50803 .63504 .50708 Metetra
.664 .741 .907 r
.63504 .50708 .63588 .50803 .64151 .50632 .64068 .50536 Metetra
.664 .741 .907 r
.64068 .50536 .64151 .50632 .64715 .5046 .64632 .50364 Metetra
.664 .741 .907 r
.64632 .50364 .64715 .5046 .65281 .50288 .65197 .50192 Metetra
.664 .741 .907 r
.65197 .50192 .65281 .50288 .65847 .50115 .65764 .50019 Metetra
.664 .741 .907 r
.65764 .50019 .65847 .50115 .66414 .49942 .66331 .49846 Metetra
.664 .741 .907 r
.66331 .49846 .66414 .49942 .66983 .49769 .669 .49672 Metetra
.664 .741 .907 r
.669 .49672 .66983 .49769 .67553 .49596 .6747 .49499 Metetra
.664 .741 .907 r
.6747 .49499 .67553 .49596 .68123 .49422 .68041 .49324 Metetra
.664 .741 .907 r
.68041 .49324 .68123 .49422 .68695 .49247 .68613 .4915 Metetra
.664 .741 .907 r
.68613 .4915 .68695 .49247 .69269 .49073 .69187 .48975 Metetra
.664 .741 .907 r
.69187 .48975 .69269 .49073 .69843 .48898 .69761 .488 Metetra
.664 .741 .907 r
.69761 .488 .69843 .48898 .70418 .48722 .70337 .48624 Metetra
.664 .741 .907 r
.70337 .48624 .70418 .48722 .70995 .48546 .70914 .48448 Metetra
.664 .741 .907 r
.70914 .48448 .70995 .48546 .71573 .4837 .71492 .48272 Metetra
.664 .741 .907 r
.71492 .48272 .71573 .4837 .72152 .48194 .72072 .48095 Metetra
.664 .741 .907 r
.72072 .48095 .72152 .48194 .72732 .48017 .72652 .47918 Metetra
.664 .741 .907 r
.72652 .47918 .72732 .48017 .73314 .4784 .73234 .47741 Metetra
.664 .741 .907 r
.73234 .47741 .73314 .4784 .73896 .47663 .73816 .47563 Metetra
.664 .741 .907 r
.73816 .47563 .73896 .47663 .7448 .47485 .744 .47385 Metetra
.664 .741 .907 r
.744 .47385 .7448 .47485 .75065 .47306 .74986 .47207 Metetra
.664 .741 .907 r
.74986 .47207 .75065 .47306 .75651 .47128 .75572 .47028 Metetra
.664 .741 .907 r
.75572 .47028 .75651 .47128 .76238 .46949 .7616 .46849 Metetra
.664 .741 .907 r
.7616 .46849 .76238 .46949 .76827 .46769 .76749 .46669 Metetra
.664 .741 .907 r
.76749 .46669 .76827 .46769 .77417 .4659 .77339 .46489 Metetra
.664 .741 .907 r
.77339 .46489 .77417 .4659 .78008 .4641 .7793 .46309 Metetra
.664 .741 .907 r
.7793 .46309 .78008 .4641 .786 .46229 .78522 .46128 Metetra
.664 .741 .907 r
.78522 .46128 .786 .46229 .79193 .46048 .79116 .45947 Metetra
.664 .741 .907 r
.79116 .45947 .79193 .46048 .79788 .45867 .79711 .45766 Metetra
.664 .741 .907 r
.79711 .45766 .79788 .45867 .80384 .45686 .80307 .45584 Metetra
.664 .741 .907 r
.80307 .45584 .80384 .45686 .80981 .45504 .80904 .45402 Metetra
.664 .741 .907 r
.80904 .45402 .80981 .45504 .81579 .45321 .81503 .4522 Metetra
.664 .741 .907 r
.81503 .4522 .81579 .45321 .82179 .45139 .82103 .45037 Metetra
.664 .741 .907 r
.82103 .45037 .82179 .45139 .8278 .44956 .82704 .44853 Metetra
.664 .741 .907 r
.82704 .44853 .8278 .44956 .83382 .44772 .83306 .4467 Metetra
.664 .741 .907 r
.83306 .4467 .83382 .44772 .83985 .44588 .8391 .44486 Metetra
.664 .741 .907 r
.8391 .44486 .83985 .44588 .8459 .44404 .84515 .44301 Metetra
.664 .741 .907 r
.84515 .44301 .8459 .44404 .85195 .44219 .85121 .44116 Metetra
.664 .741 .907 r
.85121 .44116 .85195 .44219 .85803 .44034 .85728 .43931 Metetra
.664 .741 .907 r
.85728 .43931 .85803 .44034 .86411 .43849 .86337 .43746 Metetra
.664 .741 .907 r
.86337 .43746 .86411 .43849 .87021 .43663 .86947 .4356 Metetra
.664 .741 .907 r
.86947 .4356 .87021 .43663 .87631 .43477 .87558 .43373 Metetra
.664 .741 .907 r
.87558 .43373 .87631 .43477 .88244 .43291 .8817 .43186 Metetra
.664 .741 .907 r
.8817 .43186 .88244 .43291 .88857 .43104 .88784 .42999 Metetra
.664 .741 .907 r
.88784 .42999 .88857 .43104 .89472 .42916 .89399 .42812 Metetra
.664 .741 .907 r
.89399 .42812 .89472 .42916 .90088 .42729 .90015 .42624 Metetra
.664 .741 .907 r
.90015 .42624 .90088 .42729 .90705 .42541 .90633 .42435 Metetra
.664 .741 .907 r
.90633 .42435 .90705 .42541 .91324 .42352 .91252 .42247 Metetra
.664 .741 .907 r
.91252 .42247 .91324 .42352 .91944 .42163 .91872 .42058 Metetra
.664 .741 .907 r
.91872 .42058 .91944 .42163 .92565 .41974 .92494 .41868 Metetra
.664 .741 .907 r
.92494 .41868 .92565 .41974 .93188 .41784 .93117 .41678 Metetra
.664 .741 .907 r
.93117 .41678 .93188 .41784 .93811 .41594 .93741 .41488 Metetra
.664 .741 .907 r
.93741 .41488 .93811 .41594 .94437 .41404 .94366 .41297 Metetra
.664 .741 .907 r
.94366 .41297 .94437 .41404 .95063 .41213 .94993 .41106 Metetra
.664 .741 .907 r
.94993 .41106 .95063 .41213 .95691 .41021 .95621 .40914 Metetra
.664 .741 .907 r
.38675 .58163 .38768 .58251 .39283 .58094 .39189 .58006 Metetra
.664 .741 .907 r
.39189 .58006 .39283 .58094 .39798 .57936 .39705 .57849 Metetra
.664 .741 .907 r
.39705 .57849 .39798 .57936 .40315 .57779 .40222 .57691 Metetra
.664 .741 .907 r
.40222 .57691 .40315 .57779 .40832 .57621 .40739 .57533 Metetra
.664 .741 .907 r
.40739 .57533 .40832 .57621 .41351 .57463 .41258 .57375 Metetra
.664 .741 .907 r
.41258 .57375 .41351 .57463 .4187 .57305 .41778 .57216 Metetra
.664 .741 .907 r
.41778 .57216 .4187 .57305 .42391 .57146 .42298 .57057 Metetra
.664 .741 .907 r
.42298 .57057 .42391 .57146 .42912 .56987 .4282 .56898 Metetra
.664 .741 .907 r
.4282 .56898 .42912 .56987 .43435 .56828 .43343 .56739 Metetra
.664 .741 .907 r
.43343 .56739 .43435 .56828 .43958 .56668 .43867 .56579 Metetra
.664 .741 .907 r
.43867 .56579 .43958 .56668 .44483 .56508 .44391 .56419 Metetra
.664 .741 .907 r
.44391 .56419 .44483 .56508 .45008 .56348 .44917 .56258 Metetra
.664 .741 .907 r
.44917 .56258 .45008 .56348 .45535 .56187 .45444 .56097 Metetra
.664 .741 .907 r
.45444 .56097 .45535 .56187 .46063 .56026 .45972 .55936 Metetra
.948 .674 .483 r
.45972 .55936 .46063 .56026 .46531 .59337 .46293 .67494 Metetra
.379 .205 .516 r
.46293 .67494 .46531 .59337 .47121 .55704 .4703 .55613 Metetra
.664 .741 .907 r
.4703 .55613 .47121 .55704 .47652 .55542 .47561 .55451 Metetra
.664 .741 .907 r
.47561 .55451 .47652 .55542 .48183 .5538 .48093 .55289 Metetra
.664 .741 .907 r
.48093 .55289 .48183 .5538 .48716 .55217 .48626 .55126 Metetra
.664 .741 .907 r
.48626 .55126 .48716 .55217 .4925 .55054 .4916 .54963 Metetra
.664 .741 .907 r
.4916 .54963 .4925 .55054 .49785 .54891 .49695 .548 Metetra
.664 .741 .907 r
.49695 .548 .49785 .54891 .50321 .54728 .50231 .54637 Metetra
.664 .741 .907 r
.50231 .54637 .50321 .54728 .50857 .54564 .50768 .54473 Metetra
.664 .741 .907 r
.50768 .54473 .50857 .54564 .51395 .544 .51307 .54308 Metetra
.664 .741 .907 r
.51307 .54308 .51395 .544 .51935 .54236 .51846 .54144 Metetra
.664 .741 .907 r
.51846 .54144 .51935 .54236 .52475 .54071 .52386 .53979 Metetra
.664 .741 .907 r
.52386 .53979 .52475 .54071 .53016 .53906 .52928 .53814 Metetra
.664 .741 .907 r
.52928 .53814 .53016 .53906 .53558 .53741 .5347 .53648 Metetra
.664 .741 .907 r
.5347 .53648 .53558 .53741 .54101 .53575 .54014 .53482 Metetra
.664 .741 .907 r
.54014 .53482 .54101 .53575 .54646 .53409 .54558 .53316 Metetra
.664 .741 .907 r
.54558 .53316 .54646 .53409 .55191 .53243 .55104 .5315 Metetra
.664 .741 .907 r
.55104 .5315 .55191 .53243 .55738 .53076 .55651 .52983 Metetra
.664 .741 .907 r
.55651 .52983 .55738 .53076 .56285 .52909 .56198 .52816 Metetra
.664 .741 .907 r
.56198 .52816 .56285 .52909 .56834 .52742 .56747 .52648 Metetra
.664 .741 .907 r
.56747 .52648 .56834 .52742 .57384 .52574 .57297 .5248 Metetra
.664 .741 .907 r
.57297 .5248 .57384 .52574 .57935 .52406 .57848 .52312 Metetra
.664 .741 .907 r
.57848 .52312 .57935 .52406 .58487 .52238 .58401 .52144 Metetra
.664 .741 .907 r
.58401 .52144 .58487 .52238 .5904 .52069 .58954 .51975 Metetra
.664 .741 .907 r
.58954 .51975 .5904 .52069 .59594 .519 .59508 .51806 Metetra
.959 .638 .366 r
.59508 .51806 .59594 .519 .60159 .52154 .60164 .56043 Metetra
.437 .249 .527 r
.60164 .56043 .60159 .52154 .60706 .51561 .6062 .51466 Metetra
.664 .741 .907 r
.6062 .51466 .60706 .51561 .61263 .51391 .61178 .51296 Metetra
.664 .741 .907 r
.61178 .51296 .61263 .51391 .61822 .51221 .61737 .51126 Metetra
.664 .741 .907 r
.61737 .51126 .61822 .51221 .62382 .5105 .62297 .50955 Metetra
.664 .741 .907 r
.62297 .50955 .62382 .5105 .62942 .50879 .62858 .50784 Metetra
.664 .741 .907 r
.62858 .50784 .62942 .50879 .63504 .50708 .6342 .50612 Metetra
.664 .741 .907 r
.6342 .50612 .63504 .50708 .64068 .50536 .63984 .5044 Metetra
.664 .741 .907 r
.63984 .5044 .64068 .50536 .64632 .50364 .64548 .50268 Metetra
.664 .741 .907 r
.64548 .50268 .64632 .50364 .65197 .50192 .65114 .50095 Metetra
.664 .741 .907 r
.65114 .50095 .65197 .50192 .65764 .50019 .6568 .49922 Metetra
.664 .741 .907 r
.6568 .49922 .65764 .50019 .66331 .49846 .66248 .49749 Metetra
.664 .741 .907 r
.66248 .49749 .66331 .49846 .669 .49672 .66817 .49575 Metetra
.664 .741 .907 r
.66817 .49575 .669 .49672 .6747 .49499 .67388 .49401 Metetra
.664 .741 .907 r
.67388 .49401 .6747 .49499 .68041 .49324 .67959 .49227 Metetra
.664 .741 .907 r
.67959 .49227 .68041 .49324 .68613 .4915 .68531 .49052 Metetra
.664 .741 .907 r
.68531 .49052 .68613 .4915 .69187 .48975 .69105 .48877 Metetra
.664 .741 .907 r
.69105 .48877 .69187 .48975 .69761 .488 .6968 .48702 Metetra
.664 .741 .907 r
.6968 .48702 .69761 .488 .70337 .48624 .70256 .48526 Metetra
.664 .741 .907 r
.70256 .48526 .70337 .48624 .70914 .48448 .70833 .4835 Metetra
.664 .741 .907 r
.70833 .4835 .70914 .48448 .71492 .48272 .71411 .48174 Metetra
.664 .741 .907 r
.71411 .48174 .71492 .48272 .72072 .48095 .71991 .47997 Metetra
.664 .741 .907 r
.71991 .47997 .72072 .48095 .72652 .47918 .72572 .4782 Metetra
.664 .741 .907 r
.72572 .4782 .72652 .47918 .73234 .47741 .73154 .47642 Metetra
.664 .741 .907 r
.73154 .47642 .73234 .47741 .73816 .47563 .73737 .47464 Metetra
.646 .734 .913 r
.73737 .47464 .73816 .47563 .744 .47385 .74323 .47313 Metetra
.677 .809 .946 r
.74323 .47313 .744 .47385 .74986 .47207 .74906 .47107 Metetra
.664 .741 .907 r
.74906 .47107 .74986 .47207 .75572 .47028 .75493 .46928 Metetra
.664 .741 .907 r
.75493 .46928 .75572 .47028 .7616 .46849 .76081 .46749 Metetra
.664 .741 .907 r
.76081 .46749 .7616 .46849 .76749 .46669 .7667 .46569 Metetra
.664 .741 .907 r
.7667 .46569 .76749 .46669 .77339 .46489 .7726 .46389 Metetra
.664 .741 .907 r
.7726 .46389 .77339 .46489 .7793 .46309 .77852 .46208 Metetra
.664 .741 .907 r
.77852 .46208 .7793 .46309 .78522 .46128 .78444 .46027 Metetra
.664 .741 .907 r
.78444 .46027 .78522 .46128 .79116 .45947 .79038 .45846 Metetra
.664 .741 .907 r
.79038 .45846 .79116 .45947 .79711 .45766 .79634 .45665 Metetra
.664 .741 .907 r
.79634 .45665 .79711 .45766 .80307 .45584 .8023 .45483 Metetra
.664 .741 .907 r
.8023 .45483 .80307 .45584 .80904 .45402 .80828 .453 Metetra
.664 .741 .907 r
.80828 .453 .80904 .45402 .81503 .4522 .81427 .45118 Metetra
.664 .741 .907 r
.81427 .45118 .81503 .4522 .82103 .45037 .82027 .44934 Metetra
.664 .741 .907 r
.82027 .44934 .82103 .45037 .82704 .44853 .82628 .44751 Metetra
.664 .741 .907 r
.82628 .44751 .82704 .44853 .83306 .4467 .83231 .44567 Metetra
.664 .741 .907 r
.83231 .44567 .83306 .4467 .8391 .44486 .83834 .44383 Metetra
.664 .741 .907 r
.83834 .44383 .8391 .44486 .84515 .44301 .8444 .44198 Metetra
.664 .741 .907 r
.8444 .44198 .84515 .44301 .85121 .44116 .85046 .44013 Metetra
.664 .741 .907 r
.85046 .44013 .85121 .44116 .85728 .43931 .85654 .43828 Metetra
.664 .741 .907 r
.85654 .43828 .85728 .43931 .86337 .43746 .86262 .43642 Metetra
.664 .741 .907 r
.86262 .43642 .86337 .43746 .86947 .4356 .86873 .43456 Metetra
.664 .741 .907 r
.86873 .43456 .86947 .4356 .87558 .43373 .87484 .43269 Metetra
.664 .741 .907 r
.87484 .43269 .87558 .43373 .8817 .43186 .88097 .43082 Metetra
.664 .741 .907 r
.88097 .43082 .8817 .43186 .88784 .42999 .88711 .42895 Metetra
.664 .741 .907 r
.88711 .42895 .88784 .42999 .89399 .42812 .89326 .42707 Metetra
.664 .741 .907 r
.89326 .42707 .89399 .42812 .90015 .42624 .89943 .42519 Metetra
.664 .741 .907 r
.89943 .42519 .90015 .42624 .90633 .42435 .90561 .4233 Metetra
.664 .741 .907 r
.90561 .4233 .90633 .42435 .91252 .42247 .9118 .42141 Metetra
.664 .741 .907 r
.9118 .42141 .91252 .42247 .91872 .42058 .918 .41952 Metetra
.664 .741 .907 r
.918 .41952 .91872 .42058 .92494 .41868 .92422 .41762 Metetra
.664 .741 .907 r
.92422 .41762 .92494 .41868 .93117 .41678 .93045 .41572 Metetra
.664 .741 .907 r
.93045 .41572 .93117 .41678 .93741 .41488 .9367 .41382 Metetra
.664 .741 .907 r
.9367 .41382 .93741 .41488 .94366 .41297 .94296 .41191 Metetra
.664 .741 .907 r
.94296 .41191 .94366 .41297 .94993 .41106 .94923 .40999 Metetra
.664 .741 .907 r
.94923 .40999 .94993 .41106 .95621 .40914 .95551 .40807 Metetra
.664 .741 .907 r
.38581 .58076 .38675 .58163 .39189 .58006 .39096 .57918 Metetra
.664 .741 .907 r
.39096 .57918 .39189 .58006 .39705 .57849 .39612 .57761 Metetra
.664 .741 .907 r
.39612 .57761 .39705 .57849 .40222 .57691 .40128 .57603 Metetra
.664 .741 .907 r
.40128 .57603 .40222 .57691 .40739 .57533 .40646 .57445 Metetra
.664 .741 .907 r
.40646 .57445 .40739 .57533 .41258 .57375 .41165 .57286 Metetra
.664 .741 .907 r
.41165 .57286 .41258 .57375 .41778 .57216 .41685 .57128 Metetra
.664 .741 .907 r
.41685 .57128 .41778 .57216 .42298 .57057 .42206 .56969 Metetra
.664 .741 .907 r
.42206 .56969 .42298 .57057 .4282 .56898 .42728 .56809 Metetra
.664 .741 .907 r
.42728 .56809 .4282 .56898 .43343 .56739 .43251 .56649 Metetra
.664 .741 .907 r
.43251 .56649 .43343 .56739 .43867 .56579 .43775 .5649 Metetra
.664 .741 .907 r
.43775 .5649 .43867 .56579 .44391 .56419 .443 .56329 Metetra
.664 .741 .907 r
.443 .56329 .44391 .56419 .44917 .56258 .44826 .56169 Metetra
.664 .741 .907 r
.44826 .56169 .44917 .56258 .45444 .56097 .45353 .56008 Metetra
.664 .741 .907 r
.45353 .56008 .45444 .56097 .45972 .55936 .45881 .55846 Metetra
.947 .679 .497 r
.45881 .55846 .45972 .55936 .46293 .67494 .46026 .76984 Metetra
.2 .067 .464 r
.46026 .76984 .46293 .67494 .4703 .55613 .4694 .55523 Metetra
.664 .741 .907 r
.4694 .55523 .4703 .55613 .47561 .55451 .47471 .55361 Metetra
.664 .741 .907 r
.47471 .55361 .47561 .55451 .48093 .55289 .48003 .55198 Metetra
.664 .741 .907 r
.48003 .55198 .48093 .55289 .48626 .55126 .48536 .55036 Metetra
.664 .741 .907 r
.48536 .55036 .48626 .55126 .4916 .54963 .4907 .54872 Metetra
.664 .741 .907 r
.4907 .54872 .4916 .54963 .49695 .548 .49605 .54709 Metetra
.664 .741 .907 r
.49605 .54709 .49695 .548 .50231 .54637 .50142 .54545 Metetra
.664 .741 .907 r
.50142 .54545 .50231 .54637 .50768 .54473 .50679 .54381 Metetra
.664 .741 .907 r
.50679 .54381 .50768 .54473 .51307 .54308 .51218 .54217 Metetra
.664 .741 .907 r
.51218 .54217 .51307 .54308 .51846 .54144 .51757 .54052 Metetra
.664 .741 .907 r
.51757 .54052 .51846 .54144 .52386 .53979 .52298 .53887 Metetra
.664 .741 .907 r
.52298 .53887 .52386 .53979 .52928 .53814 .52839 .53722 Metetra
.664 .741 .907 r
.52839 .53722 .52928 .53814 .5347 .53648 .53382 .53556 Metetra
.664 .741 .907 r
.53382 .53556 .5347 .53648 .54014 .53482 .53926 .5339 Metetra
.664 .741 .907 r
.53926 .5339 .54014 .53482 .54558 .53316 .5447 .53223 Metetra
.664 .741 .907 r
.5447 .53223 .54558 .53316 .55104 .5315 .55016 .53057 Metetra
.664 .741 .907 r
.55016 .53057 .55104 .5315 .55651 .52983 .55563 .5289 Metetra
.664 .741 .907 r
.55563 .5289 .55651 .52983 .56198 .52816 .56111 .52722 Metetra
.664 .741 .907 r
.56111 .52722 .56198 .52816 .56747 .52648 .5666 .52555 Metetra
.664 .741 .907 r
.5666 .52555 .56747 .52648 .57297 .5248 .57211 .52387 Metetra
.664 .741 .907 r
.57211 .52387 .57297 .5248 .57848 .52312 .57762 .52218 Metetra
.664 .741 .907 r
.57762 .52218 .57848 .52312 .58401 .52144 .58314 .5205 Metetra
.664 .741 .907 r
.58314 .5205 .58401 .52144 .58954 .51975 .58868 .51881 Metetra
.664 .741 .907 r
.58868 .51881 .58954 .51975 .59508 .51806 .59423 .51711 Metetra
.961 .654 .399 r
.59423 .51711 .59508 .51806 .60164 .56043 .60116 .57689 Metetra
0 0 .323 r
.60116 .57689 .60164 .56043 .6062 .51466 .60535 .51372 Metetra
.664 .741 .907 r
.60535 .51372 .6062 .51466 .61178 .51296 .61093 .51201 Metetra
.664 .741 .907 r
.61093 .51201 .61178 .51296 .61737 .51126 .61652 .5103 Metetra
.664 .741 .907 r
.61652 .5103 .61737 .51126 .62297 .50955 .62212 .50859 Metetra
.664 .741 .907 r
.62212 .50859 .62297 .50955 .62858 .50784 .62774 .50688 Metetra
.664 .741 .907 r
.62774 .50688 .62858 .50784 .6342 .50612 .63336 .50516 Metetra
.664 .741 .907 r
.63336 .50516 .6342 .50612 .63984 .5044 .639 .50344 Metetra
.664 .741 .907 r
.639 .50344 .63984 .5044 .64548 .50268 .64464 .50172 Metetra
.664 .741 .907 r
.64464 .50172 .64548 .50268 .65114 .50095 .6503 .49999 Metetra
.664 .741 .907 r
.6503 .49999 .65114 .50095 .6568 .49922 .65597 .49826 Metetra
.664 .741 .907 r
.65597 .49826 .6568 .49922 .66248 .49749 .66165 .49652 Metetra
.664 .741 .907 r
.66165 .49652 .66248 .49749 .66817 .49575 .66735 .49478 Metetra
.664 .741 .907 r
.66735 .49478 .66817 .49575 .67388 .49401 .67305 .49304 Metetra
.664 .741 .907 r
.67305 .49304 .67388 .49401 .67959 .49227 .67877 .4913 Metetra
.664 .741 .907 r
.67877 .4913 .67959 .49227 .68531 .49052 .68449 .48955 Metetra
.664 .741 .907 r
.68449 .48955 .68531 .49052 .69105 .48877 .69023 .4878 Metetra
.664 .741 .907 r
.69023 .4878 .69105 .48877 .6968 .48702 .69598 .48604 Metetra
.664 .741 .907 r
.69598 .48604 .6968 .48702 .70256 .48526 .70175 .48428 Metetra
.664 .741 .907 r
.70175 .48428 .70256 .48526 .70833 .4835 .70752 .48252 Metetra
.664 .741 .907 r
.70752 .48252 .70833 .4835 .71411 .48174 .71331 .48075 Metetra
.664 .741 .907 r
.71331 .48075 .71411 .48174 .71991 .47997 .7191 .47898 Metetra
.664 .741 .907 r
.7191 .47898 .71991 .47997 .72572 .4782 .72491 .47721 Metetra
.664 .741 .907 r
.72491 .47721 .72572 .4782 .73154 .47642 .73073 .47543 Metetra
.664 .741 .907 r
.73073 .47543 .73154 .47642 .73737 .47464 .73657 .47365 Metetra
.664 .741 .907 r
.73657 .47365 .73737 .47464 .74323 .47313 .74241 .47186 Metetra
.662 .69 .865 r
.74241 .47186 .74323 .47313 .74906 .47107 .74827 .47007 Metetra
.664 .741 .907 r
.74827 .47007 .74906 .47107 .75493 .46928 .75414 .46828 Metetra
.664 .741 .907 r
.75414 .46828 .75493 .46928 .76081 .46749 .76002 .46649 Metetra
.664 .741 .907 r
.76002 .46649 .76081 .46749 .7667 .46569 .76591 .46469 Metetra
.664 .741 .907 r
.76591 .46469 .7667 .46569 .7726 .46389 .77182 .46288 Metetra
.664 .741 .907 r
.77182 .46288 .7726 .46389 .77852 .46208 .77774 .46108 Metetra
.664 .741 .907 r
.77774 .46108 .77852 .46208 .78444 .46027 .78367 .45926 Metetra
.664 .741 .907 r
.78367 .45926 .78444 .46027 .79038 .45846 .78961 .45745 Metetra
.664 .741 .907 r
.78961 .45745 .79038 .45846 .79634 .45665 .79556 .45563 Metetra
.664 .741 .907 r
.79556 .45563 .79634 .45665 .8023 .45483 .80153 .45381 Metetra
.664 .741 .907 r
.80153 .45381 .8023 .45483 .80828 .453 .80751 .45198 Metetra
.664 .741 .907 r
.80751 .45198 .80828 .453 .81427 .45118 .8135 .45015 Metetra
.664 .741 .907 r
.8135 .45015 .81427 .45118 .82027 .44934 .8195 .44832 Metetra
.664 .741 .907 r
.8195 .44832 .82027 .44934 .82628 .44751 .82552 .44648 Metetra
.664 .741 .907 r
.82552 .44648 .82628 .44751 .83231 .44567 .83155 .44464 Metetra
.664 .741 .907 r
.83155 .44464 .83231 .44567 .83834 .44383 .83759 .4428 Metetra
.664 .741 .907 r
.83759 .4428 .83834 .44383 .8444 .44198 .84364 .44095 Metetra
.664 .741 .907 r
.84364 .44095 .8444 .44198 .85046 .44013 .84971 .4391 Metetra
.664 .741 .907 r
.84971 .4391 .85046 .44013 .85654 .43828 .85579 .43724 Metetra
.664 .741 .907 r
.85579 .43724 .85654 .43828 .86262 .43642 .86188 .43538 Metetra
.664 .741 .907 r
.86188 .43538 .86262 .43642 .86873 .43456 .86799 .43352 Metetra
.664 .741 .907 r
.86799 .43352 .86873 .43456 .87484 .43269 .8741 .43165 Metetra
.664 .741 .907 r
.8741 .43165 .87484 .43269 .88097 .43082 .88023 .42978 Metetra
.664 .741 .907 r
.88023 .42978 .88097 .43082 .88711 .42895 .88638 .4279 Metetra
.664 .741 .907 r
.88638 .4279 .88711 .42895 .89326 .42707 .89253 .42602 Metetra
.664 .741 .907 r
.89253 .42602 .89326 .42707 .89943 .42519 .8987 .42414 Metetra
.664 .741 .907 r
.8987 .42414 .89943 .42519 .90561 .4233 .90488 .42225 Metetra
.664 .741 .907 r
.90488 .42225 .90561 .4233 .9118 .42141 .91108 .42036 Metetra
.664 .741 .907 r
.91108 .42036 .9118 .42141 .918 .41952 .91729 .41846 Metetra
.664 .741 .907 r
.91729 .41846 .918 .41952 .92422 .41762 .92351 .41656 Metetra
.664 .741 .907 r
.92351 .41656 .92422 .41762 .93045 .41572 .92974 .41466 Metetra
.664 .741 .907 r
.92974 .41466 .93045 .41572 .9367 .41382 .93599 .41275 Metetra
.664 .741 .907 r
.93599 .41275 .9367 .41382 .94296 .41191 .94225 .41084 Metetra
.664 .741 .907 r
.94225 .41084 .94296 .41191 .94923 .40999 .94852 .40892 Metetra
.664 .741 .907 r
.94852 .40892 .94923 .40999 .95551 .40807 .95481 .407 Metetra
.664 .741 .907 r
.38487 .57988 .38581 .58076 .39096 .57918 .39002 .5783 Metetra
.664 .741 .907 r
.39002 .5783 .39096 .57918 .39612 .57761 .39518 .57673 Metetra
.664 .741 .907 r
.39518 .57673 .39612 .57761 .40128 .57603 .40035 .57515 Metetra
.664 .741 .907 r
.40035 .57515 .40128 .57603 .40646 .57445 .40553 .57356 Metetra
.664 .741 .907 r
.40553 .57356 .40646 .57445 .41165 .57286 .41072 .57198 Metetra
.664 .741 .907 r
.41072 .57198 .41165 .57286 .41685 .57128 .41592 .57039 Metetra
.664 .741 .907 r
.41592 .57039 .41685 .57128 .42206 .56969 .42113 .5688 Metetra
.664 .741 .907 r
.42113 .5688 .42206 .56969 .42728 .56809 .42636 .5672 Metetra
.664 .741 .907 r
.42636 .5672 .42728 .56809 .43251 .56649 .43159 .5656 Metetra
.664 .741 .907 r
.43159 .5656 .43251 .56649 .43775 .5649 .43683 .564 Metetra
.664 .741 .907 r
.43683 .564 .43775 .5649 .443 .56329 .44208 .5624 Metetra
.664 .741 .907 r
.44208 .5624 .443 .56329 .44826 .56169 .44734 .56079 Metetra
.664 .741 .907 r
.44734 .56079 .44826 .56169 .45353 .56008 .45261 .55918 Metetra
.664 .741 .907 r
.45261 .55918 .45353 .56008 .45881 .55846 .45789 .55756 Metetra
.947 .679 .497 r
.45789 .55756 .45881 .55846 .46026 .76984 .45925 .77139 Metetra
.954 .703 .518 r
.45925 .77139 .46026 .76984 .4694 .55523 .46849 .55433 Metetra
.664 .741 .907 r
.46849 .55433 .4694 .55523 .47471 .55361 .4738 .5527 Metetra
.664 .741 .907 r
.4738 .5527 .47471 .55361 .48003 .55198 .47912 .55108 Metetra
.664 .741 .907 r
.47912 .55108 .48003 .55198 .48536 .55036 .48446 .54945 Metetra
.664 .741 .907 r
.48446 .54945 .48536 .55036 .4907 .54872 .4898 .54781 Metetra
.664 .741 .907 r
.4898 .54781 .4907 .54872 .49605 .54709 .49516 .54618 Metetra
.664 .741 .907 r
.49516 .54618 .49605 .54709 .50142 .54545 .50052 .54454 Metetra
.664 .741 .907 r
.50052 .54454 .50142 .54545 .50679 .54381 .5059 .5429 Metetra
.664 .741 .907 r
.5059 .5429 .50679 .54381 .51218 .54217 .51128 .54125 Metetra
.664 .741 .907 r
.51128 .54125 .51218 .54217 .51757 .54052 .51668 .5396 Metetra
.664 .741 .907 r
.51668 .5396 .51757 .54052 .52298 .53887 .52209 .53795 Metetra
.664 .741 .907 r
.52209 .53795 .52298 .53887 .52839 .53722 .52751 .53629 Metetra
.664 .741 .907 r
.52751 .53629 .52839 .53722 .53382 .53556 .53293 .53463 Metetra
.664 .741 .907 r
.53293 .53463 .53382 .53556 .53926 .5339 .53837 .53297 Metetra
.664 .741 .907 r
.53837 .53297 .53926 .5339 .5447 .53223 .54382 .53131 Metetra
.664 .741 .907 r
.54382 .53131 .5447 .53223 .55016 .53057 .54929 .52964 Metetra
.664 .741 .907 r
.54929 .52964 .55016 .53057 .55563 .5289 .55476 .52796 Metetra
.664 .741 .907 r
.55476 .52796 .55563 .5289 .56111 .52722 .56024 .52629 Metetra
.664 .741 .907 r
.56024 .52629 .56111 .52722 .5666 .52555 .56573 .52461 Metetra
.664 .741 .907 r
.56573 .52461 .5666 .52555 .57211 .52387 .57124 .52293 Metetra
.664 .741 .907 r
.57124 .52293 .57211 .52387 .57762 .52218 .57675 .52124 Metetra
.664 .741 .907 r
.57675 .52124 .57762 .52218 .58314 .5205 .58228 .51955 Metetra
.664 .741 .907 r
.58228 .51955 .58314 .5205 .58868 .51881 .58782 .51786 Metetra
.664 .741 .907 r
.58782 .51786 .58868 .51881 .59423 .51711 .59337 .51617 Metetra
.961 .656 .402 r
.59337 .51617 .59423 .51711 .60116 .57689 .60034 .57823 Metetra
.985 .747 .492 r
.60034 .57823 .60116 .57689 .60535 .51372 .6045 .51277 Metetra
.664 .741 .907 r
.6045 .51277 .60535 .51372 .61093 .51201 .61008 .51106 Metetra
.664 .741 .907 r
.61008 .51106 .61093 .51201 .61652 .5103 .61567 .50935 Metetra
.664 .741 .907 r
.61567 .50935 .61652 .5103 .62212 .50859 .62128 .50764 Metetra
.664 .741 .907 r
.62128 .50764 .62212 .50859 .62774 .50688 .62689 .50592 Metetra
.664 .741 .907 r
.62689 .50592 .62774 .50688 .63336 .50516 .63252 .5042 Metetra
.664 .741 .907 r
.63252 .5042 .63336 .50516 .639 .50344 .63816 .50248 Metetra
.664 .741 .907 r
.63816 .50248 .639 .50344 .64464 .50172 .6438 .50075 Metetra
.664 .741 .907 r
.6438 .50075 .64464 .50172 .6503 .49999 .64947 .49902 Metetra
.664 .741 .907 r
.64947 .49902 .6503 .49999 .65597 .49826 .65514 .49729 Metetra
.664 .741 .907 r
.65514 .49729 .65597 .49826 .66165 .49652 .66082 .49555 Metetra
.664 .741 .907 r
.66082 .49555 .66165 .49652 .66735 .49478 .66652 .49381 Metetra
.664 .741 .907 r
.66652 .49381 .66735 .49478 .67305 .49304 .67222 .49207 Metetra
.664 .741 .907 r
.67222 .49207 .67305 .49304 .67877 .4913 .67794 .49032 Metetra
.664 .741 .907 r
.67794 .49032 .67877 .4913 .68449 .48955 .68367 .48857 Metetra
.664 .741 .907 r
.68367 .48857 .68449 .48955 .69023 .4878 .68941 .48682 Metetra
.664 .741 .907 r
.68941 .48682 .69023 .4878 .69598 .48604 .69517 .48506 Metetra
.664 .741 .907 r
.69517 .48506 .69598 .48604 .70175 .48428 .70093 .4833 Metetra
.664 .741 .907 r
.70093 .4833 .70175 .48428 .70752 .48252 .70671 .48153 Metetra
.664 .741 .907 r
.70671 .48153 .70752 .48252 .71331 .48075 .7125 .47976 Metetra
.664 .741 .907 r
.7125 .47976 .71331 .48075 .7191 .47898 .7183 .47799 Metetra
.664 .741 .907 r
.7183 .47799 .7191 .47898 .72491 .47721 .72411 .47621 Metetra
.664 .741 .907 r
.72411 .47621 .72491 .47721 .73073 .47543 .72993 .47443 Metetra
.664 .741 .907 r
.72993 .47443 .73073 .47543 .73657 .47365 .73577 .47265 Metetra
.664 .741 .907 r
.73577 .47265 .73657 .47365 .74241 .47186 .74162 .47086 Metetra
.664 .741 .907 r
.74162 .47086 .74241 .47186 .74827 .47007 .74747 .46907 Metetra
.664 .741 .907 r
.74747 .46907 .74827 .47007 .75414 .46828 .75335 .46728 Metetra
.664 .741 .907 r
.75335 .46728 .75414 .46828 .76002 .46649 .75923 .46548 Metetra
.664 .741 .907 r
.75923 .46548 .76002 .46649 .76591 .46469 .76513 .46368 Metetra
.664 .741 .907 r
.76513 .46368 .76591 .46469 .77182 .46288 .77103 .46187 Metetra
.664 .741 .907 r
.77103 .46187 .77182 .46288 .77774 .46108 .77695 .46007 Metetra
.664 .741 .907 r
.77695 .46007 .77774 .46108 .78367 .45926 .78289 .45825 Metetra
.664 .741 .907 r
.78289 .45825 .78367 .45926 .78961 .45745 .78883 .45644 Metetra
.664 .741 .907 r
.78883 .45644 .78961 .45745 .79556 .45563 .79479 .45462 Metetra
.664 .741 .907 r
.79479 .45462 .79556 .45563 .80153 .45381 .80076 .45279 Metetra
.664 .741 .907 r
.80076 .45279 .80153 .45381 .80751 .45198 .80674 .45096 Metetra
.664 .741 .907 r
.80674 .45096 .80751 .45198 .8135 .45015 .81273 .44913 Metetra
.664 .741 .907 r
.81273 .44913 .8135 .45015 .8195 .44832 .81874 .4473 Metetra
.664 .741 .907 r
.81874 .4473 .8195 .44832 .82552 .44648 .82476 .44546 Metetra
.664 .741 .907 r
.82476 .44546 .82552 .44648 .83155 .44464 .83079 .44361 Metetra
.664 .741 .907 r
.83079 .44361 .83155 .44464 .83759 .4428 .83683 .44177 Metetra
.664 .741 .907 r
.83683 .44177 .83759 .4428 .84364 .44095 .84289 .43992 Metetra
.664 .741 .907 r
.84289 .43992 .84364 .44095 .84971 .4391 .84896 .43806 Metetra
.664 .741 .907 r
.84896 .43806 .84971 .4391 .85579 .43724 .85504 .4362 Metetra
.664 .741 .907 r
.85504 .4362 .85579 .43724 .86188 .43538 .86114 .43434 Metetra
.664 .741 .907 r
.86114 .43434 .86188 .43538 .86799 .43352 .86724 .43248 Metetra
.664 .741 .907 r
.86724 .43248 .86799 .43352 .8741 .43165 .87336 .4306 Metetra
.664 .741 .907 r
.87336 .4306 .8741 .43165 .88023 .42978 .8795 .42873 Metetra
.664 .741 .907 r
.8795 .42873 .88023 .42978 .88638 .4279 .88564 .42685 Metetra
.664 .741 .907 r
.88564 .42685 .88638 .4279 .89253 .42602 .8918 .42497 Metetra
.664 .741 .907 r
.8918 .42497 .89253 .42602 .8987 .42414 .89797 .42308 Metetra
.664 .741 .907 r
.89797 .42308 .8987 .42414 .90488 .42225 .90416 .42119 Metetra
.664 .741 .907 r
.90416 .42119 .90488 .42225 .91108 .42036 .91036 .4193 Metetra
.664 .741 .907 r
.91036 .4193 .91108 .42036 .91729 .41846 .91657 .4174 Metetra
.664 .741 .907 r
.91657 .4174 .91729 .41846 .92351 .41656 .92279 .4155 Metetra
.664 .741 .907 r
.92279 .4155 .92351 .41656 .92974 .41466 .92903 .41359 Metetra
.664 .741 .907 r
.92903 .41359 .92974 .41466 .93599 .41275 .93528 .41169 Metetra
.664 .741 .907 r
.93528 .41169 .93599 .41275 .94225 .41084 .94154 .40977 Metetra
.664 .741 .907 r
.94154 .40977 .94225 .41084 .94852 .40892 .94782 .40785 Metetra
.664 .741 .907 r
.94782 .40785 .94852 .40892 .95481 .407 .95411 .40593 Metetra
.664 .741 .907 r
.38393 .579 .38487 .57988 .39002 .5783 .38908 .57743 Metetra
.664 .741 .907 r
.38908 .57743 .39002 .5783 .39518 .57673 .39425 .57585 Metetra
.664 .741 .907 r
.39425 .57585 .39518 .57673 .40035 .57515 .39942 .57426 Metetra
.664 .741 .907 r
.39942 .57426 .40035 .57515 .40553 .57356 .4046 .57268 Metetra
.664 .741 .907 r
.4046 .57268 .40553 .57356 .41072 .57198 .40979 .57109 Metetra
.664 .741 .907 r
.40979 .57109 .41072 .57198 .41592 .57039 .415 .5695 Metetra
.664 .741 .907 r
.415 .5695 .41592 .57039 .42113 .5688 .42021 .56791 Metetra
.664 .741 .907 r
.42021 .56791 .42113 .5688 .42636 .5672 .42543 .56631 Metetra
.664 .741 .907 r
.42543 .56631 .42636 .5672 .43159 .5656 .43066 .56471 Metetra
.664 .741 .907 r
.43066 .56471 .43159 .5656 .43683 .564 .43591 .56311 Metetra
.664 .741 .907 r
.43591 .56311 .43683 .564 .44208 .5624 .44116 .5615 Metetra
.664 .741 .907 r
.44116 .5615 .44208 .5624 .44734 .56079 .44642 .55989 Metetra
.664 .741 .907 r
.44642 .55989 .44734 .56079 .45261 .55918 .4517 .55828 Metetra
.664 .741 .907 r
.4517 .55828 .45261 .55918 .45789 .55756 .45698 .55666 Metetra
.947 .679 .497 r
.45698 .55666 .45789 .55756 .45925 .77139 .45828 .77055 Metetra
.944 .693 .526 r
.45828 .77055 .45925 .77139 .46849 .55433 .46758 .55342 Metetra
.664 .741 .907 r
.46758 .55342 .46849 .55433 .4738 .5527 .47289 .5518 Metetra
.664 .741 .907 r
.47289 .5518 .4738 .5527 .47912 .55108 .47822 .55017 Metetra
.664 .741 .907 r
.47822 .55017 .47912 .55108 .48446 .54945 .48356 .54854 Metetra
.664 .741 .907 r
.48356 .54854 .48446 .54945 .4898 .54781 .4889 .5469 Metetra
.664 .741 .907 r
.4889 .5469 .4898 .54781 .49516 .54618 .49426 .54526 Metetra
.664 .741 .907 r
.49426 .54526 .49516 .54618 .50052 .54454 .49963 .54362 Metetra
.664 .741 .907 r
.49963 .54362 .50052 .54454 .5059 .5429 .505 .54198 Metetra
.664 .741 .907 r
.505 .54198 .5059 .5429 .51128 .54125 .51039 .54033 Metetra
.664 .741 .907 r
.51039 .54033 .51128 .54125 .51668 .5396 .51579 .53868 Metetra
.664 .741 .907 r
.51579 .53868 .51668 .5396 .52209 .53795 .5212 .53702 Metetra
.664 .741 .907 r
.5212 .53702 .52209 .53795 .52751 .53629 .52662 .53537 Metetra
.664 .741 .907 r
.52662 .53537 .52751 .53629 .53293 .53463 .53205 .53371 Metetra
.664 .741 .907 r
.53205 .53371 .53293 .53463 .53837 .53297 .53749 .53204 Metetra
.664 .741 .907 r
.53749 .53204 .53837 .53297 .54382 .53131 .54294 .53037 Metetra
.664 .741 .907 r
.54294 .53037 .54382 .53131 .54929 .52964 .54841 .5287 Metetra
.664 .741 .907 r
.54841 .5287 .54929 .52964 .55476 .52796 .55388 .52703 Metetra
.664 .741 .907 r
.55388 .52703 .55476 .52796 .56024 .52629 .55937 .52535 Metetra
.664 .741 .907 r
.55937 .52535 .56024 .52629 .56573 .52461 .56486 .52367 Metetra
.664 .741 .907 r
.56486 .52367 .56573 .52461 .57124 .52293 .57037 .52199 Metetra
.664 .741 .907 r
.57037 .52199 .57124 .52293 .57675 .52124 .57589 .5203 Metetra
.664 .741 .907 r
.57589 .5203 .57675 .52124 .58228 .51955 .58142 .51861 Metetra
.664 .741 .907 r
.58142 .51861 .58228 .51955 .58782 .51786 .58696 .51692 Metetra
.664 .741 .907 r
.58696 .51692 .58782 .51786 .59337 .51617 .59251 .51522 Metetra
.962 .659 .409 r
.59251 .51522 .59337 .51617 .60034 .57823 .59959 .58309 Metetra
.991 .773 .391 r
.59959 .58309 .60034 .57823 .6045 .51277 .60364 .51181 Metetra
.664 .741 .907 r
.60364 .51181 .6045 .51277 .61008 .51106 .60922 .51011 Metetra
.664 .741 .907 r
.60922 .51011 .61008 .51106 .61567 .50935 .61482 .5084 Metetra
.664 .741 .907 r
.61482 .5084 .61567 .50935 .62128 .50764 .62043 .50668 Metetra
.664 .741 .907 r
.62043 .50668 .62128 .50764 .62689 .50592 .62604 .50496 Metetra
.664 .741 .907 r
.62604 .50496 .62689 .50592 .63252 .5042 .63167 .50324 Metetra
.664 .741 .907 r
.63167 .50324 .63252 .5042 .63816 .50248 .63731 .50152 Metetra
.664 .741 .907 r
.63731 .50152 .63816 .50248 .6438 .50075 .64297 .49979 Metetra
.664 .741 .907 r
.64297 .49979 .6438 .50075 .64947 .49902 .64863 .49806 Metetra
.664 .741 .907 r
.64863 .49806 .64947 .49902 .65514 .49729 .6543 .49632 Metetra
.664 .741 .907 r
.6543 .49632 .65514 .49729 .66082 .49555 .65999 .49458 Metetra
.664 .741 .907 r
.65999 .49458 .66082 .49555 .66652 .49381 .66569 .49284 Metetra
.664 .741 .907 r
.66569 .49284 .66652 .49381 .67222 .49207 .6714 .4911 Metetra
.664 .741 .907 r
.6714 .4911 .67222 .49207 .67794 .49032 .67712 .48935 Metetra
.664 .741 .907 r
.67712 .48935 .67794 .49032 .68367 .48857 .68285 .48759 Metetra
.664 .741 .907 r
.68285 .48759 .68367 .48857 .68941 .48682 .68859 .48584 Metetra
.664 .741 .907 r
.68859 .48584 .68941 .48682 .69517 .48506 .69435 .48408 Metetra
.664 .741 .907 r
.69435 .48408 .69517 .48506 .70093 .4833 .70012 .48231 Metetra
.664 .741 .907 r
.70012 .48231 .70093 .4833 .70671 .48153 .70589 .48055 Metetra
.664 .741 .907 r
.70589 .48055 .70671 .48153 .7125 .47976 .71169 .47877 Metetra
.664 .741 .907 r
.71169 .47877 .7125 .47976 .7183 .47799 .71749 .477 Metetra
.664 .741 .907 r
.71749 .477 .7183 .47799 .72411 .47621 .7233 .47522 Metetra
.664 .741 .907 r
.7233 .47522 .72411 .47621 .72993 .47443 .72913 .47344 Metetra
.664 .741 .907 r
.72913 .47344 .72993 .47443 .73577 .47265 .73497 .47166 Metetra
.664 .741 .907 r
.73497 .47166 .73577 .47265 .74162 .47086 .74082 .46987 Metetra
.664 .741 .907 r
.74082 .46987 .74162 .47086 .74747 .46907 .74668 .46807 Metetra
.664 .741 .907 r
.74668 .46807 .74747 .46907 .75335 .46728 .75255 .46628 Metetra
.664 .741 .907 r
.75255 .46628 .75335 .46728 .75923 .46548 .75844 .46448 Metetra
.664 .741 .907 r
.75844 .46448 .75923 .46548 .76513 .46368 .76434 .46267 Metetra
.664 .741 .907 r
.76434 .46267 .76513 .46368 .77103 .46187 .77025 .46087 Metetra
.664 .741 .907 r
.77025 .46087 .77103 .46187 .77695 .46007 .77617 .45906 Metetra
.664 .741 .907 r
.77617 .45906 .77695 .46007 .78289 .45825 .78211 .45724 Metetra
.664 .741 .907 r
.78211 .45724 .78289 .45825 .78883 .45644 .78805 .45542 Metetra
.664 .741 .907 r
.78805 .45542 .78883 .45644 .79479 .45462 .79401 .4536 Metetra
.664 .741 .907 r
.79401 .4536 .79479 .45462 .80076 .45279 .79999 .45177 Metetra
.664 .741 .907 r
.79999 .45177 .80076 .45279 .80674 .45096 .80597 .44994 Metetra
.664 .741 .907 r
.80597 .44994 .80674 .45096 .81273 .44913 .81197 .44811 Metetra
.664 .741 .907 r
.81197 .44811 .81273 .44913 .81874 .4473 .81798 .44627 Metetra
.664 .741 .907 r
.81798 .44627 .81874 .4473 .82476 .44546 .824 .44443 Metetra
.664 .741 .907 r
.824 .44443 .82476 .44546 .83079 .44361 .83003 .44258 Metetra
.664 .741 .907 r
.83003 .44258 .83079 .44361 .83683 .44177 .83608 .44074 Metetra
.664 .741 .907 r
.83608 .44074 .83683 .44177 .84289 .43992 .84214 .43888 Metetra
.664 .741 .907 r
.84214 .43888 .84289 .43992 .84896 .43806 .84821 .43703 Metetra
.664 .741 .907 r
.84821 .43703 .84896 .43806 .85504 .4362 .85429 .43517 Metetra
.664 .741 .907 r
.85429 .43517 .85504 .4362 .86114 .43434 .86039 .4333 Metetra
.664 .741 .907 r
.86039 .4333 .86114 .43434 .86724 .43248 .8665 .43143 Metetra
.664 .741 .907 r
.8665 .43143 .86724 .43248 .87336 .4306 .87262 .42956 Metetra
.664 .741 .907 r
.87262 .42956 .87336 .4306 .8795 .42873 .87876 .42768 Metetra
.664 .741 .907 r
.87876 .42768 .8795 .42873 .88564 .42685 .88491 .4258 Metetra
.664 .741 .907 r
.88491 .4258 .88564 .42685 .8918 .42497 .89107 .42392 Metetra
.664 .741 .907 r
.89107 .42392 .8918 .42497 .89797 .42308 .89725 .42203 Metetra
.664 .741 .907 r
.89725 .42203 .89797 .42308 .90416 .42119 .90343 .42014 Metetra
.664 .741 .907 r
.90343 .42014 .90416 .42119 .91036 .4193 .90963 .41824 Metetra
.664 .741 .907 r
.90963 .41824 .91036 .4193 .91657 .4174 .91585 .41634 Metetra
.664 .741 .907 r
.91585 .41634 .91657 .4174 .92279 .4155 .92208 .41444 Metetra
.664 .741 .907 r
.92208 .41444 .92279 .4155 .92903 .41359 .92832 .41253 Metetra
.664 .741 .907 r
.92832 .41253 .92903 .41359 .93528 .41169 .93457 .41062 Metetra
.664 .741 .907 r
.93457 .41062 .93528 .41169 .94154 .40977 .94084 .4087 Metetra
.664 .741 .907 r
.94084 .4087 .94154 .40977 .94782 .40785 .94712 .40678 Metetra
.664 .741 .907 r
.94712 .40678 .94782 .40785 .95411 .40593 .95341 .40486 Metetra
.664 .741 .907 r
.38299 .57812 .38393 .579 .38908 .57743 .38814 .57655 Metetra
.664 .741 .907 r
.38814 .57655 .38908 .57743 .39425 .57585 .39331 .57496 Metetra
.664 .741 .907 r
.39331 .57496 .39425 .57585 .39942 .57426 .39848 .57338 Metetra
.664 .741 .907 r
.39848 .57338 .39942 .57426 .4046 .57268 .40367 .57179 Metetra
.664 .741 .907 r
.40367 .57179 .4046 .57268 .40979 .57109 .40886 .57021 Metetra
.664 .741 .907 r
.40886 .57021 .40979 .57109 .415 .5695 .41407 .56861 Metetra
.664 .741 .907 r
.41407 .56861 .415 .5695 .42021 .56791 .41928 .56702 Metetra
.664 .741 .907 r
.41928 .56702 .42021 .56791 .42543 .56631 .42451 .56542 Metetra
.664 .741 .907 r
.42451 .56542 .42543 .56631 .43066 .56471 .42974 .56382 Metetra
.664 .741 .907 r
.42974 .56382 .43066 .56471 .43591 .56311 .43498 .56221 Metetra
.664 .741 .907 r
.43498 .56221 .43591 .56311 .44116 .5615 .44024 .5606 Metetra
.664 .741 .907 r
.44024 .5606 .44116 .5615 .44642 .55989 .44551 .55899 Metetra
.664 .741 .907 r
.44551 .55899 .44642 .55989 .4517 .55828 .45078 .55738 Metetra
.664 .741 .907 r
.45078 .55738 .4517 .55828 .45698 .55666 .45607 .55576 Metetra
.947 .679 .497 r
.45607 .55576 .45698 .55666 .45828 .77055 .45731 .76971 Metetra
.944 .693 .526 r
.45731 .76971 .45828 .77055 .46758 .55342 .46667 .55252 Metetra
.664 .741 .907 r
.46667 .55252 .46758 .55342 .47289 .5518 .47199 .55089 Metetra
.664 .741 .907 r
.47199 .55089 .47289 .5518 .47822 .55017 .47731 .54926 Metetra
.664 .741 .907 r
.47731 .54926 .47822 .55017 .48356 .54854 .48265 .54762 Metetra
.664 .741 .907 r
.48265 .54762 .48356 .54854 .4889 .5469 .488 .54599 Metetra
.664 .741 .907 r
.488 .54599 .4889 .5469 .49426 .54526 .49336 .54435 Metetra
.664 .741 .907 r
.49336 .54435 .49426 .54526 .49963 .54362 .49873 .54271 Metetra
.664 .741 .907 r
.49873 .54271 .49963 .54362 .505 .54198 .50411 .54106 Metetra
.664 .741 .907 r
.50411 .54106 .505 .54198 .51039 .54033 .5095 .53941 Metetra
.664 .741 .907 r
.5095 .53941 .51039 .54033 .51579 .53868 .5149 .53776 Metetra
.664 .741 .907 r
.5149 .53776 .51579 .53868 .5212 .53702 .52031 .5361 Metetra
.664 .741 .907 r
.52031 .5361 .5212 .53702 .52662 .53537 .52573 .53444 Metetra
.664 .741 .907 r
.52573 .53444 .52662 .53537 .53205 .53371 .53117 .53278 Metetra
.664 .741 .907 r
.53117 .53278 .53205 .53371 .53749 .53204 .53661 .53111 Metetra
.664 .741 .907 r
.53661 .53111 .53749 .53204 .54294 .53037 .54206 .52944 Metetra
.664 .741 .907 r
.54206 .52944 .54294 .53037 .54841 .5287 .54753 .52777 Metetra
.664 .741 .907 r
.54753 .52777 .54841 .5287 .55388 .52703 .55301 .5261 Metetra
.664 .741 .907 r
.55301 .5261 .55388 .52703 .55937 .52535 .55849 .52442 Metetra
.664 .741 .907 r
.55849 .52442 .55937 .52535 .56486 .52367 .56399 .52273 Metetra
.664 .741 .907 r
.56399 .52273 .56486 .52367 .57037 .52199 .5695 .52105 Metetra
.664 .741 .907 r
.5695 .52105 .57037 .52199 .57589 .5203 .57502 .51936 Metetra
.664 .741 .907 r
.57502 .51936 .57589 .5203 .58142 .51861 .58055 .51767 Metetra
.664 .741 .907 r
.58055 .51767 .58142 .51861 .58696 .51692 .58609 .51597 Metetra
.664 .741 .907 r
.58609 .51597 .58696 .51692 .59251 .51522 .59164 .51427 Metetra
.962 .664 .421 r
.59164 .51427 .59251 .51522 .59959 .58309 .59905 .59758 Metetra
0 0 .038 r
.59905 .59758 .59959 .58309 .60364 .51181 .60278 .51086 Metetra
.664 .741 .907 r
.60278 .51086 .60364 .51181 .60922 .51011 .60837 .50915 Metetra
.664 .741 .907 r
.60837 .50915 .60922 .51011 .61482 .5084 .61397 .50744 Metetra
.664 .741 .907 r
.61397 .50744 .61482 .5084 .62043 .50668 .61958 .50572 Metetra
.664 .741 .907 r
.61958 .50572 .62043 .50668 .62604 .50496 .6252 .504 Metetra
.664 .741 .907 r
.6252 .504 .62604 .50496 .63167 .50324 .63083 .50228 Metetra
.664 .741 .907 r
.63083 .50228 .63167 .50324 .63731 .50152 .63647 .50055 Metetra
.664 .741 .907 r
.63647 .50055 .63731 .50152 .64297 .49979 .64212 .49882 Metetra
.664 .741 .907 r
.64212 .49882 .64297 .49979 .64863 .49806 .64779 .49709 Metetra
.664 .741 .907 r
.64779 .49709 .64863 .49806 .6543 .49632 .65347 .49535 Metetra
.664 .741 .907 r
.65347 .49535 .6543 .49632 .65999 .49458 .65916 .49361 Metetra
.664 .741 .907 r
.65916 .49361 .65999 .49458 .66569 .49284 .66486 .49187 Metetra
.664 .741 .907 r
.66486 .49187 .66569 .49284 .6714 .4911 .67057 .49012 Metetra
.664 .741 .907 r
.67057 .49012 .6714 .4911 .67712 .48935 .67629 .48837 Metetra
.664 .741 .907 r
.67629 .48837 .67712 .48935 .68285 .48759 .68202 .48661 Metetra
.664 .741 .907 r
.68202 .48661 .68285 .48759 .68859 .48584 .68777 .48486 Metetra
.664 .741 .907 r
.68777 .48486 .68859 .48584 .69435 .48408 .69353 .48309 Metetra
.664 .741 .907 r
.69353 .48309 .69435 .48408 .70012 .48231 .6993 .48133 Metetra
.664 .741 .907 r
.6993 .48133 .70012 .48231 .70589 .48055 .70508 .47956 Metetra
.664 .741 .907 r
.70508 .47956 .70589 .48055 .71169 .47877 .71087 .47779 Metetra
.664 .741 .907 r
.71087 .47779 .71169 .47877 .71749 .477 .71668 .47601 Metetra
.664 .741 .907 r
.71668 .47601 .71749 .477 .7233 .47522 .7225 .47423 Metetra
.664 .741 .907 r
.7225 .47423 .7233 .47522 .72913 .47344 .72832 .47245 Metetra
.664 .741 .907 r
.72832 .47245 .72913 .47344 .73497 .47166 .73416 .47066 Metetra
.298 .562 .929 r
.73416 .47066 .73497 .47166 .74082 .46987 .74026 .47252 Metetra
.3 .005 .285 r
.74026 .47252 .74082 .46987 .74668 .46807 .74588 .46707 Metetra
.664 .741 .907 r
.74588 .46707 .74668 .46807 .75255 .46628 .75176 .46527 Metetra
.664 .741 .907 r
.75176 .46527 .75255 .46628 .75844 .46448 .75765 .46347 Metetra
.664 .741 .907 r
.75765 .46347 .75844 .46448 .76434 .46267 .76355 .46167 Metetra
.664 .741 .907 r
.76355 .46167 .76434 .46267 .77025 .46087 .76946 .45986 Metetra
.664 .741 .907 r
.76946 .45986 .77025 .46087 .77617 .45906 .77539 .45804 Metetra
.664 .741 .907 r
.77539 .45804 .77617 .45906 .78211 .45724 .78133 .45623 Metetra
.664 .741 .907 r
.78133 .45623 .78211 .45724 .78805 .45542 .78728 .45441 Metetra
.664 .741 .907 r
.78728 .45441 .78805 .45542 .79401 .4536 .79324 .45258 Metetra
.664 .741 .907 r
.79324 .45258 .79401 .4536 .79999 .45177 .79921 .45075 Metetra
.664 .741 .907 r
.79921 .45075 .79999 .45177 .80597 .44994 .8052 .44892 Metetra
.664 .741 .907 r
.8052 .44892 .80597 .44994 .81197 .44811 .8112 .44708 Metetra
.664 .741 .907 r
.8112 .44708 .81197 .44811 .81798 .44627 .81721 .44525 Metetra
.664 .741 .907 r
.81721 .44525 .81798 .44627 .824 .44443 .82323 .4434 Metetra
.664 .741 .907 r
.82323 .4434 .824 .44443 .83003 .44258 .82927 .44155 Metetra
.664 .741 .907 r
.82927 .44155 .83003 .44258 .83608 .44074 .83532 .4397 Metetra
.664 .741 .907 r
.83532 .4397 .83608 .44074 .84214 .43888 .84138 .43785 Metetra
.664 .741 .907 r
.84138 .43785 .84214 .43888 .84821 .43703 .84746 .43599 Metetra
.664 .741 .907 r
.84746 .43599 .84821 .43703 .85429 .43517 .85355 .43413 Metetra
.664 .741 .907 r
.85355 .43413 .85429 .43517 .86039 .4333 .85965 .43226 Metetra
.664 .741 .907 r
.85965 .43226 .86039 .4333 .8665 .43143 .86576 .43039 Metetra
.664 .741 .907 r
.86576 .43039 .8665 .43143 .87262 .42956 .87188 .42851 Metetra
.664 .741 .907 r
.87188 .42851 .87262 .42956 .87876 .42768 .87802 .42664 Metetra
.664 .741 .907 r
.87802 .42664 .87876 .42768 .88491 .4258 .88417 .42475 Metetra
.664 .741 .907 r
.88417 .42475 .88491 .4258 .89107 .42392 .89034 .42287 Metetra
.935 .576 .166 r
.89034 .42287 .89107 .42392 .89725 .42203 .90181 .46713 Metetra
.468 .281 .543 r
.90181 .46713 .89725 .42203 .90343 .42014 .90271 .41908 Metetra
.664 .741 .907 r
.90271 .41908 .90343 .42014 .90963 .41824 .90891 .41718 Metetra
.664 .741 .907 r
.90891 .41718 .90963 .41824 .91585 .41634 .91513 .41528 Metetra
.664 .741 .907 r
.91513 .41528 .91585 .41634 .92208 .41444 .92136 .41337 Metetra
.664 .741 .907 r
.92136 .41337 .92208 .41444 .92832 .41253 .9276 .41146 Metetra
.664 .741 .907 r
.9276 .41146 .92832 .41253 .93457 .41062 .93386 .40955 Metetra
.664 .741 .907 r
.93386 .40955 .93457 .41062 .94084 .4087 .94013 .40763 Metetra
.664 .741 .907 r
.94013 .40763 .94084 .4087 .94712 .40678 .94641 .40571 Metetra
.664 .741 .907 r
.94641 .40571 .94712 .40678 .95341 .40486 .95271 .40378 Metetra
.664 .741 .907 r
.38205 .57724 .38299 .57812 .38814 .57655 .3872 .57566 Metetra
.664 .741 .907 r
.3872 .57566 .38814 .57655 .39331 .57496 .39237 .57408 Metetra
.664 .741 .907 r
.39237 .57408 .39331 .57496 .39848 .57338 .39755 .5725 Metetra
.664 .741 .907 r
.39755 .5725 .39848 .57338 .40367 .57179 .40273 .57091 Metetra
.664 .741 .907 r
.40273 .57091 .40367 .57179 .40886 .57021 .40793 .56932 Metetra
.664 .741 .907 r
.40793 .56932 .40886 .57021 .41407 .56861 .41314 .56772 Metetra
.664 .741 .907 r
.41314 .56772 .41407 .56861 .41928 .56702 .41835 .56613 Metetra
.664 .741 .907 r
.41835 .56613 .41928 .56702 .42451 .56542 .42358 .56453 Metetra
.664 .741 .907 r
.42358 .56453 .42451 .56542 .42974 .56382 .42882 .56292 Metetra
.664 .741 .907 r
.42882 .56292 .42974 .56382 .43498 .56221 .43406 .56131 Metetra
.664 .741 .907 r
.43406 .56131 .43498 .56221 .44024 .5606 .43932 .5597 Metetra
.664 .741 .907 r
.43932 .5597 .44024 .5606 .44551 .55899 .44459 .55809 Metetra
.664 .741 .907 r
.44459 .55809 .44551 .55899 .45078 .55738 .44986 .55648 Metetra
.664 .741 .907 r
.44986 .55648 .45078 .55738 .45607 .55576 .45515 .55486 Metetra
.947 .679 .497 r
.45515 .55486 .45607 .55576 .45731 .76971 .45633 .76888 Metetra
.944 .693 .526 r
.45633 .76888 .45731 .76971 .46667 .55252 .46576 .55161 Metetra
.664 .741 .907 r
.46576 .55161 .46667 .55252 .47199 .55089 .47108 .54998 Metetra
.664 .741 .907 r
.47108 .54998 .47199 .55089 .47731 .54926 .47641 .54835 Metetra
.664 .741 .907 r
.47641 .54835 .47731 .54926 .48265 .54762 .48175 .54671 Metetra
.664 .741 .907 r
.48175 .54671 .48265 .54762 .488 .54599 .4871 .54507 Metetra
.664 .741 .907 r
.4871 .54507 .488 .54599 .49336 .54435 .49246 .54343 Metetra
.664 .741 .907 r
.49246 .54343 .49336 .54435 .49873 .54271 .49783 .54179 Metetra
.664 .741 .907 r
.49783 .54179 .49873 .54271 .50411 .54106 .50321 .54014 Metetra
.664 .741 .907 r
.50321 .54014 .50411 .54106 .5095 .53941 .5086 .53849 Metetra
.664 .741 .907 r
.5086 .53849 .5095 .53941 .5149 .53776 .51401 .53683 Metetra
.664 .741 .907 r
.51401 .53683 .5149 .53776 .52031 .5361 .51942 .53518 Metetra
.664 .741 .907 r
.51942 .53518 .52031 .5361 .52573 .53444 .52484 .53351 Metetra
.664 .741 .907 r
.52484 .53351 .52573 .53444 .53117 .53278 .53028 .53185 Metetra
.664 .741 .907 r
.53028 .53185 .53117 .53278 .53661 .53111 .53573 .53018 Metetra
.664 .741 .907 r
.53573 .53018 .53661 .53111 .54206 .52944 .54118 .52851 Metetra
.664 .741 .907 r
.54118 .52851 .54206 .52944 .54753 .52777 .54665 .52684 Metetra
.664 .741 .907 r
.54665 .52684 .54753 .52777 .55301 .5261 .55213 .52516 Metetra
.664 .741 .907 r
.55213 .52516 .55301 .5261 .55849 .52442 .55762 .52348 Metetra
.664 .741 .907 r
.55762 .52348 .55849 .52442 .56399 .52273 .56312 .52179 Metetra
.664 .741 .907 r
.56312 .52179 .56399 .52273 .5695 .52105 .56863 .52011 Metetra
.664 .741 .907 r
.56863 .52011 .5695 .52105 .57502 .51936 .57415 .51842 Metetra
.664 .741 .907 r
.57415 .51842 .57502 .51936 .58055 .51767 .57968 .51672 Metetra
.664 .741 .907 r
.57968 .51672 .58055 .51767 .58609 .51597 .58523 .51502 Metetra
.952 .605 .304 r
.58523 .51502 .58609 .51597 .59164 .51427 .59137 .54286 Metetra
.604 .377 .545 r
.59137 .54286 .59164 .51427 .59905 .59758 .59728 .55495 Metetra
.656 .437 .576 r
.59728 .55495 .59905 .59758 .60278 .51086 .60193 .50991 Metetra
.664 .741 .907 r
.60193 .50991 .60278 .51086 .60837 .50915 .60752 .5082 Metetra
.664 .741 .907 r
.60752 .5082 .60837 .50915 .61397 .50744 .61311 .50648 Metetra
.664 .741 .907 r
.61311 .50648 .61397 .50744 .61958 .50572 .61873 .50476 Metetra
.664 .741 .907 r
.61873 .50476 .61958 .50572 .6252 .504 .62435 .50304 Metetra
.664 .741 .907 r
.62435 .50304 .6252 .504 .63083 .50228 .62998 .50132 Metetra
.664 .741 .907 r
.62998 .50132 .63083 .50228 .63647 .50055 .63563 .49959 Metetra
.664 .741 .907 r
.63563 .49959 .63647 .50055 .64212 .49882 .64128 .49786 Metetra
.664 .741 .907 r
.64128 .49786 .64212 .49882 .64779 .49709 .64695 .49612 Metetra
.664 .741 .907 r
.64695 .49612 .64779 .49709 .65347 .49535 .65263 .49438 Metetra
.664 .741 .907 r
.65263 .49438 .65347 .49535 .65916 .49361 .65832 .49264 Metetra
.664 .741 .907 r
.65832 .49264 .65916 .49361 .66486 .49187 .66402 .49089 Metetra
.664 .741 .907 r
.66402 .49089 .66486 .49187 .67057 .49012 .66974 .48914 Metetra
.664 .741 .907 r
.66974 .48914 .67057 .49012 .67629 .48837 .67546 .48739 Metetra
.664 .741 .907 r
.67546 .48739 .67629 .48837 .68202 .48661 .6812 .48563 Metetra
.664 .741 .907 r
.6812 .48563 .68202 .48661 .68777 .48486 .68695 .48387 Metetra
.664 .741 .907 r
.68695 .48387 .68777 .48486 .69353 .48309 .69271 .48211 Metetra
.664 .741 .907 r
.69271 .48211 .69353 .48309 .6993 .48133 .69848 .48034 Metetra
.664 .741 .907 r
.69848 .48034 .6993 .48133 .70508 .47956 .70426 .47857 Metetra
.664 .741 .907 r
.70426 .47857 .70508 .47956 .71087 .47779 .71006 .4768 Metetra
.664 .741 .907 r
.71006 .4768 .71087 .47779 .71668 .47601 .71587 .47502 Metetra
.664 .741 .907 r
.71587 .47502 .71668 .47601 .7225 .47423 .72169 .47323 Metetra
.664 .741 .907 r
.72169 .47323 .7225 .47423 .72832 .47245 .72752 .47145 Metetra
.664 .741 .907 r
.72752 .47145 .72832 .47245 .73416 .47066 .73336 .46966 Metetra
.664 .741 .907 r
.73336 .46966 .73416 .47066 .74026 .47252 .73922 .46787 Metetra
.612 .474 .669 r
.73922 .46787 .74026 .47252 .74588 .46707 .74508 .46607 Metetra
.664 .741 .907 r
.74508 .46607 .74588 .46707 .75176 .46527 .75096 .46427 Metetra
.664 .741 .907 r
.75096 .46427 .75176 .46527 .75765 .46347 .75686 .46247 Metetra
.664 .741 .907 r
.75686 .46247 .75765 .46347 .76355 .46167 .76276 .46066 Metetra
.664 .741 .907 r
.76276 .46066 .76355 .46167 .76946 .45986 .76868 .45885 Metetra
.664 .741 .907 r
.76868 .45885 .76946 .45986 .77539 .45804 .7746 .45703 Metetra
.664 .741 .907 r
.7746 .45703 .77539 .45804 .78133 .45623 .78054 .45521 Metetra
.664 .741 .907 r
.78054 .45521 .78133 .45623 .78728 .45441 .7865 .45339 Metetra
.664 .741 .907 r
.7865 .45339 .78728 .45441 .79324 .45258 .79246 .45156 Metetra
.664 .741 .907 r
.79246 .45156 .79324 .45258 .79921 .45075 .79844 .44973 Metetra
.664 .741 .907 r
.79844 .44973 .79921 .45075 .8052 .44892 .80443 .4479 Metetra
.664 .741 .907 r
.80443 .4479 .8052 .44892 .8112 .44708 .81043 .44606 Metetra
.664 .741 .907 r
.81043 .44606 .8112 .44708 .81721 .44525 .81644 .44422 Metetra
.664 .741 .907 r
.81644 .44422 .81721 .44525 .82323 .4434 .82247 .44237 Metetra
.664 .741 .907 r
.82247 .44237 .82323 .4434 .82927 .44155 .82851 .44052 Metetra
.664 .741 .907 r
.82851 .44052 .82927 .44155 .83532 .4397 .83456 .43867 Metetra
.664 .741 .907 r
.83456 .43867 .83532 .4397 .84138 .43785 .84063 .43681 Metetra
.664 .741 .907 r
.84063 .43681 .84138 .43785 .84746 .43599 .84671 .43495 Metetra
.664 .741 .907 r
.84671 .43495 .84746 .43599 .85355 .43413 .8528 .43309 Metetra
.664 .741 .907 r
.8528 .43309 .85355 .43413 .85965 .43226 .8589 .43122 Metetra
.664 .741 .907 r
.8589 .43122 .85965 .43226 .86576 .43039 .86501 .42934 Metetra
.664 .741 .907 r
.86501 .42934 .86576 .43039 .87188 .42851 .87114 .42747 Metetra
.664 .741 .907 r
.87114 .42747 .87188 .42851 .87802 .42664 .87728 .42559 Metetra
.664 .741 .907 r
.87728 .42559 .87802 .42664 .88417 .42475 .88344 .4237 Metetra
.664 .741 .907 r
.88344 .4237 .88417 .42475 .89034 .42287 .88961 .42181 Metetra
.664 .741 .907 r
.88961 .42181 .89034 .42287 .90181 .46713 .89579 .41992 Metetra
.575 .374 .572 r
.89579 .41992 .90181 .46713 .90271 .41908 .90198 .41802 Metetra
.664 .741 .907 r
.90198 .41802 .90271 .41908 .90891 .41718 .90819 .41612 Metetra
.664 .741 .907 r
.90819 .41612 .90891 .41718 .91513 .41528 .91441 .41422 Metetra
.664 .741 .907 r
.91441 .41422 .91513 .41528 .92136 .41337 .92064 .41231 Metetra
.664 .741 .907 r
.92064 .41231 .92136 .41337 .9276 .41146 .92689 .4104 Metetra
.664 .741 .907 r
.92689 .4104 .9276 .41146 .93386 .40955 .93314 .40848 Metetra
.664 .741 .907 r
.93314 .40848 .93386 .40955 .94013 .40763 .93942 .40656 Metetra
.664 .741 .907 r
.93942 .40656 .94013 .40763 .94641 .40571 .9457 .40463 Metetra
.664 .741 .907 r
.9457 .40463 .94641 .40571 .95271 .40378 .952 .40271 Metetra
.664 .741 .907 r
.3811 .57636 .38205 .57724 .3872 .57566 .38626 .57478 Metetra
.939 .588 .328 r
.38626 .57478 .3872 .57566 .39237 .57408 .39066 .59287 Metetra
.423 .22 .498 r
.39066 .59287 .39237 .57408 .39755 .5725 .39661 .57161 Metetra
.664 .741 .907 r
.39661 .57161 .39755 .5725 .40273 .57091 .4018 .57002 Metetra
.664 .741 .907 r
.4018 .57002 .40273 .57091 .40793 .56932 .407 .56843 Metetra
.664 .741 .907 r
.407 .56843 .40793 .56932 .41314 .56772 .4122 .56683 Metetra
.664 .741 .907 r
.4122 .56683 .41314 .56772 .41835 .56613 .41742 .56523 Metetra
.664 .741 .907 r
.41742 .56523 .41835 .56613 .42358 .56453 .42265 .56363 Metetra
.664 .741 .907 r
.42265 .56363 .42358 .56453 .42882 .56292 .42789 .56203 Metetra
.664 .741 .907 r
.42789 .56203 .42882 .56292 .43406 .56131 .43314 .56042 Metetra
.664 .741 .907 r
.43314 .56042 .43406 .56131 .43932 .5597 .4384 .55881 Metetra
.664 .741 .907 r
.4384 .55881 .43932 .5597 .44459 .55809 .44367 .55719 Metetra
.664 .741 .907 r
.44367 .55719 .44459 .55809 .44986 .55648 .44895 .55557 Metetra
.664 .741 .907 r
.44895 .55557 .44986 .55648 .45515 .55486 .45424 .55395 Metetra
.947 .678 .494 r
.45424 .55395 .45515 .55486 .45633 .76888 .45597 .73627 Metetra
.818 .574 .571 r
.45597 .73627 .45633 .76888 .46576 .55161 .46485 .5507 Metetra
.664 .741 .907 r
.46485 .5507 .46576 .55161 .47108 .54998 .47017 .54907 Metetra
.664 .741 .907 r
.47017 .54907 .47108 .54998 .47641 .54835 .4755 .54744 Metetra
.664 .741 .907 r
.4755 .54744 .47641 .54835 .48175 .54671 .48084 .5458 Metetra
.664 .741 .907 r
.48084 .5458 .48175 .54671 .4871 .54507 .48619 .54416 Metetra
.664 .741 .907 r
.48619 .54416 .4871 .54507 .49246 .54343 .49156 .54252 Metetra
.664 .741 .907 r
.49156 .54252 .49246 .54343 .49783 .54179 .49693 .54087 Metetra
.664 .741 .907 r
.49693 .54087 .49783 .54179 .50321 .54014 .50231 .53922 Metetra
.664 .741 .907 r
.50231 .53922 .50321 .54014 .5086 .53849 .50771 .53757 Metetra
.664 .741 .907 r
.50771 .53757 .5086 .53849 .51401 .53683 .51311 .53591 Metetra
.664 .741 .907 r
.51311 .53591 .51401 .53683 .51942 .53518 .51853 .53425 Metetra
.664 .741 .907 r
.51853 .53425 .51942 .53518 .52484 .53351 .52396 .53259 Metetra
.664 .741 .907 r
.52396 .53259 .52484 .53351 .53028 .53185 .52939 .53092 Metetra
.664 .741 .907 r
.52939 .53092 .53028 .53185 .53573 .53018 .53484 .52925 Metetra
.664 .741 .907 r
.53484 .52925 .53573 .53018 .54118 .52851 .5403 .52758 Metetra
.664 .741 .907 r
.5403 .52758 .54118 .52851 .54665 .52684 .54577 .5259 Metetra
.664 .741 .907 r
.54577 .5259 .54665 .52684 .55213 .52516 .55125 .52422 Metetra
.664 .741 .907 r
.55125 .52422 .55213 .52516 .55762 .52348 .55674 .52254 Metetra
.664 .741 .907 r
.55674 .52254 .55762 .52348 .56312 .52179 .56224 .52085 Metetra
.664 .741 .907 r
.56224 .52085 .56312 .52179 .56863 .52011 .56776 .51916 Metetra
.664 .741 .907 r
.56776 .51916 .56863 .52011 .57415 .51842 .57328 .51747 Metetra
.664 .741 .907 r
.57328 .51747 .57415 .51842 .57968 .51672 .57882 .51577 Metetra
.664 .741 .907 r
.57882 .51577 .57968 .51672 .58523 .51502 .58436 .51407 Metetra
.96 .643 .378 r
.58436 .51407 .58523 .51502 .59137 .54286 .59085 .56011 Metetra
.625 .386 .536 r
.59085 .56011 .59137 .54286 .59728 .55495 .5968 .57257 Metetra
0 0 .347 r
.5968 .57257 .59728 .55495 .60193 .50991 .60107 .50896 Metetra
.664 .741 .907 r
.60107 .50896 .60193 .50991 .60752 .5082 .60666 .50724 Metetra
.664 .741 .907 r
.60666 .50724 .60752 .5082 .61311 .50648 .61226 .50553 Metetra
.664 .741 .907 r
.61226 .50553 .61311 .50648 .61873 .50476 .61787 .5038 Metetra
.664 .741 .907 r
.61787 .5038 .61873 .50476 .62435 .50304 .6235 .50208 Metetra
.664 .741 .907 r
.6235 .50208 .62435 .50304 .62998 .50132 .62913 .50035 Metetra
.664 .741 .907 r
.62913 .50035 .62998 .50132 .63563 .49959 .63478 .49862 Metetra
.664 .741 .907 r
.63478 .49862 .63563 .49959 .64128 .49786 .64044 .49689 Metetra
.664 .741 .907 r
.64044 .49689 .64128 .49786 .64695 .49612 .64611 .49515 Metetra
.664 .741 .907 r
.64611 .49515 .64695 .49612 .65263 .49438 .65179 .49341 Metetra
.664 .741 .907 r
.65179 .49341 .65263 .49438 .65832 .49264 .65749 .49167 Metetra
.664 .741 .907 r
.65749 .49167 .65832 .49264 .66402 .49089 .66319 .48992 Metetra
.664 .741 .907 r
.66319 .48992 .66402 .49089 .66974 .48914 .66891 .48817 Metetra
.664 .741 .907 r
.66891 .48817 .66974 .48914 .67546 .48739 .67463 .48641 Metetra
.664 .741 .907 r
.67463 .48641 .67546 .48739 .6812 .48563 .68037 .48465 Metetra
.664 .741 .907 r
.68037 .48465 .6812 .48563 .68695 .48387 .68613 .48289 Metetra
.664 .741 .907 r
.68613 .48289 .68695 .48387 .69271 .48211 .69189 .48112 Metetra
.664 .741 .907 r
.69189 .48112 .69271 .48211 .69848 .48034 .69766 .47935 Metetra
.664 .741 .907 r
.69766 .47935 .69848 .48034 .70426 .47857 .70345 .47758 Metetra
.664 .741 .907 r
.70345 .47758 .70426 .47857 .71006 .4768 .70925 .4758 Metetra
.664 .741 .907 r
.70925 .4758 .71006 .4768 .71587 .47502 .71506 .47402 Metetra
.664 .741 .907 r
.71506 .47402 .71587 .47502 .72169 .47323 .72088 .47224 Metetra
.664 .741 .907 r
.72088 .47224 .72169 .47323 .72752 .47145 .72671 .47045 Metetra
.963 .632 .313 r
.72671 .47045 .72752 .47145 .73336 .46966 .73598 .52286 Metetra
.46 .272 .538 r
.73598 .52286 .73336 .46966 .73922 .46787 .73842 .46686 Metetra
.664 .741 .907 r
.73842 .46686 .73922 .46787 .74508 .46607 .74429 .46507 Metetra
.664 .741 .907 r
.74429 .46507 .74508 .46607 .75096 .46427 .75017 .46326 Metetra
.664 .741 .907 r
.75017 .46326 .75096 .46427 .75686 .46247 .75606 .46146 Metetra
.664 .741 .907 r
.75606 .46146 .75686 .46247 .76276 .46066 .76197 .45965 Metetra
.664 .741 .907 r
.76197 .45965 .76276 .46066 .76868 .45885 .76789 .45783 Metetra
.664 .741 .907 r
.76789 .45783 .76868 .45885 .7746 .45703 .77382 .45602 Metetra
.664 .741 .907 r
.77382 .45602 .7746 .45703 .78054 .45521 .77976 .4542 Metetra
.664 .741 .907 r
.77976 .4542 .78054 .45521 .7865 .45339 .78572 .45237 Metetra
.664 .741 .907 r
.78572 .45237 .7865 .45339 .79246 .45156 .79168 .45054 Metetra
.664 .741 .907 r
.79168 .45054 .79246 .45156 .79844 .44973 .79766 .44871 Metetra
.664 .741 .907 r
.79766 .44871 .79844 .44973 .80443 .4479 .80366 .44687 Metetra
.664 .741 .907 r
.80366 .44687 .80443 .4479 .81043 .44606 .80966 .44503 Metetra
.664 .741 .907 r
.80966 .44503 .81043 .44606 .81644 .44422 .81568 .44319 Metetra
.664 .741 .907 r
.81568 .44319 .81644 .44422 .82247 .44237 .82171 .44134 Metetra
.664 .741 .907 r
.82171 .44134 .82247 .44237 .82851 .44052 .82775 .43949 Metetra
.664 .741 .907 r
.82775 .43949 .82851 .44052 .83456 .43867 .8338 .43763 Metetra
.664 .741 .907 r
.8338 .43763 .83456 .43867 .84063 .43681 .83987 .43577 Metetra
.664 .741 .907 r
.83987 .43577 .84063 .43681 .84671 .43495 .84595 .43391 Metetra
.664 .741 .907 r
.84595 .43391 .84671 .43495 .8528 .43309 .85204 .43204 Metetra
.664 .741 .907 r
.85204 .43204 .8528 .43309 .8589 .43122 .85815 .43017 Metetra
.664 .741 .907 r
.85815 .43017 .8589 .43122 .86501 .42934 .86427 .4283 Metetra
.664 .741 .907 r
.86427 .4283 .86501 .42934 .87114 .42747 .8704 .42642 Metetra
.664 .741 .907 r
.8704 .42642 .87114 .42747 .87728 .42559 .87655 .42454 Metetra
.664 .741 .907 r
.87655 .42454 .87728 .42559 .88344 .4237 .8827 .42265 Metetra
.414 .617 .935 r
.8827 .42265 .88344 .4237 .88961 .42181 .88921 .42378 Metetra
.257 0 .211 r
.88921 .42378 .88961 .42181 .89579 .41992 .89506 .41886 Metetra
.664 .741 .907 r
.89506 .41886 .89579 .41992 .90198 .41802 .90125 .41696 Metetra
.664 .741 .907 r
.90125 .41696 .90198 .41802 .90819 .41612 .90746 .41506 Metetra
.664 .741 .907 r
.90746 .41506 .90819 .41612 .91441 .41422 .91368 .41315 Metetra
.664 .741 .907 r
.91368 .41315 .91441 .41422 .92064 .41231 .91992 .41124 Metetra
.664 .741 .907 r
.91992 .41124 .92064 .41231 .92689 .4104 .92617 .40933 Metetra
.664 .741 .907 r
.92617 .40933 .92689 .4104 .93314 .40848 .93243 .40741 Metetra
.664 .741 .907 r
.93243 .40741 .93314 .40848 .93942 .40656 .93871 .40549 Metetra
.664 .741 .907 r
.93871 .40549 .93942 .40656 .9457 .40463 .945 .40356 Metetra
.664 .741 .907 r
.945 .40356 .9457 .40463 .952 .40271 .9513 .40163 Metetra
.664 .741 .907 r
.38016 .57548 .3811 .57636 .38626 .57478 .38532 .5739 Metetra
.763 .273 0 r
.38532 .5739 .38626 .57478 .39066 .59287 .39016 .58078 Metetra
.644 .449 .605 r
.39016 .58078 .39066 .59287 .39661 .57161 .39567 .57073 Metetra
.664 .741 .907 r
.39567 .57073 .39661 .57161 .4018 .57002 .40086 .56913 Metetra
.664 .741 .907 r
.40086 .56913 .4018 .57002 .407 .56843 .40606 .56754 Metetra
.664 .741 .907 r
.40606 .56754 .407 .56843 .4122 .56683 .41127 .56594 Metetra
.664 .741 .907 r
.41127 .56594 .4122 .56683 .41742 .56523 .41649 .56434 Metetra
.664 .741 .907 r
.41649 .56434 .41742 .56523 .42265 .56363 .42172 .56274 Metetra
.664 .741 .907 r
.42172 .56274 .42265 .56363 .42789 .56203 .42696 .56113 Metetra
.664 .741 .907 r
.42696 .56113 .42789 .56203 .43314 .56042 .43221 .55952 Metetra
.664 .741 .907 r
.43221 .55952 .43314 .56042 .4384 .55881 .43748 .55791 Metetra
.664 .741 .907 r
.43748 .55791 .4384 .55881 .44367 .55719 .44275 .55629 Metetra
.664 .741 .907 r
.44275 .55629 .44367 .55719 .44895 .55557 .44803 .55467 Metetra
.664 .741 .907 r
.44803 .55467 .44895 .55557 .45424 .55395 .45332 .55305 Metetra
.949 .668 .471 r
.45332 .55305 .45424 .55395 .45597 .73627 .45696 .63581 Metetra
.644 .426 .572 r
.45696 .63581 .45597 .73627 .46485 .5507 .46393 .54979 Metetra
.664 .741 .907 r
.46393 .54979 .46485 .5507 .47017 .54907 .46926 .54816 Metetra
.664 .741 .907 r
.46926 .54816 .47017 .54907 .4755 .54744 .47459 .54652 Metetra
.664 .741 .907 r
.47459 .54652 .4755 .54744 .48084 .5458 .47993 .54488 Metetra
.664 .741 .907 r
.47993 .54488 .48084 .5458 .48619 .54416 .48529 .54324 Metetra
.664 .741 .907 r
.48529 .54324 .48619 .54416 .49156 .54252 .49065 .5416 Metetra
.664 .741 .907 r
.49065 .5416 .49156 .54252 .49693 .54087 .49603 .53995 Metetra
.664 .741 .907 r
.49603 .53995 .49693 .54087 .50231 .53922 .50142 .5383 Metetra
.664 .741 .907 r
.50142 .5383 .50231 .53922 .50771 .53757 .50681 .53664 Metetra
.664 .741 .907 r
.50681 .53664 .50771 .53757 .51311 .53591 .51222 .53498 Metetra
.675 .183 0 r
.51222 .53498 .51311 .53591 .51853 .53425 .51762 .54199 Metetra
.397 .171 .45 r
.51762 .54199 .51853 .53425 .52396 .53259 .52307 .53166 Metetra
.664 .741 .907 r
.52307 .53166 .52396 .53259 .52939 .53092 .5285 .52999 Metetra
.664 .741 .907 r
.5285 .52999 .52939 .53092 .53484 .52925 .53395 .52832 Metetra
.664 .741 .907 r
.53395 .52832 .53484 .52925 .5403 .52758 .53942 .52664 Metetra
.664 .741 .907 r
.53942 .52664 .5403 .52758 .54577 .5259 .54489 .52497 Metetra
.664 .741 .907 r
.54489 .52497 .54577 .5259 .55125 .52422 .55037 .52328 Metetra
.664 .741 .907 r
.55037 .52328 .55125 .52422 .55674 .52254 .55586 .5216 Metetra
.664 .741 .907 r
.55586 .5216 .55674 .52254 .56224 .52085 .56137 .51991 Metetra
.664 .741 .907 r
.56137 .51991 .56224 .52085 .56776 .51916 .56688 .51822 Metetra
.664 .741 .907 r
.56688 .51822 .56776 .51916 .57328 .51747 .57241 .51652 Metetra
.664 .741 .907 r
.57241 .51652 .57328 .51747 .57882 .51577 .57795 .51483 Metetra
.664 .741 .907 r
.57795 .51483 .57882 .51577 .58436 .51407 .5835 .51313 Metetra
0 0 .514 r
.5835 .51313 .58436 .51407 .59085 .56011 .5892 .51909 Metetra
.439 .271 .556 r
.5892 .51909 .59085 .56011 .5968 .57257 .59582 .56692 Metetra
.88 .638 .568 r
.59582 .56692 .5968 .57257 .60107 .50896 .60021 .508 Metetra
.664 .741 .907 r
.60021 .508 .60107 .50896 .60666 .50724 .6058 .50628 Metetra
.664 .741 .907 r
.6058 .50628 .60666 .50724 .61226 .50553 .61141 .50457 Metetra
.664 .741 .907 r
.61141 .50457 .61226 .50553 .61787 .5038 .61702 .50284 Metetra
.664 .741 .907 r
.61702 .50284 .61787 .5038 .6235 .50208 .62265 .50112 Metetra
.664 .741 .907 r
.62265 .50112 .6235 .50208 .62913 .50035 .62829 .49939 Metetra
.664 .741 .907 r
.62829 .49939 .62913 .50035 .63478 .49862 .63394 .49766 Metetra
.664 .741 .907 r
.63394 .49766 .63478 .49862 .64044 .49689 .6396 .49592 Metetra
.664 .741 .907 r
.6396 .49592 .64044 .49689 .64611 .49515 .64527 .49418 Metetra
.664 .741 .907 r
.64527 .49418 .64611 .49515 .65179 .49341 .65095 .49244 Metetra
.664 .741 .907 r
.65095 .49244 .65179 .49341 .65749 .49167 .65665 .49069 Metetra
.664 .741 .907 r
.65665 .49069 .65749 .49167 .66319 .48992 .66236 .48894 Metetra
.664 .741 .907 r
.66236 .48894 .66319 .48992 .66891 .48817 .66808 .48719 Metetra
.664 .741 .907 r
.66808 .48719 .66891 .48817 .67463 .48641 .67381 .48543 Metetra
.664 .741 .907 r
.67381 .48543 .67463 .48641 .68037 .48465 .67955 .48367 Metetra
.664 .741 .907 r
.67955 .48367 .68037 .48465 .68613 .48289 .6853 .4819 Metetra
.664 .741 .907 r
.6853 .4819 .68613 .48289 .69189 .48112 .69107 .48014 Metetra
.664 .741 .907 r
.69107 .48014 .69189 .48112 .69766 .47935 .69684 .47837 Metetra
.664 .741 .907 r
.69684 .47837 .69766 .47935 .70345 .47758 .70263 .47659 Metetra
.664 .741 .907 r
.70263 .47659 .70345 .47758 .70925 .4758 .70843 .47481 Metetra
.664 .741 .907 r
.70843 .47481 .70925 .4758 .71506 .47402 .71425 .47303 Metetra
.664 .741 .907 r
.71425 .47303 .71506 .47402 .72088 .47224 .72007 .47124 Metetra
.664 .741 .907 r
.72007 .47124 .72088 .47224 .72671 .47045 .72591 .46945 Metetra
.664 .741 .907 r
.72591 .46945 .72671 .47045 .73598 .52286 .73175 .46766 Metetra
.574 .372 .569 r
.73175 .46766 .73598 .52286 .73842 .46686 .73761 .46586 Metetra
.664 .741 .907 r
.73761 .46586 .73842 .46686 .74429 .46507 .74349 .46406 Metetra
.664 .741 .907 r
.74349 .46406 .74429 .46507 .75017 .46326 .74937 .46226 Metetra
.664 .741 .907 r
.74937 .46226 .75017 .46326 .75606 .46146 .75527 .46045 Metetra
.664 .741 .907 r
.75527 .46045 .75606 .46146 .76197 .45965 .76118 .45864 Metetra
.664 .741 .907 r
.76118 .45864 .76197 .45965 .76789 .45783 .7671 .45682 Metetra
.664 .741 .907 r
.7671 .45682 .76789 .45783 .77382 .45602 .77303 .455 Metetra
.664 .741 .907 r
.77303 .455 .77382 .45602 .77976 .4542 .77898 .45318 Metetra
.664 .741 .907 r
.77898 .45318 .77976 .4542 .78572 .45237 .78493 .45135 Metetra
.664 .741 .907 r
.78493 .45135 .78572 .45237 .79168 .45054 .7909 .44952 Metetra
.664 .741 .907 r
.7909 .44952 .79168 .45054 .79766 .44871 .79689 .44769 Metetra
.664 .741 .907 r
.79689 .44769 .79766 .44871 .80366 .44687 .80288 .44585 Metetra
.664 .741 .907 r
.80288 .44585 .80366 .44687 .80966 .44503 .80889 .444 Metetra
.664 .741 .907 r
.80889 .444 .80966 .44503 .81568 .44319 .81491 .44216 Metetra
.664 .741 .907 r
.81491 .44216 .81568 .44319 .82171 .44134 .82094 .44031 Metetra
.664 .741 .907 r
.82094 .44031 .82171 .44134 .82775 .43949 .82699 .43845 Metetra
.664 .741 .907 r
.82699 .43845 .82775 .43949 .8338 .43763 .83304 .4366 Metetra
.664 .741 .907 r
.83304 .4366 .8338 .43763 .83987 .43577 .83911 .43474 Metetra
.664 .741 .907 r
.83911 .43474 .83987 .43577 .84595 .43391 .8452 .43287 Metetra
.664 .741 .907 r
.8452 .43287 .84595 .43391 .85204 .43204 .85129 .431 Metetra
.664 .741 .907 r
.85129 .431 .85204 .43204 .85815 .43017 .8574 .42913 Metetra
.664 .741 .907 r
.8574 .42913 .85815 .43017 .86427 .4283 .86352 .42725 Metetra
.664 .741 .907 r
.86352 .42725 .86427 .4283 .8704 .42642 .86966 .42537 Metetra
.664 .741 .907 r
.86966 .42537 .8704 .42642 .87655 .42454 .8758 .42348 Metetra
.664 .741 .907 r
.8758 .42348 .87655 .42454 .8827 .42265 .88196 .42159 Metetra
.664 .741 .907 r
.88196 .42159 .8827 .42265 .88921 .42378 .88814 .4197 Metetra
.618 .491 .685 r
.88814 .4197 .88921 .42378 .89506 .41886 .89432 .4178 Metetra
.664 .741 .907 r
.89432 .4178 .89506 .41886 .90125 .41696 .90052 .4159 Metetra
.664 .741 .907 r
.90052 .4159 .90125 .41696 .90746 .41506 .90674 .414 Metetra
.664 .741 .907 r
.90674 .414 .90746 .41506 .91368 .41315 .91296 .41209 Metetra
.664 .741 .907 r
.91296 .41209 .91368 .41315 .91992 .41124 .9192 .41018 Metetra
.664 .741 .907 r
.9192 .41018 .91992 .41124 .92617 .40933 .92545 .40826 Metetra
.664 .741 .907 r
.92545 .40826 .92617 .40933 .93243 .40741 .93172 .40634 Metetra
.664 .741 .907 r
.93172 .40634 .93243 .40741 .93871 .40549 .93799 .40441 Metetra
.664 .741 .907 r
.93799 .40441 .93871 .40549 .945 .40356 .94429 .40248 Metetra
.664 .741 .907 r
.94429 .40248 .945 .40356 .9513 .40163 .95059 .40055 Metetra
.664 .741 .907 r
.37922 .5746 .38016 .57548 .38532 .5739 .38438 .57302 Metetra
.942 .607 .363 r
.38438 .57302 .38532 .5739 .39016 .58078 .38864 .59427 Metetra
.292 .103 .444 r
.38864 .59427 .39016 .58078 .39567 .57073 .39473 .56984 Metetra
.664 .741 .907 r
.39473 .56984 .39567 .57073 .40086 .56913 .39992 .56824 Metetra
.664 .741 .907 r
.39992 .56824 .40086 .56913 .40606 .56754 .40513 .56665 Metetra
.664 .741 .907 r
.40513 .56665 .40606 .56754 .41127 .56594 .41034 .56505 Metetra
.664 .741 .907 r
.41034 .56505 .41127 .56594 .41649 .56434 .41556 .56345 Metetra
.664 .741 .907 r
.41556 .56345 .41649 .56434 .42172 .56274 .42079 .56184 Metetra
.664 .741 .907 r
.42079 .56184 .42172 .56274 .42696 .56113 .42604 .56023 Metetra
.664 .741 .907 r
.42604 .56023 .42696 .56113 .43221 .55952 .43129 .55862 Metetra
.664 .741 .907 r
.43129 .55862 .43221 .55952 .43748 .55791 .43655 .557 Metetra
.664 .741 .907 r
.43655 .557 .43748 .55791 .44275 .55629 .44182 .55539 Metetra
.664 .741 .907 r
.44182 .55539 .44275 .55629 .44803 .55467 .44711 .55376 Metetra
.664 .741 .907 r
.44711 .55376 .44803 .55467 .45332 .55305 .4524 .55214 Metetra
.664 .741 .907 r
.4524 .55214 .45332 .55305 .45696 .63581 .45771 .55051 Metetra
.573 .368 .566 r
.45771 .55051 .45696 .63581 .46393 .54979 .46302 .54888 Metetra
.664 .741 .907 r
.46302 .54888 .46393 .54979 .46926 .54816 .46835 .54725 Metetra
.664 .741 .907 r
.46835 .54725 .46926 .54816 .47459 .54652 .47368 .54561 Metetra
.664 .741 .907 r
.47368 .54561 .47459 .54652 .47993 .54488 .47903 .54397 Metetra
.664 .741 .907 r
.47903 .54397 .47993 .54488 .48529 .54324 .48438 .54233 Metetra
.664 .741 .907 r
.48438 .54233 .48529 .54324 .49065 .5416 .48975 .54068 Metetra
.664 .741 .907 r
.48975 .54068 .49065 .5416 .49603 .53995 .49513 .53903 Metetra
.664 .741 .907 r
.49513 .53903 .49603 .53995 .50142 .5383 .50052 .53737 Metetra
.664 .741 .907 r
.50052 .53737 .50142 .5383 .50681 .53664 .50591 .53572 Metetra
.664 .741 .907 r
.50591 .53572 .50681 .53664 .51222 .53498 .51132 .53406 Metetra
.664 .741 .907 r
.51132 .53406 .51222 .53498 .51762 .54199 .51674 .53239 Metetra
.592 .417 .613 r
.51674 .53239 .51762 .54199 .52307 .53166 .52217 .53073 Metetra
.664 .741 .907 r
.52217 .53073 .52307 .53166 .5285 .52999 .52762 .52906 Metetra
.664 .741 .907 r
.52762 .52906 .5285 .52999 .53395 .52832 .53307 .52738 Metetra
.664 .741 .907 r
.53307 .52738 .53395 .52832 .53942 .52664 .53853 .52571 Metetra
.664 .741 .907 r
.53853 .52571 .53942 .52664 .54489 .52497 .54401 .52403 Metetra
.664 .741 .907 r
.54401 .52403 .54489 .52497 .55037 .52328 .54949 .52234 Metetra
.664 .741 .907 r
.54949 .52234 .55037 .52328 .55586 .5216 .55499 .52066 Metetra
.664 .741 .907 r
.55499 .52066 .55586 .5216 .56137 .51991 .56049 .51897 Metetra
.664 .741 .907 r
.56049 .51897 .56137 .51991 .56688 .51822 .56601 .51727 Metetra
.664 .741 .907 r
.56601 .51727 .56688 .51822 .57241 .51652 .57154 .51558 Metetra
.664 .741 .907 r
.57154 .51558 .57241 .51652 .57795 .51483 .57708 .51388 Metetra
.664 .741 .907 r
.57708 .51388 .57795 .51483 .5835 .51313 .58263 .51217 Metetra
.664 .741 .907 r
.58263 .51217 .5835 .51313 .5892 .51909 .58819 .51047 Metetra
0 0 .361 r
.58819 .51047 .5892 .51909 .59582 .56692 .59462 .55004 Metetra
.735 .509 .586 r
.59462 .55004 .59582 .56692 .60021 .508 .59935 .50704 Metetra
.664 .741 .907 r
.59935 .50704 .60021 .508 .6058 .50628 .60494 .50533 Metetra
.664 .741 .907 r
.60494 .50533 .6058 .50628 .61141 .50457 .61055 .50361 Metetra
.664 .741 .907 r
.61055 .50361 .61141 .50457 .61702 .50284 .61617 .50188 Metetra
.664 .741 .907 r
.61617 .50188 .61702 .50284 .62265 .50112 .6218 .50015 Metetra
.664 .741 .907 r
.6218 .50015 .62265 .50112 .62829 .49939 .62744 .49842 Metetra
.664 .741 .907 r
.62744 .49842 .62829 .49939 .63394 .49766 .63309 .49669 Metetra
.664 .741 .907 r
.63309 .49669 .63394 .49766 .6396 .49592 .63875 .49495 Metetra
.664 .741 .907 r
.63875 .49495 .6396 .49592 .64527 .49418 .64443 .49321 Metetra
.664 .741 .907 r
.64443 .49321 .64527 .49418 .65095 .49244 .65011 .49146 Metetra
.664 .741 .907 r
.65011 .49146 .65095 .49244 .65665 .49069 .65581 .48972 Metetra
.664 .741 .907 r
.65581 .48972 .65665 .49069 .66236 .48894 .66152 .48796 Metetra
.664 .741 .907 r
.66152 .48796 .66236 .48894 .66808 .48719 .66724 .48621 Metetra
.664 .741 .907 r
.66724 .48621 .66808 .48719 .67381 .48543 .67298 .48445 Metetra
.664 .741 .907 r
.67298 .48445 .67381 .48543 .67955 .48367 .67872 .48269 Metetra
.664 .741 .907 r
.67872 .48269 .67955 .48367 .6853 .4819 .68448 .48092 Metetra
.664 .741 .907 r
.68448 .48092 .6853 .4819 .69107 .48014 .69024 .47915 Metetra
.664 .741 .907 r
.69024 .47915 .69107 .48014 .69684 .47837 .69602 .47738 Metetra
.664 .741 .907 r
.69602 .47738 .69684 .47837 .70263 .47659 .70181 .4756 Metetra
.664 .741 .907 r
.70181 .4756 .70263 .47659 .70843 .47481 .70762 .47382 Metetra
.664 .741 .907 r
.70762 .47382 .70843 .47481 .71425 .47303 .71343 .47203 Metetra
.664 .741 .907 r
.71343 .47203 .71425 .47303 .72007 .47124 .71926 .47024 Metetra
.664 .741 .907 r
.71926 .47024 .72007 .47124 .72591 .46945 .7251 .46845 Metetra
.664 .741 .907 r
.7251 .46845 .72591 .46945 .73175 .46766 .73095 .46666 Metetra
.664 .741 .907 r
.73095 .46666 .73175 .46766 .73761 .46586 .73681 .46486 Metetra
.664 .741 .907 r
.73681 .46486 .73761 .46586 .74349 .46406 .74269 .46306 Metetra
.664 .741 .907 r
.74269 .46306 .74349 .46406 .74937 .46226 .74857 .46125 Metetra
.664 .741 .907 r
.74857 .46125 .74937 .46226 .75527 .46045 .75447 .45944 Metetra
.664 .741 .907 r
.75447 .45944 .75527 .46045 .76118 .45864 .76038 .45762 Metetra
.664 .741 .907 r
.76038 .45762 .76118 .45864 .7671 .45682 .76631 .45581 Metetra
.664 .741 .907 r
.76631 .45581 .7671 .45682 .77303 .455 .77224 .45398 Metetra
.664 .741 .907 r
.77224 .45398 .77303 .455 .77898 .45318 .77819 .45216 Metetra
.664 .741 .907 r
.77819 .45216 .77898 .45318 .78493 .45135 .78415 .45033 Metetra
.664 .741 .907 r
.78415 .45033 .78493 .45135 .7909 .44952 .79012 .4485 Metetra
.664 .741 .907 r
.79012 .4485 .7909 .44952 .79689 .44769 .79611 .44666 Metetra
.664 .741 .907 r
.79611 .44666 .79689 .44769 .80288 .44585 .80211 .44482 Metetra
.664 .741 .907 r
.80211 .44482 .80288 .44585 .80889 .444 .80812 .44298 Metetra
.664 .741 .907 r
.80812 .44298 .80889 .444 .81491 .44216 .81414 .44113 Metetra
.664 .741 .907 r
.81414 .44113 .81491 .44216 .82094 .44031 .82018 .43927 Metetra
.664 .741 .907 r
.82018 .43927 .82094 .44031 .82699 .43845 .82622 .43742 Metetra
.664 .741 .907 r
.82622 .43742 .82699 .43845 .83304 .4366 .83228 .43556 Metetra
.664 .741 .907 r
.83228 .43556 .83304 .4366 .83911 .43474 .83836 .4337 Metetra
.664 .741 .907 r
.83836 .4337 .83911 .43474 .8452 .43287 .84444 .43183 Metetra
.664 .741 .907 r
.84444 .43183 .8452 .43287 .85129 .431 .85054 .42996 Metetra
.664 .741 .907 r
.85054 .42996 .85129 .431 .8574 .42913 .85665 .42808 Metetra
.664 .741 .907 r
.85665 .42808 .8574 .42913 .86352 .42725 .86278 .4262 Metetra
.664 .741 .907 r
.86278 .4262 .86352 .42725 .86966 .42537 .86891 .42432 Metetra
.664 .741 .907 r
.86891 .42432 .86966 .42537 .8758 .42348 .87506 .42243 Metetra
.664 .741 .907 r
.87506 .42243 .8758 .42348 .88196 .42159 .88123 .42054 Metetra
.664 .741 .907 r
.88123 .42054 .88196 .42159 .88814 .4197 .8874 .41864 Metetra
0 .146 .68 r
.8874 .41864 .88814 .4197 .89432 .4178 .89459 .42549 Metetra
.424 .203 .472 r
.89459 .42549 .89432 .4178 .90052 .4159 .89979 .41484 Metetra
.664 .741 .907 r
.89979 .41484 .90052 .4159 .90674 .414 .90601 .41293 Metetra
.664 .741 .907 r
.90601 .41293 .90674 .414 .91296 .41209 .91224 .41102 Metetra
.664 .741 .907 r
.91224 .41102 .91296 .41209 .9192 .41018 .91848 .40911 Metetra
.664 .741 .907 r
.91848 .40911 .9192 .41018 .92545 .40826 .92473 .40719 Metetra
.664 .741 .907 r
.92473 .40719 .92545 .40826 .93172 .40634 .931 .40526 Metetra
.664 .741 .907 r
.931 .40526 .93172 .40634 .93799 .40441 .93728 .40334 Metetra
.664 .741 .907 r
.93728 .40334 .93799 .40441 .94429 .40248 .94358 .4014 Metetra
.664 .741 .907 r
.94358 .4014 .94429 .40248 .95059 .40055 .94989 .39947 Metetra
.664 .741 .907 r
.37827 .57372 .37922 .5746 .38438 .57302 .38343 .57213 Metetra
.664 .741 .907 r
.38343 .57213 .38438 .57302 .38864 .59427 .38861 .57054 Metetra
.579 .384 .581 r
.38861 .57054 .38864 .59427 .39473 .56984 .39379 .56895 Metetra
.664 .741 .907 r
.39379 .56895 .39473 .56984 .39992 .56824 .39899 .56735 Metetra
.664 .741 .907 r
.39899 .56735 .39992 .56824 .40513 .56665 .40419 .56576 Metetra
.664 .741 .907 r
.40419 .56576 .40513 .56665 .41034 .56505 .4094 .56415 Metetra
.664 .741 .907 r
.4094 .56415 .41034 .56505 .41556 .56345 .41463 .56255 Metetra
.664 .741 .907 r
.41463 .56255 .41556 .56345 .42079 .56184 .41986 .56094 Metetra
.664 .741 .907 r
.41986 .56094 .42079 .56184 .42604 .56023 .42511 .55933 Metetra
.664 .741 .907 r
.42511 .55933 .42604 .56023 .43129 .55862 .43036 .55772 Metetra
.664 .741 .907 r
.43036 .55772 .43129 .55862 .43655 .557 .43563 .5561 Metetra
.664 .741 .907 r
.43563 .5561 .43655 .557 .44182 .55539 .4409 .55448 Metetra
.664 .741 .907 r
.4409 .55448 .44182 .55539 .44711 .55376 .44619 .55286 Metetra
.664 .741 .907 r
.44619 .55286 .44711 .55376 .4524 .55214 .45148 .55123 Metetra
.664 .741 .907 r
.45148 .55123 .4524 .55214 .45771 .55051 .45679 .5496 Metetra
.664 .741 .907 r
.45679 .5496 .45771 .55051 .46302 .54888 .46211 .54797 Metetra
.664 .741 .907 r
.46211 .54797 .46302 .54888 .46835 .54725 .46743 .54633 Metetra
.664 .741 .907 r
.46743 .54633 .46835 .54725 .47368 .54561 .47277 .54469 Metetra
.664 .741 .907 r
.47277 .54469 .47368 .54561 .47903 .54397 .47812 .54305 Metetra
.664 .741 .907 r
.47812 .54305 .47903 .54397 .48438 .54233 .48348 .54141 Metetra
.664 .741 .907 r
.48348 .54141 .48438 .54233 .48975 .54068 .48885 .53976 Metetra
.664 .741 .907 r
.48885 .53976 .48975 .54068 .49513 .53903 .49423 .53811 Metetra
.664 .741 .907 r
.49423 .53811 .49513 .53903 .50052 .53737 .49962 .53645 Metetra
.664 .741 .907 r
.49962 .53645 .50052 .53737 .50591 .53572 .50502 .53479 Metetra
.664 .741 .907 r
.50502 .53479 .50591 .53572 .51132 .53406 .51043 .53313 Metetra
.664 .741 .907 r
.51043 .53313 .51132 .53406 .51674 .53239 .51585 .53146 Metetra
.664 .741 .907 r
.51585 .53146 .51674 .53239 .52217 .53073 .52128 .5298 Metetra
.664 .741 .907 r
.52128 .5298 .52217 .53073 .52762 .52906 .52673 .52812 Metetra
.664 .741 .907 r
.52673 .52812 .52762 .52906 .53307 .52738 .53218 .52645 Metetra
.664 .741 .907 r
.53218 .52645 .53307 .52738 .53853 .52571 .53765 .52477 Metetra
.664 .741 .907 r
.53765 .52477 .53853 .52571 .54401 .52403 .54312 .52309 Metetra
.664 .741 .907 r
.54312 .52309 .54401 .52403 .54949 .52234 .54861 .5214 Metetra
.664 .741 .907 r
.54861 .5214 .54949 .52234 .55499 .52066 .55411 .51972 Metetra
.664 .741 .907 r
.55411 .51972 .55499 .52066 .56049 .51897 .55962 .51802 Metetra
.664 .741 .907 r
.55962 .51802 .56049 .51897 .56601 .51727 .56514 .51633 Metetra
.664 .741 .907 r
.56514 .51633 .56601 .51727 .57154 .51558 .57067 .51463 Metetra
.664 .741 .907 r
.57067 .51463 .57154 .51558 .57708 .51388 .57621 .51293 Metetra
.664 .741 .907 r
.57621 .51293 .57708 .51388 .58263 .51217 .58176 .51122 Metetra
.664 .741 .907 r
.58176 .51122 .58263 .51217 .58819 .51047 .58733 .50951 Metetra
.962 .674 .441 r
.58733 .50951 .58819 .51047 .59462 .55004 .59566 .6431 Metetra
.389 .217 .524 r
.59566 .6431 .59462 .55004 .59935 .50704 .59849 .50609 Metetra
.664 .741 .907 r
.59849 .50609 .59935 .50704 .60494 .50533 .60408 .50437 Metetra
.664 .741 .907 r
.60408 .50437 .60494 .50533 .61055 .50361 .60969 .50264 Metetra
.664 .741 .907 r
.60969 .50264 .61055 .50361 .61617 .50188 .61531 .50092 Metetra
.664 .741 .907 r
.61531 .50092 .61617 .50188 .6218 .50015 .62095 .49919 Metetra
.664 .741 .907 r
.62095 .49919 .6218 .50015 .62744 .49842 .62659 .49746 Metetra
.664 .741 .907 r
.62659 .49746 .62744 .49842 .63309 .49669 .63224 .49572 Metetra
.664 .741 .907 r
.63224 .49572 .63309 .49669 .63875 .49495 .63791 .49398 Metetra
.664 .741 .907 r
.63791 .49398 .63875 .49495 .64443 .49321 .64359 .49224 Metetra
.664 .741 .907 r
.64359 .49224 .64443 .49321 .65011 .49146 .64927 .49049 Metetra
.664 .741 .907 r
.64927 .49049 .65011 .49146 .65581 .48972 .65497 .48874 Metetra
.664 .741 .907 r
.65497 .48874 .65581 .48972 .66152 .48796 .66069 .48698 Metetra
.664 .741 .907 r
.66069 .48698 .66152 .48796 .66724 .48621 .66641 .48523 Metetra
.664 .741 .907 r
.66641 .48523 .66724 .48621 .67298 .48445 .67214 .48347 Metetra
.664 .741 .907 r
.67214 .48347 .67298 .48445 .67872 .48269 .67789 .4817 Metetra
.664 .741 .907 r
.67789 .4817 .67872 .48269 .68448 .48092 .68365 .47993 Metetra
.664 .741 .907 r
.68365 .47993 .68448 .48092 .69024 .47915 .68942 .47816 Metetra
.664 .741 .907 r
.68942 .47816 .69024 .47915 .69602 .47738 .6952 .47638 Metetra
.664 .741 .907 r
.6952 .47638 .69602 .47738 .70181 .4756 .701 .47461 Metetra
.664 .741 .907 r
.701 .47461 .70181 .4756 .70762 .47382 .7068 .47282 Metetra
.664 .741 .907 r
.7068 .47282 .70762 .47382 .71343 .47203 .71262 .47104 Metetra
.664 .741 .907 r
.71262 .47104 .71343 .47203 .71926 .47024 .71845 .46925 Metetra
.664 .741 .907 r
.71845 .46925 .71926 .47024 .7251 .46845 .72429 .46745 Metetra
.664 .741 .907 r
.72429 .46745 .7251 .46845 .73095 .46666 .73014 .46565 Metetra
.659 .739 .909 r
.73014 .46565 .73095 .46666 .73681 .46486 .73601 .46392 Metetra
.668 .757 .917 r
.73601 .46392 .73681 .46486 .74269 .46306 .74189 .46205 Metetra
.664 .741 .907 r
.74189 .46205 .74269 .46306 .74857 .46125 .74778 .46024 Metetra
.664 .741 .907 r
.74778 .46024 .74857 .46125 .75447 .45944 .75368 .45843 Metetra
.664 .741 .907 r
.75368 .45843 .75447 .45944 .76038 .45762 .75959 .45661 Metetra
.664 .741 .907 r
.75959 .45661 .76038 .45762 .76631 .45581 .76552 .45479 Metetra
.664 .741 .907 r
.76552 .45479 .76631 .45581 .77224 .45398 .77146 .45297 Metetra
.664 .741 .907 r
.77146 .45297 .77224 .45398 .77819 .45216 .77741 .45114 Metetra
.664 .741 .907 r
.77741 .45114 .77819 .45216 .78415 .45033 .78337 .44931 Metetra
.664 .741 .907 r
.78337 .44931 .78415 .45033 .79012 .4485 .78934 .44747 Metetra
.664 .741 .907 r
.78934 .44747 .79012 .4485 .79611 .44666 .79533 .44563 Metetra
.664 .741 .907 r
.79533 .44563 .79611 .44666 .80211 .44482 .80133 .44379 Metetra
.664 .741 .907 r
.80133 .44379 .80211 .44482 .80812 .44298 .80735 .44194 Metetra
.664 .741 .907 r
.80735 .44194 .80812 .44298 .81414 .44113 .81337 .44009 Metetra
.664 .741 .907 r
.81337 .44009 .81414 .44113 .82018 .43927 .81941 .43824 Metetra
.664 .741 .907 r
.81941 .43824 .82018 .43927 .82622 .43742 .82546 .43638 Metetra
.664 .741 .907 r
.82546 .43638 .82622 .43742 .83228 .43556 .83152 .43452 Metetra
.664 .741 .907 r
.83152 .43452 .83228 .43556 .83836 .4337 .8376 .43265 Metetra
.664 .741 .907 r
.8376 .43265 .83836 .4337 .84444 .43183 .84369 .43078 Metetra
.664 .741 .907 r
.84369 .43078 .84444 .43183 .85054 .42996 .84979 .42891 Metetra
.664 .741 .907 r
.84979 .42891 .85054 .42996 .85665 .42808 .8559 .42703 Metetra
.664 .741 .907 r
.8559 .42703 .85665 .42808 .86278 .4262 .86203 .42515 Metetra
.664 .741 .907 r
.86203 .42515 .86278 .4262 .86891 .42432 .86817 .42327 Metetra
.664 .741 .907 r
.86817 .42327 .86891 .42432 .87506 .42243 .87432 .42138 Metetra
.664 .741 .907 r
.87432 .42138 .87506 .42243 .88123 .42054 .88049 .41948 Metetra
0 0 .547 r
.88049 .41948 .88123 .42054 .8874 .41864 .88784 .42814 Metetra
.74 .454 .495 r
.88784 .42814 .8874 .41864 .89459 .42549 .89756 .4571 Metetra
.432 .25 .532 r
.89756 .4571 .89459 .42549 .89979 .41484 .89906 .41378 Metetra
.664 .741 .907 r
.89906 .41378 .89979 .41484 .90601 .41293 .90528 .41187 Metetra
.664 .741 .907 r
.90528 .41187 .90601 .41293 .91224 .41102 .91151 .40995 Metetra
.664 .741 .907 r
.91151 .40995 .91224 .41102 .91848 .40911 .91776 .40804 Metetra
.664 .741 .907 r
.91776 .40804 .91848 .40911 .92473 .40719 .92401 .40611 Metetra
.664 .741 .907 r
.92401 .40611 .92473 .40719 .931 .40526 .93029 .40419 Metetra
.664 .741 .907 r
.93029 .40419 .931 .40526 .93728 .40334 .93657 .40226 Metetra
.664 .741 .907 r
.93657 .40226 .93728 .40334 .94358 .4014 .94287 .40032 Metetra
.664 .741 .907 r
.94287 .40032 .94358 .4014 .94989 .39947 .94918 .39839 Metetra
.664 .741 .907 r
.37732 .57283 .37827 .57372 .38343 .57213 .38249 .57124 Metetra
.664 .741 .907 r
.38249 .57124 .38343 .57213 .38861 .57054 .38767 .56965 Metetra
.664 .741 .907 r
.38767 .56965 .38861 .57054 .39379 .56895 .39285 .56806 Metetra
.664 .741 .907 r
.39285 .56806 .39379 .56895 .39899 .56735 .39805 .56646 Metetra
.664 .741 .907 r
.39805 .56646 .39899 .56735 .40419 .56576 .40325 .56486 Metetra
.664 .741 .907 r
.40325 .56486 .40419 .56576 .4094 .56415 .40847 .56326 Metetra
.664 .741 .907 r
.40847 .56326 .4094 .56415 .41463 .56255 .4137 .56165 Metetra
.664 .741 .907 r
.4137 .56165 .41463 .56255 .41986 .56094 .41893 .56005 Metetra
.664 .741 .907 r
.41893 .56005 .41986 .56094 .42511 .55933 .42418 .55843 Metetra
.664 .741 .907 r
.42418 .55843 .42511 .55933 .43036 .55772 .42943 .55682 Metetra
.664 .741 .907 r
.42943 .55682 .43036 .55772 .43563 .5561 .4347 .5552 Metetra
.664 .741 .907 r
.4347 .5552 .43563 .5561 .4409 .55448 .43998 .55358 Metetra
.664 .741 .907 r
.43998 .55358 .4409 .55448 .44619 .55286 .44527 .55195 Metetra
.664 .741 .907 r
.44527 .55195 .44619 .55286 .45148 .55123 .45056 .55032 Metetra
.664 .741 .907 r
.45056 .55032 .45148 .55123 .45679 .5496 .45587 .54869 Metetra
.664 .741 .907 r
.45587 .54869 .45679 .5496 .46211 .54797 .46119 .54706 Metetra
.664 .741 .907 r
.46119 .54706 .46211 .54797 .46743 .54633 .46652 .54542 Metetra
.664 .741 .907 r
.46652 .54542 .46743 .54633 .47277 .54469 .47186 .54378 Metetra
.664 .741 .907 r
.47186 .54378 .47277 .54469 .47812 .54305 .47721 .54214 Metetra
.664 .741 .907 r
.47721 .54214 .47812 .54305 .48348 .54141 .48257 .54049 Metetra
.664 .741 .907 r
.48257 .54049 .48348 .54141 .48885 .53976 .48794 .53884 Metetra
.664 .741 .907 r
.48794 .53884 .48885 .53976 .49423 .53811 .49332 .53718 Metetra
.664 .741 .907 r
.49332 .53718 .49423 .53811 .49962 .53645 .49871 .53553 Metetra
.664 .741 .907 r
.49871 .53553 .49962 .53645 .50502 .53479 .50412 .53387 Metetra
.664 .741 .907 r
.50412 .53387 .50502 .53479 .51043 .53313 .50953 .5322 Metetra
.664 .741 .907 r
.50953 .5322 .51043 .53313 .51585 .53146 .51495 .53053 Metetra
.664 .741 .907 r
.51495 .53053 .51585 .53146 .52128 .5298 .52039 .52886 Metetra
.664 .741 .907 r
.52039 .52886 .52128 .5298 .52673 .52812 .52584 .52719 Metetra
.664 .741 .907 r
.52584 .52719 .52673 .52812 .53218 .52645 .53129 .52551 Metetra
.664 .741 .907 r
.53129 .52551 .53218 .52645 .53765 .52477 .53676 .52383 Metetra
.664 .741 .907 r
.53676 .52383 .53765 .52477 .54312 .52309 .54224 .52215 Metetra
.664 .741 .907 r
.54224 .52215 .54312 .52309 .54861 .5214 .54773 .52046 Metetra
.664 .741 .907 r
.54773 .52046 .54861 .5214 .55411 .51972 .55323 .51877 Metetra
.664 .741 .907 r
.55323 .51877 .55411 .51972 .55962 .51802 .55874 .51708 Metetra
.664 .741 .907 r
.55874 .51708 .55962 .51802 .56514 .51633 .56426 .51538 Metetra
.664 .741 .907 r
.56426 .51538 .56514 .51633 .57067 .51463 .56979 .51368 Metetra
.664 .741 .907 r
.56979 .51368 .57067 .51463 .57621 .51293 .57534 .51198 Metetra
.664 .741 .907 r
.57534 .51198 .57621 .51293 .58176 .51122 .58089 .51027 Metetra
.957 .627 .346 r
.58089 .51027 .58176 .51122 .58733 .50951 .58715 .54586 Metetra
.793 .535 .547 r
.58715 .54586 .58733 .50951 .59566 .6431 .59645 .72584 Metetra
.146 .033 .456 r
.59645 .72584 .59566 .6431 .59849 .50609 .59762 .50513 Metetra
.664 .741 .907 r
.59762 .50513 .59849 .50609 .60408 .50437 .60322 .50341 Metetra
.664 .741 .907 r
.60322 .50341 .60408 .50437 .60969 .50264 .60884 .50168 Metetra
.664 .741 .907 r
.60884 .50168 .60969 .50264 .61531 .50092 .61446 .49995 Metetra
.664 .741 .907 r
.61446 .49995 .61531 .50092 .62095 .49919 .62009 .49822 Metetra
.664 .741 .907 r
.62009 .49822 .62095 .49919 .62659 .49746 .62574 .49649 Metetra
.664 .741 .907 r
.62574 .49649 .62659 .49746 .63224 .49572 .63139 .49475 Metetra
.664 .741 .907 r
.63139 .49475 .63224 .49572 .63791 .49398 .63706 .49301 Metetra
.664 .741 .907 r
.63706 .49301 .63791 .49398 .64359 .49224 .64274 .49126 Metetra
.664 .741 .907 r
.64274 .49126 .64359 .49224 .64927 .49049 .64843 .48951 Metetra
.664 .741 .907 r
.64843 .48951 .64927 .49049 .65497 .48874 .65414 .48776 Metetra
.664 .741 .907 r
.65414 .48776 .65497 .48874 .66069 .48698 .65985 .486 Metetra
.664 .741 .907 r
.65985 .486 .66069 .48698 .66641 .48523 .66558 .48425 Metetra
.664 .741 .907 r
.66558 .48425 .66641 .48523 .67214 .48347 .67131 .48248 Metetra
.664 .741 .907 r
.67131 .48248 .67214 .48347 .67789 .4817 .67706 .48072 Metetra
.664 .741 .907 r
.67706 .48072 .67789 .4817 .68365 .47993 .68282 .47894 Metetra
.664 .741 .907 r
.68282 .47894 .68365 .47993 .68942 .47816 .6886 .47717 Metetra
.664 .741 .907 r
.6886 .47717 .68942 .47816 .6952 .47638 .69438 .47539 Metetra
.664 .741 .907 r
.69438 .47539 .6952 .47638 .701 .47461 .70018 .47361 Metetra
.664 .741 .907 r
.70018 .47361 .701 .47461 .7068 .47282 .70598 .47183 Metetra
.664 .741 .907 r
.70598 .47183 .7068 .47282 .71262 .47104 .7118 .47004 Metetra
.664 .741 .907 r
.7118 .47004 .71262 .47104 .71845 .46925 .71764 .46825 Metetra
.664 .741 .907 r
.71764 .46825 .71845 .46925 .72429 .46745 .72348 .46645 Metetra
.664 .741 .907 r
.72348 .46645 .72429 .46745 .73014 .46565 .72934 .46465 Metetra
.664 .741 .907 r
.72934 .46465 .73014 .46565 .73601 .46392 .7352 .46285 Metetra
.664 .727 .896 r
.7352 .46285 .73601 .46392 .74189 .46205 .74108 .46104 Metetra
.664 .741 .907 r
.74108 .46104 .74189 .46205 .74778 .46024 .74698 .45923 Metetra
.664 .741 .907 r
.74698 .45923 .74778 .46024 .75368 .45843 .75288 .45741 Metetra
.664 .741 .907 r
.75288 .45741 .75368 .45843 .75959 .45661 .7588 .4556 Metetra
.664 .741 .907 r
.7588 .4556 .75959 .45661 .76552 .45479 .76472 .45377 Metetra
.664 .741 .907 r
.76472 .45377 .76552 .45479 .77146 .45297 .77067 .45195 Metetra
.664 .741 .907 r
.77067 .45195 .77146 .45297 .77741 .45114 .77662 .45012 Metetra
.664 .741 .907 r
.77662 .45012 .77741 .45114 .78337 .44931 .78258 .44828 Metetra
.664 .741 .907 r
.78258 .44828 .78337 .44931 .78934 .44747 .78856 .44645 Metetra
.664 .741 .907 r
.78856 .44645 .78934 .44747 .79533 .44563 .79455 .44461 Metetra
.664 .741 .907 r
.79455 .44461 .79533 .44563 .80133 .44379 .80056 .44276 Metetra
.664 .741 .907 r
.80056 .44276 .80133 .44379 .80735 .44194 .80657 .44091 Metetra
.664 .741 .907 r
.80657 .44091 .80735 .44194 .81337 .44009 .8126 .43906 Metetra
.664 .741 .907 r
.8126 .43906 .81337 .44009 .81941 .43824 .81864 .4372 Metetra
.664 .741 .907 r
.81864 .4372 .81941 .43824 .82546 .43638 .82469 .43534 Metetra
.664 .741 .907 r
.82469 .43534 .82546 .43638 .83152 .43452 .83076 .43348 Metetra
.664 .741 .907 r
.83076 .43348 .83152 .43452 .8376 .43265 .83684 .43161 Metetra
.664 .741 .907 r
.83684 .43161 .8376 .43265 .84369 .43078 .84293 .42974 Metetra
.664 .741 .907 r
.84293 .42974 .84369 .43078 .84979 .42891 .84903 .42786 Metetra
.664 .741 .907 r
.84903 .42786 .84979 .42891 .8559 .42703 .85515 .42598 Metetra
.664 .741 .907 r
.85515 .42598 .8559 .42703 .86203 .42515 .86128 .4241 Metetra
.664 .741 .907 r
.86128 .4241 .86203 .42515 .86817 .42327 .86742 .42221 Metetra
.664 .741 .907 r
.86742 .42221 .86817 .42327 .87432 .42138 .87358 .42032 Metetra
.664 .741 .907 r
.87358 .42032 .87432 .42138 .88049 .41948 .87975 .41842 Metetra
.664 .741 .907 r
.87975 .41842 .88049 .41948 .88784 .42814 .88593 .41652 Metetra
.329 .231 .59 r
.88593 .41652 .88784 .42814 .89756 .4571 .89528 .44245 Metetra
.712 .487 .582 r
.89528 .44245 .89756 .4571 .89906 .41378 .89833 .41271 Metetra
.664 .741 .907 r
.89833 .41271 .89906 .41378 .90528 .41187 .90455 .4108 Metetra
.664 .741 .907 r
.90455 .4108 .90528 .41187 .91151 .40995 .91079 .40889 Metetra
.664 .741 .907 r
.91079 .40889 .91151 .40995 .91776 .40804 .91703 .40697 Metetra
.664 .741 .907 r
.91703 .40697 .91776 .40804 .92401 .40611 .92329 .40504 Metetra
.664 .741 .907 r
.92329 .40504 .92401 .40611 .93029 .40419 .92957 .40311 Metetra
.664 .741 .907 r
.92957 .40311 .93029 .40419 .93657 .40226 .93586 .40118 Metetra
.664 .741 .907 r
.93586 .40118 .93657 .40226 .94287 .40032 .94216 .39924 Metetra
.664 .741 .907 r
.94216 .39924 .94287 .40032 .94918 .39839 .94847 .3973 Metetra
.664 .741 .907 r
.37638 .57195 .37732 .57283 .38249 .57124 .38154 .57036 Metetra
.664 .741 .907 r
.38154 .57036 .38249 .57124 .38767 .56965 .38672 .56877 Metetra
.664 .741 .907 r
.38672 .56877 .38767 .56965 .39285 .56806 .39191 .56717 Metetra
.664 .741 .907 r
.39191 .56717 .39285 .56806 .39805 .56646 .39711 .56557 Metetra
.664 .741 .907 r
.39711 .56557 .39805 .56646 .40325 .56486 .40231 .56397 Metetra
.664 .741 .907 r
.40231 .56397 .40325 .56486 .40847 .56326 .40753 .56237 Metetra
.664 .741 .907 r
.40753 .56237 .40847 .56326 .4137 .56165 .41276 .56076 Metetra
.664 .741 .907 r
.41276 .56076 .4137 .56165 .41893 .56005 .418 .55915 Metetra
.664 .741 .907 r
.418 .55915 .41893 .56005 .42418 .55843 .42325 .55753 Metetra
.664 .741 .907 r
.42325 .55753 .42418 .55843 .42943 .55682 .42851 .55591 Metetra
.664 .741 .907 r
.42851 .55591 .42943 .55682 .4347 .5552 .43377 .55429 Metetra
.664 .741 .907 r
.43377 .55429 .4347 .5552 .43998 .55358 .43905 .55267 Metetra
.664 .741 .907 r
.43905 .55267 .43998 .55358 .44527 .55195 .44434 .55104 Metetra
.16 .507 .912 r
.44434 .55104 .44527 .55195 .45056 .55032 .44956 .5531 Metetra
.766 .456 .462 r
.44956 .5531 .45056 .55032 .45587 .54869 .45458 .5658 Metetra
.424 .22 .497 r
.45458 .5658 .45587 .54869 .46119 .54706 .46027 .54614 Metetra
.664 .741 .907 r
.46027 .54614 .46119 .54706 .46652 .54542 .4656 .54451 Metetra
.664 .741 .907 r
.4656 .54451 .46652 .54542 .47186 .54378 .47095 .54286 Metetra
.664 .741 .907 r
.47095 .54286 .47186 .54378 .47721 .54214 .4763 .54122 Metetra
.664 .741 .907 r
.4763 .54122 .47721 .54214 .48257 .54049 .48166 .53957 Metetra
.664 .741 .907 r
.48166 .53957 .48257 .54049 .48794 .53884 .48703 .53791 Metetra
.664 .741 .907 r
.48703 .53791 .48794 .53884 .49332 .53718 .49242 .53626 Metetra
.664 .741 .907 r
.49242 .53626 .49332 .53718 .49871 .53553 .49781 .5346 Metetra
.664 .741 .907 r
.49781 .5346 .49871 .53553 .50412 .53387 .50322 .53294 Metetra
.664 .741 .907 r
.50322 .53294 .50412 .53387 .50953 .5322 .50863 .53127 Metetra
.664 .741 .907 r
.50863 .53127 .50953 .5322 .51495 .53053 .51406 .5296 Metetra
.664 .741 .907 r
.51406 .5296 .51495 .53053 .52039 .52886 .5195 .52793 Metetra
.664 .741 .907 r
.5195 .52793 .52039 .52886 .52584 .52719 .52494 .52626 Metetra
.664 .741 .907 r
.52494 .52626 .52584 .52719 .53129 .52551 .5304 .52458 Metetra
.664 .741 .907 r
.5304 .52458 .53129 .52551 .53676 .52383 .53587 .5229 Metetra
.664 .741 .907 r
.53587 .5229 .53676 .52383 .54224 .52215 .54135 .52121 Metetra
.664 .741 .907 r
.54135 .52121 .54224 .52215 .54773 .52046 .54684 .51952 Metetra
.664 .741 .907 r
.54684 .51952 .54773 .52046 .55323 .51877 .55235 .51783 Metetra
.664 .741 .907 r
.55235 .51783 .55323 .51877 .55874 .51708 .55786 .51613 Metetra
.664 .741 .907 r
.55786 .51613 .55874 .51708 .56426 .51538 .56338 .51443 Metetra
.664 .741 .907 r
.56338 .51443 .56426 .51538 .56979 .51368 .56892 .51273 Metetra
.664 .741 .907 r
.56892 .51273 .56979 .51368 .57534 .51198 .57446 .51103 Metetra
.664 .741 .907 r
.57446 .51103 .57534 .51198 .58089 .51027 .58002 .50932 Metetra
.961 .666 .425 r
.58002 .50932 .58089 .51027 .58715 .54586 .5872 .59573 Metetra
.672 .436 .555 r
.5872 .59573 .58715 .54586 .59645 .72584 .59441 .6684 Metetra
.75 .509 .568 r
.59441 .6684 .59645 .72584 .59762 .50513 .59676 .50417 Metetra
.664 .741 .907 r
.59676 .50417 .59762 .50513 .60322 .50341 .60236 .50245 Metetra
.664 .741 .907 r
.60236 .50245 .60322 .50341 .60884 .50168 .60798 .50072 Metetra
.664 .741 .907 r
.60798 .50072 .60884 .50168 .61446 .49995 .6136 .49899 Metetra
.664 .741 .907 r
.6136 .49899 .61446 .49995 .62009 .49822 .61924 .49726 Metetra
.664 .741 .907 r
.61924 .49726 .62009 .49822 .62574 .49649 .62489 .49552 Metetra
.664 .741 .907 r
.62489 .49552 .62574 .49649 .63139 .49475 .63054 .49378 Metetra
.664 .741 .907 r
.63054 .49378 .63139 .49475 .63706 .49301 .63621 .49203 Metetra
.664 .741 .907 r
.63621 .49203 .63706 .49301 .64274 .49126 .6419 .49029 Metetra
.664 .741 .907 r
.6419 .49029 .64274 .49126 .64843 .48951 .64759 .48854 Metetra
.664 .741 .907 r
.64759 .48854 .64843 .48951 .65414 .48776 .6533 .48678 Metetra
.664 .741 .907 r
.6533 .48678 .65414 .48776 .65985 .486 .65901 .48502 Metetra
.664 .741 .907 r
.65901 .48502 .65985 .486 .66558 .48425 .66474 .48326 Metetra
.664 .741 .907 r
.66474 .48326 .66558 .48425 .67131 .48248 .67048 .4815 Metetra
.664 .741 .907 r
.67048 .4815 .67131 .48248 .67706 .48072 .67623 .47973 Metetra
.664 .741 .907 r
.67623 .47973 .67706 .48072 .68282 .47894 .68199 .47796 Metetra
.664 .741 .907 r
.68199 .47796 .68282 .47894 .6886 .47717 .68777 .47618 Metetra
.664 .741 .907 r
.68777 .47618 .6886 .47717 .69438 .47539 .69356 .4744 Metetra
.664 .741 .907 r
.69356 .4744 .69438 .47539 .70018 .47361 .69935 .47262 Metetra
.664 .741 .907 r
.69935 .47262 .70018 .47361 .70598 .47183 .70517 .47083 Metetra
.664 .741 .907 r
.70517 .47083 .70598 .47183 .7118 .47004 .71099 .46904 Metetra
.664 .741 .907 r
.71099 .46904 .7118 .47004 .71764 .46825 .71682 .46724 Metetra
.664 .741 .907 r
.71682 .46724 .71764 .46825 .72348 .46645 .72267 .46545 Metetra
.664 .741 .907 r
.72267 .46545 .72348 .46645 .72934 .46465 .72853 .46364 Metetra
.664 .741 .907 r
.72853 .46364 .72934 .46465 .7352 .46285 .7344 .46184 Metetra
.664 .741 .907 r
.7344 .46184 .7352 .46285 .74108 .46104 .74028 .46003 Metetra
.664 .741 .907 r
.74028 .46003 .74108 .46104 .74698 .45923 .74617 .45822 Metetra
.664 .741 .907 r
.74617 .45822 .74698 .45923 .75288 .45741 .75208 .4564 Metetra
.664 .741 .907 r
.75208 .4564 .75288 .45741 .7588 .4556 .758 .45458 Metetra
.664 .741 .907 r
.758 .45458 .7588 .4556 .76472 .45377 .76393 .45276 Metetra
.664 .741 .907 r
.76393 .45276 .76472 .45377 .77067 .45195 .76988 .45093 Metetra
.664 .741 .907 r
.76988 .45093 .77067 .45195 .77662 .45012 .77583 .4491 Metetra
.664 .741 .907 r
.77583 .4491 .77662 .45012 .78258 .44828 .7818 .44726 Metetra
.664 .741 .907 r
.7818 .44726 .78258 .44828 .78856 .44645 .78778 .44542 Metetra
.664 .741 .907 r
.78778 .44542 .78856 .44645 .79455 .44461 .79377 .44358 Metetra
.664 .741 .907 r
.79377 .44358 .79455 .44461 .80056 .44276 .79978 .44173 Metetra
.664 .741 .907 r
.79978 .44173 .80056 .44276 .80657 .44091 .8058 .43988 Metetra
.664 .741 .907 r
.8058 .43988 .80657 .44091 .8126 .43906 .81183 .43803 Metetra
.664 .741 .907 r
.81183 .43803 .8126 .43906 .81864 .4372 .81787 .43617 Metetra
.664 .741 .907 r
.81787 .43617 .81864 .4372 .82469 .43534 .82393 .4343 Metetra
.664 .741 .907 r
.82393 .4343 .82469 .43534 .83076 .43348 .83 .43244 Metetra
.664 .741 .907 r
.83 .43244 .83076 .43348 .83684 .43161 .83608 .43057 Metetra
.664 .741 .907 r
.83608 .43057 .83684 .43161 .84293 .42974 .84217 .42869 Metetra
.664 .741 .907 r
.84217 .42869 .84293 .42974 .84903 .42786 .84828 .42682 Metetra
.664 .741 .907 r
.84828 .42682 .84903 .42786 .85515 .42598 .8544 .42493 Metetra
.664 .741 .907 r
.8544 .42493 .85515 .42598 .86128 .4241 .86053 .42305 Metetra
.664 .741 .907 r
.86053 .42305 .86128 .4241 .86742 .42221 .86668 .42116 Metetra
.664 .741 .907 r
.86668 .42116 .86742 .42221 .87358 .42032 .87283 .41926 Metetra
.664 .741 .907 r
.87283 .41926 .87358 .42032 .87975 .41842 .87901 .41737 Metetra
.664 .741 .907 r
.87901 .41737 .87975 .41842 .88593 .41652 .88519 .41546 Metetra
.664 .741 .907 r
.88519 .41546 .88593 .41652 .89528 .44245 .89139 .41356 Metetra
.577 .381 .578 r
.89139 .41356 .89528 .44245 .89833 .41271 .8976 .41165 Metetra
.664 .741 .907 r
.8976 .41165 .89833 .41271 .90455 .4108 .90382 .40973 Metetra
.664 .741 .907 r
.90382 .40973 .90455 .4108 .91079 .40889 .91006 .40781 Metetra
.664 .741 .907 r
.91006 .40781 .91079 .40889 .91703 .40697 .91631 .40589 Metetra
.664 .741 .907 r
.91631 .40589 .91703 .40697 .92329 .40504 .92257 .40397 Metetra
.664 .741 .907 r
.92257 .40397 .92329 .40504 .92957 .40311 .92885 .40204 Metetra
.664 .741 .907 r
.92885 .40204 .92957 .40311 .93586 .40118 .93514 .4001 Metetra
.664 .741 .907 r
.93514 .4001 .93586 .40118 .94216 .39924 .94144 .39816 Metetra
.664 .741 .907 r
.94144 .39816 .94216 .39924 .94847 .3973 .94776 .39622 Metetra
.664 .741 .907 r
.37543 .57106 .37638 .57195 .38154 .57036 .3806 .56947 Metetra
.664 .741 .907 r
.3806 .56947 .38154 .57036 .38672 .56877 .38578 .56788 Metetra
.664 .741 .907 r
.38578 .56788 .38672 .56877 .39191 .56717 .39097 .56628 Metetra
.664 .741 .907 r
.39097 .56628 .39191 .56717 .39711 .56557 .39617 .56468 Metetra
.664 .741 .907 r
.39617 .56468 .39711 .56557 .40231 .56397 .40138 .56308 Metetra
.664 .741 .907 r
.40138 .56308 .40231 .56397 .40753 .56237 .4066 .56147 Metetra
.664 .741 .907 r
.4066 .56147 .40753 .56237 .41276 .56076 .41183 .55986 Metetra
.664 .741 .907 r
.41183 .55986 .41276 .56076 .418 .55915 .41707 .55825 Metetra
.664 .741 .907 r
.41707 .55825 .418 .55915 .42325 .55753 .42232 .55663 Metetra
.664 .741 .907 r
.42232 .55663 .42325 .55753 .42851 .55591 .42758 .55501 Metetra
.664 .741 .907 r
.42758 .55501 .42851 .55591 .43377 .55429 .43285 .55339 Metetra
.664 .741 .907 r
.43285 .55339 .43377 .55429 .43905 .55267 .43813 .55176 Metetra
.664 .741 .907 r
.43813 .55176 .43905 .55267 .44434 .55104 .44342 .55014 Metetra
.946 .605 .342 r
.44342 .55014 .44434 .55104 .44956 .5531 .44817 .57272 Metetra
.405 .207 .496 r
.44817 .57272 .44956 .5531 .45458 .5658 .45401 .54793 Metetra
.587 .395 .589 r
.45401 .54793 .45458 .5658 .46027 .54614 .45936 .54523 Metetra
.664 .741 .907 r
.45936 .54523 .46027 .54614 .4656 .54451 .46469 .54359 Metetra
.664 .741 .907 r
.46469 .54359 .4656 .54451 .47095 .54286 .47003 .54194 Metetra
.664 .741 .907 r
.47003 .54194 .47095 .54286 .4763 .54122 .47539 .5403 Metetra
.664 .741 .907 r
.47539 .5403 .4763 .54122 .48166 .53957 .48075 .53865 Metetra
.664 .741 .907 r
.48075 .53865 .48166 .53957 .48703 .53791 .48613 .53699 Metetra
.664 .741 .907 r
.48613 .53699 .48703 .53791 .49242 .53626 .49151 .53533 Metetra
.664 .741 .907 r
.49151 .53533 .49242 .53626 .49781 .5346 .49691 .53367 Metetra
.664 .741 .907 r
.49691 .53367 .49781 .5346 .50322 .53294 .50232 .53201 Metetra
.664 .741 .907 r
.50232 .53201 .50322 .53294 .50863 .53127 .50773 .53034 Metetra
.664 .741 .907 r
.50773 .53034 .50863 .53127 .51406 .5296 .51316 .52867 Metetra
.664 .741 .907 r
.51316 .52867 .51406 .5296 .5195 .52793 .5186 .527 Metetra
.664 .741 .907 r
.5186 .527 .5195 .52793 .52494 .52626 .52405 .52532 Metetra
.664 .741 .907 r
.52405 .52532 .52494 .52626 .5304 .52458 .52951 .52364 Metetra
.664 .741 .907 r
.52951 .52364 .5304 .52458 .53587 .5229 .53498 .52196 Metetra
.664 .741 .907 r
.53498 .52196 .53587 .5229 .54135 .52121 .54047 .52027 Metetra
.664 .741 .907 r
.54047 .52027 .54135 .52121 .54684 .51952 .54596 .51858 Metetra
.664 .741 .907 r
.54596 .51858 .54684 .51952 .55235 .51783 .55146 .51688 Metetra
.664 .741 .907 r
.55146 .51688 .55235 .51783 .55786 .51613 .55698 .51519 Metetra
.664 .741 .907 r
.55698 .51519 .55786 .51613 .56338 .51443 .56251 .51348 Metetra
.664 .741 .907 r
.56251 .51348 .56338 .51443 .56892 .51273 .56804 .51178 Metetra
.664 .741 .907 r
.56804 .51178 .56892 .51273 .57446 .51103 .57359 .51007 Metetra
.664 .741 .907 r
.57359 .51007 .57446 .51103 .58002 .50932 .57915 .50836 Metetra
0 .018 .534 r
.57915 .50836 .58002 .50932 .5872 .59573 .58486 .51418 Metetra
.473 .292 .553 r
.58486 .51418 .5872 .59573 .59441 .6684 .5919 .58631 Metetra
.653 .431 .57 r
.5919 .58631 .59441 .6684 .59676 .50417 .5959 .50321 Metetra
.664 .741 .907 r
.5959 .50321 .59676 .50417 .60236 .50245 .6015 .50148 Metetra
.664 .741 .907 r
.6015 .50148 .60236 .50245 .60798 .50072 .60712 .49975 Metetra
.664 .741 .907 r
.60712 .49975 .60798 .50072 .6136 .49899 .61274 .49802 Metetra
.664 .741 .907 r
.61274 .49802 .6136 .49899 .61924 .49726 .61838 .49629 Metetra
.664 .741 .907 r
.61838 .49629 .61924 .49726 .62489 .49552 .62403 .49455 Metetra
.664 .741 .907 r
.62403 .49455 .62489 .49552 .63054 .49378 .62969 .49281 Metetra
.664 .741 .907 r
.62969 .49281 .63054 .49378 .63621 .49203 .63537 .49106 Metetra
.664 .741 .907 r
.63537 .49106 .63621 .49203 .6419 .49029 .64105 .48931 Metetra
.664 .741 .907 r
.64105 .48931 .6419 .49029 .64759 .48854 .64675 .48756 Metetra
.664 .741 .907 r
.64675 .48756 .64759 .48854 .6533 .48678 .65245 .4858 Metetra
.664 .741 .907 r
.65245 .4858 .6533 .48678 .65901 .48502 .65817 .48404 Metetra
.664 .741 .907 r
.65817 .48404 .65901 .48502 .66474 .48326 .6639 .48228 Metetra
.664 .741 .907 r
.6639 .48228 .66474 .48326 .67048 .4815 .66965 .48051 Metetra
.664 .741 .907 r
.66965 .48051 .67048 .4815 .67623 .47973 .6754 .47874 Metetra
.664 .741 .907 r
.6754 .47874 .67623 .47973 .68199 .47796 .68117 .47697 Metetra
.664 .741 .907 r
.68117 .47697 .68199 .47796 .68777 .47618 .68694 .47519 Metetra
.664 .741 .907 r
.68694 .47519 .68777 .47618 .69356 .4744 .69273 .47341 Metetra
.664 .741 .907 r
.69273 .47341 .69356 .4744 .69935 .47262 .69853 .47162 Metetra
.664 .741 .907 r
.69853 .47162 .69935 .47262 .70517 .47083 .70435 .46983 Metetra
.664 .741 .907 r
.70435 .46983 .70517 .47083 .71099 .46904 .71017 .46804 Metetra
.664 .741 .907 r
.71017 .46804 .71099 .46904 .71682 .46724 .71601 .46624 Metetra
.664 .741 .907 r
.71601 .46624 .71682 .46724 .72267 .46545 .72186 .46444 Metetra
.664 .741 .907 r
.72186 .46444 .72267 .46545 .72853 .46364 .72772 .46264 Metetra
.664 .741 .907 r
.72772 .46264 .72853 .46364 .7344 .46184 .73359 .46083 Metetra
.664 .741 .907 r
.73359 .46083 .7344 .46184 .74028 .46003 .73948 .45902 Metetra
.664 .741 .907 r
.73948 .45902 .74028 .46003 .74617 .45822 .74537 .4572 Metetra
.664 .741 .907 r
.74537 .4572 .74617 .45822 .75208 .4564 .75128 .45539 Metetra
.664 .741 .907 r
.75128 .45539 .75208 .4564 .758 .45458 .7572 .45356 Metetra
.664 .741 .907 r
.7572 .45356 .758 .45458 .76393 .45276 .76314 .45174 Metetra
.664 .741 .907 r
.76314 .45174 .76393 .45276 .76988 .45093 .76908 .44991 Metetra
.664 .741 .907 r
.76908 .44991 .76988 .45093 .77583 .4491 .77504 .44807 Metetra
.664 .741 .907 r
.77504 .44807 .77583 .4491 .7818 .44726 .78101 .44624 Metetra
.664 .741 .907 r
.78101 .44624 .7818 .44726 .78778 .44542 .787 .44439 Metetra
.664 .741 .907 r
.787 .44439 .78778 .44542 .79377 .44358 .79299 .44255 Metetra
.664 .741 .907 r
.79299 .44255 .79377 .44358 .79978 .44173 .799 .4407 Metetra
.664 .741 .907 r
.799 .4407 .79978 .44173 .8058 .43988 .80502 .43885 Metetra
.664 .741 .907 r
.80502 .43885 .8058 .43988 .81183 .43803 .81106 .43699 Metetra
.664 .741 .907 r
.81106 .43699 .81183 .43803 .81787 .43617 .8171 .43513 Metetra
.664 .741 .907 r
.8171 .43513 .81787 .43617 .82393 .4343 .82316 .43326 Metetra
.664 .741 .907 r
.82316 .43326 .82393 .4343 .83 .43244 .82923 .4314 Metetra
.664 .741 .907 r
.82923 .4314 .83 .43244 .83608 .43057 .83532 .42952 Metetra
.664 .741 .907 r
.83532 .42952 .83608 .43057 .84217 .42869 .84141 .42765 Metetra
.664 .741 .907 r
.84141 .42765 .84217 .42869 .84828 .42682 .84752 .42577 Metetra
.664 .741 .907 r
.84752 .42577 .84828 .42682 .8544 .42493 .85365 .42388 Metetra
.664 .741 .907 r
.85365 .42388 .8544 .42493 .86053 .42305 .85978 .42199 Metetra
.664 .741 .907 r
.85978 .42199 .86053 .42305 .86668 .42116 .86593 .4201 Metetra
.664 .741 .907 r
.86593 .4201 .86668 .42116 .87283 .41926 .87209 .41821 Metetra
.664 .741 .907 r
.87209 .41821 .87283 .41926 .87901 .41737 .87826 .41631 Metetra
.664 .741 .907 r
.87826 .41631 .87901 .41737 .88519 .41546 .88445 .4144 Metetra
.664 .741 .907 r
.88445 .4144 .88519 .41546 .89139 .41356 .89065 .41249 Metetra
.664 .741 .907 r
.89065 .41249 .89139 .41356 .8976 .41165 .89687 .41058 Metetra
.664 .741 .907 r
.89687 .41058 .8976 .41165 .90382 .40973 .90309 .40866 Metetra
.664 .741 .907 r
.90309 .40866 .90382 .40973 .91006 .40781 .90933 .40674 Metetra
.664 .741 .907 r
.90933 .40674 .91006 .40781 .91631 .40589 .91559 .40482 Metetra
.664 .741 .907 r
.91559 .40482 .91631 .40589 .92257 .40397 .92185 .40289 Metetra
.664 .741 .907 r
.92185 .40289 .92257 .40397 .92885 .40204 .92813 .40096 Metetra
.664 .741 .907 r
.92813 .40096 .92885 .40204 .93514 .4001 .93443 .39902 Metetra
.664 .741 .907 r
.93443 .39902 .93514 .4001 .94144 .39816 .94073 .39708 Metetra
.664 .741 .907 r
.94073 .39708 .94144 .39816 .94776 .39622 .94705 .39513 Metetra
.664 .741 .907 r
.37448 .57017 .37543 .57106 .3806 .56947 .37965 .56858 Metetra
.664 .741 .907 r
.37965 .56858 .3806 .56947 .38578 .56788 .38483 .56699 Metetra
.664 .741 .907 r
.38483 .56699 .38578 .56788 .39097 .56628 .39002 .56539 Metetra
.664 .741 .907 r
.39002 .56539 .39097 .56628 .39617 .56468 .39522 .56378 Metetra
.664 .741 .907 r
.39522 .56378 .39617 .56468 .40138 .56308 .40044 .56218 Metetra
.664 .741 .907 r
.40044 .56218 .40138 .56308 .4066 .56147 .40566 .56057 Metetra
.664 .741 .907 r
.40566 .56057 .4066 .56147 .41183 .55986 .41089 .55896 Metetra
.664 .741 .907 r
.41089 .55896 .41183 .55986 .41707 .55825 .41613 .55735 Metetra
.664 .741 .907 r
.41613 .55735 .41707 .55825 .42232 .55663 .42138 .55573 Metetra
.664 .741 .907 r
.42138 .55573 .42232 .55663 .42758 .55501 .42665 .55411 Metetra
.664 .741 .907 r
.42665 .55411 .42758 .55501 .43285 .55339 .43192 .55248 Metetra
.664 .741 .907 r
.43192 .55248 .43285 .55339 .43813 .55176 .4372 .55086 Metetra
.664 .741 .907 r
.4372 .55086 .43813 .55176 .44342 .55014 .44249 .54923 Metetra
.236 .552 .931 r
.44249 .54923 .44342 .55014 .44817 .57272 .44772 .55092 Metetra
.593 .396 .584 r
.44772 .55092 .44817 .57272 .45401 .54793 .45311 .54596 Metetra
.645 .589 .777 r
.45311 .54596 .45401 .54793 .45936 .54523 .45844 .54432 Metetra
.664 .741 .907 r
.45844 .54432 .45936 .54523 .46469 .54359 .46377 .54267 Metetra
.664 .741 .907 r
.46377 .54267 .46469 .54359 .47003 .54194 .46912 .54103 Metetra
.664 .741 .907 r
.46912 .54103 .47003 .54194 .47539 .5403 .47447 .53938 Metetra
.664 .741 .907 r
.47447 .53938 .47539 .5403 .48075 .53865 .47984 .53772 Metetra
.664 .741 .907 r
.47984 .53772 .48075 .53865 .48613 .53699 .48522 .53607 Metetra
.664 .741 .907 r
.48522 .53607 .48613 .53699 .49151 .53533 .49061 .53441 Metetra
.664 .741 .907 r
.49061 .53441 .49151 .53533 .49691 .53367 .496 .53275 Metetra
.664 .741 .907 r
.496 .53275 .49691 .53367 .50232 .53201 .50141 .53108 Metetra
.664 .741 .907 r
.50141 .53108 .50232 .53201 .50773 .53034 .50683 .52941 Metetra
.664 .741 .907 r
.50683 .52941 .50773 .53034 .51316 .52867 .51226 .52774 Metetra
.664 .741 .907 r
.51226 .52774 .51316 .52867 .5186 .527 .5177 .52606 Metetra
.664 .741 .907 r
.5177 .52606 .5186 .527 .52405 .52532 .52316 .52438 Metetra
.664 .741 .907 r
.52316 .52438 .52405 .52532 .52951 .52364 .52862 .5227 Metetra
.957 .654 .415 r
.52862 .5227 .52951 .52364 .53498 .52196 .53425 .57618 Metetra
.446 .257 .529 r
.53425 .57618 .53498 .52196 .54047 .52027 .53958 .51933 Metetra
.664 .741 .907 r
.53958 .51933 .54047 .52027 .54596 .51858 .54507 .51763 Metetra
.664 .741 .907 r
.54507 .51763 .54596 .51858 .55146 .51688 .55058 .51594 Metetra
.664 .741 .907 r
.55058 .51594 .55146 .51688 .55698 .51519 .5561 .51424 Metetra
.664 .741 .907 r
.5561 .51424 .55698 .51519 .56251 .51348 .56163 .51253 Metetra
.664 .741 .907 r
.56163 .51253 .56251 .51348 .56804 .51178 .56717 .51083 Metetra
.664 .741 .907 r
.56717 .51083 .56804 .51178 .57359 .51007 .57272 .50912 Metetra
.664 .741 .907 r
.57272 .50912 .57359 .51007 .57915 .50836 .57828 .50741 Metetra
.664 .741 .907 r
.57828 .50741 .57915 .50836 .58486 .51418 .58385 .50569 Metetra
.594 .423 .62 r
.58385 .50569 .58486 .51418 .5919 .58631 .58944 .50397 Metetra
.572 .368 .565 r
.58944 .50397 .5919 .58631 .5959 .50321 .59503 .50225 Metetra
.664 .741 .907 r
.59503 .50225 .5959 .50321 .6015 .50148 .60064 .50052 Metetra
.664 .741 .907 r
.60064 .50052 .6015 .50148 .60712 .49975 .60626 .49879 Metetra
.664 .741 .907 r
.60626 .49879 .60712 .49975 .61274 .49802 .61189 .49706 Metetra
.664 .741 .907 r
.61189 .49706 .61274 .49802 .61838 .49629 .61753 .49532 Metetra
.664 .741 .907 r
.61753 .49532 .61838 .49629 .62403 .49455 .62318 .49358 Metetra
.664 .741 .907 r
.62318 .49358 .62403 .49455 .62969 .49281 .62884 .49183 Metetra
.664 .741 .907 r
.62884 .49183 .62969 .49281 .63537 .49106 .63452 .49009 Metetra
.664 .741 .907 r
.63452 .49009 .63537 .49106 .64105 .48931 .6402 .48833 Metetra
.664 .741 .907 r
.6402 .48833 .64105 .48931 .64675 .48756 .6459 .48658 Metetra
.664 .741 .907 r
.6459 .48658 .64675 .48756 .65245 .4858 .65161 .48482 Metetra
.664 .741 .907 r
.65161 .48482 .65245 .4858 .65817 .48404 .65733 .48306 Metetra
.664 .741 .907 r
.65733 .48306 .65817 .48404 .6639 .48228 .66307 .48129 Metetra
.664 .741 .907 r
.66307 .48129 .6639 .48228 .66965 .48051 .66881 .47952 Metetra
.664 .741 .907 r
.66881 .47952 .66965 .48051 .6754 .47874 .67457 .47775 Metetra
.664 .741 .907 r
.67457 .47775 .6754 .47874 .68117 .47697 .68034 .47597 Metetra
.664 .741 .907 r
.68034 .47597 .68117 .47697 .68694 .47519 .68612 .47419 Metetra
.664 .741 .907 r
.68612 .47419 .68694 .47519 .69273 .47341 .69191 .47241 Metetra
.664 .741 .907 r
.69191 .47241 .69273 .47341 .69853 .47162 .69771 .47062 Metetra
.664 .741 .907 r
.69771 .47062 .69853 .47162 .70435 .46983 .70353 .46883 Metetra
.664 .741 .907 r
.70353 .46883 .70435 .46983 .71017 .46804 .70935 .46704 Metetra
.664 .741 .907 r
.70935 .46704 .71017 .46804 .71601 .46624 .71519 .46524 Metetra
.664 .741 .907 r
.71519 .46524 .71601 .46624 .72186 .46444 .72104 .46344 Metetra
.664 .741 .907 r
.72104 .46344 .72186 .46444 .72772 .46264 .72691 .46163 Metetra
.664 .741 .907 r
.72691 .46163 .72772 .46264 .73359 .46083 .73278 .45982 Metetra
.664 .741 .907 r
.73278 .45982 .73359 .46083 .73948 .45902 .73867 .45801 Metetra
.664 .741 .907 r
.73867 .45801 .73948 .45902 .74537 .4572 .74457 .45619 Metetra
.664 .741 .907 r
.74457 .45619 .74537 .4572 .75128 .45539 .75048 .45437 Metetra
.664 .741 .907 r
.75048 .45437 .75128 .45539 .7572 .45356 .75641 .45254 Metetra
.606 .718 .924 r
.75641 .45254 .7572 .45356 .76314 .45174 .7624 .45154 Metetra
.641 .941 .96 r
.7624 .45154 .76314 .45174 .76908 .44991 .76829 .44888 Metetra
.664 .741 .907 r
.76829 .44888 .76908 .44991 .77504 .44807 .77425 .44705 Metetra
.664 .741 .907 r
.77425 .44705 .77504 .44807 .78101 .44624 .78023 .44521 Metetra
.664 .741 .907 r
.78023 .44521 .78101 .44624 .787 .44439 .78621 .44337 Metetra
.664 .741 .907 r
.78621 .44337 .787 .44439 .79299 .44255 .79221 .44152 Metetra
.664 .741 .907 r
.79221 .44152 .79299 .44255 .799 .4407 .79822 .43967 Metetra
.664 .741 .907 r
.79822 .43967 .799 .4407 .80502 .43885 .80425 .43781 Metetra
.664 .741 .907 r
.80425 .43781 .80502 .43885 .81106 .43699 .81028 .43595 Metetra
.664 .741 .907 r
.81028 .43595 .81106 .43699 .8171 .43513 .81633 .43409 Metetra
.664 .741 .907 r
.81633 .43409 .8171 .43513 .82316 .43326 .82239 .43222 Metetra
.664 .741 .907 r
.82239 .43222 .82316 .43326 .82923 .4314 .82847 .43035 Metetra
.664 .741 .907 r
.82847 .43035 .82923 .4314 .83532 .42952 .83455 .42848 Metetra
.664 .741 .907 r
.83455 .42848 .83532 .42952 .84141 .42765 .84065 .4266 Metetra
.664 .741 .907 r
.84065 .4266 .84141 .42765 .84752 .42577 .84677 .42472 Metetra
.664 .741 .907 r
.84677 .42472 .84752 .42577 .85365 .42388 .85289 .42283 Metetra
.664 .741 .907 r
.85289 .42283 .85365 .42388 .85978 .42199 .85903 .42094 Metetra
.664 .741 .907 r
.85903 .42094 .85978 .42199 .86593 .4201 .86518 .41904 Metetra
.664 .741 .907 r
.86518 .41904 .86593 .4201 .87209 .41821 .87134 .41715 Metetra
.664 .741 .907 r
.87134 .41715 .87209 .41821 .87826 .41631 .87752 .41524 Metetra
.664 .741 .907 r
.87752 .41524 .87826 .41631 .88445 .4144 .88371 .41334 Metetra
.664 .741 .907 r
.88371 .41334 .88445 .4144 .89065 .41249 .88992 .41143 Metetra
.664 .741 .907 r
.88992 .41143 .89065 .41249 .89687 .41058 .89613 .40951 Metetra
.664 .741 .907 r
.89613 .40951 .89687 .41058 .90309 .40866 .90236 .40759 Metetra
.664 .741 .907 r
.90236 .40759 .90309 .40866 .90933 .40674 .9086 .40567 Metetra
.664 .741 .907 r
.9086 .40567 .90933 .40674 .91559 .40482 .91486 .40374 Metetra
.664 .741 .907 r
.91486 .40374 .91559 .40482 .92185 .40289 .92113 .40181 Metetra
.664 .741 .907 r
.92113 .40181 .92185 .40289 .92813 .40096 .92741 .39988 Metetra
.664 .741 .907 r
.92741 .39988 .92813 .40096 .93443 .39902 .93371 .39794 Metetra
.664 .741 .907 r
.93371 .39794 .93443 .39902 .94073 .39708 .94002 .396 Metetra
.664 .741 .907 r
.94002 .396 .94073 .39708 .94705 .39513 .94634 .39405 Metetra
.664 .741 .907 r
.37353 .56929 .37448 .57017 .37965 .56858 .3787 .56769 Metetra
.664 .741 .907 r
.3787 .56769 .37965 .56858 .38483 .56699 .38388 .56609 Metetra
.664 .741 .907 r
.38388 .56609 .38483 .56699 .39002 .56539 .38908 .56449 Metetra
.664 .741 .907 r
.38908 .56449 .39002 .56539 .39522 .56378 .39428 .56289 Metetra
.664 .741 .907 r
.39428 .56289 .39522 .56378 .40044 .56218 .39949 .56128 Metetra
.664 .741 .907 r
.39949 .56128 .40044 .56218 .40566 .56057 .40472 .55967 Metetra
.664 .741 .907 r
.40472 .55967 .40566 .56057 .41089 .55896 .40995 .55806 Metetra
.664 .741 .907 r
.40995 .55806 .41089 .55896 .41613 .55735 .4152 .55644 Metetra
.664 .741 .907 r
.4152 .55644 .41613 .55735 .42138 .55573 .42045 .55482 Metetra
.664 .741 .907 r
.42045 .55482 .42138 .55573 .42665 .55411 .42571 .5532 Metetra
.664 .741 .907 r
.42571 .5532 .42665 .55411 .43192 .55248 .43099 .55158 Metetra
.664 .741 .907 r
.43099 .55158 .43192 .55248 .4372 .55086 .43627 .54995 Metetra
.629 .125 0 r
.43627 .54995 .4372 .55086 .44249 .54923 .44138 .55591 Metetra
.377 .142 .426 r
.44138 .55591 .44249 .54923 .44772 .55092 .44687 .54668 Metetra
.614 .479 .674 r
.44687 .54668 .44772 .55092 .45311 .54596 .45219 .54504 Metetra
.664 .741 .907 r
.45219 .54504 .45311 .54596 .45844 .54432 .45752 .5434 Metetra
.664 .741 .907 r
.45752 .5434 .45844 .54432 .46377 .54267 .46285 .54175 Metetra
.664 .741 .907 r
.46285 .54175 .46377 .54267 .46912 .54103 .4682 .54011 Metetra
.664 .741 .907 r
.4682 .54011 .46912 .54103 .47447 .53938 .47356 .53846 Metetra
.664 .741 .907 r
.47356 .53846 .47447 .53938 .47984 .53772 .47893 .5368 Metetra
.664 .741 .907 r
.47893 .5368 .47984 .53772 .48522 .53607 .48431 .53514 Metetra
.664 .741 .907 r
.48431 .53514 .48522 .53607 .49061 .53441 .4897 .53348 Metetra
.664 .741 .907 r
.4897 .53348 .49061 .53441 .496 .53275 .4951 .53182 Metetra
.664 .741 .907 r
.4951 .53182 .496 .53275 .50141 .53108 .50051 .53015 Metetra
.664 .741 .907 r
.50051 .53015 .50141 .53108 .50683 .52941 .50593 .52848 Metetra
.664 .741 .907 r
.50593 .52848 .50683 .52941 .51226 .52774 .51136 .5268 Metetra
.664 .741 .907 r
.51136 .5268 .51226 .52774 .5177 .52606 .51681 .52513 Metetra
.664 .741 .907 r
.51681 .52513 .5177 .52606 .52316 .52438 .52226 .52345 Metetra
.664 .741 .907 r
.52226 .52345 .52316 .52438 .52862 .5227 .52773 .52176 Metetra
.956 .678 .468 r
.52773 .52176 .52862 .5227 .53425 .57618 .53363 .69291 Metetra
.38 .208 .52 r
.53363 .69291 .53425 .57618 .53958 .51933 .5387 .52159 Metetra
.227 0 .193 r
.5387 .52159 .53958 .51933 .54507 .51763 .54419 .51669 Metetra
.664 .741 .907 r
.54419 .51669 .54507 .51763 .55058 .51594 .5497 .51499 Metetra
.664 .741 .907 r
.5497 .51499 .55058 .51594 .5561 .51424 .55522 .51329 Metetra
.664 .741 .907 r
.55522 .51329 .5561 .51424 .56163 .51253 .56075 .51158 Metetra
.664 .741 .907 r
.56075 .51158 .56163 .51253 .56717 .51083 .56629 .50988 Metetra
.664 .741 .907 r
.56629 .50988 .56717 .51083 .57272 .50912 .57184 .50816 Metetra
.664 .741 .907 r
.57184 .50816 .57272 .50912 .57828 .50741 .57741 .50645 Metetra
.664 .741 .907 r
.57741 .50645 .57828 .50741 .58385 .50569 .58298 .50473 Metetra
.664 .741 .907 r
.58298 .50473 .58385 .50569 .58944 .50397 .58857 .50301 Metetra
.664 .741 .907 r
.58857 .50301 .58944 .50397 .59503 .50225 .59417 .50128 Metetra
.664 .741 .907 r
.59417 .50128 .59503 .50225 .60064 .50052 .59977 .49956 Metetra
.664 .741 .907 r
.59977 .49956 .60064 .50052 .60626 .49879 .60539 .49782 Metetra
.664 .741 .907 r
.60539 .49782 .60626 .49879 .61189 .49706 .61103 .49609 Metetra
.664 .741 .907 r
.61103 .49609 .61189 .49706 .61753 .49532 .61667 .49435 Metetra
.664 .741 .907 r
.61667 .49435 .61753 .49532 .62318 .49358 .62232 .49261 Metetra
.664 .741 .907 r
.62232 .49261 .62318 .49358 .62884 .49183 .62799 .49086 Metetra
.664 .741 .907 r
.62799 .49086 .62884 .49183 .63452 .49009 .63367 .48911 Metetra
.664 .741 .907 r
.63367 .48911 .63452 .49009 .6402 .48833 .63936 .48736 Metetra
.664 .741 .907 r
.63936 .48736 .6402 .48833 .6459 .48658 .64506 .4856 Metetra
.664 .741 .907 r
.64506 .4856 .6459 .48658 .65161 .48482 .65077 .48384 Metetra
.664 .741 .907 r
.65077 .48384 .65161 .48482 .65733 .48306 .65649 .48207 Metetra
.664 .741 .907 r
.65649 .48207 .65733 .48306 .66307 .48129 .66223 .48031 Metetra
.664 .741 .907 r
.66223 .48031 .66307 .48129 .66881 .47952 .66798 .47854 Metetra
.664 .741 .907 r
.66798 .47854 .66881 .47952 .67457 .47775 .67373 .47676 Metetra
.664 .741 .907 r
.67373 .47676 .67457 .47775 .68034 .47597 .6795 .47498 Metetra
.664 .741 .907 r
.6795 .47498 .68034 .47597 .68612 .47419 .68529 .4732 Metetra
.664 .741 .907 r
.68529 .4732 .68612 .47419 .69191 .47241 .69108 .47141 Metetra
.664 .741 .907 r
.69108 .47141 .69191 .47241 .69771 .47062 .69689 .46962 Metetra
.664 .741 .907 r
.69689 .46962 .69771 .47062 .70353 .46883 .70271 .46783 Metetra
.664 .741 .907 r
.70271 .46783 .70353 .46883 .70935 .46704 .70854 .46603 Metetra
.664 .741 .907 r
.70854 .46603 .70935 .46704 .71519 .46524 .71438 .46423 Metetra
.664 .741 .907 r
.71438 .46423 .71519 .46524 .72104 .46344 .72023 .46243 Metetra
.664 .741 .907 r
.72023 .46243 .72104 .46344 .72691 .46163 .7261 .46062 Metetra
.664 .741 .907 r
.7261 .46062 .72691 .46163 .73278 .45982 .73198 .45881 Metetra
.664 .741 .907 r
.73198 .45881 .73278 .45982 .73867 .45801 .73787 .45699 Metetra
.664 .741 .907 r
.73787 .45699 .73867 .45801 .74457 .45619 .74377 .45518 Metetra
.664 .741 .907 r
.74377 .45518 .74457 .45619 .75048 .45437 .74968 .45335 Metetra
.664 .741 .907 r
.74968 .45335 .75048 .45437 .75641 .45254 .75561 .45153 Metetra
.968 .648 .334 r
.75561 .45153 .75641 .45254 .7624 .45154 .76768 .53447 Metetra
.461 .276 .542 r
.76768 .53447 .7624 .45154 .76829 .44888 .7675 .44786 Metetra
.664 .741 .907 r
.7675 .44786 .76829 .44888 .77425 .44705 .77346 .44602 Metetra
.664 .741 .907 r
.77346 .44602 .77425 .44705 .78023 .44521 .77944 .44418 Metetra
.664 .741 .907 r
.77944 .44418 .78023 .44521 .78621 .44337 .78543 .44234 Metetra
.664 .741 .907 r
.78543 .44234 .78621 .44337 .79221 .44152 .79143 .44049 Metetra
.664 .741 .907 r
.79143 .44049 .79221 .44152 .79822 .43967 .79744 .43863 Metetra
.664 .741 .907 r
.79744 .43863 .79822 .43967 .80425 .43781 .80347 .43677 Metetra
.664 .741 .907 r
.80347 .43677 .80425 .43781 .81028 .43595 .80951 .43491 Metetra
.664 .741 .907 r
.80951 .43491 .81028 .43595 .81633 .43409 .81556 .43305 Metetra
.664 .741 .907 r
.81556 .43305 .81633 .43409 .82239 .43222 .82162 .43118 Metetra
.664 .741 .907 r
.82162 .43118 .82239 .43222 .82847 .43035 .8277 .42931 Metetra
.664 .741 .907 r
.8277 .42931 .82847 .43035 .83455 .42848 .83379 .42743 Metetra
.664 .741 .907 r
.83379 .42743 .83455 .42848 .84065 .4266 .83989 .42555 Metetra
.664 .741 .907 r
.83989 .42555 .84065 .4266 .84677 .42472 .84601 .42366 Metetra
.664 .741 .907 r
.84601 .42366 .84677 .42472 .85289 .42283 .85214 .42178 Metetra
.664 .741 .907 r
.85214 .42178 .85289 .42283 .85903 .42094 .85828 .41988 Metetra
.664 .741 .907 r
.85828 .41988 .85903 .42094 .86518 .41904 .86443 .41799 Metetra
.664 .741 .907 r
.86443 .41799 .86518 .41904 .87134 .41715 .8706 .41609 Metetra
.664 .741 .907 r
.8706 .41609 .87134 .41715 .87752 .41524 .87678 .41418 Metetra
.664 .741 .907 r
.87678 .41418 .87752 .41524 .88371 .41334 .88297 .41227 Metetra
.664 .741 .907 r
.88297 .41227 .88371 .41334 .88992 .41143 .88918 .41036 Metetra
.664 .741 .907 r
.88918 .41036 .88992 .41143 .89613 .40951 .8954 .40844 Metetra
.664 .741 .907 r
.8954 .40844 .89613 .40951 .90236 .40759 .90163 .40652 Metetra
.664 .741 .907 r
.90163 .40652 .90236 .40759 .9086 .40567 .90788 .4046 Metetra
.664 .741 .907 r
.90788 .4046 .9086 .40567 .91486 .40374 .91413 .40267 Metetra
.664 .741 .907 r
.91413 .40267 .91486 .40374 .92113 .40181 .92041 .40073 Metetra
.664 .741 .907 r
.92041 .40073 .92113 .40181 .92741 .39988 .92669 .3988 Metetra
.664 .741 .907 r
.92669 .3988 .92741 .39988 .93371 .39794 .93299 .39686 Metetra
.664 .741 .907 r
.93299 .39686 .93371 .39794 .94002 .396 .9393 .39491 Metetra
.664 .741 .907 r
.9393 .39491 .94002 .396 .94634 .39405 .94563 .39296 Metetra
.664 .741 .907 r
.37258 .5684 .37353 .56929 .3787 .56769 .37775 .5668 Metetra
.664 .741 .907 r
.37775 .5668 .3787 .56769 .38388 .56609 .38294 .5652 Metetra
.664 .741 .907 r
.38294 .5652 .38388 .56609 .38908 .56449 .38813 .5636 Metetra
.664 .741 .907 r
.38813 .5636 .38908 .56449 .39428 .56289 .39334 .56199 Metetra
.664 .741 .907 r
.39334 .56199 .39428 .56289 .39949 .56128 .39855 .56039 Metetra
.664 .741 .907 r
.39855 .56039 .39949 .56128 .40472 .55967 .40378 .55877 Metetra
.664 .741 .907 r
.40378 .55877 .40472 .55967 .40995 .55806 .40901 .55716 Metetra
.664 .741 .907 r
.40901 .55716 .40995 .55806 .4152 .55644 .41426 .55554 Metetra
.664 .741 .907 r
.41426 .55554 .4152 .55644 .42045 .55482 .41951 .55392 Metetra
.664 .741 .907 r
.41951 .55392 .42045 .55482 .42571 .5532 .42478 .5523 Metetra
.664 .741 .907 r
.42478 .5523 .42571 .5532 .43099 .55158 .43006 .55067 Metetra
.664 .741 .907 r
.43006 .55067 .43099 .55158 .43627 .54995 .43534 .54904 Metetra
.664 .741 .907 r
.43534 .54904 .43627 .54995 .44138 .55591 .44064 .5474 Metetra
.593 .422 .619 r
.44064 .5474 .44138 .55591 .44687 .54668 .44595 .54577 Metetra
.664 .741 .907 r
.44595 .54577 .44687 .54668 .45219 .54504 .45127 .54413 Metetra
.664 .741 .907 r
.45127 .54413 .45219 .54504 .45752 .5434 .4566 .54248 Metetra
.664 .741 .907 r
.4566 .54248 .45752 .5434 .46285 .54175 .46194 .54084 Metetra
.664 .741 .907 r
.46194 .54084 .46285 .54175 .4682 .54011 .46729 .53919 Metetra
.664 .741 .907 r
.46729 .53919 .4682 .54011 .47356 .53846 .47265 .53753 Metetra
.664 .741 .907 r
.47265 .53753 .47356 .53846 .47893 .5368 .47802 .53588 Metetra
.664 .741 .907 r
.47802 .53588 .47893 .5368 .48431 .53514 .4834 .53422 Metetra
.664 .741 .907 r
.4834 .53422 .48431 .53514 .4897 .53348 .48879 .53255 Metetra
.664 .741 .907 r
.48879 .53255 .4897 .53348 .4951 .53182 .49419 .53089 Metetra
.664 .741 .907 r
.49419 .53089 .4951 .53182 .50051 .53015 .49961 .52922 Metetra
.664 .741 .907 r
.49961 .52922 .50051 .53015 .50593 .52848 .50503 .52754 Metetra
.664 .741 .907 r
.50503 .52754 .50593 .52848 .51136 .5268 .51046 .52587 Metetra
.664 .741 .907 r
.51046 .52587 .51136 .5268 .51681 .52513 .51591 .52419 Metetra
.664 .741 .907 r
.51591 .52419 .51681 .52513 .52226 .52345 .52137 .52251 Metetra
.956 .677 .467 r
.52137 .52251 .52226 .52345 .52773 .52176 .52692 .67592 Metetra
.602 .384 .558 r
.52692 .67592 .52773 .52176 .53363 .69291 .5328 .73725 Metetra
0 0 .116 r
.5328 .73725 .53363 .69291 .5387 .52159 .5378 .51744 Metetra
.615 .483 .678 r
.5378 .51744 .5387 .52159 .54419 .51669 .5433 .51574 Metetra
.664 .741 .907 r
.5433 .51574 .54419 .51669 .5497 .51499 .54881 .51404 Metetra
.664 .741 .907 r
.54881 .51404 .5497 .51499 .55522 .51329 .55433 .51234 Metetra
.664 .741 .907 r
.55433 .51234 .55522 .51329 .56075 .51158 .55987 .51063 Metetra
.664 .741 .907 r
.55987 .51063 .56075 .51158 .56629 .50988 .56541 .50892 Metetra
.664 .741 .907 r
.56541 .50892 .56629 .50988 .57184 .50816 .57097 .50721 Metetra
.664 .741 .907 r
.57097 .50721 .57184 .50816 .57741 .50645 .57653 .50549 Metetra
.664 .741 .907 r
.57653 .50549 .57741 .50645 .58298 .50473 .58211 .50377 Metetra
.664 .741 .907 r
.58211 .50377 .58298 .50473 .58857 .50301 .5877 .50205 Metetra
.664 .741 .907 r
.5877 .50205 .58857 .50301 .59417 .50128 .5933 .50032 Metetra
.664 .741 .907 r
.5933 .50032 .59417 .50128 .59977 .49956 .59891 .49859 Metetra
.664 .741 .907 r
.59891 .49859 .59977 .49956 .60539 .49782 .60453 .49686 Metetra
.664 .741 .907 r
.60453 .49686 .60539 .49782 .61103 .49609 .61017 .49512 Metetra
.664 .741 .907 r
.61017 .49512 .61103 .49609 .61667 .49435 .61581 .49338 Metetra
.664 .741 .907 r
.61581 .49338 .61667 .49435 .62232 .49261 .62147 .49163 Metetra
.664 .741 .907 r
.62147 .49163 .62232 .49261 .62799 .49086 .62714 .48988 Metetra
.664 .741 .907 r
.62714 .48988 .62799 .49086 .63367 .48911 .63282 .48813 Metetra
.664 .741 .907 r
.63282 .48813 .63367 .48911 .63936 .48736 .63851 .48638 Metetra
.664 .741 .907 r
.63851 .48638 .63936 .48736 .64506 .4856 .64421 .48462 Metetra
.664 .741 .907 r
.64421 .48462 .64506 .4856 .65077 .48384 .64993 .48285 Metetra
.664 .741 .907 r
.64993 .48285 .65077 .48384 .65649 .48207 .65565 .48109 Metetra
.664 .741 .907 r
.65565 .48109 .65649 .48207 .66223 .48031 .66139 .47932 Metetra
.664 .741 .907 r
.66139 .47932 .66223 .48031 .66798 .47854 .66714 .47755 Metetra
.664 .741 .907 r
.66714 .47755 .66798 .47854 .67373 .47676 .6729 .47577 Metetra
.664 .741 .907 r
.6729 .47577 .67373 .47676 .6795 .47498 .67867 .47399 Metetra
.664 .741 .907 r
.67867 .47399 .6795 .47498 .68529 .4732 .68446 .4722 Metetra
.664 .741 .907 r
.68446 .4722 .68529 .4732 .69108 .47141 .69025 .47042 Metetra
.664 .741 .907 r
.69025 .47042 .69108 .47141 .69689 .46962 .69606 .46862 Metetra
.664 .741 .907 r
.69606 .46862 .69689 .46962 .70271 .46783 .70188 .46683 Metetra
.664 .741 .907 r
.70188 .46683 .70271 .46783 .70854 .46603 .70772 .46503 Metetra
.664 .741 .907 r
.70772 .46503 .70854 .46603 .71438 .46423 .71356 .46323 Metetra
.664 .741 .907 r
.71356 .46323 .71438 .46423 .72023 .46243 .71942 .46142 Metetra
.664 .741 .907 r
.71942 .46142 .72023 .46243 .7261 .46062 .72529 .45961 Metetra
.664 .741 .907 r
.72529 .45961 .7261 .46062 .73198 .45881 .73117 .4578 Metetra
.664 .741 .907 r
.73117 .4578 .73198 .45881 .73787 .45699 .73706 .45598 Metetra
.664 .741 .907 r
.73706 .45598 .73787 .45699 .74377 .45518 .74296 .45416 Metetra
.836 .408 0 r
.74296 .45416 .74377 .45518 .74968 .45335 .75003 .46917 Metetra
.44 .238 .508 r
.75003 .46917 .74968 .45335 .75561 .45153 .75481 .45051 Metetra
.928 .552 .16 r
.75481 .45051 .75561 .45153 .76768 .53447 .7628 .47712 Metetra
.615 .401 .568 r
.7628 .47712 .76768 .53447 .7675 .44786 .76671 .44684 Metetra
.664 .741 .907 r
.76671 .44684 .7675 .44786 .77346 .44602 .77267 .445 Metetra
.664 .741 .907 r
.77267 .445 .77346 .44602 .77944 .44418 .77865 .44315 Metetra
.664 .741 .907 r
.77865 .44315 .77944 .44418 .78543 .44234 .78464 .4413 Metetra
.664 .741 .907 r
.78464 .4413 .78543 .44234 .79143 .44049 .79065 .43945 Metetra
.664 .741 .907 r
.79065 .43945 .79143 .44049 .79744 .43863 .79666 .4376 Metetra
.664 .741 .907 r
.79666 .4376 .79744 .43863 .80347 .43677 .80269 .43574 Metetra
.664 .741 .907 r
.80269 .43574 .80347 .43677 .80951 .43491 .80873 .43387 Metetra
.664 .741 .907 r
.80873 .43387 .80951 .43491 .81556 .43305 .81479 .43201 Metetra
.664 .741 .907 r
.81479 .43201 .81556 .43305 .82162 .43118 .82085 .43014 Metetra
.664 .741 .907 r
.82085 .43014 .82162 .43118 .8277 .42931 .82693 .42826 Metetra
.664 .741 .907 r
.82693 .42826 .8277 .42931 .83379 .42743 .83303 .42638 Metetra
.664 .741 .907 r
.83303 .42638 .83379 .42743 .83989 .42555 .83913 .4245 Metetra
.664 .741 .907 r
.83913 .4245 .83989 .42555 .84601 .42366 .84525 .42261 Metetra
.664 .741 .907 r
.84525 .42261 .84601 .42366 .85214 .42178 .85138 .42072 Metetra
.664 .741 .907 r
.85138 .42072 .85214 .42178 .85828 .41988 .85752 .41883 Metetra
.664 .741 .907 r
.85752 .41883 .85828 .41988 .86443 .41799 .86368 .41693 Metetra
.664 .741 .907 r
.86368 .41693 .86443 .41799 .8706 .41609 .86985 .41502 Metetra
.664 .741 .907 r
.86985 .41502 .8706 .41609 .87678 .41418 .87603 .41312 Metetra
.664 .741 .907 r
.87603 .41312 .87678 .41418 .88297 .41227 .88223 .41121 Metetra
.664 .741 .907 r
.88223 .41121 .88297 .41227 .88918 .41036 .88844 .40929 Metetra
.664 .741 .907 r
.88844 .40929 .88918 .41036 .8954 .40844 .89466 .40737 Metetra
.664 .741 .907 r
.89466 .40737 .8954 .40844 .90163 .40652 .9009 .40545 Metetra
.664 .741 .907 r
.9009 .40545 .90163 .40652 .90788 .4046 .90715 .40352 Metetra
.664 .741 .907 r
.90715 .40352 .90788 .4046 .91413 .40267 .91341 .40159 Metetra
.664 .741 .907 r
.91341 .40159 .91413 .40267 .92041 .40073 .91968 .39965 Metetra
.664 .741 .907 r
.91968 .39965 .92041 .40073 .92669 .3988 .92597 .39771 Metetra
.664 .741 .907 r
.92597 .39771 .92669 .3988 .93299 .39686 .93227 .39577 Metetra
.664 .741 .907 r
.93227 .39577 .93299 .39686 .9393 .39491 .93859 .39382 Metetra
.664 .741 .907 r
.93859 .39382 .9393 .39491 .94563 .39296 .94492 .39187 Metetra
.664 .741 .907 r
.37162 .56751 .37258 .5684 .37775 .5668 .3768 .56591 Metetra
.664 .741 .907 r
.3768 .56591 .37775 .5668 .38294 .5652 .38199 .56431 Metetra
.664 .741 .907 r
.38199 .56431 .38294 .5652 .38813 .5636 .38718 .5627 Metetra
.664 .741 .907 r
.38718 .5627 .38813 .5636 .39334 .56199 .39239 .5611 Metetra
.664 .741 .907 r
.39239 .5611 .39334 .56199 .39855 .56039 .39761 .55949 Metetra
.664 .741 .907 r
.39761 .55949 .39855 .56039 .40378 .55877 .40284 .55787 Metetra
.664 .741 .907 r
.40284 .55787 .40378 .55877 .40901 .55716 .40807 .55626 Metetra
.664 .741 .907 r
.40807 .55626 .40901 .55716 .41426 .55554 .41332 .55464 Metetra
.664 .741 .907 r
.41332 .55464 .41426 .55554 .41951 .55392 .41858 .55301 Metetra
.664 .741 .907 r
.41858 .55301 .41951 .55392 .42478 .5523 .42385 .55139 Metetra
.664 .741 .907 r
.42385 .55139 .42478 .5523 .43006 .55067 .42913 .54976 Metetra
.664 .741 .907 r
.42913 .54976 .43006 .55067 .43534 .54904 .43442 .54813 Metetra
.664 .741 .907 r
.43442 .54813 .43534 .54904 .44064 .5474 .43971 .54649 Metetra
.664 .741 .907 r
.43971 .54649 .44064 .5474 .44595 .54577 .44502 .54485 Metetra
.664 .741 .907 r
.44502 .54485 .44595 .54577 .45127 .54413 .45034 .54321 Metetra
.664 .741 .907 r
.45034 .54321 .45127 .54413 .4566 .54248 .45567 .54156 Metetra
.664 .741 .907 r
.45567 .54156 .4566 .54248 .46194 .54084 .46102 .53992 Metetra
.664 .741 .907 r
.46102 .53992 .46194 .54084 .46729 .53919 .46637 .53826 Metetra
.664 .741 .907 r
.46637 .53826 .46729 .53919 .47265 .53753 .47173 .53661 Metetra
.664 .741 .907 r
.47173 .53661 .47265 .53753 .47802 .53588 .4771 .53495 Metetra
.664 .741 .907 r
.4771 .53495 .47802 .53588 .4834 .53422 .48249 .53329 Metetra
.664 .741 .907 r
.48249 .53329 .4834 .53422 .48879 .53255 .48788 .53162 Metetra
.664 .741 .907 r
.48788 .53162 .48879 .53255 .49419 .53089 .49328 .52996 Metetra
.664 .741 .907 r
.49328 .52996 .49419 .53089 .49961 .52922 .4987 .52828 Metetra
.664 .741 .907 r
.4987 .52828 .49961 .52922 .50503 .52754 .50413 .52661 Metetra
.664 .741 .907 r
.50413 .52661 .50503 .52754 .51046 .52587 .50956 .52493 Metetra
.664 .741 .907 r
.50956 .52493 .51046 .52587 .51591 .52419 .51501 .52325 Metetra
.664 .741 .907 r
.51501 .52325 .51591 .52419 .52137 .52251 .52047 .52157 Metetra
.956 .674 .462 r
.52047 .52157 .52137 .52251 .52692 .67592 .52598 .64877 Metetra
.675 .457 .582 r
.52598 .64877 .52692 .67592 .5328 .73725 .5316 .61176 Metetra
.636 .417 .568 r
.5316 .61176 .5328 .73725 .5378 .51744 .53691 .51649 Metetra
.664 .741 .907 r
.53691 .51649 .5378 .51744 .5433 .51574 .54241 .51479 Metetra
.664 .741 .907 r
.54241 .51479 .5433 .51574 .54881 .51404 .54793 .51309 Metetra
.664 .741 .907 r
.54793 .51309 .54881 .51404 .55433 .51234 .55345 .51139 Metetra
.664 .741 .907 r
.55345 .51139 .55433 .51234 .55987 .51063 .55898 .50968 Metetra
.664 .741 .907 r
.55898 .50968 .55987 .51063 .56541 .50892 .56453 .50797 Metetra
.664 .741 .907 r
.56453 .50797 .56541 .50892 .57097 .50721 .57009 .50625 Metetra
.664 .741 .907 r
.57009 .50625 .57097 .50721 .57653 .50549 .57566 .50453 Metetra
.664 .741 .907 r
.57566 .50453 .57653 .50549 .58211 .50377 .58124 .50281 Metetra
.664 .741 .907 r
.58124 .50281 .58211 .50377 .5877 .50205 .58683 .50108 Metetra
.664 .741 .907 r
.58683 .50108 .5877 .50205 .5933 .50032 .59243 .49936 Metetra
.664 .741 .907 r
.59243 .49936 .5933 .50032 .59891 .49859 .59804 .49762 Metetra
.664 .741 .907 r
.59804 .49762 .59891 .49859 .60453 .49686 .60367 .49589 Metetra
.664 .741 .907 r
.60367 .49589 .60453 .49686 .61017 .49512 .60931 .49415 Metetra
.664 .741 .907 r
.60931 .49415 .61017 .49512 .61581 .49338 .61495 .4924 Metetra
.664 .741 .907 r
.61495 .4924 .61581 .49338 .62147 .49163 .62061 .49066 Metetra
.664 .741 .907 r
.62061 .49066 .62147 .49163 .62714 .48988 .62628 .48891 Metetra
.664 .741 .907 r
.62628 .48891 .62714 .48988 .63282 .48813 .63196 .48715 Metetra
.664 .741 .907 r
.63196 .48715 .63282 .48813 .63851 .48638 .63766 .4854 Metetra
.664 .741 .907 r
.63766 .4854 .63851 .48638 .64421 .48462 .64336 .48363 Metetra
.664 .741 .907 r
.64336 .48363 .64421 .48462 .64993 .48285 .64908 .48187 Metetra
.664 .741 .907 r
.64908 .48187 .64993 .48285 .65565 .48109 .65481 .4801 Metetra
.664 .741 .907 r
.65481 .4801 .65565 .48109 .66139 .47932 .66055 .47833 Metetra
.664 .741 .907 r
.66055 .47833 .66139 .47932 .66714 .47755 .6663 .47655 Metetra
.664 .741 .907 r
.6663 .47655 .66714 .47755 .6729 .47577 .67206 .47478 Metetra
.664 .741 .907 r
.67206 .47478 .6729 .47577 .67867 .47399 .67784 .47299 Metetra
.664 .741 .907 r
.67784 .47299 .67867 .47399 .68446 .4722 .68363 .47121 Metetra
.664 .741 .907 r
.68363 .47121 .68446 .4722 .69025 .47042 .68943 .46942 Metetra
.664 .741 .907 r
.68943 .46942 .69025 .47042 .69606 .46862 .69524 .46762 Metetra
.664 .741 .907 r
.69524 .46762 .69606 .46862 .70188 .46683 .70106 .46583 Metetra
.664 .741 .907 r
.70106 .46583 .70188 .46683 .70772 .46503 .7069 .46403 Metetra
.664 .741 .907 r
.7069 .46403 .70772 .46503 .71356 .46323 .71274 .46222 Metetra
.664 .741 .907 r
.71274 .46222 .71356 .46323 .71942 .46142 .7186 .46041 Metetra
.664 .741 .907 r
.7186 .46041 .71942 .46142 .72529 .45961 .72447 .4586 Metetra
.664 .741 .907 r
.72447 .4586 .72529 .45961 .73117 .4578 .73036 .45678 Metetra
.664 .741 .907 r
.73036 .45678 .73117 .4578 .73706 .45598 .73625 .45496 Metetra
.664 .741 .907 r
.73625 .45496 .73706 .45598 .74296 .45416 .74216 .45314 Metetra
.664 .741 .907 r
.74216 .45314 .74296 .45416 .75003 .46917 .74808 .45131 Metetra
.396 .258 .574 r
.74808 .45131 .75003 .46917 .75481 .45051 .75611 .47941 Metetra
.452 .259 .527 r
.75611 .47941 .75481 .45051 .7628 .47712 .75995 .44765 Metetra
.576 .379 .577 r
.75995 .44765 .7628 .47712 .76671 .44684 .76591 .44581 Metetra
.664 .741 .907 r
.76591 .44581 .76671 .44684 .77267 .445 .77188 .44397 Metetra
.664 .741 .907 r
.77188 .44397 .77267 .445 .77865 .44315 .77786 .44212 Metetra
.664 .741 .907 r
.77786 .44212 .77865 .44315 .78464 .4413 .78386 .44027 Metetra
.664 .741 .907 r
.78386 .44027 .78464 .4413 .79065 .43945 .78986 .43842 Metetra
.664 .741 .907 r
.78986 .43842 .79065 .43945 .79666 .4376 .79588 .43656 Metetra
.664 .741 .907 r
.79588 .43656 .79666 .4376 .80269 .43574 .80191 .4347 Metetra
.664 .741 .907 r
.80191 .4347 .80269 .43574 .80873 .43387 .80796 .43283 Metetra
.664 .741 .907 r
.80796 .43283 .80873 .43387 .81479 .43201 .81401 .43096 Metetra
.664 .741 .907 r
.81401 .43096 .81479 .43201 .82085 .43014 .82008 .42909 Metetra
.664 .741 .907 r
.82008 .42909 .82085 .43014 .82693 .42826 .82617 .42721 Metetra
.664 .741 .907 r
.82617 .42721 .82693 .42826 .83303 .42638 .83226 .42533 Metetra
.664 .741 .907 r
.83226 .42533 .83303 .42638 .83913 .4245 .83837 .42345 Metetra
.664 .741 .907 r
.83837 .42345 .83913 .4245 .84525 .42261 .84449 .42156 Metetra
.664 .741 .907 r
.84449 .42156 .84525 .42261 .85138 .42072 .85062 .41966 Metetra
.664 .741 .907 r
.85062 .41966 .85138 .42072 .85752 .41883 .85677 .41777 Metetra
.664 .741 .907 r
.85677 .41777 .85752 .41883 .86368 .41693 .86293 .41587 Metetra
.664 .741 .907 r
.86293 .41587 .86368 .41693 .86985 .41502 .8691 .41396 Metetra
.664 .741 .907 r
.8691 .41396 .86985 .41502 .87603 .41312 .87529 .41205 Metetra
.664 .741 .907 r
.87529 .41205 .87603 .41312 .88223 .41121 .88149 .41014 Metetra
.664 .741 .907 r
.88149 .41014 .88223 .41121 .88844 .40929 .8877 .40822 Metetra
.664 .741 .907 r
.8877 .40822 .88844 .40929 .89466 .40737 .89392 .4063 Metetra
.664 .741 .907 r
.89392 .4063 .89466 .40737 .9009 .40545 .90016 .40437 Metetra
.664 .741 .907 r
.90016 .40437 .9009 .40545 .90715 .40352 .90641 .40244 Metetra
.664 .741 .907 r
.90641 .40244 .90715 .40352 .91341 .40159 .91268 .40051 Metetra
.664 .741 .907 r
.91268 .40051 .91341 .40159 .91968 .39965 .91896 .39857 Metetra
.664 .741 .907 r
.91896 .39857 .91968 .39965 .92597 .39771 .92525 .39663 Metetra
.664 .741 .907 r
.92525 .39663 .92597 .39771 .93227 .39577 .93155 .39468 Metetra
.664 .741 .907 r
.93155 .39468 .93227 .39577 .93859 .39382 .93787 .39273 Metetra
.664 .741 .907 r
.93787 .39273 .93859 .39382 .94492 .39187 .94421 .39078 Metetra
.664 .741 .907 r
.37067 .56662 .37162 .56751 .3768 .56591 .37585 .56502 Metetra
.664 .741 .907 r
.37585 .56502 .3768 .56591 .38199 .56431 .38104 .56341 Metetra
.664 .741 .907 r
.38104 .56341 .38199 .56431 .38718 .5627 .38624 .56181 Metetra
.664 .741 .907 r
.38624 .56181 .38718 .5627 .39239 .5611 .39144 .5602 Metetra
.664 .741 .907 r
.39144 .5602 .39239 .5611 .39761 .55949 .39666 .55859 Metetra
.664 .741 .907 r
.39666 .55859 .39761 .55949 .40284 .55787 .40189 .55697 Metetra
.664 .741 .907 r
.40189 .55697 .40284 .55787 .40807 .55626 .40713 .55535 Metetra
.664 .741 .907 r
.40713 .55535 .40807 .55626 .41332 .55464 .41238 .55373 Metetra
.793 .316 0 r
.41238 .55373 .41332 .55464 .41858 .55301 .41735 .56147 Metetra
.389 .164 .447 r
.41735 .56147 .41858 .55301 .42385 .55139 .42291 .55048 Metetra
.664 .741 .907 r
.42291 .55048 .42385 .55139 .42913 .54976 .42819 .54885 Metetra
.664 .741 .907 r
.42819 .54885 .42913 .54976 .43442 .54813 .43348 .54721 Metetra
.664 .741 .907 r
.43348 .54721 .43442 .54813 .43971 .54649 .43879 .54558 Metetra
.664 .741 .907 r
.43879 .54558 .43971 .54649 .44502 .54485 .4441 .54394 Metetra
.664 .741 .907 r
.4441 .54394 .44502 .54485 .45034 .54321 .44942 .54229 Metetra
.664 .741 .907 r
.44942 .54229 .45034 .54321 .45567 .54156 .45475 .54065 Metetra
.664 .741 .907 r
.45475 .54065 .45567 .54156 .46102 .53992 .4601 .539 Metetra
.664 .741 .907 r
.4601 .539 .46102 .53992 .46637 .53826 .46545 .53734 Metetra
.664 .741 .907 r
.46545 .53734 .46637 .53826 .47173 .53661 .47081 .53568 Metetra
.664 .741 .907 r
.47081 .53568 .47173 .53661 .4771 .53495 .47619 .53402 Metetra
.664 .741 .907 r
.47619 .53402 .4771 .53495 .48249 .53329 .48157 .53236 Metetra
.664 .741 .907 r
.48157 .53236 .48249 .53329 .48788 .53162 .48697 .53069 Metetra
.664 .741 .907 r
.48697 .53069 .48788 .53162 .49328 .52996 .49238 .52902 Metetra
.664 .741 .907 r
.49238 .52902 .49328 .52996 .4987 .52828 .49779 .52735 Metetra
.664 .741 .907 r
.49779 .52735 .4987 .52828 .50413 .52661 .50322 .52567 Metetra
.664 .741 .907 r
.50322 .52567 .50413 .52661 .50956 .52493 .50866 .52399 Metetra
.664 .741 .907 r
.50866 .52399 .50956 .52493 .51501 .52325 .51411 .52231 Metetra
.664 .741 .907 r
.51411 .52231 .51501 .52325 .52047 .52157 .51957 .52062 Metetra
.957 .655 .419 r
.51957 .52062 .52047 .52157 .52598 .64877 .52505 .57585 Metetra
.593 .384 .567 r
.52505 .57585 .52598 .64877 .5316 .61176 .53059 .55772 Metetra
.636 .42 .573 r
.53059 .55772 .5316 .61176 .53691 .51649 .53602 .51554 Metetra
.664 .741 .907 r
.53602 .51554 .53691 .51649 .54241 .51479 .54152 .51384 Metetra
.664 .741 .907 r
.54152 .51384 .54241 .51479 .54793 .51309 .54704 .51214 Metetra
.664 .741 .907 r
.54704 .51214 .54793 .51309 .55345 .51139 .55256 .51043 Metetra
.664 .741 .907 r
.55256 .51043 .55345 .51139 .55898 .50968 .5581 .50872 Metetra
.664 .741 .907 r
.5581 .50872 .55898 .50968 .56453 .50797 .56365 .50701 Metetra
.664 .741 .907 r
.56365 .50701 .56453 .50797 .57009 .50625 .56921 .50529 Metetra
.664 .741 .907 r
.56921 .50529 .57009 .50625 .57566 .50453 .57478 .50357 Metetra
.664 .741 .907 r
.57478 .50357 .57566 .50453 .58124 .50281 .58036 .50185 Metetra
.664 .741 .907 r
.58036 .50185 .58124 .50281 .58683 .50108 .58596 .50012 Metetra
.664 .741 .907 r
.58596 .50012 .58683 .50108 .59243 .49936 .59156 .49839 Metetra
.664 .741 .907 r
.59156 .49839 .59243 .49936 .59804 .49762 .59718 .49665 Metetra
.664 .741 .907 r
.59718 .49665 .59804 .49762 .60367 .49589 .6028 .49492 Metetra
.664 .741 .907 r
.6028 .49492 .60367 .49589 .60931 .49415 .60844 .49317 Metetra
.664 .741 .907 r
.60844 .49317 .60931 .49415 .61495 .4924 .61409 .49143 Metetra
.664 .741 .907 r
.61409 .49143 .61495 .4924 .62061 .49066 .61975 .48968 Metetra
.664 .741 .907 r
.61975 .48968 .62061 .49066 .62628 .48891 .62543 .48793 Metetra
.664 .741 .907 r
.62543 .48793 .62628 .48891 .63196 .48715 .63111 .48617 Metetra
.664 .741 .907 r
.63111 .48617 .63196 .48715 .63766 .4854 .63681 .48441 Metetra
.664 .741 .907 r
.63681 .48441 .63766 .4854 .64336 .48363 .64252 .48265 Metetra
.664 .741 .907 r
.64252 .48265 .64336 .48363 .64908 .48187 .64823 .48088 Metetra
.664 .741 .907 r
.64823 .48088 .64908 .48187 .65481 .4801 .65397 .47911 Metetra
.664 .741 .907 r
.65397 .47911 .65481 .4801 .66055 .47833 .65971 .47734 Metetra
.664 .741 .907 r
.65971 .47734 .66055 .47833 .6663 .47655 .66546 .47556 Metetra
.664 .741 .907 r
.66546 .47556 .6663 .47655 .67206 .47478 .67123 .47378 Metetra
.664 .741 .907 r
.67123 .47378 .67206 .47478 .67784 .47299 .67701 .472 Metetra
.664 .741 .907 r
.67701 .472 .67784 .47299 .68363 .47121 .6828 .47021 Metetra
.664 .741 .907 r
.6828 .47021 .68363 .47121 .68943 .46942 .6886 .46842 Metetra
.664 .741 .907 r
.6886 .46842 .68943 .46942 .69524 .46762 .69441 .46662 Metetra
.664 .741 .907 r
.69441 .46662 .69524 .46762 .70106 .46583 .70024 .46482 Metetra
.664 .741 .907 r
.70024 .46482 .70106 .46583 .7069 .46403 .70607 .46302 Metetra
.664 .741 .907 r
.70607 .46302 .7069 .46403 .71274 .46222 .71192 .46121 Metetra
.664 .741 .907 r
.71192 .46121 .71274 .46222 .7186 .46041 .71778 .4594 Metetra
.664 .741 .907 r
.71778 .4594 .7186 .46041 .72447 .4586 .72366 .45759 Metetra
.664 .741 .907 r
.72366 .45759 .72447 .4586 .73036 .45678 .72954 .45577 Metetra
.664 .741 .907 r
.72954 .45577 .73036 .45678 .73625 .45496 .73544 .45395 Metetra
.664 .741 .907 r
.73544 .45395 .73625 .45496 .74216 .45314 .74135 .45212 Metetra
.664 .741 .907 r
.74135 .45212 .74216 .45314 .74808 .45131 .74727 .45029 Metetra
.664 .741 .907 r
.74727 .45029 .74808 .45131 .75611 .47941 .75321 .44846 Metetra
.569 .373 .576 r
.75321 .44846 .75611 .47941 .75995 .44765 .75934 .44917 Metetra
.155 0 .071 r
.75934 .44917 .75995 .44765 .76591 .44581 .76512 .44478 Metetra
.664 .741 .907 r
.76512 .44478 .76591 .44581 .77188 .44397 .77109 .44294 Metetra
.664 .741 .907 r
.77109 .44294 .77188 .44397 .77786 .44212 .77707 .44109 Metetra
.664 .741 .907 r
.77707 .44109 .77786 .44212 .78386 .44027 .78307 .43924 Metetra
.664 .741 .907 r
.78307 .43924 .78386 .44027 .78986 .43842 .78908 .43738 Metetra
.664 .741 .907 r
.78908 .43738 .78986 .43842 .79588 .43656 .7951 .43552 Metetra
.664 .741 .907 r
.7951 .43552 .79588 .43656 .80191 .4347 .80113 .43366 Metetra
.664 .741 .907 r
.80113 .43366 .80191 .4347 .80796 .43283 .80718 .43179 Metetra
.664 .741 .907 r
.80718 .43179 .80796 .43283 .81401 .43096 .81324 .42992 Metetra
.664 .741 .907 r
.81324 .42992 .81401 .43096 .82008 .42909 .81931 .42804 Metetra
.664 .741 .907 r
.81931 .42804 .82008 .42909 .82617 .42721 .8254 .42616 Metetra
.664 .741 .907 r
.8254 .42616 .82617 .42721 .83226 .42533 .8315 .42428 Metetra
.664 .741 .907 r
.8315 .42428 .83226 .42533 .83837 .42345 .83761 .42239 Metetra
.664 .741 .907 r
.83761 .42239 .83837 .42345 .84449 .42156 .84373 .4205 Metetra
.664 .741 .907 r
.84373 .4205 .84449 .42156 .85062 .41966 .84987 .41861 Metetra
.664 .741 .907 r
.84987 .41861 .85062 .41966 .85677 .41777 .85602 .41671 Metetra
.664 .741 .907 r
.85602 .41671 .85677 .41777 .86293 .41587 .86218 .4148 Metetra
.664 .741 .907 r
.86218 .4148 .86293 .41587 .8691 .41396 .86835 .4129 Metetra
.664 .741 .907 r
.86835 .4129 .8691 .41396 .87529 .41205 .87454 .41098 Metetra
.664 .741 .907 r
.87454 .41098 .87529 .41205 .88149 .41014 .88074 .40907 Metetra
.664 .741 .907 r
.88074 .40907 .88149 .41014 .8877 .40822 .88696 .40715 Metetra
.664 .741 .907 r
.88696 .40715 .8877 .40822 .89392 .4063 .89319 .40523 Metetra
.664 .741 .907 r
.89319 .40523 .89392 .4063 .90016 .40437 .89943 .4033 Metetra
.664 .741 .907 r
.89943 .4033 .90016 .40437 .90641 .40244 .90568 .40137 Metetra
.664 .741 .907 r
.90568 .40137 .90641 .40244 .91268 .40051 .91195 .39943 Metetra
.664 .741 .907 r
.91195 .39943 .91268 .40051 .91896 .39857 .91823 .39749 Metetra
.664 .741 .907 r
.91823 .39749 .91896 .39857 .92525 .39663 .92453 .39555 Metetra
.664 .741 .907 r
.92453 .39555 .92525 .39663 .93155 .39468 .93083 .3936 Metetra
.664 .741 .907 r
.93083 .3936 .93155 .39468 .93787 .39273 .93716 .39164 Metetra
.664 .741 .907 r
.93716 .39164 .93787 .39273 .94421 .39078 .94349 .38969 Metetra
.664 .741 .907 r
.36971 .56572 .37067 .56662 .37585 .56502 .37489 .56412 Metetra
.664 .741 .907 r
.37489 .56412 .37585 .56502 .38104 .56341 .38009 .56252 Metetra
.664 .741 .907 r
.38009 .56252 .38104 .56341 .38624 .56181 .38529 .56091 Metetra
.664 .741 .907 r
.38529 .56091 .38624 .56181 .39144 .5602 .3905 .5593 Metetra
.664 .741 .907 r
.3905 .5593 .39144 .5602 .39666 .55859 .39572 .55769 Metetra
.664 .741 .907 r
.39572 .55769 .39666 .55859 .40189 .55697 .40095 .55607 Metetra
.664 .741 .907 r
.40095 .55607 .40189 .55697 .40713 .55535 .40619 .55445 Metetra
.664 .741 .907 r
.40619 .55445 .40713 .55535 .41238 .55373 .41144 .55283 Metetra
.948 .647 .435 r
.41144 .55283 .41238 .55373 .41735 .56147 .41537 .59283 Metetra
.38 .194 .499 r
.41537 .59283 .41735 .56147 .42291 .55048 .42198 .54957 Metetra
.664 .741 .907 r
.42198 .54957 .42291 .55048 .42819 .54885 .42726 .54794 Metetra
.664 .741 .907 r
.42726 .54794 .42819 .54885 .43348 .54721 .43255 .5463 Metetra
.664 .741 .907 r
.43255 .5463 .43348 .54721 .43879 .54558 .43786 .54466 Metetra
.664 .741 .907 r
.43786 .54466 .43879 .54558 .4441 .54394 .44317 .54302 Metetra
.664 .741 .907 r
.44317 .54302 .4441 .54394 .44942 .54229 .44849 .54137 Metetra
.664 .741 .907 r
.44849 .54137 .44942 .54229 .45475 .54065 .45383 .53973 Metetra
.664 .741 .907 r
.45383 .53973 .45475 .54065 .4601 .539 .45917 .53807 Metetra
.664 .741 .907 r
.45917 .53807 .4601 .539 .46545 .53734 .46453 .53642 Metetra
.664 .741 .907 r
.46453 .53642 .46545 .53734 .47081 .53568 .4699 .53476 Metetra
.664 .741 .907 r
.4699 .53476 .47081 .53568 .47619 .53402 .47527 .5331 Metetra
.664 .741 .907 r
.47527 .5331 .47619 .53402 .48157 .53236 .48066 .53143 Metetra
.664 .741 .907 r
.48066 .53143 .48157 .53236 .48697 .53069 .48606 .52976 Metetra
.664 .741 .907 r
.48606 .52976 .48697 .53069 .49238 .52902 .49147 .52809 Metetra
.762 .283 0 r
.49147 .52809 .49238 .52902 .49779 .52735 .4968 .53617 Metetra
.398 .176 .456 r
.4968 .53617 .49779 .52735 .50322 .52567 .50232 .52474 Metetra
.664 .741 .907 r
.50232 .52474 .50322 .52567 .50866 .52399 .50776 .52306 Metetra
.664 .741 .907 r
.50776 .52306 .50866 .52399 .51411 .52231 .51321 .52137 Metetra
.664 .741 .907 r
.51321 .52137 .51411 .52231 .51957 .52062 .51867 .51968 Metetra
.664 .741 .907 r
.51867 .51968 .51957 .52062 .52505 .57585 .52415 .51799 Metetra
.562 .361 .566 r
.52415 .51799 .52505 .57585 .53059 .55772 .52964 .52212 Metetra
.59 .387 .574 r
.52964 .52212 .53059 .55772 .53602 .51554 .53513 .5146 Metetra
.664 .741 .907 r
.53513 .5146 .53602 .51554 .54152 .51384 .54063 .51289 Metetra
.664 .741 .907 r
.54063 .51289 .54152 .51384 .54704 .51214 .54615 .51119 Metetra
.664 .741 .907 r
.54615 .51119 .54704 .51214 .55256 .51043 .55168 .50948 Metetra
.664 .741 .907 r
.55168 .50948 .55256 .51043 .5581 .50872 .55722 .50777 Metetra
.664 .741 .907 r
.55722 .50777 .5581 .50872 .56365 .50701 .56277 .50605 Metetra
.664 .741 .907 r
.56277 .50605 .56365 .50701 .56921 .50529 .56833 .50433 Metetra
.664 .741 .907 r
.56833 .50433 .56921 .50529 .57478 .50357 .5739 .50261 Metetra
.664 .741 .907 r
.5739 .50261 .57478 .50357 .58036 .50185 .57949 .50088 Metetra
.664 .741 .907 r
.57949 .50088 .58036 .50185 .58596 .50012 .58508 .49916 Metetra
.664 .741 .907 r
.58508 .49916 .58596 .50012 .59156 .49839 .59069 .49742 Metetra
.664 .741 .907 r
.59069 .49742 .59156 .49839 .59718 .49665 .59631 .49569 Metetra
.664 .741 .907 r
.59631 .49569 .59718 .49665 .6028 .49492 .60194 .49395 Metetra
.664 .741 .907 r
.60194 .49395 .6028 .49492 .60844 .49317 .60758 .4922 Metetra
.664 .741 .907 r
.60758 .4922 .60844 .49317 .61409 .49143 .61323 .49045 Metetra
.664 .741 .907 r
.61323 .49045 .61409 .49143 .61975 .48968 .6189 .4887 Metetra
.664 .741 .907 r
.6189 .4887 .61975 .48968 .62543 .48793 .62457 .48695 Metetra
.664 .741 .907 r
.62457 .48695 .62543 .48793 .63111 .48617 .63026 .48519 Metetra
.664 .741 .907 r
.63026 .48519 .63111 .48617 .63681 .48441 .63596 .48343 Metetra
.664 .741 .907 r
.63596 .48343 .63681 .48441 .64252 .48265 .64167 .48167 Metetra
.664 .741 .907 r
.64167 .48167 .64252 .48265 .64823 .48088 .64739 .4799 Metetra
.664 .741 .907 r
.64739 .4799 .64823 .48088 .65397 .47911 .65312 .47813 Metetra
.664 .741 .907 r
.65312 .47813 .65397 .47911 .65971 .47734 .65887 .47635 Metetra
.664 .741 .907 r
.65887 .47635 .65971 .47734 .66546 .47556 .66462 .47457 Metetra
.664 .741 .907 r
.66462 .47457 .66546 .47556 .67123 .47378 .67039 .47279 Metetra
.664 .741 .907 r
.67039 .47279 .67123 .47378 .67701 .472 .67617 .471 Metetra
.737 .276 0 r
.67617 .471 .67701 .472 .6828 .47021 .68254 .48124 Metetra
.423 .211 .485 r
.68254 .48124 .6828 .47021 .6886 .46842 .68777 .46742 Metetra
.664 .741 .907 r
.68777 .46742 .6886 .46842 .69441 .46662 .69358 .46562 Metetra
.664 .741 .907 r
.69358 .46562 .69441 .46662 .70024 .46482 .69941 .46382 Metetra
.664 .741 .907 r
.69941 .46382 .70024 .46482 .70607 .46302 .70525 .46201 Metetra
.664 .741 .907 r
.70525 .46201 .70607 .46302 .71192 .46121 .7111 .4602 Metetra
.664 .741 .907 r
.7111 .4602 .71192 .46121 .71778 .4594 .71697 .45839 Metetra
.664 .741 .907 r
.71697 .45839 .71778 .4594 .72366 .45759 .72284 .45657 Metetra
.664 .741 .907 r
.72284 .45657 .72366 .45759 .72954 .45577 .72873 .45475 Metetra
.664 .741 .907 r
.72873 .45475 .72954 .45577 .73544 .45395 .73463 .45293 Metetra
.664 .741 .907 r
.73463 .45293 .73544 .45395 .74135 .45212 .74055 .4511 Metetra
.664 .741 .907 r
.74055 .4511 .74135 .45212 .74727 .45029 .74647 .44927 Metetra
.664 .741 .907 r
.74647 .44927 .74727 .45029 .75321 .44846 .75241 .44744 Metetra
.664 .741 .907 r
.75241 .44744 .75321 .44846 .75934 .44917 .75836 .4456 Metetra
.622 .505 .699 r
.75836 .4456 .75934 .44917 .76512 .44478 .76432 .44375 Metetra
.664 .741 .907 r
.76432 .44375 .76512 .44478 .77109 .44294 .77029 .44191 Metetra
.664 .741 .907 r
.77029 .44191 .77109 .44294 .77707 .44109 .77628 .44006 Metetra
.664 .741 .907 r
.77628 .44006 .77707 .44109 .78307 .43924 .78228 .4382 Metetra
.664 .741 .907 r
.78228 .4382 .78307 .43924 .78908 .43738 .78829 .43635 Metetra
.664 .741 .907 r
.78829 .43635 .78908 .43738 .7951 .43552 .79432 .43448 Metetra
.664 .741 .907 r
.79432 .43448 .7951 .43552 .80113 .43366 .80035 .43262 Metetra
.664 .741 .907 r
.80035 .43262 .80113 .43366 .80718 .43179 .8064 .43075 Metetra
.664 .741 .907 r
.8064 .43075 .80718 .43179 .81324 .42992 .81246 .42887 Metetra
.664 .741 .907 r
.81246 .42887 .81324 .42992 .81931 .42804 .81854 .427 Metetra
.664 .741 .907 r
.81854 .427 .81931 .42804 .8254 .42616 .82463 .42511 Metetra
.664 .741 .907 r
.82463 .42511 .8254 .42616 .8315 .42428 .83073 .42323 Metetra
.664 .741 .907 r
.83073 .42323 .8315 .42428 .83761 .42239 .83684 .42134 Metetra
.664 .741 .907 r
.83684 .42134 .83761 .42239 .84373 .4205 .84297 .41944 Metetra
.664 .741 .907 r
.84297 .41944 .84373 .4205 .84987 .41861 .84911 .41755 Metetra
.664 .741 .907 r
.84911 .41755 .84987 .41861 .85602 .41671 .85526 .41565 Metetra
.664 .741 .907 r
.85526 .41565 .85602 .41671 .86218 .4148 .86143 .41374 Metetra
.664 .741 .907 r
.86143 .41374 .86218 .4148 .86835 .4129 .8676 .41183 Metetra
.664 .741 .907 r
.8676 .41183 .86835 .4129 .87454 .41098 .87379 .40992 Metetra
.664 .741 .907 r
.87379 .40992 .87454 .41098 .88074 .40907 .88 .408 Metetra
.664 .741 .907 r
.88 .408 .88074 .40907 .88696 .40715 .88622 .40608 Metetra
.664 .741 .907 r
.88622 .40608 .88696 .40715 .89319 .40523 .89245 .40415 Metetra
.664 .741 .907 r
.89245 .40415 .89319 .40523 .89943 .4033 .89869 .40222 Metetra
.664 .741 .907 r
.89869 .40222 .89943 .4033 .90568 .40137 .90495 .40029 Metetra
.664 .741 .907 r
.90495 .40029 .90568 .40137 .91195 .39943 .91122 .39835 Metetra
.664 .741 .907 r
.91122 .39835 .91195 .39943 .91823 .39749 .91751 .39641 Metetra
.664 .741 .907 r
.91751 .39641 .91823 .39749 .92453 .39555 .9238 .39446 Metetra
.664 .741 .907 r
.9238 .39446 .92453 .39555 .93083 .3936 .93011 .39251 Metetra
.664 .741 .907 r
.93011 .39251 .93083 .3936 .93716 .39164 .93644 .39055 Metetra
.664 .741 .907 r
.93644 .39055 .93716 .39164 .94349 .38969 .94278 .38859 Metetra
.664 .741 .907 r
.36876 .56483 .36971 .56572 .37489 .56412 .37394 .56323 Metetra
.664 .741 .907 r
.37394 .56323 .37489 .56412 .38009 .56252 .37913 .56162 Metetra
.664 .741 .907 r
.37913 .56162 .38009 .56252 .38529 .56091 .38434 .56001 Metetra
.664 .741 .907 r
.38434 .56001 .38529 .56091 .3905 .5593 .38955 .5584 Metetra
.664 .741 .907 r
.38955 .5584 .3905 .5593 .39572 .55769 .39477 .55679 Metetra
.664 .741 .907 r
.39477 .55679 .39572 .55769 .40095 .55607 .40001 .55517 Metetra
.664 .741 .907 r
.40001 .55517 .40095 .55607 .40619 .55445 .40525 .55354 Metetra
.664 .741 .907 r
.40525 .55354 .40619 .55445 .41144 .55283 .4105 .55192 Metetra
.466 .67 .952 r
.4105 .55192 .41144 .55283 .41537 .59283 .4157 .55224 Metetra
.578 .377 .571 r
.4157 .55224 .41537 .59283 .42198 .54957 .42104 .54866 Metetra
.664 .741 .907 r
.42104 .54866 .42198 .54957 .42726 .54794 .42632 .54703 Metetra
.664 .741 .907 r
.42632 .54703 .42726 .54794 .43255 .5463 .43162 .54539 Metetra
.664 .741 .907 r
.43162 .54539 .43255 .5463 .43786 .54466 .43693 .54375 Metetra
.664 .741 .907 r
.43693 .54375 .43786 .54466 .44317 .54302 .44224 .5421 Metetra
.664 .741 .907 r
.44224 .5421 .44317 .54302 .44849 .54137 .44757 .54046 Metetra
.664 .741 .907 r
.44757 .54046 .44849 .54137 .45383 .53973 .4529 .5388 Metetra
.664 .741 .907 r
.4529 .5388 .45383 .53973 .45917 .53807 .45825 .53715 Metetra
.664 .741 .907 r
.45825 .53715 .45917 .53807 .46453 .53642 .46361 .53549 Metetra
.664 .741 .907 r
.46361 .53549 .46453 .53642 .4699 .53476 .46898 .53383 Metetra
.664 .741 .907 r
.46898 .53383 .4699 .53476 .47527 .5331 .47436 .53217 Metetra
.664 .741 .907 r
.47436 .53217 .47527 .5331 .48066 .53143 .47975 .5305 Metetra
.664 .741 .907 r
.47975 .5305 .48066 .53143 .48606 .52976 .48515 .52883 Metetra
.954 .66 .439 r
.48515 .52883 .48606 .52976 .49147 .52809 .48992 .58946 Metetra
.534 .326 .544 r
.48992 .58946 .49147 .52809 .4968 .53617 .4956 .5698 Metetra
.392 .207 .507 r
.4956 .5698 .4968 .53617 .50232 .52474 .50141 .5238 Metetra
.664 .741 .907 r
.50141 .5238 .50232 .52474 .50776 .52306 .50685 .52212 Metetra
.664 .741 .907 r
.50685 .52212 .50776 .52306 .51321 .52137 .51231 .52043 Metetra
.664 .741 .907 r
.51231 .52043 .51321 .52137 .51867 .51968 .51777 .51874 Metetra
.664 .741 .907 r
.51777 .51874 .51867 .51968 .52415 .51799 .52325 .51705 Metetra
.664 .741 .907 r
.52325 .51705 .52415 .51799 .52964 .52212 .52874 .51535 Metetra
.599 .437 .634 r
.52874 .51535 .52964 .52212 .53513 .5146 .53423 .51365 Metetra
.664 .741 .907 r
.53423 .51365 .53513 .5146 .54063 .51289 .53974 .51194 Metetra
.664 .741 .907 r
.53974 .51194 .54063 .51289 .54615 .51119 .54526 .51024 Metetra
.664 .741 .907 r
.54526 .51024 .54615 .51119 .55168 .50948 .55079 .50853 Metetra
.664 .741 .907 r
.55079 .50853 .55168 .50948 .55722 .50777 .55633 .50681 Metetra
.664 .741 .907 r
.55633 .50681 .55722 .50777 .56277 .50605 .56189 .50509 Metetra
.664 .741 .907 r
.56189 .50509 .56277 .50605 .56833 .50433 .56745 .50337 Metetra
.664 .741 .907 r
.56745 .50337 .56833 .50433 .5739 .50261 .57303 .50165 Metetra
.664 .741 .907 r
.57303 .50165 .5739 .50261 .57949 .50088 .57861 .49992 Metetra
.664 .741 .907 r
.57861 .49992 .57949 .50088 .58508 .49916 .58421 .49819 Metetra
.664 .741 .907 r
.58421 .49819 .58508 .49916 .59069 .49742 .58982 .49645 Metetra
.664 .741 .907 r
.58982 .49645 .59069 .49742 .59631 .49569 .59544 .49472 Metetra
.664 .741 .907 r
.59544 .49472 .59631 .49569 .60194 .49395 .60107 .49297 Metetra
.664 .741 .907 r
.60107 .49297 .60194 .49395 .60758 .4922 .60672 .49123 Metetra
.664 .741 .907 r
.60672 .49123 .60758 .4922 .61323 .49045 .61237 .48948 Metetra
.664 .741 .907 r
.61237 .48948 .61323 .49045 .6189 .4887 .61804 .48773 Metetra
.664 .741 .907 r
.61804 .48773 .6189 .4887 .62457 .48695 .62371 .48597 Metetra
.664 .741 .907 r
.62371 .48597 .62457 .48695 .63026 .48519 .6294 .48421 Metetra
.664 .741 .907 r
.6294 .48421 .63026 .48519 .63596 .48343 .6351 .48245 Metetra
.664 .741 .907 r
.6351 .48245 .63596 .48343 .64167 .48167 .64082 .48068 Metetra
.664 .741 .907 r
.64082 .48068 .64167 .48167 .64739 .4799 .64654 .47891 Metetra
.664 .741 .907 r
.64654 .47891 .64739 .4799 .65312 .47813 .65228 .47714 Metetra
.664 .741 .907 r
.65228 .47714 .65312 .47813 .65887 .47635 .65802 .47536 Metetra
.664 .741 .907 r
.65802 .47536 .65887 .47635 .66462 .47457 .66378 .47358 Metetra
.664 .741 .907 r
.66378 .47358 .66462 .47457 .67039 .47279 .66955 .47179 Metetra
.664 .741 .907 r
.66955 .47179 .67039 .47279 .67617 .471 .67534 .47 Metetra
.968 .664 .389 r
.67534 .47 .67617 .471 .68254 .48124 .68618 .57451 Metetra
.44 .258 .536 r
.68618 .57451 .68254 .48124 .68777 .46742 .68694 .46641 Metetra
.664 .741 .907 r
.68694 .46641 .68777 .46742 .69358 .46562 .69276 .46461 Metetra
.664 .741 .907 r
.69276 .46461 .69358 .46562 .69941 .46382 .69859 .46281 Metetra
.664 .741 .907 r
.69859 .46281 .69941 .46382 .70525 .46201 .70443 .461 Metetra
.664 .741 .907 r
.70443 .461 .70525 .46201 .7111 .4602 .71028 .45919 Metetra
.664 .741 .907 r
.71028 .45919 .7111 .4602 .71697 .45839 .71615 .45738 Metetra
.664 .741 .907 r
.71615 .45738 .71697 .45839 .72284 .45657 .72203 .45556 Metetra
.664 .741 .907 r
.72203 .45556 .72284 .45657 .72873 .45475 .72792 .45374 Metetra
.664 .741 .907 r
.72792 .45374 .72873 .45475 .73463 .45293 .73382 .45191 Metetra
.664 .741 .907 r
.73382 .45191 .73463 .45293 .74055 .4511 .73974 .45008 Metetra
.664 .741 .907 r
.73974 .45008 .74055 .4511 .74647 .44927 .74566 .44825 Metetra
.664 .741 .907 r
.74566 .44825 .74647 .44927 .75241 .44744 .7516 .44641 Metetra
.664 .741 .907 r
.7516 .44641 .75241 .44744 .75836 .4456 .75756 .44457 Metetra
.664 .741 .907 r
.75756 .44457 .75836 .4456 .76432 .44375 .76352 .44273 Metetra
.664 .741 .907 r
.76352 .44273 .76432 .44375 .77029 .44191 .7695 .44088 Metetra
.664 .741 .907 r
.7695 .44088 .77029 .44191 .77628 .44006 .77549 .43902 Metetra
.664 .741 .907 r
.77549 .43902 .77628 .44006 .78228 .4382 .78149 .43717 Metetra
.664 .741 .907 r
.78149 .43717 .78228 .4382 .78829 .43635 .7875 .43531 Metetra
.664 .741 .907 r
.7875 .43531 .78829 .43635 .79432 .43448 .79353 .43344 Metetra
.664 .741 .907 r
.79353 .43344 .79432 .43448 .80035 .43262 .79957 .43157 Metetra
.664 .741 .907 r
.79957 .43157 .80035 .43262 .8064 .43075 .80562 .4297 Metetra
.664 .741 .907 r
.80562 .4297 .8064 .43075 .81246 .42887 .81169 .42783 Metetra
.664 .741 .907 r
.81169 .42783 .81246 .42887 .81854 .427 .81777 .42595 Metetra
.664 .741 .907 r
.81777 .42595 .81854 .427 .82463 .42511 .82386 .42406 Metetra
.664 .741 .907 r
.82386 .42406 .82463 .42511 .83073 .42323 .82996 .42217 Metetra
.664 .741 .907 r
.82996 .42217 .83073 .42323 .83684 .42134 .83608 .42028 Metetra
.664 .741 .907 r
.83608 .42028 .83684 .42134 .84297 .41944 .84221 .41839 Metetra
.664 .741 .907 r
.84221 .41839 .84297 .41944 .84911 .41755 .84835 .41649 Metetra
.664 .741 .907 r
.84835 .41649 .84911 .41755 .85526 .41565 .8545 .41458 Metetra
.664 .741 .907 r
.8545 .41458 .85526 .41565 .86143 .41374 .86067 .41268 Metetra
.664 .741 .907 r
.86067 .41268 .86143 .41374 .8676 .41183 .86685 .41076 Metetra
.664 .741 .907 r
.86685 .41076 .8676 .41183 .87379 .40992 .87305 .40885 Metetra
.664 .741 .907 r
.87305 .40885 .87379 .40992 .88 .408 .87925 .40693 Metetra
.953 .61 .226 r
.87925 .40693 .88 .408 .88622 .40608 .89306 .47292 Metetra
.466 .28 .544 r
.89306 .47292 .88622 .40608 .89245 .40415 .89171 .40307 Metetra
.664 .741 .907 r
.89171 .40307 .89245 .40415 .89869 .40222 .89796 .40114 Metetra
.664 .741 .907 r
.89796 .40114 .89869 .40222 .90495 .40029 .90422 .39921 Metetra
.664 .741 .907 r
.90422 .39921 .90495 .40029 .91122 .39835 .91049 .39727 Metetra
.664 .741 .907 r
.91049 .39727 .91122 .39835 .91751 .39641 .91678 .39532 Metetra
.664 .741 .907 r
.91678 .39532 .91751 .39641 .9238 .39446 .92308 .39337 Metetra
.664 .741 .907 r
.92308 .39337 .9238 .39446 .93011 .39251 .92939 .39142 Metetra
.664 .741 .907 r
.92939 .39142 .93011 .39251 .93644 .39055 .93572 .38946 Metetra
.664 .741 .907 r
.93572 .38946 .93644 .39055 .94278 .38859 .94206 .3875 Metetra
.664 .741 .907 r
.3678 .56394 .36876 .56483 .37394 .56323 .37299 .56233 Metetra
.664 .741 .907 r
.37299 .56233 .37394 .56323 .37913 .56162 .37818 .56073 Metetra
.664 .741 .907 r
.37818 .56073 .37913 .56162 .38434 .56001 .38338 .55911 Metetra
.664 .741 .907 r
.38338 .55911 .38434 .56001 .38955 .5584 .3886 .5575 Metetra
.664 .741 .907 r
.3886 .5575 .38955 .5584 .39477 .55679 .39382 .55588 Metetra
.664 .741 .907 r
.39382 .55588 .39477 .55679 .40001 .55517 .39906 .55426 Metetra
.664 .741 .907 r
.39906 .55426 .40001 .55517 .40525 .55354 .40431 .55264 Metetra
.664 .741 .907 r
.40431 .55264 .40525 .55354 .4105 .55192 .40956 .55101 Metetra
.664 .741 .907 r
.40956 .55101 .4105 .55192 .4157 .55224 .41483 .54938 Metetra
.629 .528 .721 r
.41483 .54938 .4157 .55224 .42104 .54866 .4201 .54775 Metetra
.664 .741 .907 r
.4201 .54775 .42104 .54866 .42632 .54703 .42539 .54611 Metetra
.664 .741 .907 r
.42539 .54611 .42632 .54703 .43162 .54539 .43069 .54447 Metetra
.664 .741 .907 r
.43069 .54447 .43162 .54539 .43693 .54375 .43599 .54283 Metetra
.664 .741 .907 r
.43599 .54283 .43693 .54375 .44224 .5421 .44131 .54118 Metetra
.664 .741 .907 r
.44131 .54118 .44224 .5421 .44757 .54046 .44664 .53953 Metetra
.664 .741 .907 r
.44664 .53953 .44757 .54046 .4529 .5388 .45198 .53788 Metetra
.664 .741 .907 r
.45198 .53788 .4529 .5388 .45825 .53715 .45733 .53623 Metetra
.664 .741 .907 r
.45733 .53623 .45825 .53715 .46361 .53549 .46269 .53457 Metetra
.664 .741 .907 r
.46269 .53457 .46361 .53549 .46898 .53383 .46806 .53291 Metetra
.664 .741 .907 r
.46806 .53291 .46898 .53383 .47436 .53217 .47344 .53124 Metetra
.664 .741 .907 r
.47344 .53124 .47436 .53217 .47975 .5305 .47883 .52957 Metetra
.664 .741 .907 r
.47883 .52957 .47975 .5305 .48515 .52883 .48423 .5279 Metetra
.952 .679 .482 r
.48423 .5279 .48515 .52883 .48992 .58946 .48759 .72149 Metetra
.451 .263 .533 r
.48759 .72149 .48992 .58946 .4956 .5698 .49448 .59073 Metetra
0 0 .343 r
.49448 .59073 .4956 .5698 .50141 .5238 .5005 .52286 Metetra
.664 .741 .907 r
.5005 .52286 .50141 .5238 .50685 .52212 .50595 .52118 Metetra
.664 .741 .907 r
.50595 .52118 .50685 .52212 .51231 .52043 .5114 .51949 Metetra
.664 .741 .907 r
.5114 .51949 .51231 .52043 .51777 .51874 .51687 .5178 Metetra
.664 .741 .907 r
.51687 .5178 .51777 .51874 .52325 .51705 .52235 .5161 Metetra
.664 .741 .907 r
.52235 .5161 .52325 .51705 .52874 .51535 .52784 .5144 Metetra
.664 .741 .907 r
.52784 .5144 .52874 .51535 .53423 .51365 .53334 .5127 Metetra
.664 .741 .907 r
.53334 .5127 .53423 .51365 .53974 .51194 .53885 .51099 Metetra
.664 .741 .907 r
.53885 .51099 .53974 .51194 .54526 .51024 .54437 .50928 Metetra
.664 .741 .907 r
.54437 .50928 .54526 .51024 .55079 .50853 .5499 .50757 Metetra
.664 .741 .907 r
.5499 .50757 .55079 .50853 .55633 .50681 .55545 .50585 Metetra
.664 .741 .907 r
.55545 .50585 .55633 .50681 .56189 .50509 .561 .50413 Metetra
.664 .741 .907 r
.561 .50413 .56189 .50509 .56745 .50337 .56657 .50241 Metetra
.664 .741 .907 r
.56657 .50241 .56745 .50337 .57303 .50165 .57215 .50069 Metetra
.664 .741 .907 r
.57215 .50069 .57303 .50165 .57861 .49992 .57774 .49896 Metetra
.664 .741 .907 r
.57774 .49896 .57861 .49992 .58421 .49819 .58334 .49722 Metetra
.664 .741 .907 r
.58334 .49722 .58421 .49819 .58982 .49645 .58895 .49548 Metetra
.664 .741 .907 r
.58895 .49548 .58982 .49645 .59544 .49472 .59457 .49374 Metetra
.664 .741 .907 r
.59457 .49374 .59544 .49472 .60107 .49297 .6002 .492 Metetra
.664 .741 .907 r
.6002 .492 .60107 .49297 .60672 .49123 .60585 .49025 Metetra
.664 .741 .907 r
.60585 .49025 .60672 .49123 .61237 .48948 .61151 .4885 Metetra
.664 .741 .907 r
.61151 .4885 .61237 .48948 .61804 .48773 .61718 .48675 Metetra
.664 .741 .907 r
.61718 .48675 .61804 .48773 .62371 .48597 .62286 .48499 Metetra
.664 .741 .907 r
.62286 .48499 .62371 .48597 .6294 .48421 .62855 .48323 Metetra
.664 .741 .907 r
.62855 .48323 .6294 .48421 .6351 .48245 .63425 .48146 Metetra
.664 .741 .907 r
.63425 .48146 .6351 .48245 .64082 .48068 .63996 .47969 Metetra
.664 .741 .907 r
.63996 .47969 .64082 .48068 .64654 .47891 .64569 .47792 Metetra
.664 .741 .907 r
.64569 .47792 .64654 .47891 .65228 .47714 .65143 .47614 Metetra
.664 .741 .907 r
.65143 .47614 .65228 .47714 .65802 .47536 .65718 .47436 Metetra
.664 .741 .907 r
.65718 .47436 .65802 .47536 .66378 .47358 .66294 .47258 Metetra
.664 .741 .907 r
.66294 .47258 .66378 .47358 .66955 .47179 .66871 .47079 Metetra
.664 .741 .907 r
.66871 .47079 .66955 .47179 .67534 .47 .6745 .469 Metetra
.961 .63 .321 r
.6745 .469 .67534 .47 .68618 .57451 .68255 .51496 Metetra
.638 .419 .569 r
.68255 .51496 .68618 .57451 .68694 .46641 .68611 .46541 Metetra
.664 .741 .907 r
.68611 .46541 .68694 .46641 .69276 .46461 .69193 .46361 Metetra
.664 .741 .907 r
.69193 .46361 .69276 .46461 .69859 .46281 .69776 .4618 Metetra
.664 .741 .907 r
.69776 .4618 .69859 .46281 .70443 .461 .7036 .45999 Metetra
.664 .741 .907 r
.7036 .45999 .70443 .461 .71028 .45919 .70946 .45818 Metetra
.664 .741 .907 r
.70946 .45818 .71028 .45919 .71615 .45738 .71533 .45636 Metetra
.664 .741 .907 r
.71533 .45636 .71615 .45738 .72203 .45556 .72121 .45454 Metetra
.664 .741 .907 r
.72121 .45454 .72203 .45556 .72792 .45374 .72711 .45272 Metetra
.664 .741 .907 r
.72711 .45272 .72792 .45374 .73382 .45191 .73301 .45089 Metetra
.664 .741 .907 r
.73301 .45089 .73382 .45191 .73974 .45008 .73893 .44906 Metetra
.664 .741 .907 r
.73893 .44906 .73974 .45008 .74566 .44825 .74486 .44722 Metetra
.664 .741 .907 r
.74486 .44722 .74566 .44825 .7516 .44641 .7508 .44538 Metetra
.664 .741 .907 r
.7508 .44538 .7516 .44641 .75756 .44457 .75676 .44354 Metetra
.664 .741 .907 r
.75676 .44354 .75756 .44457 .76352 .44273 .76272 .44169 Metetra
.664 .741 .907 r
.76272 .44169 .76352 .44273 .7695 .44088 .7687 .43984 Metetra
.664 .741 .907 r
.7687 .43984 .7695 .44088 .77549 .43902 .77469 .43799 Metetra
.664 .741 .907 r
.77469 .43799 .77549 .43902 .78149 .43717 .7807 .43613 Metetra
.664 .741 .907 r
.7807 .43613 .78149 .43717 .7875 .43531 .78672 .43427 Metetra
.664 .741 .907 r
.78672 .43427 .7875 .43531 .79353 .43344 .79275 .4324 Metetra
.664 .741 .907 r
.79275 .4324 .79353 .43344 .79957 .43157 .79879 .43053 Metetra
.664 .741 .907 r
.79879 .43053 .79957 .43157 .80562 .4297 .80484 .42866 Metetra
.664 .741 .907 r
.80484 .42866 .80562 .4297 .81169 .42783 .81091 .42678 Metetra
.664 .741 .907 r
.81091 .42678 .81169 .42783 .81777 .42595 .81699 .4249 Metetra
.664 .741 .907 r
.81699 .4249 .81777 .42595 .82386 .42406 .82309 .42301 Metetra
.664 .741 .907 r
.82309 .42301 .82386 .42406 .82996 .42217 .82919 .42112 Metetra
.664 .741 .907 r
.82919 .42112 .82996 .42217 .83608 .42028 .83531 .41923 Metetra
.664 .741 .907 r
.83531 .41923 .83608 .42028 .84221 .41839 .84144 .41733 Metetra
.664 .741 .907 r
.84144 .41733 .84221 .41839 .84835 .41649 .84759 .41543 Metetra
.664 .741 .907 r
.84759 .41543 .84835 .41649 .8545 .41458 .85375 .41352 Metetra
.664 .741 .907 r
.85375 .41352 .8545 .41458 .86067 .41268 .85992 .41161 Metetra
.664 .741 .907 r
.85992 .41161 .86067 .41268 .86685 .41076 .8661 .4097 Metetra
.664 .741 .907 r
.8661 .4097 .86685 .41076 .87305 .40885 .8723 .40778 Metetra
.664 .741 .907 r
.8723 .40778 .87305 .40885 .87925 .40693 .87851 .40585 Metetra
.8 .384 0 r
.87851 .40585 .87925 .40693 .89306 .47292 .88697 .42401 Metetra
.607 .395 .568 r
.88697 .42401 .89306 .47292 .89171 .40307 .89097 .402 Metetra
.664 .741 .907 r
.89097 .402 .89171 .40307 .89796 .40114 .89722 .40006 Metetra
.664 .741 .907 r
.89722 .40006 .89796 .40114 .90422 .39921 .90348 .39812 Metetra
.664 .741 .907 r
.90348 .39812 .90422 .39921 .91049 .39727 .90976 .39618 Metetra
.664 .741 .907 r
.90976 .39618 .91049 .39727 .91678 .39532 .91605 .39423 Metetra
.664 .741 .907 r
.91605 .39423 .91678 .39532 .92308 .39337 .92235 .39228 Metetra
.664 .741 .907 r
.92235 .39228 .92308 .39337 .92939 .39142 .92867 .39033 Metetra
.664 .741 .907 r
.92867 .39033 .92939 .39142 .93572 .38946 .935 .38837 Metetra
.664 .741 .907 r
.935 .38837 .93572 .38946 .94206 .3875 .94135 .3864 Metetra
.664 .741 .907 r
.36684 .56304 .3678 .56394 .37299 .56233 .37203 .56144 Metetra
.664 .741 .907 r
.37203 .56144 .37299 .56233 .37818 .56073 .37723 .55983 Metetra
.664 .741 .907 r
.37723 .55983 .37818 .56073 .38338 .55911 .38243 .55821 Metetra
.664 .741 .907 r
.38243 .55821 .38338 .55911 .3886 .5575 .38765 .5566 Metetra
.664 .741 .907 r
.38765 .5566 .3886 .5575 .39382 .55588 .39288 .55498 Metetra
.712 .213 0 r
.39288 .55498 .39382 .55588 .39906 .55426 .39781 .56143 Metetra
.685 .419 .514 r
.39781 .56143 .39906 .55426 .40431 .55264 .40255 .57428 Metetra
.422 .221 .5 r
.40255 .57428 .40431 .55264 .40956 .55101 .40862 .5501 Metetra
.664 .741 .907 r
.40862 .5501 .40956 .55101 .41483 .54938 .41389 .54847 Metetra
.664 .741 .907 r
.41389 .54847 .41483 .54938 .4201 .54775 .41916 .54684 Metetra
.664 .741 .907 r
.41916 .54684 .4201 .54775 .42539 .54611 .42445 .5452 Metetra
.664 .741 .907 r
.42445 .5452 .42539 .54611 .43069 .54447 .42975 .54356 Metetra
.664 .741 .907 r
.42975 .54356 .43069 .54447 .43599 .54283 .43506 .54191 Metetra
.664 .741 .907 r
.43506 .54191 .43599 .54283 .44131 .54118 .44038 .54026 Metetra
.664 .741 .907 r
.44038 .54026 .44131 .54118 .44664 .53953 .44571 .53861 Metetra
.664 .741 .907 r
.44571 .53861 .44664 .53953 .45198 .53788 .45105 .53696 Metetra
.664 .741 .907 r
.45105 .53696 .45198 .53788 .45733 .53623 .4564 .5353 Metetra
.664 .741 .907 r
.4564 .5353 .45733 .53623 .46269 .53457 .46176 .53364 Metetra
.664 .741 .907 r
.46176 .53364 .46269 .53457 .46806 .53291 .46714 .53198 Metetra
.664 .741 .907 r
.46714 .53198 .46806 .53291 .47344 .53124 .47252 .53031 Metetra
.664 .741 .907 r
.47252 .53031 .47344 .53124 .47883 .52957 .47791 .52864 Metetra
.664 .741 .907 r
.47791 .52864 .47883 .52957 .48423 .5279 .48332 .52696 Metetra
.952 .679 .483 r
.48332 .52696 .48423 .5279 .48759 .72149 .48657 .7258 Metetra
.971 .719 .494 r
.48657 .7258 .48759 .72149 .49448 .59073 .49415 .52468 Metetra
.573 .369 .566 r
.49415 .52468 .49448 .59073 .5005 .52286 .4996 .52192 Metetra
.664 .741 .907 r
.4996 .52192 .5005 .52286 .50595 .52118 .50504 .52023 Metetra
.664 .741 .907 r
.50504 .52023 .50595 .52118 .5114 .51949 .5105 .51854 Metetra
.664 .741 .907 r
.5105 .51854 .5114 .51949 .51687 .5178 .51597 .51685 Metetra
.664 .741 .907 r
.51597 .51685 .51687 .5178 .52235 .5161 .52145 .51515 Metetra
.664 .741 .907 r
.52145 .51515 .52235 .5161 .52784 .5144 .52694 .51345 Metetra
.664 .741 .907 r
.52694 .51345 .52784 .5144 .53334 .5127 .53244 .51175 Metetra
.664 .741 .907 r
.53244 .51175 .53334 .5127 .53885 .51099 .53796 .51004 Metetra
.664 .741 .907 r
.53796 .51004 .53885 .51099 .54437 .50928 .54348 .50833 Metetra
.664 .741 .907 r
.54348 .50833 .54437 .50928 .5499 .50757 .54902 .50661 Metetra
.664 .741 .907 r
.54902 .50661 .5499 .50757 .55545 .50585 .55456 .5049 Metetra
.664 .741 .907 r
.55456 .5049 .55545 .50585 .561 .50413 .56012 .50317 Metetra
.664 .741 .907 r
.56012 .50317 .561 .50413 .56657 .50241 .56569 .50145 Metetra
.664 .741 .907 r
.56569 .50145 .56657 .50241 .57215 .50069 .57127 .49972 Metetra
.664 .741 .907 r
.57127 .49972 .57215 .50069 .57774 .49896 .57686 .49799 Metetra
.664 .741 .907 r
.57686 .49799 .57774 .49896 .58334 .49722 .58246 .49625 Metetra
.664 .741 .907 r
.58246 .49625 .58334 .49722 .58895 .49548 .58807 .49451 Metetra
.664 .741 .907 r
.58807 .49451 .58895 .49548 .59457 .49374 .5937 .49277 Metetra
.664 .741 .907 r
.5937 .49277 .59457 .49374 .6002 .492 .59934 .49103 Metetra
.664 .741 .907 r
.59934 .49103 .6002 .492 .60585 .49025 .60498 .48928 Metetra
.664 .741 .907 r
.60498 .48928 .60585 .49025 .61151 .4885 .61064 .48752 Metetra
.664 .741 .907 r
.61064 .48752 .61151 .4885 .61718 .48675 .61631 .48577 Metetra
.664 .741 .907 r
.61631 .48577 .61718 .48675 .62286 .48499 .622 .48401 Metetra
.664 .741 .907 r
.622 .48401 .62286 .48499 .62855 .48323 .62769 .48224 Metetra
.664 .741 .907 r
.62769 .48224 .62855 .48323 .63425 .48146 .6334 .48048 Metetra
.664 .741 .907 r
.6334 .48048 .63425 .48146 .63996 .47969 .63911 .4787 Metetra
.664 .741 .907 r
.63911 .4787 .63996 .47969 .64569 .47792 .64484 .47693 Metetra
.664 .741 .907 r
.64484 .47693 .64569 .47792 .65143 .47614 .65058 .47515 Metetra
.664 .741 .907 r
.65058 .47515 .65143 .47614 .65718 .47436 .65633 .47337 Metetra
.664 .741 .907 r
.65633 .47337 .65718 .47436 .66294 .47258 .6621 .47158 Metetra
.664 .741 .907 r
.6621 .47158 .66294 .47258 .66871 .47079 .66787 .4698 Metetra
.936 .563 .201 r
.66787 .4698 .66871 .47079 .6745 .469 .67484 .49396 Metetra
.535 .318 .532 r
.67484 .49396 .6745 .469 .68255 .51496 .68039 .48607 Metetra
.632 .42 .577 r
.68039 .48607 .68255 .51496 .68611 .46541 .68527 .46441 Metetra
.664 .741 .907 r
.68527 .46441 .68611 .46541 .69193 .46361 .6911 .4626 Metetra
.664 .741 .907 r
.6911 .4626 .69193 .46361 .69776 .4618 .69693 .46079 Metetra
.664 .741 .907 r
.69693 .46079 .69776 .4618 .7036 .45999 .70278 .45898 Metetra
.664 .741 .907 r
.70278 .45898 .7036 .45999 .70946 .45818 .70864 .45717 Metetra
.664 .741 .907 r
.70864 .45717 .70946 .45818 .71533 .45636 .71451 .45535 Metetra
.664 .741 .907 r
.71451 .45535 .71533 .45636 .72121 .45454 .72039 .45353 Metetra
.664 .741 .907 r
.72039 .45353 .72121 .45454 .72711 .45272 .72629 .4517 Metetra
.664 .741 .907 r
.72629 .4517 .72711 .45272 .73301 .45089 .7322 .44987 Metetra
.664 .741 .907 r
.7322 .44987 .73301 .45089 .73893 .44906 .73812 .44804 Metetra
.664 .741 .907 r
.73812 .44804 .73893 .44906 .74486 .44722 .74405 .4462 Metetra
.664 .741 .907 r
.74405 .4462 .74486 .44722 .7508 .44538 .75 .44436 Metetra
.664 .741 .907 r
.75 .44436 .7508 .44538 .75676 .44354 .75595 .44251 Metetra
.664 .741 .907 r
.75595 .44251 .75676 .44354 .76272 .44169 .76192 .44066 Metetra
.664 .741 .907 r
.76192 .44066 .76272 .44169 .7687 .43984 .76791 .43881 Metetra
.664 .741 .907 r
.76791 .43881 .7687 .43984 .77469 .43799 .7739 .43695 Metetra
.664 .741 .907 r
.7739 .43695 .77469 .43799 .7807 .43613 .77991 .43509 Metetra
.664 .741 .907 r
.77991 .43509 .7807 .43613 .78672 .43427 .78593 .43323 Metetra
.664 .741 .907 r
.78593 .43323 .78672 .43427 .79275 .4324 .79196 .43136 Metetra
.664 .741 .907 r
.79196 .43136 .79275 .4324 .79879 .43053 .79801 .42949 Metetra
.664 .741 .907 r
.79801 .42949 .79879 .43053 .80484 .42866 .80406 .42761 Metetra
.664 .741 .907 r
.80406 .42761 .80484 .42866 .81091 .42678 .81013 .42573 Metetra
.664 .741 .907 r
.81013 .42573 .81091 .42678 .81699 .4249 .81622 .42384 Metetra
.664 .741 .907 r
.81622 .42384 .81699 .4249 .82309 .42301 .82231 .42196 Metetra
.664 .741 .907 r
.82231 .42196 .82309 .42301 .82919 .42112 .82842 .42006 Metetra
.664 .741 .907 r
.82842 .42006 .82919 .42112 .83531 .41923 .83454 .41817 Metetra
.664 .741 .907 r
.83454 .41817 .83531 .41923 .84144 .41733 .84068 .41627 Metetra
.664 .741 .907 r
.84068 .41627 .84144 .41733 .84759 .41543 .84683 .41436 Metetra
.664 .741 .907 r
.84683 .41436 .84759 .41543 .85375 .41352 .85299 .41245 Metetra
.664 .741 .907 r
.85299 .41245 .85375 .41352 .85992 .41161 .85916 .41054 Metetra
.664 .741 .907 r
.85916 .41054 .85992 .41161 .8661 .4097 .86535 .40863 Metetra
.846 .44 0 r
.86535 .40863 .8661 .4097 .8723 .40778 .87401 .42961 Metetra
.453 .257 .523 r
.87401 .42961 .8723 .40778 .87851 .40585 .87776 .40478 Metetra
.664 .741 .907 r
.87776 .40478 .87851 .40585 .88697 .42401 .88399 .40285 Metetra
.579 .386 .584 r
.88399 .40285 .88697 .42401 .89097 .402 .89023 .40092 Metetra
.664 .741 .907 r
.89023 .40092 .89097 .402 .89722 .40006 .89648 .39898 Metetra
.664 .741 .907 r
.89648 .39898 .89722 .40006 .90348 .39812 .90275 .39704 Metetra
.664 .741 .907 r
.90275 .39704 .90348 .39812 .90976 .39618 .90903 .3951 Metetra
.664 .741 .907 r
.90903 .3951 .90976 .39618 .91605 .39423 .91532 .39315 Metetra
.664 .741 .907 r
.91532 .39315 .91605 .39423 .92235 .39228 .92163 .39119 Metetra
.664 .741 .907 r
.92163 .39119 .92235 .39228 .92867 .39033 .92795 .38924 Metetra
.664 .741 .907 r
.92795 .38924 .92867 .39033 .935 .38837 .93428 .38727 Metetra
.664 .741 .907 r
.93428 .38727 .935 .38837 .94135 .3864 .94063 .38531 Metetra
.664 .741 .907 r
.36588 .56215 .36684 .56304 .37203 .56144 .37107 .56054 Metetra
.664 .741 .907 r
.37107 .56054 .37203 .56144 .37723 .55983 .37627 .55893 Metetra
.664 .741 .907 r
.37627 .55893 .37723 .55983 .38243 .55821 .38148 .55731 Metetra
.664 .741 .907 r
.38148 .55731 .38243 .55821 .38765 .5566 .3867 .5557 Metetra
.664 .741 .907 r
.3867 .5557 .38765 .5566 .39288 .55498 .39193 .55408 Metetra
.946 .648 .441 r
.39193 .55408 .39288 .55498 .39781 .56143 .39559 .59416 Metetra
.387 .198 .5 r
.39559 .59416 .39781 .56143 .40255 .57428 .40241 .55082 Metetra
.577 .382 .58 r
.40241 .55082 .40255 .57428 .40862 .5501 .40767 .54919 Metetra
.664 .741 .907 r
.40767 .54919 .40862 .5501 .41389 .54847 .41294 .54756 Metetra
.664 .741 .907 r
.41294 .54756 .41389 .54847 .41916 .54684 .41822 .54592 Metetra
.664 .741 .907 r
.41822 .54592 .41916 .54684 .42445 .5452 .42351 .54428 Metetra
.664 .741 .907 r
.42351 .54428 .42445 .5452 .42975 .54356 .42882 .54264 Metetra
.664 .741 .907 r
.42882 .54264 .42975 .54356 .43506 .54191 .43413 .54099 Metetra
.664 .741 .907 r
.43413 .54099 .43506 .54191 .44038 .54026 .43945 .53934 Metetra
.664 .741 .907 r
.43945 .53934 .44038 .54026 .44571 .53861 .44478 .53769 Metetra
.664 .741 .907 r
.44478 .53769 .44571 .53861 .45105 .53696 .45012 .53604 Metetra
.664 .741 .907 r
.45012 .53604 .45105 .53696 .4564 .5353 .45548 .53438 Metetra
.664 .741 .907 r
.45548 .53438 .4564 .5353 .46176 .53364 .46084 .53271 Metetra
.664 .741 .907 r
.46084 .53271 .46176 .53364 .46714 .53198 .46621 .53105 Metetra
.664 .741 .907 r
.46621 .53105 .46714 .53198 .47252 .53031 .4716 .52938 Metetra
.664 .741 .907 r
.4716 .52938 .47252 .53031 .47791 .52864 .477 .52771 Metetra
.664 .741 .907 r
.477 .52771 .47791 .52864 .48332 .52696 .4824 .52603 Metetra
.953 .671 .464 r
.4824 .52603 .48332 .52696 .48657 .7258 .48671 .62481 Metetra
.647 .426 .569 r
.48671 .62481 .48657 .7258 .49415 .52468 .49315 .53302 Metetra
.372 .151 .443 r
.49315 .53302 .49415 .52468 .4996 .52192 .49869 .52098 Metetra
.664 .741 .907 r
.49869 .52098 .4996 .52192 .50504 .52023 .50414 .51929 Metetra
.664 .741 .907 r
.50414 .51929 .50504 .52023 .5105 .51854 .5096 .5176 Metetra
.664 .741 .907 r
.5096 .5176 .5105 .51854 .51597 .51685 .51507 .5159 Metetra
.664 .741 .907 r
.51507 .5159 .51597 .51685 .52145 .51515 .52055 .5142 Metetra
.664 .741 .907 r
.52055 .5142 .52145 .51515 .52694 .51345 .52604 .5125 Metetra
.664 .741 .907 r
.52604 .5125 .52694 .51345 .53244 .51175 .53155 .51079 Metetra
.664 .741 .907 r
.53155 .51079 .53244 .51175 .53796 .51004 .53706 .50909 Metetra
.664 .741 .907 r
.53706 .50909 .53796 .51004 .54348 .50833 .54259 .50737 Metetra
.664 .741 .907 r
.54259 .50737 .54348 .50833 .54902 .50661 .54813 .50566 Metetra
.664 .741 .907 r
.54813 .50566 .54902 .50661 .55456 .5049 .55367 .50394 Metetra
.664 .741 .907 r
.55367 .50394 .55456 .5049 .56012 .50317 .55923 .50221 Metetra
.664 .741 .907 r
.55923 .50221 .56012 .50317 .56569 .50145 .5648 .50049 Metetra
0 .045 .561 r
.5648 .50049 .56569 .50145 .57127 .49972 .57049 .50606 Metetra
.381 .145 .426 r
.57049 .50606 .57127 .49972 .57686 .49799 .57598 .49702 Metetra
.664 .741 .907 r
.57598 .49702 .57686 .49799 .58246 .49625 .58158 .49528 Metetra
.664 .741 .907 r
.58158 .49528 .58246 .49625 .58807 .49451 .5872 .49354 Metetra
.664 .741 .907 r
.5872 .49354 .58807 .49451 .5937 .49277 .59283 .4918 Metetra
.664 .741 .907 r
.59283 .4918 .5937 .49277 .59934 .49103 .59847 .49005 Metetra
.664 .741 .907 r
.59847 .49005 .59934 .49103 .60498 .48928 .60412 .4883 Metetra
.664 .741 .907 r
.60412 .4883 .60498 .48928 .61064 .48752 .60978 .48654 Metetra
.664 .741 .907 r
.60978 .48654 .61064 .48752 .61631 .48577 .61545 .48479 Metetra
.664 .741 .907 r
.61545 .48479 .61631 .48577 .622 .48401 .62114 .48302 Metetra
.664 .741 .907 r
.62114 .48302 .622 .48401 .62769 .48224 .62683 .48126 Metetra
.664 .741 .907 r
.62683 .48126 .62769 .48224 .6334 .48048 .63254 .47949 Metetra
.664 .741 .907 r
.63254 .47949 .6334 .48048 .63911 .4787 .63826 .47772 Metetra
.664 .741 .907 r
.63826 .47772 .63911 .4787 .64484 .47693 .64399 .47594 Metetra
.664 .741 .907 r
.64399 .47594 .64484 .47693 .65058 .47515 .64973 .47416 Metetra
.664 .741 .907 r
.64973 .47416 .65058 .47515 .65633 .47337 .65549 .47237 Metetra
.664 .741 .907 r
.65549 .47237 .65633 .47337 .6621 .47158 .66126 .47059 Metetra
.664 .741 .907 r
.66126 .47059 .6621 .47158 .66787 .4698 .66703 .4688 Metetra
.664 .741 .907 r
.66703 .4688 .66787 .4698 .67484 .49396 .67282 .467 Metetra
.568 .373 .577 r
.67282 .467 .67484 .49396 .68039 .48607 .67874 .46769 Metetra
.592 .398 .587 r
.67874 .46769 .68039 .48607 .68527 .46441 .68444 .4634 Metetra
.664 .741 .907 r
.68444 .4634 .68527 .46441 .6911 .4626 .69027 .46159 Metetra
.664 .741 .907 r
.69027 .46159 .6911 .4626 .69693 .46079 .6961 .45978 Metetra
.664 .741 .907 r
.6961 .45978 .69693 .46079 .70278 .45898 .70195 .45797 Metetra
.664 .741 .907 r
.70195 .45797 .70278 .45898 .70864 .45717 .70782 .45615 Metetra
.664 .741 .907 r
.70782 .45615 .70864 .45717 .71451 .45535 .71369 .45433 Metetra
.664 .741 .907 r
.71369 .45433 .71451 .45535 .72039 .45353 .71958 .45251 Metetra
.664 .741 .907 r
.71958 .45251 .72039 .45353 .72629 .4517 .72547 .45068 Metetra
.664 .741 .907 r
.72547 .45068 .72629 .4517 .7322 .44987 .73138 .44885 Metetra
.664 .741 .907 r
.73138 .44885 .7322 .44987 .73812 .44804 .73731 .44701 Metetra
.664 .741 .907 r
.73731 .44701 .73812 .44804 .74405 .4462 .74324 .44517 Metetra
.664 .741 .907 r
.74324 .44517 .74405 .4462 .75 .44436 .74919 .44333 Metetra
.664 .741 .907 r
.74919 .44333 .75 .44436 .75595 .44251 .75515 .44148 Metetra
.664 .741 .907 r
.75515 .44148 .75595 .44251 .76192 .44066 .76112 .43963 Metetra
.664 .741 .907 r
.76112 .43963 .76192 .44066 .76791 .43881 .76711 .43777 Metetra
.664 .741 .907 r
.76711 .43777 .76791 .43881 .7739 .43695 .77311 .43592 Metetra
.664 .741 .907 r
.77311 .43592 .7739 .43695 .77991 .43509 .77912 .43405 Metetra
.664 .741 .907 r
.77912 .43405 .77991 .43509 .78593 .43323 .78514 .43219 Metetra
.664 .741 .907 r
.78514 .43219 .78593 .43323 .79196 .43136 .79117 .43031 Metetra
.664 .741 .907 r
.79117 .43031 .79196 .43136 .79801 .42949 .79722 .42844 Metetra
.664 .741 .907 r
.79722 .42844 .79801 .42949 .80406 .42761 .80328 .42656 Metetra
.664 .741 .907 r
.80328 .42656 .80406 .42761 .81013 .42573 .80936 .42468 Metetra
.664 .741 .907 r
.80936 .42468 .81013 .42573 .81622 .42384 .81544 .42279 Metetra
.664 .741 .907 r
.81544 .42279 .81622 .42384 .82231 .42196 .82154 .4209 Metetra
.664 .741 .907 r
.82154 .4209 .82231 .42196 .82842 .42006 .82765 .41901 Metetra
.664 .741 .907 r
.82765 .41901 .82842 .42006 .83454 .41817 .83378 .41711 Metetra
.664 .741 .907 r
.83378 .41711 .83454 .41817 .84068 .41627 .83991 .41521 Metetra
.664 .741 .907 r
.83991 .41521 .84068 .41627 .84683 .41436 .84606 .4133 Metetra
.664 .741 .907 r
.84606 .4133 .84683 .41436 .85299 .41245 .85223 .41139 Metetra
.664 .741 .907 r
.85223 .41139 .85299 .41245 .85916 .41054 .8584 .40947 Metetra
.664 .741 .907 r
.8584 .40947 .85916 .41054 .86535 .40863 .86459 .40756 Metetra
.664 .741 .907 r
.86459 .40756 .86535 .40863 .87401 .42961 .8708 .40563 Metetra
.577 .382 .58 r
.8708 .40563 .87401 .42961 .87776 .40478 .87701 .40371 Metetra
.643 .732 .913 r
.87701 .40371 .87776 .40478 .88399 .40285 .88328 .4021 Metetra
.679 .823 .953 r
.88328 .4021 .88399 .40285 .89023 .40092 .88949 .39984 Metetra
.664 .741 .907 r
.88949 .39984 .89023 .40092 .89648 .39898 .89574 .3979 Metetra
.664 .741 .907 r
.89574 .3979 .89648 .39898 .90275 .39704 .90201 .39596 Metetra
.664 .741 .907 r
.90201 .39596 .90275 .39704 .90903 .3951 .90829 .39401 Metetra
.664 .741 .907 r
.90829 .39401 .90903 .3951 .91532 .39315 .91459 .39206 Metetra
.664 .741 .907 r
.91459 .39206 .91532 .39315 .92163 .39119 .9209 .3901 Metetra
.664 .741 .907 r
.9209 .3901 .92163 .39119 .92795 .38924 .92722 .38814 Metetra
.664 .741 .907 r
.92722 .38814 .92795 .38924 .93428 .38727 .93356 .38618 Metetra
.664 .741 .907 r
.93356 .38618 .93428 .38727 .94063 .38531 .93991 .38421 Metetra
.664 .741 .907 r
.36492 .56125 .36588 .56215 .37107 .56054 .37011 .55964 Metetra
.664 .741 .907 r
.37011 .55964 .37107 .56054 .37627 .55893 .37531 .55803 Metetra
.664 .741 .907 r
.37531 .55803 .37627 .55893 .38148 .55731 .38052 .55641 Metetra
.664 .741 .907 r
.38052 .55641 .38148 .55731 .3867 .5557 .38575 .55479 Metetra
.664 .741 .907 r
.38575 .55479 .3867 .5557 .39193 .55408 .39098 .55317 Metetra
.946 .658 .462 r
.39098 .55317 .39193 .55408 .39559 .59416 .39415 .60562 Metetra
.39415 .60562 .39559 .59416 .40241 .55082 .40147 .54991 Metetra
.664 .741 .907 r
.40147 .54991 .40241 .55082 .40767 .54919 .40673 .54828 Metetra
.664 .741 .907 r
.40673 .54828 .40767 .54919 .41294 .54756 .412 .54665 Metetra
.664 .741 .907 r
.412 .54665 .41294 .54756 .41822 .54592 .41728 .54501 Metetra
.664 .741 .907 r
.41728 .54501 .41822 .54592 .42351 .54428 .42258 .54337 Metetra
.664 .741 .907 r
.42258 .54337 .42351 .54428 .42882 .54264 .42788 .54172 Metetra
.664 .741 .907 r
.42788 .54172 .42882 .54264 .43413 .54099 .43319 .54007 Metetra
.664 .741 .907 r
.43319 .54007 .43413 .54099 .43945 .53934 .43852 .53842 Metetra
.95 .645 .421 r
.43852 .53842 .43945 .53934 .44478 .53769 .44285 .57813 Metetra
.434 .241 .517 r
.44285 .57813 .44478 .53769 .45012 .53604 .44919 .53511 Metetra
.664 .741 .907 r
.44919 .53511 .45012 .53604 .45548 .53438 .45455 .53345 Metetra
.664 .741 .907 r
.45455 .53345 .45548 .53438 .46084 .53271 .45992 .53178 Metetra
.664 .741 .907 r
.45992 .53178 .46084 .53271 .46621 .53105 .46529 .53012 Metetra
.664 .741 .907 r
.46529 .53012 .46621 .53105 .4716 .52938 .47068 .52845 Metetra
.664 .741 .907 r
.47068 .52845 .4716 .52938 .477 .52771 .47608 .52677 Metetra
.664 .741 .907 r
.47608 .52677 .477 .52771 .4824 .52603 .48149 .52509 Metetra
.664 .741 .907 r
.48149 .52509 .4824 .52603 .48671 .62481 .4869 .52341 Metetra
.538 .339 .558 r
.4869 .52341 .48671 .62481 .49315 .53302 .49204 .55224 Metetra
.335 .151 .476 r
.49204 .55224 .49315 .53302 .49869 .52098 .49778 .52004 Metetra
.664 .741 .907 r
.49778 .52004 .49869 .52098 .50414 .51929 .50323 .51835 Metetra
.664 .741 .907 r
.50323 .51835 .50414 .51929 .5096 .5176 .50869 .51665 Metetra
.664 .741 .907 r
.50869 .51665 .5096 .5176 .51507 .5159 .51416 .51496 Metetra
.664 .741 .907 r
.51416 .51496 .51507 .5159 .52055 .5142 .51965 .51325 Metetra
.664 .741 .907 r
.51965 .51325 .52055 .5142 .52604 .5125 .52514 .51155 Metetra
.664 .741 .907 r
.52514 .51155 .52604 .5125 .53155 .51079 .53065 .50984 Metetra
.664 .741 .907 r
.53065 .50984 .53155 .51079 .53706 .50909 .53617 .50813 Metetra
.664 .741 .907 r
.53617 .50813 .53706 .50909 .54259 .50737 .5417 .50642 Metetra
.664 .741 .907 r
.5417 .50642 .54259 .50737 .54813 .50566 .54723 .5047 Metetra
.664 .741 .907 r
.54723 .5047 .54813 .50566 .55367 .50394 .55279 .50297 Metetra
.664 .741 .907 r
.55279 .50297 .55367 .50394 .55923 .50221 .55835 .50125 Metetra
.664 .741 .907 r
.55835 .50125 .55923 .50221 .5648 .50049 .56392 .49952 Metetra
.664 .741 .907 r
.56392 .49952 .5648 .50049 .57049 .50606 .5695 .49779 Metetra
.593 .424 .621 r
.5695 .49779 .57049 .50606 .57598 .49702 .5751 .49605 Metetra
.925 .536 .18 r
.5751 .49605 .57598 .49702 .58158 .49528 .58104 .51387 Metetra
.431 .229 .504 r
.58104 .51387 .58158 .49528 .5872 .49354 .58633 .49257 Metetra
.664 .741 .907 r
.58633 .49257 .5872 .49354 .59283 .4918 .59196 .49082 Metetra
.664 .741 .907 r
.59196 .49082 .59283 .4918 .59847 .49005 .5976 .48907 Metetra
.664 .741 .907 r
.5976 .48907 .59847 .49005 .60412 .4883 .60325 .48732 Metetra
.664 .741 .907 r
.60325 .48732 .60412 .4883 .60978 .48654 .60891 .48556 Metetra
.664 .741 .907 r
.60891 .48556 .60978 .48654 .61545 .48479 .61459 .4838 Metetra
.664 .741 .907 r
.61459 .4838 .61545 .48479 .62114 .48302 .62028 .48204 Metetra
.664 .741 .907 r
.62028 .48204 .62114 .48302 .62683 .48126 .62597 .48027 Metetra
.664 .741 .907 r
.62597 .48027 .62683 .48126 .63254 .47949 .63168 .4785 Metetra
.664 .741 .907 r
.63168 .4785 .63254 .47949 .63826 .47772 .63741 .47673 Metetra
.664 .741 .907 r
.63741 .47673 .63826 .47772 .64399 .47594 .64314 .47495 Metetra
.664 .741 .907 r
.64314 .47495 .64399 .47594 .64973 .47416 .64888 .47316 Metetra
.664 .741 .907 r
.64888 .47316 .64973 .47416 .65549 .47237 .65464 .47138 Metetra
.664 .741 .907 r
.65464 .47138 .65549 .47237 .66126 .47059 .66041 .46959 Metetra
.664 .741 .907 r
.66041 .46959 .66126 .47059 .66703 .4688 .66619 .4678 Metetra
.664 .741 .907 r
.66619 .4678 .66703 .4688 .67282 .467 .67198 .466 Metetra
.664 .741 .907 r
.67198 .466 .67282 .467 .67874 .46769 .67779 .4642 Metetra
.622 .507 .701 r
.67779 .4642 .67874 .46769 .68444 .4634 .6836 .46239 Metetra
.664 .741 .907 r
.6836 .46239 .68444 .4634 .69027 .46159 .68943 .46059 Metetra
.664 .741 .907 r
.68943 .46059 .69027 .46159 .6961 .45978 .69527 .45877 Metetra
.664 .741 .907 r
.69527 .45877 .6961 .45978 .70195 .45797 .70113 .45696 Metetra
.664 .741 .907 r
.70113 .45696 .70195 .45797 .70782 .45615 .70699 .45514 Metetra
.664 .741 .907 r
.70699 .45514 .70782 .45615 .71369 .45433 .71287 .45332 Metetra
.664 .741 .907 r
.71287 .45332 .71369 .45433 .71958 .45251 .71876 .45149 Metetra
.664 .741 .907 r
.71876 .45149 .71958 .45251 .72547 .45068 .72466 .44966 Metetra
.664 .741 .907 r
.72466 .44966 .72547 .45068 .73138 .44885 .73057 .44782 Metetra
.664 .741 .907 r
.73057 .44782 .73138 .44885 .73731 .44701 .7365 .44599 Metetra
.664 .741 .907 r
.7365 .44599 .73731 .44701 .74324 .44517 .74243 .44414 Metetra
.664 .741 .907 r
.74243 .44414 .74324 .44517 .74919 .44333 .74838 .4423 Metetra
.664 .741 .907 r
.74838 .4423 .74919 .44333 .75515 .44148 .75435 .44045 Metetra
.664 .741 .907 r
.75435 .44045 .75515 .44148 .76112 .43963 .76032 .4386 Metetra
.664 .741 .907 r
.76032 .4386 .76112 .43963 .76711 .43777 .76631 .43674 Metetra
.664 .741 .907 r
.76631 .43674 .76711 .43777 .77311 .43592 .77231 .43488 Metetra
.664 .741 .907 r
.77231 .43488 .77311 .43592 .77912 .43405 .77832 .43301 Metetra
.664 .741 .907 r
.77832 .43301 .77912 .43405 .78514 .43219 .78435 .43114 Metetra
.664 .741 .907 r
.78435 .43114 .78514 .43219 .79117 .43031 .79039 .42927 Metetra
.664 .741 .907 r
.79039 .42927 .79117 .43031 .79722 .42844 .79644 .42739 Metetra
.664 .741 .907 r
.79644 .42739 .79722 .42844 .80328 .42656 .8025 .42551 Metetra
.664 .741 .907 r
.8025 .42551 .80328 .42656 .80936 .42468 .80858 .42363 Metetra
.664 .741 .907 r
.80858 .42363 .80936 .42468 .81544 .42279 .81466 .42174 Metetra
.664 .741 .907 r
.81466 .42174 .81544 .42279 .82154 .4209 .82077 .41985 Metetra
.664 .741 .907 r
.82077 .41985 .82154 .4209 .82765 .41901 .82688 .41795 Metetra
.664 .741 .907 r
.82688 .41795 .82765 .41901 .83378 .41711 .83301 .41605 Metetra
.664 .741 .907 r
.83301 .41605 .83378 .41711 .83991 .41521 .83915 .41414 Metetra
.664 .741 .907 r
.83915 .41414 .83991 .41521 .84606 .4133 .8453 .41223 Metetra
.664 .741 .907 r
.8453 .41223 .84606 .4133 .85223 .41139 .85147 .41032 Metetra
.664 .741 .907 r
.85147 .41032 .85223 .41139 .8584 .40947 .85765 .4084 Metetra
.664 .741 .907 r
.85765 .4084 .8584 .40947 .86459 .40756 .86384 .40648 Metetra
.664 .741 .907 r
.86384 .40648 .86459 .40756 .8708 .40563 .87005 .40456 Metetra
.664 .741 .907 r
.87005 .40456 .8708 .40563 .87701 .40371 .87627 .40263 Metetra
0 0 .406 r
.87627 .40263 .87701 .40371 .88328 .4021 .88393 .41362 Metetra
.433 .225 .496 r
.88393 .41362 .88328 .4021 .88949 .39984 .88874 .39876 Metetra
.664 .741 .907 r
.88874 .39876 .88949 .39984 .89574 .3979 .895 .39682 Metetra
.664 .741 .907 r
.895 .39682 .89574 .3979 .90201 .39596 .90127 .39487 Metetra
.664 .741 .907 r
.90127 .39487 .90201 .39596 .90829 .39401 .90756 .39292 Metetra
.664 .741 .907 r
.90756 .39292 .90829 .39401 .91459 .39206 .91386 .39097 Metetra
.664 .741 .907 r
.91386 .39097 .91459 .39206 .9209 .3901 .92017 .38901 Metetra
.664 .741 .907 r
.92017 .38901 .9209 .3901 .92722 .38814 .9265 .38705 Metetra
.664 .741 .907 r
.9265 .38705 .92722 .38814 .93356 .38618 .93284 .38508 Metetra
.664 .741 .907 r
.93284 .38508 .93356 .38618 .93991 .38421 .93919 .38311 Metetra
.664 .741 .907 r
.36396 .56035 .36492 .56125 .37011 .55964 .36916 .55874 Metetra
.664 .741 .907 r
.36916 .55874 .37011 .55964 .37531 .55803 .37436 .55713 Metetra
.664 .741 .907 r
.37436 .55713 .37531 .55803 .38052 .55641 .37957 .55551 Metetra
.664 .741 .907 r
.37957 .55551 .38052 .55641 .38575 .55479 .38479 .55389 Metetra
.664 .741 .907 r
.38479 .55389 .38575 .55479 .39098 .55317 .39002 .55226 Metetra
.882 .449 .088 r
.39002 .55226 .39098 .55317 .39415 .60562 .39482 .56239 Metetra
.598 .392 .572 r
.39482 .56239 .39415 .60562 .40147 .54991 .40052 .54901 Metetra
.664 .741 .907 r
.40052 .54901 .40147 .54991 .40673 .54828 .40578 .54737 Metetra
.664 .741 .907 r
.40578 .54737 .40673 .54828 .412 .54665 .41106 .54573 Metetra
.664 .741 .907 r
.41106 .54573 .412 .54665 .41728 .54501 .41634 .54409 Metetra
.664 .741 .907 r
.41634 .54409 .41728 .54501 .42258 .54337 .42164 .54245 Metetra
.664 .741 .907 r
.42164 .54245 .42258 .54337 .42788 .54172 .42694 .5408 Metetra
.664 .741 .907 r
.42694 .5408 .42788 .54172 .43319 .54007 .43226 .53915 Metetra
.664 .741 .907 r
.43226 .53915 .43319 .54007 .43852 .53842 .43758 .5375 Metetra
.948 .675 .488 r
.43758 .5375 .43852 .53842 .44285 .57813 .43955 .67371 Metetra
.366 .192 .509 r
.43955 .67371 .44285 .57813 .44919 .53511 .44826 .53418 Metetra
.664 .741 .907 r
.44826 .53418 .44919 .53511 .45455 .53345 .45362 .53252 Metetra
.664 .741 .907 r
.45362 .53252 .45455 .53345 .45992 .53178 .45899 .53085 Metetra
.664 .741 .907 r
.45899 .53085 .45992 .53178 .46529 .53012 .46437 .52918 Metetra
.664 .741 .907 r
.46437 .52918 .46529 .53012 .47068 .52845 .46976 .52751 Metetra
.664 .741 .907 r
.46976 .52751 .47068 .52845 .47608 .52677 .47516 .52584 Metetra
.664 .741 .907 r
.47516 .52584 .47608 .52677 .48149 .52509 .48057 .52416 Metetra
.664 .741 .907 r
.48057 .52416 .48149 .52509 .4869 .52341 .48599 .52247 Metetra
.664 .741 .907 r
.48599 .52247 .4869 .52341 .49204 .55224 .49142 .52079 Metetra
.575 .376 .574 r
.49142 .52079 .49204 .55224 .49778 .52004 .49686 .5191 Metetra
.664 .741 .907 r
.49686 .5191 .49778 .52004 .50323 .51835 .50232 .5174 Metetra
.664 .741 .907 r
.50232 .5174 .50323 .51835 .50869 .51665 .50778 .51571 Metetra
.664 .741 .907 r
.50778 .51571 .50869 .51665 .51416 .51496 .51326 .51401 Metetra
.664 .741 .907 r
.51326 .51401 .51416 .51496 .51965 .51325 .51875 .5123 Metetra
.664 .741 .907 r
.51875 .5123 .51965 .51325 .52514 .51155 .52424 .5106 Metetra
.664 .741 .907 r
.52424 .5106 .52514 .51155 .53065 .50984 .52975 .50889 Metetra
.664 .741 .907 r
.52975 .50889 .53065 .50984 .53617 .50813 .53527 .50717 Metetra
.664 .741 .907 r
.53527 .50717 .53617 .50813 .5417 .50642 .5408 .50546 Metetra
.664 .741 .907 r
.5408 .50546 .5417 .50642 .54723 .5047 .54634 .50374 Metetra
.664 .741 .907 r
.54634 .50374 .54723 .5047 .55279 .50297 .5519 .50201 Metetra
.664 .741 .907 r
.5519 .50201 .55279 .50297 .55835 .50125 .55746 .50029 Metetra
.664 .741 .907 r
.55746 .50029 .55835 .50125 .56392 .49952 .56304 .49856 Metetra
.664 .741 .907 r
.56304 .49856 .56392 .49952 .5695 .49779 .56862 .49682 Metetra
.664 .741 .907 r
.56862 .49682 .5695 .49779 .5751 .49605 .57422 .49508 Metetra
.961 .657 .404 r
.57422 .49508 .5751 .49605 .58104 .51387 .58092 .55946 Metetra
.38 .203 .512 r
.58092 .55946 .58104 .51387 .58633 .49257 .58545 .4916 Metetra
.664 .741 .907 r
.58545 .4916 .58633 .49257 .59196 .49082 .59108 .48985 Metetra
.664 .741 .907 r
.59108 .48985 .59196 .49082 .5976 .48907 .59672 .4881 Metetra
.664 .741 .907 r
.59672 .4881 .5976 .48907 .60325 .48732 .60238 .48634 Metetra
.664 .741 .907 r
.60238 .48634 .60325 .48732 .60891 .48556 .60805 .48458 Metetra
.664 .741 .907 r
.60805 .48458 .60891 .48556 .61459 .4838 .61372 .48282 Metetra
.664 .741 .907 r
.61372 .48282 .61459 .4838 .62028 .48204 .61941 .48105 Metetra
.664 .741 .907 r
.61941 .48105 .62028 .48204 .62597 .48027 .62511 .47928 Metetra
.664 .741 .907 r
.62511 .47928 .62597 .48027 .63168 .4785 .63083 .47751 Metetra
.664 .741 .907 r
.63083 .47751 .63168 .4785 .63741 .47673 .63655 .47573 Metetra
.664 .741 .907 r
.63655 .47573 .63741 .47673 .64314 .47495 .64229 .47395 Metetra
.664 .741 .907 r
.64229 .47395 .64314 .47495 .64888 .47316 .64803 .47217 Metetra
.664 .741 .907 r
.64803 .47217 .64888 .47316 .65464 .47138 .65379 .47038 Metetra
.664 .741 .907 r
.65379 .47038 .65464 .47138 .66041 .46959 .65957 .46859 Metetra
.664 .741 .907 r
.65957 .46859 .66041 .46959 .66619 .4678 .66535 .46679 Metetra
.664 .741 .907 r
.66535 .46679 .66619 .4678 .67198 .466 .67114 .46499 Metetra
.664 .741 .907 r
.67114 .46499 .67198 .466 .67779 .4642 .67695 .46319 Metetra
.664 .741 .907 r
.67695 .46319 .67779 .4642 .6836 .46239 .68277 .46139 Metetra
.664 .741 .907 r
.68277 .46139 .6836 .46239 .68943 .46059 .6886 .45958 Metetra
.664 .741 .907 r
.6886 .45958 .68943 .46059 .69527 .45877 .69444 .45776 Metetra
.664 .741 .907 r
.69444 .45776 .69527 .45877 .70113 .45696 .7003 .45594 Metetra
.664 .741 .907 r
.7003 .45594 .70113 .45696 .70699 .45514 .70617 .45412 Metetra
.664 .741 .907 r
.70617 .45412 .70699 .45514 .71287 .45332 .71204 .4523 Metetra
.664 .741 .907 r
.71204 .4523 .71287 .45332 .71876 .45149 .71794 .45047 Metetra
.225 .518 .914 r
.71794 .45047 .71876 .45149 .72466 .44966 .72409 .45282 Metetra
.316 .034 .317 r
.72409 .45282 .72466 .44966 .73057 .44782 .72976 .4468 Metetra
.664 .741 .907 r
.72976 .4468 .73057 .44782 .7365 .44599 .73568 .44496 Metetra
.664 .741 .907 r
.73568 .44496 .7365 .44599 .74243 .44414 .74162 .44312 Metetra
.664 .741 .907 r
.74162 .44312 .74243 .44414 .74838 .4423 .74758 .44127 Metetra
.664 .741 .907 r
.74758 .44127 .74838 .4423 .75435 .44045 .75354 .43942 Metetra
.664 .741 .907 r
.75354 .43942 .75435 .44045 .76032 .4386 .75952 .43756 Metetra
.664 .741 .907 r
.75952 .43756 .76032 .4386 .76631 .43674 .76551 .4357 Metetra
.664 .741 .907 r
.76551 .4357 .76631 .43674 .77231 .43488 .77151 .43384 Metetra
.664 .741 .907 r
.77151 .43384 .77231 .43488 .77832 .43301 .77753 .43197 Metetra
.664 .741 .907 r
.77753 .43197 .77832 .43301 .78435 .43114 .78356 .4301 Metetra
.664 .741 .907 r
.78356 .4301 .78435 .43114 .79039 .42927 .7896 .42822 Metetra
.664 .741 .907 r
.7896 .42822 .79039 .42927 .79644 .42739 .79565 .42634 Metetra
.664 .741 .907 r
.79565 .42634 .79644 .42739 .8025 .42551 .80172 .42446 Metetra
.664 .741 .907 r
.80172 .42446 .8025 .42551 .80858 .42363 .80779 .42257 Metetra
.664 .741 .907 r
.80779 .42257 .80858 .42363 .81466 .42174 .81389 .42068 Metetra
.664 .741 .907 r
.81389 .42068 .81466 .42174 .82077 .41985 .81999 .41879 Metetra
.664 .741 .907 r
.81999 .41879 .82077 .41985 .82688 .41795 .82611 .41689 Metetra
.664 .741 .907 r
.82611 .41689 .82688 .41795 .83301 .41605 .83224 .41499 Metetra
.664 .741 .907 r
.83224 .41499 .83301 .41605 .83915 .41414 .83838 .41308 Metetra
.664 .741 .907 r
.83838 .41308 .83915 .41414 .8453 .41223 .84454 .41117 Metetra
.664 .741 .907 r
.84454 .41117 .8453 .41223 .85147 .41032 .85071 .40925 Metetra
.664 .741 .907 r
.85071 .40925 .85147 .41032 .85765 .4084 .85689 .40733 Metetra
.664 .741 .907 r
.85689 .40733 .85765 .4084 .86384 .40648 .86309 .40541 Metetra
.664 .741 .907 r
.86309 .40541 .86384 .40648 .87005 .40456 .86929 .40348 Metetra
.664 .741 .907 r
.86929 .40348 .87005 .40456 .87627 .40263 .87552 .40155 Metetra
.925 .559 .138 r
.87552 .40155 .87627 .40263 .88393 .41362 .88624 .44018 Metetra
.398 .221 .521 r
.88624 .44018 .88393 .41362 .88874 .39876 .888 .39768 Metetra
.664 .741 .907 r
.888 .39768 .88874 .39876 .895 .39682 .89426 .39573 Metetra
.664 .741 .907 r
.89426 .39573 .895 .39682 .90127 .39487 .90054 .39378 Metetra
.664 .741 .907 r
.90054 .39378 .90127 .39487 .90756 .39292 .90682 .39183 Metetra
.664 .741 .907 r
.90682 .39183 .90756 .39292 .91386 .39097 .91313 .38988 Metetra
.664 .741 .907 r
.91313 .38988 .91386 .39097 .92017 .38901 .91944 .38791 Metetra
.664 .741 .907 r
.91944 .38791 .92017 .38901 .9265 .38705 .92577 .38595 Metetra
.664 .741 .907 r
.92577 .38595 .9265 .38705 .93284 .38508 .93211 .38398 Metetra
.664 .741 .907 r
.93211 .38398 .93284 .38508 .93919 .38311 .93847 .38201 Metetra
.664 .741 .907 r
.363 .55945 .36396 .56035 .36916 .55874 .3682 .55784 Metetra
.664 .741 .907 r
.3682 .55784 .36916 .55874 .37436 .55713 .3734 .55622 Metetra
.664 .741 .907 r
.3734 .55622 .37436 .55713 .37957 .55551 .37861 .55461 Metetra
.664 .741 .907 r
.37861 .55461 .37957 .55551 .38479 .55389 .38384 .55298 Metetra
.664 .741 .907 r
.38384 .55298 .38479 .55389 .39002 .55226 .38907 .55136 Metetra
.664 .741 .907 r
.38907 .55136 .39002 .55226 .39482 .56239 .39432 .54973 Metetra
.584 .4 .598 r
.39432 .54973 .39482 .56239 .40052 .54901 .39957 .54809 Metetra
.664 .741 .907 r
.39957 .54809 .40052 .54901 .40578 .54737 .40484 .54646 Metetra
.664 .741 .907 r
.40484 .54646 .40578 .54737 .41106 .54573 .41011 .54482 Metetra
.664 .741 .907 r
.41011 .54482 .41106 .54573 .41634 .54409 .4154 .54318 Metetra
.664 .741 .907 r
.4154 .54318 .41634 .54409 .42164 .54245 .42069 .54153 Metetra
.664 .741 .907 r
.42069 .54153 .42164 .54245 .42694 .5408 .426 .53988 Metetra
.664 .741 .907 r
.426 .53988 .42694 .5408 .43226 .53915 .43132 .53823 Metetra
.664 .741 .907 r
.43132 .53823 .43226 .53915 .43758 .5375 .43665 .53658 Metetra
.947 .679 .497 r
.43665 .53658 .43758 .5375 .43955 .67371 .43663 .7519 Metetra
.026 0 .392 r
.43663 .7519 .43955 .67371 .44826 .53418 .44733 .53326 Metetra
.664 .741 .907 r
.44733 .53326 .44826 .53418 .45362 .53252 .45269 .53159 Metetra
.664 .741 .907 r
.45269 .53159 .45362 .53252 .45899 .53085 .45806 .52992 Metetra
.664 .741 .907 r
.45806 .52992 .45899 .53085 .46437 .52918 .46344 .52825 Metetra
.664 .741 .907 r
.46344 .52825 .46437 .52918 .46976 .52751 .46883 .52658 Metetra
.664 .741 .907 r
.46883 .52658 .46976 .52751 .47516 .52584 .47424 .5249 Metetra
.664 .741 .907 r
.47424 .5249 .47516 .52584 .48057 .52416 .47965 .52322 Metetra
.664 .741 .907 r
.47965 .52322 .48057 .52416 .48599 .52247 .48507 .52153 Metetra
.664 .741 .907 r
.48507 .52153 .48599 .52247 .49142 .52079 .49051 .51984 Metetra
.664 .741 .907 r
.49051 .51984 .49142 .52079 .49686 .5191 .49595 .51815 Metetra
.664 .741 .907 r
.49595 .51815 .49686 .5191 .50232 .5174 .50141 .51646 Metetra
.664 .741 .907 r
.50141 .51646 .50232 .5174 .50778 .51571 .50687 .51476 Metetra
.664 .741 .907 r
.50687 .51476 .50778 .51571 .51326 .51401 .51235 .51306 Metetra
.664 .741 .907 r
.51235 .51306 .51326 .51401 .51875 .5123 .51784 .51135 Metetra
.664 .741 .907 r
.51784 .51135 .51875 .5123 .52424 .5106 .52334 .50964 Metetra
.664 .741 .907 r
.52334 .50964 .52424 .5106 .52975 .50889 .52885 .50793 Metetra
.664 .741 .907 r
.52885 .50793 .52975 .50889 .53527 .50717 .53437 .50622 Metetra
.664 .741 .907 r
.53437 .50622 .53527 .50717 .5408 .50546 .53991 .5045 Metetra
.664 .741 .907 r
.53991 .5045 .5408 .50546 .54634 .50374 .54545 .50278 Metetra
.664 .741 .907 r
.54545 .50278 .54634 .50374 .5519 .50201 .55101 .50105 Metetra
.664 .741 .907 r
.55101 .50105 .5519 .50201 .55746 .50029 .55657 .49932 Metetra
.664 .741 .907 r
.55657 .49932 .55746 .50029 .56304 .49856 .56215 .49759 Metetra
.664 .741 .907 r
.56215 .49759 .56304 .49856 .56862 .49682 .56774 .49585 Metetra
.951 .601 .297 r
.56774 .49585 .56862 .49682 .57422 .49508 .57376 .52282 Metetra
.601 .372 .541 r
.57376 .52282 .57422 .49508 .58092 .55946 .57963 .53432 Metetra
.696 .472 .58 r
.57963 .53432 .58092 .55946 .58545 .4916 .58457 .49062 Metetra
.664 .741 .907 r
.58457 .49062 .58545 .4916 .59108 .48985 .59021 .48887 Metetra
.664 .741 .907 r
.59021 .48887 .59108 .48985 .59672 .4881 .59585 .48712 Metetra
.664 .741 .907 r
.59585 .48712 .59672 .4881 .60238 .48634 .60151 .48536 Metetra
.664 .741 .907 r
.60151 .48536 .60238 .48634 .60805 .48458 .60718 .4836 Metetra
.664 .741 .907 r
.60718 .4836 .60805 .48458 .61372 .48282 .61286 .48184 Metetra
.664 .741 .907 r
.61286 .48184 .61372 .48282 .61941 .48105 .61855 .48007 Metetra
.664 .741 .907 r
.61855 .48007 .61941 .48105 .62511 .47928 .62425 .4783 Metetra
.664 .741 .907 r
.62425 .4783 .62511 .47928 .63083 .47751 .62997 .47652 Metetra
.664 .741 .907 r
.62997 .47652 .63083 .47751 .63655 .47573 .6357 .47474 Metetra
.664 .741 .907 r
.6357 .47474 .63655 .47573 .64229 .47395 .64143 .47296 Metetra
.664 .741 .907 r
.64143 .47296 .64229 .47395 .64803 .47217 .64718 .47117 Metetra
.664 .741 .907 r
.64718 .47117 .64803 .47217 .65379 .47038 .65295 .46938 Metetra
.664 .741 .907 r
.65295 .46938 .65379 .47038 .65957 .46859 .65872 .46759 Metetra
.664 .741 .907 r
.65872 .46759 .65957 .46859 .66535 .46679 .6645 .46579 Metetra
.664 .741 .907 r
.6645 .46579 .66535 .46679 .67114 .46499 .6703 .46399 Metetra
.664 .741 .907 r
.6703 .46399 .67114 .46499 .67695 .46319 .67611 .46219 Metetra
.664 .741 .907 r
.67611 .46219 .67695 .46319 .68277 .46139 .68193 .46038 Metetra
.664 .741 .907 r
.68193 .46038 .68277 .46139 .6886 .45958 .68777 .45856 Metetra
.664 .741 .907 r
.68777 .45856 .6886 .45958 .69444 .45776 .69361 .45675 Metetra
.664 .741 .907 r
.69361 .45675 .69444 .45776 .7003 .45594 .69947 .45493 Metetra
.664 .741 .907 r
.69947 .45493 .7003 .45594 .70617 .45412 .70534 .45311 Metetra
.664 .741 .907 r
.70534 .45311 .70617 .45412 .71204 .4523 .71122 .45128 Metetra
.664 .741 .907 r
.71122 .45128 .71204 .4523 .71794 .45047 .71711 .44945 Metetra
.664 .741 .907 r
.71711 .44945 .71794 .45047 .72409 .45282 .72302 .44761 Metetra
.607 .461 .658 r
.72302 .44761 .72409 .45282 .72976 .4468 .72894 .44577 Metetra
.664 .741 .907 r
.72894 .44577 .72976 .4468 .73568 .44496 .73487 .44393 Metetra
.664 .741 .907 r
.73487 .44393 .73568 .44496 .74162 .44312 .74081 .44209 Metetra
.664 .741 .907 r
.74081 .44209 .74162 .44312 .74758 .44127 .74677 .44024 Metetra
.664 .741 .907 r
.74677 .44024 .74758 .44127 .75354 .43942 .75274 .43838 Metetra
.664 .741 .907 r
.75274 .43838 .75354 .43942 .75952 .43756 .75872 .43652 Metetra
.664 .741 .907 r
.75872 .43652 .75952 .43756 .76551 .4357 .76471 .43466 Metetra
.664 .741 .907 r
.76471 .43466 .76551 .4357 .77151 .43384 .77072 .4328 Metetra
.664 .741 .907 r
.77072 .4328 .77151 .43384 .77753 .43197 .77673 .43093 Metetra
.664 .741 .907 r
.77673 .43093 .77753 .43197 .78356 .4301 .78276 .42905 Metetra
.664 .741 .907 r
.78276 .42905 .78356 .4301 .7896 .42822 .78881 .42718 Metetra
.664 .741 .907 r
.78881 .42718 .7896 .42822 .79565 .42634 .79486 .42529 Metetra
.664 .741 .907 r
.79486 .42529 .79565 .42634 .80172 .42446 .80093 .42341 Metetra
.664 .741 .907 r
.80093 .42341 .80172 .42446 .80779 .42257 .80701 .42152 Metetra
.664 .741 .907 r
.80701 .42152 .80779 .42257 .81389 .42068 .81311 .41963 Metetra
.664 .741 .907 r
.81311 .41963 .81389 .42068 .81999 .41879 .81921 .41773 Metetra
.664 .741 .907 r
.81921 .41773 .81999 .41879 .82611 .41689 .82534 .41583 Metetra
.664 .741 .907 r
.82534 .41583 .82611 .41689 .83224 .41499 .83147 .41392 Metetra
.664 .741 .907 r
.83147 .41392 .83224 .41499 .83838 .41308 .83761 .41201 Metetra
.664 .741 .907 r
.83761 .41201 .83838 .41308 .84454 .41117 .84377 .4101 Metetra
.664 .741 .907 r
.84377 .4101 .84454 .41117 .85071 .40925 .84995 .40818 Metetra
.664 .741 .907 r
.84995 .40818 .85071 .40925 .85689 .40733 .85613 .40626 Metetra
.664 .741 .907 r
.85613 .40626 .85689 .40733 .86309 .40541 .86233 .40434 Metetra
.664 .741 .907 r
.86233 .40434 .86309 .40541 .86929 .40348 .86854 .40241 Metetra
.664 .741 .907 r
.86854 .40241 .86929 .40348 .87552 .40155 .87477 .40047 Metetra
.664 .741 .907 r
.87477 .40047 .87552 .40155 .88624 .44018 .881 .39853 Metetra
.573 .372 .57 r
.881 .39853 .88624 .44018 .888 .39768 .88725 .39659 Metetra
.664 .741 .907 r
.88725 .39659 .888 .39768 .89426 .39573 .89352 .39465 Metetra
.664 .741 .907 r
.89352 .39465 .89426 .39573 .90054 .39378 .8998 .3927 Metetra
.664 .741 .907 r
.8998 .3927 .90054 .39378 .90682 .39183 .90609 .39074 Metetra
.664 .741 .907 r
.90609 .39074 .90682 .39183 .91313 .38988 .91239 .38878 Metetra
.664 .741 .907 r
.91239 .38878 .91313 .38988 .91944 .38791 .91871 .38682 Metetra
.664 .741 .907 r
.91871 .38682 .91944 .38791 .92577 .38595 .92505 .38485 Metetra
.664 .741 .907 r
.92505 .38485 .92577 .38595 .93211 .38398 .93139 .38288 Metetra
.664 .741 .907 r
.93139 .38288 .93211 .38398 .93847 .38201 .93775 .38091 Metetra
.664 .741 .907 r
.36204 .55856 .363 .55945 .3682 .55784 .36723 .55694 Metetra
.921 .53 .224 r
.36723 .55694 .3682 .55784 .3734 .55622 .37178 .56996 Metetra
.404 .193 .476 r
.37178 .56996 .3734 .55622 .37861 .55461 .37766 .5537 Metetra
.664 .741 .907 r
.37766 .5537 .37861 .55461 .38384 .55298 .38288 .55208 Metetra
.664 .741 .907 r
.38288 .55208 .38384 .55298 .38907 .55136 .38812 .55045 Metetra
.664 .741 .907 r
.38812 .55045 .38907 .55136 .39432 .54973 .39336 .54882 Metetra
.664 .741 .907 r
.39336 .54882 .39432 .54973 .39957 .54809 .39862 .54718 Metetra
.664 .741 .907 r
.39862 .54718 .39957 .54809 .40484 .54646 .40389 .54554 Metetra
.664 .741 .907 r
.40389 .54554 .40484 .54646 .41011 .54482 .40917 .5439 Metetra
.664 .741 .907 r
.40917 .5439 .41011 .54482 .4154 .54318 .41445 .54226 Metetra
.664 .741 .907 r
.41445 .54226 .4154 .54318 .42069 .54153 .41975 .54061 Metetra
.664 .741 .907 r
.41975 .54061 .42069 .54153 .426 .53988 .42506 .53896 Metetra
.664 .741 .907 r
.42506 .53896 .426 .53988 .43132 .53823 .43038 .53731 Metetra
.664 .741 .907 r
.43038 .53731 .43132 .53823 .43665 .53658 .43571 .53565 Metetra
.947 .678 .493 r
.43571 .53565 .43665 .53658 .43663 .7519 .43666 .7096 Metetra
.788 .547 .572 r
.43666 .7096 .43663 .7519 .44733 .53326 .4464 .53233 Metetra
.664 .741 .907 r
.4464 .53233 .44733 .53326 .45269 .53159 .45176 .53066 Metetra
.664 .741 .907 r
.45176 .53066 .45269 .53159 .45806 .52992 .45714 .52899 Metetra
.664 .741 .907 r
.45714 .52899 .45806 .52992 .46344 .52825 .46252 .52732 Metetra
.664 .741 .907 r
.46252 .52732 .46344 .52825 .46883 .52658 .46791 .52564 Metetra
.664 .741 .907 r
.46791 .52564 .46883 .52658 .47424 .5249 .47332 .52396 Metetra
.664 .741 .907 r
.47332 .52396 .47424 .5249 .47965 .52322 .47873 .52228 Metetra
.664 .741 .907 r
.47873 .52228 .47965 .52322 .48507 .52153 .48416 .52059 Metetra
.664 .741 .907 r
.48416 .52059 .48507 .52153 .49051 .51984 .48959 .5189 Metetra
.664 .741 .907 r
.48959 .5189 .49051 .51984 .49595 .51815 .49504 .51721 Metetra
.664 .741 .907 r
.49504 .51721 .49595 .51815 .50141 .51646 .5005 .51551 Metetra
.664 .741 .907 r
.5005 .51551 .50141 .51646 .50687 .51476 .50597 .51381 Metetra
.664 .741 .907 r
.50597 .51381 .50687 .51476 .51235 .51306 .51145 .51211 Metetra
.664 .741 .907 r
.51145 .51211 .51235 .51306 .51784 .51135 .51694 .5104 Metetra
.664 .741 .907 r
.51694 .5104 .51784 .51135 .52334 .50964 .52244 .50869 Metetra
.664 .741 .907 r
.52244 .50869 .52334 .50964 .52885 .50793 .52795 .50698 Metetra
.664 .741 .907 r
.52795 .50698 .52885 .50793 .53437 .50622 .53348 .50526 Metetra
.664 .741 .907 r
.53348 .50526 .53437 .50622 .53991 .5045 .53901 .50354 Metetra
.664 .741 .907 r
.53901 .50354 .53991 .5045 .54545 .50278 .54456 .50181 Metetra
.664 .741 .907 r
.54456 .50181 .54545 .50278 .55101 .50105 .55011 .50009 Metetra
.664 .741 .907 r
.55011 .50009 .55101 .50105 .55657 .49932 .55568 .49835 Metetra
.664 .741 .907 r
.55568 .49835 .55657 .49932 .56215 .49759 .56126 .49662 Metetra
.664 .741 .907 r
.56126 .49662 .56215 .49759 .56774 .49585 .56685 .49488 Metetra
.959 .639 .369 r
.56685 .49488 .56774 .49585 .57376 .52282 .57309 .53768 Metetra
.668 .417 .531 r
.57309 .53768 .57376 .52282 .57963 .53432 .57915 .55888 Metetra
.113 0 .421 r
.57915 .55888 .57963 .53432 .58457 .49062 .58369 .48965 Metetra
.664 .741 .907 r
.58369 .48965 .58457 .49062 .59021 .48887 .58933 .48789 Metetra
.664 .741 .907 r
.58933 .48789 .59021 .48887 .59585 .48712 .59498 .48614 Metetra
.664 .741 .907 r
.59498 .48614 .59585 .48712 .60151 .48536 .60064 .48438 Metetra
.664 .741 .907 r
.60064 .48438 .60151 .48536 .60718 .4836 .60631 .48262 Metetra
.664 .741 .907 r
.60631 .48262 .60718 .4836 .61286 .48184 .61199 .48085 Metetra
.664 .741 .907 r
.61199 .48085 .61286 .48184 .61855 .48007 .61769 .47908 Metetra
.664 .741 .907 r
.61769 .47908 .61855 .48007 .62425 .4783 .62339 .47731 Metetra
.664 .741 .907 r
.62339 .47731 .62425 .4783 .62997 .47652 .62911 .47553 Metetra
.664 .741 .907 r
.62911 .47553 .62997 .47652 .6357 .47474 .63484 .47375 Metetra
.664 .741 .907 r
.63484 .47375 .6357 .47474 .64143 .47296 .64058 .47196 Metetra
.664 .741 .907 r
.64058 .47196 .64143 .47296 .64718 .47117 .64633 .47017 Metetra
.664 .741 .907 r
.64633 .47017 .64718 .47117 .65295 .46938 .6521 .46838 Metetra
.664 .741 .907 r
.6521 .46838 .65295 .46938 .65872 .46759 .65787 .46659 Metetra
.664 .741 .907 r
.65787 .46659 .65872 .46759 .6645 .46579 .66366 .46479 Metetra
.664 .741 .907 r
.66366 .46479 .6645 .46579 .6703 .46399 .66946 .46298 Metetra
.664 .741 .907 r
.66946 .46298 .6703 .46399 .67611 .46219 .67527 .46118 Metetra
.664 .741 .907 r
.67527 .46118 .67611 .46219 .68193 .46038 .6811 .45937 Metetra
.664 .741 .907 r
.6811 .45937 .68193 .46038 .68777 .45856 .68693 .45755 Metetra
.664 .741 .907 r
.68693 .45755 .68777 .45856 .69361 .45675 .69278 .45573 Metetra
.664 .741 .907 r
.69278 .45573 .69361 .45675 .69947 .45493 .69864 .45391 Metetra
.664 .741 .907 r
.69864 .45391 .69947 .45493 .70534 .45311 .70451 .45209 Metetra
.664 .741 .907 r
.70451 .45209 .70534 .45311 .71122 .45128 .7104 .45026 Metetra
.963 .634 .317 r
.7104 .45026 .71122 .45128 .71711 .44945 .7196 .50497 Metetra
.454 .265 .534 r
.7196 .50497 .71711 .44945 .72302 .44761 .7222 .44659 Metetra
.664 .741 .907 r
.7222 .44659 .72302 .44761 .72894 .44577 .72812 .44475 Metetra
.664 .741 .907 r
.72812 .44475 .72894 .44577 .73487 .44393 .73406 .4429 Metetra
.664 .741 .907 r
.73406 .4429 .73487 .44393 .74081 .44209 .74 .44105 Metetra
.664 .741 .907 r
.74 .44105 .74081 .44209 .74677 .44024 .74596 .4392 Metetra
.664 .741 .907 r
.74596 .4392 .74677 .44024 .75274 .43838 .75193 .43735 Metetra
.664 .741 .907 r
.75193 .43735 .75274 .43838 .75872 .43652 .75791 .43549 Metetra
.664 .741 .907 r
.75791 .43549 .75872 .43652 .76471 .43466 .76391 .43362 Metetra
.664 .741 .907 r
.76391 .43362 .76471 .43466 .77072 .4328 .76992 .43175 Metetra
.664 .741 .907 r
.76992 .43175 .77072 .4328 .77673 .43093 .77594 .42988 Metetra
.664 .741 .907 r
.77594 .42988 .77673 .43093 .78276 .42905 .78197 .42801 Metetra
.664 .741 .907 r
.78197 .42801 .78276 .42905 .78881 .42718 .78802 .42613 Metetra
.664 .741 .907 r
.78802 .42613 .78881 .42718 .79486 .42529 .79408 .42424 Metetra
.664 .741 .907 r
.79408 .42424 .79486 .42529 .80093 .42341 .80015 .42236 Metetra
.664 .741 .907 r
.80015 .42236 .80093 .42341 .80701 .42152 .80623 .42046 Metetra
.664 .741 .907 r
.80623 .42046 .80701 .42152 .81311 .41963 .81233 .41857 Metetra
.664 .741 .907 r
.81233 .41857 .81311 .41963 .81921 .41773 .81844 .41667 Metetra
.664 .741 .907 r
.81844 .41667 .81921 .41773 .82534 .41583 .82456 .41477 Metetra
.664 .741 .907 r
.82456 .41477 .82534 .41583 .83147 .41392 .8307 .41286 Metetra
.664 .741 .907 r
.8307 .41286 .83147 .41392 .83761 .41201 .83685 .41095 Metetra
.664 .741 .907 r
.83685 .41095 .83761 .41201 .84377 .4101 .84301 .40903 Metetra
.664 .741 .907 r
.84301 .40903 .84377 .4101 .84995 .40818 .84918 .40711 Metetra
.664 .741 .907 r
.84918 .40711 .84995 .40818 .85613 .40626 .85537 .40519 Metetra
.664 .741 .907 r
.85537 .40519 .85613 .40626 .86233 .40434 .86157 .40326 Metetra
.664 .741 .907 r
.86157 .40326 .86233 .40434 .86854 .40241 .86779 .40133 Metetra
.664 .741 .907 r
.86779 .40133 .86854 .40241 .87477 .40047 .87401 .39939 Metetra
.664 .741 .907 r
.87401 .39939 .87477 .40047 .881 .39853 .88025 .39745 Metetra
.664 .741 .907 r
.88025 .39745 .881 .39853 .88725 .39659 .88651 .39551 Metetra
.664 .741 .907 r
.88651 .39551 .88725 .39659 .89352 .39465 .89278 .39356 Metetra
.664 .741 .907 r
.89278 .39356 .89352 .39465 .8998 .3927 .89906 .39161 Metetra
.664 .741 .907 r
.89906 .39161 .8998 .3927 .90609 .39074 .90535 .38965 Metetra
.664 .741 .907 r
.90535 .38965 .90609 .39074 .91239 .38878 .91166 .38769 Metetra
.664 .741 .907 r
.91166 .38769 .91239 .38878 .91871 .38682 .91798 .38572 Metetra
.664 .741 .907 r
.91798 .38572 .91871 .38682 .92505 .38485 .92432 .38375 Metetra
.664 .741 .907 r
.92432 .38375 .92505 .38485 .93139 .38288 .93067 .38178 Metetra
.664 .741 .907 r
.93067 .38178 .93139 .38288 .93775 .38091 .93703 .3798 Metetra
.664 .741 .907 r
.36107 .55765 .36204 .55856 .36723 .55694 .36627 .55604 Metetra
.767 .279 0 r
.36627 .55604 .36723 .55694 .37178 .56996 .37109 .563 Metetra
.686 .499 .628 r
.37109 .563 .37178 .56996 .37766 .5537 .3767 .55279 Metetra
.664 .741 .907 r
.3767 .55279 .37766 .5537 .38288 .55208 .38193 .55117 Metetra
.664 .741 .907 r
.38193 .55117 .38288 .55208 .38812 .55045 .38716 .54954 Metetra
.664 .741 .907 r
.38716 .54954 .38812 .55045 .39336 .54882 .39241 .54791 Metetra
.664 .741 .907 r
.39241 .54791 .39336 .54882 .39862 .54718 .39767 .54627 Metetra
.664 .741 .907 r
.39767 .54627 .39862 .54718 .40389 .54554 .40294 .54463 Metetra
.664 .741 .907 r
.40294 .54463 .40389 .54554 .40917 .5439 .40822 .54299 Metetra
.664 .741 .907 r
.40822 .54299 .40917 .5439 .41445 .54226 .41351 .54134 Metetra
.664 .741 .907 r
.41351 .54134 .41445 .54226 .41975 .54061 .41881 .53969 Metetra
.664 .741 .907 r
.41881 .53969 .41975 .54061 .42506 .53896 .42412 .53804 Metetra
.664 .741 .907 r
.42412 .53804 .42506 .53896 .43038 .53731 .42944 .53639 Metetra
.664 .741 .907 r
.42944 .53639 .43038 .53731 .43571 .53565 .43477 .53473 Metetra
.949 .668 .472 r
.43477 .53473 .43571 .53565 .43666 .7096 .43796 .61855 Metetra
.65 .429 .57 r
.43796 .61855 .43666 .7096 .4464 .53233 .44547 .5314 Metetra
.664 .741 .907 r
.44547 .5314 .4464 .53233 .45176 .53066 .45083 .52973 Metetra
.664 .741 .907 r
.45083 .52973 .45176 .53066 .45714 .52899 .45621 .52806 Metetra
.664 .741 .907 r
.45621 .52806 .45714 .52899 .46252 .52732 .46159 .52638 Metetra
.664 .741 .907 r
.46159 .52638 .46252 .52732 .46791 .52564 .46699 .5247 Metetra
.664 .741 .907 r
.46699 .5247 .46791 .52564 .47332 .52396 .47239 .52302 Metetra
.664 .741 .907 r
.47239 .52302 .47332 .52396 .47873 .52228 .47781 .52134 Metetra
.664 .741 .907 r
.47781 .52134 .47873 .52228 .48416 .52059 .48324 .51965 Metetra
.664 .741 .907 r
.48324 .51965 .48416 .52059 .48959 .5189 .48868 .51796 Metetra
.664 .741 .907 r
.48868 .51796 .48959 .5189 .49504 .51721 .49412 .51626 Metetra
.715 .228 0 r
.49412 .51626 .49504 .51721 .5005 .51551 .49951 .52377 Metetra
.391 .165 .447 r
.49951 .52377 .5005 .51551 .50597 .51381 .50506 .51286 Metetra
.664 .741 .907 r
.50506 .51286 .50597 .51381 .51145 .51211 .51054 .51116 Metetra
.664 .741 .907 r
.51054 .51116 .51145 .51211 .51694 .5104 .51603 .50945 Metetra
.664 .741 .907 r
.51603 .50945 .51694 .5104 .52244 .50869 .52153 .50773 Metetra
.664 .741 .907 r
.52153 .50773 .52244 .50869 .52795 .50698 .52705 .50602 Metetra
.664 .741 .907 r
.52705 .50602 .52795 .50698 .53348 .50526 .53258 .5043 Metetra
.664 .741 .907 r
.53258 .5043 .53348 .50526 .53901 .50354 .53811 .50258 Metetra
.664 .741 .907 r
.53811 .50258 .53901 .50354 .54456 .50181 .54366 .50085 Metetra
.664 .741 .907 r
.54366 .50085 .54456 .50181 .55011 .50009 .54922 .49912 Metetra
.664 .741 .907 r
.54922 .49912 .55011 .50009 .55568 .49835 .55479 .49739 Metetra
.664 .741 .907 r
.55479 .49739 .55568 .49835 .56126 .49662 .56037 .49565 Metetra
.664 .741 .907 r
.56037 .49565 .56126 .49662 .56685 .49488 .56597 .49391 Metetra
.804 .346 0 r
.56597 .49391 .56685 .49488 .57309 .53768 .57174 .50402 Metetra
.407 .247 .55 r
.57174 .50402 .57309 .53768 .57915 .55888 .57811 .54889 Metetra
.83 .59 .575 r
.57811 .54889 .57915 .55888 .58369 .48965 .58282 .48867 Metetra
.664 .741 .907 r
.58282 .48867 .58369 .48965 .58933 .48789 .58845 .48692 Metetra
.664 .741 .907 r
.58845 .48692 .58933 .48789 .59498 .48614 .5941 .48516 Metetra
.664 .741 .907 r
.5941 .48516 .59498 .48614 .60064 .48438 .59977 .4834 Metetra
.664 .741 .907 r
.59977 .4834 .60064 .48438 .60631 .48262 .60544 .48163 Metetra
.664 .741 .907 r
.60544 .48163 .60631 .48262 .61199 .48085 .61112 .47986 Metetra
.664 .741 .907 r
.61112 .47986 .61199 .48085 .61769 .47908 .61682 .47809 Metetra
.664 .741 .907 r
.61682 .47809 .61769 .47908 .62339 .47731 .62253 .47631 Metetra
.664 .741 .907 r
.62253 .47631 .62339 .47731 .62911 .47553 .62825 .47454 Metetra
.664 .741 .907 r
.62825 .47454 .62911 .47553 .63484 .47375 .63398 .47275 Metetra
.664 .741 .907 r
.63398 .47275 .63484 .47375 .64058 .47196 .63972 .47097 Metetra
.664 .741 .907 r
.63972 .47097 .64058 .47196 .64633 .47017 .64548 .46917 Metetra
.664 .741 .907 r
.64548 .46917 .64633 .47017 .6521 .46838 .65125 .46738 Metetra
.664 .741 .907 r
.65125 .46738 .6521 .46838 .65787 .46659 .65702 .46558 Metetra
.664 .741 .907 r
.65702 .46558 .65787 .46659 .66366 .46479 .66281 .46378 Metetra
.664 .741 .907 r
.66281 .46378 .66366 .46479 .66946 .46298 .66862 .46198 Metetra
.664 .741 .907 r
.66862 .46198 .66946 .46298 .67527 .46118 .67443 .46017 Metetra
.664 .741 .907 r
.67443 .46017 .67527 .46118 .6811 .45937 .68026 .45835 Metetra
.664 .741 .907 r
.68026 .45835 .6811 .45937 .68693 .45755 .6861 .45654 Metetra
.664 .741 .907 r
.6861 .45654 .68693 .45755 .69278 .45573 .69195 .45472 Metetra
.664 .741 .907 r
.69195 .45472 .69278 .45573 .69864 .45391 .69781 .45289 Metetra
.664 .741 .907 r
.69781 .45289 .69864 .45391 .70451 .45209 .70368 .45107 Metetra
.664 .741 .907 r
.70368 .45107 .70451 .45209 .7104 .45026 .70957 .44924 Metetra
.664 .741 .907 r
.70957 .44924 .7104 .45026 .7196 .50497 .71547 .4474 Metetra
.571 .367 .566 r
.71547 .4474 .7196 .50497 .7222 .44659 .72138 .44556 Metetra
.664 .741 .907 r
.72138 .44556 .7222 .44659 .72812 .44475 .7273 .44372 Metetra
.664 .741 .907 r
.7273 .44372 .72812 .44475 .73406 .4429 .73324 .44187 Metetra
.664 .741 .907 r
.73324 .44187 .73406 .4429 .74 .44105 .73919 .44002 Metetra
.664 .741 .907 r
.73919 .44002 .74 .44105 .74596 .4392 .74515 .43817 Metetra
.664 .741 .907 r
.74515 .43817 .74596 .4392 .75193 .43735 .75112 .43631 Metetra
.664 .741 .907 r
.75112 .43631 .75193 .43735 .75791 .43549 .75711 .43445 Metetra
.664 .741 .907 r
.75711 .43445 .75791 .43549 .76391 .43362 .76311 .43258 Metetra
.664 .741 .907 r
.76311 .43258 .76391 .43362 .76992 .43175 .76912 .43071 Metetra
.664 .741 .907 r
.76912 .43071 .76992 .43175 .77594 .42988 .77514 .42884 Metetra
.664 .741 .907 r
.77514 .42884 .77594 .42988 .78197 .42801 .78118 .42696 Metetra
.664 .741 .907 r
.78118 .42696 .78197 .42801 .78802 .42613 .78723 .42508 Metetra
.664 .741 .907 r
.78723 .42508 .78802 .42613 .79408 .42424 .79329 .42319 Metetra
.664 .741 .907 r
.79329 .42319 .79408 .42424 .80015 .42236 .79936 .4213 Metetra
.664 .741 .907 r
.79936 .4213 .80015 .42236 .80623 .42046 .80545 .41941 Metetra
.664 .741 .907 r
.80545 .41941 .80623 .42046 .81233 .41857 .81155 .41751 Metetra
.664 .741 .907 r
.81155 .41751 .81233 .41857 .81844 .41667 .81766 .41561 Metetra
.664 .741 .907 r
.81766 .41561 .81844 .41667 .82456 .41477 .82379 .4137 Metetra
.664 .741 .907 r
.82379 .4137 .82456 .41477 .8307 .41286 .82992 .41179 Metetra
.664 .741 .907 r
.82992 .41179 .8307 .41286 .83685 .41095 .83608 .40988 Metetra
.664 .741 .907 r
.83608 .40988 .83685 .41095 .84301 .40903 .84224 .40796 Metetra
.664 .741 .907 r
.84224 .40796 .84301 .40903 .84918 .40711 .84842 .40604 Metetra
.664 .741 .907 r
.84842 .40604 .84918 .40711 .85537 .40519 .85461 .40411 Metetra
.664 .741 .907 r
.85461 .40411 .85537 .40519 .86157 .40326 .86081 .40218 Metetra
.664 .741 .907 r
.86081 .40218 .86157 .40326 .86779 .40133 .86703 .40025 Metetra
.664 .741 .907 r
.86703 .40025 .86779 .40133 .87401 .39939 .87326 .39831 Metetra
.664 .741 .907 r
.87326 .39831 .87401 .39939 .88025 .39745 .87951 .39637 Metetra
.664 .741 .907 r
.87951 .39637 .88025 .39745 .88651 .39551 .88576 .39442 Metetra
.664 .741 .907 r
.88576 .39442 .88651 .39551 .89278 .39356 .89203 .39247 Metetra
.664 .741 .907 r
.89203 .39247 .89278 .39356 .89906 .39161 .89832 .39052 Metetra
.664 .741 .907 r
.89832 .39052 .89906 .39161 .90535 .38965 .90462 .38856 Metetra
.664 .741 .907 r
.90462 .38856 .90535 .38965 .91166 .38769 .91093 .38659 Metetra
.664 .741 .907 r
.91093 .38659 .91166 .38769 .91798 .38572 .91725 .38462 Metetra
.664 .741 .907 r
.91725 .38462 .91798 .38572 .92432 .38375 .92359 .38265 Metetra
.664 .741 .907 r
.92359 .38265 .92432 .38375 .93067 .38178 .92994 .38068 Metetra
.664 .741 .907 r
.92994 .38068 .93067 .38178 .93703 .3798 .93631 .3787 Metetra
.664 .741 .907 r
.36011 .55675 .36107 .55765 .36627 .55604 .36531 .55513 Metetra
.943 .61 .37 r
.36531 .55513 .36627 .55604 .37109 .563 .36943 .5772 Metetra
.286 .096 .439 r
.36943 .5772 .37109 .563 .3767 .55279 .37574 .55189 Metetra
.664 .741 .907 r
.37574 .55189 .3767 .55279 .38193 .55117 .38097 .55026 Metetra
.664 .741 .907 r
.38097 .55026 .38193 .55117 .38716 .54954 .38621 .54863 Metetra
.664 .741 .907 r
.38621 .54863 .38716 .54954 .39241 .54791 .39146 .54699 Metetra
.664 .741 .907 r
.39146 .54699 .39241 .54791 .39767 .54627 .39672 .54536 Metetra
.664 .741 .907 r
.39672 .54536 .39767 .54627 .40294 .54463 .40199 .54371 Metetra
.664 .741 .907 r
.40199 .54371 .40294 .54463 .40822 .54299 .40727 .54207 Metetra
.664 .741 .907 r
.40727 .54207 .40822 .54299 .41351 .54134 .41256 .54042 Metetra
.664 .741 .907 r
.41256 .54042 .41351 .54134 .41881 .53969 .41787 .53877 Metetra
.664 .741 .907 r
.41787 .53877 .41881 .53969 .42412 .53804 .42318 .53712 Metetra
.664 .741 .907 r
.42318 .53712 .42412 .53804 .42944 .53639 .4285 .53546 Metetra
.664 .741 .907 r
.4285 .53546 .42944 .53639 .43477 .53473 .43384 .5338 Metetra
.664 .741 .907 r
.43384 .5338 .43477 .53473 .43796 .61855 .43918 .53214 Metetra
.569 .364 .562 r
.43918 .53214 .43796 .61855 .44547 .5314 .44453 .53047 Metetra
.664 .741 .907 r
.44453 .53047 .44547 .5314 .45083 .52973 .4499 .5288 Metetra
.664 .741 .907 r
.4499 .5288 .45083 .52973 .45621 .52806 .45528 .52712 Metetra
.664 .741 .907 r
.45528 .52712 .45621 .52806 .46159 .52638 .46066 .52545 Metetra
.664 .741 .907 r
.46066 .52545 .46159 .52638 .46699 .5247 .46606 .52377 Metetra
.664 .741 .907 r
.46606 .52377 .46699 .5247 .47239 .52302 .47147 .52208 Metetra
.664 .741 .907 r
.47147 .52208 .47239 .52302 .47781 .52134 .47689 .5204 Metetra
.664 .741 .907 r
.47689 .5204 .47781 .52134 .48324 .51965 .48232 .51871 Metetra
.664 .741 .907 r
.48232 .51871 .48324 .51965 .48868 .51796 .48776 .51701 Metetra
.664 .741 .907 r
.48776 .51701 .48868 .51796 .49412 .51626 .49321 .51531 Metetra
.664 .741 .907 r
.49321 .51531 .49412 .51626 .49951 .52377 .49867 .51361 Metetra
.588 .411 .609 r
.49867 .51361 .49951 .52377 .50506 .51286 .50414 .51191 Metetra
.664 .741 .907 r
.50414 .51191 .50506 .51286 .51054 .51116 .50963 .5102 Metetra
.664 .741 .907 r
.50963 .5102 .51054 .51116 .51603 .50945 .51512 .50849 Metetra
.664 .741 .907 r
.51512 .50849 .51603 .50945 .52153 .50773 .52063 .50678 Metetra
.664 .741 .907 r
.52063 .50678 .52153 .50773 .52705 .50602 .52615 .50506 Metetra
.664 .741 .907 r
.52615 .50506 .52705 .50602 .53258 .5043 .53168 .50334 Metetra
.664 .741 .907 r
.53168 .50334 .53258 .5043 .53811 .50258 .53722 .50161 Metetra
.664 .741 .907 r
.53722 .50161 .53811 .50258 .54366 .50085 .54277 .49989 Metetra
.664 .741 .907 r
.54277 .49989 .54366 .50085 .54922 .49912 .54833 .49815 Metetra
.664 .741 .907 r
.54833 .49815 .54922 .49912 .55479 .49739 .5539 .49642 Metetra
.664 .741 .907 r
.5539 .49642 .55479 .49739 .56037 .49565 .55949 .49468 Metetra
.664 .741 .907 r
.55949 .49468 .56037 .49565 .56597 .49391 .56508 .49294 Metetra
.664 .741 .907 r
.56508 .49294 .56597 .49391 .57174 .50402 .57069 .49119 Metetra
.066 .021 .49 r
.57069 .49119 .57174 .50402 .57811 .54889 .57694 .5305 Metetra
.725 .499 .583 r
.57694 .5305 .57811 .54889 .58282 .48867 .58194 .48769 Metetra
.664 .741 .907 r
.58194 .48769 .58282 .48867 .58845 .48692 .58758 .48594 Metetra
.664 .741 .907 r
.58758 .48594 .58845 .48692 .5941 .48516 .59323 .48418 Metetra
.664 .741 .907 r
.59323 .48418 .5941 .48516 .59977 .4834 .59889 .48241 Metetra
.664 .741 .907 r
.59889 .48241 .59977 .4834 .60544 .48163 .60457 .48065 Metetra
.664 .741 .907 r
.60457 .48065 .60544 .48163 .61112 .47986 .61026 .47887 Metetra
.664 .741 .907 r
.61026 .47887 .61112 .47986 .61682 .47809 .61596 .4771 Metetra
.664 .741 .907 r
.61596 .4771 .61682 .47809 .62253 .47631 .62167 .47532 Metetra
.664 .741 .907 r
.62167 .47532 .62253 .47631 .62825 .47454 .62739 .47354 Metetra
.664 .741 .907 r
.62739 .47354 .62825 .47454 .63398 .47275 .63312 .47176 Metetra
.664 .741 .907 r
.63312 .47176 .63398 .47275 .63972 .47097 .63887 .46997 Metetra
.664 .741 .907 r
.63887 .46997 .63972 .47097 .64548 .46917 .64462 .46817 Metetra
.664 .741 .907 r
.64462 .46817 .64548 .46917 .65125 .46738 .65039 .46638 Metetra
.664 .741 .907 r
.65039 .46638 .65125 .46738 .65702 .46558 .65617 .46458 Metetra
.664 .741 .907 r
.65617 .46458 .65702 .46558 .66281 .46378 .66197 .46278 Metetra
.664 .741 .907 r
.66197 .46278 .66281 .46378 .66862 .46198 .66777 .46097 Metetra
.664 .741 .907 r
.66777 .46097 .66862 .46198 .67443 .46017 .67359 .45916 Metetra
.664 .741 .907 r
.67359 .45916 .67443 .46017 .68026 .45835 .67942 .45734 Metetra
.664 .741 .907 r
.67942 .45734 .68026 .45835 .6861 .45654 .68526 .45552 Metetra
.664 .741 .907 r
.68526 .45552 .6861 .45654 .69195 .45472 .69111 .4537 Metetra
.664 .741 .907 r
.69111 .4537 .69195 .45472 .69781 .45289 .69698 .45188 Metetra
.664 .741 .907 r
.69698 .45188 .69781 .45289 .70368 .45107 .70285 .45005 Metetra
.664 .741 .907 r
.70285 .45005 .70368 .45107 .70957 .44924 .70874 .44821 Metetra
.664 .741 .907 r
.70874 .44821 .70957 .44924 .71547 .4474 .71464 .44638 Metetra
.664 .741 .907 r
.71464 .44638 .71547 .4474 .72138 .44556 .72056 .44453 Metetra
.664 .741 .907 r
.72056 .44453 .72138 .44556 .7273 .44372 .72649 .44269 Metetra
.664 .741 .907 r
.72649 .44269 .7273 .44372 .73324 .44187 .73242 .44084 Metetra
.664 .741 .907 r
.73242 .44084 .73324 .44187 .73919 .44002 .73837 .43899 Metetra
.664 .741 .907 r
.73837 .43899 .73919 .44002 .74515 .43817 .74434 .43713 Metetra
.664 .741 .907 r
.74434 .43713 .74515 .43817 .75112 .43631 .75031 .43527 Metetra
.664 .741 .907 r
.75031 .43527 .75112 .43631 .75711 .43445 .7563 .43341 Metetra
.664 .741 .907 r
.7563 .43341 .75711 .43445 .76311 .43258 .7623 .43154 Metetra
.664 .741 .907 r
.7623 .43154 .76311 .43258 .76912 .43071 .76832 .42967 Metetra
.664 .741 .907 r
.76832 .42967 .76912 .43071 .77514 .42884 .77434 .42779 Metetra
.664 .741 .907 r
.77434 .42779 .77514 .42884 .78118 .42696 .78038 .42591 Metetra
.664 .741 .907 r
.78038 .42591 .78118 .42696 .78723 .42508 .78643 .42403 Metetra
.664 .741 .907 r
.78643 .42403 .78723 .42508 .79329 .42319 .7925 .42214 Metetra
.664 .741 .907 r
.7925 .42214 .79329 .42319 .79936 .4213 .79857 .42025 Metetra
.664 .741 .907 r
.79857 .42025 .79936 .4213 .80545 .41941 .80466 .41835 Metetra
.664 .741 .907 r
.80466 .41835 .80545 .41941 .81155 .41751 .81077 .41645 Metetra
.664 .741 .907 r
.81077 .41645 .81155 .41751 .81766 .41561 .81688 .41455 Metetra
.664 .741 .907 r
.81688 .41455 .81766 .41561 .82379 .4137 .82301 .41264 Metetra
.664 .741 .907 r
.82301 .41264 .82379 .4137 .82992 .41179 .82915 .41073 Metetra
.664 .741 .907 r
.82915 .41073 .82992 .41179 .83608 .40988 .83531 .40881 Metetra
.664 .741 .907 r
.83531 .40881 .83608 .40988 .84224 .40796 .84147 .40689 Metetra
.664 .741 .907 r
.84147 .40689 .84224 .40796 .84842 .40604 .84765 .40497 Metetra
.664 .741 .907 r
.84765 .40497 .84842 .40604 .85461 .40411 .85385 .40304 Metetra
.664 .741 .907 r
.85385 .40304 .85461 .40411 .86081 .40218 .86005 .4011 Metetra
.664 .741 .907 r
.86005 .4011 .86081 .40218 .86703 .40025 .86628 .39917 Metetra
.664 .741 .907 r
.86628 .39917 .86703 .40025 .87326 .39831 .87251 .39723 Metetra
0 .022 .571 r
.87251 .39723 .87326 .39831 .87951 .39637 .87989 .40563 Metetra
.425 .209 .48 r
.87989 .40563 .87951 .39637 .88576 .39442 .88502 .39333 Metetra
.664 .741 .907 r
.88502 .39333 .88576 .39442 .89203 .39247 .89129 .39138 Metetra
.664 .741 .907 r
.89129 .39138 .89203 .39247 .89832 .39052 .89758 .38942 Metetra
.664 .741 .907 r
.89758 .38942 .89832 .39052 .90462 .38856 .90388 .38746 Metetra
.664 .741 .907 r
.90388 .38746 .90462 .38856 .91093 .38659 .91019 .3855 Metetra
.664 .741 .907 r
.91019 .3855 .91093 .38659 .91725 .38462 .91652 .38353 Metetra
.664 .741 .907 r
.91652 .38353 .91725 .38462 .92359 .38265 .92286 .38155 Metetra
.664 .741 .907 r
.92286 .38155 .92359 .38265 .92994 .38068 .92921 .37957 Metetra
.664 .741 .907 r
.92921 .37957 .92994 .38068 .93631 .3787 .93558 .37759 Metetra
.664 .741 .907 r
.35914 .55585 .36011 .55675 .36531 .55513 .36434 .55423 Metetra
.664 .741 .907 r
.36434 .55423 .36531 .55513 .36943 .5772 .36956 .55261 Metetra
.576 .379 .578 r
.36956 .55261 .36943 .5772 .37574 .55189 .37478 .55098 Metetra
.664 .741 .907 r
.37478 .55098 .37574 .55189 .38097 .55026 .38001 .54935 Metetra
.664 .741 .907 r
.38001 .54935 .38097 .55026 .38621 .54863 .38525 .54772 Metetra
.664 .741 .907 r
.38525 .54772 .38621 .54863 .39146 .54699 .3905 .54608 Metetra
.664 .741 .907 r
.3905 .54608 .39146 .54699 .39672 .54536 .39577 .54444 Metetra
.664 .741 .907 r
.39577 .54444 .39672 .54536 .40199 .54371 .40104 .5428 Metetra
.664 .741 .907 r
.40104 .5428 .40199 .54371 .40727 .54207 .40632 .54115 Metetra
.664 .741 .907 r
.40632 .54115 .40727 .54207 .41256 .54042 .41162 .5395 Metetra
.664 .741 .907 r
.41162 .5395 .41256 .54042 .41787 .53877 .41692 .53785 Metetra
.664 .741 .907 r
.41692 .53785 .41787 .53877 .42318 .53712 .42224 .53619 Metetra
.664 .741 .907 r
.42224 .53619 .42318 .53712 .4285 .53546 .42756 .53453 Metetra
.664 .741 .907 r
.42756 .53453 .4285 .53546 .43384 .5338 .4329 .53287 Metetra
.664 .741 .907 r
.4329 .53287 .43384 .5338 .43918 .53214 .43824 .53121 Metetra
.664 .741 .907 r
.43824 .53121 .43918 .53214 .44453 .53047 .4436 .52954 Metetra
.664 .741 .907 r
.4436 .52954 .44453 .53047 .4499 .5288 .44897 .52787 Metetra
.664 .741 .907 r
.44897 .52787 .4499 .5288 .45528 .52712 .45435 .52619 Metetra
.664 .741 .907 r
.45435 .52619 .45528 .52712 .46066 .52545 .45973 .52451 Metetra
.664 .741 .907 r
.45973 .52451 .46066 .52545 .46606 .52377 .46513 .52283 Metetra
.664 .741 .907 r
.46513 .52283 .46606 .52377 .47147 .52208 .47054 .52114 Metetra
.664 .741 .907 r
.47054 .52114 .47147 .52208 .47689 .5204 .47596 .51945 Metetra
.664 .741 .907 r
.47596 .51945 .47689 .5204 .48232 .51871 .4814 .51776 Metetra
.664 .741 .907 r
.4814 .51776 .48232 .51871 .48776 .51701 .48684 .51607 Metetra
.664 .741 .907 r
.48684 .51607 .48776 .51701 .49321 .51531 .49229 .51437 Metetra
.664 .741 .907 r
.49229 .51437 .49321 .51531 .49867 .51361 .49776 .51266 Metetra
.664 .741 .907 r
.49776 .51266 .49867 .51361 .50414 .51191 .50323 .51096 Metetra
.664 .741 .907 r
.50323 .51096 .50414 .51191 .50963 .5102 .50872 .50925 Metetra
.664 .741 .907 r
.50872 .50925 .50963 .5102 .51512 .50849 .51422 .50754 Metetra
.664 .741 .907 r
.51422 .50754 .51512 .50849 .52063 .50678 .51972 .50582 Metetra
.664 .741 .907 r
.51972 .50582 .52063 .50678 .52615 .50506 .52524 .5041 Metetra
.664 .741 .907 r
.52524 .5041 .52615 .50506 .53168 .50334 .53077 .50238 Metetra
.664 .741 .907 r
.53077 .50238 .53168 .50334 .53722 .50161 .53632 .50065 Metetra
.664 .741 .907 r
.53632 .50065 .53722 .50161 .54277 .49989 .54187 .49892 Metetra
.664 .741 .907 r
.54187 .49892 .54277 .49989 .54833 .49815 .54743 .49719 Metetra
.664 .741 .907 r
.54743 .49719 .54833 .49815 .5539 .49642 .55301 .49545 Metetra
.664 .741 .907 r
.55301 .49545 .5539 .49642 .55949 .49468 .5586 .49371 Metetra
.664 .741 .907 r
.5586 .49371 .55949 .49468 .56508 .49294 .56419 .49197 Metetra
.664 .741 .907 r
.56419 .49197 .56508 .49294 .57069 .49119 .5698 .49022 Metetra
.962 .673 .441 r
.5698 .49022 .57069 .49119 .57694 .5305 .57749 .62404 Metetra
.38 .208 .518 r
.57749 .62404 .57694 .5305 .58194 .48769 .58105 .48671 Metetra
.664 .741 .907 r
.58105 .48671 .58194 .48769 .58758 .48594 .5867 .48495 Metetra
.664 .741 .907 r
.5867 .48495 .58758 .48594 .59323 .48418 .59235 .48319 Metetra
.664 .741 .907 r
.59235 .48319 .59323 .48418 .59889 .48241 .59802 .48143 Metetra
.664 .741 .907 r
.59802 .48143 .59889 .48241 .60457 .48065 .6037 .47966 Metetra
.664 .741 .907 r
.6037 .47966 .60457 .48065 .61026 .47887 .60939 .47789 Metetra
.664 .741 .907 r
.60939 .47789 .61026 .47887 .61596 .4771 .61509 .47611 Metetra
.664 .741 .907 r
.61509 .47611 .61596 .4771 .62167 .47532 .6208 .47433 Metetra
.664 .741 .907 r
.6208 .47433 .62167 .47532 .62739 .47354 .62653 .47255 Metetra
.664 .741 .907 r
.62653 .47255 .62739 .47354 .63312 .47176 .63226 .47076 Metetra
.664 .741 .907 r
.63226 .47076 .63312 .47176 .63887 .46997 .63801 .46897 Metetra
.664 .741 .907 r
.63801 .46897 .63887 .46997 .64462 .46817 .64377 .46717 Metetra
.664 .741 .907 r
.64377 .46717 .64462 .46817 .65039 .46638 .64954 .46538 Metetra
.664 .741 .907 r
.64954 .46538 .65039 .46638 .65617 .46458 .65532 .46357 Metetra
.664 .741 .907 r
.65532 .46357 .65617 .46458 .66197 .46278 .66112 .46177 Metetra
.664 .741 .907 r
.66112 .46177 .66197 .46278 .66777 .46097 .66693 .45996 Metetra
.664 .741 .907 r
.66693 .45996 .66777 .46097 .67359 .45916 .67275 .45815 Metetra
.664 .741 .907 r
.67275 .45815 .67359 .45916 .67942 .45734 .67858 .45633 Metetra
.664 .741 .907 r
.67858 .45633 .67942 .45734 .68526 .45552 .68442 .45451 Metetra
.664 .741 .907 r
.68442 .45451 .68526 .45552 .69111 .4537 .69028 .45268 Metetra
.664 .741 .907 r
.69028 .45268 .69111 .4537 .69698 .45188 .69614 .45086 Metetra
.664 .741 .907 r
.69614 .45086 .69698 .45188 .70285 .45005 .70202 .44902 Metetra
.664 .741 .907 r
.70202 .44902 .70285 .45005 .70874 .44821 .70792 .44719 Metetra
.664 .741 .907 r
.70792 .44719 .70874 .44821 .71464 .44638 .71382 .44535 Metetra
.664 .741 .907 r
.71382 .44535 .71464 .44638 .72056 .44453 .71974 .44351 Metetra
.664 .741 .907 r
.71974 .44351 .72056 .44453 .72649 .44269 .72567 .44166 Metetra
.664 .741 .907 r
.72567 .44166 .72649 .44269 .73242 .44084 .73161 .43981 Metetra
.664 .741 .907 r
.73161 .43981 .73242 .44084 .73837 .43899 .73756 .43795 Metetra
.664 .741 .907 r
.73756 .43795 .73837 .43899 .74434 .43713 .74353 .43609 Metetra
.664 .741 .907 r
.74353 .43609 .74434 .43713 .75031 .43527 .7495 .43423 Metetra
.664 .741 .907 r
.7495 .43423 .75031 .43527 .7563 .43341 .7555 .43236 Metetra
.664 .741 .907 r
.7555 .43236 .7563 .43341 .7623 .43154 .7615 .43049 Metetra
.664 .741 .907 r
.7615 .43049 .7623 .43154 .76832 .42967 .76751 .42862 Metetra
.664 .741 .907 r
.76751 .42862 .76832 .42967 .77434 .42779 .77354 .42674 Metetra
.664 .741 .907 r
.77354 .42674 .77434 .42779 .78038 .42591 .77959 .42486 Metetra
.664 .741 .907 r
.77959 .42486 .78038 .42591 .78643 .42403 .78564 .42297 Metetra
.664 .741 .907 r
.78564 .42297 .78643 .42403 .7925 .42214 .79171 .42108 Metetra
.664 .741 .907 r
.79171 .42108 .7925 .42214 .79857 .42025 .79779 .41919 Metetra
.664 .741 .907 r
.79779 .41919 .79857 .42025 .80466 .41835 .80388 .41729 Metetra
.664 .741 .907 r
.80388 .41729 .80466 .41835 .81077 .41645 .80998 .41539 Metetra
.664 .741 .907 r
.80998 .41539 .81077 .41645 .81688 .41455 .8161 .41348 Metetra
.664 .741 .907 r
.8161 .41348 .81688 .41455 .82301 .41264 .82223 .41157 Metetra
.664 .741 .907 r
.82223 .41157 .82301 .41264 .82915 .41073 .82838 .40966 Metetra
.664 .741 .907 r
.82838 .40966 .82915 .41073 .83531 .40881 .83453 .40774 Metetra
.664 .741 .907 r
.83453 .40774 .83531 .40881 .84147 .40689 .84071 .40582 Metetra
.664 .741 .907 r
.84071 .40582 .84147 .40689 .84765 .40497 .84689 .40389 Metetra
.664 .741 .907 r
.84689 .40389 .84765 .40497 .85385 .40304 .85309 .40196 Metetra
.664 .741 .907 r
.85309 .40196 .85385 .40304 .86005 .4011 .8593 .40002 Metetra
.664 .741 .907 r
.8593 .40002 .86005 .4011 .86628 .39917 .86552 .39809 Metetra
0 0 .514 r
.86552 .39809 .86628 .39917 .87251 .39723 .87295 .40724 Metetra
.732 .446 .495 r
.87295 .40724 .87251 .39723 .87989 .40563 .88255 .4356 Metetra
.415 .234 .525 r
.88255 .4356 .87989 .40563 .88502 .39333 .88427 .39224 Metetra
.664 .741 .907 r
.88427 .39224 .88502 .39333 .89129 .39138 .89054 .39029 Metetra
.664 .741 .907 r
.89054 .39029 .89129 .39138 .89758 .38942 .89683 .38833 Metetra
.664 .741 .907 r
.89683 .38833 .89758 .38942 .90388 .38746 .90314 .38637 Metetra
.664 .741 .907 r
.90314 .38637 .90388 .38746 .91019 .3855 .90945 .3844 Metetra
.664 .741 .907 r
.90945 .3844 .91019 .3855 .91652 .38353 .91579 .38242 Metetra
.664 .741 .907 r
.91579 .38242 .91652 .38353 .92286 .38155 .92213 .38045 Metetra
.664 .741 .907 r
.92213 .38045 .92286 .38155 .92921 .37957 .92849 .37847 Metetra
.664 .741 .907 r
.92849 .37847 .92921 .37957 .93558 .37759 .93486 .37648 Metetra
.664 .741 .907 r
.35817 .55495 .35914 .55585 .36434 .55423 .36338 .55333 Metetra
.664 .741 .907 r
.36338 .55333 .36434 .55423 .36956 .55261 .36859 .5517 Metetra
.664 .741 .907 r
.36859 .5517 .36956 .55261 .37478 .55098 .37382 .55007 Metetra
.664 .741 .907 r
.37382 .55007 .37478 .55098 .38001 .54935 .37905 .54844 Metetra
.664 .741 .907 r
.37905 .54844 .38001 .54935 .38525 .54772 .38429 .5468 Metetra
.664 .741 .907 r
.38429 .5468 .38525 .54772 .3905 .54608 .38955 .54517 Metetra
.664 .741 .907 r
.38955 .54517 .3905 .54608 .39577 .54444 .39481 .54352 Metetra
.664 .741 .907 r
.39481 .54352 .39577 .54444 .40104 .5428 .40009 .54188 Metetra
.664 .741 .907 r
.40009 .54188 .40104 .5428 .40632 .54115 .40537 .54023 Metetra
.664 .741 .907 r
.40537 .54023 .40632 .54115 .41162 .5395 .41067 .53858 Metetra
.664 .741 .907 r
.41067 .53858 .41162 .5395 .41692 .53785 .41597 .53693 Metetra
.664 .741 .907 r
.41597 .53693 .41692 .53785 .42224 .53619 .42129 .53527 Metetra
.664 .741 .907 r
.42129 .53527 .42224 .53619 .42756 .53453 .42662 .53361 Metetra
.664 .741 .907 r
.42662 .53361 .42756 .53453 .4329 .53287 .43196 .53194 Metetra
.664 .741 .907 r
.43196 .53194 .4329 .53287 .43824 .53121 .4373 .53028 Metetra
.664 .741 .907 r
.4373 .53028 .43824 .53121 .4436 .52954 .44266 .52861 Metetra
.664 .741 .907 r
.44266 .52861 .4436 .52954 .44897 .52787 .44803 .52693 Metetra
.664 .741 .907 r
.44803 .52693 .44897 .52787 .45435 .52619 .45341 .52525 Metetra
.664 .741 .907 r
.45341 .52525 .45435 .52619 .45973 .52451 .4588 .52357 Metetra
.664 .741 .907 r
.4588 .52357 .45973 .52451 .46513 .52283 .46421 .52189 Metetra
.664 .741 .907 r
.46421 .52189 .46513 .52283 .47054 .52114 .46962 .5202 Metetra
.664 .741 .907 r
.46962 .5202 .47054 .52114 .47596 .51945 .47504 .51851 Metetra
.664 .741 .907 r
.47504 .51851 .47596 .51945 .4814 .51776 .48048 .51682 Metetra
.664 .741 .907 r
.48048 .51682 .4814 .51776 .48684 .51607 .48592 .51512 Metetra
.664 .741 .907 r
.48592 .51512 .48684 .51607 .49229 .51437 .49138 .51342 Metetra
.664 .741 .907 r
.49138 .51342 .49229 .51437 .49776 .51266 .49684 .51171 Metetra
.664 .741 .907 r
.49684 .51171 .49776 .51266 .50323 .51096 .50232 .51001 Metetra
.664 .741 .907 r
.50232 .51001 .50323 .51096 .50872 .50925 .50781 .50829 Metetra
.664 .741 .907 r
.50781 .50829 .50872 .50925 .51422 .50754 .51331 .50658 Metetra
.664 .741 .907 r
.51331 .50658 .51422 .50754 .51972 .50582 .51882 .50486 Metetra
.664 .741 .907 r
.51882 .50486 .51972 .50582 .52524 .5041 .52434 .50314 Metetra
.664 .741 .907 r
.52434 .50314 .52524 .5041 .53077 .50238 .52987 .50142 Metetra
.664 .741 .907 r
.52987 .50142 .53077 .50238 .53632 .50065 .53542 .49969 Metetra
.664 .741 .907 r
.53542 .49969 .53632 .50065 .54187 .49892 .54097 .49795 Metetra
.664 .741 .907 r
.54097 .49795 .54187 .49892 .54743 .49719 .54654 .49622 Metetra
.664 .741 .907 r
.54654 .49622 .54743 .49719 .55301 .49545 .55212 .49448 Metetra
.664 .741 .907 r
.55212 .49448 .55301 .49545 .5586 .49371 .5577 .49274 Metetra
.664 .741 .907 r
.5577 .49274 .5586 .49371 .56419 .49197 .5633 .49099 Metetra
.958 .634 .359 r
.5633 .49099 .56419 .49197 .5698 .49022 .56946 .53049 Metetra
.781 .523 .547 r
.56946 .53049 .5698 .49022 .57749 .62404 .57784 .70784 Metetra
.132 .019 .447 r
.57784 .70784 .57749 .62404 .58105 .48671 .58017 .48573 Metetra
.664 .741 .907 r
.58017 .48573 .58105 .48671 .5867 .48495 .58582 .48397 Metetra
.664 .741 .907 r
.58582 .48397 .5867 .48495 .59235 .48319 .59148 .48221 Metetra
.664 .741 .907 r
.59148 .48221 .59235 .48319 .59802 .48143 .59714 .48044 Metetra
.664 .741 .907 r
.59714 .48044 .59802 .48143 .6037 .47966 .60282 .47867 Metetra
.664 .741 .907 r
.60282 .47867 .6037 .47966 .60939 .47789 .60852 .4769 Metetra
.664 .741 .907 r
.60852 .4769 .60939 .47789 .61509 .47611 .61422 .47512 Metetra
.664 .741 .907 r
.61422 .47512 .61509 .47611 .6208 .47433 .61994 .47334 Metetra
.664 .741 .907 r
.61994 .47334 .6208 .47433 .62653 .47255 .62566 .47155 Metetra
.664 .741 .907 r
.62566 .47155 .62653 .47255 .63226 .47076 .6314 .46976 Metetra
.664 .741 .907 r
.6314 .46976 .63226 .47076 .63801 .46897 .63715 .46797 Metetra
.664 .741 .907 r
.63715 .46797 .63801 .46897 .64377 .46717 .64291 .46617 Metetra
.664 .741 .907 r
.64291 .46617 .64377 .46717 .64954 .46538 .64869 .46437 Metetra
.664 .741 .907 r
.64869 .46437 .64954 .46538 .65532 .46357 .65447 .46257 Metetra
.664 .741 .907 r
.65447 .46257 .65532 .46357 .66112 .46177 .66027 .46076 Metetra
.664 .741 .907 r
.66027 .46076 .66112 .46177 .66693 .45996 .66608 .45895 Metetra
.664 .741 .907 r
.66608 .45895 .66693 .45996 .67275 .45815 .6719 .45713 Metetra
.664 .741 .907 r
.6719 .45713 .67275 .45815 .67858 .45633 .67774 .45531 Metetra
.664 .741 .907 r
.67774 .45531 .67858 .45633 .68442 .45451 .68358 .45349 Metetra
.664 .741 .907 r
.68358 .45349 .68442 .45451 .69028 .45268 .68944 .45166 Metetra
.664 .741 .907 r
.68944 .45166 .69028 .45268 .69614 .45086 .69531 .44983 Metetra
.664 .741 .907 r
.69531 .44983 .69614 .45086 .70202 .44902 .70119 .448 Metetra
.664 .741 .907 r
.70119 .448 .70202 .44902 .70792 .44719 .70709 .44616 Metetra
.664 .741 .907 r
.70709 .44616 .70792 .44719 .71382 .44535 .71299 .44432 Metetra
.664 .741 .907 r
.71299 .44432 .71382 .44535 .71974 .44351 .71891 .44248 Metetra
.664 .741 .907 r
.71891 .44248 .71974 .44351 .72567 .44166 .72484 .44063 Metetra
.664 .741 .907 r
.72484 .44063 .72567 .44166 .73161 .43981 .73079 .43877 Metetra
.664 .741 .907 r
.73079 .43877 .73161 .43981 .73756 .43795 .73674 .43692 Metetra
.664 .741 .907 r
.73674 .43692 .73756 .43795 .74353 .43609 .74271 .43506 Metetra
.664 .741 .907 r
.74271 .43506 .74353 .43609 .7495 .43423 .74869 .43319 Metetra
.664 .741 .907 r
.74869 .43319 .7495 .43423 .7555 .43236 .75469 .43132 Metetra
.664 .741 .907 r
.75469 .43132 .7555 .43236 .7615 .43049 .76069 .42945 Metetra
.664 .741 .907 r
.76069 .42945 .7615 .43049 .76751 .42862 .76671 .42757 Metetra
.664 .741 .907 r
.76671 .42757 .76751 .42862 .77354 .42674 .77274 .42569 Metetra
.664 .741 .907 r
.77274 .42569 .77354 .42674 .77959 .42486 .77879 .42381 Metetra
.664 .741 .907 r
.77879 .42381 .77959 .42486 .78564 .42297 .78484 .42192 Metetra
.664 .741 .907 r
.78484 .42192 .78564 .42297 .79171 .42108 .79091 .42003 Metetra
.664 .741 .907 r
.79091 .42003 .79171 .42108 .79779 .41919 .797 .41813 Metetra
.664 .741 .907 r
.797 .41813 .79779 .41919 .80388 .41729 .80309 .41623 Metetra
.664 .741 .907 r
.80309 .41623 .80388 .41729 .80998 .41539 .8092 .41433 Metetra
.664 .741 .907 r
.8092 .41433 .80998 .41539 .8161 .41348 .81532 .41242 Metetra
.664 .741 .907 r
.81532 .41242 .8161 .41348 .82223 .41157 .82146 .4105 Metetra
.664 .741 .907 r
.82146 .4105 .82223 .41157 .82838 .40966 .8276 .40859 Metetra
.664 .741 .907 r
.8276 .40859 .82838 .40966 .83453 .40774 .83376 .40667 Metetra
.664 .741 .907 r
.83376 .40667 .83453 .40774 .84071 .40582 .83994 .40474 Metetra
.664 .741 .907 r
.83994 .40474 .84071 .40582 .84689 .40389 .84612 .40281 Metetra
.664 .741 .907 r
.84612 .40281 .84689 .40389 .85309 .40196 .85232 .40088 Metetra
.664 .741 .907 r
.85232 .40088 .85309 .40196 .8593 .40002 .85853 .39894 Metetra
.664 .741 .907 r
.85853 .39894 .8593 .40002 .86552 .39809 .86476 .397 Metetra
.664 .741 .907 r
.86476 .397 .86552 .39809 .87295 .40724 .871 .39506 Metetra
.397 .274 .594 r
.871 .39506 .87295 .40724 .88255 .4356 .87965 .41497 Metetra
.658 .441 .578 r
.87965 .41497 .88255 .4356 .88427 .39224 .88352 .39115 Metetra
.664 .741 .907 r
.88352 .39115 .88427 .39224 .89054 .39029 .8898 .3892 Metetra
.664 .741 .907 r
.8898 .3892 .89054 .39029 .89683 .38833 .89609 .38723 Metetra
.664 .741 .907 r
.89609 .38723 .89683 .38833 .90314 .38637 .9024 .38527 Metetra
.664 .741 .907 r
.9024 .38527 .90314 .38637 .90945 .3844 .90872 .3833 Metetra
.664 .741 .907 r
.90872 .3833 .90945 .3844 .91579 .38242 .91505 .38132 Metetra
.664 .741 .907 r
.91505 .38132 .91579 .38242 .92213 .38045 .9214 .37934 Metetra
.664 .741 .907 r
.9214 .37934 .92213 .38045 .92849 .37847 .92776 .37736 Metetra
.664 .741 .907 r
.92776 .37736 .92849 .37847 .93486 .37648 .93413 .37537 Metetra
.664 .741 .907 r
.35721 .55404 .35817 .55495 .36338 .55333 .36241 .55242 Metetra
.664 .741 .907 r
.36241 .55242 .36338 .55333 .36859 .5517 .36763 .55079 Metetra
.664 .741 .907 r
.36763 .55079 .36859 .5517 .37382 .55007 .37285 .54916 Metetra
.664 .741 .907 r
.37285 .54916 .37382 .55007 .37905 .54844 .37809 .54753 Metetra
.664 .741 .907 r
.37809 .54753 .37905 .54844 .38429 .5468 .38333 .54589 Metetra
.664 .741 .907 r
.38333 .54589 .38429 .5468 .38955 .54517 .38859 .54425 Metetra
.664 .741 .907 r
.38859 .54425 .38955 .54517 .39481 .54352 .39386 .54261 Metetra
.664 .741 .907 r
.39386 .54261 .39481 .54352 .40009 .54188 .39913 .54096 Metetra
.664 .741 .907 r
.39913 .54096 .40009 .54188 .40537 .54023 .40442 .53931 Metetra
.664 .741 .907 r
.40442 .53931 .40537 .54023 .41067 .53858 .40972 .53766 Metetra
.664 .741 .907 r
.40972 .53766 .41067 .53858 .41597 .53693 .41503 .536 Metetra
.664 .741 .907 r
.41503 .536 .41597 .53693 .42129 .53527 .42035 .53434 Metetra
.664 .741 .907 r
.42035 .53434 .42129 .53527 .42662 .53361 .42568 .53268 Metetra
.66 .74 .909 r
.42568 .53268 .42662 .53361 .43196 .53194 .43101 .53108 Metetra
.926 .543 .237 r
.43101 .53108 .43196 .53194 .4373 .53028 .43592 .54615 Metetra
.413 .206 .486 r
.43592 .54615 .4373 .53028 .44266 .52861 .44173 .52767 Metetra
.664 .741 .907 r
.44173 .52767 .44266 .52861 .44803 .52693 .4471 .526 Metetra
.664 .741 .907 r
.4471 .526 .44803 .52693 .45341 .52525 .45248 .52432 Metetra
.664 .741 .907 r
.45248 .52432 .45341 .52525 .4588 .52357 .45787 .52263 Metetra
.664 .741 .907 r
.45787 .52263 .4588 .52357 .46421 .52189 .46328 .52095 Metetra
.664 .741 .907 r
.46328 .52095 .46421 .52189 .46962 .5202 .46869 .51926 Metetra
.664 .741 .907 r
.46869 .51926 .46962 .5202 .47504 .51851 .47412 .51757 Metetra
.664 .741 .907 r
.47412 .51757 .47504 .51851 .48048 .51682 .47955 .51587 Metetra
.664 .741 .907 r
.47955 .51587 .48048 .51682 .48592 .51512 .485 .51417 Metetra
.664 .741 .907 r
.485 .51417 .48592 .51512 .49138 .51342 .49046 .51247 Metetra
.664 .741 .907 r
.49046 .51247 .49138 .51342 .49684 .51171 .49593 .51076 Metetra
.664 .741 .907 r
.49593 .51076 .49684 .51171 .50232 .51001 .50141 .50905 Metetra
.664 .741 .907 r
.50141 .50905 .50232 .51001 .50781 .50829 .5069 .50734 Metetra
.664 .741 .907 r
.5069 .50734 .50781 .50829 .51331 .50658 .5124 .50562 Metetra
.664 .741 .907 r
.5124 .50562 .51331 .50658 .51882 .50486 .51791 .5039 Metetra
.664 .741 .907 r
.51791 .5039 .51882 .50486 .52434 .50314 .52343 .50218 Metetra
.664 .741 .907 r
.52343 .50218 .52434 .50314 .52987 .50142 .52897 .50045 Metetra
.664 .741 .907 r
.52897 .50045 .52987 .50142 .53542 .49969 .53452 .49872 Metetra
.664 .741 .907 r
.53452 .49872 .53542 .49969 .54097 .49795 .54007 .49699 Metetra
.664 .741 .907 r
.54007 .49699 .54097 .49795 .54654 .49622 .54564 .49525 Metetra
.664 .741 .907 r
.54564 .49525 .54654 .49622 .55212 .49448 .55122 .49351 Metetra
.664 .741 .907 r
.55122 .49351 .55212 .49448 .5577 .49274 .55681 .49176 Metetra
.664 .741 .907 r
.55681 .49176 .5577 .49274 .5633 .49099 .56241 .49002 Metetra
.961 .665 .425 r
.56241 .49002 .5633 .49099 .56946 .53049 .56917 .576 Metetra
.688 .447 .552 r
.56917 .576 .56946 .53049 .57784 .70784 .57616 .65655 Metetra
.768 .523 .564 r
.57616 .65655 .57784 .70784 .58017 .48573 .57929 .48475 Metetra
.664 .741 .907 r
.57929 .48475 .58017 .48573 .58582 .48397 .58494 .48299 Metetra
.664 .741 .907 r
.58494 .48299 .58582 .48397 .59148 .48221 .5906 .48122 Metetra
.664 .741 .907 r
.5906 .48122 .59148 .48221 .59714 .48044 .59627 .47945 Metetra
.664 .741 .907 r
.59627 .47945 .59714 .48044 .60282 .47867 .60195 .47768 Metetra
.664 .741 .907 r
.60195 .47768 .60282 .47867 .60852 .4769 .60765 .4759 Metetra
.664 .741 .907 r
.60765 .4759 .60852 .4769 .61422 .47512 .61335 .47412 Metetra
.664 .741 .907 r
.61335 .47412 .61422 .47512 .61994 .47334 .61907 .47234 Metetra
.664 .741 .907 r
.61907 .47234 .61994 .47334 .62566 .47155 .6248 .47055 Metetra
.664 .741 .907 r
.6248 .47055 .62566 .47155 .6314 .46976 .63054 .46876 Metetra
.664 .741 .907 r
.63054 .46876 .6314 .46976 .63715 .46797 .63629 .46697 Metetra
.664 .741 .907 r
.63629 .46697 .63715 .46797 .64291 .46617 .64206 .46517 Metetra
.664 .741 .907 r
.64206 .46517 .64291 .46617 .64869 .46437 .64783 .46336 Metetra
.664 .741 .907 r
.64783 .46336 .64869 .46437 .65447 .46257 .65362 .46156 Metetra
.664 .741 .907 r
.65362 .46156 .65447 .46257 .66027 .46076 .65942 .45975 Metetra
.664 .741 .907 r
.65942 .45975 .66027 .46076 .66608 .45895 .66523 .45794 Metetra
.664 .741 .907 r
.66523 .45794 .66608 .45895 .6719 .45713 .67106 .45612 Metetra
.664 .741 .907 r
.67106 .45612 .6719 .45713 .67774 .45531 .67689 .4543 Metetra
.664 .741 .907 r
.67689 .4543 .67774 .45531 .68358 .45349 .68274 .45247 Metetra
.664 .741 .907 r
.68274 .45247 .68358 .45349 .68944 .45166 .6886 .45064 Metetra
.664 .741 .907 r
.6886 .45064 .68944 .45166 .69531 .44983 .69448 .44881 Metetra
.664 .741 .907 r
.69448 .44881 .69531 .44983 .70119 .448 .70036 .44698 Metetra
.664 .741 .907 r
.70036 .44698 .70119 .448 .70709 .44616 .70626 .44514 Metetra
.664 .741 .907 r
.70626 .44514 .70709 .44616 .71299 .44432 .71217 .44329 Metetra
.664 .741 .907 r
.71217 .44329 .71299 .44432 .71891 .44248 .71809 .44144 Metetra
.664 .741 .907 r
.71809 .44144 .71891 .44248 .72484 .44063 .72402 .43959 Metetra
.664 .741 .907 r
.72402 .43959 .72484 .44063 .73079 .43877 .72997 .43774 Metetra
.664 .741 .907 r
.72997 .43774 .73079 .43877 .73674 .43692 .73593 .43588 Metetra
.664 .741 .907 r
.73593 .43588 .73674 .43692 .74271 .43506 .7419 .43402 Metetra
.664 .741 .907 r
.7419 .43402 .74271 .43506 .74869 .43319 .74788 .43215 Metetra
.664 .741 .907 r
.74788 .43215 .74869 .43319 .75469 .43132 .75388 .43028 Metetra
.664 .741 .907 r
.75388 .43028 .75469 .43132 .76069 .42945 .75989 .4284 Metetra
.664 .741 .907 r
.75989 .4284 .76069 .42945 .76671 .42757 .76591 .42652 Metetra
.664 .741 .907 r
.76591 .42652 .76671 .42757 .77274 .42569 .77194 .42464 Metetra
.664 .741 .907 r
.77194 .42464 .77274 .42569 .77879 .42381 .77799 .42275 Metetra
.664 .741 .907 r
.77799 .42275 .77879 .42381 .78484 .42192 .78405 .42086 Metetra
.664 .741 .907 r
.78405 .42086 .78484 .42192 .79091 .42003 .79012 .41897 Metetra
.664 .741 .907 r
.79012 .41897 .79091 .42003 .797 .41813 .79621 .41707 Metetra
.664 .741 .907 r
.79621 .41707 .797 .41813 .80309 .41623 .80231 .41517 Metetra
.664 .741 .907 r
.80231 .41517 .80309 .41623 .8092 .41433 .80842 .41326 Metetra
.664 .741 .907 r
.80842 .41326 .8092 .41433 .81532 .41242 .81454 .41135 Metetra
.664 .741 .907 r
.81454 .41135 .81532 .41242 .82146 .4105 .82068 .40944 Metetra
.664 .741 .907 r
.82068 .40944 .82146 .4105 .8276 .40859 .82683 .40752 Metetra
.664 .741 .907 r
.82683 .40752 .8276 .40859 .83376 .40667 .83299 .40559 Metetra
.664 .741 .907 r
.83299 .40559 .83376 .40667 .83994 .40474 .83917 .40367 Metetra
.664 .741 .907 r
.83917 .40367 .83994 .40474 .84612 .40281 .84535 .40174 Metetra
.664 .741 .907 r
.84535 .40174 .84612 .40281 .85232 .40088 .85156 .3998 Metetra
.664 .741 .907 r
.85156 .3998 .85232 .40088 .85853 .39894 .85777 .39786 Metetra
.664 .741 .907 r
.85777 .39786 .85853 .39894 .86476 .397 .864 .39592 Metetra
.664 .741 .907 r
.864 .39592 .86476 .397 .871 .39506 .87024 .39397 Metetra
.664 .741 .907 r
.87024 .39397 .871 .39506 .87965 .41497 .8765 .39202 Metetra
.577 .382 .58 r
.8765 .39202 .87965 .41497 .88352 .39115 .88277 .39006 Metetra
.664 .741 .907 r
.88277 .39006 .88352 .39115 .8898 .3892 .88905 .3881 Metetra
.664 .741 .907 r
.88905 .3881 .8898 .3892 .89609 .38723 .89535 .38614 Metetra
.664 .741 .907 r
.89535 .38614 .89609 .38723 .9024 .38527 .90166 .38417 Metetra
.664 .741 .907 r
.90166 .38417 .9024 .38527 .90872 .3833 .90798 .3822 Metetra
.664 .741 .907 r
.90798 .3822 .90872 .3833 .91505 .38132 .91432 .38022 Metetra
.664 .741 .907 r
.91432 .38022 .91505 .38132 .9214 .37934 .92067 .37824 Metetra
.664 .741 .907 r
.92067 .37824 .9214 .37934 .92776 .37736 .92703 .37625 Metetra
.664 .741 .907 r
.92703 .37625 .92776 .37736 .93413 .37537 .93341 .37426 Metetra
.664 .741 .907 r
.35624 .55314 .35721 .55404 .36241 .55242 .36144 .55151 Metetra
.664 .741 .907 r
.36144 .55151 .36241 .55242 .36763 .55079 .36666 .54988 Metetra
.664 .741 .907 r
.36666 .54988 .36763 .55079 .37285 .54916 .37189 .54825 Metetra
.664 .741 .907 r
.37189 .54825 .37285 .54916 .37809 .54753 .37713 .54662 Metetra
.664 .741 .907 r
.37713 .54662 .37809 .54753 .38333 .54589 .38237 .54498 Metetra
.664 .741 .907 r
.38237 .54498 .38333 .54589 .38859 .54425 .38763 .54333 Metetra
.664 .741 .907 r
.38763 .54333 .38859 .54425 .39386 .54261 .3929 .54169 Metetra
.664 .741 .907 r
.3929 .54169 .39386 .54261 .39913 .54096 .39818 .54004 Metetra
.664 .741 .907 r
.39818 .54004 .39913 .54096 .40442 .53931 .40347 .53839 Metetra
.664 .741 .907 r
.40347 .53839 .40442 .53931 .40972 .53766 .40877 .53674 Metetra
.664 .741 .907 r
.40877 .53674 .40972 .53766 .41503 .536 .41408 .53508 Metetra
.664 .741 .907 r
.41408 .53508 .41503 .536 .42035 .53434 .4194 .53342 Metetra
.664 .741 .907 r
.4194 .53342 .42035 .53434 .42568 .53268 .42473 .53175 Metetra
.949 .633 .397 r
.42473 .53175 .42568 .53268 .43101 .53108 .42913 .56336 Metetra
.427 .231 .51 r
.42913 .56336 .43101 .53108 .43592 .54615 .43543 .52841 Metetra
.579 .387 .586 r
.43543 .52841 .43592 .54615 .44173 .52767 .44079 .52674 Metetra
.664 .741 .907 r
.44079 .52674 .44173 .52767 .4471 .526 .44616 .52506 Metetra
.664 .741 .907 r
.44616 .52506 .4471 .526 .45248 .52432 .45155 .52338 Metetra
.664 .741 .907 r
.45155 .52338 .45248 .52432 .45787 .52263 .45694 .52169 Metetra
.664 .741 .907 r
.45694 .52169 .45787 .52263 .46328 .52095 .46235 .52001 Metetra
.664 .741 .907 r
.46235 .52001 .46328 .52095 .46869 .51926 .46776 .51831 Metetra
.664 .741 .907 r
.46776 .51831 .46869 .51926 .47412 .51757 .47319 .51662 Metetra
.664 .741 .907 r
.47319 .51662 .47412 .51757 .47955 .51587 .47863 .51492 Metetra
.664 .741 .907 r
.47863 .51492 .47955 .51587 .485 .51417 .48408 .51322 Metetra
.664 .741 .907 r
.48408 .51322 .485 .51417 .49046 .51247 .48954 .51152 Metetra
.664 .741 .907 r
.48954 .51152 .49046 .51247 .49593 .51076 .49501 .50981 Metetra
.664 .741 .907 r
.49501 .50981 .49593 .51076 .50141 .50905 .50049 .5081 Metetra
.664 .741 .907 r
.50049 .5081 .50141 .50905 .5069 .50734 .50598 .50638 Metetra
.664 .741 .907 r
.50598 .50638 .5069 .50734 .5124 .50562 .51149 .50466 Metetra
.664 .741 .907 r
.51149 .50466 .5124 .50562 .51791 .5039 .517 .50294 Metetra
.664 .741 .907 r
.517 .50294 .51791 .5039 .52343 .50218 .52253 .50122 Metetra
.664 .741 .907 r
.52253 .50122 .52343 .50218 .52897 .50045 .52807 .49949 Metetra
.664 .741 .907 r
.52807 .49949 .52897 .50045 .53452 .49872 .53361 .49775 Metetra
.664 .741 .907 r
.53361 .49775 .53452 .49872 .54007 .49699 .53917 .49602 Metetra
.664 .741 .907 r
.53917 .49602 .54007 .49699 .54564 .49525 .54474 .49428 Metetra
.664 .741 .907 r
.54474 .49428 .54564 .49525 .55122 .49351 .55033 .49254 Metetra
.664 .741 .907 r
.55033 .49254 .55122 .49351 .55681 .49176 .55592 .49079 Metetra
.664 .741 .907 r
.55592 .49079 .55681 .49176 .56241 .49002 .56152 .48904 Metetra
.767 .299 0 r
.56152 .48904 .56241 .49002 .56917 .576 .56728 .49831 Metetra
.441 .265 .545 r
.56728 .49831 .56917 .576 .57616 .65655 .57417 .58223 Metetra
.673 .445 .568 r
.57417 .58223 .57616 .65655 .57929 .48475 .57841 .48377 Metetra
.664 .741 .907 r
.57841 .48377 .57929 .48475 .58494 .48299 .58406 .482 Metetra
.664 .741 .907 r
.58406 .482 .58494 .48299 .5906 .48122 .58972 .48024 Metetra
.664 .741 .907 r
.58972 .48024 .5906 .48122 .59627 .47945 .59539 .47847 Metetra
.664 .741 .907 r
.59539 .47847 .59627 .47945 .60195 .47768 .60108 .47669 Metetra
.664 .741 .907 r
.60108 .47669 .60195 .47768 .60765 .4759 .60677 .47491 Metetra
.664 .741 .907 r
.60677 .47491 .60765 .4759 .61335 .47412 .61248 .47313 Metetra
.664 .741 .907 r
.61248 .47313 .61335 .47412 .61907 .47234 .6182 .47134 Metetra
.664 .741 .907 r
.6182 .47134 .61907 .47234 .6248 .47055 .62393 .46955 Metetra
.664 .741 .907 r
.62393 .46955 .6248 .47055 .63054 .46876 .62968 .46776 Metetra
.664 .741 .907 r
.62968 .46776 .63054 .46876 .63629 .46697 .63543 .46596 Metetra
.664 .741 .907 r
.63543 .46596 .63629 .46697 .64206 .46517 .6412 .46416 Metetra
.664 .741 .907 r
.6412 .46416 .64206 .46517 .64783 .46336 .64698 .46236 Metetra
.664 .741 .907 r
.64698 .46236 .64783 .46336 .65362 .46156 .65277 .46055 Metetra
.664 .741 .907 r
.65277 .46055 .65362 .46156 .65942 .45975 .65857 .45874 Metetra
.664 .741 .907 r
.65857 .45874 .65942 .45975 .66523 .45794 .66439 .45692 Metetra
.664 .741 .907 r
.66439 .45692 .66523 .45794 .67106 .45612 .67021 .4551 Metetra
.664 .741 .907 r
.67021 .4551 .67106 .45612 .67689 .4543 .67605 .45328 Metetra
.664 .741 .907 r
.67605 .45328 .67689 .4543 .68274 .45247 .6819 .45145 Metetra
.664 .741 .907 r
.6819 .45145 .68274 .45247 .6886 .45064 .68776 .44962 Metetra
.664 .741 .907 r
.68776 .44962 .6886 .45064 .69448 .44881 .69364 .44779 Metetra
.664 .741 .907 r
.69364 .44779 .69448 .44881 .70036 .44698 .69953 .44595 Metetra
.664 .741 .907 r
.69953 .44595 .70036 .44698 .70626 .44514 .70543 .44411 Metetra
.324 .578 .933 r
.70543 .44411 .70626 .44514 .71217 .44329 .71154 .44574 Metetra
.261 0 .237 r
.71154 .44574 .71217 .44329 .71809 .44144 .71726 .44041 Metetra
.664 .741 .907 r
.71726 .44041 .71809 .44144 .72402 .43959 .7232 .43856 Metetra
.664 .741 .907 r
.7232 .43856 .72402 .43959 .72997 .43774 .72915 .4367 Metetra
.664 .741 .907 r
.72915 .4367 .72997 .43774 .73593 .43588 .73511 .43484 Metetra
.664 .741 .907 r
.73511 .43484 .73593 .43588 .7419 .43402 .74108 .43297 Metetra
.664 .741 .907 r
.74108 .43297 .7419 .43402 .74788 .43215 .74707 .43111 Metetra
.664 .741 .907 r
.74707 .43111 .74788 .43215 .75388 .43028 .75307 .42923 Metetra
.664 .741 .907 r
.75307 .42923 .75388 .43028 .75989 .4284 .75908 .42736 Metetra
.664 .741 .907 r
.75908 .42736 .75989 .4284 .76591 .42652 .7651 .42547 Metetra
.664 .741 .907 r
.7651 .42547 .76591 .42652 .77194 .42464 .77114 .42359 Metetra
.664 .741 .907 r
.77114 .42359 .77194 .42464 .77799 .42275 .77719 .4217 Metetra
.664 .741 .907 r
.77719 .4217 .77799 .42275 .78405 .42086 .78325 .41981 Metetra
.664 .741 .907 r
.78325 .41981 .78405 .42086 .79012 .41897 .78933 .41791 Metetra
.664 .741 .907 r
.78933 .41791 .79012 .41897 .79621 .41707 .79542 .41601 Metetra
.664 .741 .907 r
.79542 .41601 .79621 .41707 .80231 .41517 .80152 .41411 Metetra
.664 .741 .907 r
.80152 .41411 .80231 .41517 .80842 .41326 .80763 .4122 Metetra
.664 .741 .907 r
.80763 .4122 .80842 .41326 .81454 .41135 .81376 .41028 Metetra
.664 .741 .907 r
.81376 .41028 .81454 .41135 .82068 .40944 .8199 .40837 Metetra
.664 .741 .907 r
.8199 .40837 .82068 .40944 .82683 .40752 .82605 .40645 Metetra
.664 .741 .907 r
.82605 .40645 .82683 .40752 .83299 .40559 .83222 .40452 Metetra
.664 .741 .907 r
.83222 .40452 .83299 .40559 .83917 .40367 .83839 .40259 Metetra
.664 .741 .907 r
.83839 .40259 .83917 .40367 .84535 .40174 .84459 .40066 Metetra
.664 .741 .907 r
.84459 .40066 .84535 .40174 .85156 .3998 .85079 .39872 Metetra
.664 .741 .907 r
.85079 .39872 .85156 .3998 .85777 .39786 .85701 .39678 Metetra
.664 .741 .907 r
.85701 .39678 .85777 .39786 .864 .39592 .86324 .39483 Metetra
.664 .741 .907 r
.86324 .39483 .864 .39592 .87024 .39397 .86949 .39288 Metetra
.664 .741 .907 r
.86949 .39288 .87024 .39397 .8765 .39202 .87575 .39093 Metetra
.664 .741 .907 r
.87575 .39093 .8765 .39202 .88277 .39006 .88202 .38897 Metetra
.664 .741 .907 r
.88202 .38897 .88277 .39006 .88905 .3881 .8883 .38701 Metetra
.664 .741 .907 r
.8883 .38701 .88905 .3881 .89535 .38614 .8946 .38504 Metetra
.664 .741 .907 r
.8946 .38504 .89535 .38614 .90166 .38417 .90091 .38307 Metetra
.664 .741 .907 r
.90091 .38307 .90166 .38417 .90798 .3822 .90724 .38109 Metetra
.664 .741 .907 r
.90724 .38109 .90798 .3822 .91432 .38022 .91358 .37912 Metetra
.664 .741 .907 r
.91358 .37912 .91432 .38022 .92067 .37824 .91993 .37713 Metetra
.664 .741 .907 r
.91993 .37713 .92067 .37824 .92703 .37625 .9263 .37514 Metetra
.664 .741 .907 r
.9263 .37514 .92703 .37625 .93341 .37426 .93268 .37315 Metetra
.664 .741 .907 r
.35527 .55223 .35624 .55314 .36144 .55151 .36048 .5506 Metetra
.664 .741 .907 r
.36048 .5506 .36144 .55151 .36666 .54988 .36569 .54897 Metetra
.664 .741 .907 r
.36569 .54897 .36666 .54988 .37189 .54825 .37092 .54734 Metetra
.664 .741 .907 r
.37092 .54734 .37189 .54825 .37713 .54662 .37616 .5457 Metetra
.664 .741 .907 r
.37616 .5457 .37713 .54662 .38237 .54498 .38141 .54406 Metetra
.664 .741 .907 r
.38141 .54406 .38237 .54498 .38763 .54333 .38667 .54242 Metetra
.664 .741 .907 r
.38667 .54242 .38763 .54333 .3929 .54169 .39194 .54077 Metetra
.664 .741 .907 r
.39194 .54077 .3929 .54169 .39818 .54004 .39723 .53912 Metetra
.664 .741 .907 r
.39723 .53912 .39818 .54004 .40347 .53839 .40252 .53747 Metetra
.664 .741 .907 r
.40252 .53747 .40347 .53839 .40877 .53674 .40782 .53581 Metetra
.664 .741 .907 r
.40782 .53581 .40877 .53674 .41408 .53508 .41313 .53415 Metetra
.664 .741 .907 r
.41313 .53415 .41408 .53508 .4194 .53342 .41845 .53249 Metetra
.664 .741 .907 r
.41845 .53249 .4194 .53342 .42473 .53175 .42379 .53082 Metetra
.926 .541 .227 r
.42379 .53082 .42473 .53175 .42913 .56336 .42866 .54573 Metetra
.655 .447 .59 r
.42866 .54573 .42913 .56336 .43543 .52841 .43448 .52748 Metetra
.664 .741 .907 r
.43448 .52748 .43543 .52841 .44079 .52674 .43985 .5258 Metetra
.664 .741 .907 r
.43985 .5258 .44079 .52674 .44616 .52506 .44523 .52412 Metetra
.664 .741 .907 r
.44523 .52412 .44616 .52506 .45155 .52338 .45061 .52244 Metetra
.664 .741 .907 r
.45061 .52244 .45155 .52338 .45694 .52169 .45601 .52075 Metetra
.664 .741 .907 r
.45601 .52075 .45694 .52169 .46235 .52001 .46142 .51906 Metetra
.664 .741 .907 r
.46142 .51906 .46235 .52001 .46776 .51831 .46683 .51737 Metetra
.664 .741 .907 r
.46683 .51737 .46776 .51831 .47319 .51662 .47226 .51567 Metetra
.664 .741 .907 r
.47226 .51567 .47319 .51662 .47863 .51492 .4777 .51397 Metetra
.664 .741 .907 r
.4777 .51397 .47863 .51492 .48408 .51322 .48316 .51227 Metetra
.664 .741 .907 r
.48316 .51227 .48408 .51322 .48954 .51152 .48862 .51056 Metetra
.664 .741 .907 r
.48862 .51056 .48954 .51152 .49501 .50981 .49409 .50885 Metetra
.664 .741 .907 r
.49409 .50885 .49501 .50981 .50049 .5081 .49957 .50714 Metetra
.664 .741 .907 r
.49957 .50714 .50049 .5081 .50598 .50638 .50507 .50542 Metetra
.664 .741 .907 r
.50507 .50542 .50598 .50638 .51149 .50466 .51058 .5037 Metetra
.952 .616 .339 r
.51058 .5037 .51149 .50466 .517 .50294 .51601 .53244 Metetra
.432 .236 .512 r
.51601 .53244 .517 .50294 .52253 .50122 .52162 .50025 Metetra
.664 .741 .907 r
.52162 .50025 .52253 .50122 .52807 .49949 .52716 .49852 Metetra
.664 .741 .907 r
.52716 .49852 .52807 .49949 .53361 .49775 .53271 .49679 Metetra
.664 .741 .907 r
.53271 .49679 .53361 .49775 .53917 .49602 .53827 .49505 Metetra
.664 .741 .907 r
.53827 .49505 .53917 .49602 .54474 .49428 .54385 .49331 Metetra
.664 .741 .907 r
.54385 .49331 .54474 .49428 .55033 .49254 .54943 .49156 Metetra
.664 .741 .907 r
.54943 .49156 .55033 .49254 .55592 .49079 .55502 .48981 Metetra
.664 .741 .907 r
.55502 .48981 .55592 .49079 .56152 .48904 .56063 .48806 Metetra
.664 .741 .907 r
.56063 .48806 .56152 .48904 .56728 .49831 .56625 .48631 Metetra
.585 .402 .601 r
.56625 .48631 .56728 .49831 .57417 .58223 .57188 .48455 Metetra
.568 .362 .561 r
.57188 .48455 .57417 .58223 .57841 .48377 .57752 .48278 Metetra
.664 .741 .907 r
.57752 .48278 .57841 .48377 .58406 .482 .58317 .48102 Metetra
.664 .741 .907 r
.58317 .48102 .58406 .482 .58972 .48024 .58884 .47925 Metetra
.664 .741 .907 r
.58884 .47925 .58972 .48024 .59539 .47847 .59451 .47748 Metetra
.664 .741 .907 r
.59451 .47748 .59539 .47847 .60108 .47669 .6002 .4757 Metetra
.664 .741 .907 r
.6002 .4757 .60108 .47669 .60677 .47491 .6059 .47392 Metetra
.664 .741 .907 r
.6059 .47392 .60677 .47491 .61248 .47313 .61161 .47213 Metetra
.664 .741 .907 r
.61161 .47213 .61248 .47313 .6182 .47134 .61733 .47035 Metetra
.664 .741 .907 r
.61733 .47035 .6182 .47134 .62393 .46955 .62307 .46855 Metetra
.664 .741 .907 r
.62307 .46855 .62393 .46955 .62968 .46776 .62881 .46676 Metetra
.664 .741 .907 r
.62881 .46676 .62968 .46776 .63543 .46596 .63457 .46496 Metetra
.664 .741 .907 r
.63457 .46496 .63543 .46596 .6412 .46416 .64034 .46316 Metetra
.664 .741 .907 r
.64034 .46316 .6412 .46416 .64698 .46236 .64612 .46135 Metetra
.664 .741 .907 r
.64612 .46135 .64698 .46236 .65277 .46055 .65191 .45954 Metetra
.664 .741 .907 r
.65191 .45954 .65277 .46055 .65857 .45874 .65772 .45773 Metetra
.664 .741 .907 r
.65772 .45773 .65857 .45874 .66439 .45692 .66354 .45591 Metetra
.664 .741 .907 r
.66354 .45591 .66439 .45692 .67021 .4551 .66937 .45409 Metetra
.664 .741 .907 r
.66937 .45409 .67021 .4551 .67605 .45328 .67521 .45226 Metetra
.664 .741 .907 r
.67521 .45226 .67605 .45328 .6819 .45145 .68106 .45043 Metetra
.664 .741 .907 r
.68106 .45043 .6819 .45145 .68776 .44962 .68693 .4486 Metetra
.664 .741 .907 r
.68693 .4486 .68776 .44962 .69364 .44779 .6928 .44676 Metetra
.664 .741 .907 r
.6928 .44676 .69364 .44779 .69953 .44595 .69869 .44492 Metetra
.664 .741 .907 r
.69869 .44492 .69953 .44595 .70543 .44411 .7046 .44308 Metetra
.664 .741 .907 r
.7046 .44308 .70543 .44411 .71154 .44574 .71051 .44123 Metetra
.612 .476 .672 r
.71051 .44123 .71154 .44574 .71726 .44041 .71644 .43938 Metetra
.664 .741 .907 r
.71644 .43938 .71726 .44041 .7232 .43856 .72238 .43752 Metetra
.664 .741 .907 r
.72238 .43752 .7232 .43856 .72915 .4367 .72833 .43566 Metetra
.664 .741 .907 r
.72833 .43566 .72915 .4367 .73511 .43484 .73429 .4338 Metetra
.664 .741 .907 r
.73429 .4338 .73511 .43484 .74108 .43297 .74027 .43193 Metetra
.664 .741 .907 r
.74027 .43193 .74108 .43297 .74707 .43111 .74626 .43006 Metetra
.664 .741 .907 r
.74626 .43006 .74707 .43111 .75307 .42923 .75226 .42819 Metetra
.664 .741 .907 r
.75226 .42819 .75307 .42923 .75908 .42736 .75827 .42631 Metetra
.664 .741 .907 r
.75827 .42631 .75908 .42736 .7651 .42547 .7643 .42442 Metetra
.664 .741 .907 r
.7643 .42442 .7651 .42547 .77114 .42359 .77034 .42254 Metetra
.664 .741 .907 r
.77034 .42254 .77114 .42359 .77719 .4217 .77639 .42065 Metetra
.664 .741 .907 r
.77639 .42065 .77719 .4217 .78325 .41981 .78246 .41875 Metetra
.664 .741 .907 r
.78246 .41875 .78325 .41981 .78933 .41791 .78853 .41685 Metetra
.664 .741 .907 r
.78853 .41685 .78933 .41791 .79542 .41601 .79462 .41495 Metetra
.664 .741 .907 r
.79462 .41495 .79542 .41601 .80152 .41411 .80073 .41304 Metetra
.664 .741 .907 r
.80073 .41304 .80152 .41411 .80763 .4122 .80684 .41113 Metetra
.664 .741 .907 r
.80684 .41113 .80763 .4122 .81376 .41028 .81297 .40921 Metetra
.664 .741 .907 r
.81297 .40921 .81376 .41028 .8199 .40837 .81912 .4073 Metetra
.664 .741 .907 r
.81912 .4073 .8199 .40837 .82605 .40645 .82527 .40537 Metetra
.664 .741 .907 r
.82527 .40537 .82605 .40645 .83222 .40452 .83144 .40344 Metetra
.664 .741 .907 r
.83144 .40344 .83222 .40452 .83839 .40259 .83762 .40151 Metetra
.664 .741 .907 r
.83762 .40151 .83839 .40259 .84459 .40066 .84382 .39958 Metetra
.664 .741 .907 r
.84382 .39958 .84459 .40066 .85079 .39872 .85003 .39764 Metetra
.664 .741 .907 r
.85003 .39764 .85079 .39872 .85701 .39678 .85625 .39569 Metetra
.664 .741 .907 r
.85625 .39569 .85701 .39678 .86324 .39483 .86248 .39375 Metetra
.664 .741 .907 r
.86248 .39375 .86324 .39483 .86949 .39288 .86873 .39179 Metetra
.664 .741 .907 r
.86873 .39179 .86949 .39288 .87575 .39093 .87499 .38984 Metetra
.664 .741 .907 r
.87499 .38984 .87575 .39093 .88202 .38897 .88127 .38788 Metetra
.664 .741 .907 r
.88127 .38788 .88202 .38897 .8883 .38701 .88755 .38591 Metetra
.664 .741 .907 r
.88755 .38591 .8883 .38701 .8946 .38504 .89386 .38394 Metetra
.664 .741 .907 r
.89386 .38394 .8946 .38504 .90091 .38307 .90017 .38197 Metetra
.664 .741 .907 r
.90017 .38197 .90091 .38307 .90724 .38109 .9065 .37999 Metetra
.664 .741 .907 r
.9065 .37999 .90724 .38109 .91358 .37912 .91284 .37801 Metetra
.664 .741 .907 r
.91284 .37801 .91358 .37912 .91993 .37713 .9192 .37602 Metetra
.664 .741 .907 r
.9192 .37602 .91993 .37713 .9263 .37514 .92557 .37403 Metetra
.664 .741 .907 r
.92557 .37403 .9263 .37514 .93268 .37315 .93195 .37204 Metetra
.664 .741 .907 r
.35429 .55132 .35527 .55223 .36048 .5506 .35951 .54969 Metetra
.664 .741 .907 r
.35951 .54969 .36048 .5506 .36569 .54897 .36473 .54806 Metetra
.664 .741 .907 r
.36473 .54806 .36569 .54897 .37092 .54734 .36996 .54643 Metetra
.664 .741 .907 r
.36996 .54643 .37092 .54734 .37616 .5457 .3752 .54479 Metetra
.664 .741 .907 r
.3752 .54479 .37616 .5457 .38141 .54406 .38045 .54314 Metetra
.664 .741 .907 r
.38045 .54314 .38141 .54406 .38667 .54242 .38571 .5415 Metetra
.664 .741 .907 r
.38571 .5415 .38667 .54242 .39194 .54077 .39099 .53985 Metetra
.664 .741 .907 r
.39099 .53985 .39194 .54077 .39723 .53912 .39627 .5382 Metetra
.664 .741 .907 r
.39627 .5382 .39723 .53912 .40252 .53747 .40156 .53654 Metetra
.664 .741 .907 r
.40156 .53654 .40252 .53747 .40782 .53581 .40687 .53489 Metetra
.664 .741 .907 r
.40687 .53489 .40782 .53581 .41313 .53415 .41218 .53322 Metetra
.664 .741 .907 r
.41218 .53322 .41313 .53415 .41845 .53249 .4175 .53156 Metetra
.664 .741 .907 r
.4175 .53156 .41845 .53249 .42379 .53082 .42284 .52989 Metetra
.664 .741 .907 r
.42284 .52989 .42379 .53082 .42866 .54573 .42819 .52822 Metetra
.579 .387 .586 r
.42819 .52822 .42866 .54573 .43448 .52748 .43354 .52654 Metetra
.664 .741 .907 r
.43354 .52654 .43448 .52748 .43985 .5258 .43891 .52487 Metetra
.664 .741 .907 r
.43891 .52487 .43985 .5258 .44523 .52412 .44429 .52318 Metetra
.664 .741 .907 r
.44429 .52318 .44523 .52412 .45061 .52244 .44968 .5215 Metetra
.664 .741 .907 r
.44968 .5215 .45061 .52244 .45601 .52075 .45507 .51981 Metetra
.664 .741 .907 r
.45507 .51981 .45601 .52075 .46142 .51906 .46048 .51812 Metetra
.664 .741 .907 r
.46048 .51812 .46142 .51906 .46683 .51737 .4659 .51642 Metetra
.664 .741 .907 r
.4659 .51642 .46683 .51737 .47226 .51567 .47134 .51473 Metetra
.664 .741 .907 r
.47134 .51473 .47226 .51567 .4777 .51397 .47678 .51302 Metetra
.664 .741 .907 r
.47678 .51302 .4777 .51397 .48316 .51227 .48223 .51132 Metetra
.664 .741 .907 r
.48223 .51132 .48316 .51227 .48862 .51056 .4877 .50961 Metetra
.664 .741 .907 r
.4877 .50961 .48862 .51056 .49409 .50885 .49317 .5079 Metetra
.664 .741 .907 r
.49317 .5079 .49409 .50885 .49957 .50714 .49866 .50618 Metetra
.664 .741 .907 r
.49866 .50618 .49957 .50714 .50507 .50542 .50415 .50446 Metetra
.664 .741 .907 r
.50415 .50446 .50507 .50542 .51058 .5037 .50966 .50274 Metetra
.956 .676 .465 r
.50966 .50274 .51058 .5037 .51601 .53244 .51473 .65731 Metetra
.405 .226 .522 r
.51473 .65731 .51601 .53244 .52162 .50025 .52071 .49929 Metetra
.664 .741 .907 r
.52071 .49929 .52162 .50025 .52716 .49852 .52625 .49755 Metetra
.664 .741 .907 r
.52625 .49755 .52716 .49852 .53271 .49679 .53181 .49582 Metetra
.664 .741 .907 r
.53181 .49582 .53271 .49679 .53827 .49505 .53737 .49408 Metetra
.664 .741 .907 r
.53737 .49408 .53827 .49505 .54385 .49331 .54295 .49233 Metetra
.664 .741 .907 r
.54295 .49233 .54385 .49331 .54943 .49156 .54853 .49059 Metetra
.664 .741 .907 r
.54853 .49059 .54943 .49156 .55502 .48981 .55413 .48884 Metetra
.664 .741 .907 r
.55413 .48884 .55502 .48981 .56063 .48806 .55974 .48708 Metetra
.664 .741 .907 r
.55974 .48708 .56063 .48806 .56625 .48631 .56536 .48533 Metetra
.664 .741 .907 r
.56536 .48533 .56625 .48631 .57188 .48455 .57099 .48356 Metetra
.664 .741 .907 r
.57099 .48356 .57188 .48455 .57752 .48278 .57663 .4818 Metetra
.664 .741 .907 r
.57663 .4818 .57752 .48278 .58317 .48102 .58229 .48003 Metetra
.664 .741 .907 r
.58229 .48003 .58317 .48102 .58884 .47925 .58796 .47826 Metetra
.664 .741 .907 r
.58796 .47826 .58884 .47925 .59451 .47748 .59363 .47648 Metetra
.664 .741 .907 r
.59363 .47648 .59451 .47748 .6002 .4757 .59932 .47471 Metetra
.664 .741 .907 r
.59932 .47471 .6002 .4757 .6059 .47392 .60503 .47292 Metetra
.664 .741 .907 r
.60503 .47292 .6059 .47392 .61161 .47213 .61074 .47114 Metetra
.664 .741 .907 r
.61074 .47114 .61161 .47213 .61733 .47035 .61646 .46935 Metetra
.664 .741 .907 r
.61646 .46935 .61733 .47035 .62307 .46855 .6222 .46755 Metetra
.664 .741 .907 r
.6222 .46755 .62307 .46855 .62881 .46676 .62795 .46576 Metetra
.664 .741 .907 r
.62795 .46576 .62881 .46676 .63457 .46496 .63371 .46395 Metetra
.664 .741 .907 r
.63371 .46395 .63457 .46496 .64034 .46316 .63948 .46215 Metetra
.664 .741 .907 r
.63948 .46215 .64034 .46316 .64612 .46135 .64526 .46034 Metetra
.664 .741 .907 r
.64526 .46034 .64612 .46135 .65191 .45954 .65106 .45853 Metetra
.664 .741 .907 r
.65106 .45853 .65191 .45954 .65772 .45773 .65687 .45671 Metetra
.664 .741 .907 r
.65687 .45671 .65772 .45773 .66354 .45591 .66269 .45489 Metetra
.664 .741 .907 r
.66269 .45489 .66354 .45591 .66937 .45409 .66852 .45307 Metetra
.664 .741 .907 r
.66852 .45307 .66937 .45409 .67521 .45226 .67436 .45124 Metetra
.664 .741 .907 r
.67436 .45124 .67521 .45226 .68106 .45043 .68022 .44941 Metetra
.664 .741 .907 r
.68022 .44941 .68106 .45043 .68693 .4486 .68609 .44758 Metetra
.664 .741 .907 r
.68609 .44758 .68693 .4486 .6928 .44676 .69197 .44574 Metetra
.664 .741 .907 r
.69197 .44574 .6928 .44676 .69869 .44492 .69786 .4439 Metetra
.664 .741 .907 r
.69786 .4439 .69869 .44492 .7046 .44308 .70376 .44205 Metetra
.664 .741 .907 r
.70376 .44205 .7046 .44308 .71051 .44123 .70968 .4402 Metetra
.664 .741 .907 r
.70968 .4402 .71051 .44123 .71644 .43938 .71561 .43834 Metetra
.664 .741 .907 r
.71561 .43834 .71644 .43938 .72238 .43752 .72155 .43649 Metetra
.664 .741 .907 r
.72155 .43649 .72238 .43752 .72833 .43566 .72751 .43462 Metetra
.664 .741 .907 r
.72751 .43462 .72833 .43566 .73429 .4338 .73347 .43276 Metetra
.664 .741 .907 r
.73347 .43276 .73429 .4338 .74027 .43193 .73945 .43089 Metetra
.965 .639 .315 r
.73945 .43089 .74027 .43193 .74626 .43006 .75007 .4972 Metetra
.454 .267 .536 r
.75007 .4972 .74626 .43006 .75226 .42819 .75145 .42714 Metetra
.664 .741 .907 r
.75145 .42714 .75226 .42819 .75827 .42631 .75746 .42526 Metetra
.664 .741 .907 r
.75746 .42526 .75827 .42631 .7643 .42442 .76349 .42337 Metetra
.664 .741 .907 r
.76349 .42337 .7643 .42442 .77034 .42254 .76954 .42148 Metetra
.664 .741 .907 r
.76954 .42148 .77034 .42254 .77639 .42065 .77559 .41959 Metetra
.664 .741 .907 r
.77559 .41959 .77639 .42065 .78246 .41875 .78166 .41769 Metetra
.664 .741 .907 r
.78166 .41769 .78246 .41875 .78853 .41685 .78774 .41579 Metetra
.664 .741 .907 r
.78774 .41579 .78853 .41685 .79462 .41495 .79383 .41388 Metetra
.664 .741 .907 r
.79383 .41388 .79462 .41495 .80073 .41304 .79994 .41198 Metetra
.664 .741 .907 r
.79994 .41198 .80073 .41304 .80684 .41113 .80606 .41006 Metetra
.664 .741 .907 r
.80606 .41006 .80684 .41113 .81297 .40921 .81219 .40814 Metetra
.664 .741 .907 r
.81219 .40814 .81297 .40921 .81912 .4073 .81834 .40622 Metetra
.664 .741 .907 r
.81834 .40622 .81912 .4073 .82527 .40537 .82449 .4043 Metetra
.664 .741 .907 r
.82449 .4043 .82527 .40537 .83144 .40344 .83066 .40237 Metetra
.664 .741 .907 r
.83066 .40237 .83144 .40344 .83762 .40151 .83685 .40043 Metetra
.664 .741 .907 r
.83685 .40043 .83762 .40151 .84382 .39958 .84305 .3985 Metetra
.664 .741 .907 r
.84305 .3985 .84382 .39958 .85003 .39764 .84926 .39655 Metetra
.664 .741 .907 r
.84926 .39655 .85003 .39764 .85625 .39569 .85548 .39461 Metetra
.664 .741 .907 r
.85548 .39461 .85625 .39569 .86248 .39375 .86172 .39266 Metetra
.664 .741 .907 r
.86172 .39266 .86248 .39375 .86873 .39179 .86797 .3907 Metetra
.664 .741 .907 r
.86797 .3907 .86873 .39179 .87499 .38984 .87424 .38874 Metetra
.664 .741 .907 r
.87424 .38874 .87499 .38984 .88127 .38788 .88051 .38678 Metetra
.664 .741 .907 r
.88051 .38678 .88127 .38788 .88755 .38591 .8868 .38481 Metetra
.664 .741 .907 r
.8868 .38481 .88755 .38591 .89386 .38394 .89311 .38284 Metetra
.664 .741 .907 r
.89311 .38284 .89386 .38394 .90017 .38197 .89943 .38087 Metetra
.664 .741 .907 r
.89943 .38087 .90017 .38197 .9065 .37999 .90576 .37889 Metetra
.664 .741 .907 r
.90576 .37889 .9065 .37999 .91284 .37801 .91211 .3769 Metetra
.664 .741 .907 r
.91211 .3769 .91284 .37801 .9192 .37602 .91846 .37491 Metetra
.664 .741 .907 r
.91846 .37491 .9192 .37602 .92557 .37403 .92484 .37292 Metetra
.664 .741 .907 r
.92484 .37292 .92557 .37403 .93195 .37204 .93122 .37092 Metetra
.664 .741 .907 r
.35332 .55042 .35429 .55132 .35951 .54969 .35853 .54878 Metetra
.664 .741 .907 r
.35853 .54878 .35951 .54969 .36473 .54806 .36376 .54715 Metetra
.664 .741 .907 r
.36376 .54715 .36473 .54806 .36996 .54643 .36899 .54551 Metetra
.664 .741 .907 r
.36899 .54551 .36996 .54643 .3752 .54479 .37423 .54387 Metetra
.664 .741 .907 r
.37423 .54387 .3752 .54479 .38045 .54314 .37949 .54223 Metetra
.664 .741 .907 r
.37949 .54223 .38045 .54314 .38571 .5415 .38475 .54058 Metetra
.664 .741 .907 r
.38475 .54058 .38571 .5415 .39099 .53985 .39003 .53893 Metetra
.664 .741 .907 r
.39003 .53893 .39099 .53985 .39627 .5382 .39531 .53728 Metetra
.664 .741 .907 r
.39531 .53728 .39627 .5382 .40156 .53654 .40061 .53562 Metetra
.664 .741 .907 r
.40061 .53562 .40156 .53654 .40687 .53489 .40591 .53396 Metetra
.664 .741 .907 r
.40591 .53396 .40687 .53489 .41218 .53322 .41123 .5323 Metetra
.664 .741 .907 r
.41123 .5323 .41218 .53322 .4175 .53156 .41656 .53063 Metetra
.664 .741 .907 r
.41656 .53063 .4175 .53156 .42284 .52989 .42189 .52896 Metetra
.664 .741 .907 r
.42189 .52896 .42284 .52989 .42819 .52822 .42724 .52729 Metetra
.664 .741 .907 r
.42724 .52729 .42819 .52822 .43354 .52654 .4326 .52561 Metetra
.664 .741 .907 r
.4326 .52561 .43354 .52654 .43891 .52487 .43797 .52393 Metetra
.664 .741 .907 r
.43797 .52393 .43891 .52487 .44429 .52318 .44335 .52224 Metetra
.664 .741 .907 r
.44335 .52224 .44429 .52318 .44968 .5215 .44874 .52056 Metetra
.664 .741 .907 r
.44874 .52056 .44968 .5215 .45507 .51981 .45414 .51887 Metetra
.664 .741 .907 r
.45414 .51887 .45507 .51981 .46048 .51812 .45955 .51717 Metetra
.664 .741 .907 r
.45955 .51717 .46048 .51812 .4659 .51642 .46497 .51548 Metetra
.664 .741 .907 r
.46497 .51548 .4659 .51642 .47134 .51473 .47041 .51378 Metetra
.664 .741 .907 r
.47041 .51378 .47134 .51473 .47678 .51302 .47585 .51207 Metetra
.664 .741 .907 r
.47585 .51207 .47678 .51302 .48223 .51132 .48131 .51037 Metetra
.664 .741 .907 r
.48131 .51037 .48223 .51132 .4877 .50961 .48677 .50866 Metetra
.664 .741 .907 r
.48677 .50866 .4877 .50961 .49317 .5079 .49225 .50694 Metetra
.664 .741 .907 r
.49225 .50694 .49317 .5079 .49866 .50618 .49774 .50522 Metetra
.664 .741 .907 r
.49774 .50522 .49866 .50618 .50415 .50446 .50324 .5035 Metetra
.956 .674 .46 r
.50324 .5035 .50415 .50446 .50966 .50274 .50814 .62674 Metetra
.625 .401 .556 r
.50814 .62674 .50966 .50274 .51473 .65731 .51357 .71953 Metetra
0 0 .317 r
.51357 .71953 .51473 .65731 .52071 .49929 .5198 .49832 Metetra
.664 .741 .907 r
.5198 .49832 .52071 .49929 .52625 .49755 .52535 .49659 Metetra
.664 .741 .907 r
.52535 .49659 .52625 .49755 .53181 .49582 .5309 .49485 Metetra
.664 .741 .907 r
.5309 .49485 .53181 .49582 .53737 .49408 .53647 .49311 Metetra
.664 .741 .907 r
.53647 .49311 .53737 .49408 .54295 .49233 .54204 .49136 Metetra
.664 .741 .907 r
.54204 .49136 .54295 .49233 .54853 .49059 .54763 .48961 Metetra
.664 .741 .907 r
.54763 .48961 .54853 .49059 .55413 .48884 .55323 .48786 Metetra
.664 .741 .907 r
.55323 .48786 .55413 .48884 .55974 .48708 .55885 .4861 Metetra
.664 .741 .907 r
.55885 .4861 .55974 .48708 .56536 .48533 .56447 .48434 Metetra
.664 .741 .907 r
.56447 .48434 .56536 .48533 .57099 .48356 .5701 .48258 Metetra
.664 .741 .907 r
.5701 .48258 .57099 .48356 .57663 .4818 .57575 .48081 Metetra
.664 .741 .907 r
.57575 .48081 .57663 .4818 .58229 .48003 .58141 .47904 Metetra
.664 .741 .907 r
.58141 .47904 .58229 .48003 .58796 .47826 .58707 .47727 Metetra
.664 .741 .907 r
.58707 .47727 .58796 .47826 .59363 .47648 .59275 .47549 Metetra
.664 .741 .907 r
.59275 .47549 .59363 .47648 .59932 .47471 .59845 .47371 Metetra
.664 .741 .907 r
.59845 .47371 .59932 .47471 .60503 .47292 .60415 .47193 Metetra
.664 .741 .907 r
.60415 .47193 .60503 .47292 .61074 .47114 .60987 .47014 Metetra
.664 .741 .907 r
.60987 .47014 .61074 .47114 .61646 .46935 .61559 .46835 Metetra
.664 .741 .907 r
.61559 .46835 .61646 .46935 .6222 .46755 .62133 .46655 Metetra
.664 .741 .907 r
.62133 .46655 .6222 .46755 .62795 .46576 .62708 .46475 Metetra
.664 .741 .907 r
.62708 .46475 .62795 .46576 .63371 .46395 .63284 .46295 Metetra
.664 .741 .907 r
.63284 .46295 .63371 .46395 .63948 .46215 .63862 .46114 Metetra
.664 .741 .907 r
.63862 .46114 .63948 .46215 .64526 .46034 .6444 .45933 Metetra
.664 .741 .907 r
.6444 .45933 .64526 .46034 .65106 .45853 .6502 .45752 Metetra
.664 .741 .907 r
.6502 .45752 .65106 .45853 .65687 .45671 .65601 .4557 Metetra
.664 .741 .907 r
.65601 .4557 .65687 .45671 .66269 .45489 .66183 .45388 Metetra
.664 .741 .907 r
.66183 .45388 .66269 .45489 .66852 .45307 .66767 .45205 Metetra
.664 .741 .907 r
.66767 .45205 .66852 .45307 .67436 .45124 .67352 .45022 Metetra
.664 .741 .907 r
.67352 .45022 .67436 .45124 .68022 .44941 .67937 .44839 Metetra
.664 .741 .907 r
.67937 .44839 .68022 .44941 .68609 .44758 .68524 .44655 Metetra
.664 .741 .907 r
.68524 .44655 .68609 .44758 .69197 .44574 .69113 .44471 Metetra
.664 .741 .907 r
.69113 .44471 .69197 .44574 .69786 .4439 .69702 .44287 Metetra
.664 .741 .907 r
.69702 .44287 .69786 .4439 .70376 .44205 .70293 .44102 Metetra
.664 .741 .907 r
.70293 .44102 .70376 .44205 .70968 .4402 .70885 .43916 Metetra
.664 .741 .907 r
.70885 .43916 .70968 .4402 .71561 .43834 .71478 .43731 Metetra
.664 .741 .907 r
.71478 .43731 .71561 .43834 .72155 .43649 .72073 .43545 Metetra
.664 .741 .907 r
.72073 .43545 .72155 .43649 .72751 .43462 .72668 .43358 Metetra
.712 .257 0 r
.72668 .43358 .72751 .43462 .73347 .43276 .73347 .44448 Metetra
.423 .212 .486 r
.73347 .44448 .73347 .43276 .73945 .43089 .73863 .42984 Metetra
.968 .648 .332 r
.73863 .42984 .73945 .43089 .75007 .4972 .75026 .51125 Metetra
0 0 .172 r
.75026 .51125 .75007 .4972 .75145 .42714 .75063 .42609 Metetra
.664 .741 .907 r
.75063 .42609 .75145 .42714 .75746 .42526 .75665 .42421 Metetra
.664 .741 .907 r
.75665 .42421 .75746 .42526 .76349 .42337 .76269 .42232 Metetra
.664 .741 .907 r
.76269 .42232 .76349 .42337 .76954 .42148 .76873 .42043 Metetra
.664 .741 .907 r
.76873 .42043 .76954 .42148 .77559 .41959 .77479 .41853 Metetra
.664 .741 .907 r
.77479 .41853 .77559 .41959 .78166 .41769 .78086 .41663 Metetra
.664 .741 .907 r
.78086 .41663 .78166 .41769 .78774 .41579 .78694 .41473 Metetra
.664 .741 .907 r
.78694 .41473 .78774 .41579 .79383 .41388 .79304 .41282 Metetra
.664 .741 .907 r
.79304 .41282 .79383 .41388 .79994 .41198 .79915 .41091 Metetra
.664 .741 .907 r
.79915 .41091 .79994 .41198 .80606 .41006 .80527 .40899 Metetra
.664 .741 .907 r
.80527 .40899 .80606 .41006 .81219 .40814 .8114 .40707 Metetra
.664 .741 .907 r
.8114 .40707 .81219 .40814 .81834 .40622 .81755 .40515 Metetra
.664 .741 .907 r
.81755 .40515 .81834 .40622 .82449 .4043 .82371 .40322 Metetra
.664 .741 .907 r
.82371 .40322 .82449 .4043 .83066 .40237 .82989 .40129 Metetra
.664 .741 .907 r
.82989 .40129 .83066 .40237 .83685 .40043 .83608 .39935 Metetra
.664 .741 .907 r
.83608 .39935 .83685 .40043 .84305 .3985 .84228 .39741 Metetra
.664 .741 .907 r
.84228 .39741 .84305 .3985 .84926 .39655 .84849 .39547 Metetra
.664 .741 .907 r
.84849 .39547 .84926 .39655 .85548 .39461 .85472 .39352 Metetra
.664 .741 .907 r
.85472 .39352 .85548 .39461 .86172 .39266 .86096 .39157 Metetra
.664 .741 .907 r
.86096 .39157 .86172 .39266 .86797 .3907 .86721 .38961 Metetra
.664 .741 .907 r
.86721 .38961 .86797 .3907 .87424 .38874 .87348 .38765 Metetra
.664 .741 .907 r
.87348 .38765 .87424 .38874 .88051 .38678 .87976 .38568 Metetra
.664 .741 .907 r
.87976 .38568 .88051 .38678 .8868 .38481 .88605 .38371 Metetra
.664 .741 .907 r
.88605 .38371 .8868 .38481 .89311 .38284 .89236 .38174 Metetra
.664 .741 .907 r
.89236 .38174 .89311 .38284 .89943 .38087 .89868 .37976 Metetra
.664 .741 .907 r
.89868 .37976 .89943 .38087 .90576 .37889 .90502 .37778 Metetra
.664 .741 .907 r
.90502 .37778 .90576 .37889 .91211 .3769 .91137 .37579 Metetra
.664 .741 .907 r
.91137 .37579 .91211 .3769 .91846 .37491 .91773 .3738 Metetra
.664 .741 .907 r
.91773 .3738 .91846 .37491 .92484 .37292 .92411 .37181 Metetra
.664 .741 .907 r
.92411 .37181 .92484 .37292 .93122 .37092 .9305 .36981 Metetra
.664 .741 .907 r
.35235 .54951 .35332 .55042 .35853 .54878 .35756 .54787 Metetra
.664 .741 .907 r
.35756 .54787 .35853 .54878 .36376 .54715 .36279 .54624 Metetra
.664 .741 .907 r
.36279 .54624 .36376 .54715 .36899 .54551 .36802 .5446 Metetra
.664 .741 .907 r
.36802 .5446 .36899 .54551 .37423 .54387 .37327 .54296 Metetra
.664 .741 .907 r
.37327 .54296 .37423 .54387 .37949 .54223 .37852 .54131 Metetra
.664 .741 .907 r
.37852 .54131 .37949 .54223 .38475 .54058 .38379 .53966 Metetra
.664 .741 .907 r
.38379 .53966 .38475 .54058 .39003 .53893 .38907 .53801 Metetra
.664 .741 .907 r
.38907 .53801 .39003 .53893 .39531 .53728 .39435 .53635 Metetra
.664 .741 .907 r
.39435 .53635 .39531 .53728 .40061 .53562 .39965 .53469 Metetra
.664 .741 .907 r
.39965 .53469 .40061 .53562 .40591 .53396 .40496 .53303 Metetra
.664 .741 .907 r
.40496 .53303 .40591 .53396 .41123 .5323 .41028 .53137 Metetra
.664 .741 .907 r
.41028 .53137 .41123 .5323 .41656 .53063 .41561 .5297 Metetra
.664 .741 .907 r
.41561 .5297 .41656 .53063 .42189 .52896 .42094 .52803 Metetra
.664 .741 .907 r
.42094 .52803 .42189 .52896 .42724 .52729 .42629 .52635 Metetra
.664 .741 .907 r
.42629 .52635 .42724 .52729 .4326 .52561 .43165 .52467 Metetra
.664 .741 .907 r
.43165 .52467 .4326 .52561 .43797 .52393 .43703 .52299 Metetra
.664 .741 .907 r
.43703 .52299 .43797 .52393 .44335 .52224 .44241 .5213 Metetra
.664 .741 .907 r
.44241 .5213 .44335 .52224 .44874 .52056 .4478 .51962 Metetra
.664 .741 .907 r
.4478 .51962 .44874 .52056 .45414 .51887 .4532 .51792 Metetra
.664 .741 .907 r
.4532 .51792 .45414 .51887 .45955 .51717 .45862 .51623 Metetra
.664 .741 .907 r
.45862 .51623 .45955 .51717 .46497 .51548 .46404 .51453 Metetra
.664 .741 .907 r
.46404 .51453 .46497 .51548 .47041 .51378 .46948 .51283 Metetra
.664 .741 .907 r
.46948 .51283 .47041 .51378 .47585 .51207 .47492 .51112 Metetra
.664 .741 .907 r
.47492 .51112 .47585 .51207 .48131 .51037 .48038 .50941 Metetra
.664 .741 .907 r
.48038 .50941 .48131 .51037 .48677 .50866 .48585 .5077 Metetra
.664 .741 .907 r
.48585 .5077 .48677 .50866 .49225 .50694 .49133 .50598 Metetra
.664 .741 .907 r
.49133 .50598 .49225 .50694 .49774 .50522 .49682 .50427 Metetra
.664 .741 .907 r
.49682 .50427 .49774 .50522 .50324 .5035 .50232 .50254 Metetra
.956 .677 .467 r
.50232 .50254 .50324 .5035 .50814 .62674 .50702 .65936 Metetra
.595 .367 .541 r
.50702 .65936 .50814 .62674 .51357 .71953 .51276 .67084 Metetra
.774 .53 .567 r
.51276 .67084 .51357 .71953 .5198 .49832 .51889 .49735 Metetra
.664 .741 .907 r
.51889 .49735 .5198 .49832 .52535 .49659 .52444 .49562 Metetra
.664 .741 .907 r
.52444 .49562 .52535 .49659 .5309 .49485 .53 .49388 Metetra
.664 .741 .907 r
.53 .49388 .5309 .49485 .53647 .49311 .53556 .49213 Metetra
.664 .741 .907 r
.53556 .49213 .53647 .49311 .54204 .49136 .54114 .49039 Metetra
.664 .741 .907 r
.54114 .49039 .54204 .49136 .54763 .48961 .54673 .48863 Metetra
.664 .741 .907 r
.54673 .48863 .54763 .48961 .55323 .48786 .55234 .48688 Metetra
.664 .741 .907 r
.55234 .48688 .55323 .48786 .55885 .4861 .55795 .48512 Metetra
.664 .741 .907 r
.55795 .48512 .55885 .4861 .56447 .48434 .56358 .48336 Metetra
.664 .741 .907 r
.56358 .48336 .56447 .48434 .5701 .48258 .56921 .4816 Metetra
.664 .741 .907 r
.56921 .4816 .5701 .48258 .57575 .48081 .57486 .47983 Metetra
.664 .741 .907 r
.57486 .47983 .57575 .48081 .58141 .47904 .58052 .47806 Metetra
.664 .741 .907 r
.58052 .47806 .58141 .47904 .58707 .47727 .58619 .47628 Metetra
.664 .741 .907 r
.58619 .47628 .58707 .47727 .59275 .47549 .59187 .4745 Metetra
.664 .741 .907 r
.59187 .4745 .59275 .47549 .59845 .47371 .59757 .47272 Metetra
.664 .741 .907 r
.59757 .47272 .59845 .47371 .60415 .47193 .60327 .47093 Metetra
.664 .741 .907 r
.60327 .47093 .60415 .47193 .60987 .47014 .60899 .46914 Metetra
.664 .741 .907 r
.60899 .46914 .60987 .47014 .61559 .46835 .61472 .46735 Metetra
.664 .741 .907 r
.61472 .46735 .61559 .46835 .62133 .46655 .62046 .46555 Metetra
.664 .741 .907 r
.62046 .46555 .62133 .46655 .62708 .46475 .62621 .46375 Metetra
.664 .741 .907 r
.62621 .46375 .62708 .46475 .63284 .46295 .63198 .46194 Metetra
.664 .741 .907 r
.63198 .46194 .63284 .46295 .63862 .46114 .63776 .46013 Metetra
.664 .741 .907 r
.63776 .46013 .63862 .46114 .6444 .45933 .64355 .45832 Metetra
.664 .741 .907 r
.64355 .45832 .6444 .45933 .6502 .45752 .64935 .4565 Metetra
.664 .741 .907 r
.64935 .4565 .6502 .45752 .65601 .4557 .65516 .45468 Metetra
.664 .741 .907 r
.65516 .45468 .65601 .4557 .66183 .45388 .66098 .45286 Metetra
.664 .741 .907 r
.66098 .45286 .66183 .45388 .66767 .45205 .66682 .45103 Metetra
.664 .741 .907 r
.66682 .45103 .66767 .45205 .67352 .45022 .67267 .4492 Metetra
.664 .741 .907 r
.67267 .4492 .67352 .45022 .67937 .44839 .67853 .44736 Metetra
.664 .741 .907 r
.67853 .44736 .67937 .44839 .68524 .44655 .6844 .44552 Metetra
.664 .741 .907 r
.6844 .44552 .68524 .44655 .69113 .44471 .69029 .44368 Metetra
.664 .741 .907 r
.69029 .44368 .69113 .44471 .69702 .44287 .69619 .44184 Metetra
.664 .741 .907 r
.69619 .44184 .69702 .44287 .70293 .44102 .70209 .43998 Metetra
.664 .741 .907 r
.70209 .43998 .70293 .44102 .70885 .43916 .70802 .43813 Metetra
.664 .741 .907 r
.70802 .43813 .70885 .43916 .71478 .43731 .71395 .43627 Metetra
.664 .741 .907 r
.71395 .43627 .71478 .43731 .72073 .43545 .7199 .43441 Metetra
.664 .741 .907 r
.7199 .43441 .72073 .43545 .72668 .43358 .72586 .43254 Metetra
.87 .456 .013 r
.72586 .43254 .72668 .43358 .73347 .44448 .73305 .44984 Metetra
0 0 .278 r
.73305 .44984 .73347 .44448 .73863 .42984 .73781 .4288 Metetra
.863 .447 0 r
.73781 .4288 .73863 .42984 .75026 .51125 .7451 .44598 Metetra
.595 .383 .564 r
.7451 .44598 .75026 .51125 .75063 .42609 .74982 .42504 Metetra
.664 .741 .907 r
.74982 .42504 .75063 .42609 .75665 .42421 .75584 .42315 Metetra
.664 .741 .907 r
.75584 .42315 .75665 .42421 .76269 .42232 .76188 .42126 Metetra
.664 .741 .907 r
.76188 .42126 .76269 .42232 .76873 .42043 .76793 .41937 Metetra
.664 .741 .907 r
.76793 .41937 .76873 .42043 .77479 .41853 .77399 .41747 Metetra
.664 .741 .907 r
.77399 .41747 .77479 .41853 .78086 .41663 .78006 .41557 Metetra
.664 .741 .907 r
.78006 .41557 .78086 .41663 .78694 .41473 .78615 .41366 Metetra
.664 .741 .907 r
.78615 .41366 .78694 .41473 .79304 .41282 .79224 .41175 Metetra
.664 .741 .907 r
.79224 .41175 .79304 .41282 .79915 .41091 .79836 .40984 Metetra
.664 .741 .907 r
.79836 .40984 .79915 .41091 .80527 .40899 .80448 .40792 Metetra
.664 .741 .907 r
.80448 .40792 .80527 .40899 .8114 .40707 .81062 .406 Metetra
.664 .741 .907 r
.81062 .406 .8114 .40707 .81755 .40515 .81677 .40407 Metetra
.664 .741 .907 r
.81677 .40407 .81755 .40515 .82371 .40322 .82293 .40214 Metetra
.664 .741 .907 r
.82293 .40214 .82371 .40322 .82989 .40129 .82911 .40021 Metetra
.664 .741 .907 r
.82911 .40021 .82989 .40129 .83608 .39935 .8353 .39827 Metetra
.664 .741 .907 r
.8353 .39827 .83608 .39935 .84228 .39741 .8415 .39633 Metetra
.664 .741 .907 r
.8415 .39633 .84228 .39741 .84849 .39547 .84772 .39438 Metetra
.664 .741 .907 r
.84772 .39438 .84849 .39547 .85472 .39352 .85395 .39243 Metetra
.664 .741 .907 r
.85395 .39243 .85472 .39352 .86096 .39157 .86019 .39048 Metetra
.664 .741 .907 r
.86019 .39048 .86096 .39157 .86721 .38961 .86645 .38852 Metetra
.664 .741 .907 r
.86645 .38852 .86721 .38961 .87348 .38765 .87272 .38655 Metetra
.664 .741 .907 r
.87272 .38655 .87348 .38765 .87976 .38568 .87901 .38459 Metetra
.664 .741 .907 r
.87901 .38459 .87976 .38568 .88605 .38371 .8853 .38261 Metetra
.664 .741 .907 r
.8853 .38261 .88605 .38371 .89236 .38174 .89161 .38064 Metetra
.664 .741 .907 r
.89161 .38064 .89236 .38174 .89868 .37976 .89794 .37866 Metetra
.664 .741 .907 r
.89794 .37866 .89868 .37976 .90502 .37778 .90428 .37667 Metetra
.664 .741 .907 r
.90428 .37667 .90502 .37778 .91137 .37579 .91063 .37468 Metetra
.664 .741 .907 r
.91063 .37468 .91137 .37579 .91773 .3738 .91699 .37269 Metetra
.664 .741 .907 r
.91699 .37269 .91773 .3738 .92411 .37181 .92337 .37069 Metetra
.664 .741 .907 r
.92337 .37069 .92411 .37181 .9305 .36981 .92977 .36869 Metetra
.664 .741 .907 r
.35137 .5486 .35235 .54951 .35756 .54787 .35659 .54696 Metetra
.664 .741 .907 r
.35659 .54696 .35756 .54787 .36279 .54624 .36182 .54532 Metetra
.664 .741 .907 r
.36182 .54532 .36279 .54624 .36802 .5446 .36705 .54368 Metetra
.664 .741 .907 r
.36705 .54368 .36802 .5446 .37327 .54296 .3723 .54204 Metetra
.664 .741 .907 r
.3723 .54204 .37327 .54296 .37852 .54131 .37756 .54039 Metetra
.664 .741 .907 r
.37756 .54039 .37852 .54131 .38379 .53966 .38283 .53874 Metetra
.664 .741 .907 r
.38283 .53874 .38379 .53966 .38907 .53801 .38811 .53708 Metetra
.664 .741 .907 r
.38811 .53708 .38907 .53801 .39435 .53635 .39339 .53543 Metetra
.52 .693 .947 r
.39339 .53543 .39435 .53635 .39965 .53469 .39863 .53531 Metetra
.39863 .53531 .39965 .53469 .40496 .53303 .404 .5321 Metetra
.664 .741 .907 r
.404 .5321 .40496 .53303 .41028 .53137 .40932 .53044 Metetra
.664 .741 .907 r
.40932 .53044 .41028 .53137 .41561 .5297 .41465 .52877 Metetra
.664 .741 .907 r
.41465 .52877 .41561 .5297 .42094 .52803 .41999 .52709 Metetra
.664 .741 .907 r
.41999 .52709 .42094 .52803 .42629 .52635 .42535 .52541 Metetra
.664 .741 .907 r
.42535 .52541 .42629 .52635 .43165 .52467 .43071 .52373 Metetra
.664 .741 .907 r
.43071 .52373 .43165 .52467 .43703 .52299 .43608 .52205 Metetra
.664 .741 .907 r
.43608 .52205 .43703 .52299 .44241 .5213 .44147 .52036 Metetra
.664 .741 .907 r
.44147 .52036 .44241 .5213 .4478 .51962 .44686 .51867 Metetra
.664 .741 .907 r
.44686 .51867 .4478 .51962 .4532 .51792 .45227 .51698 Metetra
.664 .741 .907 r
.45227 .51698 .4532 .51792 .45862 .51623 .45768 .51528 Metetra
.664 .741 .907 r
.45768 .51528 .45862 .51623 .46404 .51453 .46311 .51358 Metetra
.664 .741 .907 r
.46311 .51358 .46404 .51453 .46948 .51283 .46855 .51188 Metetra
.664 .741 .907 r
.46855 .51188 .46948 .51283 .47492 .51112 .474 .51017 Metetra
.664 .741 .907 r
.474 .51017 .47492 .51112 .48038 .50941 .47946 .50846 Metetra
.664 .741 .907 r
.47946 .50846 .48038 .50941 .48585 .5077 .48493 .50674 Metetra
.664 .741 .907 r
.48493 .50674 .48585 .5077 .49133 .50598 .49041 .50503 Metetra
.664 .741 .907 r
.49041 .50503 .49133 .50598 .49682 .50427 .4959 .5033 Metetra
.664 .741 .907 r
.4959 .5033 .49682 .50427 .50232 .50254 .5014 .50158 Metetra
.957 .669 .451 r
.5014 .50158 .50232 .50254 .50702 .65936 .50639 .59667 Metetra
.6 .389 .567 r
.50639 .59667 .50702 .65936 .51276 .67084 .51216 .57421 Metetra
.637 .416 .566 r
.51216 .57421 .51276 .67084 .51889 .49735 .51798 .49639 Metetra
.664 .741 .907 r
.51798 .49639 .51889 .49735 .52444 .49562 .52353 .49465 Metetra
.664 .741 .907 r
.52353 .49465 .52444 .49562 .53 .49388 .52909 .4929 Metetra
.664 .741 .907 r
.52909 .4929 .53 .49388 .53556 .49213 .53466 .49116 Metetra
.664 .741 .907 r
.53466 .49116 .53556 .49213 .54114 .49039 .54024 .48941 Metetra
.664 .741 .907 r
.54024 .48941 .54114 .49039 .54673 .48863 .54583 .48766 Metetra
.664 .741 .907 r
.54583 .48766 .54673 .48863 .55234 .48688 .55144 .4859 Metetra
.664 .741 .907 r
.55144 .4859 .55234 .48688 .55795 .48512 .55705 .48414 Metetra
.664 .741 .907 r
.55705 .48414 .55795 .48512 .56358 .48336 .56268 .48238 Metetra
.664 .741 .907 r
.56268 .48238 .56358 .48336 .56921 .4816 .56832 .48061 Metetra
.664 .741 .907 r
.56832 .48061 .56921 .4816 .57486 .47983 .57397 .47884 Metetra
.664 .741 .907 r
.57397 .47884 .57486 .47983 .58052 .47806 .57963 .47707 Metetra
.664 .741 .907 r
.57963 .47707 .58052 .47806 .58619 .47628 .58531 .47529 Metetra
.664 .741 .907 r
.58531 .47529 .58619 .47628 .59187 .4745 .59099 .47351 Metetra
.664 .741 .907 r
.59099 .47351 .59187 .4745 .59757 .47272 .59669 .47172 Metetra
.664 .741 .907 r
.59669 .47172 .59757 .47272 .60327 .47093 .6024 .46993 Metetra
.553 .074 0 r
.6024 .46993 .60327 .47093 .60899 .46914 .60834 .47689 Metetra
.392 .164 .445 r
.60834 .47689 .60899 .46914 .61472 .46735 .61385 .46634 Metetra
.664 .741 .907 r
.61385 .46634 .61472 .46735 .62046 .46555 .61959 .46454 Metetra
.664 .741 .907 r
.61959 .46454 .62046 .46555 .62621 .46375 .62535 .46274 Metetra
.664 .741 .907 r
.62535 .46274 .62621 .46375 .63198 .46194 .63111 .46093 Metetra
.664 .741 .907 r
.63111 .46093 .63198 .46194 .63776 .46013 .63689 .45912 Metetra
.664 .741 .907 r
.63689 .45912 .63776 .46013 .64355 .45832 .64268 .45731 Metetra
.664 .741 .907 r
.64268 .45731 .64355 .45832 .64935 .4565 .64849 .45549 Metetra
.664 .741 .907 r
.64849 .45549 .64935 .4565 .65516 .45468 .6543 .45367 Metetra
.664 .741 .907 r
.6543 .45367 .65516 .45468 .66098 .45286 .66013 .45184 Metetra
.664 .741 .907 r
.66013 .45184 .66098 .45286 .66682 .45103 .66597 .45001 Metetra
.664 .741 .907 r
.66597 .45001 .66682 .45103 .67267 .4492 .67182 .44818 Metetra
.664 .741 .907 r
.67182 .44818 .67267 .4492 .67853 .44736 .67768 .44634 Metetra
.664 .741 .907 r
.67768 .44634 .67853 .44736 .6844 .44552 .68356 .4445 Metetra
.664 .741 .907 r
.68356 .4445 .6844 .44552 .69029 .44368 .68945 .44265 Metetra
.664 .741 .907 r
.68945 .44265 .69029 .44368 .69619 .44184 .69535 .4408 Metetra
.664 .741 .907 r
.69535 .4408 .69619 .44184 .70209 .43998 .70126 .43895 Metetra
.664 .741 .907 r
.70126 .43895 .70209 .43998 .70802 .43813 .70718 .43709 Metetra
.664 .741 .907 r
.70718 .43709 .70802 .43813 .71395 .43627 .71312 .43523 Metetra
.664 .741 .907 r
.71312 .43523 .71395 .43627 .7199 .43441 .71907 .43337 Metetra
.664 .741 .907 r
.71907 .43337 .7199 .43441 .72586 .43254 .72503 .4315 Metetra
.664 .741 .907 r
.72503 .4315 .72586 .43254 .73305 .44984 .73101 .42963 Metetra
.544 .36 .582 r
.73101 .42963 .73305 .44984 .73781 .4288 .73745 .43468 Metetra
.383 .144 .423 r
.73745 .43468 .73781 .4288 .7451 .44598 .74299 .42587 Metetra
.577 .384 .583 r
.74299 .42587 .7451 .44598 .74982 .42504 .74901 .42399 Metetra
.664 .741 .907 r
.74901 .42399 .74982 .42504 .75584 .42315 .75503 .4221 Metetra
.664 .741 .907 r
.75503 .4221 .75584 .42315 .76188 .42126 .76107 .42021 Metetra
.664 .741 .907 r
.76107 .42021 .76188 .42126 .76793 .41937 .76712 .41831 Metetra
.664 .741 .907 r
.76712 .41831 .76793 .41937 .77399 .41747 .77318 .41641 Metetra
.664 .741 .907 r
.77318 .41641 .77399 .41747 .78006 .41557 .77926 .41451 Metetra
.664 .741 .907 r
.77926 .41451 .78006 .41557 .78615 .41366 .78535 .4126 Metetra
.664 .741 .907 r
.78535 .4126 .78615 .41366 .79224 .41175 .79145 .41069 Metetra
.664 .741 .907 r
.79145 .41069 .79224 .41175 .79836 .40984 .79756 .40877 Metetra
.664 .741 .907 r
.79756 .40877 .79836 .40984 .80448 .40792 .80369 .40685 Metetra
.664 .741 .907 r
.80369 .40685 .80448 .40792 .81062 .406 .80983 .40493 Metetra
.664 .741 .907 r
.80983 .40493 .81062 .406 .81677 .40407 .81599 .403 Metetra
.664 .741 .907 r
.81599 .403 .81677 .40407 .82293 .40214 .82215 .40107 Metetra
.664 .741 .907 r
.82215 .40107 .82293 .40214 .82911 .40021 .82833 .39913 Metetra
.664 .741 .907 r
.82833 .39913 .82911 .40021 .8353 .39827 .83453 .39719 Metetra
.664 .741 .907 r
.83453 .39719 .8353 .39827 .8415 .39633 .84073 .39524 Metetra
.664 .741 .907 r
.84073 .39524 .8415 .39633 .84772 .39438 .84695 .39329 Metetra
.664 .741 .907 r
.84695 .39329 .84772 .39438 .85395 .39243 .85318 .39134 Metetra
.664 .741 .907 r
.85318 .39134 .85395 .39243 .86019 .39048 .85943 .38938 Metetra
.664 .741 .907 r
.85943 .38938 .86019 .39048 .86645 .38852 .86569 .38742 Metetra
.664 .741 .907 r
.86569 .38742 .86645 .38852 .87272 .38655 .87196 .38546 Metetra
.664 .741 .907 r
.87196 .38546 .87272 .38655 .87901 .38459 .87825 .38349 Metetra
.664 .741 .907 r
.87825 .38349 .87901 .38459 .8853 .38261 .88455 .38151 Metetra
.664 .741 .907 r
.88455 .38151 .8853 .38261 .89161 .38064 .89086 .37953 Metetra
.664 .741 .907 r
.89086 .37953 .89161 .38064 .89794 .37866 .89719 .37755 Metetra
.664 .741 .907 r
.89719 .37755 .89794 .37866 .90428 .37667 .90353 .37556 Metetra
.664 .741 .907 r
.90353 .37556 .90428 .37667 .91063 .37468 .90989 .37357 Metetra
.664 .741 .907 r
.90989 .37357 .91063 .37468 .91699 .37269 .91626 .37158 Metetra
.664 .741 .907 r
.91626 .37158 .91699 .37269 .92337 .37069 .92264 .36958 Metetra
.664 .741 .907 r
.92264 .36958 .92337 .37069 .92977 .36869 .92903 .36757 Metetra
.664 .741 .907 r
.3504 .54768 .35137 .5486 .35659 .54696 .35562 .54605 Metetra
.664 .741 .907 r
.35562 .54605 .35659 .54696 .36182 .54532 .36084 .54441 Metetra
.664 .741 .907 r
.36084 .54441 .36182 .54532 .36705 .54368 .36608 .54277 Metetra
.664 .741 .907 r
.36608 .54277 .36705 .54368 .3723 .54204 .37133 .54112 Metetra
.664 .741 .907 r
.37133 .54112 .3723 .54204 .37756 .54039 .37659 .53947 Metetra
.664 .741 .907 r
.37659 .53947 .37756 .54039 .38283 .53874 .38186 .53782 Metetra
.664 .741 .907 r
.38186 .53782 .38283 .53874 .38811 .53708 .38714 .53616 Metetra
.664 .741 .907 r
.38714 .53616 .38811 .53708 .39339 .53543 .39243 .5345 Metetra
.948 .638 .416 r
.39243 .5345 .39339 .53543 .39863 .53531 .3964 .56811 Metetra
.415 .22 .505 r
.3964 .56811 .39863 .53531 .404 .5321 .40305 .53117 Metetra
.664 .741 .907 r
.40305 .53117 .404 .5321 .40932 .53044 .40837 .5295 Metetra
.664 .741 .907 r
.40837 .5295 .40932 .53044 .41465 .52877 .4137 .52783 Metetra
.664 .741 .907 r
.4137 .52783 .41465 .52877 .41999 .52709 .41904 .52616 Metetra
.664 .741 .907 r
.41904 .52616 .41999 .52709 .42535 .52541 .4244 .52448 Metetra
.664 .741 .907 r
.4244 .52448 .42535 .52541 .43071 .52373 .42976 .5228 Metetra
.664 .741 .907 r
.42976 .5228 .43071 .52373 .43608 .52205 .43514 .52111 Metetra
.664 .741 .907 r
.43514 .52111 .43608 .52205 .44147 .52036 .44052 .51942 Metetra
.664 .741 .907 r
.44052 .51942 .44147 .52036 .44686 .51867 .44592 .51773 Metetra
.664 .741 .907 r
.44592 .51773 .44686 .51867 .45227 .51698 .45133 .51603 Metetra
.664 .741 .907 r
.45133 .51603 .45227 .51698 .45768 .51528 .45675 .51433 Metetra
.664 .741 .907 r
.45675 .51433 .45768 .51528 .46311 .51358 .46218 .51263 Metetra
.664 .741 .907 r
.46218 .51263 .46311 .51358 .46855 .51188 .46761 .51092 Metetra
.664 .741 .907 r
.46761 .51092 .46855 .51188 .474 .51017 .47307 .50922 Metetra
.664 .741 .907 r
.47307 .50922 .474 .51017 .47946 .50846 .47853 .5075 Metetra
.664 .741 .907 r
.47853 .5075 .47946 .50846 .48493 .50674 .484 .50579 Metetra
.664 .741 .907 r
.484 .50579 .48493 .50674 .49041 .50503 .48948 .50407 Metetra
.664 .741 .907 r
.48948 .50407 .49041 .50503 .4959 .5033 .49498 .50234 Metetra
.664 .741 .907 r
.49498 .50234 .4959 .5033 .5014 .50158 .50048 .50062 Metetra
.569 .075 0 r
.50048 .50062 .5014 .50158 .50639 .59667 .50596 .5068 Metetra
.531 .332 .556 r
.50596 .5068 .50639 .59667 .51216 .57421 .51137 .53622 Metetra
.656 .436 .574 r
.51137 .53622 .51216 .57421 .51798 .49639 .51707 .49542 Metetra
.664 .741 .907 r
.51707 .49542 .51798 .49639 .52353 .49465 .52262 .49368 Metetra
.664 .741 .907 r
.52262 .49368 .52353 .49465 .52909 .4929 .52818 .49193 Metetra
.664 .741 .907 r
.52818 .49193 .52909 .4929 .53466 .49116 .53375 .49018 Metetra
.664 .741 .907 r
.53375 .49018 .53466 .49116 .54024 .48941 .53934 .48843 Metetra
.664 .741 .907 r
.53934 .48843 .54024 .48941 .54583 .48766 .54493 .48668 Metetra
.664 .741 .907 r
.54493 .48668 .54583 .48766 .55144 .4859 .55054 .48492 Metetra
.664 .741 .907 r
.55054 .48492 .55144 .4859 .55705 .48414 .55616 .48316 Metetra
.664 .741 .907 r
.55616 .48316 .55705 .48414 .56268 .48238 .56179 .48139 Metetra
.664 .741 .907 r
.56179 .48139 .56268 .48238 .56832 .48061 .56743 .47962 Metetra
.664 .741 .907 r
.56743 .47962 .56832 .48061 .57397 .47884 .57308 .47785 Metetra
.664 .741 .907 r
.57308 .47785 .57397 .47884 .57963 .47707 .57875 .47607 Metetra
.664 .741 .907 r
.57875 .47607 .57963 .47707 .58531 .47529 .58442 .47429 Metetra
.664 .741 .907 r
.58442 .47429 .58531 .47529 .59099 .47351 .59011 .47251 Metetra
.664 .741 .907 r
.59011 .47251 .59099 .47351 .59669 .47172 .59581 .47072 Metetra
.664 .741 .907 r
.59581 .47072 .59669 .47172 .6024 .46993 .60152 .46893 Metetra
.632 .73 .918 r
.60152 .46893 .6024 .46993 .60834 .47689 .60725 .4676 Metetra
.594 .418 .613 r
.60725 .4676 .60834 .47689 .61385 .46634 .61297 .46534 Metetra
.664 .741 .907 r
.61297 .46534 .61385 .46634 .61959 .46454 .61872 .46354 Metetra
.664 .741 .907 r
.61872 .46354 .61959 .46454 .62535 .46274 .62448 .46173 Metetra
.664 .741 .907 r
.62448 .46173 .62535 .46274 .63111 .46093 .63025 .45992 Metetra
.664 .741 .907 r
.63025 .45992 .63111 .46093 .63689 .45912 .63603 .45811 Metetra
.664 .741 .907 r
.63603 .45811 .63689 .45912 .64268 .45731 .64182 .45629 Metetra
.664 .741 .907 r
.64182 .45629 .64268 .45731 .64849 .45549 .64763 .45447 Metetra
.664 .741 .907 r
.64763 .45447 .64849 .45549 .6543 .45367 .65345 .45265 Metetra
.664 .741 .907 r
.65345 .45265 .6543 .45367 .66013 .45184 .65928 .45082 Metetra
.664 .741 .907 r
.65928 .45082 .66013 .45184 .66597 .45001 .66512 .44899 Metetra
.664 .741 .907 r
.66512 .44899 .66597 .45001 .67182 .44818 .67097 .44715 Metetra
.664 .741 .907 r
.67097 .44715 .67182 .44818 .67768 .44634 .67684 .44531 Metetra
.664 .741 .907 r
.67684 .44531 .67768 .44634 .68356 .4445 .68272 .44347 Metetra
.664 .741 .907 r
.68272 .44347 .68356 .4445 .68945 .44265 .68861 .44162 Metetra
.664 .741 .907 r
.68861 .44162 .68945 .44265 .69535 .4408 .69451 .43977 Metetra
.664 .741 .907 r
.69451 .43977 .69535 .4408 .70126 .43895 .70042 .43792 Metetra
.664 .741 .907 r
.70042 .43792 .70126 .43895 .70718 .43709 .70635 .43606 Metetra
.664 .741 .907 r
.70635 .43606 .70718 .43709 .71312 .43523 .71229 .43419 Metetra
.664 .741 .907 r
.71229 .43419 .71312 .43523 .71907 .43337 .71824 .43233 Metetra
.664 .741 .907 r
.71824 .43233 .71907 .43337 .72503 .4315 .72421 .43046 Metetra
.664 .741 .907 r
.72421 .43046 .72503 .4315 .73101 .42963 .73018 .42858 Metetra
.664 .741 .907 r
.73018 .42858 .73101 .42963 .73745 .43468 .73617 .4267 Metetra
.357 .262 .609 r
.73617 .4267 .73745 .43468 .74299 .42587 .74326 .44101 Metetra
.431 .226 .499 r
.74326 .44101 .74299 .42587 .74901 .42399 .74819 .42294 Metetra
.664 .741 .907 r
.74819 .42294 .74901 .42399 .75503 .4221 .75422 .42105 Metetra
.664 .741 .907 r
.75422 .42105 .75503 .4221 .76107 .42021 .76026 .41915 Metetra
.664 .741 .907 r
.76026 .41915 .76107 .42021 .76712 .41831 .76631 .41725 Metetra
.664 .741 .907 r
.76631 .41725 .76712 .41831 .77318 .41641 .77238 .41535 Metetra
.664 .741 .907 r
.77238 .41535 .77318 .41641 .77926 .41451 .77846 .41344 Metetra
.664 .741 .907 r
.77846 .41344 .77926 .41451 .78535 .4126 .78455 .41153 Metetra
.664 .741 .907 r
.78455 .41153 .78535 .4126 .79145 .41069 .79065 .40962 Metetra
.664 .741 .907 r
.79065 .40962 .79145 .41069 .79756 .40877 .79677 .4077 Metetra
.664 .741 .907 r
.79677 .4077 .79756 .40877 .80369 .40685 .8029 .40578 Metetra
.664 .741 .907 r
.8029 .40578 .80369 .40685 .80983 .40493 .80904 .40385 Metetra
.664 .741 .907 r
.80904 .40385 .80983 .40493 .81599 .403 .8152 .40192 Metetra
.664 .741 .907 r
.8152 .40192 .81599 .403 .82215 .40107 .82137 .39999 Metetra
.664 .741 .907 r
.82137 .39999 .82215 .40107 .82833 .39913 .82755 .39805 Metetra
.664 .741 .907 r
.82755 .39805 .82833 .39913 .83453 .39719 .83375 .3961 Metetra
.664 .741 .907 r
.83375 .3961 .83453 .39719 .84073 .39524 .83996 .39416 Metetra
.664 .741 .907 r
.83996 .39416 .84073 .39524 .84695 .39329 .84618 .39221 Metetra
.664 .741 .907 r
.84618 .39221 .84695 .39329 .85318 .39134 .85242 .39025 Metetra
.664 .741 .907 r
.85242 .39025 .85318 .39134 .85943 .38938 .85867 .38829 Metetra
.664 .741 .907 r
.85867 .38829 .85943 .38938 .86569 .38742 .86493 .38633 Metetra
.664 .741 .907 r
.86493 .38633 .86569 .38742 .87196 .38546 .8712 .38436 Metetra
.664 .741 .907 r
.8712 .38436 .87196 .38546 .87825 .38349 .87749 .38239 Metetra
.664 .741 .907 r
.87749 .38239 .87825 .38349 .88455 .38151 .8838 .38041 Metetra
.664 .741 .907 r
.8838 .38041 .88455 .38151 .89086 .37953 .89011 .37843 Metetra
.664 .741 .907 r
.89011 .37843 .89086 .37953 .89719 .37755 .89644 .37644 Metetra
.664 .741 .907 r
.89644 .37644 .89719 .37755 .90353 .37556 .90279 .37445 Metetra
.664 .741 .907 r
.90279 .37445 .90353 .37556 .90989 .37357 .90915 .37246 Metetra
.664 .741 .907 r
.90915 .37246 .90989 .37357 .91626 .37158 .91552 .37046 Metetra
.664 .741 .907 r
.91552 .37046 .91626 .37158 .92264 .36958 .9219 .36846 Metetra
.664 .741 .907 r
.9219 .36846 .92264 .36958 .92903 .36757 .9283 .36645 Metetra
.664 .741 .907 r
.34942 .54677 .3504 .54768 .35562 .54605 .35464 .54513 Metetra
.664 .741 .907 r
.35464 .54513 .35562 .54605 .36084 .54441 .35987 .54349 Metetra
.664 .741 .907 r
.35987 .54349 .36084 .54441 .36608 .54277 .36511 .54185 Metetra
.664 .741 .907 r
.36511 .54185 .36608 .54277 .37133 .54112 .37036 .5402 Metetra
.664 .741 .907 r
.37036 .5402 .37133 .54112 .37659 .53947 .37563 .53855 Metetra
.664 .741 .907 r
.37563 .53855 .37659 .53947 .38186 .53782 .3809 .53689 Metetra
.664 .741 .907 r
.3809 .53689 .38186 .53782 .38714 .53616 .38618 .53524 Metetra
.664 .741 .907 r
.38618 .53524 .38714 .53616 .39243 .5345 .39147 .53357 Metetra
.948 .635 .409 r
.39147 .53357 .39243 .5345 .3964 .56811 .39549 .56549 Metetra
.886 .669 .605 r
.39549 .56549 .3964 .56811 .40305 .53117 .40209 .53024 Metetra
.664 .741 .907 r
.40209 .53024 .40305 .53117 .40837 .5295 .40741 .52857 Metetra
.664 .741 .907 r
.40741 .52857 .40837 .5295 .4137 .52783 .41275 .5269 Metetra
.664 .741 .907 r
.41275 .5269 .4137 .52783 .41904 .52616 .41809 .52522 Metetra
.664 .741 .907 r
.41809 .52522 .41904 .52616 .4244 .52448 .42345 .52354 Metetra
.664 .741 .907 r
.42345 .52354 .4244 .52448 .42976 .5228 .42882 .52186 Metetra
.664 .741 .907 r
.42882 .52186 .42976 .5228 .43514 .52111 .43419 .52017 Metetra
.664 .741 .907 r
.43419 .52017 .43514 .52111 .44052 .51942 .43958 .51848 Metetra
.664 .741 .907 r
.43958 .51848 .44052 .51942 .44592 .51773 .44498 .51678 Metetra
.664 .741 .907 r
.44498 .51678 .44592 .51773 .45133 .51603 .45039 .51509 Metetra
.664 .741 .907 r
.45039 .51509 .45133 .51603 .45675 .51433 .45581 .51338 Metetra
.664 .741 .907 r
.45581 .51338 .45675 .51433 .46218 .51263 .46124 .51168 Metetra
.664 .741 .907 r
.46124 .51168 .46218 .51263 .46761 .51092 .46668 .50997 Metetra
.922 .529 .193 r
.46668 .50997 .46761 .51092 .47307 .50922 .47187 .52502 Metetra
.611 .37 .528 r
.47187 .52502 .47307 .50922 .47853 .5075 .47721 .53411 Metetra
.425 .227 .506 r
.47721 .53411 .47853 .5075 .484 .50579 .48307 .50483 Metetra
.664 .741 .907 r
.48307 .50483 .484 .50579 .48948 .50407 .48856 .50311 Metetra
.664 .741 .907 r
.48856 .50311 .48948 .50407 .49498 .50234 .49406 .50138 Metetra
.664 .741 .907 r
.49406 .50138 .49498 .50234 .50048 .50062 .49956 .49965 Metetra
.664 .741 .907 r
.49956 .49965 .50048 .50062 .50596 .5068 .50508 .49792 Metetra
.401 .279 .597 r
.50508 .49792 .50596 .5068 .51137 .53622 .51056 .50961 Metetra
.618 .411 .578 r
.51056 .50961 .51137 .53622 .51707 .49542 .51615 .49445 Metetra
.664 .741 .907 r
.51615 .49445 .51707 .49542 .52262 .49368 .52171 .4927 Metetra
.664 .741 .907 r
.52171 .4927 .52262 .49368 .52818 .49193 .52727 .49096 Metetra
.664 .741 .907 r
.52727 .49096 .52818 .49193 .53375 .49018 .53285 .48921 Metetra
.664 .741 .907 r
.53285 .48921 .53375 .49018 .53934 .48843 .53843 .48745 Metetra
.664 .741 .907 r
.53843 .48745 .53934 .48843 .54493 .48668 .54403 .4857 Metetra
.664 .741 .907 r
.54403 .4857 .54493 .48668 .55054 .48492 .54964 .48394 Metetra
.664 .741 .907 r
.54964 .48394 .55054 .48492 .55616 .48316 .55526 .48217 Metetra
.664 .741 .907 r
.55526 .48217 .55616 .48316 .56179 .48139 .56089 .48041 Metetra
.664 .741 .907 r
.56089 .48041 .56179 .48139 .56743 .47962 .56654 .47863 Metetra
.664 .741 .907 r
.56654 .47863 .56743 .47962 .57308 .47785 .57219 .47686 Metetra
.664 .741 .907 r
.57219 .47686 .57308 .47785 .57875 .47607 .57786 .47508 Metetra
.664 .741 .907 r
.57786 .47508 .57875 .47607 .58442 .47429 .58353 .4733 Metetra
.664 .741 .907 r
.58353 .4733 .58442 .47429 .59011 .47251 .58922 .47151 Metetra
.664 .741 .907 r
.58922 .47151 .59011 .47251 .59581 .47072 .59493 .46972 Metetra
.664 .741 .907 r
.59493 .46972 .59581 .47072 .60152 .46893 .60064 .46793 Metetra
.664 .741 .907 r
.60064 .46793 .60152 .46893 .60725 .4676 .60636 .46614 Metetra
.658 .66 .841 r
.60636 .46614 .60725 .4676 .61297 .46534 .6121 .46434 Metetra
.664 .741 .907 r
.6121 .46434 .61297 .46534 .61872 .46354 .61785 .46253 Metetra
.664 .741 .907 r
.61785 .46253 .61872 .46354 .62448 .46173 .62361 .46072 Metetra
.664 .741 .907 r
.62361 .46072 .62448 .46173 .63025 .45992 .62938 .45891 Metetra
.664 .741 .907 r
.62938 .45891 .63025 .45992 .63603 .45811 .63516 .4571 Metetra
.664 .741 .907 r
.63516 .4571 .63603 .45811 .64182 .45629 .64096 .45528 Metetra
.664 .741 .907 r
.64096 .45528 .64182 .45629 .64763 .45447 .64677 .45345 Metetra
.664 .741 .907 r
.64677 .45345 .64763 .45447 .65345 .45265 .65259 .45163 Metetra
.664 .741 .907 r
.65259 .45163 .65345 .45265 .65928 .45082 .65842 .4498 Metetra
.963 .635 .331 r
.65842 .4498 .65928 .45082 .66512 .44899 .66647 .49971 Metetra
.446 .256 .528 r
.66647 .49971 .66512 .44899 .67097 .44715 .67012 .44613 Metetra
.664 .741 .907 r
.67012 .44613 .67097 .44715 .67684 .44531 .67599 .44428 Metetra
.664 .741 .907 r
.67599 .44428 .67684 .44531 .68272 .44347 .68187 .44244 Metetra
.664 .741 .907 r
.68187 .44244 .68272 .44347 .68861 .44162 .68776 .44059 Metetra
.664 .741 .907 r
.68776 .44059 .68861 .44162 .69451 .43977 .69367 .43874 Metetra
.664 .741 .907 r
.69367 .43874 .69451 .43977 .70042 .43792 .69959 .43688 Metetra
.664 .741 .907 r
.69959 .43688 .70042 .43792 .70635 .43606 .70552 .43502 Metetra
.664 .741 .907 r
.70552 .43502 .70635 .43606 .71229 .43419 .71146 .43315 Metetra
.664 .741 .907 r
.71146 .43315 .71229 .43419 .71824 .43233 .71741 .43128 Metetra
.664 .741 .907 r
.71741 .43128 .71824 .43233 .72421 .43046 .72338 .42941 Metetra
.664 .741 .907 r
.72338 .42941 .72421 .43046 .73018 .42858 .72936 .42754 Metetra
.664 .741 .907 r
.72936 .42754 .73018 .42858 .73617 .4267 .73535 .42565 Metetra
.664 .741 .907 r
.73535 .42565 .73617 .4267 .74326 .44101 .74136 .42377 Metetra
.579 .388 .587 r
.74136 .42377 .74326 .44101 .74819 .42294 .74737 .42188 Metetra
.664 .741 .907 r
.74737 .42188 .74819 .42294 .75422 .42105 .7534 .41999 Metetra
.664 .741 .907 r
.7534 .41999 .75422 .42105 .76026 .41915 .75945 .41809 Metetra
.664 .741 .907 r
.75945 .41809 .76026 .41915 .76631 .41725 .7655 .41619 Metetra
.664 .741 .907 r
.7655 .41619 .76631 .41725 .77238 .41535 .77157 .41429 Metetra
.664 .741 .907 r
.77157 .41429 .77238 .41535 .77846 .41344 .77765 .41238 Metetra
.664 .741 .907 r
.77765 .41238 .77846 .41344 .78455 .41153 .78375 .41047 Metetra
.664 .741 .907 r
.78375 .41047 .78455 .41153 .79065 .40962 .78985 .40855 Metetra
.664 .741 .907 r
.78985 .40855 .79065 .40962 .79677 .4077 .79598 .40663 Metetra
.664 .741 .907 r
.79598 .40663 .79677 .4077 .8029 .40578 .80211 .4047 Metetra
.664 .741 .907 r
.80211 .4047 .8029 .40578 .80904 .40385 .80825 .40278 Metetra
.664 .741 .907 r
.80825 .40278 .80904 .40385 .8152 .40192 .81441 .40084 Metetra
.664 .741 .907 r
.81441 .40084 .8152 .40192 .82137 .39999 .82059 .39891 Metetra
.664 .741 .907 r
.82059 .39891 .82137 .39999 .82755 .39805 .82677 .39696 Metetra
.664 .741 .907 r
.82677 .39696 .82755 .39805 .83375 .3961 .83297 .39502 Metetra
.664 .741 .907 r
.83297 .39502 .83375 .3961 .83996 .39416 .83918 .39307 Metetra
.664 .741 .907 r
.83918 .39307 .83996 .39416 .84618 .39221 .84541 .39112 Metetra
.664 .741 .907 r
.84541 .39112 .84618 .39221 .85242 .39025 .85165 .38916 Metetra
.664 .741 .907 r
.85165 .38916 .85242 .39025 .85867 .38829 .8579 .3872 Metetra
.664 .741 .907 r
.8579 .3872 .85867 .38829 .86493 .38633 .86416 .38523 Metetra
0 .073 .617 r
.86416 .38523 .86493 .38633 .8712 .38436 .87149 .39297 Metetra
.417 .197 .47 r
.87149 .39297 .8712 .38436 .87749 .38239 .87674 .38128 Metetra
.664 .741 .907 r
.87674 .38128 .87749 .38239 .8838 .38041 .88304 .3793 Metetra
.664 .741 .907 r
.88304 .3793 .8838 .38041 .89011 .37843 .88936 .37732 Metetra
.664 .741 .907 r
.88936 .37732 .89011 .37843 .89644 .37644 .8957 .37533 Metetra
.664 .741 .907 r
.8957 .37533 .89644 .37644 .90279 .37445 .90204 .37334 Metetra
.664 .741 .907 r
.90204 .37334 .90279 .37445 .90915 .37246 .9084 .37135 Metetra
.664 .741 .907 r
.9084 .37135 .90915 .37246 .91552 .37046 .91478 .36935 Metetra
.664 .741 .907 r
.91478 .36935 .91552 .37046 .9219 .36846 .92117 .36734 Metetra
.664 .741 .907 r
.92117 .36734 .9219 .36846 .9283 .36645 .92757 .36533 Metetra
.664 .741 .907 r
.34844 .54586 .34942 .54677 .35464 .54513 .35367 .54422 Metetra
.664 .741 .907 r
.35367 .54422 .35464 .54513 .35987 .54349 .3589 .54258 Metetra
.664 .741 .907 r
.3589 .54258 .35987 .54349 .36511 .54185 .36414 .54093 Metetra
.664 .741 .907 r
.36414 .54093 .36511 .54185 .37036 .5402 .36939 .53928 Metetra
.664 .741 .907 r
.36939 .53928 .37036 .5402 .37563 .53855 .37466 .53763 Metetra
.664 .741 .907 r
.37466 .53763 .37563 .53855 .3809 .53689 .37993 .53597 Metetra
.664 .741 .907 r
.37993 .53597 .3809 .53689 .38618 .53524 .38521 .53431 Metetra
.664 .741 .907 r
.38521 .53431 .38618 .53524 .39147 .53357 .39051 .53265 Metetra
.664 .741 .907 r
.39051 .53265 .39147 .53357 .39549 .56549 .39581 .53098 Metetra
.571 .371 .57 r
.39581 .53098 .39549 .56549 .40209 .53024 .40113 .52931 Metetra
.664 .741 .907 r
.40113 .52931 .40209 .53024 .40741 .52857 .40646 .52764 Metetra
.664 .741 .907 r
.40646 .52764 .40741 .52857 .41275 .5269 .41179 .52596 Metetra
.664 .741 .907 r
.41179 .52596 .41275 .5269 .41809 .52522 .41714 .52428 Metetra
.664 .741 .907 r
.41714 .52428 .41809 .52522 .42345 .52354 .4225 .5226 Metetra
.664 .741 .907 r
.4225 .5226 .42345 .52354 .42882 .52186 .42787 .52091 Metetra
.664 .741 .907 r
.42787 .52091 .42882 .52186 .43419 .52017 .43325 .51923 Metetra
.664 .741 .907 r
.43325 .51923 .43419 .52017 .43958 .51848 .43864 .51753 Metetra
.664 .741 .907 r
.43864 .51753 .43958 .51848 .44498 .51678 .44404 .51584 Metetra
.664 .741 .907 r
.44404 .51584 .44498 .51678 .45039 .51509 .44945 .51414 Metetra
.664 .741 .907 r
.44945 .51414 .45039 .51509 .45581 .51338 .45487 .51243 Metetra
.664 .741 .907 r
.45487 .51243 .45581 .51338 .46124 .51168 .4603 .51073 Metetra
.664 .741 .907 r
.4603 .51073 .46124 .51168 .46668 .50997 .46575 .50902 Metetra
.952 .678 .481 r
.46575 .50902 .46668 .50997 .47187 .52502 .46832 .68642 Metetra
.504 .303 .541 r
.46832 .68642 .47187 .52502 .47721 .53411 .47533 .59769 Metetra
.362 .187 .504 r
.47533 .59769 .47721 .53411 .48307 .50483 .48215 .50387 Metetra
.664 .741 .907 r
.48215 .50387 .48307 .50483 .48856 .50311 .48763 .50214 Metetra
.664 .741 .907 r
.48763 .50214 .48856 .50311 .49406 .50138 .49313 .50042 Metetra
.664 .741 .907 r
.49313 .50042 .49406 .50138 .49956 .49965 .49864 .49869 Metetra
.664 .741 .907 r
.49864 .49869 .49956 .49965 .50508 .49792 .50416 .49695 Metetra
.664 .741 .907 r
.50416 .49695 .50508 .49792 .51056 .50961 .5097 .49522 Metetra
.581 .393 .592 r
.5097 .49522 .51056 .50961 .51615 .49445 .51524 .49347 Metetra
.664 .741 .907 r
.51524 .49347 .51615 .49445 .52171 .4927 .52079 .49173 Metetra
.664 .741 .907 r
.52079 .49173 .52171 .4927 .52727 .49096 .52636 .48998 Metetra
.664 .741 .907 r
.52636 .48998 .52727 .49096 .53285 .48921 .53194 .48823 Metetra
.664 .741 .907 r
.53194 .48823 .53285 .48921 .53843 .48745 .53753 .48647 Metetra
.664 .741 .907 r
.53753 .48647 .53843 .48745 .54403 .4857 .54313 .48472 Metetra
.664 .741 .907 r
.54313 .48472 .54403 .4857 .54964 .48394 .54874 .48295 Metetra
.664 .741 .907 r
.54874 .48295 .54964 .48394 .55526 .48217 .55436 .48119 Metetra
.664 .741 .907 r
.55436 .48119 .55526 .48217 .56089 .48041 .55999 .47942 Metetra
.664 .741 .907 r
.55999 .47942 .56089 .48041 .56654 .47863 .56564 .47765 Metetra
.664 .741 .907 r
.56564 .47765 .56654 .47863 .57219 .47686 .5713 .47587 Metetra
.664 .741 .907 r
.5713 .47587 .57219 .47686 .57786 .47508 .57697 .47409 Metetra
.664 .741 .907 r
.57697 .47409 .57786 .47508 .58353 .4733 .58265 .4723 Metetra
.664 .741 .907 r
.58265 .4723 .58353 .4733 .58922 .47151 .58834 .47052 Metetra
.664 .741 .907 r
.58834 .47052 .58922 .47151 .59493 .46972 .59404 .46873 Metetra
.664 .741 .907 r
.59404 .46873 .59493 .46972 .60064 .46793 .59976 .46693 Metetra
.664 .741 .907 r
.59976 .46693 .60064 .46793 .60636 .46614 .60549 .46513 Metetra
.664 .741 .907 r
.60549 .46513 .60636 .46614 .6121 .46434 .61122 .46333 Metetra
.664 .741 .907 r
.61122 .46333 .6121 .46434 .61785 .46253 .61698 .46152 Metetra
.664 .741 .907 r
.61698 .46152 .61785 .46253 .62361 .46072 .62274 .45971 Metetra
.664 .741 .907 r
.62274 .45971 .62361 .46072 .62938 .45891 .62851 .4579 Metetra
.664 .741 .907 r
.62851 .4579 .62938 .45891 .63516 .4571 .6343 .45608 Metetra
.664 .741 .907 r
.6343 .45608 .63516 .4571 .64096 .45528 .6401 .45426 Metetra
.664 .741 .907 r
.6401 .45426 .64096 .45528 .64677 .45345 .64591 .45244 Metetra
.664 .741 .907 r
.64591 .45244 .64677 .45345 .65259 .45163 .65173 .45061 Metetra
.664 .741 .907 r
.65173 .45061 .65259 .45163 .65842 .4498 .65756 .44878 Metetra
.968 .665 .393 r
.65756 .44878 .65842 .4498 .66647 .49971 .66828 .56189 Metetra
.32 .162 .505 r
.66828 .56189 .66647 .49971 .67012 .44613 .66927 .4451 Metetra
.664 .741 .907 r
.66927 .4451 .67012 .44613 .67599 .44428 .67514 .44326 Metetra
.664 .741 .907 r
.67514 .44326 .67599 .44428 .68187 .44244 .68102 .44141 Metetra
.664 .741 .907 r
.68102 .44141 .68187 .44244 .68776 .44059 .68692 .43956 Metetra
.664 .741 .907 r
.68692 .43956 .68776 .44059 .69367 .43874 .69283 .4377 Metetra
.664 .741 .907 r
.69283 .4377 .69367 .43874 .69959 .43688 .69875 .43584 Metetra
.664 .741 .907 r
.69875 .43584 .69959 .43688 .70552 .43502 .70468 .43398 Metetra
.664 .741 .907 r
.70468 .43398 .70552 .43502 .71146 .43315 .71062 .43211 Metetra
.664 .741 .907 r
.71062 .43211 .71146 .43315 .71741 .43128 .71658 .43024 Metetra
.664 .741 .907 r
.71658 .43024 .71741 .43128 .72338 .42941 .72255 .42837 Metetra
.664 .741 .907 r
.72255 .42837 .72338 .42941 .72936 .42754 .72853 .42649 Metetra
.664 .741 .907 r
.72853 .42649 .72936 .42754 .73535 .42565 .73453 .4246 Metetra
.664 .741 .907 r
.73453 .4246 .73535 .42565 .74136 .42377 .74054 .42272 Metetra
.664 .741 .907 r
.74054 .42272 .74136 .42377 .74737 .42188 .74656 .42083 Metetra
.664 .741 .907 r
.74656 .42083 .74737 .42188 .7534 .41999 .75259 .41893 Metetra
.664 .741 .907 r
.75259 .41893 .7534 .41999 .75945 .41809 .75864 .41703 Metetra
.664 .741 .907 r
.75864 .41703 .75945 .41809 .7655 .41619 .76469 .41513 Metetra
.664 .741 .907 r
.76469 .41513 .7655 .41619 .77157 .41429 .77077 .41322 Metetra
.664 .741 .907 r
.77077 .41322 .77157 .41429 .77765 .41238 .77685 .41131 Metetra
.664 .741 .907 r
.77685 .41131 .77765 .41238 .78375 .41047 .78295 .4094 Metetra
.664 .741 .907 r
.78295 .4094 .78375 .41047 .78985 .40855 .78906 .40748 Metetra
.664 .741 .907 r
.78906 .40748 .78985 .40855 .79598 .40663 .79518 .40556 Metetra
.664 .741 .907 r
.79518 .40556 .79598 .40663 .80211 .4047 .80132 .40363 Metetra
.664 .741 .907 r
.80132 .40363 .80211 .4047 .80825 .40278 .80746 .4017 Metetra
.664 .741 .907 r
.80746 .4017 .80825 .40278 .81441 .40084 .81363 .39976 Metetra
.664 .741 .907 r
.81363 .39976 .81441 .40084 .82059 .39891 .8198 .39782 Metetra
.664 .741 .907 r
.8198 .39782 .82059 .39891 .82677 .39696 .82599 .39588 Metetra
.664 .741 .907 r
.82599 .39588 .82677 .39696 .83297 .39502 .83219 .39393 Metetra
.664 .741 .907 r
.83219 .39393 .83297 .39502 .83918 .39307 .83841 .39198 Metetra
.664 .741 .907 r
.83841 .39198 .83918 .39307 .84541 .39112 .84464 .39002 Metetra
.664 .741 .907 r
.84464 .39002 .84541 .39112 .85165 .38916 .85088 .38806 Metetra
.664 .741 .907 r
.85088 .38806 .85165 .38916 .8579 .3872 .85713 .3861 Metetra
.664 .741 .907 r
.85713 .3861 .8579 .3872 .86416 .38523 .8634 .38413 Metetra
.955 .616 .235 r
.8634 .38413 .86416 .38523 .87149 .39297 .87764 .45612 Metetra
.441 .259 .537 r
.87764 .45612 .87149 .39297 .87674 .38128 .87598 .38018 Metetra
.664 .741 .907 r
.87598 .38018 .87674 .38128 .88304 .3793 .88229 .3782 Metetra
.664 .741 .907 r
.88229 .3782 .88304 .3793 .88936 .37732 .88861 .37621 Metetra
.664 .741 .907 r
.88861 .37621 .88936 .37732 .8957 .37533 .89495 .37422 Metetra
.664 .741 .907 r
.89495 .37422 .8957 .37533 .90204 .37334 .9013 .37223 Metetra
.664 .741 .907 r
.9013 .37223 .90204 .37334 .9084 .37135 .90766 .37023 Metetra
.664 .741 .907 r
.90766 .37023 .9084 .37135 .91478 .36935 .91404 .36823 Metetra
.664 .741 .907 r
.91404 .36823 .91478 .36935 .92117 .36734 .92043 .36622 Metetra
.664 .741 .907 r
.92043 .36622 .92117 .36734 .92757 .36533 .92684 .36421 Metetra
.664 .741 .907 r
.34746 .54494 .34844 .54586 .35367 .54422 .35269 .5433 Metetra
.664 .741 .907 r
.35269 .5433 .35367 .54422 .3589 .54258 .35792 .54166 Metetra
.664 .741 .907 r
.35792 .54166 .3589 .54258 .36414 .54093 .36317 .54001 Metetra
.664 .741 .907 r
.36317 .54001 .36414 .54093 .36939 .53928 .36842 .53836 Metetra
.664 .741 .907 r
.36842 .53836 .36939 .53928 .37466 .53763 .37369 .5367 Metetra
.664 .741 .907 r
.37369 .5367 .37466 .53763 .37993 .53597 .37896 .53504 Metetra
.664 .741 .907 r
.37896 .53504 .37993 .53597 .38521 .53431 .38425 .53338 Metetra
.664 .741 .907 r
.38425 .53338 .38521 .53431 .39051 .53265 .38955 .53172 Metetra
.664 .741 .907 r
.38955 .53172 .39051 .53265 .39581 .53098 .39485 .53005 Metetra
.664 .741 .907 r
.39485 .53005 .39581 .53098 .40113 .52931 .40017 .52838 Metetra
.664 .741 .907 r
.40017 .52838 .40113 .52931 .40646 .52764 .4055 .5267 Metetra
.664 .741 .907 r
.4055 .5267 .40646 .52764 .41179 .52596 .41084 .52503 Metetra
.664 .741 .907 r
.41084 .52503 .41179 .52596 .41714 .52428 .41619 .52335 Metetra
.664 .741 .907 r
.41619 .52335 .41714 .52428 .4225 .5226 .42155 .52166 Metetra
.664 .741 .907 r
.42155 .52166 .4225 .5226 .42787 .52091 .42692 .51997 Metetra
.664 .741 .907 r
.42692 .51997 .42787 .52091 .43325 .51923 .4323 .51828 Metetra
.664 .741 .907 r
.4323 .51828 .43325 .51923 .43864 .51753 .43769 .51659 Metetra
.664 .741 .907 r
.43769 .51659 .43864 .51753 .44404 .51584 .44309 .51489 Metetra
.664 .741 .907 r
.44309 .51489 .44404 .51584 .44945 .51414 .44851 .51319 Metetra
.664 .741 .907 r
.44851 .51319 .44945 .51414 .45487 .51243 .45393 .51148 Metetra
.664 .741 .907 r
.45393 .51148 .45487 .51243 .4603 .51073 .45937 .50977 Metetra
.664 .741 .907 r
.45937 .50977 .4603 .51073 .46575 .50902 .46481 .50806 Metetra
.952 .679 .483 r
.46481 .50806 .46575 .50902 .46832 .68642 .46689 .7122 Metetra
.845 .694 .16 r
.46689 .7122 .46832 .68642 .47533 .59769 .47516 .54348 Metetra
.632 .415 .57 r
.47516 .54348 .47533 .59769 .48215 .50387 .48122 .50291 Metetra
.664 .741 .907 r
.48122 .50291 .48215 .50387 .48763 .50214 .48671 .50118 Metetra
.664 .741 .907 r
.48671 .50118 .48763 .50214 .49313 .50042 .49221 .49945 Metetra
.664 .741 .907 r
.49221 .49945 .49313 .50042 .49864 .49869 .49772 .49772 Metetra
.664 .741 .907 r
.49772 .49772 .49864 .49869 .50416 .49695 .50324 .49598 Metetra
.664 .741 .907 r
.50324 .49598 .50416 .49695 .5097 .49522 .50878 .49424 Metetra
.664 .741 .907 r
.50878 .49424 .5097 .49522 .51524 .49347 .51432 .4925 Metetra
.664 .741 .907 r
.51432 .4925 .51524 .49347 .52079 .49173 .51988 .49076 Metetra
.664 .741 .907 r
.51988 .49076 .52079 .49173 .52636 .48998 .52545 .48901 Metetra
.664 .741 .907 r
.52545 .48901 .52636 .48998 .53194 .48823 .53103 .48725 Metetra
.664 .741 .907 r
.53103 .48725 .53194 .48823 .53753 .48647 .53662 .48549 Metetra
.664 .741 .907 r
.53662 .48549 .53753 .48647 .54313 .48472 .54222 .48373 Metetra
.664 .741 .907 r
.54222 .48373 .54313 .48472 .54874 .48295 .54784 .48197 Metetra
.664 .741 .907 r
.54784 .48197 .54874 .48295 .55436 .48119 .55346 .4802 Metetra
.664 .741 .907 r
.55346 .4802 .55436 .48119 .55999 .47942 .5591 .47843 Metetra
.664 .741 .907 r
.5591 .47843 .55999 .47942 .56564 .47765 .56475 .47665 Metetra
.664 .741 .907 r
.56475 .47665 .56564 .47765 .5713 .47587 .5704 .47488 Metetra
.664 .741 .907 r
.5704 .47488 .5713 .47587 .57697 .47409 .57608 .47309 Metetra
.664 .741 .907 r
.57608 .47309 .57697 .47409 .58265 .4723 .58176 .47131 Metetra
.664 .741 .907 r
.58176 .47131 .58265 .4723 .58834 .47052 .58745 .46952 Metetra
.664 .741 .907 r
.58745 .46952 .58834 .47052 .59404 .46873 .59316 .46772 Metetra
.664 .741 .907 r
.59316 .46772 .59404 .46873 .59976 .46693 .59888 .46593 Metetra
.664 .741 .907 r
.59888 .46593 .59976 .46693 .60549 .46513 .60461 .46413 Metetra
.664 .741 .907 r
.60461 .46413 .60549 .46513 .61122 .46333 .61035 .46232 Metetra
.664 .741 .907 r
.61035 .46232 .61122 .46333 .61698 .46152 .6161 .46051 Metetra
.664 .741 .907 r
.6161 .46051 .61698 .46152 .62274 .45971 .62187 .4587 Metetra
.664 .741 .907 r
.62187 .4587 .62274 .45971 .62851 .4579 .62764 .45689 Metetra
.664 .741 .907 r
.62764 .45689 .62851 .4579 .6343 .45608 .63343 .45507 Metetra
.664 .741 .907 r
.63343 .45507 .6343 .45608 .6401 .45426 .63923 .45324 Metetra
.664 .741 .907 r
.63923 .45324 .6401 .45426 .64591 .45244 .64505 .45142 Metetra
.664 .741 .907 r
.64505 .45142 .64591 .45244 .65173 .45061 .65087 .44959 Metetra
.911 .514 .12 r
.65087 .44959 .65173 .45061 .65756 .44878 .65754 .46849 Metetra
.663 .413 .532 r
.65754 .46849 .65756 .44878 .66828 .56189 .66464 .4954 Metetra
.632 .411 .565 r
.66464 .4954 .66828 .56189 .66927 .4451 .66842 .44407 Metetra
.664 .741 .907 r
.66842 .44407 .66927 .4451 .67514 .44326 .67429 .44223 Metetra
.664 .741 .907 r
.67429 .44223 .67514 .44326 .68102 .44141 .68018 .44038 Metetra
.664 .741 .907 r
.68018 .44038 .68102 .44141 .68692 .43956 .68608 .43852 Metetra
.664 .741 .907 r
.68608 .43852 .68692 .43956 .69283 .4377 .69199 .43666 Metetra
.664 .741 .907 r
.69199 .43666 .69283 .4377 .69875 .43584 .69791 .4348 Metetra
.664 .741 .907 r
.69791 .4348 .69875 .43584 .70468 .43398 .70384 .43294 Metetra
.664 .741 .907 r
.70384 .43294 .70468 .43398 .71062 .43211 .70979 .43107 Metetra
.664 .741 .907 r
.70979 .43107 .71062 .43211 .71658 .43024 .71575 .4292 Metetra
.664 .741 .907 r
.71575 .4292 .71658 .43024 .72255 .42837 .72172 .42732 Metetra
.664 .741 .907 r
.72172 .42732 .72255 .42837 .72853 .42649 .72771 .42544 Metetra
.664 .741 .907 r
.72771 .42544 .72853 .42649 .73453 .4246 .73371 .42355 Metetra
.664 .741 .907 r
.73371 .42355 .73453 .4246 .74054 .42272 .73972 .42166 Metetra
.664 .741 .907 r
.73972 .42166 .74054 .42272 .74656 .42083 .74574 .41977 Metetra
.664 .741 .907 r
.74574 .41977 .74656 .42083 .75259 .41893 .75177 .41787 Metetra
.664 .741 .907 r
.75177 .41787 .75259 .41893 .75864 .41703 .75782 .41597 Metetra
.664 .741 .907 r
.75782 .41597 .75864 .41703 .76469 .41513 .76388 .41407 Metetra
.664 .741 .907 r
.76388 .41407 .76469 .41513 .77077 .41322 .76996 .41216 Metetra
.664 .741 .907 r
.76996 .41216 .77077 .41322 .77685 .41131 .77605 .41025 Metetra
.664 .741 .907 r
.77605 .41025 .77685 .41131 .78295 .4094 .78214 .40833 Metetra
.664 .741 .907 r
.78214 .40833 .78295 .4094 .78906 .40748 .78826 .40641 Metetra
.664 .741 .907 r
.78826 .40641 .78906 .40748 .79518 .40556 .79438 .40448 Metetra
.664 .741 .907 r
.79438 .40448 .79518 .40556 .80132 .40363 .80052 .40255 Metetra
.664 .741 .907 r
.80052 .40255 .80132 .40363 .80746 .4017 .80667 .40062 Metetra
.664 .741 .907 r
.80667 .40062 .80746 .4017 .81363 .39976 .81284 .39868 Metetra
.664 .741 .907 r
.81284 .39868 .81363 .39976 .8198 .39782 .81902 .39674 Metetra
.664 .741 .907 r
.81902 .39674 .8198 .39782 .82599 .39588 .82521 .39479 Metetra
.664 .741 .907 r
.82521 .39479 .82599 .39588 .83219 .39393 .83141 .39284 Metetra
.664 .741 .907 r
.83141 .39284 .83219 .39393 .83841 .39198 .83763 .39089 Metetra
.664 .741 .907 r
.83763 .39089 .83841 .39198 .84464 .39002 .84386 .38893 Metetra
.664 .741 .907 r
.84386 .38893 .84464 .39002 .85088 .38806 .85011 .38697 Metetra
0 0 .456 r
.85011 .38697 .85088 .38806 .85713 .3861 .8576 .39692 Metetra
.425 .213 .485 r
.8576 .39692 .85713 .3861 .8634 .38413 .86264 .38303 Metetra
.664 .741 .907 r
.86264 .38303 .8634 .38413 .87764 .45612 .86892 .38106 Metetra
.568 .362 .561 r
.86892 .38106 .87764 .45612 .87598 .38018 .87522 .37908 Metetra
.664 .741 .907 r
.87522 .37908 .87598 .38018 .88229 .3782 .88153 .37709 Metetra
.664 .741 .907 r
.88153 .37709 .88229 .3782 .88861 .37621 .88786 .3751 Metetra
.664 .741 .907 r
.88786 .3751 .88861 .37621 .89495 .37422 .8942 .37311 Metetra
.664 .741 .907 r
.8942 .37311 .89495 .37422 .9013 .37223 .90055 .37111 Metetra
.664 .741 .907 r
.90055 .37111 .9013 .37223 .90766 .37023 .90692 .36911 Metetra
.664 .741 .907 r
.90692 .36911 .90766 .37023 .91404 .36823 .9133 .36711 Metetra
.664 .741 .907 r
.9133 .36711 .91404 .36823 .92043 .36622 .91969 .3651 Metetra
.664 .741 .907 r
.91969 .3651 .92043 .36622 .92684 .36421 .9261 .36308 Metetra
.664 .741 .907 r
.34648 .54403 .34746 .54494 .35269 .5433 .35171 .54239 Metetra
.664 .741 .907 r
.35171 .54239 .35269 .5433 .35792 .54166 .35695 .54074 Metetra
.664 .741 .907 r
.35695 .54074 .35792 .54166 .36317 .54001 .36219 .53909 Metetra
.664 .741 .907 r
.36219 .53909 .36317 .54001 .36842 .53836 .36745 .53743 Metetra
.664 .741 .907 r
.36745 .53743 .36842 .53836 .37369 .5367 .37272 .53578 Metetra
.937 .577 .302 r
.37272 .53578 .37369 .5367 .37896 .53504 .37717 .55306 Metetra
.458 .244 .499 r
.37717 .55306 .37896 .53504 .38425 .53338 .38304 .53822 Metetra
.324 .065 .358 r
.38304 .53822 .38425 .53338 .38955 .53172 .38858 .53079 Metetra
.664 .741 .907 r
.38858 .53079 .38955 .53172 .39485 .53005 .39389 .52912 Metetra
.664 .741 .907 r
.39389 .52912 .39485 .53005 .40017 .52838 .39921 .52745 Metetra
.664 .741 .907 r
.39921 .52745 .40017 .52838 .4055 .5267 .40454 .52577 Metetra
.664 .741 .907 r
.40454 .52577 .4055 .5267 .41084 .52503 .40988 .52409 Metetra
.664 .741 .907 r
.40988 .52409 .41084 .52503 .41619 .52335 .41523 .52241 Metetra
.664 .741 .907 r
.41523 .52241 .41619 .52335 .42155 .52166 .42059 .52072 Metetra
.664 .741 .907 r
.42059 .52072 .42155 .52166 .42692 .51997 .42597 .51903 Metetra
.664 .741 .907 r
.42597 .51903 .42692 .51997 .4323 .51828 .43135 .51734 Metetra
.664 .741 .907 r
.43135 .51734 .4323 .51828 .43769 .51659 .43674 .51564 Metetra
.664 .741 .907 r
.43674 .51564 .43769 .51659 .44309 .51489 .44215 .51394 Metetra
.664 .741 .907 r
.44215 .51394 .44309 .51489 .44851 .51319 .44756 .51224 Metetra
.664 .741 .907 r
.44756 .51224 .44851 .51319 .45393 .51148 .45299 .51053 Metetra
.664 .741 .907 r
.45299 .51053 .45393 .51148 .45937 .50977 .45843 .50882 Metetra
.302 .585 .941 r
.45843 .50882 .45937 .50977 .46481 .50806 .46382 .51021 Metetra
.933 .657 .495 r
.46382 .51021 .46481 .50806 .46689 .7122 .46678 .65881 Metetra
.745 .507 .571 r
.46678 .65881 .46689 .7122 .47516 .54348 .47469 .51144 Metetra
.595 .39 .573 r
.47469 .51144 .47516 .54348 .48122 .50291 .48029 .50194 Metetra
.664 .741 .907 r
.48029 .50194 .48122 .50291 .48671 .50118 .48578 .50022 Metetra
.664 .741 .907 r
.48578 .50022 .48671 .50118 .49221 .49945 .49128 .49849 Metetra
.664 .741 .907 r
.49128 .49849 .49221 .49945 .49772 .49772 .4968 .49675 Metetra
.664 .741 .907 r
.4968 .49675 .49772 .49772 .50324 .49598 .50232 .49501 Metetra
.664 .741 .907 r
.50232 .49501 .50324 .49598 .50878 .49424 .50786 .49327 Metetra
.664 .741 .907 r
.50786 .49327 .50878 .49424 .51432 .4925 .51341 .49153 Metetra
.664 .741 .907 r
.51341 .49153 .51432 .4925 .51988 .49076 .51897 .48978 Metetra
.664 .741 .907 r
.51897 .48978 .51988 .49076 .52545 .48901 .52454 .48803 Metetra
.664 .741 .907 r
.52454 .48803 .52545 .48901 .53103 .48725 .53012 .48627 Metetra
.664 .741 .907 r
.53012 .48627 .53103 .48725 .53662 .48549 .53571 .48451 Metetra
.664 .741 .907 r
.53571 .48451 .53662 .48549 .54222 .48373 .54132 .48275 Metetra
.664 .741 .907 r
.54132 .48275 .54222 .48373 .54784 .48197 .54693 .48098 Metetra
.664 .741 .907 r
.54693 .48098 .54784 .48197 .55346 .4802 .55256 .47921 Metetra
.664 .741 .907 r
.55256 .47921 .55346 .4802 .5591 .47843 .5582 .47744 Metetra
.664 .741 .907 r
.5582 .47744 .5591 .47843 .56475 .47665 .56385 .47566 Metetra
.664 .741 .907 r
.56385 .47566 .56475 .47665 .5704 .47488 .56951 .47388 Metetra
.664 .741 .907 r
.56951 .47388 .5704 .47488 .57608 .47309 .57518 .4721 Metetra
.664 .741 .907 r
.57518 .4721 .57608 .47309 .58176 .47131 .58087 .47031 Metetra
.664 .741 .907 r
.58087 .47031 .58176 .47131 .58745 .46952 .58657 .46852 Metetra
.664 .741 .907 r
.58657 .46852 .58745 .46952 .59316 .46772 .59227 .46672 Metetra
.664 .741 .907 r
.59227 .46672 .59316 .46772 .59888 .46593 .59799 .46492 Metetra
.664 .741 .907 r
.59799 .46492 .59888 .46593 .60461 .46413 .60373 .46312 Metetra
.664 .741 .907 r
.60373 .46312 .60461 .46413 .61035 .46232 .60947 .46131 Metetra
.664 .741 .907 r
.60947 .46131 .61035 .46232 .6161 .46051 .61523 .4595 Metetra
.664 .741 .907 r
.61523 .4595 .6161 .46051 .62187 .4587 .62099 .45769 Metetra
.664 .741 .907 r
.62099 .45769 .62187 .4587 .62764 .45689 .62677 .45587 Metetra
.664 .741 .907 r
.62677 .45587 .62764 .45689 .63343 .45507 .63256 .45405 Metetra
.664 .741 .907 r
.63256 .45405 .63343 .45507 .63923 .45324 .63837 .45223 Metetra
.664 .741 .907 r
.63837 .45223 .63923 .45324 .64505 .45142 .64418 .4504 Metetra
.664 .741 .907 r
.64418 .4504 .64505 .45142 .65087 .44959 .65001 .44856 Metetra
.664 .741 .907 r
.65001 .44856 .65087 .44959 .65754 .46849 .65585 .44673 Metetra
.575 .38 .58 r
.65585 .44673 .65754 .46849 .66464 .4954 .6617 .44489 Metetra
.569 .365 .565 r
.6617 .44489 .66464 .4954 .66842 .44407 .66757 .44304 Metetra
.664 .741 .907 r
.66757 .44304 .66842 .44407 .67429 .44223 .67344 .44119 Metetra
.664 .741 .907 r
.67344 .44119 .67429 .44223 .68018 .44038 .67933 .43934 Metetra
.664 .741 .907 r
.67933 .43934 .68018 .44038 .68608 .43852 .68523 .43749 Metetra
.664 .741 .907 r
.68523 .43749 .68608 .43852 .69199 .43666 .69114 .43563 Metetra
.664 .741 .907 r
.69114 .43563 .69199 .43666 .69791 .4348 .69707 .43376 Metetra
.664 .741 .907 r
.69707 .43376 .69791 .4348 .70384 .43294 .70301 .4319 Metetra
.664 .741 .907 r
.70301 .4319 .70384 .43294 .70979 .43107 .70896 .43002 Metetra
.664 .741 .907 r
.70896 .43002 .70979 .43107 .71575 .4292 .71492 .42815 Metetra
.664 .741 .907 r
.71492 .42815 .71575 .4292 .72172 .42732 .72089 .42627 Metetra
.664 .741 .907 r
.72089 .42627 .72172 .42732 .72771 .42544 .72688 .42439 Metetra
.664 .741 .907 r
.72688 .42439 .72771 .42544 .73371 .42355 .73288 .4225 Metetra
.664 .741 .907 r
.73288 .4225 .73371 .42355 .73972 .42166 .73889 .42061 Metetra
.664 .741 .907 r
.73889 .42061 .73972 .42166 .74574 .41977 .74492 .41871 Metetra
.664 .741 .907 r
.74492 .41871 .74574 .41977 .75177 .41787 .75096 .41681 Metetra
.664 .741 .907 r
.75096 .41681 .75177 .41787 .75782 .41597 .75701 .41491 Metetra
.664 .741 .907 r
.75701 .41491 .75782 .41597 .76388 .41407 .76307 .413 Metetra
.664 .741 .907 r
.76307 .413 .76388 .41407 .76996 .41216 .76915 .41109 Metetra
.664 .741 .907 r
.76915 .41109 .76996 .41216 .77605 .41025 .77524 .40918 Metetra
.664 .741 .907 r
.77524 .40918 .77605 .41025 .78214 .40833 .78134 .40726 Metetra
.664 .741 .907 r
.78134 .40726 .78214 .40833 .78826 .40641 .78746 .40533 Metetra
.664 .741 .907 r
.78746 .40533 .78826 .40641 .79438 .40448 .79359 .40341 Metetra
.664 .741 .907 r
.79359 .40341 .79438 .40448 .80052 .40255 .79973 .40147 Metetra
.664 .741 .907 r
.79973 .40147 .80052 .40255 .80667 .40062 .80588 .39954 Metetra
.664 .741 .907 r
.80588 .39954 .80667 .40062 .81284 .39868 .81205 .3976 Metetra
.664 .741 .907 r
.81205 .3976 .81284 .39868 .81902 .39674 .81823 .39566 Metetra
.664 .741 .907 r
.81823 .39566 .81902 .39674 .82521 .39479 .82443 .39371 Metetra
.664 .741 .907 r
.82443 .39371 .82521 .39479 .83141 .39284 .83063 .39175 Metetra
.664 .741 .907 r
.83063 .39175 .83141 .39284 .83763 .39089 .83685 .3898 Metetra
.664 .741 .907 r
.83685 .3898 .83763 .39089 .84386 .38893 .84309 .38784 Metetra
.664 .741 .907 r
.84309 .38784 .84386 .38893 .85011 .38697 .84933 .38587 Metetra
.664 .741 .907 r
.84933 .38587 .85011 .38697 .8576 .39692 .8556 .3839 Metetra
.583 .399 .598 r
.8556 .3839 .8576 .39692 .86264 .38303 .86187 .38193 Metetra
0 0 .498 r
.86187 .38193 .86264 .38303 .86892 .38106 .86939 .39142 Metetra
.424 .21 .483 r
.86939 .39142 .86892 .38106 .87522 .37908 .87446 .37797 Metetra
.664 .741 .907 r
.87446 .37797 .87522 .37908 .88153 .37709 .88077 .37598 Metetra
.664 .741 .907 r
.88077 .37598 .88153 .37709 .88786 .3751 .8871 .37399 Metetra
.664 .741 .907 r
.8871 .37399 .88786 .3751 .8942 .37311 .89345 .372 Metetra
.664 .741 .907 r
.89345 .372 .8942 .37311 .90055 .37111 .8998 .37 Metetra
.664 .741 .907 r
.8998 .37 .90055 .37111 .90692 .36911 .90617 .368 Metetra
.664 .741 .907 r
.90617 .368 .90692 .36911 .9133 .36711 .91256 .36599 Metetra
.664 .741 .907 r
.91256 .36599 .9133 .36711 .91969 .3651 .91895 .36398 Metetra
.664 .741 .907 r
.91895 .36398 .91969 .3651 .9261 .36308 .92536 .36196 Metetra
.664 .741 .907 r
.3455 .54311 .34648 .54403 .35171 .54239 .35073 .54147 Metetra
.664 .741 .907 r
.35073 .54147 .35171 .54239 .35695 .54074 .35597 .53982 Metetra
.664 .741 .907 r
.35597 .53982 .35695 .54074 .36219 .53909 .36122 .53817 Metetra
.664 .741 .907 r
.36122 .53817 .36219 .53909 .36745 .53743 .36648 .53651 Metetra
.664 .741 .907 r
.36648 .53651 .36745 .53743 .37272 .53578 .37175 .53485 Metetra
.945 .665 .478 r
.37175 .53485 .37272 .53578 .37717 .55306 .37387 .6048 Metetra
.359 .178 .495 r
.37387 .6048 .37717 .55306 .38304 .53822 .38232 .53153 Metetra
.596 .434 .633 r
.38232 .53153 .38304 .53822 .38858 .53079 .38762 .52986 Metetra
.664 .741 .907 r
.38762 .52986 .38858 .53079 .39389 .52912 .39293 .52819 Metetra
.664 .741 .907 r
.39293 .52819 .39389 .52912 .39921 .52745 .39825 .52651 Metetra
.664 .741 .907 r
.39825 .52651 .39921 .52745 .40454 .52577 .40358 .52483 Metetra
.664 .741 .907 r
.40358 .52483 .40454 .52577 .40988 .52409 .40892 .52315 Metetra
.664 .741 .907 r
.40892 .52315 .40988 .52409 .41523 .52241 .41428 .52147 Metetra
.664 .741 .907 r
.41428 .52147 .41523 .52241 .42059 .52072 .41964 .51978 Metetra
.664 .741 .907 r
.41964 .51978 .42059 .52072 .42597 .51903 .42502 .51809 Metetra
.664 .741 .907 r
.42502 .51809 .42597 .51903 .43135 .51734 .4304 .51639 Metetra
.664 .741 .907 r
.4304 .51639 .43135 .51734 .43674 .51564 .4358 .51469 Metetra
.664 .741 .907 r
.4358 .51469 .43674 .51564 .44215 .51394 .4412 .51299 Metetra
.664 .741 .907 r
.4412 .51299 .44215 .51394 .44756 .51224 .44662 .51129 Metetra
.664 .741 .907 r
.44662 .51129 .44756 .51224 .45299 .51053 .45205 .50958 Metetra
.664 .741 .907 r
.45205 .50958 .45299 .51053 .45843 .50882 .45749 .50786 Metetra
.664 .741 .907 r
.45749 .50786 .45843 .50882 .46382 .51021 .46294 .50615 Metetra
.95 .654 .211 r
.46294 .50615 .46382 .51021 .46678 .65881 .46771 .54527 Metetra
.58 .369 .56 r
.46771 .54527 .46678 .65881 .47469 .51144 .47348 .52847 Metetra
.334 .144 .466 r
.47348 .52847 .47469 .51144 .48029 .50194 .47936 .50098 Metetra
.664 .741 .907 r
.47936 .50098 .48029 .50194 .48578 .50022 .48485 .49925 Metetra
.664 .741 .907 r
.48485 .49925 .48578 .50022 .49128 .49849 .49036 .49752 Metetra
.664 .741 .907 r
.49036 .49752 .49128 .49849 .4968 .49675 .49587 .49578 Metetra
.664 .741 .907 r
.49587 .49578 .4968 .49675 .50232 .49501 .5014 .49404 Metetra
.664 .741 .907 r
.5014 .49404 .50232 .49501 .50786 .49327 .50694 .4923 Metetra
.664 .741 .907 r
.50694 .4923 .50786 .49327 .51341 .49153 .51249 .49055 Metetra
.664 .741 .907 r
.51249 .49055 .51341 .49153 .51897 .48978 .51805 .4888 Metetra
.664 .741 .907 r
.51805 .4888 .51897 .48978 .52454 .48803 .52362 .48705 Metetra
.664 .741 .907 r
.52362 .48705 .52454 .48803 .53012 .48627 .52921 .48529 Metetra
.664 .741 .907 r
.52921 .48529 .53012 .48627 .53571 .48451 .5348 .48353 Metetra
.664 .741 .907 r
.5348 .48353 .53571 .48451 .54132 .48275 .54041 .48177 Metetra
.664 .741 .907 r
.54041 .48177 .54132 .48275 .54693 .48098 .54603 .48 Metetra
0 .317 .797 r
.54603 .48 .54693 .48098 .55256 .47921 .5517 .48367 Metetra
.333 .072 .361 r
.5517 .48367 .55256 .47921 .5582 .47744 .5573 .47645 Metetra
.664 .741 .907 r
.5573 .47645 .5582 .47744 .56385 .47566 .56295 .47467 Metetra
.664 .741 .907 r
.56295 .47467 .56385 .47566 .56951 .47388 .56862 .47289 Metetra
.664 .741 .907 r
.56862 .47289 .56951 .47388 .57518 .4721 .57429 .4711 Metetra
.664 .741 .907 r
.57429 .4711 .57518 .4721 .58087 .47031 .57998 .46931 Metetra
.664 .741 .907 r
.57998 .46931 .58087 .47031 .58657 .46852 .58568 .46752 Metetra
.664 .741 .907 r
.58568 .46752 .58657 .46852 .59227 .46672 .59139 .46572 Metetra
.664 .741 .907 r
.59139 .46572 .59227 .46672 .59799 .46492 .59711 .46392 Metetra
.664 .741 .907 r
.59711 .46392 .59799 .46492 .60373 .46312 .60285 .46211 Metetra
.664 .741 .907 r
.60285 .46211 .60373 .46312 .60947 .46131 .60859 .46031 Metetra
.664 .741 .907 r
.60859 .46031 .60947 .46131 .61523 .4595 .61435 .45849 Metetra
.664 .741 .907 r
.61435 .45849 .61523 .4595 .62099 .45769 .62012 .45668 Metetra
.664 .741 .907 r
.62012 .45668 .62099 .45769 .62677 .45587 .6259 .45486 Metetra
.664 .741 .907 r
.6259 .45486 .62677 .45587 .63256 .45405 .6317 .45303 Metetra
.664 .741 .907 r
.6317 .45303 .63256 .45405 .63837 .45223 .6375 .45121 Metetra
.664 .741 .907 r
.6375 .45121 .63837 .45223 .64418 .4504 .64332 .44937 Metetra
.664 .741 .907 r
.64332 .44937 .64418 .4504 .65001 .44856 .64915 .44754 Metetra
.664 .741 .907 r
.64915 .44754 .65001 .44856 .65585 .44673 .65499 .4457 Metetra
0 .321 .804 r
.65499 .4457 .65585 .44673 .6617 .44489 .66109 .44973 Metetra
.354 .102 .386 r
.66109 .44973 .6617 .44489 .66757 .44304 .66671 .44201 Metetra
.664 .741 .907 r
.66671 .44201 .66757 .44304 .67344 .44119 .67259 .44016 Metetra
.664 .741 .907 r
.67259 .44016 .67344 .44119 .67933 .43934 .67848 .43831 Metetra
.664 .741 .907 r
.67848 .43831 .67933 .43934 .68523 .43749 .68438 .43645 Metetra
.664 .741 .907 r
.68438 .43645 .68523 .43749 .69114 .43563 .6903 .43459 Metetra
.664 .741 .907 r
.6903 .43459 .69114 .43563 .69707 .43376 .69623 .43272 Metetra
.664 .741 .907 r
.69623 .43272 .69707 .43376 .70301 .4319 .70217 .43085 Metetra
.664 .741 .907 r
.70217 .43085 .70301 .4319 .70896 .43002 .70812 .42898 Metetra
.664 .741 .907 r
.70812 .42898 .70896 .43002 .71492 .42815 .71408 .4271 Metetra
.664 .741 .907 r
.71408 .4271 .71492 .42815 .72089 .42627 .72006 .42522 Metetra
.664 .741 .907 r
.72006 .42522 .72089 .42627 .72688 .42439 .72605 .42333 Metetra
.664 .741 .907 r
.72605 .42333 .72688 .42439 .73288 .4225 .73206 .42144 Metetra
.664 .741 .907 r
.73206 .42144 .73288 .4225 .73889 .42061 .73807 .41955 Metetra
.664 .741 .907 r
.73807 .41955 .73889 .42061 .74492 .41871 .7441 .41765 Metetra
.664 .741 .907 r
.7441 .41765 .74492 .41871 .75096 .41681 .75014 .41575 Metetra
.664 .741 .907 r
.75014 .41575 .75096 .41681 .75701 .41491 .75619 .41385 Metetra
.664 .741 .907 r
.75619 .41385 .75701 .41491 .76307 .413 .76226 .41194 Metetra
.664 .741 .907 r
.76226 .41194 .76307 .413 .76915 .41109 .76834 .41002 Metetra
.664 .741 .907 r
.76834 .41002 .76915 .41109 .77524 .40918 .77443 .40811 Metetra
.664 .741 .907 r
.77443 .40811 .77524 .40918 .78134 .40726 .78054 .40619 Metetra
.664 .741 .907 r
.78054 .40619 .78134 .40726 .78746 .40533 .78666 .40426 Metetra
.664 .741 .907 r
.78666 .40426 .78746 .40533 .79359 .40341 .79279 .40233 Metetra
.664 .741 .907 r
.79279 .40233 .79359 .40341 .79973 .40147 .79893 .4004 Metetra
.664 .741 .907 r
.79893 .4004 .79973 .40147 .80588 .39954 .80509 .39846 Metetra
.664 .741 .907 r
.80509 .39846 .80588 .39954 .81205 .3976 .81126 .39652 Metetra
.664 .741 .907 r
.81126 .39652 .81205 .3976 .81823 .39566 .81744 .39457 Metetra
.664 .741 .907 r
.81744 .39457 .81823 .39566 .82443 .39371 .82364 .39262 Metetra
.664 .741 .907 r
.82364 .39262 .82443 .39371 .83063 .39175 .82985 .39066 Metetra
.664 .741 .907 r
.82985 .39066 .83063 .39175 .83685 .3898 .83607 .3887 Metetra
.664 .741 .907 r
.83607 .3887 .83685 .3898 .84309 .38784 .84231 .38674 Metetra
.664 .741 .907 r
.84231 .38674 .84309 .38784 .84933 .38587 .84856 .38477 Metetra
.664 .741 .907 r
.84856 .38477 .84933 .38587 .8556 .3839 .85483 .3828 Metetra
.664 .741 .907 r
.85483 .3828 .8556 .3839 .86187 .38193 .8611 .38083 Metetra
0 0 .5 r
.8611 .38083 .86187 .38193 .86939 .39142 .86862 .39029 Metetra
.935 .788 .673 r
.86862 .39029 .86939 .39142 .87446 .37797 .8737 .37686 Metetra
.664 .741 .907 r
.8737 .37686 .87446 .37797 .88077 .37598 .88002 .37487 Metetra
.664 .741 .907 r
.88002 .37487 .88077 .37598 .8871 .37399 .88635 .37288 Metetra
.664 .741 .907 r
.88635 .37288 .8871 .37399 .89345 .372 .89269 .37088 Metetra
.664 .741 .907 r
.89269 .37088 .89345 .372 .8998 .37 .89905 .36888 Metetra
.664 .741 .907 r
.89905 .36888 .8998 .37 .90617 .368 .90543 .36688 Metetra
.664 .741 .907 r
.90543 .36688 .90617 .368 .91256 .36599 .91181 .36487 Metetra
.664 .741 .907 r
.91181 .36487 .91256 .36599 .91895 .36398 .91821 .36285 Metetra
.664 .741 .907 r
.91821 .36285 .91895 .36398 .92536 .36196 .92463 .36083 Metetra
.664 .741 .907 r
.34452 .5422 .3455 .54311 .35073 .54147 .34975 .54055 Metetra
.664 .741 .907 r
.34975 .54055 .35073 .54147 .35597 .53982 .35499 .5389 Metetra
.664 .741 .907 r
.35499 .5389 .35597 .53982 .36122 .53817 .36024 .53724 Metetra
.664 .741 .907 r
.36024 .53724 .36122 .53817 .36648 .53651 .3655 .53559 Metetra
.664 .741 .907 r
.3655 .53559 .36648 .53651 .37175 .53485 .37077 .53393 Metetra
.944 .613 .369 r
.37077 .53393 .37175 .53485 .37387 .6048 .37494 .5573 Metetra
.618 .405 .571 r
.37494 .5573 .37387 .6048 .38232 .53153 .38135 .5306 Metetra
.664 .741 .907 r
.38135 .5306 .38232 .53153 .38762 .52986 .38665 .52893 Metetra
.664 .741 .907 r
.38665 .52893 .38762 .52986 .39293 .52819 .39196 .52725 Metetra
.664 .741 .907 r
.39196 .52725 .39293 .52819 .39825 .52651 .39729 .52558 Metetra
.664 .741 .907 r
.39729 .52558 .39825 .52651 .40358 .52483 .40262 .5239 Metetra
.664 .741 .907 r
.40262 .5239 .40358 .52483 .40892 .52315 .40796 .52221 Metetra
.664 .741 .907 r
.40796 .52221 .40892 .52315 .41428 .52147 .41332 .52052 Metetra
.664 .741 .907 r
.41332 .52052 .41428 .52147 .41964 .51978 .41869 .51883 Metetra
.95 .665 .463 r
.41869 .51883 .41964 .51978 .42502 .51809 .42188 .58936 Metetra
.431 .24 .519 r
.42188 .58936 .42502 .51809 .4304 .51639 .42945 .51544 Metetra
.664 .741 .907 r
.42945 .51544 .4304 .51639 .4358 .51469 .43485 .51374 Metetra
.664 .741 .907 r
.43485 .51374 .4358 .51469 .4412 .51299 .44026 .51204 Metetra
.664 .741 .907 r
.44026 .51204 .4412 .51299 .44662 .51129 .44568 .51033 Metetra
.664 .741 .907 r
.44568 .51033 .44662 .51129 .45205 .50958 .45111 .50862 Metetra
.664 .741 .907 r
.45111 .50862 .45205 .50958 .45749 .50786 .45655 .50691 Metetra
.664 .741 .907 r
.45655 .50691 .45749 .50786 .46294 .50615 .462 .50519 Metetra
.664 .741 .907 r
.462 .50519 .46294 .50615 .46771 .54527 .46747 .50347 Metetra
.57 .367 .567 r
.46747 .50347 .46771 .54527 .47348 .52847 .47294 .50175 Metetra
.573 .375 .574 r
.47294 .50175 .47348 .52847 .47936 .50098 .47842 .50002 Metetra
.664 .741 .907 r
.47842 .50002 .47936 .50098 .48485 .49925 .48392 .49829 Metetra
.664 .741 .907 r
.48392 .49829 .48485 .49925 .49036 .49752 .48943 .49655 Metetra
.664 .741 .907 r
.48943 .49655 .49036 .49752 .49587 .49578 .49495 .49481 Metetra
.664 .741 .907 r
.49495 .49481 .49587 .49578 .5014 .49404 .50048 .49307 Metetra
.664 .741 .907 r
.50048 .49307 .5014 .49404 .50694 .4923 .50602 .49133 Metetra
.664 .741 .907 r
.50602 .49133 .50694 .4923 .51249 .49055 .51157 .48958 Metetra
.664 .741 .907 r
.51157 .48958 .51249 .49055 .51805 .4888 .51713 .48782 Metetra
.664 .741 .907 r
.51713 .48782 .51805 .4888 .52362 .48705 .52271 .48607 Metetra
.664 .741 .907 r
.52271 .48607 .52362 .48705 .52921 .48529 .5283 .48431 Metetra
.664 .741 .907 r
.5283 .48431 .52921 .48529 .5348 .48353 .53389 .48255 Metetra
.664 .741 .907 r
.53389 .48255 .5348 .48353 .54041 .48177 .5395 .48078 Metetra
.664 .741 .907 r
.5395 .48078 .54041 .48177 .54603 .48 .54512 .47901 Metetra
.664 .741 .907 r
.54512 .47901 .54603 .48 .5517 .48367 .55075 .47724 Metetra
.598 .439 .637 r
.55075 .47724 .5517 .48367 .5573 .47645 .5564 .47546 Metetra
.938 .565 .229 r
.5564 .47546 .5573 .47645 .56295 .47467 .56231 .49635 Metetra
.426 .225 .503 r
.56231 .49635 .56295 .47467 .56862 .47289 .56772 .47189 Metetra
.664 .741 .907 r
.56772 .47189 .56862 .47289 .57429 .4711 .5734 .4701 Metetra
.664 .741 .907 r
.5734 .4701 .57429 .4711 .57998 .46931 .57909 .46831 Metetra
.664 .741 .907 r
.57909 .46831 .57998 .46931 .58568 .46752 .58479 .46652 Metetra
.664 .741 .907 r
.58479 .46652 .58568 .46752 .59139 .46572 .5905 .46472 Metetra
.664 .741 .907 r
.5905 .46472 .59139 .46572 .59711 .46392 .59623 .46291 Metetra
.664 .741 .907 r
.59623 .46291 .59711 .46392 .60285 .46211 .60196 .46111 Metetra
.664 .741 .907 r
.60196 .46111 .60285 .46211 .60859 .46031 .60771 .45929 Metetra
.664 .741 .907 r
.60771 .45929 .60859 .46031 .61435 .45849 .61347 .45748 Metetra
.664 .741 .907 r
.61347 .45748 .61435 .45849 .62012 .45668 .61924 .45566 Metetra
.664 .741 .907 r
.61924 .45566 .62012 .45668 .6259 .45486 .62503 .45384 Metetra
.664 .741 .907 r
.62503 .45384 .6259 .45486 .6317 .45303 .63083 .45201 Metetra
.664 .741 .907 r
.63083 .45201 .6317 .45303 .6375 .45121 .63663 .45019 Metetra
.664 .741 .907 r
.63663 .45019 .6375 .45121 .64332 .44937 .64245 .44835 Metetra
.664 .741 .907 r
.64245 .44835 .64332 .44937 .64915 .44754 .64829 .44651 Metetra
.664 .741 .907 r
.64829 .44651 .64915 .44754 .65499 .4457 .65413 .44467 Metetra
.664 .741 .907 r
.65413 .44467 .65499 .4457 .66109 .44973 .65999 .44283 Metetra
.596 .435 .633 r
.65999 .44283 .66109 .44973 .66671 .44201 .66586 .44098 Metetra
.664 .741 .907 r
.66586 .44098 .66671 .44201 .67259 .44016 .67174 .43913 Metetra
.664 .741 .907 r
.67174 .43913 .67259 .44016 .67848 .43831 .67763 .43727 Metetra
.664 .741 .907 r
.67763 .43727 .67848 .43831 .68438 .43645 .68354 .43541 Metetra
.664 .741 .907 r
.68354 .43541 .68438 .43645 .6903 .43459 .68945 .43355 Metetra
.664 .741 .907 r
.68945 .43355 .6903 .43459 .69623 .43272 .69538 .43168 Metetra
.664 .741 .907 r
.69538 .43168 .69623 .43272 .70217 .43085 .70133 .42981 Metetra
.664 .741 .907 r
.70133 .42981 .70217 .43085 .70812 .42898 .70728 .42793 Metetra
.664 .741 .907 r
.70728 .42793 .70812 .42898 .71408 .4271 .71325 .42605 Metetra
.664 .741 .907 r
.71325 .42605 .71408 .4271 .72006 .42522 .71923 .42417 Metetra
.664 .741 .907 r
.71923 .42417 .72006 .42522 .72605 .42333 .72522 .42228 Metetra
.664 .741 .907 r
.72522 .42228 .72605 .42333 .73206 .42144 .73123 .42039 Metetra
.664 .741 .907 r
.73123 .42039 .73206 .42144 .73807 .41955 .73725 .41849 Metetra
.664 .741 .907 r
.73725 .41849 .73807 .41955 .7441 .41765 .74328 .41659 Metetra
.664 .741 .907 r
.74328 .41659 .7441 .41765 .75014 .41575 .74932 .41469 Metetra
.664 .741 .907 r
.74932 .41469 .75014 .41575 .75619 .41385 .75538 .41278 Metetra
.664 .741 .907 r
.75538 .41278 .75619 .41385 .76226 .41194 .76145 .41087 Metetra
.664 .741 .907 r
.76145 .41087 .76226 .41194 .76834 .41002 .76753 .40896 Metetra
.664 .741 .907 r
.76753 .40896 .76834 .41002 .77443 .40811 .77363 .40704 Metetra
.664 .741 .907 r
.77363 .40704 .77443 .40811 .78054 .40619 .77973 .40511 Metetra
.664 .741 .907 r
.77973 .40511 .78054 .40619 .78666 .40426 .78585 .40318 Metetra
.664 .741 .907 r
.78585 .40318 .78666 .40426 .79279 .40233 .79199 .40125 Metetra
.664 .741 .907 r
.79199 .40125 .79279 .40233 .79893 .4004 .79814 .39932 Metetra
.664 .741 .907 r
.79814 .39932 .79893 .4004 .80509 .39846 .8043 .39737 Metetra
.664 .741 .907 r
.8043 .39737 .80509 .39846 .81126 .39652 .81047 .39543 Metetra
.664 .741 .907 r
.81047 .39543 .81126 .39652 .81744 .39457 .81666 .39348 Metetra
.664 .741 .907 r
.81666 .39348 .81744 .39457 .82364 .39262 .82286 .39153 Metetra
.664 .741 .907 r
.82286 .39153 .82364 .39262 .82985 .39066 .82907 .38957 Metetra
.664 .741 .907 r
.82907 .38957 .82985 .39066 .83607 .3887 .8353 .38761 Metetra
.664 .741 .907 r
.8353 .38761 .83607 .3887 .84231 .38674 .84154 .38565 Metetra
.664 .741 .907 r
.84154 .38565 .84231 .38674 .84856 .38477 .84779 .38368 Metetra
.664 .741 .907 r
.84779 .38368 .84856 .38477 .85483 .3828 .85406 .3817 Metetra
.664 .741 .907 r
.85406 .3817 .85483 .3828 .8611 .38083 .86034 .37972 Metetra
.658 .223 0 r
.86034 .37972 .8611 .38083 .86862 .39029 .8682 .39246 Metetra
.8682 .39246 .86862 .39029 .8737 .37686 .87294 .37575 Metetra
.664 .741 .907 r
.87294 .37575 .8737 .37686 .88002 .37487 .87926 .37376 Metetra
.664 .741 .907 r
.87926 .37376 .88002 .37487 .88635 .37288 .88559 .37177 Metetra
.664 .741 .907 r
.88559 .37177 .88635 .37288 .89269 .37088 .89194 .36977 Metetra
.664 .741 .907 r
.89194 .36977 .89269 .37088 .89905 .36888 .8983 .36776 Metetra
.664 .741 .907 r
.8983 .36776 .89905 .36888 .90543 .36688 .90468 .36576 Metetra
.664 .741 .907 r
.90468 .36576 .90543 .36688 .91181 .36487 .91107 .36374 Metetra
.664 .741 .907 r
.91107 .36374 .91181 .36487 .91821 .36285 .91747 .36173 Metetra
.664 .741 .907 r
.91747 .36173 .91821 .36285 .92463 .36083 .92389 .3597 Metetra
.664 .741 .907 r
.34354 .54128 .34452 .5422 .34975 .54055 .34877 .53963 Metetra
.664 .741 .907 r
.34877 .53963 .34975 .54055 .35499 .5389 .35401 .53798 Metetra
.664 .741 .907 r
.35401 .53798 .35499 .5389 .36024 .53724 .35926 .53632 Metetra
.664 .741 .907 r
.35926 .53632 .36024 .53724 .3655 .53559 .36453 .53466 Metetra
.664 .741 .907 r
.36453 .53466 .3655 .53559 .37077 .53393 .3698 .533 Metetra
.664 .741 .907 r
.3698 .533 .37077 .53393 .37494 .5573 .37508 .53133 Metetra
.573 .375 .574 r
.37508 .53133 .37494 .5573 .38135 .5306 .38038 .52966 Metetra
.664 .741 .907 r
.38038 .52966 .38135 .5306 .38665 .52893 .38568 .52799 Metetra
.664 .741 .907 r
.38568 .52799 .38665 .52893 .39196 .52725 .391 .52632 Metetra
.664 .741 .907 r
.391 .52632 .39196 .52725 .39729 .52558 .39632 .52464 Metetra
.664 .741 .907 r
.39632 .52464 .39729 .52558 .40262 .5239 .40166 .52296 Metetra
.664 .741 .907 r
.40166 .52296 .40262 .5239 .40796 .52221 .407 .52127 Metetra
.664 .741 .907 r
.407 .52127 .40796 .52221 .41332 .52052 .41236 .51958 Metetra
.664 .741 .907 r
.41236 .51958 .41332 .52052 .41869 .51883 .41773 .51789 Metetra
.947 .679 .497 r
.41773 .51789 .41869 .51883 .42188 .58936 .41645 .73453 Metetra
.342 .172 .5 r
.41645 .73453 .42188 .58936 .42945 .51544 .4285 .5145 Metetra
.664 .741 .907 r
.4285 .5145 .42945 .51544 .43485 .51374 .4339 .51279 Metetra
.664 .741 .907 r
.4339 .51279 .43485 .51374 .44026 .51204 .43931 .51109 Metetra
.664 .741 .907 r
.43931 .51109 .44026 .51204 .44568 .51033 .44473 .50938 Metetra
.664 .741 .907 r
.44473 .50938 .44568 .51033 .45111 .50862 .45016 .50767 Metetra
.664 .741 .907 r
.45016 .50767 .45111 .50862 .45655 .50691 .45561 .50595 Metetra
.664 .741 .907 r
.45561 .50595 .45655 .50691 .462 .50519 .46106 .50423 Metetra
.664 .741 .907 r
.46106 .50423 .462 .50519 .46747 .50347 .46653 .50251 Metetra
.664 .741 .907 r
.46653 .50251 .46747 .50347 .47294 .50175 .472 .50078 Metetra
.664 .741 .907 r
.472 .50078 .47294 .50175 .47842 .50002 .47749 .49905 Metetra
.664 .741 .907 r
.47749 .49905 .47842 .50002 .48392 .49829 .48299 .49732 Metetra
.664 .741 .907 r
.48299 .49732 .48392 .49829 .48943 .49655 .4885 .49558 Metetra
.664 .741 .907 r
.4885 .49558 .48943 .49655 .49495 .49481 .49402 .49384 Metetra
.664 .741 .907 r
.49402 .49384 .49495 .49481 .50048 .49307 .49955 .4921 Metetra
.664 .741 .907 r
.49955 .4921 .50048 .49307 .50602 .49133 .5051 .49035 Metetra
.664 .741 .907 r
.5051 .49035 .50602 .49133 .51157 .48958 .51065 .4886 Metetra
.664 .741 .907 r
.51065 .4886 .51157 .48958 .51713 .48782 .51622 .48685 Metetra
.664 .741 .907 r
.51622 .48685 .51713 .48782 .52271 .48607 .52179 .48509 Metetra
.664 .741 .907 r
.52179 .48509 .52271 .48607 .5283 .48431 .52738 .48333 Metetra
.664 .741 .907 r
.52738 .48333 .5283 .48431 .53389 .48255 .53298 .48156 Metetra
.664 .741 .907 r
.53298 .48156 .53389 .48255 .5395 .48078 .53859 .47979 Metetra
.664 .741 .907 r
.53859 .47979 .5395 .48078 .54512 .47901 .54422 .47802 Metetra
.664 .741 .907 r
.54422 .47802 .54512 .47901 .55075 .47724 .54985 .47624 Metetra
0 0 .499 r
.54985 .47624 .55075 .47724 .5564 .47546 .55557 .48234 Metetra
.832 .546 .504 r
.55557 .48234 .5564 .47546 .56231 .49635 .56181 .53194 Metetra
.33 .159 .491 r
.56181 .53194 .56231 .49635 .56772 .47189 .56682 .47089 Metetra
.664 .741 .907 r
.56682 .47089 .56772 .47189 .5734 .4701 .5725 .4691 Metetra
.664 .741 .907 r
.5725 .4691 .5734 .4701 .57909 .46831 .57819 .46731 Metetra
.664 .741 .907 r
.57819 .46731 .57909 .46831 .58479 .46652 .5839 .46551 Metetra
.664 .741 .907 r
.5839 .46551 .58479 .46652 .5905 .46472 .58961 .46371 Metetra
.664 .741 .907 r
.58961 .46371 .5905 .46472 .59623 .46291 .59534 .46191 Metetra
.664 .741 .907 r
.59534 .46191 .59623 .46291 .60196 .46111 .60108 .4601 Metetra
.664 .741 .907 r
.60108 .4601 .60196 .46111 .60771 .45929 .60683 .45828 Metetra
.664 .741 .907 r
.60683 .45828 .60771 .45929 .61347 .45748 .61259 .45647 Metetra
.664 .741 .907 r
.61259 .45647 .61347 .45748 .61924 .45566 .61837 .45465 Metetra
.664 .741 .907 r
.61837 .45465 .61924 .45566 .62503 .45384 .62416 .45282 Metetra
.664 .741 .907 r
.62416 .45282 .62503 .45384 .63083 .45201 .62995 .45099 Metetra
.664 .741 .907 r
.62995 .45099 .63083 .45201 .63663 .45019 .63577 .44916 Metetra
.664 .741 .907 r
.63577 .44916 .63663 .45019 .64245 .44835 .64159 .44733 Metetra
.664 .741 .907 r
.64159 .44733 .64245 .44835 .64829 .44651 .64742 .44549 Metetra
.664 .741 .907 r
.64742 .44549 .64829 .44651 .65413 .44467 .65327 .44365 Metetra
.664 .741 .907 r
.65327 .44365 .65413 .44467 .65999 .44283 .65913 .4418 Metetra
.664 .741 .907 r
.65913 .4418 .65999 .44283 .66586 .44098 .665 .43995 Metetra
.664 .741 .907 r
.665 .43995 .66586 .44098 .67174 .43913 .67088 .43809 Metetra
.664 .741 .907 r
.67088 .43809 .67174 .43913 .67763 .43727 .67678 .43623 Metetra
.664 .741 .907 r
.67678 .43623 .67763 .43727 .68354 .43541 .68269 .43437 Metetra
.664 .741 .907 r
.68269 .43437 .68354 .43541 .68945 .43355 .68861 .43251 Metetra
.664 .741 .907 r
.68861 .43251 .68945 .43355 .69538 .43168 .69454 .43064 Metetra
.664 .741 .907 r
.69454 .43064 .69538 .43168 .70133 .42981 .70049 .42876 Metetra
.826 .393 0 r
.70049 .42876 .70133 .42981 .70728 .42793 .70734 .44283 Metetra
.426 .219 .495 r
.70734 .44283 .70728 .42793 .71325 .42605 .71241 .425 Metetra
.664 .741 .907 r
.71241 .425 .71325 .42605 .71923 .42417 .7184 .42312 Metetra
.664 .741 .907 r
.7184 .42312 .71923 .42417 .72522 .42228 .72439 .42123 Metetra
.664 .741 .907 r
.72439 .42123 .72522 .42228 .73123 .42039 .7304 .41933 Metetra
.664 .741 .907 r
.7304 .41933 .73123 .42039 .73725 .41849 .73642 .41743 Metetra
.664 .741 .907 r
.73642 .41743 .73725 .41849 .74328 .41659 .74246 .41553 Metetra
.664 .741 .907 r
.74246 .41553 .74328 .41659 .74932 .41469 .7485 .41363 Metetra
.664 .741 .907 r
.7485 .41363 .74932 .41469 .75538 .41278 .75456 .41172 Metetra
.664 .741 .907 r
.75456 .41172 .75538 .41278 .76145 .41087 .76063 .4098 Metetra
.664 .741 .907 r
.76063 .4098 .76145 .41087 .76753 .40896 .76672 .40788 Metetra
.664 .741 .907 r
.76672 .40788 .76753 .40896 .77363 .40704 .77282 .40596 Metetra
.664 .741 .907 r
.77282 .40596 .77363 .40704 .77973 .40511 .77893 .40404 Metetra
.664 .741 .907 r
.77893 .40404 .77973 .40511 .78585 .40318 .78505 .40211 Metetra
.664 .741 .907 r
.78505 .40211 .78585 .40318 .79199 .40125 .79119 .40017 Metetra
.664 .741 .907 r
.79119 .40017 .79199 .40125 .79814 .39932 .79734 .39823 Metetra
.664 .741 .907 r
.79734 .39823 .79814 .39932 .8043 .39737 .8035 .39629 Metetra
.664 .741 .907 r
.8035 .39629 .8043 .39737 .81047 .39543 .80968 .39434 Metetra
.664 .741 .907 r
.80968 .39434 .81047 .39543 .81666 .39348 .81587 .39239 Metetra
.664 .741 .907 r
.81587 .39239 .81666 .39348 .82286 .39153 .82207 .39044 Metetra
.664 .741 .907 r
.82207 .39044 .82286 .39153 .82907 .38957 .82829 .38848 Metetra
.664 .741 .907 r
.82829 .38848 .82907 .38957 .8353 .38761 .83452 .38651 Metetra
.664 .741 .907 r
.83452 .38651 .8353 .38761 .84154 .38565 .84076 .38455 Metetra
.664 .741 .907 r
.84076 .38455 .84154 .38565 .84779 .38368 .84701 .38257 Metetra
.664 .741 .907 r
.84701 .38257 .84779 .38368 .85406 .3817 .85328 .3806 Metetra
.664 .741 .907 r
.85328 .3806 .85406 .3817 .86034 .37972 .85957 .37862 Metetra
0 .013 .562 r
.85957 .37862 .86034 .37972 .8682 .39246 .86698 .38715 Metetra
.735 .542 .632 r
.86698 .38715 .8682 .39246 .87294 .37575 .87217 .37464 Metetra
.664 .741 .907 r
.87217 .37464 .87294 .37575 .87926 .37376 .8785 .37265 Metetra
.664 .741 .907 r
.8785 .37265 .87926 .37376 .88559 .37177 .88484 .37065 Metetra
.664 .741 .907 r
.88484 .37065 .88559 .37177 .89194 .36977 .89119 .36865 Metetra
.664 .741 .907 r
.89119 .36865 .89194 .36977 .8983 .36776 .89755 .36664 Metetra
.664 .741 .907 r
.89755 .36664 .8983 .36776 .90468 .36576 .90393 .36463 Metetra
.664 .741 .907 r
.90393 .36463 .90468 .36576 .91107 .36374 .91032 .36262 Metetra
.664 .741 .907 r
.91032 .36262 .91107 .36374 .91747 .36173 .91673 .3606 Metetra
.664 .741 .907 r
.91673 .3606 .91747 .36173 .92389 .3597 .92315 .35858 Metetra
.664 .741 .907 r
.34255 .54036 .34354 .54128 .34877 .53963 .34779 .53871 Metetra
.664 .741 .907 r
.34779 .53871 .34877 .53963 .35401 .53798 .35303 .53705 Metetra
.664 .741 .907 r
.35303 .53705 .35401 .53798 .35926 .53632 .35828 .53539 Metetra
.664 .741 .907 r
.35828 .53539 .35926 .53632 .36453 .53466 .36355 .53373 Metetra
.664 .741 .907 r
.36355 .53373 .36453 .53466 .3698 .533 .36882 .53207 Metetra
.664 .741 .907 r
.36882 .53207 .3698 .533 .37508 .53133 .37411 .5304 Metetra
.664 .741 .907 r
.37411 .5304 .37508 .53133 .38038 .52966 .37941 .52873 Metetra
.664 .741 .907 r
.37941 .52873 .38038 .52966 .38568 .52799 .38471 .52706 Metetra
.664 .741 .907 r
.38471 .52706 .38568 .52799 .391 .52632 .39003 .52538 Metetra
.664 .741 .907 r
.39003 .52538 .391 .52632 .39632 .52464 .39536 .5237 Metetra
.664 .741 .907 r
.39536 .5237 .39632 .52464 .40166 .52296 .40069 .52202 Metetra
.664 .741 .907 r
.40069 .52202 .40166 .52296 .407 .52127 .40604 .52033 Metetra
.664 .741 .907 r
.40604 .52033 .407 .52127 .41236 .51958 .4114 .51864 Metetra
.664 .741 .907 r
.4114 .51864 .41236 .51958 .41773 .51789 .41677 .51695 Metetra
.947 .679 .497 r
.41677 .51695 .41773 .51789 .41645 .73453 .41543 .73365 Metetra
.944 .693 .526 r
.41543 .73365 .41645 .73453 .4285 .5145 .42755 .51355 Metetra
.664 .741 .907 r
.42755 .51355 .4285 .5145 .4339 .51279 .43295 .51184 Metetra
.664 .741 .907 r
.43295 .51184 .4339 .51279 .43931 .51109 .43836 .51014 Metetra
.664 .741 .907 r
.43836 .51014 .43931 .51109 .44473 .50938 .44378 .50842 Metetra
.664 .741 .907 r
.44378 .50842 .44473 .50938 .45016 .50767 .44922 .50671 Metetra
.664 .741 .907 r
.44922 .50671 .45016 .50767 .45561 .50595 .45467 .50499 Metetra
.664 .741 .907 r
.45467 .50499 .45561 .50595 .46106 .50423 .46012 .50327 Metetra
.664 .741 .907 r
.46012 .50327 .46106 .50423 .46653 .50251 .46559 .50155 Metetra
.664 .741 .907 r
.46559 .50155 .46653 .50251 .472 .50078 .47107 .49982 Metetra
.664 .741 .907 r
.47107 .49982 .472 .50078 .47749 .49905 .47656 .49809 Metetra
.664 .741 .907 r
.47656 .49809 .47749 .49905 .48299 .49732 .48206 .49635 Metetra
.664 .741 .907 r
.48206 .49635 .48299 .49732 .4885 .49558 .48757 .49461 Metetra
.664 .741 .907 r
.48757 .49461 .4885 .49558 .49402 .49384 .49309 .49287 Metetra
.664 .741 .907 r
.49309 .49287 .49402 .49384 .49955 .4921 .49863 .49112 Metetra
.664 .741 .907 r
.49863 .49112 .49955 .4921 .5051 .49035 .50417 .48938 Metetra
.664 .741 .907 r
.50417 .48938 .5051 .49035 .51065 .4886 .50973 .48762 Metetra
.664 .741 .907 r
.50973 .48762 .51065 .4886 .51622 .48685 .5153 .48587 Metetra
.664 .741 .907 r
.5153 .48587 .51622 .48685 .52179 .48509 .52088 .48411 Metetra
.664 .741 .907 r
.52088 .48411 .52179 .48509 .52738 .48333 .52647 .48234 Metetra
.664 .741 .907 r
.52647 .48234 .52738 .48333 .53298 .48156 .53207 .48058 Metetra
.664 .741 .907 r
.53207 .48058 .53298 .48156 .53859 .47979 .53768 .4788 Metetra
.664 .741 .907 r
.53768 .4788 .53859 .47979 .54422 .47802 .54331 .47703 Metetra
.664 .741 .907 r
.54331 .47703 .54422 .47802 .54985 .47624 .54895 .47525 Metetra
.879 .453 .05 r
.54895 .47525 .54985 .47624 .55557 .48234 .55473 .48836 Metetra
.602 .326 .47 r
.55473 .48836 .55557 .48234 .56181 .53194 .56047 .49205 Metetra
.615 .403 .57 r
.56047 .49205 .56181 .53194 .56682 .47089 .56592 .4699 Metetra
.664 .741 .907 r
.56592 .4699 .56682 .47089 .5725 .4691 .57161 .4681 Metetra
.664 .741 .907 r
.57161 .4681 .5725 .4691 .57819 .46731 .5773 .46631 Metetra
.664 .741 .907 r
.5773 .46631 .57819 .46731 .5839 .46551 .58301 .46451 Metetra
.664 .741 .907 r
.58301 .46451 .5839 .46551 .58961 .46371 .58873 .4627 Metetra
.664 .741 .907 r
.58873 .4627 .58961 .46371 .59534 .46191 .59446 .4609 Metetra
.664 .741 .907 r
.59446 .4609 .59534 .46191 .60108 .4601 .6002 .45909 Metetra
.664 .741 .907 r
.6002 .45909 .60108 .4601 .60683 .45828 .60595 .45727 Metetra
.664 .741 .907 r
.60595 .45727 .60683 .45828 .61259 .45647 .61172 .45545 Metetra
.664 .741 .907 r
.61172 .45545 .61259 .45647 .61837 .45465 .61749 .45363 Metetra
.664 .741 .907 r
.61749 .45363 .61837 .45465 .62416 .45282 .62328 .4518 Metetra
.664 .741 .907 r
.62328 .4518 .62416 .45282 .62995 .45099 .62908 .44997 Metetra
.664 .741 .907 r
.62908 .44997 .62995 .45099 .63577 .44916 .6349 .44814 Metetra
.664 .741 .907 r
.6349 .44814 .63577 .44916 .64159 .44733 .64072 .4463 Metetra
.664 .741 .907 r
.64072 .4463 .64159 .44733 .64742 .44549 .64656 .44446 Metetra
.664 .741 .907 r
.64656 .44446 .64742 .44549 .65327 .44365 .65241 .44262 Metetra
.664 .741 .907 r
.65241 .44262 .65327 .44365 .65913 .4418 .65827 .44077 Metetra
.664 .741 .907 r
.65827 .44077 .65913 .4418 .665 .43995 .66414 .43891 Metetra
.664 .741 .907 r
.66414 .43891 .665 .43995 .67088 .43809 .67003 .43706 Metetra
.664 .741 .907 r
.67003 .43706 .67088 .43809 .67678 .43623 .67593 .4352 Metetra
.664 .741 .907 r
.67593 .4352 .67678 .43623 .68269 .43437 .68184 .43333 Metetra
.664 .741 .907 r
.68184 .43333 .68269 .43437 .68861 .43251 .68776 .43146 Metetra
.664 .741 .907 r
.68776 .43146 .68861 .43251 .69454 .43064 .6937 .42959 Metetra
.954 .607 .266 r
.6937 .42959 .69454 .43064 .70049 .42876 .7018 .46771 Metetra
.443 .251 .523 r
.7018 .46771 .70049 .42876 .70734 .44283 .70561 .42583 Metetra
.578 .387 .587 r
.70561 .42583 .70734 .44283 .71241 .425 .71158 .42395 Metetra
.664 .741 .907 r
.71158 .42395 .71241 .425 .7184 .42312 .71756 .42206 Metetra
.664 .741 .907 r
.71756 .42206 .7184 .42312 .72439 .42123 .72356 .42017 Metetra
.664 .741 .907 r
.72356 .42017 .72439 .42123 .7304 .41933 .72957 .41827 Metetra
.664 .741 .907 r
.72957 .41827 .7304 .41933 .73642 .41743 .7356 .41637 Metetra
.664 .741 .907 r
.7356 .41637 .73642 .41743 .74246 .41553 .74163 .41447 Metetra
.664 .741 .907 r
.74163 .41447 .74246 .41553 .7485 .41363 .74768 .41256 Metetra
.664 .741 .907 r
.74768 .41256 .7485 .41363 .75456 .41172 .75374 .41065 Metetra
.664 .741 .907 r
.75374 .41065 .75456 .41172 .76063 .4098 .75982 .40873 Metetra
.664 .741 .907 r
.75982 .40873 .76063 .4098 .76672 .40788 .76591 .40681 Metetra
.664 .741 .907 r
.76591 .40681 .76672 .40788 .77282 .40596 .77201 .40489 Metetra
.664 .741 .907 r
.77201 .40489 .77282 .40596 .77893 .40404 .77812 .40296 Metetra
.664 .741 .907 r
.77812 .40296 .77893 .40404 .78505 .40211 .78425 .40103 Metetra
.664 .741 .907 r
.78425 .40103 .78505 .40211 .79119 .40017 .79039 .39909 Metetra
.664 .741 .907 r
.79039 .39909 .79119 .40017 .79734 .39823 .79654 .39715 Metetra
.664 .741 .907 r
.79654 .39715 .79734 .39823 .8035 .39629 .80271 .39521 Metetra
.664 .741 .907 r
.80271 .39521 .8035 .39629 .80968 .39434 .80888 .39326 Metetra
.664 .741 .907 r
.80888 .39326 .80968 .39434 .81587 .39239 .81508 .3913 Metetra
.664 .741 .907 r
.81508 .3913 .81587 .39239 .82207 .39044 .82128 .38935 Metetra
.664 .741 .907 r
.82128 .38935 .82207 .39044 .82829 .38848 .8275 .38738 Metetra
.664 .741 .907 r
.8275 .38738 .82829 .38848 .83452 .38651 .83373 .38542 Metetra
.664 .741 .907 r
.83373 .38542 .83452 .38651 .84076 .38455 .83998 .38345 Metetra
.664 .741 .907 r
.83998 .38345 .84076 .38455 .84701 .38257 .84624 .38147 Metetra
.664 .741 .907 r
.84624 .38147 .84701 .38257 .85328 .3806 .85251 .37949 Metetra
.664 .741 .907 r
.85251 .37949 .85328 .3806 .85957 .37862 .8588 .37751 Metetra
.664 .741 .907 r
.8588 .37751 .85957 .37862 .86698 .38715 .8651 .37552 Metetra
.584 .403 .602 r
.8651 .37552 .86698 .38715 .87217 .37464 .87141 .37353 Metetra
.664 .741 .907 r
.87141 .37353 .87217 .37464 .8785 .37265 .87774 .37154 Metetra
.664 .741 .907 r
.87774 .37154 .8785 .37265 .88484 .37065 .88408 .36954 Metetra
.664 .741 .907 r
.88408 .36954 .88484 .37065 .89119 .36865 .89043 .36753 Metetra
.664 .741 .907 r
.89043 .36753 .89119 .36865 .89755 .36664 .8968 .36552 Metetra
.664 .741 .907 r
.8968 .36552 .89755 .36664 .90393 .36463 .90318 .36351 Metetra
.664 .741 .907 r
.90318 .36351 .90393 .36463 .91032 .36262 .90958 .36149 Metetra
.664 .741 .907 r
.90958 .36149 .91032 .36262 .91673 .3606 .91599 .35947 Metetra
.664 .741 .907 r
.91599 .35947 .91673 .3606 .92315 .35858 .92241 .35744 Metetra
.664 .741 .907 r
.34157 .53944 .34255 .54036 .34779 .53871 .3468 .53778 Metetra
.664 .741 .907 r
.3468 .53778 .34779 .53871 .35303 .53705 .35205 .53613 Metetra
.664 .741 .907 r
.35205 .53613 .35303 .53705 .35828 .53539 .3573 .53447 Metetra
.664 .741 .907 r
.3573 .53447 .35828 .53539 .36355 .53373 .36257 .53281 Metetra
.664 .741 .907 r
.36257 .53281 .36355 .53373 .36882 .53207 .36785 .53114 Metetra
.664 .741 .907 r
.36785 .53114 .36882 .53207 .37411 .5304 .37314 .52947 Metetra
.664 .741 .907 r
.37314 .52947 .37411 .5304 .37941 .52873 .37843 .5278 Metetra
.664 .741 .907 r
.37843 .5278 .37941 .52873 .38471 .52706 .38374 .52612 Metetra
.664 .741 .907 r
.38374 .52612 .38471 .52706 .39003 .52538 .38906 .52444 Metetra
.664 .741 .907 r
.38906 .52444 .39003 .52538 .39536 .5237 .39439 .52276 Metetra
.664 .741 .907 r
.39439 .52276 .39536 .5237 .40069 .52202 .39973 .52108 Metetra
.664 .741 .907 r
.39973 .52108 .40069 .52202 .40604 .52033 .40508 .51939 Metetra
.664 .741 .907 r
.40508 .51939 .40604 .52033 .4114 .51864 .41044 .51769 Metetra
.664 .741 .907 r
.41044 .51769 .4114 .51864 .41677 .51695 .41581 .516 Metetra
.947 .678 .493 r
.41581 .516 .41677 .51695 .41543 .73365 .4158 .68801 Metetra
.78 .539 .571 r
.4158 .68801 .41543 .73365 .42755 .51355 .42659 .5126 Metetra
.664 .741 .907 r
.42659 .5126 .42755 .51355 .43295 .51184 .432 .51089 Metetra
.664 .741 .907 r
.432 .51089 .43295 .51184 .43836 .51014 .43741 .50918 Metetra
.664 .741 .907 r
.43741 .50918 .43836 .51014 .44378 .50842 .44284 .50747 Metetra
.664 .741 .907 r
.44284 .50747 .44378 .50842 .44922 .50671 .44827 .50575 Metetra
.664 .741 .907 r
.44827 .50575 .44922 .50671 .45467 .50499 .45372 .50403 Metetra
.664 .741 .907 r
.45372 .50403 .45467 .50499 .46012 .50327 .45918 .50231 Metetra
.664 .741 .907 r
.45918 .50231 .46012 .50327 .46559 .50155 .46465 .50058 Metetra
.664 .741 .907 r
.46465 .50058 .46559 .50155 .47107 .49982 .47013 .49885 Metetra
.664 .741 .907 r
.47013 .49885 .47107 .49982 .47656 .49809 .47562 .49712 Metetra
.664 .741 .907 r
.47562 .49712 .47656 .49809 .48206 .49635 .48113 .49538 Metetra
.664 .741 .907 r
.48113 .49538 .48206 .49635 .48757 .49461 .48664 .49364 Metetra
.664 .741 .907 r
.48664 .49364 .48757 .49461 .49309 .49287 .49217 .4919 Metetra
.664 .741 .907 r
.49217 .4919 .49309 .49287 .49863 .49112 .4977 .49015 Metetra
.664 .741 .907 r
.4977 .49015 .49863 .49112 .50417 .48938 .50325 .4884 Metetra
.664 .741 .907 r
.50325 .4884 .50417 .48938 .50973 .48762 .50881 .48664 Metetra
.664 .741 .907 r
.50881 .48664 .50973 .48762 .5153 .48587 .51438 .48488 Metetra
.664 .741 .907 r
.51438 .48488 .5153 .48587 .52088 .48411 .51996 .48312 Metetra
.664 .741 .907 r
.51996 .48312 .52088 .48411 .52647 .48234 .52555 .48136 Metetra
.664 .741 .907 r
.52555 .48136 .52647 .48234 .53207 .48058 .53116 .47959 Metetra
.664 .741 .907 r
.53116 .47959 .53207 .48058 .53768 .4788 .53677 .47782 Metetra
.664 .741 .907 r
.53677 .47782 .53768 .4788 .54331 .47703 .5424 .47604 Metetra
.664 .741 .907 r
.5424 .47604 .54331 .47703 .54895 .47525 .54804 .47426 Metetra
.901 .49 .107 r
.54804 .47426 .54895 .47525 .55473 .48836 .55383 .48901 Metetra
.979 .917 .638 r
.55383 .48901 .55473 .48836 .56047 .49205 .5594 .47569 Metetra
.605 .408 .588 r
.5594 .47569 .56047 .49205 .56592 .4699 .56503 .4689 Metetra
.664 .741 .907 r
.56503 .4689 .56592 .4699 .57161 .4681 .57071 .4671 Metetra
.664 .741 .907 r
.57071 .4671 .57161 .4681 .5773 .46631 .57641 .4653 Metetra
.664 .741 .907 r
.57641 .4653 .5773 .46631 .58301 .46451 .58212 .4635 Metetra
.664 .741 .907 r
.58212 .4635 .58301 .46451 .58873 .4627 .58784 .4617 Metetra
.664 .741 .907 r
.58784 .4617 .58873 .4627 .59446 .4609 .59357 .45989 Metetra
.664 .741 .907 r
.59357 .45989 .59446 .4609 .6002 .45909 .59931 .45807 Metetra
.664 .741 .907 r
.59931 .45807 .6002 .45909 .60595 .45727 .60507 .45626 Metetra
.664 .741 .907 r
.60507 .45626 .60595 .45727 .61172 .45545 .61083 .45444 Metetra
.664 .741 .907 r
.61083 .45444 .61172 .45545 .61749 .45363 .61661 .45261 Metetra
.664 .741 .907 r
.61661 .45261 .61749 .45363 .62328 .4518 .62241 .45078 Metetra
.664 .741 .907 r
.62241 .45078 .62328 .4518 .62908 .44997 .62821 .44895 Metetra
.664 .741 .907 r
.62821 .44895 .62908 .44997 .6349 .44814 .63403 .44712 Metetra
.664 .741 .907 r
.63403 .44712 .6349 .44814 .64072 .4463 .63985 .44528 Metetra
.664 .741 .907 r
.63985 .44528 .64072 .4463 .64656 .44446 .64569 .44343 Metetra
.664 .741 .907 r
.64569 .44343 .64656 .44446 .65241 .44262 .65154 .44159 Metetra
.664 .741 .907 r
.65154 .44159 .65241 .44262 .65827 .44077 .65741 .43973 Metetra
.664 .741 .907 r
.65741 .43973 .65827 .44077 .66414 .43891 .66329 .43788 Metetra
.664 .741 .907 r
.66329 .43788 .66414 .43891 .67003 .43706 .66917 .43602 Metetra
.664 .741 .907 r
.66917 .43602 .67003 .43706 .67593 .4352 .67507 .43416 Metetra
.664 .741 .907 r
.67507 .43416 .67593 .4352 .68184 .43333 .68099 .43229 Metetra
.664 .741 .907 r
.68099 .43229 .68184 .43333 .68776 .43146 .68691 .43042 Metetra
.664 .741 .907 r
.68691 .43042 .68776 .43146 .6937 .42959 .69285 .42855 Metetra
.837 .406 0 r
.69285 .42855 .6937 .42959 .7018 .46771 .69967 .44296 Metetra
.629 .417 .576 r
.69967 .44296 .7018 .46771 .70561 .42583 .70477 .42478 Metetra
.664 .741 .907 r
.70477 .42478 .70561 .42583 .71158 .42395 .71074 .4229 Metetra
.664 .741 .907 r
.71074 .4229 .71158 .42395 .71756 .42206 .71673 .42101 Metetra
.664 .741 .907 r
.71673 .42101 .71756 .42206 .72356 .42017 .72273 .41911 Metetra
.664 .741 .907 r
.72273 .41911 .72356 .42017 .72957 .41827 .72874 .41722 Metetra
.664 .741 .907 r
.72874 .41722 .72957 .41827 .7356 .41637 .73477 .41531 Metetra
.664 .741 .907 r
.73477 .41531 .7356 .41637 .74163 .41447 .74081 .41341 Metetra
.664 .741 .907 r
.74081 .41341 .74163 .41447 .74768 .41256 .74686 .4115 Metetra
.664 .741 .907 r
.74686 .4115 .74768 .41256 .75374 .41065 .75293 .40958 Metetra
.664 .741 .907 r
.75293 .40958 .75374 .41065 .75982 .40873 .759 .40766 Metetra
.664 .741 .907 r
.759 .40766 .75982 .40873 .76591 .40681 .76509 .40574 Metetra
.664 .741 .907 r
.76509 .40574 .76591 .40681 .77201 .40489 .7712 .40381 Metetra
.664 .741 .907 r
.7712 .40381 .77201 .40489 .77812 .40296 .77731 .40188 Metetra
.664 .741 .907 r
.77731 .40188 .77812 .40296 .78425 .40103 .78344 .39995 Metetra
.664 .741 .907 r
.78344 .39995 .78425 .40103 .79039 .39909 .78959 .39801 Metetra
.664 .741 .907 r
.78959 .39801 .79039 .39909 .79654 .39715 .79574 .39607 Metetra
.664 .741 .907 r
.79574 .39607 .79654 .39715 .80271 .39521 .80191 .39412 Metetra
.664 .741 .907 r
.80191 .39412 .80271 .39521 .80888 .39326 .80809 .39217 Metetra
.664 .741 .907 r
.80809 .39217 .80888 .39326 .81508 .3913 .81429 .39021 Metetra
.664 .741 .907 r
.81429 .39021 .81508 .3913 .82128 .38935 .82049 .38825 Metetra
.664 .741 .907 r
.82049 .38825 .82128 .38935 .8275 .38738 .82672 .38629 Metetra
.664 .741 .907 r
.82672 .38629 .8275 .38738 .83373 .38542 .83295 .38432 Metetra
.664 .741 .907 r
.83295 .38432 .83373 .38542 .83998 .38345 .8392 .38235 Metetra
.664 .741 .907 r
.8392 .38235 .83998 .38345 .84624 .38147 .84546 .38037 Metetra
.664 .741 .907 r
.84546 .38037 .84624 .38147 .85251 .37949 .85174 .37839 Metetra
.664 .741 .907 r
.85174 .37839 .85251 .37949 .8588 .37751 .85803 .3764 Metetra
.664 .741 .907 r
.85803 .3764 .8588 .37751 .8651 .37552 .86433 .37441 Metetra
.664 .741 .907 r
.86433 .37441 .8651 .37552 .87141 .37353 .87065 .37242 Metetra
.664 .741 .907 r
.87065 .37242 .87141 .37353 .87774 .37154 .87698 .37042 Metetra
.664 .741 .907 r
.87698 .37042 .87774 .37154 .88408 .36954 .88332 .36842 Metetra
.664 .741 .907 r
.88332 .36842 .88408 .36954 .89043 .36753 .88968 .36641 Metetra
.664 .741 .907 r
.88968 .36641 .89043 .36753 .8968 .36552 .89605 .3644 Metetra
.664 .741 .907 r
.89605 .3644 .8968 .36552 .90318 .36351 .90243 .36239 Metetra
.664 .741 .907 r
.90243 .36239 .90318 .36351 .90958 .36149 .90883 .36037 Metetra
.664 .741 .907 r
.90883 .36037 .90958 .36149 .91599 .35947 .91525 .35834 Metetra
.664 .741 .907 r
.91525 .35834 .91599 .35947 .92241 .35744 .92167 .35631 Metetra
.664 .741 .907 r
.34058 .53852 .34157 .53944 .3468 .53778 .34582 .53686 Metetra
.941 .601 .352 r
.34582 .53686 .3468 .53778 .35205 .53613 .34993 .55715 Metetra
.407 .203 .488 r
.34993 .55715 .35205 .53613 .3573 .53447 .35632 .53354 Metetra
.664 .741 .907 r
.35632 .53354 .3573 .53447 .36257 .53281 .36159 .53188 Metetra
.664 .741 .907 r
.36159 .53188 .36257 .53281 .36785 .53114 .36687 .53021 Metetra
.664 .741 .907 r
.36687 .53021 .36785 .53114 .37314 .52947 .37216 .52854 Metetra
.664 .741 .907 r
.37216 .52854 .37314 .52947 .37843 .5278 .37746 .52686 Metetra
.664 .741 .907 r
.37746 .52686 .37843 .5278 .38374 .52612 .38277 .52519 Metetra
.664 .741 .907 r
.38277 .52519 .38374 .52612 .38906 .52444 .38809 .52351 Metetra
.664 .741 .907 r
.38809 .52351 .38906 .52444 .39439 .52276 .39342 .52182 Metetra
.664 .741 .907 r
.39342 .52182 .39439 .52276 .39973 .52108 .39877 .52013 Metetra
.664 .741 .907 r
.39877 .52013 .39973 .52108 .40508 .51939 .40412 .51844 Metetra
.664 .741 .907 r
.40412 .51844 .40508 .51939 .41044 .51769 .40948 .51675 Metetra
.389 .633 .952 r
.40948 .51675 .41044 .51769 .41581 .516 .41477 .51757 Metetra
.926 .65 .498 r
.41477 .51757 .41581 .516 .4158 .68801 .41691 .61963 Metetra
.689 .461 .571 r
.41691 .61963 .4158 .68801 .42659 .5126 .42564 .51165 Metetra
.664 .741 .907 r
.42564 .51165 .42659 .5126 .432 .51089 .43104 .50994 Metetra
.664 .741 .907 r
.43104 .50994 .432 .51089 .43741 .50918 .43646 .50823 Metetra
.664 .741 .907 r
.43646 .50823 .43741 .50918 .44284 .50747 .44189 .50651 Metetra
.664 .741 .907 r
.44189 .50651 .44284 .50747 .44827 .50575 .44733 .50479 Metetra
.664 .741 .907 r
.44733 .50479 .44827 .50575 .45372 .50403 .45278 .50307 Metetra
.664 .741 .907 r
.45278 .50307 .45372 .50403 .45918 .50231 .45824 .50135 Metetra
.664 .741 .907 r
.45824 .50135 .45918 .50231 .46465 .50058 .46371 .49962 Metetra
.664 .741 .907 r
.46371 .49962 .46465 .50058 .47013 .49885 .46919 .49789 Metetra
.664 .741 .907 r
.46919 .49789 .47013 .49885 .47562 .49712 .47469 .49615 Metetra
.664 .741 .907 r
.47469 .49615 .47562 .49712 .48113 .49538 .48019 .49441 Metetra
.664 .741 .907 r
.48019 .49441 .48113 .49538 .48664 .49364 .48571 .49267 Metetra
.664 .741 .907 r
.48571 .49267 .48664 .49364 .49217 .4919 .49124 .49092 Metetra
.664 .741 .907 r
.49124 .49092 .49217 .4919 .4977 .49015 .49677 .48917 Metetra
.664 .741 .907 r
.49677 .48917 .4977 .49015 .50325 .4884 .50232 .48742 Metetra
.664 .741 .907 r
.50232 .48742 .50325 .4884 .50881 .48664 .50789 .48566 Metetra
.664 .741 .907 r
.50789 .48566 .50881 .48664 .51438 .48488 .51346 .4839 Metetra
.664 .741 .907 r
.51346 .4839 .51438 .48488 .51996 .48312 .51904 .48214 Metetra
.664 .741 .907 r
.51904 .48214 .51996 .48312 .52555 .48136 .52464 .48037 Metetra
.664 .741 .907 r
.52464 .48037 .52555 .48136 .53116 .47959 .53024 .4786 Metetra
.664 .741 .907 r
.53024 .4786 .53116 .47959 .53677 .47782 .53586 .47682 Metetra
.664 .741 .907 r
.53586 .47682 .53677 .47782 .5424 .47604 .54149 .47505 Metetra
.664 .741 .907 r
.54149 .47505 .5424 .47604 .54804 .47426 .54713 .47326 Metetra
.664 .741 .907 r
.54713 .47326 .54804 .47426 .55383 .48901 .55278 .47148 Metetra
.577 .385 .585 r
.55278 .47148 .55383 .48901 .5594 .47569 .55845 .46969 Metetra
.6 .445 .643 r
.55845 .46969 .5594 .47569 .56503 .4689 .56412 .4679 Metetra
.664 .741 .907 r
.56412 .4679 .56503 .4689 .57071 .4671 .56981 .4661 Metetra
.664 .741 .907 r
.56981 .4661 .57071 .4671 .57641 .4653 .57551 .4643 Metetra
.664 .741 .907 r
.57551 .4643 .57641 .4653 .58212 .4635 .58122 .4625 Metetra
.664 .741 .907 r
.58122 .4625 .58212 .4635 .58784 .4617 .58694 .46069 Metetra
.664 .741 .907 r
.58694 .46069 .58784 .4617 .59357 .45989 .59268 .45888 Metetra
.664 .741 .907 r
.59268 .45888 .59357 .45989 .59931 .45807 .59843 .45706 Metetra
.664 .741 .907 r
.59843 .45706 .59931 .45807 .60507 .45626 .60418 .45524 Metetra
.664 .741 .907 r
.60418 .45524 .60507 .45626 .61083 .45444 .60995 .45342 Metetra
.664 .741 .907 r
.60995 .45342 .61083 .45444 .61661 .45261 .61574 .45159 Metetra
.664 .741 .907 r
.61574 .45159 .61661 .45261 .62241 .45078 .62153 .44976 Metetra
.664 .741 .907 r
.62153 .44976 .62241 .45078 .62821 .44895 .62734 .44793 Metetra
.664 .741 .907 r
.62734 .44793 .62821 .44895 .63403 .44712 .63315 .44609 Metetra
.664 .741 .907 r
.63315 .44609 .63403 .44712 .63985 .44528 .63898 .44425 Metetra
.664 .741 .907 r
.63898 .44425 .63985 .44528 .64569 .44343 .64483 .4424 Metetra
.664 .741 .907 r
.64483 .4424 .64569 .44343 .65154 .44159 .65068 .44055 Metetra
.664 .741 .907 r
.65068 .44055 .65154 .44159 .65741 .43973 .65655 .4387 Metetra
.664 .741 .907 r
.65655 .4387 .65741 .43973 .66329 .43788 .66243 .43684 Metetra
.664 .741 .907 r
.66243 .43684 .66329 .43788 .66917 .43602 .66832 .43498 Metetra
.664 .741 .907 r
.66832 .43498 .66917 .43602 .67507 .43416 .67422 .43312 Metetra
.664 .741 .907 r
.67422 .43312 .67507 .43416 .68099 .43229 .68014 .43125 Metetra
.664 .741 .907 r
.68014 .43125 .68099 .43229 .68691 .43042 .68606 .42937 Metetra
.664 .741 .907 r
.68606 .42937 .68691 .43042 .69285 .42855 .69201 .4275 Metetra
.664 .741 .907 r
.69201 .4275 .69285 .42855 .69967 .44296 .69796 .42562 Metetra
.577 .386 .586 r
.69796 .42562 .69967 .44296 .70477 .42478 .70392 .42373 Metetra
.664 .741 .907 r
.70392 .42373 .70477 .42478 .71074 .4229 .7099 .42184 Metetra
.664 .741 .907 r
.7099 .42184 .71074 .4229 .71673 .42101 .71589 .41995 Metetra
.664 .741 .907 r
.71589 .41995 .71673 .42101 .72273 .41911 .7219 .41806 Metetra
.664 .741 .907 r
.7219 .41806 .72273 .41911 .72874 .41722 .72791 .41615 Metetra
.664 .741 .907 r
.72791 .41615 .72874 .41722 .73477 .41531 .73394 .41425 Metetra
.664 .741 .907 r
.73394 .41425 .73477 .41531 .74081 .41341 .73998 .41234 Metetra
.664 .741 .907 r
.73998 .41234 .74081 .41341 .74686 .4115 .74604 .41043 Metetra
.664 .741 .907 r
.74604 .41043 .74686 .4115 .75293 .40958 .75211 .40851 Metetra
.664 .741 .907 r
.75211 .40851 .75293 .40958 .759 .40766 .75819 .40659 Metetra
.664 .741 .907 r
.75819 .40659 .759 .40766 .76509 .40574 .76428 .40467 Metetra
.664 .741 .907 r
.76428 .40467 .76509 .40574 .7712 .40381 .77039 .40274 Metetra
.664 .741 .907 r
.77039 .40274 .7712 .40381 .77731 .40188 .7765 .4008 Metetra
.664 .741 .907 r
.7765 .4008 .77731 .40188 .78344 .39995 .78264 .39887 Metetra
.664 .741 .907 r
.78264 .39887 .78344 .39995 .78959 .39801 .78878 .39693 Metetra
.664 .741 .907 r
.78878 .39693 .78959 .39801 .79574 .39607 .79494 .39498 Metetra
.664 .741 .907 r
.79494 .39498 .79574 .39607 .80191 .39412 .80111 .39303 Metetra
.664 .741 .907 r
.80111 .39303 .80191 .39412 .80809 .39217 .8073 .39108 Metetra
.664 .741 .907 r
.8073 .39108 .80809 .39217 .81429 .39021 .81349 .38912 Metetra
.664 .741 .907 r
.81349 .38912 .81429 .39021 .82049 .38825 .81971 .38716 Metetra
.664 .741 .907 r
.81971 .38716 .82049 .38825 .82672 .38629 .82593 .38519 Metetra
.664 .741 .907 r
.82593 .38519 .82672 .38629 .83295 .38432 .83217 .38322 Metetra
.664 .741 .907 r
.83217 .38322 .83295 .38432 .8392 .38235 .83842 .38124 Metetra
.664 .741 .907 r
.83842 .38124 .8392 .38235 .84546 .38037 .84469 .37927 Metetra
.664 .741 .907 r
.84469 .37927 .84546 .38037 .85174 .37839 .85096 .37728 Metetra
.664 .741 .907 r
.85096 .37728 .85174 .37839 .85803 .3764 .85726 .37529 Metetra
.664 .741 .907 r
.85726 .37529 .85803 .3764 .86433 .37441 .86356 .3733 Metetra
.664 .741 .907 r
.86356 .3733 .86433 .37441 .87065 .37242 .86988 .37131 Metetra
.664 .741 .907 r
.86988 .37131 .87065 .37242 .87698 .37042 .87621 .36931 Metetra
.664 .741 .907 r
.87621 .36931 .87698 .37042 .88332 .36842 .88256 .3673 Metetra
.664 .741 .907 r
.88256 .3673 .88332 .36842 .88968 .36641 .88892 .36529 Metetra
.664 .741 .907 r
.88892 .36529 .88968 .36641 .89605 .3644 .8953 .36328 Metetra
.664 .741 .907 r
.8953 .36328 .89605 .3644 .90243 .36239 .90168 .36126 Metetra
.664 .741 .907 r
.90168 .36126 .90243 .36239 .90883 .36037 .90809 .35924 Metetra
.664 .741 .907 r
.90809 .35924 .90883 .36037 .91525 .35834 .9145 .35721 Metetra
.664 .741 .907 r
.9145 .35721 .91525 .35834 .92167 .35631 .92093 .35518 Metetra
.664 .741 .907 r
.33959 .53759 .34058 .53852 .34582 .53686 .34483 .53594 Metetra
.909 .503 .179 r
.34483 .53594 .34582 .53686 .34993 .55715 .34938 .54767 Metetra
.691 .49 .611 r
.34938 .54767 .34993 .55715 .35632 .53354 .35534 .53261 Metetra
.664 .741 .907 r
.35534 .53261 .35632 .53354 .36159 .53188 .36061 .53095 Metetra
.664 .741 .907 r
.36061 .53095 .36159 .53188 .36687 .53021 .36589 .52928 Metetra
.664 .741 .907 r
.36589 .52928 .36687 .53021 .37216 .52854 .37118 .52761 Metetra
.664 .741 .907 r
.37118 .52761 .37216 .52854 .37746 .52686 .37649 .52593 Metetra
.664 .741 .907 r
.37649 .52593 .37746 .52686 .38277 .52519 .3818 .52425 Metetra
.664 .741 .907 r
.3818 .52425 .38277 .52519 .38809 .52351 .38712 .52257 Metetra
.664 .741 .907 r
.38712 .52257 .38809 .52351 .39342 .52182 .39246 .52088 Metetra
.664 .741 .907 r
.39246 .52088 .39342 .52182 .39877 .52013 .3978 .51919 Metetra
.664 .741 .907 r
.3978 .51919 .39877 .52013 .40412 .51844 .40315 .5175 Metetra
.664 .741 .907 r
.40315 .5175 .40412 .51844 .40948 .51675 .40852 .5158 Metetra
.664 .741 .907 r
.40852 .5158 .40948 .51675 .41477 .51757 .4139 .5141 Metetra
0 0 .4 r
.4139 .5141 .41477 .51757 .41691 .61963 .41877 .52862 Metetra
.584 .373 .561 r
.41877 .52862 .41691 .61963 .42564 .51165 .42468 .51069 Metetra
.951 .643 .413 r
.42468 .51069 .42564 .51165 .43104 .50994 .42894 .54941 Metetra
.424 .229 .51 r
.42894 .54941 .43104 .50994 .43646 .50823 .43551 .50727 Metetra
.664 .741 .907 r
.43551 .50727 .43646 .50823 .44189 .50651 .44094 .50555 Metetra
.664 .741 .907 r
.44094 .50555 .44189 .50651 .44733 .50479 .44638 .50383 Metetra
.664 .741 .907 r
.44638 .50383 .44733 .50479 .45278 .50307 .45183 .50211 Metetra
.664 .741 .907 r
.45183 .50211 .45278 .50307 .45824 .50135 .45729 .50038 Metetra
.664 .741 .907 r
.45729 .50038 .45824 .50135 .46371 .49962 .46277 .49865 Metetra
.664 .741 .907 r
.46277 .49865 .46371 .49962 .46919 .49789 .46825 .49692 Metetra
.664 .741 .907 r
.46825 .49692 .46919 .49789 .47469 .49615 .47375 .49518 Metetra
.664 .741 .907 r
.47375 .49518 .47469 .49615 .48019 .49441 .47926 .49344 Metetra
.664 .741 .907 r
.47926 .49344 .48019 .49441 .48571 .49267 .48478 .4917 Metetra
.664 .741 .907 r
.48478 .4917 .48571 .49267 .49124 .49092 .49031 .48995 Metetra
.664 .741 .907 r
.49031 .48995 .49124 .49092 .49677 .48917 .49585 .4882 Metetra
.512 .685 .945 r
.49585 .4882 .49677 .48917 .50232 .48742 .50139 .48815 Metetra
.50139 .48815 .50232 .48742 .50789 .48566 .50696 .48468 Metetra
.664 .741 .907 r
.50696 .48468 .50789 .48566 .51346 .4839 .51254 .48292 Metetra
.664 .741 .907 r
.51254 .48292 .51346 .4839 .51904 .48214 .51812 .48115 Metetra
.664 .741 .907 r
.51812 .48115 .51904 .48214 .52464 .48037 .52372 .47938 Metetra
.664 .741 .907 r
.52372 .47938 .52464 .48037 .53024 .4786 .52933 .47761 Metetra
.664 .741 .907 r
.52933 .47761 .53024 .4786 .53586 .47682 .53495 .47583 Metetra
.664 .741 .907 r
.53495 .47583 .53586 .47682 .54149 .47505 .54058 .47405 Metetra
.664 .741 .907 r
.54058 .47405 .54149 .47505 .54713 .47326 .54622 .47227 Metetra
.664 .741 .907 r
.54622 .47227 .54713 .47326 .55278 .47148 .55188 .47048 Metetra
.664 .741 .907 r
.55188 .47048 .55278 .47148 .55845 .46969 .55755 .46869 Metetra
.664 .741 .907 r
.55755 .46869 .55845 .46969 .56412 .4679 .56322 .46689 Metetra
.664 .741 .907 r
.56322 .46689 .56412 .4679 .56981 .4661 .56891 .4651 Metetra
.953 .608 .302 r
.56891 .4651 .56981 .4661 .57551 .4643 .57509 .49499 Metetra
.431 .235 .512 r
.57509 .49499 .57551 .4643 .58122 .4625 .58033 .46149 Metetra
.664 .741 .907 r
.58033 .46149 .58122 .4625 .58694 .46069 .58605 .45968 Metetra
.664 .741 .907 r
.58605 .45968 .58694 .46069 .59268 .45888 .59179 .45786 Metetra
.664 .741 .907 r
.59179 .45786 .59268 .45888 .59843 .45706 .59754 .45605 Metetra
.664 .741 .907 r
.59754 .45605 .59843 .45706 .60418 .45524 .6033 .45423 Metetra
.664 .741 .907 r
.6033 .45423 .60418 .45524 .60995 .45342 .60907 .4524 Metetra
.664 .741 .907 r
.60907 .4524 .60995 .45342 .61574 .45159 .61486 .45057 Metetra
.664 .741 .907 r
.61486 .45057 .61574 .45159 .62153 .44976 .62065 .44874 Metetra
.664 .741 .907 r
.62065 .44874 .62153 .44976 .62734 .44793 .62646 .4469 Metetra
.664 .741 .907 r
.62646 .4469 .62734 .44793 .63315 .44609 .63228 .44506 Metetra
.664 .741 .907 r
.63228 .44506 .63315 .44609 .63898 .44425 .63811 .44322 Metetra
.664 .741 .907 r
.63811 .44322 .63898 .44425 .64483 .4424 .64396 .44137 Metetra
.664 .741 .907 r
.64396 .44137 .64483 .4424 .65068 .44055 .64982 .43952 Metetra
.664 .741 .907 r
.64982 .43952 .65068 .44055 .65655 .4387 .65568 .43766 Metetra
.664 .741 .907 r
.65568 .43766 .65655 .4387 .66243 .43684 .66157 .43581 Metetra
.664 .741 .907 r
.66157 .43581 .66243 .43684 .66832 .43498 .66746 .43394 Metetra
.664 .741 .907 r
.66746 .43394 .66832 .43498 .67422 .43312 .67337 .43207 Metetra
.664 .741 .907 r
.67337 .43207 .67422 .43312 .68014 .43125 .67928 .4302 Metetra
.664 .741 .907 r
.67928 .4302 .68014 .43125 .68606 .42937 .68522 .42833 Metetra
.664 .741 .907 r
.68522 .42833 .68606 .42937 .69201 .4275 .69116 .42645 Metetra
.664 .741 .907 r
.69116 .42645 .69201 .4275 .69796 .42562 .69711 .42457 Metetra
.664 .741 .907 r
.69711 .42457 .69796 .42562 .70392 .42373 .70308 .42268 Metetra
.664 .741 .907 r
.70308 .42268 .70392 .42373 .7099 .42184 .70906 .42079 Metetra
.664 .741 .907 r
.70906 .42079 .7099 .42184 .71589 .41995 .71506 .41889 Metetra
.664 .741 .907 r
.71506 .41889 .71589 .41995 .7219 .41806 .72106 .417 Metetra
.664 .741 .907 r
.72106 .417 .7219 .41806 .72791 .41615 .72708 .41509 Metetra
.945 .586 .219 r
.72708 .41509 .72791 .41615 .73394 .41425 .73544 .44929 Metetra
.443 .25 .522 r
.73544 .44929 .73394 .41425 .73998 .41234 .73916 .41128 Metetra
.664 .741 .907 r
.73916 .41128 .73998 .41234 .74604 .41043 .74522 .40936 Metetra
.664 .741 .907 r
.74522 .40936 .74604 .41043 .75211 .40851 .75129 .40744 Metetra
.664 .741 .907 r
.75129 .40744 .75211 .40851 .75819 .40659 .75737 .40552 Metetra
.664 .741 .907 r
.75737 .40552 .75819 .40659 .76428 .40467 .76346 .40359 Metetra
.664 .741 .907 r
.76346 .40359 .76428 .40467 .77039 .40274 .76957 .40166 Metetra
.664 .741 .907 r
.76957 .40166 .77039 .40274 .7765 .4008 .77569 .39972 Metetra
.664 .741 .907 r
.77569 .39972 .7765 .4008 .78264 .39887 .78183 .39779 Metetra
.664 .741 .907 r
.78183 .39779 .78264 .39887 .78878 .39693 .78798 .39584 Metetra
.664 .741 .907 r
.78798 .39584 .78878 .39693 .79494 .39498 .79414 .39389 Metetra
.664 .741 .907 r
.79414 .39389 .79494 .39498 .80111 .39303 .80031 .39194 Metetra
.664 .741 .907 r
.80031 .39194 .80111 .39303 .8073 .39108 .8065 .38999 Metetra
.664 .741 .907 r
.8065 .38999 .8073 .39108 .81349 .38912 .8127 .38803 Metetra
.664 .741 .907 r
.8127 .38803 .81349 .38912 .81971 .38716 .81892 .38606 Metetra
.664 .741 .907 r
.81892 .38606 .81971 .38716 .82593 .38519 .82514 .38409 Metetra
.664 .741 .907 r
.82514 .38409 .82593 .38519 .83217 .38322 .83138 .38212 Metetra
.664 .741 .907 r
.83138 .38212 .83217 .38322 .83842 .38124 .83764 .38014 Metetra
.664 .741 .907 r
.83764 .38014 .83842 .38124 .84469 .37927 .84391 .37816 Metetra
.664 .741 .907 r
.84391 .37816 .84469 .37927 .85096 .37728 .85019 .37617 Metetra
.664 .741 .907 r
.85019 .37617 .85096 .37728 .85726 .37529 .85648 .37418 Metetra
.664 .741 .907 r
.85648 .37418 .85726 .37529 .86356 .3733 .86279 .37219 Metetra
.664 .741 .907 r
.86279 .37219 .86356 .3733 .86988 .37131 .86911 .37019 Metetra
.664 .741 .907 r
.86911 .37019 .86988 .37131 .87621 .36931 .87545 .36819 Metetra
.664 .741 .907 r
.87545 .36819 .87621 .36931 .88256 .3673 .8818 .36618 Metetra
.664 .741 .907 r
.8818 .36618 .88256 .3673 .88892 .36529 .88816 .36417 Metetra
.664 .741 .907 r
.88816 .36417 .88892 .36529 .8953 .36328 .89454 .36215 Metetra
.664 .741 .907 r
.89454 .36215 .8953 .36328 .90168 .36126 .90093 .36013 Metetra
.664 .741 .907 r
.90093 .36013 .90168 .36126 .90809 .35924 .90734 .35811 Metetra
.664 .741 .907 r
.90734 .35811 .90809 .35924 .9145 .35721 .91376 .35608 Metetra
.664 .741 .907 r
.91376 .35608 .9145 .35721 .92093 .35518 .92019 .35404 Metetra
.664 .741 .907 r
.3386 .53667 .33959 .53759 .34483 .53594 .34385 .53501 Metetra
.664 .741 .907 r
.34385 .53501 .34483 .53594 .34938 .54767 .3491 .53335 Metetra
.579 .391 .591 r
.3491 .53335 .34938 .54767 .35534 .53261 .35436 .53169 Metetra
.664 .741 .907 r
.35436 .53169 .35534 .53261 .36061 .53095 .35963 .53002 Metetra
.664 .741 .907 r
.35963 .53002 .36061 .53095 .36589 .52928 .36491 .52835 Metetra
.664 .741 .907 r
.36491 .52835 .36589 .52928 .37118 .52761 .37021 .52667 Metetra
.664 .741 .907 r
.37021 .52667 .37118 .52761 .37649 .52593 .37551 .52499 Metetra
.664 .741 .907 r
.37551 .52499 .37649 .52593 .3818 .52425 .38083 .52331 Metetra
.664 .741 .907 r
.38083 .52331 .3818 .52425 .38712 .52257 .38615 .52163 Metetra
.664 .741 .907 r
.38615 .52163 .38712 .52257 .39246 .52088 .39149 .51994 Metetra
.664 .741 .907 r
.39149 .51994 .39246 .52088 .3978 .51919 .39683 .51825 Metetra
.664 .741 .907 r
.39683 .51825 .3978 .51919 .40315 .5175 .40219 .51655 Metetra
.664 .741 .907 r
.40219 .51655 .40315 .5175 .40852 .5158 .40756 .51486 Metetra
.664 .741 .907 r
.40756 .51486 .40852 .5158 .4139 .5141 .41293 .51315 Metetra
.664 .741 .907 r
.41293 .51315 .4139 .5141 .41877 .52862 .41832 .51145 Metetra
0 0 .142 r
.41832 .51145 .41877 .52862 .42468 .51069 .42119 .59328 Metetra
.629 .402 .554 r
.42119 .59328 .42468 .51069 .42894 .54941 .42481 .65849 Metetra
.366 .19 .505 r
.42481 .65849 .42894 .54941 .43551 .50727 .43456 .50631 Metetra
.664 .741 .907 r
.43456 .50631 .43551 .50727 .44094 .50555 .43999 .50459 Metetra
.664 .741 .907 r
.43999 .50459 .44094 .50555 .44638 .50383 .44543 .50287 Metetra
.664 .741 .907 r
.44543 .50287 .44638 .50383 .45183 .50211 .45089 .50115 Metetra
.664 .741 .907 r
.45089 .50115 .45183 .50211 .45729 .50038 .45635 .49942 Metetra
.664 .741 .907 r
.45635 .49942 .45729 .50038 .46277 .49865 .46183 .49769 Metetra
.664 .741 .907 r
.46183 .49769 .46277 .49865 .46825 .49692 .46731 .49595 Metetra
.664 .741 .907 r
.46731 .49595 .46825 .49692 .47375 .49518 .47281 .49421 Metetra
.664 .741 .907 r
.47281 .49421 .47375 .49518 .47926 .49344 .47832 .49247 Metetra
.664 .741 .907 r
.47832 .49247 .47926 .49344 .48478 .4917 .48384 .49072 Metetra
.664 .741 .907 r
.48384 .49072 .48478 .4917 .49031 .48995 .48937 .48897 Metetra
.664 .741 .907 r
.48937 .48897 .49031 .48995 .49585 .4882 .49492 .48722 Metetra
.664 .741 .907 r
.49492 .48722 .49585 .4882 .50139 .48815 .50047 .48546 Metetra
.631 .542 .735 r
.50047 .48546 .50139 .48815 .50696 .48468 .50604 .4837 Metetra
.664 .741 .907 r
.50604 .4837 .50696 .48468 .51254 .48292 .51161 .48193 Metetra
.664 .741 .907 r
.51161 .48193 .51254 .48292 .51812 .48115 .5172 .48017 Metetra
.664 .741 .907 r
.5172 .48017 .51812 .48115 .52372 .47938 .5228 .47839 Metetra
.664 .741 .907 r
.5228 .47839 .52372 .47938 .52933 .47761 .52841 .47662 Metetra
.664 .741 .907 r
.52841 .47662 .52933 .47761 .53495 .47583 .53404 .47484 Metetra
.664 .741 .907 r
.53404 .47484 .53495 .47583 .54058 .47405 .53967 .47306 Metetra
.664 .741 .907 r
.53967 .47306 .54058 .47405 .54622 .47227 .54532 .47127 Metetra
.664 .741 .907 r
.54532 .47127 .54622 .47227 .55188 .47048 .55097 .46948 Metetra
.664 .741 .907 r
.55097 .46948 .55188 .47048 .55755 .46869 .55664 .46769 Metetra
.664 .741 .907 r
.55664 .46769 .55755 .46869 .56322 .46689 .56232 .46589 Metetra
.944 .581 .255 r
.56232 .46589 .56322 .46689 .56891 .4651 .56835 .48957 Metetra
.67 .423 .539 r
.56835 .48957 .56891 .4651 .57509 .49499 .57465 .52507 Metetra
.248 .093 .465 r
.57465 .52507 .57509 .49499 .58033 .46149 .57943 .46048 Metetra
.664 .741 .907 r
.57943 .46048 .58033 .46149 .58605 .45968 .58516 .45867 Metetra
.664 .741 .907 r
.58516 .45867 .58605 .45968 .59179 .45786 .5909 .45685 Metetra
.664 .741 .907 r
.5909 .45685 .59179 .45786 .59754 .45605 .59665 .45503 Metetra
.664 .741 .907 r
.59665 .45503 .59754 .45605 .6033 .45423 .60241 .45321 Metetra
.664 .741 .907 r
.60241 .45321 .6033 .45423 .60907 .4524 .60819 .45138 Metetra
.664 .741 .907 r
.60819 .45138 .60907 .4524 .61486 .45057 .61397 .44955 Metetra
.664 .741 .907 r
.61397 .44955 .61486 .45057 .62065 .44874 .61977 .44772 Metetra
.664 .741 .907 r
.61977 .44772 .62065 .44874 .62646 .4469 .62558 .44588 Metetra
.664 .741 .907 r
.62558 .44588 .62646 .4469 .63228 .44506 .63141 .44404 Metetra
.664 .741 .907 r
.63141 .44404 .63228 .44506 .63811 .44322 .63724 .44219 Metetra
.664 .741 .907 r
.63724 .44219 .63811 .44322 .64396 .44137 .64309 .44034 Metetra
.664 .741 .907 r
.64309 .44034 .64396 .44137 .64982 .43952 .64895 .43849 Metetra
.664 .741 .907 r
.64895 .43849 .64982 .43952 .65568 .43766 .65482 .43663 Metetra
.664 .741 .907 r
.65482 .43663 .65568 .43766 .66157 .43581 .66071 .43477 Metetra
.664 .741 .907 r
.66071 .43477 .66157 .43581 .66746 .43394 .6666 .4329 Metetra
.664 .741 .907 r
.6666 .4329 .66746 .43394 .67337 .43207 .67251 .43103 Metetra
.664 .741 .907 r
.67251 .43103 .67337 .43207 .67928 .4302 .67843 .42916 Metetra
.664 .741 .907 r
.67843 .42916 .67928 .4302 .68522 .42833 .68436 .42728 Metetra
.664 .741 .907 r
.68436 .42728 .68522 .42833 .69116 .42645 .69031 .4254 Metetra
.664 .741 .907 r
.69031 .4254 .69116 .42645 .69711 .42457 .69627 .42352 Metetra
.664 .741 .907 r
.69627 .42352 .69711 .42457 .70308 .42268 .70224 .42163 Metetra
.664 .741 .907 r
.70224 .42163 .70308 .42268 .70906 .42079 .70822 .41973 Metetra
.664 .741 .907 r
.70822 .41973 .70906 .42079 .71506 .41889 .71422 .41784 Metetra
.664 .741 .907 r
.71422 .41784 .71506 .41889 .72106 .417 .72023 .41593 Metetra
.664 .741 .907 r
.72023 .41593 .72106 .417 .72708 .41509 .72625 .41403 Metetra
.97 .658 .353 r
.72625 .41403 .72708 .41509 .73544 .44929 .73971 .52795 Metetra
.387 .215 .523 r
.73971 .52795 .73544 .44929 .73916 .41128 .73833 .41021 Metetra
.664 .741 .907 r
.73833 .41021 .73916 .41128 .74522 .40936 .74439 .40829 Metetra
.664 .741 .907 r
.74439 .40829 .74522 .40936 .75129 .40744 .75046 .40637 Metetra
.664 .741 .907 r
.75046 .40637 .75129 .40744 .75737 .40552 .75655 .40444 Metetra
.664 .741 .907 r
.75655 .40444 .75737 .40552 .76346 .40359 .76265 .40251 Metetra
.664 .741 .907 r
.76265 .40251 .76346 .40359 .76957 .40166 .76876 .40058 Metetra
.664 .741 .907 r
.76876 .40058 .76957 .40166 .77569 .39972 .77488 .39864 Metetra
.664 .741 .907 r
.77488 .39864 .77569 .39972 .78183 .39779 .78102 .3967 Metetra
.664 .741 .907 r
.78102 .3967 .78183 .39779 .78798 .39584 .78717 .39476 Metetra
.664 .741 .907 r
.78717 .39476 .78798 .39584 .79414 .39389 .79334 .39281 Metetra
.664 .741 .907 r
.79334 .39281 .79414 .39389 .80031 .39194 .79951 .39085 Metetra
.664 .741 .907 r
.79951 .39085 .80031 .39194 .8065 .38999 .8057 .38889 Metetra
.664 .741 .907 r
.8057 .38889 .8065 .38999 .8127 .38803 .81191 .38693 Metetra
.664 .741 .907 r
.81191 .38693 .8127 .38803 .81892 .38606 .81813 .38496 Metetra
.664 .741 .907 r
.81813 .38496 .81892 .38606 .82514 .38409 .82436 .38299 Metetra
.664 .741 .907 r
.82436 .38299 .82514 .38409 .83138 .38212 .8306 .38102 Metetra
.664 .741 .907 r
.8306 .38102 .83138 .38212 .83764 .38014 .83686 .37904 Metetra
.664 .741 .907 r
.83686 .37904 .83764 .38014 .84391 .37816 .84313 .37705 Metetra
.664 .741 .907 r
.84313 .37705 .84391 .37816 .85019 .37617 .84941 .37506 Metetra
.664 .741 .907 r
.84941 .37506 .85019 .37617 .85648 .37418 .85571 .37307 Metetra
.664 .741 .907 r
.85571 .37307 .85648 .37418 .86279 .37219 .86202 .37108 Metetra
.664 .741 .907 r
.86202 .37108 .86279 .37219 .86911 .37019 .86835 .36907 Metetra
.664 .741 .907 r
.86835 .36907 .86911 .37019 .87545 .36819 .87469 .36707 Metetra
.664 .741 .907 r
.87469 .36707 .87545 .36819 .8818 .36618 .88104 .36506 Metetra
.664 .741 .907 r
.88104 .36506 .8818 .36618 .88816 .36417 .88741 .36304 Metetra
.664 .741 .907 r
.88741 .36304 .88816 .36417 .89454 .36215 .89379 .36103 Metetra
.651 .735 .911 r
.89379 .36103 .89454 .36215 .90093 .36013 .9002 .35921 Metetra
.675 .79 .936 r
.9002 .35921 .90093 .36013 .90734 .35811 .90659 .35698 Metetra
.664 .741 .907 r
.90659 .35698 .90734 .35811 .91376 .35608 .91301 .35494 Metetra
.664 .741 .907 r
.91301 .35494 .91376 .35608 .92019 .35404 .91945 .35291 Metetra
.664 .741 .907 r
.33761 .53575 .3386 .53667 .34385 .53501 .34286 .53409 Metetra
.664 .741 .907 r
.34286 .53409 .34385 .53501 .3491 .53335 .34811 .53242 Metetra
.6 .723 .931 r
.34811 .53242 .3491 .53335 .35436 .53169 .35333 .53154 Metetra
.673 .933 .969 r
.35333 .53154 .35436 .53169 .35963 .53002 .35865 .52909 Metetra
.664 .741 .907 r
.35865 .52909 .35963 .53002 .36491 .52835 .36393 .52741 Metetra
.664 .741 .907 r
.36393 .52741 .36491 .52835 .37021 .52667 .36923 .52574 Metetra
.664 .741 .907 r
.36923 .52574 .37021 .52667 .37551 .52499 .37454 .52406 Metetra
.664 .741 .907 r
.37454 .52406 .37551 .52499 .38083 .52331 .37985 .52237 Metetra
.664 .741 .907 r
.37985 .52237 .38083 .52331 .38615 .52163 .38518 .52069 Metetra
.664 .741 .907 r
.38518 .52069 .38615 .52163 .39149 .51994 .39052 .519 Metetra
.664 .741 .907 r
.39052 .519 .39149 .51994 .39683 .51825 .39586 .5173 Metetra
.664 .741 .907 r
.39586 .5173 .39683 .51825 .40219 .51655 .40122 .51561 Metetra
.664 .741 .907 r
.40122 .51561 .40219 .51655 .40756 .51486 .40659 .51391 Metetra
.664 .741 .907 r
.40659 .51391 .40756 .51486 .41293 .51315 .41197 .5122 Metetra
.664 .741 .907 r
.41197 .5122 .41293 .51315 .41832 .51145 .41736 .5105 Metetra
.948 .676 .487 r
.41736 .5105 .41832 .51145 .42119 .59328 .41827 .65544 Metetra
.438 .243 .518 r
.41827 .65544 .42119 .59328 .42481 .65849 .42563 .59464 Metetra
.678 .451 .57 r
.42563 .59464 .42481 .65849 .43456 .50631 .4336 .50536 Metetra
.664 .741 .907 r
.4336 .50536 .43456 .50631 .43999 .50459 .43904 .50363 Metetra
.664 .741 .907 r
.43904 .50363 .43999 .50459 .44543 .50287 .44448 .50191 Metetra
.664 .741 .907 r
.44448 .50191 .44543 .50287 .45089 .50115 .44994 .50018 Metetra
.664 .741 .907 r
.44994 .50018 .45089 .50115 .45635 .49942 .4554 .49845 Metetra
.664 .741 .907 r
.4554 .49845 .45635 .49942 .46183 .49769 .46088 .49672 Metetra
.664 .741 .907 r
.46088 .49672 .46183 .49769 .46731 .49595 .46637 .49498 Metetra
.664 .741 .907 r
.46637 .49498 .46731 .49595 .47281 .49421 .47187 .49324 Metetra
.664 .741 .907 r
.47187 .49324 .47281 .49421 .47832 .49247 .47738 .49149 Metetra
.664 .741 .907 r
.47738 .49149 .47832 .49247 .48384 .49072 .48291 .48974 Metetra
.664 .741 .907 r
.48291 .48974 .48384 .49072 .48937 .48897 .48844 .48799 Metetra
.664 .741 .907 r
.48844 .48799 .48937 .48897 .49492 .48722 .49399 .48624 Metetra
.664 .741 .907 r
.49399 .48624 .49492 .48722 .50047 .48546 .49954 .48448 Metetra
.664 .741 .907 r
.49954 .48448 .50047 .48546 .50604 .4837 .50511 .48272 Metetra
.664 .741 .907 r
.50511 .48272 .50604 .4837 .51161 .48193 .51069 .48095 Metetra
.664 .741 .907 r
.51069 .48095 .51161 .48193 .5172 .48017 .51628 .47918 Metetra
.664 .741 .907 r
.51628 .47918 .5172 .48017 .5228 .47839 .52188 .47741 Metetra
.664 .741 .907 r
.52188 .47741 .5228 .47839 .52841 .47662 .5275 .47563 Metetra
.664 .741 .907 r
.5275 .47563 .52841 .47662 .53404 .47484 .53312 .47385 Metetra
.664 .741 .907 r
.53312 .47385 .53404 .47484 .53967 .47306 .53876 .47206 Metetra
.664 .741 .907 r
.53876 .47206 .53967 .47306 .54532 .47127 .5444 .47027 Metetra
.664 .741 .907 r
.5444 .47027 .54532 .47127 .55097 .46948 .55006 .46848 Metetra
.664 .741 .907 r
.55006 .46848 .55097 .46948 .55664 .46769 .55574 .46669 Metetra
.664 .741 .907 r
.55574 .46669 .55664 .46769 .56232 .46589 .56142 .46489 Metetra
.958 .629 .344 r
.56142 .46489 .56232 .46589 .56835 .48957 .56762 .50292 Metetra
.563 .323 .51 r
.56762 .50292 .56835 .48957 .57465 .52507 .57344 .50383 Metetra
.714 .486 .578 r
.57344 .50383 .57465 .52507 .57943 .46048 .57854 .45947 Metetra
.664 .741 .907 r
.57854 .45947 .57943 .46048 .58516 .45867 .58427 .45765 Metetra
.664 .741 .907 r
.58427 .45765 .58516 .45867 .5909 .45685 .59001 .45584 Metetra
.664 .741 .907 r
.59001 .45584 .5909 .45685 .59665 .45503 .59576 .45401 Metetra
.664 .741 .907 r
.59576 .45401 .59665 .45503 .60241 .45321 .60153 .45219 Metetra
.664 .741 .907 r
.60153 .45219 .60241 .45321 .60819 .45138 .6073 .45036 Metetra
.664 .741 .907 r
.6073 .45036 .60819 .45138 .61397 .44955 .61309 .44853 Metetra
.664 .741 .907 r
.61309 .44853 .61397 .44955 .61977 .44772 .61889 .44669 Metetra
.664 .741 .907 r
.61889 .44669 .61977 .44772 .62558 .44588 .62471 .44485 Metetra
.664 .741 .907 r
.62471 .44485 .62558 .44588 .63141 .44404 .63053 .44301 Metetra
.664 .741 .907 r
.63053 .44301 .63141 .44404 .63724 .44219 .63637 .44116 Metetra
.664 .741 .907 r
.63637 .44116 .63724 .44219 .64309 .44034 .64222 .43931 Metetra
.664 .741 .907 r
.64222 .43931 .64309 .44034 .64895 .43849 .64808 .43745 Metetra
.664 .741 .907 r
.64808 .43745 .64895 .43849 .65482 .43663 .65396 .43559 Metetra
.664 .741 .907 r
.65396 .43559 .65482 .43663 .66071 .43477 .65984 .43373 Metetra
.664 .741 .907 r
.65984 .43373 .66071 .43477 .6666 .4329 .66574 .43186 Metetra
.664 .741 .907 r
.66574 .43186 .6666 .4329 .67251 .43103 .67165 .42999 Metetra
.664 .741 .907 r
.67165 .42999 .67251 .43103 .67843 .42916 .67758 .42811 Metetra
.664 .741 .907 r
.67758 .42811 .67843 .42916 .68436 .42728 .68351 .42623 Metetra
.664 .741 .907 r
.68351 .42623 .68436 .42728 .69031 .4254 .68946 .42435 Metetra
.664 .741 .907 r
.68946 .42435 .69031 .4254 .69627 .42352 .69542 .42246 Metetra
.664 .741 .907 r
.69542 .42246 .69627 .42352 .70224 .42163 .7014 .42057 Metetra
.664 .741 .907 r
.7014 .42057 .70224 .42163 .70822 .41973 .70738 .41868 Metetra
.664 .741 .907 r
.70738 .41868 .70822 .41973 .71422 .41784 .71338 .41678 Metetra
0 .191 .708 r
.71338 .41678 .71422 .41784 .72023 .41593 .71983 .42221 Metetra
.38 .143 .424 r
.71983 .42221 .72023 .41593 .72625 .41403 .72542 .41297 Metetra
.942 .58 .207 r
.72542 .41297 .72625 .41403 .73971 .52795 .73365 .44544 Metetra
.603 .387 .56 r
.73365 .44544 .73971 .52795 .73833 .41021 .7375 .40914 Metetra
.664 .741 .907 r
.7375 .40914 .73833 .41021 .74439 .40829 .74357 .40722 Metetra
.664 .741 .907 r
.74357 .40722 .74439 .40829 .75046 .40637 .74964 .4053 Metetra
.664 .741 .907 r
.74964 .4053 .75046 .40637 .75655 .40444 .75573 .40337 Metetra
.664 .741 .907 r
.75573 .40337 .75655 .40444 .76265 .40251 .76183 .40144 Metetra
.664 .741 .907 r
.76183 .40144 .76265 .40251 .76876 .40058 .76795 .3995 Metetra
.664 .741 .907 r
.76795 .3995 .76876 .40058 .77488 .39864 .77407 .39756 Metetra
.664 .741 .907 r
.77407 .39756 .77488 .39864 .78102 .3967 .78021 .39562 Metetra
.664 .741 .907 r
.78021 .39562 .78102 .3967 .78717 .39476 .78637 .39367 Metetra
.664 .741 .907 r
.78637 .39367 .78717 .39476 .79334 .39281 .79253 .39172 Metetra
.664 .741 .907 r
.79253 .39172 .79334 .39281 .79951 .39085 .79871 .38976 Metetra
.664 .741 .907 r
.79871 .38976 .79951 .39085 .8057 .38889 .80491 .3878 Metetra
.664 .741 .907 r
.80491 .3878 .8057 .38889 .81191 .38693 .81111 .38583 Metetra
.664 .741 .907 r
.81111 .38583 .81191 .38693 .81813 .38496 .81733 .38386 Metetra
.664 .741 .907 r
.81733 .38386 .81813 .38496 .82436 .38299 .82357 .38189 Metetra
.664 .741 .907 r
.82357 .38189 .82436 .38299 .8306 .38102 .82981 .37991 Metetra
.664 .741 .907 r
.82981 .37991 .8306 .38102 .83686 .37904 .83607 .37793 Metetra
.664 .741 .907 r
.83607 .37793 .83686 .37904 .84313 .37705 .84235 .37594 Metetra
.664 .741 .907 r
.84235 .37594 .84313 .37705 .84941 .37506 .84864 .37395 Metetra
.664 .741 .907 r
.84864 .37395 .84941 .37506 .85571 .37307 .85494 .37196 Metetra
.664 .741 .907 r
.85494 .37196 .85571 .37307 .86202 .37108 .86125 .36996 Metetra
.664 .741 .907 r
.86125 .36996 .86202 .37108 .86835 .36907 .86758 .36796 Metetra
.664 .741 .907 r
.86758 .36796 .86835 .36907 .87469 .36707 .87392 .36595 Metetra
.664 .741 .907 r
.87392 .36595 .87469 .36707 .88104 .36506 .88028 .36394 Metetra
.664 .741 .907 r
.88028 .36394 .88104 .36506 .88741 .36304 .88665 .36192 Metetra
.664 .741 .907 r
.88665 .36192 .88741 .36304 .89379 .36103 .89303 .3599 Metetra
.664 .741 .907 r
.89303 .3599 .89379 .36103 .9002 .35921 .89943 .35787 Metetra
.663 .703 .877 r
.89943 .35787 .9002 .35921 .90659 .35698 .90584 .35584 Metetra
.664 .741 .907 r
.90584 .35584 .90659 .35698 .91301 .35494 .91226 .35381 Metetra
.664 .741 .907 r
.91226 .35381 .91301 .35494 .91945 .35291 .9187 .35177 Metetra
.664 .741 .907 r
.33662 .53482 .33761 .53575 .34286 .53409 .34187 .53316 Metetra
.664 .741 .907 r
.34187 .53316 .34286 .53409 .34811 .53242 .34712 .53149 Metetra
.905 .493 .161 r
.34712 .53149 .34811 .53242 .35333 .53154 .35172 .54288 Metetra
.371 .154 .449 r
.35172 .54288 .35333 .53154 .35865 .52909 .35767 .52815 Metetra
.664 .741 .907 r
.35767 .52815 .35865 .52909 .36393 .52741 .36295 .52648 Metetra
.664 .741 .907 r
.36295 .52648 .36393 .52741 .36923 .52574 .36825 .5248 Metetra
.664 .741 .907 r
.36825 .5248 .36923 .52574 .37454 .52406 .37356 .52312 Metetra
.664 .741 .907 r
.37356 .52312 .37454 .52406 .37985 .52237 .37888 .52143 Metetra
.664 .741 .907 r
.37888 .52143 .37985 .52237 .38518 .52069 .3842 .51974 Metetra
.664 .741 .907 r
.3842 .51974 .38518 .52069 .39052 .519 .38954 .51805 Metetra
.664 .741 .907 r
.38954 .51805 .39052 .519 .39586 .5173 .39489 .51636 Metetra
.664 .741 .907 r
.39489 .51636 .39586 .5173 .40122 .51561 .40026 .51466 Metetra
.664 .741 .907 r
.40026 .51466 .40122 .51561 .40659 .51391 .40563 .51296 Metetra
.664 .741 .907 r
.40563 .51296 .40659 .51391 .41197 .5122 .41101 .51125 Metetra
.664 .741 .907 r
.41101 .51125 .41197 .5122 .41736 .5105 .4164 .50954 Metetra
.949 .674 .482 r
.4164 .50954 .41736 .5105 .41827 .65544 .41807 .6285 Metetra
.796 .555 .573 r
.41807 .6285 .41827 .65544 .42563 .59464 .42722 .50612 Metetra
.565 .358 .558 r
.42722 .50612 .42563 .59464 .4336 .50536 .43265 .5044 Metetra
.664 .741 .907 r
.43265 .5044 .4336 .50536 .43904 .50363 .43808 .50267 Metetra
.664 .741 .907 r
.43808 .50267 .43904 .50363 .44448 .50191 .44353 .50095 Metetra
.664 .741 .907 r
.44353 .50095 .44448 .50191 .44994 .50018 .44899 .49922 Metetra
.664 .741 .907 r
.44899 .49922 .44994 .50018 .4554 .49845 .45446 .49749 Metetra
.664 .741 .907 r
.45446 .49749 .4554 .49845 .46088 .49672 .45994 .49575 Metetra
.664 .741 .907 r
.45994 .49575 .46088 .49672 .46637 .49498 .46543 .49401 Metetra
.664 .741 .907 r
.46543 .49401 .46637 .49498 .47187 .49324 .47093 .49227 Metetra
.664 .741 .907 r
.47093 .49227 .47187 .49324 .47738 .49149 .47645 .49052 Metetra
.664 .741 .907 r
.47645 .49052 .47738 .49149 .48291 .48974 .48197 .48877 Metetra
.664 .741 .907 r
.48197 .48877 .48291 .48974 .48844 .48799 .48751 .48701 Metetra
.664 .741 .907 r
.48751 .48701 .48844 .48799 .49399 .48624 .49306 .48526 Metetra
.664 .741 .907 r
.49306 .48526 .49399 .48624 .49954 .48448 .49861 .4835 Metetra
.664 .741 .907 r
.49861 .4835 .49954 .48448 .50511 .48272 .50418 .48173 Metetra
.664 .741 .907 r
.50418 .48173 .50511 .48272 .51069 .48095 .50977 .47996 Metetra
.664 .741 .907 r
.50977 .47996 .51069 .48095 .51628 .47918 .51536 .47819 Metetra
.664 .741 .907 r
.51536 .47819 .51628 .47918 .52188 .47741 .52096 .47641 Metetra
.664 .741 .907 r
.52096 .47641 .52188 .47741 .5275 .47563 .52658 .47464 Metetra
.664 .741 .907 r
.52658 .47464 .5275 .47563 .53312 .47385 .5322 .47285 Metetra
.664 .741 .907 r
.5322 .47285 .53312 .47385 .53876 .47206 .53784 .47107 Metetra
.664 .741 .907 r
.53784 .47107 .53876 .47206 .5444 .47027 .54349 .46928 Metetra
.664 .741 .907 r
.54349 .46928 .5444 .47027 .55006 .46848 .54916 .46748 Metetra
.664 .741 .907 r
.54916 .46748 .55006 .46848 .55574 .46669 .55483 .46568 Metetra
.664 .741 .907 r
.55483 .46568 .55574 .46669 .56142 .46489 .56051 .46388 Metetra
.664 .741 .907 r
.56051 .46388 .56142 .46489 .56762 .50292 .56621 .46208 Metetra
.414 .247 .544 r
.56621 .46208 .56762 .50292 .57344 .50383 .57266 .51221 Metetra
.705 .629 .066 r
.57266 .51221 .57344 .50383 .57854 .45947 .57764 .45846 Metetra
.664 .741 .907 r
.57764 .45846 .57854 .45947 .58427 .45765 .58337 .45664 Metetra
.664 .741 .907 r
.58337 .45664 .58427 .45765 .59001 .45584 .58912 .45482 Metetra
.664 .741 .907 r
.58912 .45482 .59001 .45584 .59576 .45401 .59487 .453 Metetra
.664 .741 .907 r
.59487 .453 .59576 .45401 .60153 .45219 .60064 .45117 Metetra
.664 .741 .907 r
.60064 .45117 .60153 .45219 .6073 .45036 .60642 .44934 Metetra
.664 .741 .907 r
.60642 .44934 .6073 .45036 .61309 .44853 .61221 .4475 Metetra
.664 .741 .907 r
.61221 .4475 .61309 .44853 .61889 .44669 .61801 .44566 Metetra
.664 .741 .907 r
.61801 .44566 .61889 .44669 .62471 .44485 .62383 .44382 Metetra
.664 .741 .907 r
.62383 .44382 .62471 .44485 .63053 .44301 .62966 .44198 Metetra
.664 .741 .907 r
.62966 .44198 .63053 .44301 .63637 .44116 .6355 .44013 Metetra
.664 .741 .907 r
.6355 .44013 .63637 .44116 .64222 .43931 .64135 .43827 Metetra
.664 .741 .907 r
.64135 .43827 .64222 .43931 .64808 .43745 .64721 .43641 Metetra
.664 .741 .907 r
.64721 .43641 .64808 .43745 .65396 .43559 .65309 .43455 Metetra
.664 .741 .907 r
.65309 .43455 .65396 .43559 .65984 .43373 .65898 .43269 Metetra
.664 .741 .907 r
.65898 .43269 .65984 .43373 .66574 .43186 .66488 .43082 Metetra
.664 .741 .907 r
.66488 .43082 .66574 .43186 .67165 .42999 .6708 .42894 Metetra
.664 .741 .907 r
.6708 .42894 .67165 .42999 .67758 .42811 .67672 .42706 Metetra
.664 .741 .907 r
.67672 .42706 .67758 .42811 .68351 .42623 .68266 .42518 Metetra
.664 .741 .907 r
.68266 .42518 .68351 .42623 .68946 .42435 .68861 .4233 Metetra
.664 .741 .907 r
.68861 .4233 .68946 .42435 .69542 .42246 .69457 .42141 Metetra
.664 .741 .907 r
.69457 .42141 .69542 .42246 .7014 .42057 .70055 .41951 Metetra
.664 .741 .907 r
.70055 .41951 .7014 .42057 .70738 .41868 .70654 .41762 Metetra
.664 .741 .907 r
.70654 .41762 .70738 .41868 .71338 .41678 .71254 .41572 Metetra
.624 .726 .92 r
.71254 .41572 .71338 .41678 .71983 .42221 .71859 .4144 Metetra
.599 .43 .624 r
.71859 .4144 .71983 .42221 .72542 .41297 .72458 .4119 Metetra
.664 .741 .907 r
.72458 .4119 .72542 .41297 .73365 .44544 .73062 .40999 Metetra
.57 .368 .568 r
.73062 .40999 .73365 .44544 .7375 .40914 .73667 .40807 Metetra
.664 .741 .907 r
.73667 .40807 .7375 .40914 .74357 .40722 .74274 .40615 Metetra
.664 .741 .907 r
.74274 .40615 .74357 .40722 .74964 .4053 .74882 .40422 Metetra
.664 .741 .907 r
.74882 .40422 .74964 .4053 .75573 .40337 .75491 .40229 Metetra
.664 .741 .907 r
.75491 .40229 .75573 .40337 .76183 .40144 .76101 .40036 Metetra
.664 .741 .907 r
.76101 .40036 .76183 .40144 .76795 .3995 .76713 .39842 Metetra
.664 .741 .907 r
.76713 .39842 .76795 .3995 .77407 .39756 .77326 .39648 Metetra
.664 .741 .907 r
.77326 .39648 .77407 .39756 .78021 .39562 .7794 .39453 Metetra
.664 .741 .907 r
.7794 .39453 .78021 .39562 .78637 .39367 .78556 .39258 Metetra
.664 .741 .907 r
.78556 .39258 .78637 .39367 .79253 .39172 .79173 .39063 Metetra
.664 .741 .907 r
.79173 .39063 .79253 .39172 .79871 .38976 .79791 .38867 Metetra
.664 .741 .907 r
.79791 .38867 .79871 .38976 .80491 .3878 .80411 .3867 Metetra
.664 .741 .907 r
.80411 .3867 .80491 .3878 .81111 .38583 .81032 .38474 Metetra
.664 .741 .907 r
.81032 .38474 .81111 .38583 .81733 .38386 .81654 .38276 Metetra
.664 .741 .907 r
.81654 .38276 .81733 .38386 .82357 .38189 .82278 .38079 Metetra
.664 .741 .907 r
.82278 .38079 .82357 .38189 .82981 .37991 .82903 .37881 Metetra
.664 .741 .907 r
.82903 .37881 .82981 .37991 .83607 .37793 .83529 .37682 Metetra
.664 .741 .907 r
.83529 .37682 .83607 .37793 .84235 .37594 .84157 .37483 Metetra
.664 .741 .907 r
.84157 .37483 .84235 .37594 .84864 .37395 .84786 .37284 Metetra
.664 .741 .907 r
.84786 .37284 .84864 .37395 .85494 .37196 .85416 .37084 Metetra
.664 .741 .907 r
.85416 .37084 .85494 .37196 .86125 .36996 .86048 .36884 Metetra
.664 .741 .907 r
.86048 .36884 .86125 .36996 .86758 .36796 .86681 .36684 Metetra
.664 .741 .907 r
.86681 .36684 .86758 .36796 .87392 .36595 .87315 .36483 Metetra
.664 .741 .907 r
.87315 .36483 .87392 .36595 .88028 .36394 .87951 .36281 Metetra
.664 .741 .907 r
.87951 .36281 .88028 .36394 .88665 .36192 .88589 .36079 Metetra
.664 .741 .907 r
.88589 .36079 .88665 .36192 .89303 .3599 .89227 .35877 Metetra
.664 .741 .907 r
.89227 .35877 .89303 .3599 .89943 .35787 .89867 .35674 Metetra
.664 .741 .907 r
.89867 .35674 .89943 .35787 .90584 .35584 .90509 .35471 Metetra
.664 .741 .907 r
.90509 .35471 .90584 .35584 .91226 .35381 .91152 .35267 Metetra
.664 .741 .907 r
.91152 .35267 .91226 .35381 .9187 .35177 .91796 .35063 Metetra
.664 .741 .907 r
.33563 .53389 .33662 .53482 .34187 .53316 .34088 .53223 Metetra
.664 .741 .907 r
.34088 .53223 .34187 .53316 .34712 .53149 .34614 .53056 Metetra
.875 .437 .073 r
.34614 .53056 .34712 .53149 .35172 .54288 .35082 .54022 Metetra
.807 .634 .668 r
.35082 .54022 .35172 .54288 .35767 .52815 .35668 .52722 Metetra
.664 .741 .907 r
.35668 .52722 .35767 .52815 .36295 .52648 .36197 .52554 Metetra
.664 .741 .907 r
.36197 .52554 .36295 .52648 .36825 .5248 .36727 .52386 Metetra
.664 .741 .907 r
.36727 .52386 .36825 .5248 .37356 .52312 .37258 .52218 Metetra
.664 .741 .907 r
.37258 .52218 .37356 .52312 .37888 .52143 .3779 .52049 Metetra
.664 .741 .907 r
.3779 .52049 .37888 .52143 .3842 .51974 .38323 .5188 Metetra
.664 .741 .907 r
.38323 .5188 .3842 .51974 .38954 .51805 .38857 .51711 Metetra
.664 .741 .907 r
.38857 .51711 .38954 .51805 .39489 .51636 .39392 .51541 Metetra
.664 .741 .907 r
.39392 .51541 .39489 .51636 .40026 .51466 .39929 .51371 Metetra
.664 .741 .907 r
.39929 .51371 .40026 .51466 .40563 .51296 .40466 .51201 Metetra
.664 .741 .907 r
.40466 .51201 .40563 .51296 .41101 .51125 .41004 .5103 Metetra
.664 .741 .907 r
.41004 .5103 .41101 .51125 .4164 .50954 .41544 .50859 Metetra
.949 .622 .373 r
.41544 .50859 .4164 .50954 .41807 .6285 .41992 .53649 Metetra
.576 .366 .559 r
.41992 .53649 .41807 .6285 .42722 .50612 .42568 .52478 Metetra
.408 .203 .486 r
.42568 .52478 .42722 .50612 .43265 .5044 .43169 .50344 Metetra
.664 .741 .907 r
.43169 .50344 .43265 .5044 .43808 .50267 .43713 .50171 Metetra
.664 .741 .907 r
.43713 .50171 .43808 .50267 .44353 .50095 .44258 .49998 Metetra
.664 .741 .907 r
.44258 .49998 .44353 .50095 .44899 .49922 .44804 .49825 Metetra
.664 .741 .907 r
.44804 .49825 .44899 .49922 .45446 .49749 .45351 .49652 Metetra
.664 .741 .907 r
.45351 .49652 .45446 .49749 .45994 .49575 .45899 .49478 Metetra
.664 .741 .907 r
.45899 .49478 .45994 .49575 .46543 .49401 .46449 .49304 Metetra
.664 .741 .907 r
.46449 .49304 .46543 .49401 .47093 .49227 .46999 .49129 Metetra
.664 .741 .907 r
.46999 .49129 .47093 .49227 .47645 .49052 .47551 .48954 Metetra
.664 .741 .907 r
.47551 .48954 .47645 .49052 .48197 .48877 .48103 .48779 Metetra
.941 .577 .27 r
.48103 .48779 .48197 .48877 .48751 .48701 .48632 .50818 Metetra
.416 .214 .495 r
.48632 .50818 .48751 .48701 .49306 .48526 .49212 .48427 Metetra
.664 .741 .907 r
.49212 .48427 .49306 .48526 .49861 .4835 .49768 .48251 Metetra
.664 .741 .907 r
.49768 .48251 .49861 .4835 .50418 .48173 .50326 .48074 Metetra
.664 .741 .907 r
.50326 .48074 .50418 .48173 .50977 .47996 .50884 .47897 Metetra
.664 .741 .907 r
.50884 .47897 .50977 .47996 .51536 .47819 .51443 .4772 Metetra
.664 .741 .907 r
.51443 .4772 .51536 .47819 .52096 .47641 .52004 .47542 Metetra
.664 .741 .907 r
.52004 .47542 .52096 .47641 .52658 .47464 .52566 .47364 Metetra
.664 .741 .907 r
.52566 .47364 .52658 .47464 .5322 .47285 .53129 .47186 Metetra
.664 .741 .907 r
.53129 .47186 .5322 .47285 .53784 .47107 .53693 .47007 Metetra
.664 .741 .907 r
.53693 .47007 .53784 .47107 .54349 .46928 .54258 .46828 Metetra
.664 .741 .907 r
.54258 .46828 .54349 .46928 .54916 .46748 .54825 .46648 Metetra
.664 .741 .907 r
.54825 .46648 .54916 .46748 .55483 .46568 .55392 .46468 Metetra
.664 .741 .907 r
.55392 .46468 .55483 .46568 .56051 .46388 .55961 .46288 Metetra
.664 .741 .907 r
.55961 .46288 .56051 .46388 .56621 .46208 .56531 .46107 Metetra
.585 .102 0 r
.56531 .46107 .56621 .46208 .57266 .51221 .57114 .46811 Metetra
.587 .379 .566 r
.57114 .46811 .57266 .51221 .57764 .45846 .57674 .45744 Metetra
.664 .741 .907 r
.57674 .45744 .57764 .45846 .58337 .45664 .58248 .45563 Metetra
.664 .741 .907 r
.58248 .45563 .58337 .45664 .58912 .45482 .58822 .4538 Metetra
.664 .741 .907 r
.58822 .4538 .58912 .45482 .59487 .453 .59398 .45198 Metetra
.664 .741 .907 r
.59398 .45198 .59487 .453 .60064 .45117 .59975 .45015 Metetra
.664 .741 .907 r
.59975 .45015 .60064 .45117 .60642 .44934 .60553 .44832 Metetra
.664 .741 .907 r
.60553 .44832 .60642 .44934 .61221 .4475 .61133 .44648 Metetra
.664 .741 .907 r
.61133 .44648 .61221 .4475 .61801 .44566 .61713 .44464 Metetra
.664 .741 .907 r
.61713 .44464 .61801 .44566 .62383 .44382 .62295 .44279 Metetra
.664 .741 .907 r
.62295 .44279 .62383 .44382 .62966 .44198 .62878 .44094 Metetra
.664 .741 .907 r
.62878 .44094 .62966 .44198 .6355 .44013 .63462 .43909 Metetra
.664 .741 .907 r
.63462 .43909 .6355 .44013 .64135 .43827 .64048 .43724 Metetra
.664 .741 .907 r
.64048 .43724 .64135 .43827 .64721 .43641 .64635 .43537 Metetra
.664 .741 .907 r
.64635 .43537 .64721 .43641 .65309 .43455 .65222 .43351 Metetra
.664 .741 .907 r
.65222 .43351 .65309 .43455 .65898 .43269 .65812 .43164 Metetra
.664 .741 .907 r
.65812 .43164 .65898 .43269 .66488 .43082 .66402 .42977 Metetra
.664 .741 .907 r
.66402 .42977 .66488 .43082 .6708 .42894 .66994 .42789 Metetra
.664 .741 .907 r
.66994 .42789 .6708 .42894 .67672 .42706 .67586 .42602 Metetra
.664 .741 .907 r
.67586 .42602 .67672 .42706 .68266 .42518 .68181 .42413 Metetra
.664 .741 .907 r
.68181 .42413 .68266 .42518 .68861 .4233 .68776 .42224 Metetra
.664 .741 .907 r
.68776 .42224 .68861 .4233 .69457 .42141 .69373 .42035 Metetra
.664 .741 .907 r
.69373 .42035 .69457 .42141 .70055 .41951 .6997 .41846 Metetra
.664 .741 .907 r
.6997 .41846 .70055 .41951 .70654 .41762 .7057 .41656 Metetra
.664 .741 .907 r
.7057 .41656 .70654 .41762 .71254 .41572 .7117 .41465 Metetra
.664 .741 .907 r
.7117 .41465 .71254 .41572 .71859 .4144 .71772 .41275 Metetra
.655 .644 .827 r
.71772 .41275 .71859 .4144 .72458 .4119 .72375 .41083 Metetra
.664 .741 .907 r
.72375 .41083 .72458 .4119 .73062 .40999 .72979 .40892 Metetra
.664 .741 .907 r
.72979 .40892 .73062 .40999 .73667 .40807 .73584 .407 Metetra
.664 .741 .907 r
.73584 .407 .73667 .40807 .74274 .40615 .74191 .40507 Metetra
.664 .741 .907 r
.74191 .40507 .74274 .40615 .74882 .40422 .74799 .40315 Metetra
.664 .741 .907 r
.74799 .40315 .74882 .40422 .75491 .40229 .75409 .40121 Metetra
.664 .741 .907 r
.75409 .40121 .75491 .40229 .76101 .40036 .76019 .39928 Metetra
.664 .741 .907 r
.76019 .39928 .76101 .40036 .76713 .39842 .76631 .39734 Metetra
.664 .741 .907 r
.76631 .39734 .76713 .39842 .77326 .39648 .77245 .39539 Metetra
.664 .741 .907 r
.77245 .39539 .77326 .39648 .7794 .39453 .77859 .39344 Metetra
.664 .741 .907 r
.77859 .39344 .7794 .39453 .78556 .39258 .78475 .39149 Metetra
.664 .741 .907 r
.78475 .39149 .78556 .39258 .79173 .39063 .79092 .38953 Metetra
.664 .741 .907 r
.79092 .38953 .79173 .39063 .79791 .38867 .79711 .38757 Metetra
.664 .741 .907 r
.79711 .38757 .79791 .38867 .80411 .3867 .80331 .38561 Metetra
.664 .741 .907 r
.80331 .38561 .80411 .3867 .81032 .38474 .80952 .38364 Metetra
.664 .741 .907 r
.80952 .38364 .81032 .38474 .81654 .38276 .81575 .38166 Metetra
.664 .741 .907 r
.81575 .38166 .81654 .38276 .82278 .38079 .82199 .37968 Metetra
.664 .741 .907 r
.82199 .37968 .82278 .38079 .82903 .37881 .82824 .3777 Metetra
.664 .741 .907 r
.82824 .3777 .82903 .37881 .83529 .37682 .83451 .37571 Metetra
.664 .741 .907 r
.83451 .37571 .83529 .37682 .84157 .37483 .84078 .37372 Metetra
.664 .741 .907 r
.84078 .37372 .84157 .37483 .84786 .37284 .84708 .37173 Metetra
.664 .741 .907 r
.84708 .37173 .84786 .37284 .85416 .37084 .85339 .36973 Metetra
.664 .741 .907 r
.85339 .36973 .85416 .37084 .86048 .36884 .85971 .36772 Metetra
.664 .741 .907 r
.85971 .36772 .86048 .36884 .86681 .36684 .86604 .36572 Metetra
.664 .741 .907 r
.86604 .36572 .86681 .36684 .87315 .36483 .87239 .3637 Metetra
.664 .741 .907 r
.87239 .3637 .87315 .36483 .87951 .36281 .87875 .36169 Metetra
.664 .741 .907 r
.87875 .36169 .87951 .36281 .88589 .36079 .88513 .35966 Metetra
.664 .741 .907 r
.88513 .35966 .88589 .36079 .89227 .35877 .89151 .35764 Metetra
.664 .741 .907 r
.89151 .35764 .89227 .35877 .89867 .35674 .89792 .35561 Metetra
.664 .741 .907 r
.89792 .35561 .89867 .35674 .90509 .35471 .90434 .35357 Metetra
.664 .741 .907 r
.90434 .35357 .90509 .35471 .91152 .35267 .91077 .35153 Metetra
.664 .741 .907 r
.91077 .35153 .91152 .35267 .91796 .35063 .91721 .34949 Metetra
.664 .741 .907 r
.33464 .53297 .33563 .53389 .34088 .53223 .33989 .5313 Metetra
.664 .741 .907 r
.33989 .5313 .34088 .53223 .34614 .53056 .34515 .52963 Metetra
.943 .612 .372 r
.34515 .52963 .34614 .53056 .35082 .54022 .34914 .55247 Metetra
.179 0 .384 r
.34914 .55247 .35082 .54022 .35668 .52722 .3557 .52628 Metetra
.664 .741 .907 r
.3557 .52628 .35668 .52722 .36197 .52554 .36099 .52461 Metetra
.664 .741 .907 r
.36099 .52461 .36197 .52554 .36727 .52386 .36629 .52292 Metetra
.664 .741 .907 r
.36629 .52292 .36727 .52386 .37258 .52218 .3716 .52124 Metetra
.664 .741 .907 r
.3716 .52124 .37258 .52218 .3779 .52049 .37692 .51955 Metetra
.664 .741 .907 r
.37692 .51955 .3779 .52049 .38323 .5188 .38225 .51786 Metetra
.664 .741 .907 r
.38225 .51786 .38323 .5188 .38857 .51711 .3876 .51616 Metetra
.664 .741 .907 r
.3876 .51616 .38857 .51711 .39392 .51541 .39295 .51446 Metetra
.664 .741 .907 r
.39295 .51446 .39392 .51541 .39929 .51371 .39832 .51276 Metetra
.664 .741 .907 r
.39832 .51276 .39929 .51371 .40466 .51201 .40369 .51105 Metetra
.664 .741 .907 r
.40369 .51105 .40466 .51201 .41004 .5103 .40908 .50935 Metetra
.664 .741 .907 r
.40908 .50935 .41004 .5103 .41544 .50859 .41448 .50763 Metetra
.664 .741 .907 r
.41448 .50763 .41544 .50859 .41992 .53649 .41988 .50592 Metetra
.563 .364 .569 r
.41988 .50592 .41992 .53649 .42568 .52478 .42524 .50637 Metetra
.587 .391 .583 r
.42524 .50637 .42568 .52478 .43169 .50344 .43073 .50247 Metetra
.664 .741 .907 r
.43073 .50247 .43169 .50344 .43713 .50171 .43617 .50075 Metetra
.952 .666 .459 r
.43617 .50075 .43713 .50171 .44258 .49998 .43962 .57912 Metetra
.43 .239 .518 r
.43962 .57912 .44258 .49998 .44804 .49825 .44709 .49729 Metetra
.664 .741 .907 r
.44709 .49729 .44804 .49825 .45351 .49652 .45256 .49555 Metetra
.664 .741 .907 r
.45256 .49555 .45351 .49652 .45899 .49478 .45805 .49381 Metetra
.664 .741 .907 r
.45805 .49381 .45899 .49478 .46449 .49304 .46354 .49206 Metetra
.664 .741 .907 r
.46354 .49206 .46449 .49304 .46999 .49129 .46905 .49032 Metetra
.664 .741 .907 r
.46905 .49032 .46999 .49129 .47551 .48954 .47457 .48857 Metetra
.664 .741 .907 r
.47457 .48857 .47551 .48954 .48103 .48779 .4801 .48681 Metetra
.664 .741 .907 r
.4801 .48681 .48103 .48779 .48632 .50818 .48564 .48505 Metetra
.573 .376 .576 r
.48564 .48505 .48632 .50818 .49212 .48427 .49119 .48329 Metetra
.664 .741 .907 r
.49119 .48329 .49212 .48427 .49768 .48251 .49675 .48153 Metetra
.664 .741 .907 r
.49675 .48153 .49768 .48251 .50326 .48074 .50233 .47976 Metetra
.664 .741 .907 r
.50233 .47976 .50326 .48074 .50884 .47897 .50791 .47799 Metetra
.664 .741 .907 r
.50791 .47799 .50884 .47897 .51443 .4772 .51351 .47621 Metetra
.664 .741 .907 r
.51351 .47621 .51443 .4772 .52004 .47542 .51912 .47443 Metetra
.664 .741 .907 r
.51912 .47443 .52004 .47542 .52566 .47364 .52474 .47265 Metetra
.664 .741 .907 r
.52474 .47265 .52566 .47364 .53129 .47186 .53037 .47086 Metetra
.664 .741 .907 r
.53037 .47086 .53129 .47186 .53693 .47007 .53601 .46907 Metetra
.664 .741 .907 r
.53601 .46907 .53693 .47007 .54258 .46828 .54167 .46727 Metetra
.664 .741 .907 r
.54167 .46727 .54258 .46828 .54825 .46648 .54733 .46548 Metetra
.664 .741 .907 r
.54733 .46548 .54825 .46648 .55392 .46468 .55301 .46367 Metetra
.664 .741 .907 r
.55301 .46367 .55392 .46468 .55961 .46288 .5587 .46187 Metetra
.664 .741 .907 r
.5587 .46187 .55961 .46288 .56531 .46107 .5644 .46006 Metetra
.664 .741 .907 r
.5644 .46006 .56531 .46107 .57114 .46811 .57012 .45825 Metetra
.586 .409 .609 r
.57012 .45825 .57114 .46811 .57674 .45744 .57584 .45643 Metetra
.664 .741 .907 r
.57584 .45643 .57674 .45744 .58248 .45563 .58158 .45461 Metetra
.664 .741 .907 r
.58158 .45461 .58248 .45563 .58822 .4538 .58733 .45279 Metetra
.664 .741 .907 r
.58733 .45279 .58822 .4538 .59398 .45198 .59309 .45096 Metetra
.664 .741 .907 r
.59309 .45096 .59398 .45198 .59975 .45015 .59886 .44913 Metetra
.664 .741 .907 r
.59886 .44913 .59975 .45015 .60553 .44832 .60464 .44729 Metetra
.955 .61 .296 r
.60464 .44729 .60553 .44832 .61133 .44648 .61136 .48047 Metetra
.433 .238 .515 r
.61136 .48047 .61133 .44648 .61713 .44464 .61625 .44361 Metetra
.664 .741 .907 r
.61625 .44361 .61713 .44464 .62295 .44279 .62207 .44176 Metetra
.664 .741 .907 r
.62207 .44176 .62295 .44279 .62878 .44094 .6279 .43991 Metetra
.664 .741 .907 r
.6279 .43991 .62878 .44094 .63462 .43909 .63375 .43806 Metetra
.664 .741 .907 r
.63375 .43806 .63462 .43909 .64048 .43724 .63961 .4362 Metetra
.664 .741 .907 r
.63961 .4362 .64048 .43724 .64635 .43537 .64548 .43434 Metetra
.664 .741 .907 r
.64548 .43434 .64635 .43537 .65222 .43351 .65136 .43247 Metetra
.664 .741 .907 r
.65136 .43247 .65222 .43351 .65812 .43164 .65725 .4306 Metetra
.664 .741 .907 r
.65725 .4306 .65812 .43164 .66402 .42977 .66316 .42873 Metetra
.664 .741 .907 r
.66316 .42873 .66402 .42977 .66994 .42789 .66908 .42685 Metetra
.664 .741 .907 r
.66908 .42685 .66994 .42789 .67586 .42602 .67501 .42496 Metetra
.664 .741 .907 r
.67501 .42496 .67586 .42602 .68181 .42413 .68095 .42308 Metetra
.664 .741 .907 r
.68095 .42308 .68181 .42413 .68776 .42224 .68691 .42119 Metetra
.664 .741 .907 r
.68691 .42119 .68776 .42224 .69373 .42035 .69288 .4193 Metetra
.664 .741 .907 r
.69288 .4193 .69373 .42035 .6997 .41846 .69886 .4174 Metetra
.664 .741 .907 r
.69886 .4174 .6997 .41846 .7057 .41656 .70485 .4155 Metetra
.664 .741 .907 r
.70485 .4155 .7057 .41656 .7117 .41465 .71086 .41359 Metetra
.664 .741 .907 r
.71086 .41359 .7117 .41465 .71772 .41275 .71688 .41168 Metetra
.664 .741 .907 r
.71688 .41168 .71772 .41275 .72375 .41083 .72291 .40977 Metetra
.664 .741 .907 r
.72291 .40977 .72375 .41083 .72979 .40892 .72896 .40785 Metetra
.664 .741 .907 r
.72896 .40785 .72979 .40892 .73584 .407 .73501 .40592 Metetra
.664 .741 .907 r
.73501 .40592 .73584 .407 .74191 .40507 .74108 .404 Metetra
.664 .741 .907 r
.74108 .404 .74191 .40507 .74799 .40315 .74717 .40207 Metetra
.664 .741 .907 r
.74717 .40207 .74799 .40315 .75409 .40121 .75326 .40013 Metetra
.664 .741 .907 r
.75326 .40013 .75409 .40121 .76019 .39928 .75937 .3982 Metetra
.664 .741 .907 r
.75937 .3982 .76019 .39928 .76631 .39734 .7655 .39625 Metetra
.664 .741 .907 r
.7655 .39625 .76631 .39734 .77245 .39539 .77163 .39431 Metetra
.664 .741 .907 r
.77163 .39431 .77245 .39539 .77859 .39344 .77778 .39235 Metetra
.664 .741 .907 r
.77778 .39235 .77859 .39344 .78475 .39149 .78394 .3904 Metetra
.288 .548 .922 r
.78394 .3904 .78475 .39149 .79092 .38953 .79045 .39246 Metetra
.292 .001 .287 r
.79045 .39246 .79092 .38953 .79711 .38757 .79631 .38648 Metetra
.664 .741 .907 r
.79631 .38648 .79711 .38757 .80331 .38561 .80251 .38451 Metetra
.664 .741 .907 r
.80251 .38451 .80331 .38561 .80952 .38364 .80872 .38254 Metetra
.664 .741 .907 r
.80872 .38254 .80952 .38364 .81575 .38166 .81495 .38056 Metetra
.664 .741 .907 r
.81495 .38056 .81575 .38166 .82199 .37968 .8212 .37858 Metetra
.664 .741 .907 r
.8212 .37858 .82199 .37968 .82824 .3777 .82745 .37659 Metetra
.664 .741 .907 r
.82745 .37659 .82824 .3777 .83451 .37571 .83372 .3746 Metetra
.664 .741 .907 r
.83372 .3746 .83451 .37571 .84078 .37372 .84 .37261 Metetra
.664 .741 .907 r
.84 .37261 .84078 .37372 .84708 .37173 .8463 .37061 Metetra
.664 .741 .907 r
.8463 .37061 .84708 .37173 .85339 .36973 .85261 .36861 Metetra
.664 .741 .907 r
.85261 .36861 .85339 .36973 .85971 .36772 .85893 .3666 Metetra
.664 .741 .907 r
.85893 .3666 .85971 .36772 .86604 .36572 .86527 .36459 Metetra
.664 .741 .907 r
.86527 .36459 .86604 .36572 .87239 .3637 .87162 .36258 Metetra
.664 .741 .907 r
.87162 .36258 .87239 .3637 .87875 .36169 .87798 .36056 Metetra
.664 .741 .907 r
.87798 .36056 .87875 .36169 .88513 .35966 .88436 .35854 Metetra
.664 .741 .907 r
.88436 .35854 .88513 .35966 .89151 .35764 .89076 .35651 Metetra
.664 .741 .907 r
.89076 .35651 .89151 .35764 .89792 .35561 .89716 .35447 Metetra
.664 .741 .907 r
.89716 .35447 .89792 .35561 .90434 .35357 .90358 .35244 Metetra
.664 .741 .907 r
.90358 .35244 .90434 .35357 .91077 .35153 .91002 .3504 Metetra
.664 .741 .907 r
.91002 .3504 .91077 .35153 .91721 .34949 .91647 .34835 Metetra
.664 .741 .907 r
.33364 .53204 .33464 .53297 .33989 .5313 .3389 .53037 Metetra
.664 .741 .907 r
.3389 .53037 .33989 .5313 .34515 .52963 .34416 .5287 Metetra
.664 .741 .907 r
.34416 .5287 .34515 .52963 .34914 .55247 .34943 .52703 Metetra
.571 .373 .573 r
.34943 .52703 .34914 .55247 .3557 .52628 .35471 .52535 Metetra
.664 .741 .907 r
.35471 .52535 .3557 .52628 .36099 .52461 .36 .52367 Metetra
.664 .741 .907 r
.36 .52367 .36099 .52461 .36629 .52292 .36531 .52198 Metetra
.664 .741 .907 r
.36531 .52198 .36629 .52292 .3716 .52124 .37062 .5203 Metetra
.664 .741 .907 r
.37062 .5203 .3716 .52124 .37692 .51955 .37594 .51861 Metetra
.664 .741 .907 r
.37594 .51861 .37692 .51955 .38225 .51786 .38128 .51691 Metetra
.664 .741 .907 r
.38128 .51691 .38225 .51786 .3876 .51616 .38662 .51521 Metetra
.664 .741 .907 r
.38662 .51521 .3876 .51616 .39295 .51446 .39198 .51351 Metetra
.664 .741 .907 r
.39198 .51351 .39295 .51446 .39832 .51276 .39735 .51181 Metetra
.664 .741 .907 r
.39735 .51181 .39832 .51276 .40369 .51105 .40272 .5101 Metetra
.664 .741 .907 r
.40272 .5101 .40369 .51105 .40908 .50935 .40811 .50839 Metetra
.664 .741 .907 r
.40811 .50839 .40908 .50935 .41448 .50763 .41351 .50668 Metetra
.664 .741 .907 r
.41351 .50668 .41448 .50763 .41988 .50592 .41892 .50496 Metetra
.664 .741 .907 r
.41892 .50496 .41988 .50592 .42524 .50637 .42434 .50324 Metetra
.624 .517 .712 r
.42434 .50324 .42524 .50637 .43073 .50247 .42977 .50151 Metetra
.952 .661 .448 r
.42977 .50151 .43073 .50247 .43617 .50075 .4335 .56342 Metetra
.718 .475 .557 r
.4335 .56342 .43617 .50075 .43962 .57912 .4351 .71767 Metetra
.323 .157 .494 r
.4351 .71767 .43962 .57912 .44709 .49729 .44614 .49632 Metetra
.664 .741 .907 r
.44614 .49632 .44709 .49729 .45256 .49555 .45161 .49458 Metetra
.664 .741 .907 r
.45161 .49458 .45256 .49555 .45805 .49381 .4571 .49284 Metetra
.664 .741 .907 r
.4571 .49284 .45805 .49381 .46354 .49206 .4626 .49109 Metetra
.664 .741 .907 r
.4626 .49109 .46354 .49206 .46905 .49032 .46811 .48934 Metetra
.664 .741 .907 r
.46811 .48934 .46905 .49032 .47457 .48857 .47363 .48759 Metetra
.664 .741 .907 r
.47363 .48759 .47457 .48857 .4801 .48681 .47916 .48583 Metetra
.664 .741 .907 r
.47916 .48583 .4801 .48681 .48564 .48505 .4847 .48407 Metetra
.664 .741 .907 r
.4847 .48407 .48564 .48505 .49119 .48329 .49025 .48231 Metetra
.664 .741 .907 r
.49025 .48231 .49119 .48329 .49675 .48153 .49582 .48054 Metetra
.664 .741 .907 r
.49582 .48054 .49675 .48153 .50233 .47976 .5014 .47877 Metetra
.664 .741 .907 r
.5014 .47877 .50233 .47976 .50791 .47799 .50698 .477 Metetra
.664 .741 .907 r
.50698 .477 .50791 .47799 .51351 .47621 .51258 .47522 Metetra
.664 .741 .907 r
.51258 .47522 .51351 .47621 .51912 .47443 .51819 .47344 Metetra
.664 .741 .907 r
.51819 .47344 .51912 .47443 .52474 .47265 .52382 .47165 Metetra
.664 .741 .907 r
.52382 .47165 .52474 .47265 .53037 .47086 .52945 .46986 Metetra
.664 .741 .907 r
.52945 .46986 .53037 .47086 .53601 .46907 .5351 .46807 Metetra
.664 .741 .907 r
.5351 .46807 .53601 .46907 .54167 .46727 .54075 .46627 Metetra
.664 .741 .907 r
.54075 .46627 .54167 .46727 .54733 .46548 .54642 .46447 Metetra
.664 .741 .907 r
.54642 .46447 .54733 .46548 .55301 .46367 .5521 .46267 Metetra
.664 .741 .907 r
.5521 .46267 .55301 .46367 .5587 .46187 .55779 .46086 Metetra
.664 .741 .907 r
.55779 .46086 .5587 .46187 .5644 .46006 .5635 .45905 Metetra
.664 .741 .907 r
.5635 .45905 .5644 .46006 .57012 .45825 .56921 .45723 Metetra
.664 .741 .907 r
.56921 .45723 .57012 .45825 .57584 .45643 .57494 .45542 Metetra
.664 .741 .907 r
.57494 .45542 .57584 .45643 .58158 .45461 .58068 .45359 Metetra
.664 .741 .907 r
.58068 .45359 .58158 .45461 .58733 .45279 .58643 .45177 Metetra
.664 .741 .907 r
.58643 .45177 .58733 .45279 .59309 .45096 .59219 .44994 Metetra
.664 .741 .907 r
.59219 .44994 .59309 .45096 .59886 .44913 .59797 .4481 Metetra
.664 .741 .907 r
.59797 .4481 .59886 .44913 .60464 .44729 .60376 .44627 Metetra
.965 .656 .386 r
.60376 .44627 .60464 .44729 .61136 .48047 .61149 .519 Metetra
.286 .127 .483 r
.61149 .519 .61136 .48047 .61625 .44361 .61537 .44258 Metetra
.664 .741 .907 r
.61537 .44258 .61625 .44361 .62207 .44176 .62119 .44073 Metetra
.664 .741 .907 r
.62119 .44073 .62207 .44176 .6279 .43991 .62702 .43888 Metetra
.664 .741 .907 r
.62702 .43888 .6279 .43991 .63375 .43806 .63287 .43702 Metetra
.664 .741 .907 r
.63287 .43702 .63375 .43806 .63961 .4362 .63873 .43516 Metetra
.664 .741 .907 r
.63873 .43516 .63961 .4362 .64548 .43434 .6446 .4333 Metetra
.664 .741 .907 r
.6446 .4333 .64548 .43434 .65136 .43247 .65049 .43143 Metetra
.664 .741 .907 r
.65049 .43143 .65136 .43247 .65725 .4306 .65639 .42955 Metetra
.664 .741 .907 r
.65639 .42955 .65725 .4306 .66316 .42873 .66229 .42768 Metetra
.664 .741 .907 r
.66229 .42768 .66316 .42873 .66908 .42685 .66822 .4258 Metetra
.664 .741 .907 r
.66822 .4258 .66908 .42685 .67501 .42496 .67415 .42391 Metetra
.664 .741 .907 r
.67415 .42391 .67501 .42496 .68095 .42308 .6801 .42203 Metetra
.664 .741 .907 r
.6801 .42203 .68095 .42308 .68691 .42119 .68605 .42013 Metetra
.664 .741 .907 r
.68605 .42013 .68691 .42119 .69288 .4193 .69203 .41824 Metetra
.664 .741 .907 r
.69203 .41824 .69288 .4193 .69886 .4174 .69801 .41634 Metetra
.664 .741 .907 r
.69801 .41634 .69886 .4174 .70485 .4155 .70401 .41443 Metetra
.664 .741 .907 r
.70401 .41443 .70485 .4155 .71086 .41359 .71002 .41252 Metetra
.664 .741 .907 r
.71002 .41252 .71086 .41359 .71688 .41168 .71604 .41061 Metetra
.664 .741 .907 r
.71604 .41061 .71688 .41168 .72291 .40977 .72207 .4087 Metetra
.664 .741 .907 r
.72207 .4087 .72291 .40977 .72896 .40785 .72812 .40678 Metetra
.664 .741 .907 r
.72812 .40678 .72896 .40785 .73501 .40592 .73418 .40485 Metetra
.664 .741 .907 r
.73418 .40485 .73501 .40592 .74108 .404 .74025 .40292 Metetra
.664 .741 .907 r
.74025 .40292 .74108 .404 .74717 .40207 .74634 .40099 Metetra
.664 .741 .907 r
.74634 .40099 .74717 .40207 .75326 .40013 .75244 .39905 Metetra
.664 .741 .907 r
.75244 .39905 .75326 .40013 .75937 .3982 .75855 .39711 Metetra
.664 .741 .907 r
.75855 .39711 .75937 .3982 .7655 .39625 .76468 .39517 Metetra
.664 .741 .907 r
.76468 .39517 .7655 .39625 .77163 .39431 .77082 .39322 Metetra
0 0 .444 r
.77082 .39322 .77163 .39431 .77778 .39235 .77784 .40233 Metetra
.411 .194 .471 r
.77784 .40233 .77778 .39235 .78394 .3904 .78313 .38931 Metetra
.948 .595 .218 r
.78313 .38931 .78394 .3904 .79045 .39246 .79308 .43304 Metetra
.434 .246 .524 r
.79308 .43304 .79045 .39246 .79631 .38648 .7955 .38538 Metetra
.664 .741 .907 r
.7955 .38538 .79631 .38648 .80251 .38451 .80171 .38341 Metetra
.664 .741 .907 r
.80171 .38341 .80251 .38451 .80872 .38254 .80793 .38143 Metetra
.664 .741 .907 r
.80793 .38143 .80872 .38254 .81495 .38056 .81416 .37946 Metetra
.664 .741 .907 r
.81416 .37946 .81495 .38056 .8212 .37858 .8204 .37747 Metetra
.664 .741 .907 r
.8204 .37747 .8212 .37858 .82745 .37659 .82666 .37549 Metetra
.664 .741 .907 r
.82666 .37549 .82745 .37659 .83372 .3746 .83293 .37349 Metetra
.664 .741 .907 r
.83293 .37349 .83372 .3746 .84 .37261 .83922 .3715 Metetra
.664 .741 .907 r
.83922 .3715 .84 .37261 .8463 .37061 .84552 .3695 Metetra
.664 .741 .907 r
.84552 .3695 .8463 .37061 .85261 .36861 .85183 .36749 Metetra
.664 .741 .907 r
.85183 .36749 .85261 .36861 .85893 .3666 .85816 .36548 Metetra
.664 .741 .907 r
.85816 .36548 .85893 .3666 .86527 .36459 .8645 .36347 Metetra
.664 .741 .907 r
.8645 .36347 .86527 .36459 .87162 .36258 .87085 .36145 Metetra
.664 .741 .907 r
.87085 .36145 .87162 .36258 .87798 .36056 .87722 .35943 Metetra
.664 .741 .907 r
.87722 .35943 .87798 .36056 .88436 .35854 .8836 .3574 Metetra
.664 .741 .907 r
.8836 .3574 .88436 .35854 .89076 .35651 .89 .35537 Metetra
.664 .741 .907 r
.89 .35537 .89076 .35651 .89716 .35447 .89641 .35334 Metetra
.664 .741 .907 r
.89641 .35334 .89716 .35447 .90358 .35244 .90283 .3513 Metetra
.664 .741 .907 r
.90283 .3513 .90358 .35244 .91002 .3504 .90927 .34925 Metetra
.664 .741 .907 r
.90927 .34925 .91002 .3504 .91647 .34835 .91572 .34721 Metetra
.664 .741 .907 r
.33265 .53111 .33364 .53204 .3389 .53037 .3379 .52944 Metetra
.664 .741 .907 r
.3379 .52944 .3389 .53037 .34416 .5287 .34316 .52777 Metetra
.664 .741 .907 r
.34316 .52777 .34416 .5287 .34943 .52703 .34844 .52609 Metetra
.664 .741 .907 r
.34844 .52609 .34943 .52703 .35471 .52535 .35372 .52441 Metetra
.889 .463 .11 r
.35372 .52441 .35471 .52535 .36 .52367 .35841 .53491 Metetra
.382 .163 .452 r
.35841 .53491 .36 .52367 .36531 .52198 .36432 .52104 Metetra
.664 .741 .907 r
.36432 .52104 .36531 .52198 .37062 .5203 .36964 .51935 Metetra
.664 .741 .907 r
.36964 .51935 .37062 .5203 .37594 .51861 .37496 .51766 Metetra
.664 .741 .907 r
.37496 .51766 .37594 .51861 .38128 .51691 .3803 .51597 Metetra
.664 .741 .907 r
.3803 .51597 .38128 .51691 .38662 .51521 .38565 .51427 Metetra
.664 .741 .907 r
.38565 .51427 .38662 .51521 .39198 .51351 .39101 .51256 Metetra
.664 .741 .907 r
.39101 .51256 .39198 .51351 .39735 .51181 .39638 .51086 Metetra
.664 .741 .907 r
.39638 .51086 .39735 .51181 .40272 .5101 .40175 .50915 Metetra
.664 .741 .907 r
.40175 .50915 .40272 .5101 .40811 .50839 .40715 .50743 Metetra
.664 .741 .907 r
.40715 .50743 .40811 .50839 .41351 .50668 .41255 .50572 Metetra
.664 .741 .907 r
.41255 .50572 .41351 .50668 .41892 .50496 .41796 .504 Metetra
.664 .741 .907 r
.41796 .504 .41892 .50496 .42434 .50324 .42338 .50228 Metetra
.664 .741 .907 r
.42338 .50228 .42434 .50324 .42977 .50151 .42882 .50055 Metetra
.951 .673 .475 r
.42882 .50055 .42977 .50151 .4335 .56342 .43115 .61271 Metetra
.647 .413 .55 r
.43115 .61271 .4335 .56342 .4351 .71767 .43541 .66508 Metetra
.762 .522 .569 r
.43541 .66508 .4351 .71767 .44614 .49632 .44518 .49535 Metetra
.664 .741 .907 r
.44518 .49535 .44614 .49632 .45161 .49458 .45066 .49361 Metetra
.664 .741 .907 r
.45066 .49361 .45161 .49458 .4571 .49284 .45615 .49186 Metetra
.664 .741 .907 r
.45615 .49186 .4571 .49284 .4626 .49109 .46165 .49011 Metetra
.664 .741 .907 r
.46165 .49011 .4626 .49109 .46811 .48934 .46716 .48836 Metetra
.664 .741 .907 r
.46716 .48836 .46811 .48934 .47363 .48759 .47268 .48661 Metetra
.664 .741 .907 r
.47268 .48661 .47363 .48759 .47916 .48583 .47822 .48485 Metetra
.664 .741 .907 r
.47822 .48485 .47916 .48583 .4847 .48407 .48376 .48309 Metetra
.664 .741 .907 r
.48376 .48309 .4847 .48407 .49025 .48231 .48932 .48132 Metetra
.664 .741 .907 r
.48932 .48132 .49025 .48231 .49582 .48054 .49489 .47955 Metetra
.664 .741 .907 r
.49489 .47955 .49582 .48054 .5014 .47877 .50046 .47778 Metetra
.664 .741 .907 r
.50046 .47778 .5014 .47877 .50698 .477 .50606 .476 Metetra
.664 .741 .907 r
.50606 .476 .50698 .477 .51258 .47522 .51166 .47422 Metetra
.664 .741 .907 r
.51166 .47422 .51258 .47522 .51819 .47344 .51727 .47244 Metetra
.664 .741 .907 r
.51727 .47244 .51819 .47344 .52382 .47165 .52289 .47065 Metetra
.664 .741 .907 r
.52289 .47065 .52382 .47165 .52945 .46986 .52853 .46886 Metetra
.664 .741 .907 r
.52853 .46886 .52945 .46986 .5351 .46807 .53418 .46707 Metetra
.664 .741 .907 r
.53418 .46707 .5351 .46807 .54075 .46627 .53984 .46527 Metetra
.664 .741 .907 r
.53984 .46527 .54075 .46627 .54642 .46447 .54551 .46347 Metetra
.664 .741 .907 r
.54551 .46347 .54642 .46447 .5521 .46267 .55119 .46166 Metetra
.664 .741 .907 r
.55119 .46166 .5521 .46267 .55779 .46086 .55689 .45985 Metetra
.664 .741 .907 r
.55689 .45985 .55779 .46086 .5635 .45905 .56259 .45804 Metetra
.664 .741 .907 r
.56259 .45804 .5635 .45905 .56921 .45723 .56831 .45622 Metetra
.664 .741 .907 r
.56831 .45622 .56921 .45723 .57494 .45542 .57404 .4544 Metetra
.664 .741 .907 r
.57404 .4544 .57494 .45542 .58068 .45359 .57978 .45258 Metetra
.664 .741 .907 r
.57978 .45258 .58068 .45359 .58643 .45177 .58553 .45075 Metetra
.664 .741 .907 r
.58553 .45075 .58643 .45177 .59219 .44994 .5913 .44892 Metetra
.664 .741 .907 r
.5913 .44892 .59219 .44994 .59797 .4481 .59708 .44708 Metetra
.933 .555 .199 r
.59708 .44708 .59797 .4481 .60376 .44627 .60343 .46865 Metetra
.616 .376 .531 r
.60343 .46865 .60376 .44627 .61149 .519 .6097 .48364 Metetra
.661 .438 .57 r
.6097 .48364 .61149 .519 .61537 .44258 .61448 .44155 Metetra
.664 .741 .907 r
.61448 .44155 .61537 .44258 .62119 .44073 .62031 .4397 Metetra
.664 .741 .907 r
.62031 .4397 .62119 .44073 .62702 .43888 .62615 .43784 Metetra
.664 .741 .907 r
.62615 .43784 .62702 .43888 .63287 .43702 .632 .43598 Metetra
.664 .741 .907 r
.632 .43598 .63287 .43702 .63873 .43516 .63786 .43412 Metetra
.664 .741 .907 r
.63786 .43412 .63873 .43516 .6446 .4333 .64373 .43225 Metetra
.664 .741 .907 r
.64373 .43225 .6446 .4333 .65049 .43143 .64962 .43038 Metetra
.664 .741 .907 r
.64962 .43038 .65049 .43143 .65639 .42955 .65552 .42851 Metetra
.664 .741 .907 r
.65552 .42851 .65639 .42955 .66229 .42768 .66143 .42663 Metetra
.664 .741 .907 r
.66143 .42663 .66229 .42768 .66822 .4258 .66735 .42475 Metetra
.664 .741 .907 r
.66735 .42475 .66822 .4258 .67415 .42391 .67329 .42286 Metetra
.664 .741 .907 r
.67329 .42286 .67415 .42391 .6801 .42203 .67924 .42097 Metetra
.664 .741 .907 r
.67924 .42097 .6801 .42203 .68605 .42013 .6852 .41908 Metetra
.664 .741 .907 r
.6852 .41908 .68605 .42013 .69203 .41824 .69117 .41718 Metetra
.664 .741 .907 r
.69117 .41718 .69203 .41824 .69801 .41634 .69716 .41528 Metetra
.664 .741 .907 r
.69716 .41528 .69801 .41634 .70401 .41443 .70316 .41337 Metetra
.664 .741 .907 r
.70316 .41337 .70401 .41443 .71002 .41252 .70917 .41146 Metetra
.664 .741 .907 r
.70917 .41146 .71002 .41252 .71604 .41061 .7152 .40954 Metetra
.664 .741 .907 r
.7152 .40954 .71604 .41061 .72207 .4087 .72123 .40763 Metetra
.664 .741 .907 r
.72123 .40763 .72207 .4087 .72812 .40678 .72729 .4057 Metetra
.664 .741 .907 r
.72729 .4057 .72812 .40678 .73418 .40485 .73335 .40378 Metetra
.664 .741 .907 r
.73335 .40378 .73418 .40485 .74025 .40292 .73942 .40184 Metetra
.664 .741 .907 r
.73942 .40184 .74025 .40292 .74634 .40099 .74551 .39991 Metetra
.664 .741 .907 r
.74551 .39991 .74634 .40099 .75244 .39905 .75162 .39797 Metetra
.664 .741 .907 r
.75162 .39797 .75244 .39905 .75855 .39711 .75773 .39603 Metetra
.664 .741 .907 r
.75773 .39603 .75855 .39711 .76468 .39517 .76386 .39408 Metetra
.664 .741 .907 r
.76386 .39408 .76468 .39517 .77082 .39322 .77 .39213 Metetra
.947 .592 .216 r
.77 .39213 .77082 .39322 .77784 .40233 .77951 .43306 Metetra
.395 .213 .512 r
.77951 .43306 .77784 .40233 .78313 .38931 .78232 .38821 Metetra
.664 .741 .907 r
.78232 .38821 .78313 .38931 .79308 .43304 .7885 .38625 Metetra
.567 .363 .564 r
.7885 .38625 .79308 .43304 .7955 .38538 .7947 .38428 Metetra
.664 .741 .907 r
.7947 .38428 .7955 .38538 .80171 .38341 .80091 .38231 Metetra
.664 .741 .907 r
.80091 .38231 .80171 .38341 .80793 .38143 .80713 .38033 Metetra
.664 .741 .907 r
.80713 .38033 .80793 .38143 .81416 .37946 .81336 .37835 Metetra
.664 .741 .907 r
.81336 .37835 .81416 .37946 .8204 .37747 .81961 .37636 Metetra
.664 .741 .907 r
.81961 .37636 .8204 .37747 .82666 .37549 .82587 .37437 Metetra
.664 .741 .907 r
.82587 .37437 .82666 .37549 .83293 .37349 .83215 .37238 Metetra
.664 .741 .907 r
.83215 .37238 .83293 .37349 .83922 .3715 .83843 .37038 Metetra
.664 .741 .907 r
.83843 .37038 .83922 .3715 .84552 .3695 .84474 .36838 Metetra
.664 .741 .907 r
.84474 .36838 .84552 .3695 .85183 .36749 .85105 .36637 Metetra
.664 .741 .907 r
.85105 .36637 .85183 .36749 .85816 .36548 .85738 .36436 Metetra
.664 .741 .907 r
.85738 .36436 .85816 .36548 .8645 .36347 .86372 .36235 Metetra
.664 .741 .907 r
.86372 .36235 .8645 .36347 .87085 .36145 .87008 .36033 Metetra
.664 .741 .907 r
.87008 .36033 .87085 .36145 .87722 .35943 .87645 .3583 Metetra
.664 .741 .907 r
.87645 .3583 .87722 .35943 .8836 .3574 .88284 .35627 Metetra
.664 .741 .907 r
.88284 .35627 .8836 .3574 .89 .35537 .88924 .35424 Metetra
.664 .741 .907 r
.88924 .35424 .89 .35537 .89641 .35334 .89565 .3522 Metetra
.664 .741 .907 r
.89565 .3522 .89641 .35334 .90283 .3513 .90208 .35016 Metetra
.664 .741 .907 r
.90208 .35016 .90283 .3513 .90927 .34925 .90852 .34811 Metetra
.664 .741 .907 r
.90852 .34811 .90927 .34925 .91572 .34721 .91497 .34606 Metetra
.664 .741 .907 r
.33165 .53018 .33265 .53111 .3379 .52944 .33691 .52851 Metetra
.664 .741 .907 r
.33691 .52851 .3379 .52944 .34316 .52777 .34217 .52683 Metetra
.664 .741 .907 r
.34217 .52683 .34316 .52777 .34844 .52609 .34745 .52515 Metetra
.664 .741 .907 r
.34745 .52515 .34844 .52609 .35372 .52441 .35273 .52347 Metetra
.919 .525 .212 r
.35273 .52347 .35372 .52441 .35841 .53491 .35729 .53656 Metetra
.977 .91 .582 r
.35729 .53656 .35841 .53491 .36432 .52104 .36334 .5201 Metetra
.664 .741 .907 r
.36334 .5201 .36432 .52104 .36964 .51935 .36865 .51841 Metetra
.664 .741 .907 r
.36865 .51841 .36964 .51935 .37496 .51766 .37398 .51672 Metetra
.664 .741 .907 r
.37398 .51672 .37496 .51766 .3803 .51597 .37932 .51502 Metetra
.664 .741 .907 r
.37932 .51502 .3803 .51597 .38565 .51427 .38467 .51332 Metetra
.664 .741 .907 r
.38467 .51332 .38565 .51427 .39101 .51256 .39003 .51161 Metetra
.664 .741 .907 r
.39003 .51161 .39101 .51256 .39638 .51086 .3954 .5099 Metetra
.664 .741 .907 r
.3954 .5099 .39638 .51086 .40175 .50915 .40078 .50819 Metetra
.664 .741 .907 r
.40078 .50819 .40175 .50915 .40715 .50743 .40618 .50648 Metetra
.664 .741 .907 r
.40618 .50648 .40715 .50743 .41255 .50572 .41158 .50476 Metetra
.664 .741 .907 r
.41158 .50476 .41255 .50572 .41796 .504 .41699 .50304 Metetra
.664 .741 .907 r
.41699 .50304 .41796 .504 .42338 .50228 .42242 .50131 Metetra
.664 .741 .907 r
.42242 .50131 .42338 .50228 .42882 .50055 .42785 .49958 Metetra
.951 .669 .467 r
.42785 .49958 .42882 .50055 .43115 .61271 .4308 .58863 Metetra
.599 .396 .578 r
.4308 .58863 .43115 .61271 .43541 .66508 .43658 .58009 Metetra
.651 .427 .566 r
.43658 .58009 .43541 .66508 .44518 .49535 .44423 .49438 Metetra
.664 .741 .907 r
.44423 .49438 .44518 .49535 .45066 .49361 .44971 .49263 Metetra
.664 .741 .907 r
.44971 .49263 .45066 .49361 .45615 .49186 .4552 .49089 Metetra
.664 .741 .907 r
.4552 .49089 .45615 .49186 .46165 .49011 .4607 .48914 Metetra
.664 .741 .907 r
.4607 .48914 .46165 .49011 .46716 .48836 .46622 .48738 Metetra
.664 .741 .907 r
.46622 .48738 .46716 .48836 .47268 .48661 .47174 .48563 Metetra
.664 .741 .907 r
.47174 .48563 .47268 .48661 .47822 .48485 .47728 .48387 Metetra
.664 .741 .907 r
.47728 .48387 .47822 .48485 .48376 .48309 .48282 .4821 Metetra
.664 .741 .907 r
.48282 .4821 .48376 .48309 .48932 .48132 .48838 .48034 Metetra
.664 .741 .907 r
.48838 .48034 .48932 .48132 .49489 .47955 .49395 .47856 Metetra
.664 .741 .907 r
.49395 .47856 .49489 .47955 .50046 .47778 .49953 .47679 Metetra
.664 .741 .907 r
.49953 .47679 .50046 .47778 .50606 .476 .50512 .47501 Metetra
.664 .741 .907 r
.50512 .47501 .50606 .476 .51166 .47422 .51073 .47323 Metetra
.664 .741 .907 r
.51073 .47323 .51166 .47422 .51727 .47244 .51634 .47144 Metetra
.664 .741 .907 r
.51634 .47144 .51727 .47244 .52289 .47065 .52197 .46965 Metetra
.664 .741 .907 r
.52197 .46965 .52289 .47065 .52853 .46886 .52761 .46786 Metetra
.664 .741 .907 r
.52761 .46786 .52853 .46886 .53418 .46707 .53326 .46606 Metetra
.664 .741 .907 r
.53326 .46606 .53418 .46707 .53984 .46527 .53892 .46426 Metetra
.664 .741 .907 r
.53892 .46426 .53984 .46527 .54551 .46347 .54459 .46246 Metetra
.664 .741 .907 r
.54459 .46246 .54551 .46347 .55119 .46166 .55028 .46065 Metetra
.664 .741 .907 r
.55028 .46065 .55119 .46166 .55689 .45985 .55598 .45884 Metetra
.664 .741 .907 r
.55598 .45884 .55689 .45985 .56259 .45804 .56168 .45702 Metetra
.664 .741 .907 r
.56168 .45702 .56259 .45804 .56831 .45622 .56741 .45521 Metetra
.664 .741 .907 r
.56741 .45521 .56831 .45622 .57404 .4544 .57314 .45338 Metetra
.664 .741 .907 r
.57314 .45338 .57404 .4544 .57978 .45258 .57888 .45156 Metetra
.664 .741 .907 r
.57888 .45156 .57978 .45258 .58553 .45075 .58464 .44973 Metetra
.664 .741 .907 r
.58464 .44973 .58553 .45075 .5913 .44892 .5904 .44789 Metetra
.664 .741 .907 r
.5904 .44789 .5913 .44892 .59708 .44708 .59618 .44605 Metetra
0 0 .479 r
.59618 .44605 .59708 .44708 .60343 .46865 .60218 .45281 Metetra
.573 .384 .587 r
.60218 .45281 .60343 .46865 .6097 .48364 .60802 .45162 Metetra
.596 .389 .57 r
.60802 .45162 .6097 .48364 .61448 .44155 .6136 .44052 Metetra
.664 .741 .907 r
.6136 .44052 .61448 .44155 .62031 .4397 .61942 .43866 Metetra
.664 .741 .907 r
.61942 .43866 .62031 .4397 .62615 .43784 .62526 .43681 Metetra
.664 .741 .907 r
.62526 .43681 .62615 .43784 .632 .43598 .63112 .43494 Metetra
.664 .741 .907 r
.63112 .43494 .632 .43598 .63786 .43412 .63698 .43308 Metetra
.664 .741 .907 r
.63698 .43308 .63786 .43412 .64373 .43225 .64286 .43121 Metetra
.664 .741 .907 r
.64286 .43121 .64373 .43225 .64962 .43038 .64875 .42934 Metetra
.664 .741 .907 r
.64875 .42934 .64962 .43038 .65552 .42851 .65465 .42746 Metetra
.664 .741 .907 r
.65465 .42746 .65552 .42851 .66143 .42663 .66056 .42558 Metetra
.664 .741 .907 r
.66056 .42558 .66143 .42663 .66735 .42475 .66649 .4237 Metetra
.664 .741 .907 r
.66649 .4237 .66735 .42475 .67329 .42286 .67243 .42181 Metetra
.664 .741 .907 r
.67243 .42181 .67329 .42286 .67924 .42097 .67838 .41991 Metetra
.664 .741 .907 r
.67838 .41991 .67924 .42097 .6852 .41908 .68435 .41802 Metetra
.664 .741 .907 r
.68435 .41802 .6852 .41908 .69117 .41718 .69032 .41612 Metetra
.664 .741 .907 r
.69032 .41612 .69117 .41718 .69716 .41528 .69631 .41421 Metetra
.664 .741 .907 r
.69631 .41421 .69716 .41528 .70316 .41337 .70231 .4123 Metetra
.664 .741 .907 r
.70231 .4123 .70316 .41337 .70917 .41146 .70833 .41039 Metetra
.664 .741 .907 r
.70833 .41039 .70917 .41146 .7152 .40954 .71436 .40847 Metetra
.664 .741 .907 r
.71436 .40847 .7152 .40954 .72123 .40763 .7204 .40655 Metetra
.664 .741 .907 r
.7204 .40655 .72123 .40763 .72729 .4057 .72645 .40463 Metetra
.664 .741 .907 r
.72645 .40463 .72729 .4057 .73335 .40378 .73251 .4027 Metetra
.664 .741 .907 r
.73251 .4027 .73335 .40378 .73942 .40184 .73859 .40077 Metetra
.664 .741 .907 r
.73859 .40077 .73942 .40184 .74551 .39991 .74469 .39883 Metetra
.664 .741 .907 r
.74469 .39883 .74551 .39991 .75162 .39797 .75079 .39689 Metetra
.664 .741 .907 r
.75079 .39689 .75162 .39797 .75773 .39603 .75691 .39494 Metetra
.664 .741 .907 r
.75691 .39494 .75773 .39603 .76386 .39408 .76304 .39299 Metetra
.664 .741 .907 r
.76304 .39299 .76386 .39408 .77 .39213 .76918 .39104 Metetra
.91 .525 .104 r
.76918 .39104 .77 .39213 .77951 .43306 .77751 .41685 Metetra
.701 .475 .579 r
.77751 .41685 .77951 .43306 .78232 .38821 .78151 .38712 Metetra
.664 .741 .907 r
.78151 .38712 .78232 .38821 .7885 .38625 .7877 .38515 Metetra
.664 .741 .907 r
.7877 .38515 .7885 .38625 .7947 .38428 .79389 .38318 Metetra
.664 .741 .907 r
.79389 .38318 .7947 .38428 .80091 .38231 .8001 .38121 Metetra
.664 .741 .907 r
.8001 .38121 .80091 .38231 .80713 .38033 .80633 .37923 Metetra
.664 .741 .907 r
.80633 .37923 .80713 .38033 .81336 .37835 .81256 .37724 Metetra
.664 .741 .907 r
.81256 .37724 .81336 .37835 .81961 .37636 .81881 .37526 Metetra
.664 .741 .907 r
.81881 .37526 .81961 .37636 .82587 .37437 .82508 .37326 Metetra
.664 .741 .907 r
.82508 .37326 .82587 .37437 .83215 .37238 .83136 .37127 Metetra
.664 .741 .907 r
.83136 .37127 .83215 .37238 .83843 .37038 .83765 .36927 Metetra
.664 .741 .907 r
.83765 .36927 .83843 .37038 .84474 .36838 .84395 .36726 Metetra
.664 .741 .907 r
.84395 .36726 .84474 .36838 .85105 .36637 .85027 .36525 Metetra
.664 .741 .907 r
.85027 .36525 .85105 .36637 .85738 .36436 .8566 .36324 Metetra
.664 .741 .907 r
.8566 .36324 .85738 .36436 .86372 .36235 .86295 .36122 Metetra
.664 .741 .907 r
.86295 .36122 .86372 .36235 .87008 .36033 .86931 .3592 Metetra
.664 .741 .907 r
.86931 .3592 .87008 .36033 .87645 .3583 .87568 .35717 Metetra
.664 .741 .907 r
.87568 .35717 .87645 .3583 .88284 .35627 .88207 .35514 Metetra
.664 .741 .907 r
.88207 .35514 .88284 .35627 .88924 .35424 .88847 .3531 Metetra
.664 .741 .907 r
.88847 .3531 .88924 .35424 .89565 .3522 .89489 .35106 Metetra
.664 .741 .907 r
.89489 .35106 .89565 .3522 .90208 .35016 .90132 .34902 Metetra
.664 .741 .907 r
.90132 .34902 .90208 .35016 .90852 .34811 .90776 .34697 Metetra
.664 .741 .907 r
.90776 .34697 .90852 .34811 .91497 .34606 .91422 .34491 Metetra
.664 .741 .907 r
.33066 .52925 .33165 .53018 .33691 .52851 .33591 .52757 Metetra
.664 .741 .907 r
.33591 .52757 .33691 .52851 .34217 .52683 .34118 .5259 Metetra
.664 .741 .907 r
.34118 .5259 .34217 .52683 .34745 .52515 .34646 .52422 Metetra
.933 .565 .282 r
.34646 .52422 .34745 .52515 .35273 .52347 .35084 .54003 Metetra
.396 .187 .474 r
.35084 .54003 .35273 .52347 .35729 .53656 .35704 .52085 Metetra
.577 .386 .587 r
.35704 .52085 .35729 .53656 .36334 .5201 .36235 .51916 Metetra
.664 .741 .907 r
.36235 .51916 .36334 .5201 .36865 .51841 .36767 .51747 Metetra
.664 .741 .907 r
.36767 .51747 .36865 .51841 .37398 .51672 .373 .51577 Metetra
.664 .741 .907 r
.373 .51577 .37398 .51672 .37932 .51502 .37834 .51407 Metetra
.664 .741 .907 r
.37834 .51407 .37932 .51502 .38467 .51332 .38369 .51237 Metetra
.664 .741 .907 r
.38369 .51237 .38467 .51332 .39003 .51161 .38906 .51066 Metetra
.664 .741 .907 r
.38906 .51066 .39003 .51161 .3954 .5099 .39443 .50895 Metetra
.664 .741 .907 r
.39443 .50895 .3954 .5099 .40078 .50819 .39981 .50724 Metetra
.664 .741 .907 r
.39981 .50724 .40078 .50819 .40618 .50648 .40521 .50552 Metetra
.664 .741 .907 r
.40521 .50552 .40618 .50648 .41158 .50476 .41061 .5038 Metetra
.664 .741 .907 r
.41061 .5038 .41158 .50476 .41699 .50304 .41603 .50208 Metetra
.664 .741 .907 r
.41603 .50208 .41699 .50304 .42242 .50131 .42146 .50035 Metetra
.664 .741 .907 r
.42146 .50035 .42242 .50131 .42785 .49958 .42689 .49862 Metetra
.9 .485 .126 r
.42689 .49862 .42785 .49958 .4308 .58863 .43195 .51101 Metetra
.48 .289 .544 r
.43195 .51101 .4308 .58863 .43658 .58009 .43599 .56435 Metetra
.796 .559 .579 r
.43599 .56435 .43658 .58009 .44423 .49438 .44327 .49341 Metetra
.664 .741 .907 r
.44327 .49341 .44423 .49438 .44971 .49263 .44876 .49166 Metetra
.664 .741 .907 r
.44876 .49166 .44971 .49263 .4552 .49089 .45425 .48991 Metetra
.664 .741 .907 r
.45425 .48991 .4552 .49089 .4607 .48914 .45975 .48816 Metetra
.664 .741 .907 r
.45975 .48816 .4607 .48914 .46622 .48738 .46527 .48641 Metetra
.664 .741 .907 r
.46527 .48641 .46622 .48738 .47174 .48563 .4708 .48465 Metetra
.664 .741 .907 r
.4708 .48465 .47174 .48563 .47728 .48387 .47633 .48288 Metetra
.664 .741 .907 r
.47633 .48288 .47728 .48387 .48282 .4821 .48188 .48112 Metetra
.664 .741 .907 r
.48188 .48112 .48282 .4821 .48838 .48034 .48744 .47935 Metetra
.664 .741 .907 r
.48744 .47935 .48838 .48034 .49395 .47856 .49302 .47758 Metetra
.664 .741 .907 r
.49302 .47758 .49395 .47856 .49953 .47679 .4986 .4758 Metetra
.664 .741 .907 r
.4986 .4758 .49953 .47679 .50512 .47501 .50419 .47402 Metetra
.664 .741 .907 r
.50419 .47402 .50512 .47501 .51073 .47323 .5098 .47223 Metetra
.664 .741 .907 r
.5098 .47223 .51073 .47323 .51634 .47144 .51542 .47045 Metetra
.664 .741 .907 r
.51542 .47045 .51634 .47144 .52197 .46965 .52105 .46865 Metetra
.664 .741 .907 r
.52105 .46865 .52197 .46965 .52761 .46786 .52669 .46686 Metetra
.664 .741 .907 r
.52669 .46686 .52761 .46786 .53326 .46606 .53234 .46506 Metetra
.664 .741 .907 r
.53234 .46506 .53326 .46606 .53892 .46426 .538 .46326 Metetra
.664 .741 .907 r
.538 .46326 .53892 .46426 .54459 .46246 .54368 .46145 Metetra
.664 .741 .907 r
.54368 .46145 .54459 .46246 .55028 .46065 .54937 .45964 Metetra
.664 .741 .907 r
.54937 .45964 .55028 .46065 .55598 .45884 .55507 .45783 Metetra
.664 .741 .907 r
.55507 .45783 .55598 .45884 .56168 .45702 .56078 .45601 Metetra
.664 .741 .907 r
.56078 .45601 .56168 .45702 .56741 .45521 .5665 .45419 Metetra
.664 .741 .907 r
.5665 .45419 .56741 .45521 .57314 .45338 .57223 .45236 Metetra
.664 .741 .907 r
.57223 .45236 .57314 .45338 .57888 .45156 .57798 .45054 Metetra
.664 .741 .907 r
.57798 .45054 .57888 .45156 .58464 .44973 .58374 .4487 Metetra
.664 .741 .907 r
.58374 .4487 .58464 .44973 .5904 .44789 .58951 .44687 Metetra
.664 .741 .907 r
.58951 .44687 .5904 .44789 .59618 .44605 .59529 .44503 Metetra
.664 .741 .907 r
.59529 .44503 .59618 .44605 .60218 .45281 .60109 .44318 Metetra
.586 .41 .61 r
.60109 .44318 .60218 .45281 .60802 .45162 .60689 .44133 Metetra
.585 .406 .606 r
.60689 .44133 .60802 .45162 .6136 .44052 .61271 .43948 Metetra
.664 .741 .907 r
.61271 .43948 .6136 .44052 .61942 .43866 .61854 .43763 Metetra
.664 .741 .907 r
.61854 .43763 .61942 .43866 .62526 .43681 .62438 .43577 Metetra
.664 .741 .907 r
.62438 .43577 .62526 .43681 .63112 .43494 .63024 .4339 Metetra
.664 .741 .907 r
.63024 .4339 .63112 .43494 .63698 .43308 .63611 .43204 Metetra
.664 .741 .907 r
.63611 .43204 .63698 .43308 .64286 .43121 .64198 .43017 Metetra
.664 .741 .907 r
.64198 .43017 .64286 .43121 .64875 .42934 .64788 .42829 Metetra
.664 .741 .907 r
.64788 .42829 .64875 .42934 .65465 .42746 .65378 .42641 Metetra
.664 .741 .907 r
.65378 .42641 .65465 .42746 .66056 .42558 .6597 .42453 Metetra
.664 .741 .907 r
.6597 .42453 .66056 .42558 .66649 .4237 .66563 .42264 Metetra
.664 .741 .907 r
.66563 .42264 .66649 .4237 .67243 .42181 .67157 .42075 Metetra
.664 .741 .907 r
.67157 .42075 .67243 .42181 .67838 .41991 .67752 .41886 Metetra
.664 .741 .907 r
.67752 .41886 .67838 .41991 .68435 .41802 .68349 .41696 Metetra
.664 .741 .907 r
.68349 .41696 .68435 .41802 .69032 .41612 .68947 .41506 Metetra
.664 .741 .907 r
.68947 .41506 .69032 .41612 .69631 .41421 .69546 .41315 Metetra
.664 .741 .907 r
.69546 .41315 .69631 .41421 .70231 .4123 .70146 .41124 Metetra
.664 .741 .907 r
.70146 .41124 .70231 .4123 .70833 .41039 .70748 .40932 Metetra
.664 .741 .907 r
.70748 .40932 .70833 .41039 .71436 .40847 .71351 .4074 Metetra
.664 .741 .907 r
.71351 .4074 .71436 .40847 .7204 .40655 .71956 .40548 Metetra
.664 .741 .907 r
.71956 .40548 .7204 .40655 .72645 .40463 .72561 .40355 Metetra
.664 .741 .907 r
.72561 .40355 .72645 .40463 .73251 .4027 .73168 .40162 Metetra
.664 .741 .907 r
.73168 .40162 .73251 .4027 .73859 .40077 .73776 .39969 Metetra
.664 .741 .907 r
.73776 .39969 .73859 .40077 .74469 .39883 .74386 .39775 Metetra
.664 .741 .907 r
.74386 .39775 .74469 .39883 .75079 .39689 .74996 .3958 Metetra
.664 .741 .907 r
.74996 .3958 .75079 .39689 .75691 .39494 .75608 .39386 Metetra
.664 .741 .907 r
.75608 .39386 .75691 .39494 .76304 .39299 .76222 .3919 Metetra
.664 .741 .907 r
.76222 .3919 .76304 .39299 .76918 .39104 .76837 .38995 Metetra
.664 .741 .907 r
.76837 .38995 .76918 .39104 .77751 .41685 .77453 .38799 Metetra
.57 .371 .571 r
.77453 .38799 .77751 .41685 .78151 .38712 .7807 .38602 Metetra
.664 .741 .907 r
.7807 .38602 .78151 .38712 .7877 .38515 .78689 .38405 Metetra
.664 .741 .907 r
.78689 .38405 .7877 .38515 .79389 .38318 .79309 .38208 Metetra
.664 .741 .907 r
.79309 .38208 .79389 .38318 .8001 .38121 .7993 .3801 Metetra
.664 .741 .907 r
.7993 .3801 .8001 .38121 .80633 .37923 .80553 .37812 Metetra
.664 .741 .907 r
.80553 .37812 .80633 .37923 .81256 .37724 .81177 .37613 Metetra
.664 .741 .907 r
.81177 .37613 .81256 .37724 .81881 .37526 .81802 .37414 Metetra
.664 .741 .907 r
.81802 .37414 .81881 .37526 .82508 .37326 .82429 .37215 Metetra
.664 .741 .907 r
.82429 .37215 .82508 .37326 .83136 .37127 .83057 .37015 Metetra
.664 .741 .907 r
.83057 .37015 .83136 .37127 .83765 .36927 .83686 .36815 Metetra
.664 .741 .907 r
.83686 .36815 .83765 .36927 .84395 .36726 .84317 .36614 Metetra
.664 .741 .907 r
.84317 .36614 .84395 .36726 .85027 .36525 .84949 .36413 Metetra
.664 .741 .907 r
.84949 .36413 .85027 .36525 .8566 .36324 .85583 .36211 Metetra
.664 .741 .907 r
.85583 .36211 .8566 .36324 .86295 .36122 .86218 .36009 Metetra
.664 .741 .907 r
.86218 .36009 .86295 .36122 .86931 .3592 .86854 .35807 Metetra
.664 .741 .907 r
.86854 .35807 .86931 .3592 .87568 .35717 .87492 .35604 Metetra
.664 .741 .907 r
.87492 .35604 .87568 .35717 .88207 .35514 .88131 .354 Metetra
.664 .741 .907 r
.88131 .354 .88207 .35514 .88847 .3531 .88771 .35197 Metetra
.664 .741 .907 r
.88771 .35197 .88847 .3531 .89489 .35106 .89413 .34992 Metetra
.664 .741 .907 r
.89413 .34992 .89489 .35106 .90132 .34902 .90056 .34788 Metetra
.664 .741 .907 r
.90056 .34788 .90132 .34902 .90776 .34697 .90701 .34582 Metetra
.664 .741 .907 r
.90701 .34582 .90776 .34697 .91422 .34491 .91347 .34377 Metetra
.664 .741 .907 r
.32966 .52831 .33066 .52925 .33591 .52757 .33492 .52664 Metetra
.664 .741 .907 r
.33492 .52664 .33591 .52757 .34118 .5259 .34018 .52496 Metetra
.664 .741 .907 r
.34018 .52496 .34118 .5259 .34646 .52422 .34546 .52328 Metetra
.945 .649 .445 r
.34546 .52328 .34646 .52422 .35084 .54003 .34854 .56403 Metetra
.254 .079 .441 r
.34854 .56403 .35084 .54003 .35704 .52085 .35605 .51991 Metetra
.664 .741 .907 r
.35605 .51991 .35704 .52085 .36235 .51916 .36136 .51821 Metetra
0 .168 .66 r
.36136 .51821 .36235 .51916 .36767 .51747 .36642 .52216 Metetra
.307 .044 .34 r
.36642 .52216 .36767 .51747 .373 .51577 .37202 .51482 Metetra
.664 .741 .907 r
.37202 .51482 .373 .51577 .37834 .51407 .37736 .51312 Metetra
.664 .741 .907 r
.37736 .51312 .37834 .51407 .38369 .51237 .38271 .51142 Metetra
.664 .741 .907 r
.38271 .51142 .38369 .51237 .38906 .51066 .38808 .50971 Metetra
.664 .741 .907 r
.38808 .50971 .38906 .51066 .39443 .50895 .39345 .50799 Metetra
.664 .741 .907 r
.39345 .50799 .39443 .50895 .39981 .50724 .39884 .50628 Metetra
.664 .741 .907 r
.39884 .50628 .39981 .50724 .40521 .50552 .40424 .50456 Metetra
.664 .741 .907 r
.40424 .50456 .40521 .50552 .41061 .5038 .40964 .50284 Metetra
.664 .741 .907 r
.40964 .50284 .41061 .5038 .41603 .50208 .41506 .50111 Metetra
.664 .741 .907 r
.41506 .50111 .41603 .50208 .42146 .50035 .42049 .49938 Metetra
.664 .741 .907 r
.42049 .49938 .42146 .50035 .42689 .49862 .42593 .49765 Metetra
.664 .741 .907 r
.42593 .49765 .42689 .49862 .43195 .51101 .43138 .49592 Metetra
.558 .373 .586 r
.43138 .49592 .43195 .51101 .43599 .56435 .43677 .49694 Metetra
.569 .362 .559 r
.43677 .49694 .43599 .56435 .44327 .49341 .44232 .49243 Metetra
.664 .741 .907 r
.44232 .49243 .44327 .49341 .44876 .49166 .4478 .49069 Metetra
.915 .514 .168 r
.4478 .49069 .44876 .49166 .45425 .48991 .45295 .50489 Metetra
.671 .419 .53 r
.45295 .50489 .45425 .48991 .45975 .48816 .458 .52724 Metetra
.423 .227 .508 r
.458 .52724 .45975 .48816 .46527 .48641 .46432 .48542 Metetra
.664 .741 .907 r
.46432 .48542 .46527 .48641 .4708 .48465 .46985 .48366 Metetra
.664 .741 .907 r
.46985 .48366 .4708 .48465 .47633 .48288 .47539 .4819 Metetra
.664 .741 .907 r
.47539 .4819 .47633 .48288 .48188 .48112 .48094 .48013 Metetra
.664 .741 .907 r
.48094 .48013 .48188 .48112 .48744 .47935 .4865 .47836 Metetra
.664 .741 .907 r
.4865 .47836 .48744 .47935 .49302 .47758 .49208 .47658 Metetra
.664 .741 .907 r
.49208 .47658 .49302 .47758 .4986 .4758 .49766 .47481 Metetra
.664 .741 .907 r
.49766 .47481 .4986 .4758 .50419 .47402 .50326 .47302 Metetra
.664 .741 .907 r
.50326 .47302 .50419 .47402 .5098 .47223 .50887 .47124 Metetra
.664 .741 .907 r
.50887 .47124 .5098 .47223 .51542 .47045 .51449 .46945 Metetra
.664 .741 .907 r
.51449 .46945 .51542 .47045 .52105 .46865 .52012 .46765 Metetra
.664 .741 .907 r
.52012 .46765 .52105 .46865 .52669 .46686 .52576 .46586 Metetra
.664 .741 .907 r
.52576 .46586 .52669 .46686 .53234 .46506 .53142 .46406 Metetra
.664 .741 .907 r
.53142 .46406 .53234 .46506 .538 .46326 .53709 .46225 Metetra
.664 .741 .907 r
.53709 .46225 .538 .46326 .54368 .46145 .54276 .46044 Metetra
.664 .741 .907 r
.54276 .46044 .54368 .46145 .54937 .45964 .54845 .45863 Metetra
.664 .741 .907 r
.54845 .45863 .54937 .45964 .55507 .45783 .55415 .45681 Metetra
.664 .741 .907 r
.55415 .45681 .55507 .45783 .56078 .45601 .55987 .455 Metetra
.664 .741 .907 r
.55987 .455 .56078 .45601 .5665 .45419 .56559 .45317 Metetra
.664 .741 .907 r
.56559 .45317 .5665 .45419 .57223 .45236 .57133 .45135 Metetra
.664 .741 .907 r
.57133 .45135 .57223 .45236 .57798 .45054 .57708 .44951 Metetra
.664 .741 .907 r
.57708 .44951 .57798 .45054 .58374 .4487 .58284 .44768 Metetra
.664 .741 .907 r
.58284 .44768 .58374 .4487 .58951 .44687 .58861 .44584 Metetra
.664 .741 .907 r
.58861 .44584 .58951 .44687 .59529 .44503 .5944 .444 Metetra
.664 .741 .907 r
.5944 .444 .59529 .44503 .60109 .44318 .60019 .44215 Metetra
.664 .741 .907 r
.60019 .44215 .60109 .44318 .60689 .44133 .606 .4403 Metetra
.664 .741 .907 r
.606 .4403 .60689 .44133 .61271 .43948 .61182 .43845 Metetra
.664 .741 .907 r
.61182 .43845 .61271 .43948 .61854 .43763 .61766 .43659 Metetra
.664 .741 .907 r
.61766 .43659 .61854 .43763 .62438 .43577 .6235 .43473 Metetra
.664 .741 .907 r
.6235 .43473 .62438 .43577 .63024 .4339 .62936 .43286 Metetra
.664 .741 .907 r
.62936 .43286 .63024 .4339 .63611 .43204 .63523 .43099 Metetra
.664 .741 .907 r
.63523 .43099 .63611 .43204 .64198 .43017 .64111 .42912 Metetra
.957 .616 .294 r
.64111 .42912 .64198 .43017 .64788 .42829 .64852 .46759 Metetra
.436 .242 .518 r
.64852 .46759 .64788 .42829 .65378 .42641 .65291 .42536 Metetra
.664 .741 .907 r
.65291 .42536 .65378 .42641 .6597 .42453 .65883 .42348 Metetra
.664 .741 .907 r
.65883 .42348 .6597 .42453 .66563 .42264 .66476 .42159 Metetra
.664 .741 .907 r
.66476 .42159 .66563 .42264 .67157 .42075 .67071 .4197 Metetra
.664 .741 .907 r
.67071 .4197 .67157 .42075 .67752 .41886 .67666 .4178 Metetra
.664 .741 .907 r
.67666 .4178 .67752 .41886 .68349 .41696 .68263 .4159 Metetra
.664 .741 .907 r
.68263 .4159 .68349 .41696 .68947 .41506 .68861 .41399 Metetra
.664 .741 .907 r
.68861 .41399 .68947 .41506 .69546 .41315 .69461 .41208 Metetra
.664 .741 .907 r
.69461 .41208 .69546 .41315 .70146 .41124 .70062 .41017 Metetra
.664 .741 .907 r
.70062 .41017 .70146 .41124 .70748 .40932 .70664 .40825 Metetra
.664 .741 .907 r
.70664 .40825 .70748 .40932 .71351 .4074 .71267 .40633 Metetra
.664 .741 .907 r
.71267 .40633 .71351 .4074 .71956 .40548 .71871 .40441 Metetra
.664 .741 .907 r
.71871 .40441 .71956 .40548 .72561 .40355 .72477 .40248 Metetra
.664 .741 .907 r
.72477 .40248 .72561 .40355 .73168 .40162 .73084 .40054 Metetra
.664 .741 .907 r
.73084 .40054 .73168 .40162 .73776 .39969 .73693 .3986 Metetra
.664 .741 .907 r
.73693 .3986 .73776 .39969 .74386 .39775 .74303 .39666 Metetra
.664 .741 .907 r
.74303 .39666 .74386 .39775 .74996 .3958 .74914 .39472 Metetra
.664 .741 .907 r
.74914 .39472 .74996 .3958 .75608 .39386 .75526 .39277 Metetra
.664 .741 .907 r
.75526 .39277 .75608 .39386 .76222 .3919 .7614 .39081 Metetra
.664 .741 .907 r
.7614 .39081 .76222 .3919 .76837 .38995 .76755 .38885 Metetra
.664 .741 .907 r
.76755 .38885 .76837 .38995 .77453 .38799 .77371 .38689 Metetra
.664 .741 .907 r
.77371 .38689 .77453 .38799 .7807 .38602 .77988 .38492 Metetra
.664 .741 .907 r
.77988 .38492 .7807 .38602 .78689 .38405 .78607 .38295 Metetra
.664 .741 .907 r
.78607 .38295 .78689 .38405 .79309 .38208 .79228 .38098 Metetra
.664 .741 .907 r
.79228 .38098 .79309 .38208 .7993 .3801 .79849 .379 Metetra
.664 .741 .907 r
.79849 .379 .7993 .3801 .80553 .37812 .80472 .37701 Metetra
.664 .741 .907 r
.80472 .37701 .80553 .37812 .81177 .37613 .81097 .37503 Metetra
.664 .741 .907 r
.81097 .37503 .81177 .37613 .81802 .37414 .81722 .37303 Metetra
.664 .741 .907 r
.81722 .37303 .81802 .37414 .82429 .37215 .82349 .37104 Metetra
.664 .741 .907 r
.82349 .37104 .82429 .37215 .83057 .37015 .82978 .36903 Metetra
.664 .741 .907 r
.82978 .36903 .83057 .37015 .83686 .36815 .83607 .36703 Metetra
.664 .741 .907 r
.83607 .36703 .83686 .36815 .84317 .36614 .84238 .36502 Metetra
.664 .741 .907 r
.84238 .36502 .84317 .36614 .84949 .36413 .84871 .36301 Metetra
0 .286 .785 r
.84871 .36301 .84949 .36413 .85583 .36211 .8558 .36827 Metetra
.386 .149 .428 r
.8558 .36827 .85583 .36211 .86218 .36009 .8614 .35896 Metetra
.664 .741 .907 r
.8614 .35896 .86218 .36009 .86854 .35807 .86777 .35694 Metetra
.664 .741 .907 r
.86777 .35694 .86854 .35807 .87492 .35604 .87415 .3549 Metetra
.664 .741 .907 r
.87415 .3549 .87492 .35604 .88131 .354 .88054 .35287 Metetra
.664 .741 .907 r
.88054 .35287 .88131 .354 .88771 .35197 .88695 .35083 Metetra
.664 .741 .907 r
.88695 .35083 .88771 .35197 .89413 .34992 .89337 .34878 Metetra
.664 .741 .907 r
.89337 .34878 .89413 .34992 .90056 .34788 .89981 .34673 Metetra
.664 .741 .907 r
.89981 .34673 .90056 .34788 .90701 .34582 .90626 .34468 Metetra
.664 .741 .907 r
.90626 .34468 .90701 .34582 .91347 .34377 .91272 .34262 Metetra
.664 .741 .907 r
.32866 .52738 .32966 .52831 .33492 .52664 .33392 .5257 Metetra
.664 .741 .907 r
.33392 .5257 .33492 .52664 .34018 .52496 .33919 .52402 Metetra
.664 .741 .907 r
.33919 .52402 .34018 .52496 .34546 .52328 .34447 .52234 Metetra
.664 .741 .907 r
.34447 .52234 .34546 .52328 .34854 .56403 .34976 .52065 Metetra
.567 .363 .563 r
.34976 .52065 .34854 .56403 .35605 .51991 .35506 .51896 Metetra
.664 .741 .907 r
.35506 .51896 .35605 .51991 .36136 .51821 .36038 .51727 Metetra
.664 .741 .907 r
.36038 .51727 .36136 .51821 .36642 .52216 .3657 .51557 Metetra
.595 .434 .633 r
.3657 .51557 .36642 .52216 .37202 .51482 .37103 .51387 Metetra
.664 .741 .907 r
.37103 .51387 .37202 .51482 .37736 .51312 .37638 .51217 Metetra
.664 .741 .907 r
.37638 .51217 .37736 .51312 .38271 .51142 .38173 .51046 Metetra
.664 .741 .907 r
.38173 .51046 .38271 .51142 .38808 .50971 .3871 .50875 Metetra
.664 .741 .907 r
.3871 .50875 .38808 .50971 .39345 .50799 .39248 .50704 Metetra
.664 .741 .907 r
.39248 .50704 .39345 .50799 .39884 .50628 .39787 .50532 Metetra
.664 .741 .907 r
.39787 .50532 .39884 .50628 .40424 .50456 .40326 .5036 Metetra
.664 .741 .907 r
.40326 .5036 .40424 .50456 .40964 .50284 .40867 .50188 Metetra
.664 .741 .907 r
.40867 .50188 .40964 .50284 .41506 .50111 .41409 .50015 Metetra
.664 .741 .907 r
.41409 .50015 .41506 .50111 .42049 .49938 .41952 .49842 Metetra
.664 .741 .907 r
.41952 .49842 .42049 .49938 .42593 .49765 .42497 .49668 Metetra
.664 .741 .907 r
.42497 .49668 .42593 .49765 .43138 .49592 .43042 .49495 Metetra
.664 .741 .907 r
.43042 .49495 .43138 .49592 .43677 .49694 .43588 .4932 Metetra
.616 .493 .69 r
.43588 .4932 .43677 .49694 .44232 .49243 .44136 .49146 Metetra
.664 .741 .907 r
.44136 .49146 .44232 .49243 .4478 .49069 .44685 .48971 Metetra
.953 .674 .471 r
.44685 .48971 .4478 .49069 .45295 .50489 .44959 .61344 Metetra
.515 .308 .537 r
.44959 .61344 .45295 .50489 .458 .52724 .4562 .56799 Metetra
.231 .076 .454 r
.4562 .56799 .458 .52724 .46432 .48542 .46337 .48444 Metetra
.664 .741 .907 r
.46337 .48444 .46432 .48542 .46985 .48366 .4689 .48268 Metetra
.664 .741 .907 r
.4689 .48268 .46985 .48366 .47539 .4819 .47445 .48091 Metetra
.664 .741 .907 r
.47445 .48091 .47539 .4819 .48094 .48013 .48 .47914 Metetra
.664 .741 .907 r
.48 .47914 .48094 .48013 .4865 .47836 .48556 .47737 Metetra
.664 .741 .907 r
.48556 .47737 .4865 .47836 .49208 .47658 .49114 .47559 Metetra
.664 .741 .907 r
.49114 .47559 .49208 .47658 .49766 .47481 .49673 .47381 Metetra
.664 .741 .907 r
.49673 .47381 .49766 .47481 .50326 .47302 .50233 .47203 Metetra
.664 .741 .907 r
.50233 .47203 .50326 .47302 .50887 .47124 .50794 .47024 Metetra
.664 .741 .907 r
.50794 .47024 .50887 .47124 .51449 .46945 .51356 .46845 Metetra
.664 .741 .907 r
.51356 .46845 .51449 .46945 .52012 .46765 .51919 .46665 Metetra
.664 .741 .907 r
.51919 .46665 .52012 .46765 .52576 .46586 .52484 .46485 Metetra
.664 .741 .907 r
.52484 .46485 .52576 .46586 .53142 .46406 .5305 .46305 Metetra
.664 .741 .907 r
.5305 .46305 .53142 .46406 .53709 .46225 .53617 .46124 Metetra
.664 .741 .907 r
.53617 .46124 .53709 .46225 .54276 .46044 .54185 .45943 Metetra
.664 .741 .907 r
.54185 .45943 .54276 .46044 .54845 .45863 .54754 .45762 Metetra
.664 .741 .907 r
.54754 .45762 .54845 .45863 .55415 .45681 .55324 .4558 Metetra
.664 .741 .907 r
.55324 .4558 .55415 .45681 .55987 .455 .55896 .45398 Metetra
.664 .741 .907 r
.55896 .45398 .55987 .455 .56559 .45317 .56468 .45215 Metetra
.664 .741 .907 r
.56468 .45215 .56559 .45317 .57133 .45135 .57042 .45032 Metetra
.664 .741 .907 r
.57042 .45032 .57133 .45135 .57708 .44951 .57617 .44849 Metetra
.664 .741 .907 r
.57617 .44849 .57708 .44951 .58284 .44768 .58194 .44665 Metetra
.664 .741 .907 r
.58194 .44665 .58284 .44768 .58861 .44584 .58771 .44481 Metetra
.664 .741 .907 r
.58771 .44481 .58861 .44584 .5944 .444 .5935 .44297 Metetra
.664 .741 .907 r
.5935 .44297 .5944 .444 .60019 .44215 .5993 .44112 Metetra
.664 .741 .907 r
.5993 .44112 .60019 .44215 .606 .4403 .60511 .43927 Metetra
.664 .741 .907 r
.60511 .43927 .606 .4403 .61182 .43845 .61093 .43741 Metetra
.664 .741 .907 r
.61093 .43741 .61182 .43845 .61766 .43659 .61677 .43555 Metetra
.664 .741 .907 r
.61677 .43555 .61766 .43659 .6235 .43473 .62262 .43369 Metetra
.664 .741 .907 r
.62262 .43369 .6235 .43473 .62936 .43286 .62848 .43182 Metetra
.664 .741 .907 r
.62848 .43182 .62936 .43286 .63523 .43099 .63435 .42995 Metetra
.664 .741 .907 r
.63435 .42995 .63523 .43099 .64111 .42912 .64023 .42807 Metetra
.969 .673 .409 r
.64023 .42807 .64111 .42912 .64852 .46759 .65291 .60798 Metetra
.402 .225 .523 r
.65291 .60798 .64852 .46759 .65291 .42536 .65204 .42431 Metetra
.664 .741 .907 r
.65204 .42431 .65291 .42536 .65883 .42348 .65796 .42242 Metetra
.664 .741 .907 r
.65796 .42242 .65883 .42348 .66476 .42159 .6639 .42053 Metetra
.664 .741 .907 r
.6639 .42053 .66476 .42159 .67071 .4197 .66984 .41864 Metetra
.664 .741 .907 r
.66984 .41864 .67071 .4197 .67666 .4178 .6758 .41674 Metetra
.664 .741 .907 r
.6758 .41674 .67666 .4178 .68263 .4159 .68177 .41484 Metetra
.664 .741 .907 r
.68177 .41484 .68263 .4159 .68861 .41399 .68776 .41293 Metetra
.664 .741 .907 r
.68776 .41293 .68861 .41399 .69461 .41208 .69376 .41102 Metetra
.664 .741 .907 r
.69376 .41102 .69461 .41208 .70062 .41017 .69977 .4091 Metetra
.664 .741 .907 r
.69977 .4091 .70062 .41017 .70664 .40825 .70579 .40718 Metetra
.664 .741 .907 r
.70579 .40718 .70664 .40825 .71267 .40633 .71182 .40526 Metetra
.664 .741 .907 r
.71182 .40526 .71267 .40633 .71871 .40441 .71787 .40333 Metetra
.664 .741 .907 r
.71787 .40333 .71871 .40441 .72477 .40248 .72393 .4014 Metetra
.664 .741 .907 r
.72393 .4014 .72477 .40248 .73084 .40054 .73001 .39946 Metetra
.664 .741 .907 r
.73001 .39946 .73084 .40054 .73693 .3986 .73609 .39752 Metetra
.664 .741 .907 r
.73609 .39752 .73693 .3986 .74303 .39666 .74219 .39558 Metetra
.664 .741 .907 r
.74219 .39558 .74303 .39666 .74914 .39472 .74831 .39363 Metetra
.664 .741 .907 r
.74831 .39363 .74914 .39472 .75526 .39277 .75443 .39168 Metetra
.664 .741 .907 r
.75443 .39168 .75526 .39277 .7614 .39081 .76057 .38972 Metetra
.664 .741 .907 r
.76057 .38972 .7614 .39081 .76755 .38885 .76673 .38776 Metetra
.664 .741 .907 r
.76673 .38776 .76755 .38885 .77371 .38689 .77289 .38579 Metetra
.664 .741 .907 r
.77289 .38579 .77371 .38689 .77988 .38492 .77907 .38383 Metetra
.664 .741 .907 r
.77907 .38383 .77988 .38492 .78607 .38295 .78526 .38185 Metetra
.664 .741 .907 r
.78526 .38185 .78607 .38295 .79228 .38098 .79147 .37987 Metetra
.664 .741 .907 r
.79147 .37987 .79228 .38098 .79849 .379 .79769 .37789 Metetra
.664 .741 .907 r
.79769 .37789 .79849 .379 .80472 .37701 .80392 .37591 Metetra
.664 .741 .907 r
.80392 .37591 .80472 .37701 .81097 .37503 .81017 .37391 Metetra
.664 .741 .907 r
.81017 .37391 .81097 .37503 .81722 .37303 .81643 .37192 Metetra
.664 .741 .907 r
.81643 .37192 .81722 .37303 .82349 .37104 .8227 .36992 Metetra
.664 .741 .907 r
.8227 .36992 .82349 .37104 .82978 .36903 .82898 .36792 Metetra
.664 .741 .907 r
.82898 .36792 .82978 .36903 .83607 .36703 .83528 .36591 Metetra
.664 .741 .907 r
.83528 .36591 .83607 .36703 .84238 .36502 .8416 .3639 Metetra
.664 .741 .907 r
.8416 .3639 .84238 .36502 .84871 .36301 .84793 .36188 Metetra
.962 .632 .264 r
.84793 .36188 .84871 .36301 .8558 .36827 .8648 .46165 Metetra
.445 .261 .536 r
.8648 .46165 .8558 .36827 .8614 .35896 .86062 .35783 Metetra
.664 .741 .907 r
.86062 .35783 .8614 .35896 .86777 .35694 .86699 .3558 Metetra
.664 .741 .907 r
.86699 .3558 .86777 .35694 .87415 .3549 .87338 .35377 Metetra
.664 .741 .907 r
.87338 .35377 .87415 .3549 .88054 .35287 .87977 .35173 Metetra
.664 .741 .907 r
.87977 .35173 .88054 .35287 .88695 .35083 .88618 .34969 Metetra
.664 .741 .907 r
.88618 .34969 .88695 .35083 .89337 .34878 .89261 .34764 Metetra
.664 .741 .907 r
.89261 .34764 .89337 .34878 .89981 .34673 .89905 .34559 Metetra
.664 .741 .907 r
.89905 .34559 .89981 .34673 .90626 .34468 .9055 .34353 Metetra
.664 .741 .907 r
.9055 .34353 .90626 .34468 .91272 .34262 .91197 .34147 Metetra
.664 .741 .907 r
.32766 .52644 .32866 .52738 .33392 .5257 .33292 .52477 Metetra
.664 .741 .907 r
.33292 .52477 .33392 .5257 .33919 .52402 .33819 .52308 Metetra
.664 .741 .907 r
.33819 .52308 .33919 .52402 .34447 .52234 .34347 .5214 Metetra
.664 .741 .907 r
.34347 .5214 .34447 .52234 .34976 .52065 .34877 .51971 Metetra
.664 .741 .907 r
.34877 .51971 .34976 .52065 .35506 .51896 .35407 .51802 Metetra
.664 .741 .907 r
.35407 .51802 .35506 .51896 .36038 .51727 .35939 .51632 Metetra
.664 .741 .907 r
.35939 .51632 .36038 .51727 .3657 .51557 .36471 .51463 Metetra
.664 .741 .907 r
.36471 .51463 .3657 .51557 .37103 .51387 .37005 .51292 Metetra
.664 .741 .907 r
.37005 .51292 .37103 .51387 .37638 .51217 .3754 .51122 Metetra
.664 .741 .907 r
.3754 .51122 .37638 .51217 .38173 .51046 .38075 .50951 Metetra
.664 .741 .907 r
.38075 .50951 .38173 .51046 .3871 .50875 .38612 .5078 Metetra
.664 .741 .907 r
.38612 .5078 .3871 .50875 .39248 .50704 .3915 .50608 Metetra
.664 .741 .907 r
.3915 .50608 .39248 .50704 .39787 .50532 .39689 .50436 Metetra
.664 .741 .907 r
.39689 .50436 .39787 .50532 .40326 .5036 .40229 .50264 Metetra
.664 .741 .907 r
.40229 .50264 .40326 .5036 .40867 .50188 .4077 .50091 Metetra
.664 .741 .907 r
.4077 .50091 .40867 .50188 .41409 .50015 .41312 .49918 Metetra
.664 .741 .907 r
.41312 .49918 .41409 .50015 .41952 .49842 .41856 .49745 Metetra
.664 .741 .907 r
.41856 .49745 .41952 .49842 .42497 .49668 .424 .49571 Metetra
.664 .741 .907 r
.424 .49571 .42497 .49668 .43042 .49495 .42946 .49397 Metetra
.664 .741 .907 r
.42946 .49397 .43042 .49495 .43588 .4932 .43492 .49223 Metetra
.664 .741 .907 r
.43492 .49223 .43588 .4932 .44136 .49146 .4404 .49048 Metetra
.664 .741 .907 r
.4404 .49048 .44136 .49146 .44685 .48971 .44589 .48873 Metetra
.952 .679 .482 r
.44589 .48873 .44685 .48971 .44959 .61344 .44698 .68535 Metetra
.272 .113 .474 r
.44698 .68535 .44959 .61344 .4562 .56799 .45552 .55239 Metetra
.795 .557 .578 r
.45552 .55239 .4562 .56799 .46337 .48444 .46242 .48346 Metetra
.664 .741 .907 r
.46242 .48346 .46337 .48444 .4689 .48268 .46796 .4817 Metetra
.664 .741 .907 r
.46796 .4817 .4689 .48268 .47445 .48091 .4735 .47993 Metetra
.664 .741 .907 r
.4735 .47993 .47445 .48091 .48 .47914 .47906 .47816 Metetra
.664 .741 .907 r
.47906 .47816 .48 .47914 .48556 .47737 .48462 .47638 Metetra
.664 .741 .907 r
.48462 .47638 .48556 .47737 .49114 .47559 .4902 .4746 Metetra
.664 .741 .907 r
.4902 .4746 .49114 .47559 .49673 .47381 .49579 .47282 Metetra
.664 .741 .907 r
.49579 .47282 .49673 .47381 .50233 .47203 .50139 .47103 Metetra
.664 .741 .907 r
.50139 .47103 .50233 .47203 .50794 .47024 .50701 .46924 Metetra
.664 .741 .907 r
.50701 .46924 .50794 .47024 .51356 .46845 .51263 .46745 Metetra
.664 .741 .907 r
.51263 .46745 .51356 .46845 .51919 .46665 .51827 .46565 Metetra
.664 .741 .907 r
.51827 .46565 .51919 .46665 .52484 .46485 .52391 .46385 Metetra
.664 .741 .907 r
.52391 .46385 .52484 .46485 .5305 .46305 .52957 .46204 Metetra
.664 .741 .907 r
.52957 .46204 .5305 .46305 .53617 .46124 .53524 .46023 Metetra
.664 .741 .907 r
.53524 .46023 .53617 .46124 .54185 .45943 .54093 .45842 Metetra
.664 .741 .907 r
.54093 .45842 .54185 .45943 .54754 .45762 .54662 .4566 Metetra
.664 .741 .907 r
.54662 .4566 .54754 .45762 .55324 .4558 .55233 .45479 Metetra
.664 .741 .907 r
.55233 .45479 .55324 .4558 .55896 .45398 .55805 .45296 Metetra
.664 .741 .907 r
.55805 .45296 .55896 .45398 .56468 .45215 .56378 .45113 Metetra
.664 .741 .907 r
.56378 .45113 .56468 .45215 .57042 .45032 .56952 .4493 Metetra
.664 .741 .907 r
.56952 .4493 .57042 .45032 .57617 .44849 .57527 .44747 Metetra
.664 .741 .907 r
.57527 .44747 .57617 .44849 .58194 .44665 .58104 .44563 Metetra
.664 .741 .907 r
.58104 .44563 .58194 .44665 .58771 .44481 .58681 .44379 Metetra
.664 .741 .907 r
.58681 .44379 .58771 .44481 .5935 .44297 .5926 .44194 Metetra
.664 .741 .907 r
.5926 .44194 .5935 .44297 .5993 .44112 .5984 .44009 Metetra
.664 .741 .907 r
.5984 .44009 .5993 .44112 .60511 .43927 .60422 .43823 Metetra
.664 .741 .907 r
.60422 .43823 .60511 .43927 .61093 .43741 .61004 .43638 Metetra
.664 .741 .907 r
.61004 .43638 .61093 .43741 .61677 .43555 .61588 .43451 Metetra
.664 .741 .907 r
.61588 .43451 .61677 .43555 .62262 .43369 .62173 .43265 Metetra
.664 .741 .907 r
.62173 .43265 .62262 .43369 .62848 .43182 .62759 .43078 Metetra
.664 .741 .907 r
.62759 .43078 .62848 .43182 .63435 .42995 .63347 .4289 Metetra
.664 .741 .907 r
.63347 .4289 .63435 .42995 .64023 .42807 .63936 .42703 Metetra
.962 .634 .328 r
.63936 .42703 .64023 .42807 .65291 .60798 .64715 .47612 Metetra
.6 .382 .557 r
.64715 .47612 .65291 .60798 .65204 .42431 .65117 .42326 Metetra
.664 .741 .907 r
.65117 .42326 .65204 .42431 .65796 .42242 .65709 .42137 Metetra
.664 .741 .907 r
.65709 .42137 .65796 .42242 .6639 .42053 .66303 .41948 Metetra
.664 .741 .907 r
.66303 .41948 .6639 .42053 .66984 .41864 .66898 .41758 Metetra
.664 .741 .907 r
.66898 .41758 .66984 .41864 .6758 .41674 .67494 .41568 Metetra
.664 .741 .907 r
.67494 .41568 .6758 .41674 .68177 .41484 .68091 .41377 Metetra
.664 .741 .907 r
.68091 .41377 .68177 .41484 .68776 .41293 .6869 .41186 Metetra
.664 .741 .907 r
.6869 .41186 .68776 .41293 .69376 .41102 .6929 .40995 Metetra
.664 .741 .907 r
.6929 .40995 .69376 .41102 .69977 .4091 .69891 .40803 Metetra
.664 .741 .907 r
.69891 .40803 .69977 .4091 .70579 .40718 .70494 .40611 Metetra
.664 .741 .907 r
.70494 .40611 .70579 .40718 .71182 .40526 .71098 .40418 Metetra
.664 .741 .907 r
.71098 .40418 .71182 .40526 .71787 .40333 .71703 .40225 Metetra
.664 .741 .907 r
.71703 .40225 .71787 .40333 .72393 .4014 .72309 .40032 Metetra
.664 .741 .907 r
.72309 .40032 .72393 .4014 .73001 .39946 .72917 .39838 Metetra
.664 .741 .907 r
.72917 .39838 .73001 .39946 .73609 .39752 .73526 .39644 Metetra
.664 .741 .907 r
.73526 .39644 .73609 .39752 .74219 .39558 .74136 .39449 Metetra
.664 .741 .907 r
.74136 .39449 .74219 .39558 .74831 .39363 .74748 .39254 Metetra
.664 .741 .907 r
.74748 .39254 .74831 .39363 .75443 .39168 .75361 .39059 Metetra
.664 .741 .907 r
.75361 .39059 .75443 .39168 .76057 .38972 .75975 .38863 Metetra
.664 .741 .907 r
.75975 .38863 .76057 .38972 .76673 .38776 .7659 .38666 Metetra
.664 .741 .907 r
.7659 .38666 .76673 .38776 .77289 .38579 .77207 .3847 Metetra
.664 .741 .907 r
.77207 .3847 .77289 .38579 .77907 .38383 .77825 .38272 Metetra
.664 .741 .907 r
.77825 .38272 .77907 .38383 .78526 .38185 .78445 .38075 Metetra
.664 .741 .907 r
.78445 .38075 .78526 .38185 .79147 .37987 .79066 .37877 Metetra
.664 .741 .907 r
.79066 .37877 .79147 .37987 .79769 .37789 .79688 .37678 Metetra
.664 .741 .907 r
.79688 .37678 .79769 .37789 .80392 .37591 .80312 .3748 Metetra
.664 .741 .907 r
.80312 .3748 .80392 .37591 .81017 .37391 .80936 .3728 Metetra
.664 .741 .907 r
.80936 .3728 .81017 .37391 .81643 .37192 .81563 .37081 Metetra
.664 .741 .907 r
.81563 .37081 .81643 .37192 .8227 .36992 .8219 .3688 Metetra
.664 .741 .907 r
.8219 .3688 .8227 .36992 .82898 .36792 .82819 .3668 Metetra
.664 .741 .907 r
.82819 .3668 .82898 .36792 .83528 .36591 .8345 .36479 Metetra
.664 .741 .907 r
.8345 .36479 .83528 .36591 .8416 .3639 .84081 .36277 Metetra
.664 .741 .907 r
.84081 .36277 .8416 .3639 .84793 .36188 .84714 .36075 Metetra
0 0 .482 r
.84714 .36075 .84793 .36188 .8648 .46165 .8547 .37051 Metetra
.576 .364 .557 r
.8547 .37051 .8648 .46165 .86062 .35783 .85985 .3567 Metetra
.664 .741 .907 r
.85985 .3567 .86062 .35783 .86699 .3558 .86622 .35467 Metetra
.664 .741 .907 r
.86622 .35467 .86699 .3558 .87338 .35377 .8726 .35263 Metetra
.664 .741 .907 r
.8726 .35263 .87338 .35377 .87977 .35173 .879 .35059 Metetra
.664 .741 .907 r
.879 .35059 .87977 .35173 .88618 .34969 .88542 .34854 Metetra
.664 .741 .907 r
.88542 .34854 .88618 .34969 .89261 .34764 .89185 .34649 Metetra
.664 .741 .907 r
.89185 .34649 .89261 .34764 .89905 .34559 .89829 .34444 Metetra
.664 .741 .907 r
.89829 .34444 .89905 .34559 .9055 .34353 .90475 .34238 Metetra
.664 .741 .907 r
.90475 .34238 .9055 .34353 .91197 .34147 .91122 .34032 Metetra
.664 .741 .907 r
.32665 .52551 .32766 .52644 .33292 .52477 .33192 .52383 Metetra
.664 .741 .907 r
.33192 .52383 .33292 .52477 .33819 .52308 .33719 .52214 Metetra
.664 .741 .907 r
.33719 .52214 .33819 .52308 .34347 .5214 .34248 .52046 Metetra
.664 .741 .907 r
.34248 .52046 .34347 .5214 .34877 .51971 .34777 .51877 Metetra
.664 .741 .907 r
.34777 .51877 .34877 .51971 .35407 .51802 .35308 .51707 Metetra
.841 .382 0 r
.35308 .51707 .35407 .51802 .35939 .51632 .35788 .52574 Metetra
.463 .223 .465 r
.35788 .52574 .35939 .51632 .36471 .51463 .36347 .51899 Metetra
.295 .025 .323 r
.36347 .51899 .36471 .51463 .37005 .51292 .36906 .51197 Metetra
.664 .741 .907 r
.36906 .51197 .37005 .51292 .3754 .51122 .37441 .51027 Metetra
.664 .741 .907 r
.37441 .51027 .3754 .51122 .38075 .50951 .37977 .50855 Metetra
.664 .741 .907 r
.37977 .50855 .38075 .50951 .38612 .5078 .38514 .50684 Metetra
.664 .741 .907 r
.38514 .50684 .38612 .5078 .3915 .50608 .39052 .50512 Metetra
.664 .741 .907 r
.39052 .50512 .3915 .50608 .39689 .50436 .39591 .5034 Metetra
.664 .741 .907 r
.39591 .5034 .39689 .50436 .40229 .50264 .40132 .50168 Metetra
.664 .741 .907 r
.40132 .50168 .40229 .50264 .4077 .50091 .40673 .49995 Metetra
.664 .741 .907 r
.40673 .49995 .4077 .50091 .41312 .49918 .41215 .49822 Metetra
.664 .741 .907 r
.41215 .49822 .41312 .49918 .41856 .49745 .41759 .49648 Metetra
.664 .741 .907 r
.41759 .49648 .41856 .49745 .424 .49571 .42304 .49474 Metetra
.664 .741 .907 r
.42304 .49474 .424 .49571 .42946 .49397 .42849 .493 Metetra
.664 .741 .907 r
.42849 .493 .42946 .49397 .43492 .49223 .43396 .49126 Metetra
.664 .741 .907 r
.43396 .49126 .43492 .49223 .4404 .49048 .43944 .48951 Metetra
.664 .741 .907 r
.43944 .48951 .4404 .49048 .44589 .48873 .44493 .48776 Metetra
.952 .679 .483 r
.44493 .48776 .44589 .48873 .44698 .68535 .44574 .69457 Metetra
.986 .738 .47 r
.44574 .69457 .44698 .68535 .45552 .55239 .45595 .48424 Metetra
.564 .357 .558 r
.45595 .48424 .45552 .55239 .46242 .48346 .46147 .48248 Metetra
.664 .741 .907 r
.46147 .48248 .46242 .48346 .46796 .4817 .46701 .48071 Metetra
.664 .741 .907 r
.46701 .48071 .46796 .4817 .4735 .47993 .47255 .47894 Metetra
.664 .741 .907 r
.47255 .47894 .4735 .47993 .47906 .47816 .47811 .47717 Metetra
.664 .741 .907 r
.47811 .47717 .47906 .47816 .48462 .47638 .48368 .47539 Metetra
.664 .741 .907 r
.48368 .47539 .48462 .47638 .4902 .4746 .48926 .47361 Metetra
.664 .741 .907 r
.48926 .47361 .4902 .4746 .49579 .47282 .49485 .47182 Metetra
.664 .741 .907 r
.49485 .47182 .49579 .47282 .50139 .47103 .50046 .47003 Metetra
.664 .741 .907 r
.50046 .47003 .50139 .47103 .50701 .46924 .50607 .46824 Metetra
.664 .741 .907 r
.50607 .46824 .50701 .46924 .51263 .46745 .5117 .46644 Metetra
.664 .741 .907 r
.5117 .46644 .51263 .46745 .51827 .46565 .51734 .46464 Metetra
.664 .741 .907 r
.51734 .46464 .51827 .46565 .52391 .46385 .52299 .46284 Metetra
.664 .741 .907 r
.52299 .46284 .52391 .46385 .52957 .46204 .52865 .46103 Metetra
.664 .741 .907 r
.52865 .46103 .52957 .46204 .53524 .46023 .53432 .45922 Metetra
.664 .741 .907 r
.53432 .45922 .53524 .46023 .54093 .45842 .54001 .45741 Metetra
.664 .741 .907 r
.54001 .45741 .54093 .45842 .54662 .4566 .5457 .45559 Metetra
.664 .741 .907 r
.5457 .45559 .54662 .4566 .55233 .45479 .55141 .45377 Metetra
.664 .741 .907 r
.55141 .45377 .55233 .45479 .55805 .45296 .55713 .45194 Metetra
.664 .741 .907 r
.55713 .45194 .55805 .45296 .56378 .45113 .56287 .45011 Metetra
.664 .741 .907 r
.56287 .45011 .56378 .45113 .56952 .4493 .56861 .44828 Metetra
.664 .741 .907 r
.56861 .44828 .56952 .4493 .57527 .44747 .57437 .44644 Metetra
.664 .741 .907 r
.57437 .44644 .57527 .44747 .58104 .44563 .58013 .4446 Metetra
.664 .741 .907 r
.58013 .4446 .58104 .44563 .58681 .44379 .58591 .44276 Metetra
.664 .741 .907 r
.58591 .44276 .58681 .44379 .5926 .44194 .5917 .44091 Metetra
.664 .741 .907 r
.5917 .44091 .5926 .44194 .5984 .44009 .59751 .43905 Metetra
.664 .741 .907 r
.59751 .43905 .5984 .44009 .60422 .43823 .60332 .4372 Metetra
.664 .741 .907 r
.60332 .4372 .60422 .43823 .61004 .43638 .60915 .43534 Metetra
.664 .741 .907 r
.60915 .43534 .61004 .43638 .61588 .43451 .61499 .43347 Metetra
.664 .741 .907 r
.61499 .43347 .61588 .43451 .62173 .43265 .62085 .43161 Metetra
.664 .741 .907 r
.62085 .43161 .62173 .43265 .62759 .43078 .62671 .42973 Metetra
.664 .741 .907 r
.62671 .42973 .62759 .43078 .63347 .4289 .63259 .42786 Metetra
.766 .31 0 r
.63259 .42786 .63347 .4289 .63936 .42703 .63892 .43872 Metetra
.663 .399 .511 r
.63892 .43872 .63936 .42703 .64715 .47612 .64554 .45548 Metetra
.688 .464 .577 r
.64554 .45548 .64715 .47612 .65117 .42326 .65029 .42221 Metetra
.664 .741 .907 r
.65029 .42221 .65117 .42326 .65709 .42137 .65622 .42031 Metetra
.664 .741 .907 r
.65622 .42031 .65709 .42137 .66303 .41948 .66216 .41842 Metetra
.664 .741 .907 r
.66216 .41842 .66303 .41948 .66898 .41758 .66811 .41652 Metetra
.664 .741 .907 r
.66811 .41652 .66898 .41758 .67494 .41568 .67408 .41462 Metetra
.664 .741 .907 r
.67408 .41462 .67494 .41568 .68091 .41377 .68005 .41271 Metetra
.664 .741 .907 r
.68005 .41271 .68091 .41377 .6869 .41186 .68604 .4108 Metetra
.664 .741 .907 r
.68604 .4108 .6869 .41186 .6929 .40995 .69205 .40888 Metetra
.664 .741 .907 r
.69205 .40888 .6929 .40995 .69891 .40803 .69806 .40696 Metetra
.664 .741 .907 r
.69806 .40696 .69891 .40803 .70494 .40611 .70409 .40504 Metetra
.664 .741 .907 r
.70409 .40504 .70494 .40611 .71098 .40418 .71013 .40311 Metetra
.664 .741 .907 r
.71013 .40311 .71098 .40418 .71703 .40225 .71618 .40117 Metetra
.664 .741 .907 r
.71618 .40117 .71703 .40225 .72309 .40032 .72225 .39924 Metetra
.664 .741 .907 r
.72225 .39924 .72309 .40032 .72917 .39838 .72833 .3973 Metetra
.664 .741 .907 r
.72833 .3973 .72917 .39838 .73526 .39644 .73442 .39535 Metetra
.664 .741 .907 r
.73442 .39535 .73526 .39644 .74136 .39449 .74053 .3934 Metetra
.664 .741 .907 r
.74053 .3934 .74136 .39449 .74748 .39254 .74665 .39145 Metetra
.664 .741 .907 r
.74665 .39145 .74748 .39254 .75361 .39059 .75278 .38949 Metetra
.664 .741 .907 r
.75278 .38949 .75361 .39059 .75975 .38863 .75892 .38753 Metetra
.664 .741 .907 r
.75892 .38753 .75975 .38863 .7659 .38666 .76508 .38557 Metetra
.664 .741 .907 r
.76508 .38557 .7659 .38666 .77207 .3847 .77125 .3836 Metetra
.664 .741 .907 r
.77125 .3836 .77207 .3847 .77825 .38272 .77744 .38162 Metetra
.664 .741 .907 r
.77744 .38162 .77825 .38272 .78445 .38075 .78364 .37965 Metetra
.664 .741 .907 r
.78364 .37965 .78445 .38075 .79066 .37877 .78985 .37766 Metetra
.664 .741 .907 r
.78985 .37766 .79066 .37877 .79688 .37678 .79607 .37568 Metetra
.664 .741 .907 r
.79607 .37568 .79688 .37678 .80312 .3748 .80231 .37368 Metetra
.664 .741 .907 r
.80231 .37368 .80312 .3748 .80936 .3728 .80856 .37169 Metetra
.664 .741 .907 r
.80856 .37169 .80936 .3728 .81563 .37081 .81483 .36969 Metetra
.664 .741 .907 r
.81483 .36969 .81563 .37081 .8219 .3688 .82111 .36769 Metetra
.664 .741 .907 r
.82111 .36769 .8219 .3688 .82819 .3668 .8274 .36568 Metetra
.664 .741 .907 r
.8274 .36568 .82819 .3668 .8345 .36479 .8337 .36366 Metetra
.833 .423 0 r
.8337 .36366 .8345 .36479 .84081 .36277 .8422 .38366 Metetra
.437 .237 .51 r
.8422 .38366 .84081 .36277 .84714 .36075 .84636 .35962 Metetra
.664 .741 .907 r
.84636 .35962 .84714 .36075 .8547 .37051 .85271 .3576 Metetra
.58 .396 .596 r
.85271 .3576 .8547 .37051 .85985 .3567 .85907 .35557 Metetra
.664 .741 .907 r
.85907 .35557 .85985 .3567 .86622 .35467 .86544 .35353 Metetra
.664 .741 .907 r
.86544 .35353 .86622 .35467 .8726 .35263 .87183 .35149 Metetra
.664 .741 .907 r
.87183 .35149 .8726 .35263 .879 .35059 .87823 .34945 Metetra
.664 .741 .907 r
.87823 .34945 .879 .35059 .88542 .34854 .88465 .3474 Metetra
.664 .741 .907 r
.88465 .3474 .88542 .34854 .89185 .34649 .89108 .34535 Metetra
.664 .741 .907 r
.89108 .34535 .89185 .34649 .89829 .34444 .89753 .34329 Metetra
.664 .741 .907 r
.89753 .34329 .89829 .34444 .90475 .34238 .90399 .34123 Metetra
.664 .741 .907 r
.90399 .34123 .90475 .34238 .91122 .34032 .91046 .33916 Metetra
.664 .741 .907 r
.32565 .52457 .32665 .52551 .33192 .52383 .33092 .52289 Metetra
.664 .741 .907 r
.33092 .52289 .33192 .52383 .33719 .52214 .33619 .5212 Metetra
.664 .741 .907 r
.33619 .5212 .33719 .52214 .34248 .52046 .34148 .51952 Metetra
.664 .741 .907 r
.34148 .51952 .34248 .52046 .34777 .51877 .34678 .51782 Metetra
.664 .741 .907 r
.34678 .51782 .34777 .51877 .35308 .51707 .35209 .51613 Metetra
.946 .654 .453 r
.35209 .51613 .35308 .51707 .35788 .52574 .35497 .56296 Metetra
.361 .173 .486 r
.35497 .56296 .35788 .52574 .36347 .51899 .36273 .51273 Metetra
.596 .438 .637 r
.36273 .51273 .36347 .51899 .36906 .51197 .36808 .51102 Metetra
.664 .741 .907 r
.36808 .51102 .36906 .51197 .37441 .51027 .37343 .50931 Metetra
.664 .741 .907 r
.37343 .50931 .37441 .51027 .37977 .50855 .37879 .5076 Metetra
.664 .741 .907 r
.37879 .5076 .37977 .50855 .38514 .50684 .38416 .50588 Metetra
.664 .741 .907 r
.38416 .50588 .38514 .50684 .39052 .50512 .38954 .50416 Metetra
.664 .741 .907 r
.38954 .50416 .39052 .50512 .39591 .5034 .39494 .50244 Metetra
.664 .741 .907 r
.39494 .50244 .39591 .5034 .40132 .50168 .40034 .50071 Metetra
.664 .741 .907 r
.40034 .50071 .40132 .50168 .40673 .49995 .40576 .49898 Metetra
.664 .741 .907 r
.40576 .49898 .40673 .49995 .41215 .49822 .41118 .49725 Metetra
.664 .741 .907 r
.41118 .49725 .41215 .49822 .41759 .49648 .41662 .49551 Metetra
.664 .741 .907 r
.41662 .49551 .41759 .49648 .42304 .49474 .42207 .49377 Metetra
.664 .741 .907 r
.42207 .49377 .42304 .49474 .42849 .493 .42753 .49203 Metetra
.664 .741 .907 r
.42753 .49203 .42849 .493 .43396 .49126 .433 .49028 Metetra
.664 .741 .907 r
.433 .49028 .43396 .49126 .43944 .48951 .43848 .48853 Metetra
.664 .741 .907 r
.43848 .48853 .43944 .48951 .44493 .48776 .44397 .48678 Metetra
.953 .672 .466 r
.44397 .48678 .44493 .48776 .44574 .69457 .44701 .59315 Metetra
.657 .43 .564 r
.44701 .59315 .44574 .69457 .45595 .48424 .45499 .48326 Metetra
.664 .741 .907 r
.45499 .48326 .45595 .48424 .46147 .48248 .46052 .48149 Metetra
.664 .741 .907 r
.46052 .48149 .46147 .48248 .46701 .48071 .46606 .47972 Metetra
.664 .741 .907 r
.46606 .47972 .46701 .48071 .47255 .47894 .47161 .47795 Metetra
.664 .741 .907 r
.47161 .47795 .47255 .47894 .47811 .47717 .47717 .47617 Metetra
.664 .741 .907 r
.47717 .47617 .47811 .47717 .48368 .47539 .48274 .47439 Metetra
.664 .741 .907 r
.48274 .47439 .48368 .47539 .48926 .47361 .48832 .47261 Metetra
.664 .741 .907 r
.48832 .47261 .48926 .47361 .49485 .47182 .49392 .47082 Metetra
.664 .741 .907 r
.49392 .47082 .49485 .47182 .50046 .47003 .49952 .46903 Metetra
.664 .741 .907 r
.49952 .46903 .50046 .47003 .50607 .46824 .50514 .46724 Metetra
.664 .741 .907 r
.50514 .46724 .50607 .46824 .5117 .46644 .51077 .46544 Metetra
.664 .741 .907 r
.51077 .46544 .5117 .46644 .51734 .46464 .51641 .46364 Metetra
.664 .741 .907 r
.51641 .46364 .51734 .46464 .52299 .46284 .52206 .46183 Metetra
.664 .741 .907 r
.52206 .46183 .52299 .46284 .52865 .46103 .52772 .46002 Metetra
.512 .684 .944 r
.52772 .46002 .52865 .46103 .53432 .45922 .5334 .45996 Metetra
.5334 .45996 .53432 .45922 .54001 .45741 .53909 .45639 Metetra
.664 .741 .907 r
.53909 .45639 .54001 .45741 .5457 .45559 .54479 .45457 Metetra
.664 .741 .907 r
.54479 .45457 .5457 .45559 .55141 .45377 .5505 .45275 Metetra
.664 .741 .907 r
.5505 .45275 .55141 .45377 .55713 .45194 .55622 .45092 Metetra
.664 .741 .907 r
.55622 .45092 .55713 .45194 .56287 .45011 .56195 .44909 Metetra
.664 .741 .907 r
.56195 .44909 .56287 .45011 .56861 .44828 .5677 .44726 Metetra
.664 .741 .907 r
.5677 .44726 .56861 .44828 .57437 .44644 .57346 .44542 Metetra
.664 .741 .907 r
.57346 .44542 .57437 .44644 .58013 .4446 .57923 .44357 Metetra
.664 .741 .907 r
.57923 .44357 .58013 .4446 .58591 .44276 .58501 .44173 Metetra
.664 .741 .907 r
.58501 .44173 .58591 .44276 .5917 .44091 .59081 .43987 Metetra
.664 .741 .907 r
.59081 .43987 .5917 .44091 .59751 .43905 .59661 .43802 Metetra
.664 .741 .907 r
.59661 .43802 .59751 .43905 .60332 .4372 .60243 .43616 Metetra
.664 .741 .907 r
.60243 .43616 .60332 .4372 .60915 .43534 .60826 .4343 Metetra
.664 .741 .907 r
.60826 .4343 .60915 .43534 .61499 .43347 .6141 .43243 Metetra
.664 .741 .907 r
.6141 .43243 .61499 .43347 .62085 .43161 .61996 .43056 Metetra
.664 .741 .907 r
.61996 .43056 .62085 .43161 .62671 .42973 .62583 .42869 Metetra
.664 .741 .907 r
.62583 .42869 .62671 .42973 .63259 .42786 .63171 .42681 Metetra
.664 .741 .907 r
.63171 .42681 .63259 .42786 .63892 .43872 .6376 .42493 Metetra
.464 .308 .584 r
.6376 .42493 .63892 .43872 .64554 .45548 .64402 .43727 Metetra
.64 .43 .582 r
.64402 .43727 .64554 .45548 .65029 .42221 .64942 .42115 Metetra
.664 .741 .907 r
.64942 .42115 .65029 .42221 .65622 .42031 .65535 .41926 Metetra
.664 .741 .907 r
.65535 .41926 .65622 .42031 .66216 .41842 .66129 .41736 Metetra
.664 .741 .907 r
.66129 .41736 .66216 .41842 .66811 .41652 .66725 .41546 Metetra
.664 .741 .907 r
.66725 .41546 .66811 .41652 .67408 .41462 .67321 .41355 Metetra
.664 .741 .907 r
.67321 .41355 .67408 .41462 .68005 .41271 .67919 .41164 Metetra
.664 .741 .907 r
.67919 .41164 .68005 .41271 .68604 .4108 .68519 .40973 Metetra
.664 .741 .907 r
.68519 .40973 .68604 .4108 .69205 .40888 .69119 .40781 Metetra
.664 .741 .907 r
.69119 .40781 .69205 .40888 .69806 .40696 .69721 .40589 Metetra
.664 .741 .907 r
.69721 .40589 .69806 .40696 .70409 .40504 .70324 .40396 Metetra
.664 .741 .907 r
.70324 .40396 .70409 .40504 .71013 .40311 .70928 .40203 Metetra
.664 .741 .907 r
.70928 .40203 .71013 .40311 .71618 .40117 .71534 .4001 Metetra
.664 .741 .907 r
.71534 .4001 .71618 .40117 .72225 .39924 .72141 .39816 Metetra
.664 .741 .907 r
.72141 .39816 .72225 .39924 .72833 .3973 .72749 .39621 Metetra
.664 .741 .907 r
.72749 .39621 .72833 .3973 .73442 .39535 .73359 .39427 Metetra
.664 .741 .907 r
.73359 .39427 .73442 .39535 .74053 .3934 .73969 .39232 Metetra
.664 .741 .907 r
.73969 .39232 .74053 .3934 .74665 .39145 .74582 .39036 Metetra
.664 .741 .907 r
.74582 .39036 .74665 .39145 .75278 .38949 .75195 .3884 Metetra
.664 .741 .907 r
.75195 .3884 .75278 .38949 .75892 .38753 .7581 .38644 Metetra
.664 .741 .907 r
.7581 .38644 .75892 .38753 .76508 .38557 .76426 .38447 Metetra
.664 .741 .907 r
.76426 .38447 .76508 .38557 .77125 .3836 .77043 .3825 Metetra
.664 .741 .907 r
.77043 .3825 .77125 .3836 .77744 .38162 .77662 .38052 Metetra
.664 .741 .907 r
.77662 .38052 .77744 .38162 .78364 .37965 .78282 .37854 Metetra
.664 .741 .907 r
.78282 .37854 .78364 .37965 .78985 .37766 .78904 .37655 Metetra
.664 .741 .907 r
.78904 .37655 .78985 .37766 .79607 .37568 .79526 .37457 Metetra
.664 .741 .907 r
.79526 .37457 .79607 .37568 .80231 .37368 .8015 .37257 Metetra
.664 .741 .907 r
.8015 .37257 .80231 .37368 .80856 .37169 .80776 .37057 Metetra
.664 .741 .907 r
.80776 .37057 .80856 .37169 .81483 .36969 .81403 .36857 Metetra
.664 .741 .907 r
.81403 .36857 .81483 .36969 .82111 .36769 .82031 .36657 Metetra
.664 .741 .907 r
.82031 .36657 .82111 .36769 .8274 .36568 .8266 .36455 Metetra
.664 .741 .907 r
.8266 .36455 .8274 .36568 .8337 .36366 .83291 .36254 Metetra
.664 .741 .907 r
.83291 .36254 .8337 .36366 .8422 .38366 .83924 .36052 Metetra
.572 .375 .576 r
.83924 .36052 .8422 .38366 .84636 .35962 .84557 .3585 Metetra
.664 .741 .907 r
.84557 .3585 .84636 .35962 .85271 .3576 .85192 .35647 Metetra
.664 .741 .907 r
.85192 .35647 .85271 .3576 .85907 .35557 .85829 .35443 Metetra
.664 .741 .907 r
.85829 .35443 .85907 .35557 .86544 .35353 .86467 .3524 Metetra
.664 .741 .907 r
.86467 .3524 .86544 .35353 .87183 .35149 .87106 .35035 Metetra
.664 .741 .907 r
.87106 .35035 .87183 .35149 .87823 .34945 .87746 .34831 Metetra
.664 .741 .907 r
.87746 .34831 .87823 .34945 .88465 .3474 .88388 .34626 Metetra
.664 .741 .907 r
.88388 .34626 .88465 .3474 .89108 .34535 .89032 .3442 Metetra
.664 .741 .907 r
.89032 .3442 .89108 .34535 .89753 .34329 .89677 .34214 Metetra
.664 .741 .907 r
.89677 .34214 .89753 .34329 .90399 .34123 .90323 .34008 Metetra
.664 .741 .907 r
.90323 .34008 .90399 .34123 .91046 .33916 .90971 .33801 Metetra
.664 .741 .907 r
.32465 .52363 .32565 .52457 .33092 .52289 .32992 .52195 Metetra
.664 .741 .907 r
.32992 .52195 .33092 .52289 .33619 .5212 .33519 .52026 Metetra
.664 .741 .907 r
.33519 .52026 .33619 .5212 .34148 .51952 .34048 .51857 Metetra
.664 .741 .907 r
.34048 .51857 .34148 .51952 .34678 .51782 .34578 .51688 Metetra
.664 .741 .907 r
.34578 .51688 .34678 .51782 .35209 .51613 .35109 .51518 Metetra
.944 .61 .363 r
.35109 .51518 .35209 .51613 .35497 .56296 .35518 .53787 Metetra
.653 .439 .58 r
.35518 .53787 .35497 .56296 .36273 .51273 .36174 .51178 Metetra
.664 .741 .907 r
.36174 .51178 .36273 .51273 .36808 .51102 .36709 .51007 Metetra
.664 .741 .907 r
.36709 .51007 .36808 .51102 .37343 .50931 .37244 .50836 Metetra
.664 .741 .907 r
.37244 .50836 .37343 .50931 .37879 .5076 .3778 .50664 Metetra
.664 .741 .907 r
.3778 .50664 .37879 .5076 .38416 .50588 .38318 .50492 Metetra
.664 .741 .907 r
.38318 .50492 .38416 .50588 .38954 .50416 .38856 .5032 Metetra
.664 .741 .907 r
.38856 .5032 .38954 .50416 .39494 .50244 .39396 .50148 Metetra
.664 .741 .907 r
.39396 .50148 .39494 .50244 .40034 .50071 .39937 .49975 Metetra
.664 .741 .907 r
.39937 .49975 .40034 .50071 .40576 .49898 .40478 .49802 Metetra
.664 .741 .907 r
.40478 .49802 .40576 .49898 .41118 .49725 .41021 .49628 Metetra
.664 .741 .907 r
.41021 .49628 .41118 .49725 .41662 .49551 .41565 .49454 Metetra
.664 .741 .907 r
.41565 .49454 .41662 .49551 .42207 .49377 .4211 .4928 Metetra
.664 .741 .907 r
.4211 .4928 .42207 .49377 .42753 .49203 .42656 .49106 Metetra
.664 .741 .907 r
.42656 .49106 .42753 .49203 .433 .49028 .43204 .48931 Metetra
.664 .741 .907 r
.43204 .48931 .433 .49028 .43848 .48853 .43752 .48755 Metetra
.664 .741 .907 r
.43752 .48755 .43848 .48853 .44397 .48678 .44301 .4858 Metetra
.664 .741 .907 r
.44301 .4858 .44397 .48678 .44701 .59315 .44852 .48404 Metetra
.548 .342 .553 r
.44852 .48404 .44701 .59315 .45499 .48326 .45373 .49676 Metetra
.395 .182 .468 r
.45373 .49676 .45499 .48326 .46052 .48149 .45957 .48051 Metetra
.664 .741 .907 r
.45957 .48051 .46052 .48149 .46606 .47972 .46511 .47873 Metetra
.664 .741 .907 r
.46511 .47873 .46606 .47972 .47161 .47795 .47066 .47696 Metetra
.938 .569 .256 r
.47066 .47696 .47161 .47795 .47717 .47617 .47591 .49638 Metetra
.41 .206 .489 r
.47591 .49638 .47717 .47617 .48274 .47439 .48179 .4734 Metetra
.664 .741 .907 r
.48179 .4734 .48274 .47439 .48832 .47261 .48738 .47161 Metetra
.664 .741 .907 r
.48738 .47161 .48832 .47261 .49392 .47082 .49298 .46983 Metetra
.664 .741 .907 r
.49298 .46983 .49392 .47082 .49952 .46903 .49858 .46803 Metetra
.664 .741 .907 r
.49858 .46803 .49952 .46903 .50514 .46724 .5042 .46624 Metetra
.664 .741 .907 r
.5042 .46624 .50514 .46724 .51077 .46544 .50983 .46444 Metetra
.664 .741 .907 r
.50983 .46444 .51077 .46544 .51641 .46364 .51548 .46263 Metetra
.664 .741 .907 r
.51548 .46263 .51641 .46364 .52206 .46183 .52113 .46083 Metetra
.664 .741 .907 r
.52113 .46083 .52206 .46183 .52772 .46002 .5268 .45901 Metetra
.664 .741 .907 r
.5268 .45901 .52772 .46002 .5334 .45996 .53248 .4572 Metetra
.63 .54 .734 r
.53248 .4572 .5334 .45996 .53909 .45639 .53817 .45538 Metetra
.664 .741 .907 r
.53817 .45538 .53909 .45639 .54479 .45457 .54387 .45356 Metetra
.664 .741 .907 r
.54387 .45356 .54479 .45457 .5505 .45275 .54958 .45173 Metetra
.664 .741 .907 r
.54958 .45173 .5505 .45275 .55622 .45092 .5553 .4499 Metetra
.664 .741 .907 r
.5553 .4499 .55622 .45092 .56195 .44909 .56104 .44807 Metetra
.664 .741 .907 r
.56104 .44807 .56195 .44909 .5677 .44726 .56679 .44623 Metetra
.664 .741 .907 r
.56679 .44623 .5677 .44726 .57346 .44542 .57255 .44439 Metetra
.664 .741 .907 r
.57255 .44439 .57346 .44542 .57923 .44357 .57832 .44254 Metetra
.664 .741 .907 r
.57832 .44254 .57923 .44357 .58501 .44173 .58411 .44069 Metetra
.664 .741 .907 r
.58411 .44069 .58501 .44173 .59081 .43987 .58991 .43884 Metetra
.664 .741 .907 r
.58991 .43884 .59081 .43987 .59661 .43802 .59571 .43698 Metetra
.664 .741 .907 r
.59571 .43698 .59661 .43802 .60243 .43616 .60154 .43512 Metetra
.664 .741 .907 r
.60154 .43512 .60243 .43616 .60826 .4343 .60737 .43326 Metetra
.664 .741 .907 r
.60737 .43326 .60826 .4343 .6141 .43243 .61321 .43139 Metetra
.664 .741 .907 r
.61321 .43139 .6141 .43243 .61996 .43056 .61907 .42952 Metetra
.664 .741 .907 r
.61907 .42952 .61996 .43056 .62583 .42869 .62494 .42764 Metetra
.664 .741 .907 r
.62494 .42764 .62583 .42869 .63171 .42681 .63082 .42576 Metetra
.664 .741 .907 r
.63082 .42576 .63171 .42681 .6376 .42493 .63672 .42388 Metetra
.607 .136 0 r
.63672 .42388 .6376 .42493 .64402 .43727 .64299 .43207 Metetra
.731 .542 .637 r
.64299 .43207 .64402 .43727 .64942 .42115 .64855 .4201 Metetra
.664 .741 .907 r
.64855 .4201 .64942 .42115 .65535 .41926 .65448 .4182 Metetra
.664 .741 .907 r
.65448 .4182 .65535 .41926 .66129 .41736 .66042 .4163 Metetra
.664 .741 .907 r
.66042 .4163 .66129 .41736 .66725 .41546 .66638 .41439 Metetra
.664 .741 .907 r
.66638 .41439 .66725 .41546 .67321 .41355 .67235 .41249 Metetra
.664 .741 .907 r
.67235 .41249 .67321 .41355 .67919 .41164 .67833 .41057 Metetra
.664 .741 .907 r
.67833 .41057 .67919 .41164 .68519 .40973 .68433 .40866 Metetra
.664 .741 .907 r
.68433 .40866 .68519 .40973 .69119 .40781 .69033 .40674 Metetra
.664 .741 .907 r
.69033 .40674 .69119 .40781 .69721 .40589 .69635 .40481 Metetra
.664 .741 .907 r
.69635 .40481 .69721 .40589 .70324 .40396 .70239 .40288 Metetra
.664 .741 .907 r
.70239 .40288 .70324 .40396 .70928 .40203 .70843 .40095 Metetra
.664 .741 .907 r
.70843 .40095 .70928 .40203 .71534 .4001 .71449 .39901 Metetra
.664 .741 .907 r
.71449 .39901 .71534 .4001 .72141 .39816 .72056 .39707 Metetra
.664 .741 .907 r
.72056 .39707 .72141 .39816 .72749 .39621 .72665 .39513 Metetra
.664 .741 .907 r
.72665 .39513 .72749 .39621 .73359 .39427 .73275 .39318 Metetra
.664 .741 .907 r
.73275 .39318 .73359 .39427 .73969 .39232 .73886 .39123 Metetra
.664 .741 .907 r
.73886 .39123 .73969 .39232 .74582 .39036 .74498 .38927 Metetra
.664 .741 .907 r
.74498 .38927 .74582 .39036 .75195 .3884 .75112 .38731 Metetra
.664 .741 .907 r
.75112 .38731 .75195 .3884 .7581 .38644 .75727 .38534 Metetra
.664 .741 .907 r
.75727 .38534 .7581 .38644 .76426 .38447 .76343 .38337 Metetra
.664 .741 .907 r
.76343 .38337 .76426 .38447 .77043 .3825 .76961 .3814 Metetra
.664 .741 .907 r
.76961 .3814 .77043 .3825 .77662 .38052 .7758 .37942 Metetra
.664 .741 .907 r
.7758 .37942 .77662 .38052 .78282 .37854 .78201 .37743 Metetra
.664 .741 .907 r
.78201 .37743 .78282 .37854 .78904 .37655 .78822 .37545 Metetra
.664 .741 .907 r
.78822 .37545 .78904 .37655 .79526 .37457 .79445 .37345 Metetra
.664 .741 .907 r
.79445 .37345 .79526 .37457 .8015 .37257 .8007 .37146 Metetra
.664 .741 .907 r
.8007 .37146 .8015 .37257 .80776 .37057 .80695 .36946 Metetra
.664 .741 .907 r
.80695 .36946 .80776 .37057 .81403 .36857 .81323 .36745 Metetra
.664 .741 .907 r
.81323 .36745 .81403 .36857 .82031 .36657 .81951 .36544 Metetra
.664 .741 .907 r
.81951 .36544 .82031 .36657 .8266 .36455 .82581 .36343 Metetra
.664 .741 .907 r
.82581 .36343 .8266 .36455 .83291 .36254 .83212 .36141 Metetra
.664 .741 .907 r
.83212 .36141 .83291 .36254 .83924 .36052 .83845 .35939 Metetra
.664 .741 .907 r
.83845 .35939 .83924 .36052 .84557 .3585 .84479 .35736 Metetra
.664 .741 .907 r
.84479 .35736 .84557 .3585 .85192 .35647 .85114 .35533 Metetra
.664 .741 .907 r
.85114 .35533 .85192 .35647 .85829 .35443 .85751 .3533 Metetra
.664 .741 .907 r
.85751 .3533 .85829 .35443 .86467 .3524 .86389 .35126 Metetra
.664 .741 .907 r
.86389 .35126 .86467 .3524 .87106 .35035 .87028 .34921 Metetra
.664 .741 .907 r
.87028 .34921 .87106 .35035 .87746 .34831 .87669 .34717 Metetra
.664 .741 .907 r
.87669 .34717 .87746 .34831 .88388 .34626 .88312 .34511 Metetra
.664 .741 .907 r
.88312 .34511 .88388 .34626 .89032 .3442 .88955 .34305 Metetra
.664 .741 .907 r
.88955 .34305 .89032 .3442 .89677 .34214 .89601 .34099 Metetra
.664 .741 .907 r
.89601 .34099 .89677 .34214 .90323 .34008 .90247 .33892 Metetra
.664 .741 .907 r
.90247 .33892 .90323 .34008 .90971 .33801 .90895 .33685 Metetra
.664 .741 .907 r
.32364 .5227 .32465 .52363 .32992 .52195 .32891 .52101 Metetra
.664 .741 .907 r
.32891 .52101 .32992 .52195 .33519 .52026 .33419 .51932 Metetra
.664 .741 .907 r
.33419 .51932 .33519 .52026 .34048 .51857 .33948 .51763 Metetra
.664 .741 .907 r
.33948 .51763 .34048 .51857 .34578 .51688 .34478 .51593 Metetra
.664 .741 .907 r
.34478 .51593 .34578 .51688 .35109 .51518 .3501 .51423 Metetra
.868 .425 .05 r
.3501 .51423 .35109 .51518 .35518 .53787 .35485 .52379 Metetra
.646 .443 .594 r
.35485 .52379 .35518 .53787 .36174 .51178 .36075 .51082 Metetra
.664 .741 .907 r
.36075 .51082 .36174 .51178 .36709 .51007 .3661 .50911 Metetra
.664 .741 .907 r
.3661 .50911 .36709 .51007 .37244 .50836 .37145 .5074 Metetra
.664 .741 .907 r
.37145 .5074 .37244 .50836 .3778 .50664 .37682 .50568 Metetra
.664 .741 .907 r
.37682 .50568 .3778 .50664 .38318 .50492 .38219 .50396 Metetra
.664 .741 .907 r
.38219 .50396 .38318 .50492 .38856 .5032 .38758 .50224 Metetra
.664 .741 .907 r
.38758 .50224 .38856 .5032 .39396 .50148 .39298 .50051 Metetra
.664 .741 .907 r
.39298 .50051 .39396 .50148 .39937 .49975 .39839 .49878 Metetra
.664 .741 .907 r
.39839 .49878 .39937 .49975 .40478 .49802 .40381 .49705 Metetra
.664 .741 .907 r
.40381 .49705 .40478 .49802 .41021 .49628 .40924 .49531 Metetra
.664 .741 .907 r
.40924 .49531 .41021 .49628 .41565 .49454 .41468 .49357 Metetra
.664 .741 .907 r
.41468 .49357 .41565 .49454 .4211 .4928 .42013 .49183 Metetra
.664 .741 .907 r
.42013 .49183 .4211 .4928 .42656 .49106 .4256 .49008 Metetra
.664 .741 .907 r
.4256 .49008 .42656 .49106 .43204 .48931 .43107 .48833 Metetra
.664 .741 .907 r
.43107 .48833 .43204 .48931 .43752 .48755 .43656 .48657 Metetra
.664 .741 .907 r
.43656 .48657 .43752 .48755 .44301 .4858 .44205 .48482 Metetra
.664 .741 .907 r
.44205 .48482 .44301 .4858 .44852 .48404 .44756 .48305 Metetra
.664 .741 .907 r
.44756 .48305 .44852 .48404 .45373 .49676 .45308 .48129 Metetra
.576 .386 .587 r
.45308 .48129 .45373 .49676 .45957 .48051 .45861 .47952 Metetra
.664 .741 .907 r
.45861 .47952 .45957 .48051 .46511 .47873 .46415 .47775 Metetra
.933 .555 .232 r
.46415 .47775 .46511 .47873 .47066 .47696 .46938 .49549 Metetra
.78 .517 .539 r
.46938 .49549 .47066 .47696 .47591 .49638 .47375 .57526 Metetra
.384 .202 .507 r
.47375 .57526 .47591 .49638 .48179 .4734 .48085 .4724 Metetra
.664 .741 .907 r
.48085 .4724 .48179 .4734 .48738 .47161 .48644 .47062 Metetra
.664 .741 .907 r
.48644 .47062 .48738 .47161 .49298 .46983 .49203 .46883 Metetra
.664 .741 .907 r
.49203 .46883 .49298 .46983 .49858 .46803 .49765 .46703 Metetra
.664 .741 .907 r
.49765 .46703 .49858 .46803 .5042 .46624 .50327 .46523 Metetra
.664 .741 .907 r
.50327 .46523 .5042 .46624 .50983 .46444 .5089 .46343 Metetra
.664 .741 .907 r
.5089 .46343 .50983 .46444 .51548 .46263 .51455 .46162 Metetra
.664 .741 .907 r
.51455 .46162 .51548 .46263 .52113 .46083 .5202 .45982 Metetra
.664 .741 .907 r
.5202 .45982 .52113 .46083 .5268 .45901 .52587 .458 Metetra
.664 .741 .907 r
.52587 .458 .5268 .45901 .53248 .4572 .53155 .45618 Metetra
.664 .741 .907 r
.53155 .45618 .53248 .4572 .53817 .45538 .53724 .45436 Metetra
.664 .741 .907 r
.53724 .45436 .53817 .45538 .54387 .45356 .54295 .45254 Metetra
.664 .741 .907 r
.54295 .45254 .54387 .45356 .54958 .45173 .54866 .45071 Metetra
.664 .741 .907 r
.54866 .45071 .54958 .45173 .5553 .4499 .55439 .44888 Metetra
.664 .741 .907 r
.55439 .44888 .5553 .4499 .56104 .44807 .56013 .44704 Metetra
.664 .741 .907 r
.56013 .44704 .56104 .44807 .56679 .44623 .56588 .4452 Metetra
.664 .741 .907 r
.56588 .4452 .56679 .44623 .57255 .44439 .57164 .44336 Metetra
.664 .741 .907 r
.57164 .44336 .57255 .44439 .57832 .44254 .57742 .44151 Metetra
.664 .741 .907 r
.57742 .44151 .57832 .44254 .58411 .44069 .5832 .43966 Metetra
.664 .741 .907 r
.5832 .43966 .58411 .44069 .58991 .43884 .589 .43781 Metetra
.664 .741 .907 r
.589 .43781 .58991 .43884 .59571 .43698 .59482 .43595 Metetra
.664 .741 .907 r
.59482 .43595 .59571 .43698 .60154 .43512 .60064 .43408 Metetra
.664 .741 .907 r
.60064 .43408 .60154 .43512 .60737 .43326 .60647 .43222 Metetra
.664 .741 .907 r
.60647 .43222 .60737 .43326 .61321 .43139 .61232 .43035 Metetra
.664 .741 .907 r
.61232 .43035 .61321 .43139 .61907 .42952 .61818 .42847 Metetra
.664 .741 .907 r
.61818 .42847 .61907 .42952 .62494 .42764 .62406 .42659 Metetra
.664 .741 .907 r
.62406 .42659 .62494 .42764 .63082 .42576 .62994 .42471 Metetra
.664 .741 .907 r
.62994 .42471 .63082 .42576 .63672 .42388 .63584 .42282 Metetra
.664 .741 .907 r
.63584 .42282 .63672 .42388 .64299 .43207 .64175 .42093 Metetra
.582 .401 .602 r
.64175 .42093 .64299 .43207 .64855 .4201 .64767 .41904 Metetra
.664 .741 .907 r
.64767 .41904 .64855 .4201 .65448 .4182 .6536 .41714 Metetra
.664 .741 .907 r
.6536 .41714 .65448 .4182 .66042 .4163 .65955 .41524 Metetra
.664 .741 .907 r
.65955 .41524 .66042 .4163 .66638 .41439 .66551 .41333 Metetra
.664 .741 .907 r
.66551 .41333 .66638 .41439 .67235 .41249 .67148 .41142 Metetra
.664 .741 .907 r
.67148 .41142 .67235 .41249 .67833 .41057 .67747 .40951 Metetra
.664 .741 .907 r
.67747 .40951 .67833 .41057 .68433 .40866 .68347 .40759 Metetra
.963 .632 .312 r
.68347 .40759 .68433 .40866 .69033 .40674 .69235 .46197 Metetra
.44 .249 .524 r
.69235 .46197 .69033 .40674 .69635 .40481 .6955 .40374 Metetra
.664 .741 .907 r
.6955 .40374 .69635 .40481 .70239 .40288 .70153 .40181 Metetra
.664 .741 .907 r
.70153 .40181 .70239 .40288 .70843 .40095 .70758 .39987 Metetra
.664 .741 .907 r
.70758 .39987 .70843 .40095 .71449 .39901 .71365 .39793 Metetra
.664 .741 .907 r
.71365 .39793 .71449 .39901 .72056 .39707 .71972 .39599 Metetra
.664 .741 .907 r
.71972 .39599 .72056 .39707 .72665 .39513 .72581 .39404 Metetra
.664 .741 .907 r
.72581 .39404 .72665 .39513 .73275 .39318 .73191 .39209 Metetra
.664 .741 .907 r
.73191 .39209 .73275 .39318 .73886 .39123 .73802 .39013 Metetra
.664 .741 .907 r
.73802 .39013 .73886 .39123 .74498 .38927 .74415 .38817 Metetra
.664 .741 .907 r
.74415 .38817 .74498 .38927 .75112 .38731 .75029 .38621 Metetra
.664 .741 .907 r
.75029 .38621 .75112 .38731 .75727 .38534 .75644 .38424 Metetra
.664 .741 .907 r
.75644 .38424 .75727 .38534 .76343 .38337 .76261 .38227 Metetra
.664 .741 .907 r
.76261 .38227 .76343 .38337 .76961 .3814 .76879 .38029 Metetra
.664 .741 .907 r
.76879 .38029 .76961 .3814 .7758 .37942 .77498 .37831 Metetra
.664 .741 .907 r
.77498 .37831 .7758 .37942 .78201 .37743 .78119 .37633 Metetra
.664 .741 .907 r
.78119 .37633 .78201 .37743 .78822 .37545 .78741 .37434 Metetra
.664 .741 .907 r
.78741 .37434 .78822 .37545 .79445 .37345 .79364 .37234 Metetra
.664 .741 .907 r
.79364 .37234 .79445 .37345 .8007 .37146 .79989 .37034 Metetra
.664 .741 .907 r
.79989 .37034 .8007 .37146 .80695 .36946 .80615 .36834 Metetra
.664 .741 .907 r
.80615 .36834 .80695 .36946 .81323 .36745 .81242 .36633 Metetra
.664 .741 .907 r
.81242 .36633 .81323 .36745 .81951 .36544 .81871 .36432 Metetra
.664 .741 .907 r
.81871 .36432 .81951 .36544 .82581 .36343 .82501 .36231 Metetra
.664 .741 .907 r
.82501 .36231 .82581 .36343 .83212 .36141 .83133 .36029 Metetra
.664 .741 .907 r
.83133 .36029 .83212 .36141 .83845 .35939 .83766 .35826 Metetra
.664 .741 .907 r
.83766 .35826 .83845 .35939 .84479 .35736 .844 .35623 Metetra
.664 .741 .907 r
.844 .35623 .84479 .35736 .85114 .35533 .85036 .3542 Metetra
.664 .741 .907 r
.85036 .3542 .85114 .35533 .85751 .3533 .85673 .35216 Metetra
.664 .741 .907 r
.85673 .35216 .85751 .3533 .86389 .35126 .86311 .35012 Metetra
.664 .741 .907 r
.86311 .35012 .86389 .35126 .87028 .34921 .86951 .34807 Metetra
.664 .741 .907 r
.86951 .34807 .87028 .34921 .87669 .34717 .87592 .34602 Metetra
.664 .741 .907 r
.87592 .34602 .87669 .34717 .88312 .34511 .88235 .34396 Metetra
.664 .741 .907 r
.88235 .34396 .88312 .34511 .88955 .34305 .88879 .3419 Metetra
.664 .741 .907 r
.88879 .3419 .88955 .34305 .89601 .34099 .89524 .33984 Metetra
.664 .741 .907 r
.89524 .33984 .89601 .34099 .90247 .33892 .90171 .33777 Metetra
.664 .741 .907 r
.90171 .33777 .90247 .33892 .90895 .33685 .9082 .3357 Metetra
.664 .741 .907 r
.32264 .52176 .32364 .5227 .32891 .52101 .32791 .52007 Metetra
.664 .741 .907 r
.32791 .52007 .32891 .52101 .33419 .51932 .33319 .51838 Metetra
.664 .741 .907 r
.33319 .51838 .33419 .51932 .33948 .51763 .33848 .51668 Metetra
.664 .741 .907 r
.33848 .51668 .33948 .51763 .34478 .51593 .34379 .51498 Metetra
.664 .741 .907 r
.34379 .51498 .34478 .51593 .3501 .51423 .3491 .51328 Metetra
.664 .741 .907 r
.3491 .51328 .3501 .51423 .35485 .52379 .35442 .51158 Metetra
.58 .395 .596 r
.35442 .51158 .35485 .52379 .36075 .51082 .35976 .50987 Metetra
.664 .741 .907 r
.35976 .50987 .36075 .51082 .3661 .50911 .36511 .50816 Metetra
.664 .741 .907 r
.36511 .50816 .3661 .50911 .37145 .5074 .37046 .50644 Metetra
.664 .741 .907 r
.37046 .50644 .37145 .5074 .37682 .50568 .37583 .50473 Metetra
.664 .741 .907 r
.37583 .50473 .37682 .50568 .38219 .50396 .38121 .503 Metetra
.664 .741 .907 r
.38121 .503 .38219 .50396 .38758 .50224 .3866 .50128 Metetra
.664 .741 .907 r
.3866 .50128 .38758 .50224 .39298 .50051 .392 .49955 Metetra
.664 .741 .907 r
.392 .49955 .39298 .50051 .39839 .49878 .39741 .49782 Metetra
.664 .741 .907 r
.39741 .49782 .39839 .49878 .40381 .49705 .40283 .49608 Metetra
.664 .741 .907 r
.40283 .49608 .40381 .49705 .40924 .49531 .40826 .49434 Metetra
.664 .741 .907 r
.40826 .49434 .40924 .49531 .41468 .49357 .41371 .4926 Metetra
.664 .741 .907 r
.41371 .4926 .41468 .49357 .42013 .49183 .41916 .49085 Metetra
.664 .741 .907 r
.41916 .49085 .42013 .49183 .4256 .49008 .42463 .4891 Metetra
.664 .741 .907 r
.42463 .4891 .4256 .49008 .43107 .48833 .43011 .48735 Metetra
.664 .741 .907 r
.43011 .48735 .43107 .48833 .43656 .48657 .43559 .48559 Metetra
.664 .741 .907 r
.43559 .48559 .43656 .48657 .44205 .48482 .44109 .48383 Metetra
.664 .741 .907 r
.44109 .48383 .44205 .48482 .44756 .48305 .4466 .48207 Metetra
.664 .741 .907 r
.4466 .48207 .44756 .48305 .45308 .48129 .45212 .4803 Metetra
.664 .741 .907 r
.45212 .4803 .45308 .48129 .45861 .47952 .45766 .47853 Metetra
.664 .741 .907 r
.45766 .47853 .45861 .47952 .46415 .47775 .4632 .47675 Metetra
.954 .678 .474 r
.4632 .47675 .46415 .47775 .46938 .49549 .46565 .65725 Metetra
.52 .313 .539 r
.46565 .65725 .46938 .49549 .47375 .57526 .47242 .59718 Metetra
.73 .627 .062 r
.47242 .59718 .47375 .57526 .48085 .4724 .4799 .47141 Metetra
.664 .741 .907 r
.4799 .47141 .48085 .4724 .48644 .47062 .48549 .46962 Metetra
.664 .741 .907 r
.48549 .46962 .48644 .47062 .49203 .46883 .49109 .46783 Metetra
.664 .741 .907 r
.49109 .46783 .49203 .46883 .49765 .46703 .49671 .46603 Metetra
.664 .741 .907 r
.49671 .46603 .49765 .46703 .50327 .46523 .50233 .46423 Metetra
.664 .741 .907 r
.50233 .46423 .50327 .46523 .5089 .46343 .50797 .46242 Metetra
.664 .741 .907 r
.50797 .46242 .5089 .46343 .51455 .46162 .51361 .46062 Metetra
.664 .741 .907 r
.51361 .46062 .51455 .46162 .5202 .45982 .51927 .4588 Metetra
.664 .741 .907 r
.51927 .4588 .5202 .45982 .52587 .458 .52494 .45699 Metetra
.664 .741 .907 r
.52494 .45699 .52587 .458 .53155 .45618 .53063 .45517 Metetra
.664 .741 .907 r
.53063 .45517 .53155 .45618 .53724 .45436 .53632 .45335 Metetra
.664 .741 .907 r
.53632 .45335 .53724 .45436 .54295 .45254 .54203 .45152 Metetra
.664 .741 .907 r
.54203 .45152 .54295 .45254 .54866 .45071 .54774 .44969 Metetra
.664 .741 .907 r
.54774 .44969 .54866 .45071 .55439 .44888 .55347 .44786 Metetra
.664 .741 .907 r
.55347 .44786 .55439 .44888 .56013 .44704 .55921 .44602 Metetra
.664 .741 .907 r
.55921 .44602 .56013 .44704 .56588 .4452 .56497 .44418 Metetra
.664 .741 .907 r
.56497 .44418 .56588 .4452 .57164 .44336 .57073 .44233 Metetra
.664 .741 .907 r
.57073 .44233 .57164 .44336 .57742 .44151 .57651 .44048 Metetra
.664 .741 .907 r
.57651 .44048 .57742 .44151 .5832 .43966 .5823 .43863 Metetra
.664 .741 .907 r
.5823 .43863 .5832 .43966 .589 .43781 .5881 .43677 Metetra
.664 .741 .907 r
.5881 .43677 .589 .43781 .59482 .43595 .59392 .43491 Metetra
.664 .741 .907 r
.59392 .43491 .59482 .43595 .60064 .43408 .59974 .43304 Metetra
.664 .741 .907 r
.59974 .43304 .60064 .43408 .60647 .43222 .60558 .43117 Metetra
.664 .741 .907 r
.60558 .43117 .60647 .43222 .61232 .43035 .61143 .4293 Metetra
.664 .741 .907 r
.61143 .4293 .61232 .43035 .61818 .42847 .61729 .42742 Metetra
.664 .741 .907 r
.61729 .42742 .61818 .42847 .62406 .42659 .62317 .42554 Metetra
.664 .741 .907 r
.62317 .42554 .62406 .42659 .62994 .42471 .62906 .42366 Metetra
.664 .741 .907 r
.62906 .42366 .62994 .42471 .63584 .42282 .63495 .42177 Metetra
.664 .741 .907 r
.63495 .42177 .63584 .42282 .64175 .42093 .64087 .41988 Metetra
.664 .741 .907 r
.64087 .41988 .64175 .42093 .64767 .41904 .64679 .41798 Metetra
.664 .741 .907 r
.64679 .41798 .64767 .41904 .6536 .41714 .65273 .41608 Metetra
.664 .741 .907 r
.65273 .41608 .6536 .41714 .65955 .41524 .65868 .41417 Metetra
.664 .741 .907 r
.65868 .41417 .65955 .41524 .66551 .41333 .66464 .41227 Metetra
.664 .741 .907 r
.66464 .41227 .66551 .41333 .67148 .41142 .67062 .41035 Metetra
.664 .741 .907 r
.67062 .41035 .67148 .41142 .67747 .40951 .6766 .40844 Metetra
.664 .741 .907 r
.6766 .40844 .67747 .40951 .68347 .40759 .6826 .40652 Metetra
0 .025 .559 r
.6826 .40652 .68347 .40759 .69235 .46197 .68906 .41338 Metetra
.566 .361 .561 r
.68906 .41338 .69235 .46197 .6955 .40374 .69508 .41095 Metetra
.381 .149 .432 r
.69508 .41095 .6955 .40374 .70153 .40181 .70068 .40073 Metetra
.664 .741 .907 r
.70068 .40073 .70153 .40181 .70758 .39987 .70673 .39879 Metetra
.664 .741 .907 r
.70673 .39879 .70758 .39987 .71365 .39793 .7128 .39685 Metetra
.664 .741 .907 r
.7128 .39685 .71365 .39793 .71972 .39599 .71887 .3949 Metetra
.664 .741 .907 r
.71887 .3949 .71972 .39599 .72581 .39404 .72497 .39295 Metetra
.664 .741 .907 r
.72497 .39295 .72581 .39404 .73191 .39209 .73107 .391 Metetra
.664 .741 .907 r
.73107 .391 .73191 .39209 .73802 .39013 .73719 .38904 Metetra
.664 .741 .907 r
.73719 .38904 .73802 .39013 .74415 .38817 .74331 .38708 Metetra
.664 .741 .907 r
.74331 .38708 .74415 .38817 .75029 .38621 .74946 .38511 Metetra
.664 .741 .907 r
.74946 .38511 .75029 .38621 .75644 .38424 .75561 .38314 Metetra
.664 .741 .907 r
.75561 .38314 .75644 .38424 .76261 .38227 .76178 .38117 Metetra
.664 .741 .907 r
.76178 .38117 .76261 .38227 .76879 .38029 .76797 .37919 Metetra
.664 .741 .907 r
.76797 .37919 .76879 .38029 .77498 .37831 .77416 .3772 Metetra
.664 .741 .907 r
.77416 .3772 .77498 .37831 .78119 .37633 .78037 .37522 Metetra
.664 .741 .907 r
.78037 .37522 .78119 .37633 .78741 .37434 .78659 .37322 Metetra
.664 .741 .907 r
.78659 .37322 .78741 .37434 .79364 .37234 .79283 .37123 Metetra
.664 .741 .907 r
.79283 .37123 .79364 .37234 .79989 .37034 .79908 .36923 Metetra
.664 .741 .907 r
.79908 .36923 .79989 .37034 .80615 .36834 .80534 .36722 Metetra
.664 .741 .907 r
.80534 .36722 .80615 .36834 .81242 .36633 .81162 .36521 Metetra
.664 .741 .907 r
.81162 .36521 .81242 .36633 .81871 .36432 .81791 .3632 Metetra
.664 .741 .907 r
.81791 .3632 .81871 .36432 .82501 .36231 .82422 .36118 Metetra
.664 .741 .907 r
.82422 .36118 .82501 .36231 .83133 .36029 .83053 .35916 Metetra
.664 .741 .907 r
.83053 .35916 .83133 .36029 .83766 .35826 .83687 .35713 Metetra
.664 .741 .907 r
.83687 .35713 .83766 .35826 .844 .35623 .84321 .3551 Metetra
.664 .741 .907 r
.84321 .3551 .844 .35623 .85036 .3542 .84957 .35306 Metetra
.664 .741 .907 r
.84957 .35306 .85036 .3542 .85673 .35216 .85594 .35102 Metetra
.664 .741 .907 r
.85594 .35102 .85673 .35216 .86311 .35012 .86233 .34898 Metetra
.664 .741 .907 r
.86233 .34898 .86311 .35012 .86951 .34807 .86873 .34693 Metetra
.664 .741 .907 r
.86873 .34693 .86951 .34807 .87592 .34602 .87515 .34487 Metetra
.664 .741 .907 r
.87515 .34487 .87592 .34602 .88235 .34396 .88158 .34282 Metetra
.664 .741 .907 r
.88158 .34282 .88235 .34396 .88879 .3419 .88802 .34075 Metetra
.664 .741 .907 r
.88802 .34075 .88879 .3419 .89524 .33984 .89448 .33869 Metetra
.664 .741 .907 r
.89448 .33869 .89524 .33984 .90171 .33777 .90095 .33661 Metetra
.664 .741 .907 r
.90095 .33661 .90171 .33777 .9082 .3357 .90744 .33454 Metetra
.664 .741 .907 r
.32163 .52081 .32264 .52176 .32791 .52007 .3269 .51913 Metetra
.664 .741 .907 r
.3269 .51913 .32791 .52007 .33319 .51838 .33219 .51743 Metetra
.664 .741 .907 r
.33219 .51743 .33319 .51838 .33848 .51668 .33748 .51574 Metetra
.664 .741 .907 r
.33748 .51574 .33848 .51668 .34379 .51498 .34279 .51404 Metetra
.664 .741 .907 r
.34279 .51404 .34379 .51498 .3491 .51328 .3481 .51233 Metetra
.664 .741 .907 r
.3481 .51233 .3491 .51328 .35442 .51158 .35343 .51063 Metetra
.664 .741 .907 r
.35343 .51063 .35442 .51158 .35976 .50987 .35877 .50892 Metetra
.946 .625 .391 r
.35877 .50892 .35976 .50987 .36511 .50816 .3627 .53644 Metetra
.407 .207 .493 r
.3627 .53644 .36511 .50816 .37046 .50644 .36947 .50549 Metetra
.664 .741 .907 r
.36947 .50549 .37046 .50644 .37583 .50473 .37484 .50377 Metetra
.664 .741 .907 r
.37484 .50377 .37583 .50473 .38121 .503 .38022 .50204 Metetra
.664 .741 .907 r
.38022 .50204 .38121 .503 .3866 .50128 .38561 .50031 Metetra
.664 .741 .907 r
.38561 .50031 .3866 .50128 .392 .49955 .39102 .49858 Metetra
.664 .741 .907 r
.39102 .49858 .392 .49955 .39741 .49782 .39643 .49685 Metetra
.664 .741 .907 r
.39643 .49685 .39741 .49782 .40283 .49608 .40185 .49511 Metetra
.664 .741 .907 r
.40185 .49511 .40283 .49608 .40826 .49434 .40729 .49337 Metetra
.664 .741 .907 r
.40729 .49337 .40826 .49434 .41371 .4926 .41273 .49163 Metetra
.664 .741 .907 r
.41273 .49163 .41371 .4926 .41916 .49085 .41819 .48988 Metetra
.664 .741 .907 r
.41819 .48988 .41916 .49085 .42463 .4891 .42366 .48813 Metetra
.664 .741 .907 r
.42366 .48813 .42463 .4891 .43011 .48735 .42914 .48637 Metetra
.664 .741 .907 r
.42914 .48637 .43011 .48735 .43559 .48559 .43463 .48461 Metetra
.664 .741 .907 r
.43463 .48461 .43559 .48559 .44109 .48383 .44013 .48285 Metetra
.664 .741 .907 r
.44013 .48285 .44109 .48383 .4466 .48207 .44564 .48108 Metetra
.664 .741 .907 r
.44564 .48108 .4466 .48207 .45212 .4803 .45117 .47931 Metetra
.664 .741 .907 r
.45117 .47931 .45212 .4803 .45766 .47853 .4567 .47754 Metetra
.664 .741 .907 r
.4567 .47754 .45766 .47853 .4632 .47675 .46225 .47576 Metetra
.954 .678 .474 r
.46225 .47576 .4632 .47675 .46565 .65725 .46455 .66187 Metetra
.981 .733 .484 r
.46455 .66187 .46565 .65725 .47242 .59718 .47272 .51424 Metetra
.612 .393 .561 r
.47272 .51424 .47242 .59718 .4799 .47141 .47895 .47041 Metetra
.664 .741 .907 r
.47895 .47041 .4799 .47141 .48549 .46962 .48455 .46862 Metetra
.664 .741 .907 r
.48455 .46862 .48549 .46962 .49109 .46783 .49015 .46682 Metetra
.664 .741 .907 r
.49015 .46682 .49109 .46783 .49671 .46603 .49576 .46502 Metetra
.664 .741 .907 r
.49576 .46502 .49671 .46603 .50233 .46423 .50139 .46322 Metetra
.664 .741 .907 r
.50139 .46322 .50233 .46423 .50797 .46242 .50703 .46142 Metetra
.664 .741 .907 r
.50703 .46142 .50797 .46242 .51361 .46062 .51268 .45961 Metetra
.664 .741 .907 r
.51268 .45961 .51361 .46062 .51927 .4588 .51834 .45779 Metetra
.664 .741 .907 r
.51834 .45779 .51927 .4588 .52494 .45699 .52401 .45597 Metetra
.664 .741 .907 r
.52401 .45597 .52494 .45699 .53063 .45517 .5297 .45415 Metetra
.664 .741 .907 r
.5297 .45415 .53063 .45517 .53632 .45335 .53539 .45233 Metetra
.664 .741 .907 r
.53539 .45233 .53632 .45335 .54203 .45152 .5411 .4505 Metetra
.664 .741 .907 r
.5411 .4505 .54203 .45152 .54774 .44969 .54682 .44867 Metetra
.664 .741 .907 r
.54682 .44867 .54774 .44969 .55347 .44786 .55255 .44683 Metetra
.664 .741 .907 r
.55255 .44683 .55347 .44786 .55921 .44602 .5583 .44499 Metetra
.664 .741 .907 r
.5583 .44499 .55921 .44602 .56497 .44418 .56405 .44315 Metetra
.664 .741 .907 r
.56405 .44315 .56497 .44418 .57073 .44233 .56982 .4413 Metetra
.664 .741 .907 r
.56982 .4413 .57073 .44233 .57651 .44048 .5756 .43945 Metetra
.664 .741 .907 r
.5756 .43945 .57651 .44048 .5823 .43863 .58139 .43759 Metetra
.664 .741 .907 r
.58139 .43759 .5823 .43863 .5881 .43677 .5872 .43573 Metetra
.664 .741 .907 r
.5872 .43573 .5881 .43677 .59392 .43491 .59301 .43387 Metetra
.664 .741 .907 r
.59301 .43387 .59392 .43491 .59974 .43304 .59884 .432 Metetra
.664 .741 .907 r
.59884 .432 .59974 .43304 .60558 .43117 .60468 .43013 Metetra
.664 .741 .907 r
.60468 .43013 .60558 .43117 .61143 .4293 .61054 .42825 Metetra
.664 .741 .907 r
.61054 .42825 .61143 .4293 .61729 .42742 .6164 .42638 Metetra
.664 .741 .907 r
.6164 .42638 .61729 .42742 .62317 .42554 .62228 .42449 Metetra
.664 .741 .907 r
.62228 .42449 .62317 .42554 .62906 .42366 .62817 .42261 Metetra
.664 .741 .907 r
.62817 .42261 .62906 .42366 .63495 .42177 .63407 .42071 Metetra
.664 .741 .907 r
.63407 .42071 .63495 .42177 .64087 .41988 .63999 .41882 Metetra
.664 .741 .907 r
.63999 .41882 .64087 .41988 .64679 .41798 .64591 .41692 Metetra
.664 .741 .907 r
.64591 .41692 .64679 .41798 .65273 .41608 .65185 .41502 Metetra
.664 .741 .907 r
.65185 .41502 .65273 .41608 .65868 .41417 .65781 .41311 Metetra
.664 .741 .907 r
.65781 .41311 .65868 .41417 .66464 .41227 .66377 .4112 Metetra
.664 .741 .907 r
.66377 .4112 .66464 .41227 .67062 .41035 .66975 .40928 Metetra
.664 .741 .907 r
.66975 .40928 .67062 .41035 .6766 .40844 .67574 .40737 Metetra
.95 .595 .244 r
.67574 .40737 .6766 .40844 .6826 .40652 .68349 .44135 Metetra
.492 .283 .524 r
.68349 .44135 .6826 .40652 .68906 .41338 .68857 .41971 Metetra
.133 0 .346 r
.68857 .41971 .68906 .41338 .69508 .41095 .69379 .40158 Metetra
.586 .411 .611 r
.69379 .40158 .69508 .41095 .70068 .40073 .69983 .39965 Metetra
.664 .741 .907 r
.69983 .39965 .70068 .40073 .70673 .39879 .70588 .39771 Metetra
.664 .741 .907 r
.70588 .39771 .70673 .39879 .7128 .39685 .71195 .39576 Metetra
.664 .741 .907 r
.71195 .39576 .7128 .39685 .71887 .3949 .71803 .39382 Metetra
.664 .741 .907 r
.71803 .39382 .71887 .3949 .72497 .39295 .72412 .39186 Metetra
.664 .741 .907 r
.72412 .39186 .72497 .39295 .73107 .391 .73023 .38991 Metetra
.664 .741 .907 r
.73023 .38991 .73107 .391 .73719 .38904 .73635 .38795 Metetra
.664 .741 .907 r
.73635 .38795 .73719 .38904 .74331 .38708 .74248 .38598 Metetra
.664 .741 .907 r
.74248 .38598 .74331 .38708 .74946 .38511 .74862 .38401 Metetra
.664 .741 .907 r
.74862 .38401 .74946 .38511 .75561 .38314 .75478 .38204 Metetra
.664 .741 .907 r
.75478 .38204 .75561 .38314 .76178 .38117 .76096 .38006 Metetra
.664 .741 .907 r
.76096 .38006 .76178 .38117 .76797 .37919 .76714 .37808 Metetra
.664 .741 .907 r
.76714 .37808 .76797 .37919 .77416 .3772 .77334 .3761 Metetra
.664 .741 .907 r
.77334 .3761 .77416 .3772 .78037 .37522 .77955 .37411 Metetra
.664 .741 .907 r
.77955 .37411 .78037 .37522 .78659 .37322 .78578 .37211 Metetra
.664 .741 .907 r
.78578 .37211 .78659 .37322 .79283 .37123 .79202 .37011 Metetra
.664 .741 .907 r
.79202 .37011 .79283 .37123 .79908 .36923 .79827 .36811 Metetra
0 .064 .605 r
.79827 .36811 .79908 .36923 .80534 .36722 .80537 .37556 Metetra
.399 .174 .454 r
.80537 .37556 .80534 .36722 .81162 .36521 .81082 .36409 Metetra
.664 .741 .907 r
.81082 .36409 .81162 .36521 .81791 .3632 .81711 .36207 Metetra
.664 .741 .907 r
.81711 .36207 .81791 .3632 .82422 .36118 .82342 .36005 Metetra
.664 .741 .907 r
.82342 .36005 .82422 .36118 .83053 .35916 .82974 .35803 Metetra
.664 .741 .907 r
.82974 .35803 .83053 .35916 .83687 .35713 .83607 .356 Metetra
.664 .741 .907 r
.83607 .356 .83687 .35713 .84321 .3551 .84242 .35396 Metetra
.664 .741 .907 r
.84242 .35396 .84321 .3551 .84957 .35306 .84878 .35193 Metetra
.664 .741 .907 r
.84878 .35193 .84957 .35306 .85594 .35102 .85516 .34988 Metetra
.664 .741 .907 r
.85516 .34988 .85594 .35102 .86233 .34898 .86155 .34783 Metetra
.664 .741 .907 r
.86155 .34783 .86233 .34898 .86873 .34693 .86796 .34578 Metetra
.664 .741 .907 r
.86796 .34578 .86873 .34693 .87515 .34487 .87437 .34373 Metetra
.664 .741 .907 r
.87437 .34373 .87515 .34487 .88158 .34282 .88081 .34167 Metetra
.664 .741 .907 r
.88081 .34167 .88158 .34282 .88802 .34075 .88725 .3396 Metetra
.664 .741 .907 r
.88725 .3396 .88802 .34075 .89448 .33869 .89371 .33753 Metetra
.664 .741 .907 r
.89371 .33753 .89448 .33869 .90095 .33661 .90019 .33546 Metetra
.664 .741 .907 r
.90019 .33546 .90095 .33661 .90744 .33454 .90668 .33338 Metetra
.664 .741 .907 r
.32062 .51987 .32163 .52081 .3269 .51913 .3259 .51818 Metetra
.664 .741 .907 r
.3259 .51818 .3269 .51913 .33219 .51743 .33118 .51649 Metetra
.664 .741 .907 r
.33118 .51649 .33219 .51743 .33748 .51574 .33648 .51479 Metetra
.664 .741 .907 r
.33648 .51479 .33748 .51574 .34279 .51404 .34179 .51309 Metetra
.664 .741 .907 r
.34179 .51309 .34279 .51404 .3481 .51233 .3471 .51138 Metetra
.664 .741 .907 r
.3471 .51138 .3481 .51233 .35343 .51063 .35243 .50967 Metetra
.664 .741 .907 r
.35243 .50967 .35343 .51063 .35877 .50892 .35777 .50796 Metetra
.947 .651 .444 r
.35777 .50796 .35877 .50892 .3627 .53644 .36089 .55211 Metetra
0 0 .275 r
.36089 .55211 .3627 .53644 .36947 .50549 .36848 .50453 Metetra
.664 .741 .907 r
.36848 .50453 .36947 .50549 .37484 .50377 .37385 .5028 Metetra
.664 .741 .907 r
.37385 .5028 .37484 .50377 .38022 .50204 .37924 .50108 Metetra
.664 .741 .907 r
.37924 .50108 .38022 .50204 .38561 .50031 .38463 .49935 Metetra
.664 .741 .907 r
.38463 .49935 .38561 .50031 .39102 .49858 .39003 .49762 Metetra
.664 .741 .907 r
.39003 .49762 .39102 .49858 .39643 .49685 .39545 .49588 Metetra
.664 .741 .907 r
.39545 .49588 .39643 .49685 .40185 .49511 .40087 .49414 Metetra
.664 .741 .907 r
.40087 .49414 .40185 .49511 .40729 .49337 .40631 .4924 Metetra
.664 .741 .907 r
.40631 .4924 .40729 .49337 .41273 .49163 .41176 .49065 Metetra
.664 .741 .907 r
.41176 .49065 .41273 .49163 .41819 .48988 .41722 .4889 Metetra
.664 .741 .907 r
.41722 .4889 .41819 .48988 .42366 .48813 .42269 .48715 Metetra
.664 .741 .907 r
.42269 .48715 .42366 .48813 .42914 .48637 .42817 .48539 Metetra
.664 .741 .907 r
.42817 .48539 .42914 .48637 .43463 .48461 .43366 .48363 Metetra
.664 .741 .907 r
.43366 .48363 .43463 .48461 .44013 .48285 .43917 .48186 Metetra
.664 .741 .907 r
.43917 .48186 .44013 .48285 .44564 .48108 .44468 .4801 Metetra
.664 .741 .907 r
.44468 .4801 .44564 .48108 .45117 .47931 .45021 .47832 Metetra
.664 .741 .907 r
.45021 .47832 .45117 .47931 .4567 .47754 .45574 .47655 Metetra
.664 .741 .907 r
.45574 .47655 .4567 .47754 .46225 .47576 .46129 .47477 Metetra
.956 .667 .449 r
.46129 .47477 .46225 .47576 .46455 .66187 .46533 .55953 Metetra
.614 .395 .56 r
.46533 .55953 .46455 .66187 .47272 .51424 .47192 .50263 Metetra
.749 .526 .592 r
.47192 .50263 .47272 .51424 .47895 .47041 .47801 .46941 Metetra
.664 .741 .907 r
.47801 .46941 .47895 .47041 .48455 .46862 .4836 .46762 Metetra
.664 .741 .907 r
.4836 .46762 .48455 .46862 .49015 .46682 .48921 .46582 Metetra
.664 .741 .907 r
.48921 .46582 .49015 .46682 .49576 .46502 .49482 .46402 Metetra
.664 .741 .907 r
.49482 .46402 .49576 .46502 .50139 .46322 .50045 .46222 Metetra
.664 .741 .907 r
.50045 .46222 .50139 .46322 .50703 .46142 .50609 .46041 Metetra
.664 .741 .907 r
.50609 .46041 .50703 .46142 .51268 .45961 .51174 .45859 Metetra
.664 .741 .907 r
.51174 .45859 .51268 .45961 .51834 .45779 .51741 .45678 Metetra
.664 .741 .907 r
.51741 .45678 .51834 .45779 .52401 .45597 .52308 .45496 Metetra
.664 .741 .907 r
.52308 .45496 .52401 .45597 .5297 .45415 .52877 .45314 Metetra
.664 .741 .907 r
.52877 .45314 .5297 .45415 .53539 .45233 .53447 .45131 Metetra
.664 .741 .907 r
.53447 .45131 .53539 .45233 .5411 .4505 .54018 .44948 Metetra
.664 .741 .907 r
.54018 .44948 .5411 .4505 .54682 .44867 .5459 .44764 Metetra
.664 .741 .907 r
.5459 .44764 .54682 .44867 .55255 .44683 .55164 .4458 Metetra
.664 .741 .907 r
.55164 .4458 .55255 .44683 .5583 .44499 .55738 .44396 Metetra
.311 .58 .937 r
.55738 .44396 .5583 .44499 .56405 .44315 .56318 .44545 Metetra
.192 0 .159 r
.56318 .44545 .56405 .44315 .56982 .4413 .56891 .44027 Metetra
.664 .741 .907 r
.56891 .44027 .56982 .4413 .5756 .43945 .57469 .43841 Metetra
.664 .741 .907 r
.57469 .43841 .5756 .43945 .58139 .43759 .58049 .43655 Metetra
.664 .741 .907 r
.58049 .43655 .58139 .43759 .5872 .43573 .58629 .43469 Metetra
.664 .741 .907 r
.58629 .43469 .5872 .43573 .59301 .43387 .59211 .43283 Metetra
.664 .741 .907 r
.59211 .43283 .59301 .43387 .59884 .432 .59794 .43096 Metetra
.664 .741 .907 r
.59794 .43096 .59884 .432 .60468 .43013 .60379 .42908 Metetra
.664 .741 .907 r
.60379 .42908 .60468 .43013 .61054 .42825 .60964 .42721 Metetra
.664 .741 .907 r
.60964 .42721 .61054 .42825 .6164 .42638 .61551 .42533 Metetra
.664 .741 .907 r
.61551 .42533 .6164 .42638 .62228 .42449 .62139 .42344 Metetra
.664 .741 .907 r
.62139 .42344 .62228 .42449 .62817 .42261 .62728 .42155 Metetra
.664 .741 .907 r
.62728 .42155 .62817 .42261 .63407 .42071 .63319 .41966 Metetra
.664 .741 .907 r
.63319 .41966 .63407 .42071 .63999 .41882 .6391 .41776 Metetra
.664 .741 .907 r
.6391 .41776 .63999 .41882 .64591 .41692 .64503 .41586 Metetra
.664 .741 .907 r
.64503 .41586 .64591 .41692 .65185 .41502 .65098 .41395 Metetra
.664 .741 .907 r
.65098 .41395 .65185 .41502 .65781 .41311 .65693 .41205 Metetra
.664 .741 .907 r
.65693 .41205 .65781 .41311 .66377 .4112 .6629 .41013 Metetra
.664 .741 .907 r
.6629 .41013 .66377 .4112 .66975 .40928 .66888 .40821 Metetra
.664 .741 .907 r
.66888 .40821 .66975 .40928 .67574 .40737 .67487 .40629 Metetra
.664 .741 .907 r
.67487 .40629 .67574 .40737 .68349 .44135 .68088 .40437 Metetra
.567 .364 .565 r
.68088 .40437 .68349 .44135 .68857 .41971 .6869 .40244 Metetra
.574 .382 .583 r
.6869 .40244 .68857 .41971 .69379 .40158 .69293 .4005 Metetra
.664 .741 .907 r
.69293 .4005 .69379 .40158 .69983 .39965 .69897 .39857 Metetra
.664 .741 .907 r
.69897 .39857 .69983 .39965 .70588 .39771 .70503 .39662 Metetra
.664 .741 .907 r
.70503 .39662 .70588 .39771 .71195 .39576 .7111 .39468 Metetra
.664 .741 .907 r
.7111 .39468 .71195 .39576 .71803 .39382 .71718 .39273 Metetra
.664 .741 .907 r
.71718 .39273 .71803 .39382 .72412 .39186 .72328 .39077 Metetra
.664 .741 .907 r
.72328 .39077 .72412 .39186 .73023 .38991 .72939 .38882 Metetra
.664 .741 .907 r
.72939 .38882 .73023 .38991 .73635 .38795 .73551 .38685 Metetra
.664 .741 .907 r
.73551 .38685 .73635 .38795 .74248 .38598 .74164 .38489 Metetra
.664 .741 .907 r
.74164 .38489 .74248 .38598 .74862 .38401 .74779 .38291 Metetra
.664 .741 .907 r
.74779 .38291 .74862 .38401 .75478 .38204 .75395 .38094 Metetra
.664 .741 .907 r
.75395 .38094 .75478 .38204 .76096 .38006 .76013 .37896 Metetra
.664 .741 .907 r
.76013 .37896 .76096 .38006 .76714 .37808 .76632 .37697 Metetra
.664 .741 .907 r
.76632 .37697 .76714 .37808 .77334 .3761 .77252 .37499 Metetra
.664 .741 .907 r
.77252 .37499 .77334 .3761 .77955 .37411 .77873 .37299 Metetra
.664 .741 .907 r
.77873 .37299 .77955 .37411 .78578 .37211 .78496 .371 Metetra
.664 .741 .907 r
.78496 .371 .78578 .37211 .79202 .37011 .7912 .369 Metetra
.664 .741 .907 r
.7912 .369 .79202 .37011 .79827 .36811 .79746 .36699 Metetra
.664 .741 .907 r
.79746 .36699 .79827 .36811 .80537 .37556 .80373 .36498 Metetra
.583 .404 .605 r
.80373 .36498 .80537 .37556 .81082 .36409 .81001 .36297 Metetra
.664 .741 .907 r
.81001 .36297 .81082 .36409 .81711 .36207 .81631 .36095 Metetra
.664 .741 .907 r
.81631 .36095 .81711 .36207 .82342 .36005 .82262 .35892 Metetra
.664 .741 .907 r
.82262 .35892 .82342 .36005 .82974 .35803 .82894 .3569 Metetra
.664 .741 .907 r
.82894 .3569 .82974 .35803 .83607 .356 .83528 .35486 Metetra
.664 .741 .907 r
.83528 .35486 .83607 .356 .84242 .35396 .84163 .35283 Metetra
.664 .741 .907 r
.84163 .35283 .84242 .35396 .84878 .35193 .848 .35079 Metetra
.664 .741 .907 r
.848 .35079 .84878 .35193 .85516 .34988 .85438 .34874 Metetra
.664 .741 .907 r
.85438 .34874 .85516 .34988 .86155 .34783 .86077 .34669 Metetra
.664 .741 .907 r
.86077 .34669 .86155 .34783 .86796 .34578 .86718 .34464 Metetra
.664 .741 .907 r
.86718 .34464 .86796 .34578 .87437 .34373 .8736 .34258 Metetra
.664 .741 .907 r
.8736 .34258 .87437 .34373 .88081 .34167 .88003 .34051 Metetra
.664 .741 .907 r
.88003 .34051 .88081 .34167 .88725 .3396 .88648 .33845 Metetra
.664 .741 .907 r
.88648 .33845 .88725 .3396 .89371 .33753 .89295 .33637 Metetra
.664 .741 .907 r
.89295 .33637 .89371 .33753 .90019 .33546 .89943 .3343 Metetra
.664 .741 .907 r
.89943 .3343 .90019 .33546 .90668 .33338 .90592 .33222 Metetra
.664 .741 .907 r
.31961 .51893 .32062 .51987 .3259 .51818 .32489 .51724 Metetra
.664 .741 .907 r
.32489 .51724 .3259 .51818 .33118 .51649 .33018 .51554 Metetra
.664 .741 .907 r
.33018 .51554 .33118 .51649 .33648 .51479 .33547 .51384 Metetra
.664 .741 .907 r
.33547 .51384 .33648 .51479 .34179 .51309 .34078 .51214 Metetra
.664 .741 .907 r
.34078 .51214 .34179 .51309 .3471 .51138 .3461 .51043 Metetra
.664 .741 .907 r
.3461 .51043 .3471 .51138 .35243 .50967 .35143 .50872 Metetra
.664 .741 .907 r
.35143 .50872 .35243 .50967 .35777 .50796 .35678 .507 Metetra
.939 .584 .311 r
.35678 .507 .35777 .50796 .36089 .55211 .36114 .52546 Metetra
.637 .424 .577 r
.36114 .52546 .36089 .55211 .36848 .50453 .36749 .50357 Metetra
.664 .741 .907 r
.36749 .50357 .36848 .50453 .37385 .5028 .37286 .50184 Metetra
.664 .741 .907 r
.37286 .50184 .37385 .5028 .37924 .50108 .37825 .50012 Metetra
.664 .741 .907 r
.37825 .50012 .37924 .50108 .38463 .49935 .38364 .49838 Metetra
.664 .741 .907 r
.38364 .49838 .38463 .49935 .39003 .49762 .38905 .49665 Metetra
.664 .741 .907 r
.38905 .49665 .39003 .49762 .39545 .49588 .39447 .49491 Metetra
.664 .741 .907 r
.39447 .49491 .39545 .49588 .40087 .49414 .39989 .49317 Metetra
.664 .741 .907 r
.39989 .49317 .40087 .49414 .40631 .4924 .40533 .49142 Metetra
.664 .741 .907 r
.40533 .49142 .40631 .4924 .41176 .49065 .41078 .48968 Metetra
.664 .741 .907 r
.41078 .48968 .41176 .49065 .41722 .4889 .41625 .48792 Metetra
.664 .741 .907 r
.41625 .48792 .41722 .4889 .42269 .48715 .42172 .48617 Metetra
.664 .741 .907 r
.42172 .48617 .42269 .48715 .42817 .48539 .4272 .48441 Metetra
.664 .741 .907 r
.4272 .48441 .42817 .48539 .43366 .48363 .43269 .48265 Metetra
.664 .741 .907 r
.43269 .48265 .43366 .48363 .43917 .48186 .4382 .48088 Metetra
.664 .741 .907 r
.4382 .48088 .43917 .48186 .44468 .4801 .44372 .47911 Metetra
.664 .741 .907 r
.44372 .47911 .44468 .4801 .45021 .47832 .44925 .47734 Metetra
.664 .741 .907 r
.44925 .47734 .45021 .47832 .45574 .47655 .45478 .47556 Metetra
.664 .741 .907 r
.45478 .47556 .45574 .47655 .46129 .47477 .46034 .47378 Metetra
.664 .741 .907 r
.46034 .47378 .46129 .47477 .46533 .55953 .4659 .47199 Metetra
.552 .345 .554 r
.4659 .47199 .46533 .55953 .47192 .50263 .47133 .47879 Metetra
.604 .398 .576 r
.47133 .47879 .47192 .50263 .47801 .46941 .47706 .46841 Metetra
.947 .594 .298 r
.47706 .46841 .47801 .46941 .4836 .46762 .48233 .492 Metetra
.413 .212 .495 r
.48233 .492 .4836 .46762 .48921 .46582 .48826 .46482 Metetra
.664 .741 .907 r
.48826 .46482 .48921 .46582 .49482 .46402 .49388 .46301 Metetra
.664 .741 .907 r
.49388 .46301 .49482 .46402 .50045 .46222 .49951 .46121 Metetra
.664 .741 .907 r
.49951 .46121 .50045 .46222 .50609 .46041 .50515 .4594 Metetra
.664 .741 .907 r
.50515 .4594 .50609 .46041 .51174 .45859 .51081 .45758 Metetra
.664 .741 .907 r
.51081 .45758 .51174 .45859 .51741 .45678 .51647 .45576 Metetra
.664 .741 .907 r
.51647 .45576 .51741 .45678 .52308 .45496 .52215 .45394 Metetra
.664 .741 .907 r
.52215 .45394 .52308 .45496 .52877 .45314 .52784 .45212 Metetra
.664 .741 .907 r
.52784 .45212 .52877 .45314 .53447 .45131 .53354 .45029 Metetra
.664 .741 .907 r
.53354 .45029 .53447 .45131 .54018 .44948 .53925 .44846 Metetra
.664 .741 .907 r
.53925 .44846 .54018 .44948 .5459 .44764 .54498 .44662 Metetra
.664 .741 .907 r
.54498 .44662 .5459 .44764 .55164 .4458 .55072 .44478 Metetra
.664 .741 .907 r
.55072 .44478 .55164 .4458 .55738 .44396 .55646 .44293 Metetra
.636 .732 .917 r
.55646 .44293 .55738 .44396 .56318 .44545 .56223 .44149 Metetra
.623 .494 .685 r
.56223 .44149 .56318 .44545 .56891 .44027 .568 .43923 Metetra
.664 .741 .907 r
.568 .43923 .56891 .44027 .57469 .43841 .57378 .43738 Metetra
.664 .741 .907 r
.57378 .43738 .57469 .43841 .58049 .43655 .57958 .43552 Metetra
.664 .741 .907 r
.57958 .43552 .58049 .43655 .58629 .43469 .58539 .43365 Metetra
.664 .741 .907 r
.58539 .43365 .58629 .43469 .59211 .43283 .59121 .43178 Metetra
.664 .741 .907 r
.59121 .43178 .59211 .43283 .59794 .43096 .59704 .42991 Metetra
.664 .741 .907 r
.59704 .42991 .59794 .43096 .60379 .42908 .60289 .42804 Metetra
.664 .741 .907 r
.60289 .42804 .60379 .42908 .60964 .42721 .60875 .42616 Metetra
.664 .741 .907 r
.60875 .42616 .60964 .42721 .61551 .42533 .61462 .42427 Metetra
.664 .741 .907 r
.61462 .42427 .61551 .42533 .62139 .42344 .6205 .42239 Metetra
.664 .741 .907 r
.6205 .42239 .62139 .42344 .62728 .42155 .62639 .4205 Metetra
.664 .741 .907 r
.62639 .4205 .62728 .42155 .63319 .41966 .6323 .4186 Metetra
.664 .741 .907 r
.6323 .4186 .63319 .41966 .6391 .41776 .63822 .4167 Metetra
.664 .741 .907 r
.63822 .4167 .6391 .41776 .64503 .41586 .64415 .4148 Metetra
.664 .741 .907 r
.64415 .4148 .64503 .41586 .65098 .41395 .6501 .41289 Metetra
.664 .741 .907 r
.6501 .41289 .65098 .41395 .65693 .41205 .65606 .41098 Metetra
.664 .741 .907 r
.65606 .41098 .65693 .41205 .6629 .41013 .66203 .40906 Metetra
.664 .741 .907 r
.66203 .40906 .6629 .41013 .66888 .40821 .66801 .40714 Metetra
.664 .741 .907 r
.66801 .40714 .66888 .40821 .67487 .40629 .674 .40522 Metetra
.664 .741 .907 r
.674 .40522 .67487 .40629 .68088 .40437 .68001 .40329 Metetra
.664 .741 .907 r
.68001 .40329 .68088 .40437 .6869 .40244 .68603 .40136 Metetra
.664 .741 .907 r
.68603 .40136 .6869 .40244 .69293 .4005 .69207 .39942 Metetra
.664 .741 .907 r
.69207 .39942 .69293 .4005 .69897 .39857 .69811 .39748 Metetra
.664 .741 .907 r
.69811 .39748 .69897 .39857 .70503 .39662 .70417 .39554 Metetra
.664 .741 .907 r
.70417 .39554 .70503 .39662 .7111 .39468 .71025 .39359 Metetra
.664 .741 .907 r
.71025 .39359 .7111 .39468 .71718 .39273 .71633 .39164 Metetra
.664 .741 .907 r
.71633 .39164 .71718 .39273 .72328 .39077 .72243 .38968 Metetra
.664 .741 .907 r
.72243 .38968 .72328 .39077 .72939 .38882 .72854 .38772 Metetra
.664 .741 .907 r
.72854 .38772 .72939 .38882 .73551 .38685 .73467 .38576 Metetra
.664 .741 .907 r
.73467 .38576 .73551 .38685 .74164 .38489 .74081 .38379 Metetra
.664 .741 .907 r
.74081 .38379 .74164 .38489 .74779 .38291 .74696 .38181 Metetra
.664 .741 .907 r
.74696 .38181 .74779 .38291 .75395 .38094 .75312 .37983 Metetra
.664 .741 .907 r
.75312 .37983 .75395 .38094 .76013 .37896 .7593 .37785 Metetra
.664 .741 .907 r
.7593 .37785 .76013 .37896 .76632 .37697 .76549 .37587 Metetra
.664 .741 .907 r
.76549 .37587 .76632 .37697 .77252 .37499 .77169 .37388 Metetra
.664 .741 .907 r
.77169 .37388 .77252 .37499 .77873 .37299 .77791 .37188 Metetra
.664 .741 .907 r
.77791 .37188 .77873 .37299 .78496 .371 .78414 .36988 Metetra
.664 .741 .907 r
.78414 .36988 .78496 .371 .7912 .369 .79039 .36788 Metetra
.664 .741 .907 r
.79039 .36788 .7912 .369 .79746 .36699 .79665 .36587 Metetra
.664 .741 .907 r
.79665 .36587 .79746 .36699 .80373 .36498 .80292 .36386 Metetra
.664 .741 .907 r
.80292 .36386 .80373 .36498 .81001 .36297 .8092 .36184 Metetra
.664 .741 .907 r
.8092 .36184 .81001 .36297 .81631 .36095 .8155 .35982 Metetra
.664 .741 .907 r
.8155 .35982 .81631 .36095 .82262 .35892 .82182 .35779 Metetra
.664 .741 .907 r
.82182 .35779 .82262 .35892 .82894 .3569 .82814 .35576 Metetra
.664 .741 .907 r
.82814 .35576 .82894 .3569 .83528 .35486 .83449 .35373 Metetra
.664 .741 .907 r
.83449 .35373 .83528 .35486 .84163 .35283 .84084 .35169 Metetra
.664 .741 .907 r
.84084 .35169 .84163 .35283 .848 .35079 .84721 .34965 Metetra
.664 .741 .907 r
.84721 .34965 .848 .35079 .85438 .34874 .85359 .3476 Metetra
.664 .741 .907 r
.85359 .3476 .85438 .34874 .86077 .34669 .85999 .34555 Metetra
.664 .741 .907 r
.85999 .34555 .86077 .34669 .86718 .34464 .8664 .34349 Metetra
.664 .741 .907 r
.8664 .34349 .86718 .34464 .8736 .34258 .87282 .34143 Metetra
.664 .741 .907 r
.87282 .34143 .8736 .34258 .88003 .34051 .87926 .33936 Metetra
.664 .741 .907 r
.87926 .33936 .88003 .34051 .88648 .33845 .88571 .33729 Metetra
.664 .741 .907 r
.88571 .33729 .88648 .33845 .89295 .33637 .89218 .33522 Metetra
.664 .741 .907 r
.89218 .33522 .89295 .33637 .89943 .3343 .89866 .33314 Metetra
.664 .741 .907 r
.89866 .33314 .89943 .3343 .90592 .33222 .90516 .33105 Metetra
.664 .741 .907 r
.3186 .51799 .31961 .51893 .32489 .51724 .32388 .51629 Metetra
.664 .741 .907 r
.32388 .51629 .32489 .51724 .33018 .51554 .32917 .51459 Metetra
.664 .741 .907 r
.32917 .51459 .33018 .51554 .33547 .51384 .33447 .51289 Metetra
.664 .741 .907 r
.33447 .51289 .33547 .51384 .34078 .51214 .33978 .51118 Metetra
.664 .741 .907 r
.33978 .51118 .34078 .51214 .3461 .51043 .3451 .50948 Metetra
.664 .741 .907 r
.3451 .50948 .3461 .51043 .35143 .50872 .35044 .50776 Metetra
.664 .741 .907 r
.35044 .50776 .35143 .50872 .35678 .507 .35578 .50605 Metetra
.887 .459 .1 r
.35578 .50605 .35678 .507 .36114 .52546 .36053 .51665 Metetra
.691 .492 .612 r
.36053 .51665 .36114 .52546 .36749 .50357 .3665 .50261 Metetra
.664 .741 .907 r
.3665 .50261 .36749 .50357 .37286 .50184 .37187 .50088 Metetra
.664 .741 .907 r
.37187 .50088 .37286 .50184 .37825 .50012 .37726 .49915 Metetra
.664 .741 .907 r
.37726 .49915 .37825 .50012 .38364 .49838 .38266 .49742 Metetra
.664 .741 .907 r
.38266 .49742 .38364 .49838 .38905 .49665 .38806 .49568 Metetra
.664 .741 .907 r
.38806 .49568 .38905 .49665 .39447 .49491 .39348 .49394 Metetra
.664 .741 .907 r
.39348 .49394 .39447 .49491 .39989 .49317 .39891 .4922 Metetra
.664 .741 .907 r
.39891 .4922 .39989 .49317 .40533 .49142 .40436 .49045 Metetra
.664 .741 .907 r
.40436 .49045 .40533 .49142 .41078 .48968 .40981 .4887 Metetra
.664 .741 .907 r
.40981 .4887 .41078 .48968 .41625 .48792 .41527 .48694 Metetra
.664 .741 .907 r
.41527 .48694 .41625 .48792 .42172 .48617 .42074 .48519 Metetra
.664 .741 .907 r
.42074 .48519 .42172 .48617 .4272 .48441 .42623 .48343 Metetra
.664 .741 .907 r
.42623 .48343 .4272 .48441 .43269 .48265 .43173 .48166 Metetra
.664 .741 .907 r
.43173 .48166 .43269 .48265 .4382 .48088 .43723 .47989 Metetra
.664 .741 .907 r
.43723 .47989 .4382 .48088 .44372 .47911 .44275 .47812 Metetra
.664 .741 .907 r
.44275 .47812 .44372 .47911 .44925 .47734 .44828 .47634 Metetra
.664 .741 .907 r
.44828 .47634 .44925 .47734 .45478 .47556 .45383 .47456 Metetra
.664 .741 .907 r
.45383 .47456 .45478 .47556 .46034 .47378 .45938 .47278 Metetra
.664 .741 .907 r
.45938 .47278 .46034 .47378 .4659 .47199 .46494 .471 Metetra
.664 .741 .907 r
.46494 .471 .4659 .47199 .47133 .47879 .47052 .4692 Metetra
.584 .408 .608 r
.47052 .4692 .47133 .47879 .47706 .46841 .47611 .46741 Metetra
.956 .676 .463 r
.47611 .46741 .47706 .46841 .48233 .492 .47978 .61229 Metetra
.394 .212 .512 r
.47978 .61229 .48233 .492 .48826 .46482 .48731 .46381 Metetra
.664 .741 .907 r
.48731 .46381 .48826 .46482 .49388 .46301 .49294 .46201 Metetra
.664 .741 .907 r
.49294 .46201 .49388 .46301 .49951 .46121 .49857 .4602 Metetra
.664 .741 .907 r
.49857 .4602 .49951 .46121 .50515 .4594 .50421 .45839 Metetra
.664 .741 .907 r
.50421 .45839 .50515 .4594 .51081 .45758 .50987 .45657 Metetra
.664 .741 .907 r
.50987 .45657 .51081 .45758 .51647 .45576 .51554 .45475 Metetra
.664 .741 .907 r
.51554 .45475 .51647 .45576 .52215 .45394 .52122 .45293 Metetra
.664 .741 .907 r
.52122 .45293 .52215 .45394 .52784 .45212 .52691 .4511 Metetra
.664 .741 .907 r
.52691 .4511 .52784 .45212 .53354 .45029 .53261 .44927 Metetra
.664 .741 .907 r
.53261 .44927 .53354 .45029 .53925 .44846 .53833 .44743 Metetra
.664 .741 .907 r
.53833 .44743 .53925 .44846 .54498 .44662 .54406 .44559 Metetra
.664 .741 .907 r
.54406 .44559 .54498 .44662 .55072 .44478 .5498 .44375 Metetra
.664 .741 .907 r
.5498 .44375 .55072 .44478 .55646 .44293 .55555 .4419 Metetra
.664 .741 .907 r
.55555 .4419 .55646 .44293 .56223 .44149 .56131 .44005 Metetra
.659 .67 .849 r
.56131 .44005 .56223 .44149 .568 .43923 .56708 .4382 Metetra
.664 .741 .907 r
.56708 .4382 .568 .43923 .57378 .43738 .57287 .43634 Metetra
.664 .741 .907 r
.57287 .43634 .57378 .43738 .57958 .43552 .57867 .43448 Metetra
.664 .741 .907 r
.57867 .43448 .57958 .43552 .58539 .43365 .58448 .43261 Metetra
.664 .741 .907 r
.58448 .43261 .58539 .43365 .59121 .43178 .59031 .43074 Metetra
.664 .741 .907 r
.59031 .43074 .59121 .43178 .59704 .42991 .59614 .42887 Metetra
.664 .741 .907 r
.59614 .42887 .59704 .42991 .60289 .42804 .60199 .42699 Metetra
.664 .741 .907 r
.60199 .42699 .60289 .42804 .60875 .42616 .60785 .42511 Metetra
.664 .741 .907 r
.60785 .42511 .60875 .42616 .61462 .42427 .61372 .42322 Metetra
.664 .741 .907 r
.61372 .42322 .61462 .42427 .6205 .42239 .61961 .42133 Metetra
.664 .741 .907 r
.61961 .42133 .6205 .42239 .62639 .4205 .62551 .41944 Metetra
.664 .741 .907 r
.62551 .41944 .62639 .4205 .6323 .4186 .63141 .41754 Metetra
.664 .741 .907 r
.63141 .41754 .6323 .4186 .63822 .4167 .63734 .41564 Metetra
.664 .741 .907 r
.63734 .41564 .63822 .4167 .64415 .4148 .64327 .41373 Metetra
.664 .741 .907 r
.64327 .41373 .64415 .4148 .6501 .41289 .64922 .41182 Metetra
.664 .741 .907 r
.64922 .41182 .6501 .41289 .65606 .41098 .65518 .40991 Metetra
.664 .741 .907 r
.65518 .40991 .65606 .41098 .66203 .40906 .66115 .40799 Metetra
.664 .741 .907 r
.66115 .40799 .66203 .40906 .66801 .40714 .66714 .40607 Metetra
.664 .741 .907 r
.66714 .40607 .66801 .40714 .674 .40522 .67314 .40415 Metetra
.664 .741 .907 r
.67314 .40415 .674 .40522 .68001 .40329 .67915 .40222 Metetra
.664 .741 .907 r
.67915 .40222 .68001 .40329 .68603 .40136 .68517 .40028 Metetra
.664 .741 .907 r
.68517 .40028 .68603 .40136 .69207 .39942 .69121 .39834 Metetra
.664 .741 .907 r
.69121 .39834 .69207 .39942 .69811 .39748 .69726 .3964 Metetra
.664 .741 .907 r
.69726 .3964 .69811 .39748 .70417 .39554 .70332 .39445 Metetra
.664 .741 .907 r
.70332 .39445 .70417 .39554 .71025 .39359 .70939 .3925 Metetra
.967 .643 .324 r
.70939 .3925 .71025 .39359 .71633 .39164 .71998 .46629 Metetra
.442 .253 .527 r
.71998 .46629 .71633 .39164 .72243 .38968 .72158 .38859 Metetra
.664 .741 .907 r
.72158 .38859 .72243 .38968 .72854 .38772 .7277 .38663 Metetra
.664 .741 .907 r
.7277 .38663 .72854 .38772 .73467 .38576 .73383 .38466 Metetra
.664 .741 .907 r
.73383 .38466 .73467 .38576 .74081 .38379 .73997 .38269 Metetra
.664 .741 .907 r
.73997 .38269 .74081 .38379 .74696 .38181 .74612 .38071 Metetra
.664 .741 .907 r
.74612 .38071 .74696 .38181 .75312 .37983 .75229 .37873 Metetra
.664 .741 .907 r
.75229 .37873 .75312 .37983 .7593 .37785 .75847 .37675 Metetra
.664 .741 .907 r
.75847 .37675 .7593 .37785 .76549 .37587 .76466 .37476 Metetra
.664 .741 .907 r
.76466 .37476 .76549 .37587 .77169 .37388 .77087 .37276 Metetra
.664 .741 .907 r
.77087 .37276 .77169 .37388 .77791 .37188 .77709 .37077 Metetra
.664 .741 .907 r
.77709 .37077 .77791 .37188 .78414 .36988 .78332 .36876 Metetra
.664 .741 .907 r
.78332 .36876 .78414 .36988 .79039 .36788 .78957 .36676 Metetra
.664 .741 .907 r
.78957 .36676 .79039 .36788 .79665 .36587 .79583 .36475 Metetra
.664 .741 .907 r
.79583 .36475 .79665 .36587 .80292 .36386 .80211 .36273 Metetra
.664 .741 .907 r
.80211 .36273 .80292 .36386 .8092 .36184 .8084 .36071 Metetra
.664 .741 .907 r
.8084 .36071 .8092 .36184 .8155 .35982 .8147 .35869 Metetra
.664 .741 .907 r
.8147 .35869 .8155 .35982 .82182 .35779 .82102 .35666 Metetra
.664 .741 .907 r
.82102 .35666 .82182 .35779 .82814 .35576 .82735 .35463 Metetra
.664 .741 .907 r
.82735 .35463 .82814 .35576 .83449 .35373 .83369 .35259 Metetra
.664 .741 .907 r
.83369 .35259 .83449 .35373 .84084 .35169 .84005 .35055 Metetra
.664 .741 .907 r
.84005 .35055 .84084 .35169 .84721 .34965 .84642 .3485 Metetra
.664 .741 .907 r
.84642 .3485 .84721 .34965 .85359 .3476 .8528 .34645 Metetra
.664 .741 .907 r
.8528 .34645 .85359 .3476 .85999 .34555 .8592 .3444 Metetra
.664 .741 .907 r
.8592 .3444 .85999 .34555 .8664 .34349 .86562 .34234 Metetra
.664 .741 .907 r
.86562 .34234 .8664 .34349 .87282 .34143 .87205 .34028 Metetra
.664 .741 .907 r
.87205 .34028 .87282 .34143 .87926 .33936 .87849 .33821 Metetra
.664 .741 .907 r
.87849 .33821 .87926 .33936 .88571 .33729 .88494 .33613 Metetra
.664 .741 .907 r
.88494 .33613 .88571 .33729 .89218 .33522 .89141 .33406 Metetra
.664 .741 .907 r
.89141 .33406 .89218 .33522 .89866 .33314 .8979 .33197 Metetra
.664 .741 .907 r
.8979 .33197 .89866 .33314 .90516 .33105 .9044 .32989 Metetra
.664 .741 .907 r
.31759 .51704 .3186 .51799 .32388 .51629 .32287 .51534 Metetra
.664 .741 .907 r
.32287 .51534 .32388 .51629 .32917 .51459 .32816 .51364 Metetra
.664 .741 .907 r
.32816 .51364 .32917 .51459 .33447 .51289 .33346 .51194 Metetra
.664 .741 .907 r
.33346 .51194 .33447 .51289 .33978 .51118 .33878 .51023 Metetra
.664 .741 .907 r
.33878 .51023 .33978 .51118 .3451 .50948 .3441 .50852 Metetra
.664 .741 .907 r
.3441 .50852 .3451 .50948 .35044 .50776 .34943 .50681 Metetra
.664 .741 .907 r
.34943 .50681 .35044 .50776 .35578 .50605 .35478 .50509 Metetra
.664 .741 .907 r
.35478 .50509 .35578 .50605 .36053 .51665 .36014 .50337 Metetra
.578 .39 .591 r
.36014 .50337 .36053 .51665 .3665 .50261 .3655 .50164 Metetra
.664 .741 .907 r
.3655 .50164 .3665 .50261 .37187 .50088 .37088 .49992 Metetra
.664 .741 .907 r
.37088 .49992 .37187 .50088 .37726 .49915 .37627 .49818 Metetra
.664 .741 .907 r
.37627 .49818 .37726 .49915 .38266 .49742 .38167 .49645 Metetra
.664 .741 .907 r
.38167 .49645 .38266 .49742 .38806 .49568 .38708 .49471 Metetra
.664 .741 .907 r
.38708 .49471 .38806 .49568 .39348 .49394 .3925 .49297 Metetra
.664 .741 .907 r
.3925 .49297 .39348 .49394 .39891 .4922 .39793 .49122 Metetra
.664 .741 .907 r
.39793 .49122 .39891 .4922 .40436 .49045 .40338 .48947 Metetra
.664 .741 .907 r
.40338 .48947 .40436 .49045 .40981 .4887 .40883 .48772 Metetra
.664 .741 .907 r
.40883 .48772 .40981 .4887 .41527 .48694 .41429 .48596 Metetra
.664 .741 .907 r
.41429 .48596 .41527 .48694 .42074 .48519 .41977 .48421 Metetra
.664 .741 .907 r
.41977 .48421 .42074 .48519 .42623 .48343 .42526 .48244 Metetra
.664 .741 .907 r
.42526 .48244 .42623 .48343 .43173 .48166 .43076 .48067 Metetra
.664 .741 .907 r
.43076 .48067 .43173 .48166 .43723 .47989 .43627 .4789 Metetra
.664 .741 .907 r
.43627 .4789 .43723 .47989 .44275 .47812 .44179 .47713 Metetra
.664 .741 .907 r
.44179 .47713 .44275 .47812 .44828 .47634 .44732 .47535 Metetra
.664 .741 .907 r
.44732 .47535 .44828 .47634 .45383 .47456 .45286 .47357 Metetra
.664 .741 .907 r
.45286 .47357 .45383 .47456 .45938 .47278 .45842 .47179 Metetra
.664 .741 .907 r
.45842 .47179 .45938 .47278 .46494 .471 .46399 .47 Metetra
.632 .731 .919 r
.46399 .47 .46494 .471 .47052 .4692 .46956 .46865 Metetra
.953 .674 .47 r
.46956 .46865 .47052 .4692 .47611 .46741 .47269 .62929 Metetra
.591 .369 .548 r
.47269 .62929 .47611 .46741 .47978 .61229 .47777 .68652 Metetra
0 0 .362 r
.47777 .68652 .47978 .61229 .48731 .46381 .48637 .46281 Metetra
.664 .741 .907 r
.48637 .46281 .48731 .46381 .49294 .46201 .49199 .461 Metetra
.664 .741 .907 r
.49199 .461 .49294 .46201 .49857 .4602 .49763 .45919 Metetra
.664 .741 .907 r
.49763 .45919 .49857 .4602 .50421 .45839 .50327 .45737 Metetra
.664 .741 .907 r
.50327 .45737 .50421 .45839 .50987 .45657 .50893 .45555 Metetra
.664 .741 .907 r
.50893 .45555 .50987 .45657 .51554 .45475 .5146 .45373 Metetra
.664 .741 .907 r
.5146 .45373 .51554 .45475 .52122 .45293 .52028 .45191 Metetra
.664 .741 .907 r
.52028 .45191 .52122 .45293 .52691 .4511 .52598 .45008 Metetra
.664 .741 .907 r
.52598 .45008 .52691 .4511 .53261 .44927 .53168 .44824 Metetra
.664 .741 .907 r
.53168 .44824 .53261 .44927 .53833 .44743 .5374 .44641 Metetra
.664 .741 .907 r
.5374 .44641 .53833 .44743 .54406 .44559 .54313 .44456 Metetra
.664 .741 .907 r
.54313 .44456 .54406 .44559 .5498 .44375 .54887 .44272 Metetra
.664 .741 .907 r
.54887 .44272 .5498 .44375 .55555 .4419 .55463 .44087 Metetra
.664 .741 .907 r
.55463 .44087 .55555 .4419 .56131 .44005 .56039 .43902 Metetra
.664 .741 .907 r
.56039 .43902 .56131 .44005 .56708 .4382 .56617 .43716 Metetra
.664 .741 .907 r
.56617 .43716 .56708 .4382 .57287 .43634 .57196 .4353 Metetra
.664 .741 .907 r
.57196 .4353 .57287 .43634 .57867 .43448 .57776 .43344 Metetra
.664 .741 .907 r
.57776 .43344 .57867 .43448 .58448 .43261 .58357 .43157 Metetra
.664 .741 .907 r
.58357 .43157 .58448 .43261 .59031 .43074 .5894 .4297 Metetra
.664 .741 .907 r
.5894 .4297 .59031 .43074 .59614 .42887 .59524 .42782 Metetra
.664 .741 .907 r
.59524 .42782 .59614 .42887 .60199 .42699 .60109 .42594 Metetra
.664 .741 .907 r
.60109 .42594 .60199 .42699 .60785 .42511 .60695 .42406 Metetra
.664 .741 .907 r
.60695 .42406 .60785 .42511 .61372 .42322 .61283 .42217 Metetra
.664 .741 .907 r
.61283 .42217 .61372 .42322 .61961 .42133 .61871 .42028 Metetra
.664 .741 .907 r
.61871 .42028 .61961 .42133 .62551 .41944 .62461 .41838 Metetra
.664 .741 .907 r
.62461 .41838 .62551 .41944 .63141 .41754 .63053 .41648 Metetra
.664 .741 .907 r
.63053 .41648 .63141 .41754 .63734 .41564 .63645 .41458 Metetra
.664 .741 .907 r
.63645 .41458 .63734 .41564 .64327 .41373 .64239 .41267 Metetra
.664 .741 .907 r
.64239 .41267 .64327 .41373 .64922 .41182 .64834 .41076 Metetra
.664 .741 .907 r
.64834 .41076 .64922 .41182 .65518 .40991 .6543 .40884 Metetra
.664 .741 .907 r
.6543 .40884 .65518 .40991 .66115 .40799 .66028 .40692 Metetra
.664 .741 .907 r
.66028 .40692 .66115 .40799 .66714 .40607 .66627 .405 Metetra
.664 .741 .907 r
.66627 .405 .66714 .40607 .67314 .40415 .67227 .40307 Metetra
.664 .741 .907 r
.67227 .40307 .67314 .40415 .67915 .40222 .67828 .40114 Metetra
.664 .741 .907 r
.67828 .40114 .67915 .40222 .68517 .40028 .68431 .3992 Metetra
.664 .741 .907 r
.68431 .3992 .68517 .40028 .69121 .39834 .69035 .39726 Metetra
.664 .741 .907 r
.69035 .39726 .69121 .39834 .69726 .3964 .6964 .39531 Metetra
.895 .494 .071 r
.6964 .39531 .69726 .3964 .70332 .39445 .70367 .41525 Metetra
.425 .223 .501 r
.70367 .41525 .70332 .39445 .70939 .3925 .70854 .39141 Metetra
.922 .541 .142 r
.70854 .39141 .70939 .3925 .71998 .46629 .71624 .41674 Metetra
.614 .395 .561 r
.71624 .41674 .71998 .46629 .72158 .38859 .72074 .38749 Metetra
.664 .741 .907 r
.72074 .38749 .72158 .38859 .7277 .38663 .72685 .38553 Metetra
.664 .741 .907 r
.72685 .38553 .7277 .38663 .73383 .38466 .73298 .38356 Metetra
.664 .741 .907 r
.73298 .38356 .73383 .38466 .73997 .38269 .73913 .38158 Metetra
.664 .741 .907 r
.73913 .38158 .73997 .38269 .74612 .38071 .74528 .37961 Metetra
.664 .741 .907 r
.74528 .37961 .74612 .38071 .75229 .37873 .75145 .37762 Metetra
.664 .741 .907 r
.75145 .37762 .75229 .37873 .75847 .37675 .75764 .37564 Metetra
.664 .741 .907 r
.75764 .37564 .75847 .37675 .76466 .37476 .76383 .37365 Metetra
.664 .741 .907 r
.76383 .37365 .76466 .37476 .77087 .37276 .77004 .37165 Metetra
.664 .741 .907 r
.77004 .37165 .77087 .37276 .77709 .37077 .77627 .36965 Metetra
.664 .741 .907 r
.77627 .36965 .77709 .37077 .78332 .36876 .78251 .36765 Metetra
.664 .741 .907 r
.78251 .36765 .78332 .36876 .78957 .36676 .78876 .36564 Metetra
.664 .741 .907 r
.78876 .36564 .78957 .36676 .79583 .36475 .79502 .36362 Metetra
.664 .741 .907 r
.79502 .36362 .79583 .36475 .80211 .36273 .8013 .36161 Metetra
.664 .741 .907 r
.8013 .36161 .80211 .36273 .8084 .36071 .80759 .35958 Metetra
.664 .741 .907 r
.80759 .35958 .8084 .36071 .8147 .35869 .8139 .35756 Metetra
.664 .741 .907 r
.8139 .35756 .8147 .35869 .82102 .35666 .82021 .35553 Metetra
.664 .741 .907 r
.82021 .35553 .82102 .35666 .82735 .35463 .82655 .35349 Metetra
.664 .741 .907 r
.82655 .35349 .82735 .35463 .83369 .35259 .83289 .35145 Metetra
.664 .741 .907 r
.83289 .35145 .83369 .35259 .84005 .35055 .83925 .34941 Metetra
.664 .741 .907 r
.83925 .34941 .84005 .35055 .84642 .3485 .84563 .34736 Metetra
.664 .741 .907 r
.84563 .34736 .84642 .3485 .8528 .34645 .85202 .34531 Metetra
.664 .741 .907 r
.85202 .34531 .8528 .34645 .8592 .3444 .85842 .34325 Metetra
.664 .741 .907 r
.85842 .34325 .8592 .3444 .86562 .34234 .86484 .34119 Metetra
.664 .741 .907 r
.86484 .34119 .86562 .34234 .87205 .34028 .87127 .33912 Metetra
.664 .741 .907 r
.87127 .33912 .87205 .34028 .87849 .33821 .87771 .33705 Metetra
.664 .741 .907 r
.87771 .33705 .87849 .33821 .88494 .33613 .88417 .33498 Metetra
.664 .741 .907 r
.88417 .33498 .88494 .33613 .89141 .33406 .89065 .3329 Metetra
.664 .741 .907 r
.89065 .3329 .89141 .33406 .8979 .33197 .89713 .33081 Metetra
.664 .741 .907 r
.89713 .33081 .8979 .33197 .9044 .32989 .90364 .32872 Metetra
.664 .741 .907 r
.31657 .51609 .31759 .51704 .32287 .51534 .32186 .5144 Metetra
.664 .741 .907 r
.32186 .5144 .32287 .51534 .32816 .51364 .32715 .51269 Metetra
.664 .741 .907 r
.32715 .51269 .32816 .51364 .33346 .51194 .33246 .51099 Metetra
.664 .741 .907 r
.33246 .51099 .33346 .51194 .33878 .51023 .33777 .50928 Metetra
.664 .741 .907 r
.33777 .50928 .33878 .51023 .3441 .50852 .3431 .50757 Metetra
.664 .741 .907 r
.3431 .50757 .3441 .50852 .34943 .50681 .34843 .50585 Metetra
.664 .741 .907 r
.34843 .50585 .34943 .50681 .35478 .50509 .35378 .50413 Metetra
.664 .741 .907 r
.35378 .50413 .35478 .50509 .36014 .50337 .35914 .50241 Metetra
.664 .741 .907 r
.35914 .50241 .36014 .50337 .3655 .50164 .36451 .50068 Metetra
.895 .474 .122 r
.36451 .50068 .3655 .50164 .37088 .49992 .36928 .51195 Metetra
.379 .161 .452 r
.36928 .51195 .37088 .49992 .37627 .49818 .37528 .49722 Metetra
.664 .741 .907 r
.37528 .49722 .37627 .49818 .38167 .49645 .38068 .49548 Metetra
.664 .741 .907 r
.38068 .49548 .38167 .49645 .38708 .49471 .38609 .49374 Metetra
.664 .741 .907 r
.38609 .49374 .38708 .49471 .3925 .49297 .39151 .492 Metetra
.664 .741 .907 r
.39151 .492 .3925 .49297 .39793 .49122 .39695 .49025 Metetra
.664 .741 .907 r
.39695 .49025 .39793 .49122 .40338 .48947 .40239 .4885 Metetra
.664 .741 .907 r
.40239 .4885 .40338 .48947 .40883 .48772 .40785 .48674 Metetra
.664 .741 .907 r
.40785 .48674 .40883 .48772 .41429 .48596 .41332 .48498 Metetra
.664 .741 .907 r
.41332 .48498 .41429 .48596 .41977 .48421 .4188 .48322 Metetra
.664 .741 .907 r
.4188 .48322 .41977 .48421 .42526 .48244 .42429 .48146 Metetra
.664 .741 .907 r
.42429 .48146 .42526 .48244 .43076 .48067 .42979 .47969 Metetra
.664 .741 .907 r
.42979 .47969 .43076 .48067 .43627 .4789 .4353 .47792 Metetra
.664 .741 .907 r
.4353 .47792 .43627 .4789 .44179 .47713 .44082 .47614 Metetra
.664 .741 .907 r
.44082 .47614 .44179 .47713 .44732 .47535 .44636 .47436 Metetra
.664 .741 .907 r
.44636 .47436 .44732 .47535 .45286 .47357 .4519 .47258 Metetra
.664 .741 .907 r
.4519 .47258 .45286 .47357 .45842 .47179 .45746 .47079 Metetra
.664 .741 .907 r
.45746 .47079 .45842 .47179 .46399 .47 .46303 .469 Metetra
.664 .741 .907 r
.46303 .469 .46399 .47 .46956 .46865 .46861 .4672 Metetra
.959 .678 .459 r
.46861 .4672 .46956 .46865 .47269 .62929 .47209 .6022 Metetra
.702 .474 .576 r
.47209 .6022 .47269 .62929 .47777 .68652 .47859 .55207 Metetra
.624 .401 .559 r
.47859 .55207 .47777 .68652 .48637 .46281 .48542 .4618 Metetra
.664 .741 .907 r
.48542 .4618 .48637 .46281 .49199 .461 .49104 .45999 Metetra
.664 .741 .907 r
.49104 .45999 .49199 .461 .49763 .45919 .49668 .45818 Metetra
.664 .741 .907 r
.49668 .45818 .49763 .45919 .50327 .45737 .50233 .45636 Metetra
.664 .741 .907 r
.50233 .45636 .50327 .45737 .50893 .45555 .50799 .45454 Metetra
.664 .741 .907 r
.50799 .45454 .50893 .45555 .5146 .45373 .51367 .45271 Metetra
.664 .741 .907 r
.51367 .45271 .5146 .45373 .52028 .45191 .51935 .45089 Metetra
.664 .741 .907 r
.51935 .45089 .52028 .45191 .52598 .45008 .52505 .44905 Metetra
.664 .741 .907 r
.52505 .44905 .52598 .45008 .53168 .44824 .53075 .44722 Metetra
.664 .741 .907 r
.53075 .44722 .53168 .44824 .5374 .44641 .53647 .44538 Metetra
.664 .741 .907 r
.53647 .44538 .5374 .44641 .54313 .44456 .54221 .44354 Metetra
.664 .741 .907 r
.54221 .44354 .54313 .44456 .54887 .44272 .54795 .44169 Metetra
.664 .741 .907 r
.54795 .44169 .54887 .44272 .55463 .44087 .55371 .43984 Metetra
.664 .741 .907 r
.55371 .43984 .55463 .44087 .56039 .43902 .55947 .43798 Metetra
.664 .741 .907 r
.55947 .43798 .56039 .43902 .56617 .43716 .56525 .43612 Metetra
.664 .741 .907 r
.56525 .43612 .56617 .43716 .57196 .4353 .57105 .43426 Metetra
.664 .741 .907 r
.57105 .43426 .57196 .4353 .57776 .43344 .57685 .4324 Metetra
.664 .741 .907 r
.57685 .4324 .57776 .43344 .58357 .43157 .58267 .43053 Metetra
.664 .741 .907 r
.58267 .43053 .58357 .43157 .5894 .4297 .58849 .42865 Metetra
.664 .741 .907 r
.58849 .42865 .5894 .4297 .59524 .42782 .59434 .42677 Metetra
.664 .741 .907 r
.59434 .42677 .59524 .42782 .60109 .42594 .60019 .42489 Metetra
.664 .741 .907 r
.60019 .42489 .60109 .42594 .60695 .42406 .60605 .423 Metetra
.664 .741 .907 r
.60605 .423 .60695 .42406 .61283 .42217 .61193 .42111 Metetra
.664 .741 .907 r
.61193 .42111 .61283 .42217 .61871 .42028 .61782 .41922 Metetra
.664 .741 .907 r
.61782 .41922 .61871 .42028 .62461 .41838 .62372 .41732 Metetra
.664 .741 .907 r
.62372 .41732 .62461 .41838 .63053 .41648 .62964 .41542 Metetra
.664 .741 .907 r
.62964 .41542 .63053 .41648 .63645 .41458 .63557 .41351 Metetra
.664 .741 .907 r
.63557 .41351 .63645 .41458 .64239 .41267 .64151 .4116 Metetra
.664 .741 .907 r
.64151 .4116 .64239 .41267 .64834 .41076 .64746 .40969 Metetra
.664 .741 .907 r
.64746 .40969 .64834 .41076 .6543 .40884 .65342 .40777 Metetra
.664 .741 .907 r
.65342 .40777 .6543 .40884 .66028 .40692 .6594 .40585 Metetra
.664 .741 .907 r
.6594 .40585 .66028 .40692 .66627 .405 .66539 .40392 Metetra
.664 .741 .907 r
.66539 .40392 .66627 .405 .67227 .40307 .6714 .40199 Metetra
.664 .741 .907 r
.6714 .40199 .67227 .40307 .67828 .40114 .67741 .40006 Metetra
.664 .741 .907 r
.67741 .40006 .67828 .40114 .68431 .3992 .68344 .39812 Metetra
.664 .741 .907 r
.68344 .39812 .68431 .3992 .69035 .39726 .68948 .39618 Metetra
.664 .741 .907 r
.68948 .39618 .69035 .39726 .6964 .39531 .69554 .39423 Metetra
.48 .661 .941 r
.69554 .39423 .6964 .39531 .70367 .41525 .70173 .39451 Metetra
.489 .315 .572 r
.70173 .39451 .70367 .41525 .70854 .39141 .70873 .40871 Metetra
.42 .215 .493 r
.70873 .40871 .70854 .39141 .71624 .41674 .71378 .38836 Metetra
.568 .368 .569 r
.71378 .38836 .71624 .41674 .72074 .38749 .71989 .3864 Metetra
.664 .741 .907 r
.71989 .3864 .72074 .38749 .72685 .38553 .72601 .38443 Metetra
.664 .741 .907 r
.72601 .38443 .72685 .38553 .73298 .38356 .73214 .38246 Metetra
.664 .741 .907 r
.73214 .38246 .73298 .38356 .73913 .38158 .73829 .38048 Metetra
.664 .741 .907 r
.73829 .38048 .73913 .38158 .74528 .37961 .74445 .3785 Metetra
.664 .741 .907 r
.74445 .3785 .74528 .37961 .75145 .37762 .75062 .37652 Metetra
.664 .741 .907 r
.75062 .37652 .75145 .37762 .75764 .37564 .75681 .37453 Metetra
.664 .741 .907 r
.75681 .37453 .75764 .37564 .76383 .37365 .763 .37253 Metetra
.664 .741 .907 r
.763 .37253 .76383 .37365 .77004 .37165 .76922 .37053 Metetra
.664 .741 .907 r
.76922 .37053 .77004 .37165 .77627 .36965 .77544 .36853 Metetra
.664 .741 .907 r
.77544 .36853 .77627 .36965 .78251 .36765 .78168 .36653 Metetra
.664 .741 .907 r
.78168 .36653 .78251 .36765 .78876 .36564 .78794 .36451 Metetra
.664 .741 .907 r
.78794 .36451 .78876 .36564 .79502 .36362 .79421 .3625 Metetra
.664 .741 .907 r
.79421 .3625 .79502 .36362 .8013 .36161 .80049 .36048 Metetra
.664 .741 .907 r
.80049 .36048 .8013 .36161 .80759 .35958 .80678 .35846 Metetra
.664 .741 .907 r
.80678 .35846 .80759 .35958 .8139 .35756 .81309 .35643 Metetra
.664 .741 .907 r
.81309 .35643 .8139 .35756 .82021 .35553 .81941 .35439 Metetra
.664 .741 .907 r
.81941 .35439 .82021 .35553 .82655 .35349 .82575 .35236 Metetra
.664 .741 .907 r
.82575 .35236 .82655 .35349 .83289 .35145 .8321 .35031 Metetra
.664 .741 .907 r
.8321 .35031 .83289 .35145 .83925 .34941 .83846 .34827 Metetra
.664 .741 .907 r
.83846 .34827 .83925 .34941 .84563 .34736 .84484 .34622 Metetra
.664 .741 .907 r
.84484 .34622 .84563 .34736 .85202 .34531 .85123 .34416 Metetra
.664 .741 .907 r
.85123 .34416 .85202 .34531 .85842 .34325 .85764 .3421 Metetra
.664 .741 .907 r
.85764 .3421 .85842 .34325 .86484 .34119 .86406 .34004 Metetra
.664 .741 .907 r
.86406 .34004 .86484 .34119 .87127 .33912 .87049 .33797 Metetra
.664 .741 .907 r
.87049 .33797 .87127 .33912 .87771 .33705 .87694 .33589 Metetra
.664 .741 .907 r
.87694 .33589 .87771 .33705 .88417 .33498 .8834 .33382 Metetra
.664 .741 .907 r
.8834 .33382 .88417 .33498 .89065 .3329 .88988 .33173 Metetra
.664 .741 .907 r
.88988 .33173 .89065 .3329 .89713 .33081 .89637 .32965 Metetra
.664 .741 .907 r
.89637 .32965 .89713 .33081 .90364 .32872 .90287 .32755 Metetra
.664 .741 .907 r
.31556 .51515 .31657 .51609 .32186 .5144 .32084 .51345 Metetra
.664 .741 .907 r
.32084 .51345 .32186 .5144 .32715 .51269 .32614 .51174 Metetra
.664 .741 .907 r
.32614 .51174 .32715 .51269 .33246 .51099 .33145 .51003 Metetra
.664 .741 .907 r
.33145 .51003 .33246 .51099 .33777 .50928 .33676 .50832 Metetra
.664 .741 .907 r
.33676 .50832 .33777 .50928 .3431 .50757 .34209 .50661 Metetra
.664 .741 .907 r
.34209 .50661 .3431 .50757 .34843 .50585 .34743 .50489 Metetra
.664 .741 .907 r
.34743 .50489 .34843 .50585 .35378 .50413 .35278 .50317 Metetra
.664 .741 .907 r
.35278 .50317 .35378 .50413 .35914 .50241 .35814 .50144 Metetra
.948 .646 .431 r
.35814 .50144 .35914 .50241 .36451 .50068 .36153 .54056 Metetra
.411 .213 .499 r
.36153 .54056 .36451 .50068 .36928 .51195 .36889 .49798 Metetra
.576 .388 .589 r
.36889 .49798 .36928 .51195 .37528 .49722 .37429 .49625 Metetra
.664 .741 .907 r
.37429 .49625 .37528 .49722 .38068 .49548 .37969 .49451 Metetra
.664 .741 .907 r
.37969 .49451 .38068 .49548 .38609 .49374 .3851 .49277 Metetra
.664 .741 .907 r
.3851 .49277 .38609 .49374 .39151 .492 .39053 .49102 Metetra
.664 .741 .907 r
.39053 .49102 .39151 .492 .39695 .49025 .39596 .48927 Metetra
.664 .741 .907 r
.39596 .48927 .39695 .49025 .40239 .4885 .40141 .48752 Metetra
.664 .741 .907 r
.40141 .48752 .40239 .4885 .40785 .48674 .40687 .48576 Metetra
.664 .741 .907 r
.40687 .48576 .40785 .48674 .41332 .48498 .41234 .484 Metetra
.664 .741 .907 r
.41234 .484 .41332 .48498 .4188 .48322 .41782 .48224 Metetra
.664 .741 .907 r
.41782 .48224 .4188 .48322 .42429 .48146 .42331 .48047 Metetra
.664 .741 .907 r
.42331 .48047 .42429 .48146 .42979 .47969 .42882 .4787 Metetra
.664 .741 .907 r
.42882 .4787 .42979 .47969 .4353 .47792 .43433 .47692 Metetra
.664 .741 .907 r
.43433 .47692 .4353 .47792 .44082 .47614 .43985 .47515 Metetra
.664 .741 .907 r
.43985 .47515 .44082 .47614 .44636 .47436 .44539 .47336 Metetra
.664 .741 .907 r
.44539 .47336 .44636 .47436 .4519 .47258 .45094 .47158 Metetra
.664 .741 .907 r
.45094 .47158 .4519 .47258 .45746 .47079 .4565 .46979 Metetra
.664 .741 .907 r
.4565 .46979 .45746 .47079 .46303 .469 .46207 .468 Metetra
.664 .741 .907 r
.46207 .468 .46303 .469 .46861 .4672 .46765 .4662 Metetra
.957 .652 .412 r
.46765 .4662 .46861 .4672 .47209 .6022 .47241 .51762 Metetra
.557 .349 .554 r
.47241 .51762 .47209 .6022 .47859 .55207 .47805 .51982 Metetra
.701 .471 .572 r
.47805 .51982 .47859 .55207 .48542 .4618 .48447 .46079 Metetra
.664 .741 .907 r
.48447 .46079 .48542 .4618 .49104 .45999 .4901 .45898 Metetra
.664 .741 .907 r
.4901 .45898 .49104 .45999 .49668 .45818 .49574 .45716 Metetra
.664 .741 .907 r
.49574 .45716 .49668 .45818 .50233 .45636 .50139 .45534 Metetra
.664 .741 .907 r
.50139 .45534 .50233 .45636 .50799 .45454 .50705 .45352 Metetra
.664 .741 .907 r
.50705 .45352 .50799 .45454 .51367 .45271 .51273 .4517 Metetra
.664 .741 .907 r
.51273 .4517 .51367 .45271 .51935 .45089 .51841 .44987 Metetra
.664 .741 .907 r
.51841 .44987 .51935 .45089 .52505 .44905 .52411 .44803 Metetra
.664 .741 .907 r
.52411 .44803 .52505 .44905 .53075 .44722 .52982 .44619 Metetra
.664 .741 .907 r
.52982 .44619 .53075 .44722 .53647 .44538 .53555 .44435 Metetra
.664 .741 .907 r
.53555 .44435 .53647 .44538 .54221 .44354 .54128 .44251 Metetra
.664 .741 .907 r
.54128 .44251 .54221 .44354 .54795 .44169 .54703 .44066 Metetra
.664 .741 .907 r
.54703 .44066 .54795 .44169 .55371 .43984 .55278 .4388 Metetra
.664 .741 .907 r
.55278 .4388 .55371 .43984 .55947 .43798 .55855 .43695 Metetra
.664 .741 .907 r
.55855 .43695 .55947 .43798 .56525 .43612 .56434 .43509 Metetra
.664 .741 .907 r
.56434 .43509 .56525 .43612 .57105 .43426 .57013 .43322 Metetra
.664 .741 .907 r
.57013 .43322 .57105 .43426 .57685 .4324 .57594 .43135 Metetra
.664 .741 .907 r
.57594 .43135 .57685 .4324 .58267 .43053 .58176 .42948 Metetra
.664 .741 .907 r
.58176 .42948 .58267 .43053 .58849 .42865 .58759 .4276 Metetra
.664 .741 .907 r
.58759 .4276 .58849 .42865 .59434 .42677 .59343 .42572 Metetra
.664 .741 .907 r
.59343 .42572 .59434 .42677 .60019 .42489 .59929 .42384 Metetra
.664 .741 .907 r
.59929 .42384 .60019 .42489 .60605 .423 .60515 .42195 Metetra
.664 .741 .907 r
.60515 .42195 .60605 .423 .61193 .42111 .61103 .42006 Metetra
.664 .741 .907 r
.61103 .42006 .61193 .42111 .61782 .41922 .61693 .41816 Metetra
.664 .741 .907 r
.61693 .41816 .61782 .41922 .62372 .41732 .62283 .41626 Metetra
.664 .741 .907 r
.62283 .41626 .62372 .41732 .62964 .41542 .62875 .41436 Metetra
.664 .741 .907 r
.62875 .41436 .62964 .41542 .63557 .41351 .63468 .41245 Metetra
.664 .741 .907 r
.63468 .41245 .63557 .41351 .64151 .4116 .64062 .41054 Metetra
.664 .741 .907 r
.64062 .41054 .64151 .4116 .64746 .40969 .64658 .40862 Metetra
.664 .741 .907 r
.64658 .40862 .64746 .40969 .65342 .40777 .65254 .4067 Metetra
.664 .741 .907 r
.65254 .4067 .65342 .40777 .6594 .40585 .65853 .40477 Metetra
.664 .741 .907 r
.65853 .40477 .6594 .40585 .66539 .40392 .66452 .40285 Metetra
.664 .741 .907 r
.66452 .40285 .66539 .40392 .6714 .40199 .67052 .40091 Metetra
.664 .741 .907 r
.67052 .40091 .6714 .40199 .67741 .40006 .67654 .39898 Metetra
.664 .741 .907 r
.67654 .39898 .67741 .40006 .68344 .39812 .68257 .39704 Metetra
.664 .741 .907 r
.68257 .39704 .68344 .39812 .68948 .39618 .68862 .39509 Metetra
.664 .741 .907 r
.68862 .39509 .68948 .39618 .69554 .39423 .69468 .39314 Metetra
.664 .741 .907 r
.69468 .39314 .69554 .39423 .70173 .39451 .70075 .39119 Metetra
.623 .516 .712 r
.70075 .39119 .70173 .39451 .70873 .40871 .70683 .38923 Metetra
.572 .377 .579 r
.70683 .38923 .70873 .40871 .71378 .38836 .71293 .38727 Metetra
.664 .741 .907 r
.71293 .38727 .71378 .38836 .71989 .3864 .71904 .3853 Metetra
.664 .741 .907 r
.71904 .3853 .71989 .3864 .72601 .38443 .72516 .38333 Metetra
.664 .741 .907 r
.72516 .38333 .72601 .38443 .73214 .38246 .7313 .38136 Metetra
.664 .741 .907 r
.7313 .38136 .73214 .38246 .73829 .38048 .73744 .37938 Metetra
.664 .741 .907 r
.73744 .37938 .73829 .38048 .74445 .3785 .74361 .37739 Metetra
.664 .741 .907 r
.74361 .37739 .74445 .3785 .75062 .37652 .74978 .37541 Metetra
.664 .741 .907 r
.74978 .37541 .75062 .37652 .75681 .37453 .75597 .37341 Metetra
.664 .741 .907 r
.75597 .37341 .75681 .37453 .763 .37253 .76217 .37142 Metetra
.664 .741 .907 r
.76217 .37142 .763 .37253 .76922 .37053 .76839 .36942 Metetra
.664 .741 .907 r
.76839 .36942 .76922 .37053 .77544 .36853 .77462 .36741 Metetra
.664 .741 .907 r
.77462 .36741 .77544 .36853 .78168 .36653 .78086 .3654 Metetra
.664 .741 .907 r
.78086 .3654 .78168 .36653 .78794 .36451 .78712 .36339 Metetra
.664 .741 .907 r
.78712 .36339 .78794 .36451 .79421 .3625 .79339 .36137 Metetra
.664 .741 .907 r
.79339 .36137 .79421 .3625 .80049 .36048 .79967 .35935 Metetra
.664 .741 .907 r
.79967 .35935 .80049 .36048 .80678 .35846 .80597 .35732 Metetra
.664 .741 .907 r
.80597 .35732 .80678 .35846 .81309 .35643 .81228 .35529 Metetra
.664 .741 .907 r
.81228 .35529 .81309 .35643 .81941 .35439 .81861 .35326 Metetra
.664 .741 .907 r
.81861 .35326 .81941 .35439 .82575 .35236 .82495 .35122 Metetra
.664 .741 .907 r
.82495 .35122 .82575 .35236 .8321 .35031 .8313 .34917 Metetra
.664 .741 .907 r
.8313 .34917 .8321 .35031 .83846 .34827 .83767 .34712 Metetra
.664 .741 .907 r
.83767 .34712 .83846 .34827 .84484 .34622 .84405 .34507 Metetra
.664 .741 .907 r
.84405 .34507 .84484 .34622 .85123 .34416 .85044 .34301 Metetra
.664 .741 .907 r
.85044 .34301 .85123 .34416 .85764 .3421 .85685 .34095 Metetra
.664 .741 .907 r
.85685 .34095 .85764 .3421 .86406 .34004 .86327 .33888 Metetra
.664 .741 .907 r
.86327 .33888 .86406 .34004 .87049 .33797 .86971 .33681 Metetra
.664 .741 .907 r
.86971 .33681 .87049 .33797 .87694 .33589 .87616 .33474 Metetra
.664 .741 .907 r
.87616 .33474 .87694 .33589 .8834 .33382 .88263 .33266 Metetra
.664 .741 .907 r
.88263 .33266 .8834 .33382 .88988 .33173 .88911 .33057 Metetra
.664 .741 .907 r
.88911 .33057 .88988 .33173 .89637 .32965 .8956 .32848 Metetra
.664 .741 .907 r
.8956 .32848 .89637 .32965 .90287 .32755 .90211 .32639 Metetra
.664 .741 .907 r
.31454 .5142 .31556 .51515 .32084 .51345 .31983 .5125 Metetra
.664 .741 .907 r
.31983 .5125 .32084 .51345 .32614 .51174 .32513 .51079 Metetra
.664 .741 .907 r
.32513 .51079 .32614 .51174 .33145 .51003 .33044 .50908 Metetra
.664 .741 .907 r
.33044 .50908 .33145 .51003 .33676 .50832 .33576 .50737 Metetra
.664 .741 .907 r
.33576 .50737 .33676 .50832 .34209 .50661 .34109 .50565 Metetra
.664 .741 .907 r
.34109 .50565 .34209 .50661 .34743 .50489 .34643 .50393 Metetra
.664 .741 .907 r
.34643 .50393 .34743 .50489 .35278 .50317 .35178 .50221 Metetra
.664 .741 .907 r
.35178 .50221 .35278 .50317 .35814 .50144 .35714 .50048 Metetra
.948 .646 .431 r
.35714 .50048 .35814 .50144 .36153 .54056 .36052 .53962 Metetra
.93 .712 .586 r
.36052 .53962 .36153 .54056 .36889 .49798 .3679 .49702 Metetra
.664 .741 .907 r
.3679 .49702 .36889 .49798 .37429 .49625 .37329 .49528 Metetra
.664 .741 .907 r
.37329 .49528 .37429 .49625 .37969 .49451 .3787 .49354 Metetra
.664 .741 .907 r
.3787 .49354 .37969 .49451 .3851 .49277 .38411 .49179 Metetra
.664 .741 .907 r
.38411 .49179 .3851 .49277 .39053 .49102 .38954 .49005 Metetra
.664 .741 .907 r
.38954 .49005 .39053 .49102 .39596 .48927 .39498 .48829 Metetra
.664 .741 .907 r
.39498 .48829 .39596 .48927 .40141 .48752 .40043 .48654 Metetra
.664 .741 .907 r
.40043 .48654 .40141 .48752 .40687 .48576 .40589 .48478 Metetra
.664 .741 .907 r
.40589 .48478 .40687 .48576 .41234 .484 .41136 .48302 Metetra
.664 .741 .907 r
.41136 .48302 .41234 .484 .41782 .48224 .41684 .48125 Metetra
.664 .741 .907 r
.41684 .48125 .41782 .48224 .42331 .48047 .42234 .47948 Metetra
.664 .741 .907 r
.42234 .47948 .42331 .48047 .42882 .4787 .42784 .47771 Metetra
.664 .741 .907 r
.42784 .47771 .42882 .4787 .43433 .47692 .43336 .47593 Metetra
.664 .741 .907 r
.43336 .47593 .43433 .47692 .43985 .47515 .43889 .47415 Metetra
.664 .741 .907 r
.43889 .47415 .43985 .47515 .44539 .47336 .44443 .47237 Metetra
.664 .741 .907 r
.44443 .47237 .44539 .47336 .45094 .47158 .44998 .47058 Metetra
.664 .741 .907 r
.44998 .47058 .45094 .47158 .4565 .46979 .45554 .46879 Metetra
.664 .741 .907 r
.45554 .46879 .4565 .46979 .46207 .468 .46111 .467 Metetra
.664 .741 .907 r
.46111 .467 .46207 .468 .46765 .4662 .4667 .4652 Metetra
.664 .741 .907 r
.4667 .4652 .46765 .4662 .47241 .51762 .47229 .4634 Metetra
.527 .328 .554 r
.47229 .4634 .47241 .51762 .47805 .51982 .47764 .47953 Metetra
.607 .394 .566 r
.47764 .47953 .47805 .51982 .48447 .46079 .48352 .45978 Metetra
.664 .741 .907 r
.48352 .45978 .48447 .46079 .4901 .45898 .48915 .45797 Metetra
.664 .741 .907 r
.48915 .45797 .4901 .45898 .49574 .45716 .49479 .45615 Metetra
.664 .741 .907 r
.49479 .45615 .49574 .45716 .50139 .45534 .50044 .45433 Metetra
.95 .603 .306 r
.50044 .45433 .50139 .45534 .50705 .45352 .50595 .4809 Metetra
.415 .216 .498 r
.50595 .4809 .50705 .45352 .51273 .4517 .51179 .45067 Metetra
.664 .741 .907 r
.51179 .45067 .51273 .4517 .51841 .44987 .51748 .44884 Metetra
.664 .741 .907 r
.51748 .44884 .51841 .44987 .52411 .44803 .52318 .44701 Metetra
.664 .741 .907 r
.52318 .44701 .52411 .44803 .52982 .44619 .52889 .44517 Metetra
.664 .741 .907 r
.52889 .44517 .52982 .44619 .53555 .44435 .53462 .44332 Metetra
.664 .741 .907 r
.53462 .44332 .53555 .44435 .54128 .44251 .54035 .44148 Metetra
.664 .741 .907 r
.54035 .44148 .54128 .44251 .54703 .44066 .5461 .43962 Metetra
.664 .741 .907 r
.5461 .43962 .54703 .44066 .55278 .4388 .55186 .43777 Metetra
.664 .741 .907 r
.55186 .43777 .55278 .4388 .55855 .43695 .55763 .43591 Metetra
.664 .741 .907 r
.55763 .43591 .55855 .43695 .56434 .43509 .56342 .43405 Metetra
.664 .741 .907 r
.56342 .43405 .56434 .43509 .57013 .43322 .56922 .43218 Metetra
.664 .741 .907 r
.56922 .43218 .57013 .43322 .57594 .43135 .57502 .43031 Metetra
.664 .741 .907 r
.57502 .43031 .57594 .43135 .58176 .42948 .58085 .42843 Metetra
.664 .741 .907 r
.58085 .42843 .58176 .42948 .58759 .4276 .58668 .42656 Metetra
.664 .741 .907 r
.58668 .42656 .58759 .4276 .59343 .42572 .59252 .42467 Metetra
.664 .741 .907 r
.59252 .42467 .59343 .42572 .59929 .42384 .59838 .42279 Metetra
.664 .741 .907 r
.59838 .42279 .59929 .42384 .60515 .42195 .60425 .4209 Metetra
.664 .741 .907 r
.60425 .4209 .60515 .42195 .61103 .42006 .61014 .419 Metetra
.664 .741 .907 r
.61014 .419 .61103 .42006 .61693 .41816 .61603 .4171 Metetra
.664 .741 .907 r
.61603 .4171 .61693 .41816 .62283 .41626 .62194 .4152 Metetra
.664 .741 .907 r
.62194 .4152 .62283 .41626 .62875 .41436 .62786 .41329 Metetra
.664 .741 .907 r
.62786 .41329 .62875 .41436 .63468 .41245 .63379 .41138 Metetra
.664 .741 .907 r
.63379 .41138 .63468 .41245 .64062 .41054 .63974 .40947 Metetra
.664 .741 .907 r
.63974 .40947 .64062 .41054 .64658 .40862 .64569 .40755 Metetra
.664 .741 .907 r
.64569 .40755 .64658 .40862 .65254 .4067 .65166 .40563 Metetra
.664 .741 .907 r
.65166 .40563 .65254 .4067 .65853 .40477 .65765 .4037 Metetra
.664 .741 .907 r
.65765 .4037 .65853 .40477 .66452 .40285 .66364 .40177 Metetra
.664 .741 .907 r
.66364 .40177 .66452 .40285 .67052 .40091 .66965 .39983 Metetra
.664 .741 .907 r
.66965 .39983 .67052 .40091 .67654 .39898 .67567 .39789 Metetra
.664 .741 .907 r
.67567 .39789 .67654 .39898 .68257 .39704 .68171 .39595 Metetra
.664 .741 .907 r
.68171 .39595 .68257 .39704 .68862 .39509 .68775 .394 Metetra
.664 .741 .907 r
.68775 .394 .68862 .39509 .69468 .39314 .69382 .39205 Metetra
.664 .741 .907 r
.69382 .39205 .69468 .39314 .70075 .39119 .69989 .3901 Metetra
.664 .741 .907 r
.69989 .3901 .70075 .39119 .70683 .38923 .70597 .38814 Metetra
.664 .741 .907 r
.70597 .38814 .70683 .38923 .71293 .38727 .71207 .38617 Metetra
.664 .741 .907 r
.71207 .38617 .71293 .38727 .71904 .3853 .71819 .3842 Metetra
.664 .741 .907 r
.71819 .3842 .71904 .3853 .72516 .38333 .72431 .38223 Metetra
.664 .741 .907 r
.72431 .38223 .72516 .38333 .7313 .38136 .73045 .38025 Metetra
.664 .741 .907 r
.73045 .38025 .7313 .38136 .73744 .37938 .7366 .37827 Metetra
.664 .741 .907 r
.7366 .37827 .73744 .37938 .74361 .37739 .74277 .37629 Metetra
.664 .741 .907 r
.74277 .37629 .74361 .37739 .74978 .37541 .74895 .3743 Metetra
.664 .741 .907 r
.74895 .3743 .74978 .37541 .75597 .37341 .75514 .3723 Metetra
.664 .741 .907 r
.75514 .3723 .75597 .37341 .76217 .37142 .76134 .3703 Metetra
.664 .741 .907 r
.76134 .3703 .76217 .37142 .76839 .36942 .76756 .3683 Metetra
.664 .741 .907 r
.76756 .3683 .76839 .36942 .77462 .36741 .77379 .36629 Metetra
.664 .741 .907 r
.77379 .36629 .77462 .36741 .78086 .3654 .78004 .36428 Metetra
.664 .741 .907 r
.78004 .36428 .78086 .3654 .78712 .36339 .7863 .36227 Metetra
.664 .741 .907 r
.7863 .36227 .78712 .36339 .79339 .36137 .79257 .36025 Metetra
.664 .741 .907 r
.79257 .36025 .79339 .36137 .79967 .35935 .79886 .35822 Metetra
.664 .741 .907 r
.79886 .35822 .79967 .35935 .80597 .35732 .80516 .35619 Metetra
.664 .741 .907 r
.80516 .35619 .80597 .35732 .81228 .35529 .81147 .35416 Metetra
.664 .741 .907 r
.81147 .35416 .81228 .35529 .81861 .35326 .8178 .35212 Metetra
.664 .741 .907 r
.8178 .35212 .81861 .35326 .82495 .35122 .82414 .35008 Metetra
.664 .741 .907 r
.82414 .35008 .82495 .35122 .8313 .34917 .8305 .34803 Metetra
.664 .741 .907 r
.8305 .34803 .8313 .34917 .83767 .34712 .83687 .34598 Metetra
.664 .741 .907 r
.83687 .34598 .83767 .34712 .84405 .34507 .84325 .34392 Metetra
.664 .741 .907 r
.84325 .34392 .84405 .34507 .85044 .34301 .84965 .34186 Metetra
.664 .741 .907 r
.84965 .34186 .85044 .34301 .85685 .34095 .85606 .3398 Metetra
.664 .741 .907 r
.85606 .3398 .85685 .34095 .86327 .33888 .86249 .33773 Metetra
.664 .741 .907 r
.86249 .33773 .86327 .33888 .86971 .33681 .86893 .33565 Metetra
.664 .741 .907 r
.86893 .33565 .86971 .33681 .87616 .33474 .87538 .33358 Metetra
.664 .741 .907 r
.87538 .33358 .87616 .33474 .88263 .33266 .88185 .33149 Metetra
.664 .741 .907 r
.88185 .33149 .88263 .33266 .88911 .33057 .88833 .3294 Metetra
.664 .741 .907 r
.88833 .3294 .88911 .33057 .8956 .32848 .89483 .32731 Metetra
.664 .741 .907 r
.89483 .32731 .8956 .32848 .90211 .32639 .90134 .32522 Metetra
.664 .741 .907 r
.31353 .51325 .31454 .5142 .31983 .5125 .31882 .51154 Metetra
.664 .741 .907 r
.31882 .51154 .31983 .5125 .32513 .51079 .32412 .50984 Metetra
.664 .741 .907 r
.32412 .50984 .32513 .51079 .33044 .50908 .32943 .50813 Metetra
.664 .741 .907 r
.32943 .50813 .33044 .50908 .33576 .50737 .33475 .50641 Metetra
.664 .741 .907 r
.33475 .50641 .33576 .50737 .34109 .50565 .34008 .50469 Metetra
.664 .741 .907 r
.34008 .50469 .34109 .50565 .34643 .50393 .34542 .50297 Metetra
.664 .741 .907 r
.34542 .50297 .34643 .50393 .35178 .50221 .35078 .50124 Metetra
.664 .741 .907 r
.35078 .50124 .35178 .50221 .35714 .50048 .35614 .49952 Metetra
.871 .43 .055 r
.35614 .49952 .35714 .50048 .36052 .53962 .36094 .50941 Metetra
.604 .396 .571 r
.36094 .50941 .36052 .53962 .3679 .49702 .3669 .49605 Metetra
.664 .741 .907 r
.3669 .49605 .3679 .49702 .37329 .49528 .3723 .49431 Metetra
.664 .741 .907 r
.3723 .49431 .37329 .49528 .3787 .49354 .3777 .49257 Metetra
.664 .741 .907 r
.3777 .49257 .3787 .49354 .38411 .49179 .38312 .49082 Metetra
.664 .741 .907 r
.38312 .49082 .38411 .49179 .38954 .49005 .38855 .48907 Metetra
.664 .741 .907 r
.38855 .48907 .38954 .49005 .39498 .48829 .39399 .48732 Metetra
.664 .741 .907 r
.39399 .48732 .39498 .48829 .40043 .48654 .39944 .48556 Metetra
.664 .741 .907 r
.39944 .48556 .40043 .48654 .40589 .48478 .40491 .4838 Metetra
.664 .741 .907 r
.40491 .4838 .40589 .48478 .41136 .48302 .41038 .48203 Metetra
.664 .741 .907 r
.41038 .48203 .41136 .48302 .41684 .48125 .41587 .48027 Metetra
.664 .741 .907 r
.41587 .48027 .41684 .48125 .42234 .47948 .42136 .47849 Metetra
.664 .741 .907 r
.42136 .47849 .42234 .47948 .42784 .47771 .42687 .47672 Metetra
.664 .741 .907 r
.42687 .47672 .42784 .47771 .43336 .47593 .43239 .47494 Metetra
.664 .741 .907 r
.43239 .47494 .43336 .47593 .43889 .47415 .43792 .47316 Metetra
.664 .741 .907 r
.43792 .47316 .43889 .47415 .44443 .47237 .44346 .47137 Metetra
.664 .741 .907 r
.44346 .47137 .44443 .47237 .44998 .47058 .44901 .46958 Metetra
.664 .741 .907 r
.44901 .46958 .44998 .47058 .45554 .46879 .45457 .46779 Metetra
.664 .741 .907 r
.45457 .46779 .45554 .46879 .46111 .467 .46015 .46599 Metetra
.664 .741 .907 r
.46015 .46599 .46111 .467 .4667 .4652 .46574 .46419 Metetra
.664 .741 .907 r
.46574 .46419 .4667 .4652 .47229 .4634 .47133 .46239 Metetra
.664 .741 .907 r
.47133 .46239 .47229 .4634 .47764 .47953 .47694 .46058 Metetra
.572 .377 .579 r
.47694 .46058 .47764 .47953 .48352 .45978 .48257 .45877 Metetra
.664 .741 .907 r
.48257 .45877 .48352 .45978 .48915 .45797 .4882 .45695 Metetra
.664 .741 .907 r
.4882 .45695 .48915 .45797 .49479 .45615 .49384 .45513 Metetra
.374 .618 .947 r
.49384 .45513 .49479 .45615 .50044 .45433 .49948 .45612 Metetra
.94 .655 .472 r
.49948 .45612 .50044 .45433 .50595 .4809 .50434 .5884 Metetra
.385 .204 .509 r
.50434 .5884 .50595 .4809 .51179 .45067 .51085 .44965 Metetra
.664 .741 .907 r
.51085 .44965 .51179 .45067 .51748 .44884 .51654 .44782 Metetra
.664 .741 .907 r
.51654 .44782 .51748 .44884 .52318 .44701 .52224 .44598 Metetra
.664 .741 .907 r
.52224 .44598 .52318 .44701 .52889 .44517 .52796 .44414 Metetra
.664 .741 .907 r
.52796 .44414 .52889 .44517 .53462 .44332 .53368 .44229 Metetra
.664 .741 .907 r
.53368 .44229 .53462 .44332 .54035 .44148 .53942 .44044 Metetra
.664 .741 .907 r
.53942 .44044 .54035 .44148 .5461 .43962 .54517 .43859 Metetra
.664 .741 .907 r
.54517 .43859 .5461 .43962 .55186 .43777 .55094 .43673 Metetra
.664 .741 .907 r
.55094 .43673 .55186 .43777 .55763 .43591 .55671 .43487 Metetra
.664 .741 .907 r
.55671 .43487 .55763 .43591 .56342 .43405 .5625 .43301 Metetra
.664 .741 .907 r
.5625 .43301 .56342 .43405 .56922 .43218 .5683 .43114 Metetra
.664 .741 .907 r
.5683 .43114 .56922 .43218 .57502 .43031 .57411 .42926 Metetra
.664 .741 .907 r
.57411 .42926 .57502 .43031 .58085 .42843 .57993 .42739 Metetra
.664 .741 .907 r
.57993 .42739 .58085 .42843 .58668 .42656 .58577 .42551 Metetra
.664 .741 .907 r
.58577 .42551 .58668 .42656 .59252 .42467 .59162 .42362 Metetra
.664 .741 .907 r
.59162 .42362 .59252 .42467 .59838 .42279 .59748 .42173 Metetra
.664 .741 .907 r
.59748 .42173 .59838 .42279 .60425 .4209 .60335 .41984 Metetra
.664 .741 .907 r
.60335 .41984 .60425 .4209 .61014 .419 .60924 .41794 Metetra
.664 .741 .907 r
.60924 .41794 .61014 .419 .61603 .4171 .61513 .41604 Metetra
.664 .741 .907 r
.61513 .41604 .61603 .4171 .62194 .4152 .62104 .41414 Metetra
.664 .741 .907 r
.62104 .41414 .62194 .4152 .62786 .41329 .62697 .41223 Metetra
.664 .741 .907 r
.62697 .41223 .62786 .41329 .63379 .41138 .6329 .41032 Metetra
.664 .741 .907 r
.6329 .41032 .63379 .41138 .63974 .40947 .63885 .4084 Metetra
.664 .741 .907 r
.63885 .4084 .63974 .40947 .64569 .40755 .64481 .40648 Metetra
.664 .741 .907 r
.64481 .40648 .64569 .40755 .65166 .40563 .65078 .40455 Metetra
.664 .741 .907 r
.65078 .40455 .65166 .40563 .65765 .4037 .65677 .40262 Metetra
.664 .741 .907 r
.65677 .40262 .65765 .4037 .66364 .40177 .66277 .40069 Metetra
.664 .741 .907 r
.66277 .40069 .66364 .40177 .66965 .39983 .66878 .39875 Metetra
.664 .741 .907 r
.66878 .39875 .66965 .39983 .67567 .39789 .6748 .39681 Metetra
.664 .741 .907 r
.6748 .39681 .67567 .39789 .68171 .39595 .68084 .39487 Metetra
.664 .741 .907 r
.68084 .39487 .68171 .39595 .68775 .394 .68689 .39292 Metetra
.664 .741 .907 r
.68689 .39292 .68775 .394 .69382 .39205 .69295 .39096 Metetra
.664 .741 .907 r
.69295 .39096 .69382 .39205 .69989 .3901 .69903 .389 Metetra
.664 .741 .907 r
.69903 .389 .69989 .3901 .70597 .38814 .70512 .38704 Metetra
.664 .741 .907 r
.70512 .38704 .70597 .38814 .71207 .38617 .71122 .38507 Metetra
.664 .741 .907 r
.71122 .38507 .71207 .38617 .71819 .3842 .71733 .3831 Metetra
.664 .741 .907 r
.71733 .3831 .71819 .3842 .72431 .38223 .72346 .38113 Metetra
.664 .741 .907 r
.72346 .38113 .72431 .38223 .73045 .38025 .7296 .37915 Metetra
.664 .741 .907 r
.7296 .37915 .73045 .38025 .7366 .37827 .73576 .37716 Metetra
.664 .741 .907 r
.73576 .37716 .7366 .37827 .74277 .37629 .74193 .37518 Metetra
.664 .741 .907 r
.74193 .37518 .74277 .37629 .74895 .3743 .74811 .37318 Metetra
.664 .741 .907 r
.74811 .37318 .74895 .3743 .75514 .3723 .7543 .37119 Metetra
.664 .741 .907 r
.7543 .37119 .75514 .3723 .76134 .3703 .76051 .36919 Metetra
.664 .741 .907 r
.76051 .36919 .76134 .3703 .76756 .3683 .76673 .36718 Metetra
.954 .609 .242 r
.76673 .36718 .76756 .3683 .77379 .36629 .77709 .41819 Metetra
.441 .25 .524 r
.77709 .41819 .77379 .36629 .78004 .36428 .77922 .36316 Metetra
.664 .741 .907 r
.77922 .36316 .78004 .36428 .7863 .36227 .78548 .36114 Metetra
.664 .741 .907 r
.78548 .36114 .7863 .36227 .79257 .36025 .79175 .35912 Metetra
.664 .741 .907 r
.79175 .35912 .79257 .36025 .79886 .35822 .79804 .35709 Metetra
.664 .741 .907 r
.79804 .35709 .79886 .35822 .80516 .35619 .80435 .35506 Metetra
.664 .741 .907 r
.80435 .35506 .80516 .35619 .81147 .35416 .81066 .35302 Metetra
.664 .741 .907 r
.81066 .35302 .81147 .35416 .8178 .35212 .817 .35098 Metetra
.664 .741 .907 r
.817 .35098 .8178 .35212 .82414 .35008 .82334 .34894 Metetra
.664 .741 .907 r
.82334 .34894 .82414 .35008 .8305 .34803 .8297 .34689 Metetra
.664 .741 .907 r
.8297 .34689 .8305 .34803 .83687 .34598 .83607 .34483 Metetra
.664 .741 .907 r
.83607 .34483 .83687 .34598 .84325 .34392 .84246 .34278 Metetra
.664 .741 .907 r
.84246 .34278 .84325 .34392 .84965 .34186 .84886 .34071 Metetra
.664 .741 .907 r
.84886 .34071 .84965 .34186 .85606 .3398 .85527 .33864 Metetra
.664 .741 .907 r
.85527 .33864 .85606 .3398 .86249 .33773 .8617 .33657 Metetra
.664 .741 .907 r
.8617 .33657 .86249 .33773 .86893 .33565 .86815 .3345 Metetra
.664 .741 .907 r
.86815 .3345 .86893 .33565 .87538 .33358 .8746 .33241 Metetra
.664 .741 .907 r
.8746 .33241 .87538 .33358 .88185 .33149 .88108 .33033 Metetra
.664 .741 .907 r
.88108 .33033 .88185 .33149 .88833 .3294 .88756 .32824 Metetra
.664 .741 .907 r
.88756 .32824 .88833 .3294 .89483 .32731 .89406 .32614 Metetra
.664 .741 .907 r
.89406 .32614 .89483 .32731 .90134 .32522 .90058 .32404 Metetra
.664 .741 .907 r
.31251 .5123 .31353 .51325 .31882 .51154 .3178 .51059 Metetra
.664 .741 .907 r
.3178 .51059 .31882 .51154 .32412 .50984 .3231 .50888 Metetra
.664 .741 .907 r
.3231 .50888 .32412 .50984 .32943 .50813 .32842 .50717 Metetra
.664 .741 .907 r
.32842 .50717 .32943 .50813 .33475 .50641 .33374 .50545 Metetra
.664 .741 .907 r
.33374 .50545 .33475 .50641 .34008 .50469 .33907 .50373 Metetra
.664 .741 .907 r
.33907 .50373 .34008 .50469 .34542 .50297 .34442 .50201 Metetra
.664 .741 .907 r
.34442 .50201 .34542 .50297 .35078 .50124 .34977 .50028 Metetra
.664 .741 .907 r
.34977 .50028 .35078 .50124 .35614 .49952 .35514 .49855 Metetra
.664 .741 .907 r
.35514 .49855 .35614 .49952 .36094 .50941 .36052 .49682 Metetra
.578 .392 .593 r
.36052 .49682 .36094 .50941 .3669 .49605 .3659 .49508 Metetra
.664 .741 .907 r
.3659 .49508 .3669 .49605 .3723 .49431 .3713 .49334 Metetra
.664 .741 .907 r
.3713 .49334 .3723 .49431 .3777 .49257 .37671 .49159 Metetra
.664 .741 .907 r
.37671 .49159 .3777 .49257 .38312 .49082 .38213 .48984 Metetra
.664 .741 .907 r
.38213 .48984 .38312 .49082 .38855 .48907 .38756 .48809 Metetra
.664 .741 .907 r
.38756 .48809 .38855 .48907 .39399 .48732 .39301 .48634 Metetra
.664 .741 .907 r
.39301 .48634 .39399 .48732 .39944 .48556 .39846 .48458 Metetra
.664 .741 .907 r
.39846 .48458 .39944 .48556 .40491 .4838 .40392 .48281 Metetra
.664 .741 .907 r
.40392 .48281 .40491 .4838 .41038 .48203 .4094 .48105 Metetra
.664 .741 .907 r
.4094 .48105 .41038 .48203 .41587 .48027 .41489 .47928 Metetra
.664 .741 .907 r
.41489 .47928 .41587 .48027 .42136 .47849 .42038 .47751 Metetra
.664 .741 .907 r
.42038 .47751 .42136 .47849 .42687 .47672 .42589 .47573 Metetra
.664 .741 .907 r
.42589 .47573 .42687 .47672 .43239 .47494 .43141 .47395 Metetra
.664 .741 .907 r
.43141 .47395 .43239 .47494 .43792 .47316 .43695 .47216 Metetra
.664 .741 .907 r
.43695 .47216 .43792 .47316 .44346 .47137 .44249 .47038 Metetra
.664 .741 .907 r
.44249 .47038 .44346 .47137 .44901 .46958 .44804 .46858 Metetra
.664 .741 .907 r
.44804 .46858 .44901 .46958 .45457 .46779 .45361 .46679 Metetra
.664 .741 .907 r
.45361 .46679 .45457 .46779 .46015 .46599 .45919 .46499 Metetra
.664 .741 .907 r
.45919 .46499 .46015 .46599 .46574 .46419 .46478 .46319 Metetra
.664 .741 .907 r
.46478 .46319 .46574 .46419 .47133 .46239 .47038 .46138 Metetra
.664 .741 .907 r
.47038 .46138 .47133 .46239 .47694 .46058 .47599 .45957 Metetra
.664 .741 .907 r
.47599 .45957 .47694 .46058 .48257 .45877 .48161 .45776 Metetra
.664 .741 .907 r
.48161 .45776 .48257 .45877 .4882 .45695 .48725 .45594 Metetra
.664 .741 .907 r
.48725 .45594 .4882 .45695 .49384 .45513 .4929 .45412 Metetra
.959 .674 .453 r
.4929 .45412 .49384 .45513 .49948 .45612 .49745 .58907 Metetra
.556 .34 .542 r
.49745 .58907 .49948 .45612 .50434 .5884 .50336 .58675 Metetra
.952 .695 .511 r
.50336 .58675 .50434 .5884 .51085 .44965 .50991 .44863 Metetra
.664 .741 .907 r
.50991 .44863 .51085 .44965 .51654 .44782 .5156 .44679 Metetra
.664 .741 .907 r
.5156 .44679 .51654 .44782 .52224 .44598 .52131 .44495 Metetra
.664 .741 .907 r
.52131 .44495 .52224 .44598 .52796 .44414 .52702 .44311 Metetra
.664 .741 .907 r
.52702 .44311 .52796 .44414 .53368 .44229 .53275 .44126 Metetra
.664 .741 .907 r
.53275 .44126 .53368 .44229 .53942 .44044 .53849 .43941 Metetra
.664 .741 .907 r
.53849 .43941 .53942 .44044 .54517 .43859 .54425 .43755 Metetra
.664 .741 .907 r
.54425 .43755 .54517 .43859 .55094 .43673 .55001 .43569 Metetra
.664 .741 .907 r
.55001 .43569 .55094 .43673 .55671 .43487 .55579 .43383 Metetra
.664 .741 .907 r
.55579 .43383 .55671 .43487 .5625 .43301 .56158 .43196 Metetra
.664 .741 .907 r
.56158 .43196 .5625 .43301 .5683 .43114 .56738 .43009 Metetra
.664 .741 .907 r
.56738 .43009 .5683 .43114 .57411 .42926 .5732 .42822 Metetra
.664 .741 .907 r
.5732 .42822 .57411 .42926 .57993 .42739 .57902 .42634 Metetra
.664 .741 .907 r
.57902 .42634 .57993 .42739 .58577 .42551 .58486 .42446 Metetra
.664 .741 .907 r
.58486 .42446 .58577 .42551 .59162 .42362 .59071 .42257 Metetra
.664 .741 .907 r
.59071 .42257 .59162 .42362 .59748 .42173 .59657 .42068 Metetra
.664 .741 .907 r
.59657 .42068 .59748 .42173 .60335 .41984 .60245 .41878 Metetra
.664 .741 .907 r
.60245 .41878 .60335 .41984 .60924 .41794 .60834 .41688 Metetra
.664 .741 .907 r
.60834 .41688 .60924 .41794 .61513 .41604 .61424 .41498 Metetra
.664 .741 .907 r
.61424 .41498 .61513 .41604 .62104 .41414 .62015 .41307 Metetra
.664 .741 .907 r
.62015 .41307 .62104 .41414 .62697 .41223 .62607 .41116 Metetra
.664 .741 .907 r
.62607 .41116 .62697 .41223 .6329 .41032 .63201 .40925 Metetra
.664 .741 .907 r
.63201 .40925 .6329 .41032 .63885 .4084 .63796 .40733 Metetra
.664 .741 .907 r
.63796 .40733 .63885 .4084 .64481 .40648 .64392 .4054 Metetra
.664 .741 .907 r
.64392 .4054 .64481 .40648 .65078 .40455 .6499 .40348 Metetra
.664 .741 .907 r
.6499 .40348 .65078 .40455 .65677 .40262 .65589 .40155 Metetra
.664 .741 .907 r
.65589 .40155 .65677 .40262 .66277 .40069 .66189 .39961 Metetra
.664 .741 .907 r
.66189 .39961 .66277 .40069 .66878 .39875 .6679 .39767 Metetra
.664 .741 .907 r
.6679 .39767 .66878 .39875 .6748 .39681 .67393 .39573 Metetra
.664 .741 .907 r
.67393 .39573 .6748 .39681 .68084 .39487 .67997 .39378 Metetra
.664 .741 .907 r
.67997 .39378 .68084 .39487 .68689 .39292 .68602 .39183 Metetra
.664 .741 .907 r
.68602 .39183 .68689 .39292 .69295 .39096 .69209 .38987 Metetra
.664 .741 .907 r
.69209 .38987 .69295 .39096 .69903 .389 .69817 .38791 Metetra
.664 .741 .907 r
.69817 .38791 .69903 .389 .70512 .38704 .70426 .38594 Metetra
.664 .741 .907 r
.70426 .38594 .70512 .38704 .71122 .38507 .71036 .38398 Metetra
.664 .741 .907 r
.71036 .38398 .71122 .38507 .71733 .3831 .71648 .382 Metetra
.664 .741 .907 r
.71648 .382 .71733 .3831 .72346 .38113 .72261 .38002 Metetra
.664 .741 .907 r
.72261 .38002 .72346 .38113 .7296 .37915 .72876 .37804 Metetra
.664 .741 .907 r
.72876 .37804 .7296 .37915 .73576 .37716 .73491 .37606 Metetra
.664 .741 .907 r
.73491 .37606 .73576 .37716 .74193 .37518 .74108 .37407 Metetra
.664 .741 .907 r
.74108 .37407 .74193 .37518 .74811 .37318 .74727 .37207 Metetra
.664 .741 .907 r
.74727 .37207 .74811 .37318 .7543 .37119 .75347 .37007 Metetra
.664 .741 .907 r
.75347 .37007 .7543 .37119 .76051 .36919 .75968 .36807 Metetra
.664 .741 .907 r
.75968 .36807 .76051 .36919 .76673 .36718 .7659 .36606 Metetra
.932 .563 .163 r
.7659 .36606 .76673 .36718 .77709 .41819 .7749 .39958 Metetra
.71 .478 .57 r
.7749 .39958 .77709 .41819 .77922 .36316 .77839 .36203 Metetra
.664 .741 .907 r
.77839 .36203 .77922 .36316 .78548 .36114 .78466 .36001 Metetra
.664 .741 .907 r
.78466 .36001 .78548 .36114 .79175 .35912 .79094 .35799 Metetra
.664 .741 .907 r
.79094 .35799 .79175 .35912 .79804 .35709 .79723 .35596 Metetra
.664 .741 .907 r
.79723 .35596 .79804 .35709 .80435 .35506 .80353 .35392 Metetra
.664 .741 .907 r
.80353 .35392 .80435 .35506 .81066 .35302 .80985 .35188 Metetra
.664 .741 .907 r
.80985 .35188 .81066 .35302 .817 .35098 .81619 .34984 Metetra
.664 .741 .907 r
.81619 .34984 .817 .35098 .82334 .34894 .82254 .34779 Metetra
.664 .741 .907 r
.82254 .34779 .82334 .34894 .8297 .34689 .8289 .34574 Metetra
.664 .741 .907 r
.8289 .34574 .8297 .34689 .83607 .34483 .83527 .34369 Metetra
.664 .741 .907 r
.83527 .34369 .83607 .34483 .84246 .34278 .84166 .34163 Metetra
.664 .741 .907 r
.84166 .34163 .84246 .34278 .84886 .34071 .84807 .33956 Metetra
.664 .741 .907 r
.84807 .33956 .84886 .34071 .85527 .33864 .85449 .33749 Metetra
.664 .741 .907 r
.85449 .33749 .85527 .33864 .8617 .33657 .86092 .33541 Metetra
.664 .741 .907 r
.86092 .33541 .8617 .33657 .86815 .3345 .86736 .33334 Metetra
.664 .741 .907 r
.86736 .33334 .86815 .3345 .8746 .33241 .87382 .33125 Metetra
.664 .741 .907 r
.87382 .33125 .8746 .33241 .88108 .33033 .8803 .32916 Metetra
.664 .741 .907 r
.8803 .32916 .88108 .33033 .88756 .32824 .88679 .32707 Metetra
.664 .741 .907 r
.88679 .32707 .88756 .32824 .89406 .32614 .89329 .32497 Metetra
.664 .741 .907 r
.89329 .32497 .89406 .32614 .90058 .32404 .89981 .32287 Metetra
.664 .741 .907 r
.31149 .51135 .31251 .5123 .3178 .51059 .31678 .50964 Metetra
.664 .741 .907 r
.31678 .50964 .3178 .51059 .3231 .50888 .32209 .50793 Metetra
.664 .741 .907 r
.32209 .50793 .3231 .50888 .32842 .50717 .3274 .50621 Metetra
.664 .741 .907 r
.3274 .50621 .32842 .50717 .33374 .50545 .33273 .50449 Metetra
.664 .741 .907 r
.33273 .50449 .33374 .50545 .33907 .50373 .33806 .50277 Metetra
.664 .741 .907 r
.33806 .50277 .33907 .50373 .34442 .50201 .34341 .50104 Metetra
.664 .741 .907 r
.34341 .50104 .34442 .50201 .34977 .50028 .34877 .49932 Metetra
.664 .741 .907 r
.34877 .49932 .34977 .50028 .35514 .49855 .35414 .49758 Metetra
.664 .741 .907 r
.35414 .49758 .35514 .49855 .36052 .49682 .35951 .49585 Metetra
.664 .741 .907 r
.35951 .49585 .36052 .49682 .3659 .49508 .3649 .49411 Metetra
.664 .741 .907 r
.3649 .49411 .3659 .49508 .3713 .49334 .3703 .49236 Metetra
.949 .644 .423 r
.3703 .49236 .3713 .49334 .37671 .49159 .37391 .53072 Metetra
.41 .212 .498 r
.37391 .53072 .37671 .49159 .38213 .48984 .38114 .48887 Metetra
.664 .741 .907 r
.38114 .48887 .38213 .48984 .38756 .48809 .38657 .48711 Metetra
.664 .741 .907 r
.38657 .48711 .38756 .48809 .39301 .48634 .39202 .48536 Metetra
.664 .741 .907 r
.39202 .48536 .39301 .48634 .39846 .48458 .39747 .48359 Metetra
.664 .741 .907 r
.39747 .48359 .39846 .48458 .40392 .48281 .40294 .48183 Metetra
.664 .741 .907 r
.40294 .48183 .40392 .48281 .4094 .48105 .40842 .48006 Metetra
.664 .741 .907 r
.40842 .48006 .4094 .48105 .41489 .47928 .41391 .47829 Metetra
.664 .741 .907 r
.41391 .47829 .41489 .47928 .42038 .47751 .41941 .47651 Metetra
.664 .741 .907 r
.41941 .47651 .42038 .47751 .42589 .47573 .42492 .47474 Metetra
.664 .741 .907 r
.42492 .47474 .42589 .47573 .43141 .47395 .43044 .47295 Metetra
.664 .741 .907 r
.43044 .47295 .43141 .47395 .43695 .47216 .43597 .47117 Metetra
.664 .741 .907 r
.43597 .47117 .43695 .47216 .44249 .47038 .44152 .46938 Metetra
.664 .741 .907 r
.44152 .46938 .44249 .47038 .44804 .46858 .44708 .46758 Metetra
.664 .741 .907 r
.44708 .46758 .44804 .46858 .45361 .46679 .45265 .46579 Metetra
.664 .741 .907 r
.45265 .46579 .45361 .46679 .45919 .46499 .45823 .46398 Metetra
.664 .741 .907 r
.45823 .46398 .45919 .46499 .46478 .46319 .46382 .46218 Metetra
.664 .741 .907 r
.46382 .46218 .46478 .46319 .47038 .46138 .46942 .46037 Metetra
.664 .741 .907 r
.46942 .46037 .47038 .46138 .47599 .45957 .47503 .45856 Metetra
.664 .741 .907 r
.47503 .45856 .47599 .45957 .48161 .45776 .48066 .45674 Metetra
.664 .741 .907 r
.48066 .45674 .48161 .45776 .48725 .45594 .4863 .45492 Metetra
.664 .741 .907 r
.4863 .45492 .48725 .45594 .4929 .45412 .49195 .4531 Metetra
.958 .678 .46 r
.49195 .4531 .4929 .45412 .49745 .58907 .49611 .63077 Metetra
.077 0 .402 r
.49611 .63077 .49745 .58907 .50336 .58675 .50282 .51917 Metetra
.652 .426 .563 r
.50282 .51917 .50336 .58675 .50991 .44863 .50896 .44761 Metetra
.664 .741 .907 r
.50896 .44761 .50991 .44863 .5156 .44679 .51466 .44577 Metetra
.664 .741 .907 r
.51466 .44577 .5156 .44679 .52131 .44495 .52037 .44393 Metetra
.664 .741 .907 r
.52037 .44393 .52131 .44495 .52702 .44311 .52609 .44208 Metetra
.664 .741 .907 r
.52609 .44208 .52702 .44311 .53275 .44126 .53182 .44023 Metetra
.664 .741 .907 r
.53182 .44023 .53275 .44126 .53849 .43941 .53756 .43838 Metetra
.664 .741 .907 r
.53756 .43838 .53849 .43941 .54425 .43755 .54332 .43652 Metetra
.664 .741 .907 r
.54332 .43652 .54425 .43755 .55001 .43569 .54909 .43466 Metetra
.664 .741 .907 r
.54909 .43466 .55001 .43569 .55579 .43383 .55487 .43279 Metetra
.664 .741 .907 r
.55487 .43279 .55579 .43383 .56158 .43196 .56066 .43092 Metetra
.664 .741 .907 r
.56066 .43092 .56158 .43196 .56738 .43009 .56646 .42905 Metetra
.664 .741 .907 r
.56646 .42905 .56738 .43009 .5732 .42822 .57228 .42717 Metetra
.664 .741 .907 r
.57228 .42717 .5732 .42822 .57902 .42634 .57811 .42529 Metetra
.664 .741 .907 r
.57811 .42529 .57902 .42634 .58486 .42446 .58395 .4234 Metetra
.664 .741 .907 r
.58395 .4234 .58486 .42446 .59071 .42257 .5898 .42151 Metetra
.664 .741 .907 r
.5898 .42151 .59071 .42257 .59657 .42068 .59567 .41962 Metetra
.664 .741 .907 r
.59567 .41962 .59657 .42068 .60245 .41878 .60154 .41772 Metetra
.664 .741 .907 r
.60154 .41772 .60245 .41878 .60834 .41688 .60743 .41582 Metetra
.664 .741 .907 r
.60743 .41582 .60834 .41688 .61424 .41498 .61334 .41392 Metetra
.664 .741 .907 r
.61334 .41392 .61424 .41498 .62015 .41307 .61925 .41201 Metetra
.664 .741 .907 r
.61925 .41201 .62015 .41307 .62607 .41116 .62518 .41009 Metetra
0 .004 .532 r
.62518 .41009 .62607 .41116 .63201 .40925 .6314 .41679 Metetra
.374 .141 .428 r
.6314 .41679 .63201 .40925 .63796 .40733 .63707 .40626 Metetra
.664 .741 .907 r
.63707 .40626 .63796 .40733 .64392 .4054 .64304 .40433 Metetra
.664 .741 .907 r
.64304 .40433 .64392 .4054 .6499 .40348 .64902 .4024 Metetra
.664 .741 .907 r
.64902 .4024 .6499 .40348 .65589 .40155 .65501 .40047 Metetra
.664 .741 .907 r
.65501 .40047 .65589 .40155 .66189 .39961 .66101 .39853 Metetra
.664 .741 .907 r
.66101 .39853 .66189 .39961 .6679 .39767 .66703 .39659 Metetra
.664 .741 .907 r
.66703 .39659 .6679 .39767 .67393 .39573 .67306 .39464 Metetra
.664 .741 .907 r
.67306 .39464 .67393 .39573 .67997 .39378 .6791 .39269 Metetra
.664 .741 .907 r
.6791 .39269 .67997 .39378 .68602 .39183 .68516 .39074 Metetra
.664 .741 .907 r
.68516 .39074 .68602 .39183 .69209 .38987 .69122 .38878 Metetra
.664 .741 .907 r
.69122 .38878 .69209 .38987 .69817 .38791 .6973 .38681 Metetra
.664 .741 .907 r
.6973 .38681 .69817 .38791 .70426 .38594 .7034 .38485 Metetra
.664 .741 .907 r
.7034 .38485 .70426 .38594 .71036 .38398 .70951 .38287 Metetra
.664 .741 .907 r
.70951 .38287 .71036 .38398 .71648 .382 .71563 .3809 Metetra
.664 .741 .907 r
.71563 .3809 .71648 .382 .72261 .38002 .72176 .37892 Metetra
.664 .741 .907 r
.72176 .37892 .72261 .38002 .72876 .37804 .72791 .37694 Metetra
.664 .741 .907 r
.72791 .37694 .72876 .37804 .73491 .37606 .73407 .37495 Metetra
.664 .741 .907 r
.73407 .37495 .73491 .37606 .74108 .37407 .74024 .37295 Metetra
.664 .741 .907 r
.74024 .37295 .74108 .37407 .74727 .37207 .74643 .37096 Metetra
.664 .741 .907 r
.74643 .37096 .74727 .37207 .75347 .37007 .75263 .36896 Metetra
.933 .564 .168 r
.75263 .36896 .75347 .37007 .75968 .36807 .76139 .4017 Metetra
.435 .24 .515 r
.76139 .4017 .75968 .36807 .7659 .36606 .76507 .36494 Metetra
.664 .741 .907 r
.76507 .36494 .7659 .36606 .7749 .39958 .77131 .36293 Metetra
.565 .362 .564 r
.77131 .36293 .7749 .39958 .77839 .36203 .77757 .36091 Metetra
.664 .741 .907 r
.77757 .36091 .77839 .36203 .78466 .36001 .78383 .35888 Metetra
.664 .741 .907 r
.78383 .35888 .78466 .36001 .79094 .35799 .79012 .35686 Metetra
.664 .741 .907 r
.79012 .35686 .79094 .35799 .79723 .35596 .79641 .35482 Metetra
.664 .741 .907 r
.79641 .35482 .79723 .35596 .80353 .35392 .80272 .35279 Metetra
.664 .741 .907 r
.80272 .35279 .80353 .35392 .80985 .35188 .80904 .35075 Metetra
.664 .741 .907 r
.80904 .35075 .80985 .35188 .81619 .34984 .81538 .3487 Metetra
.664 .741 .907 r
.81538 .3487 .81619 .34984 .82254 .34779 .82173 .34665 Metetra
.664 .741 .907 r
.82173 .34665 .82254 .34779 .8289 .34574 .8281 .3446 Metetra
.664 .741 .907 r
.8281 .3446 .8289 .34574 .83527 .34369 .83447 .34254 Metetra
.664 .741 .907 r
.83447 .34254 .83527 .34369 .84166 .34163 .84087 .34047 Metetra
.664 .741 .907 r
.84087 .34047 .84166 .34163 .84807 .33956 .84727 .33841 Metetra
.664 .741 .907 r
.84727 .33841 .84807 .33956 .85449 .33749 .8537 .33633 Metetra
.664 .741 .907 r
.8537 .33633 .85449 .33749 .86092 .33541 .86013 .33426 Metetra
.664 .741 .907 r
.86013 .33426 .86092 .33541 .86736 .33334 .86658 .33217 Metetra
.664 .741 .907 r
.86658 .33217 .86736 .33334 .87382 .33125 .87304 .33009 Metetra
.664 .741 .907 r
.87304 .33009 .87382 .33125 .8803 .32916 .87952 .328 Metetra
.664 .741 .907 r
.87952 .328 .8803 .32916 .88679 .32707 .88601 .3259 Metetra
.664 .741 .907 r
.88601 .3259 .88679 .32707 .89329 .32497 .89252 .3238 Metetra
.664 .741 .907 r
.89252 .3238 .89329 .32497 .89981 .32287 .89904 .3217 Metetra
.664 .741 .907 r
.31047 .5104 .31149 .51135 .31678 .50964 .31577 .50868 Metetra
.664 .741 .907 r
.31577 .50868 .31678 .50964 .32209 .50793 .32107 .50697 Metetra
.664 .741 .907 r
.32107 .50697 .32209 .50793 .3274 .50621 .32639 .50525 Metetra
.664 .741 .907 r
.32639 .50525 .3274 .50621 .33273 .50449 .33172 .50353 Metetra
.664 .741 .907 r
.33172 .50353 .33273 .50449 .33806 .50277 .33705 .50181 Metetra
.664 .741 .907 r
.33705 .50181 .33806 .50277 .34341 .50104 .3424 .50008 Metetra
.664 .741 .907 r
.3424 .50008 .34341 .50104 .34877 .49932 .34776 .49835 Metetra
.664 .741 .907 r
.34776 .49835 .34877 .49932 .35414 .49758 .35313 .49662 Metetra
.664 .741 .907 r
.35313 .49662 .35414 .49758 .35951 .49585 .35851 .49488 Metetra
.664 .741 .907 r
.35851 .49488 .35951 .49585 .3649 .49411 .3639 .49314 Metetra
.634 .129 0 r
.3639 .49314 .3649 .49411 .3703 .49236 .36895 .49907 Metetra
.578 .307 .47 r
.36895 .49907 .3703 .49236 .37391 .53072 .37419 .50136 Metetra
.606 .396 .571 r
.37419 .50136 .37391 .53072 .38114 .48887 .38014 .48789 Metetra
.664 .741 .907 r
.38014 .48789 .38114 .48887 .38657 .48711 .38558 .48613 Metetra
.664 .741 .907 r
.38558 .48613 .38657 .48711 .39202 .48536 .39103 .48437 Metetra
.664 .741 .907 r
.39103 .48437 .39202 .48536 .39747 .48359 .39648 .48261 Metetra
.664 .741 .907 r
.39648 .48261 .39747 .48359 .40294 .48183 .40195 .48084 Metetra
.664 .741 .907 r
.40195 .48084 .40294 .48183 .40842 .48006 .40743 .47907 Metetra
.664 .741 .907 r
.40743 .47907 .40842 .48006 .41391 .47829 .41292 .4773 Metetra
.664 .741 .907 r
.41292 .4773 .41391 .47829 .41941 .47651 .41843 .47552 Metetra
.664 .741 .907 r
.41843 .47552 .41941 .47651 .42492 .47474 .42394 .47374 Metetra
.664 .741 .907 r
.42394 .47374 .42492 .47474 .43044 .47295 .42947 .47196 Metetra
.664 .741 .907 r
.42947 .47196 .43044 .47295 .43597 .47117 .435 .47017 Metetra
.664 .741 .907 r
.435 .47017 .43597 .47117 .44152 .46938 .44055 .46838 Metetra
.664 .741 .907 r
.44055 .46838 .44152 .46938 .44708 .46758 .44611 .46658 Metetra
.664 .741 .907 r
.44611 .46658 .44708 .46758 .45265 .46579 .45168 .46478 Metetra
.664 .741 .907 r
.45168 .46478 .45265 .46579 .45823 .46398 .45726 .46298 Metetra
.664 .741 .907 r
.45726 .46298 .45823 .46398 .46382 .46218 .46285 .46117 Metetra
.664 .741 .907 r
.46285 .46117 .46382 .46218 .46942 .46037 .46846 .45936 Metetra
.664 .741 .907 r
.46846 .45936 .46942 .46037 .47503 .45856 .47408 .45755 Metetra
.664 .741 .907 r
.47408 .45755 .47503 .45856 .48066 .45674 .4797 .45573 Metetra
.664 .741 .907 r
.4797 .45573 .48066 .45674 .4863 .45492 .48534 .45391 Metetra
.664 .741 .907 r
.48534 .45391 .4863 .45492 .49195 .4531 .491 .45208 Metetra
.959 .655 .411 r
.491 .45208 .49195 .4531 .49611 .63077 .49614 .51087 Metetra
.588 .372 .555 r
.49614 .51087 .49611 .63077 .50282 .51917 .50214 .47614 Metetra
.623 .405 .566 r
.50214 .47614 .50282 .51917 .50896 .44761 .50802 .44658 Metetra
.664 .741 .907 r
.50802 .44658 .50896 .44761 .51466 .44577 .51372 .44474 Metetra
.664 .741 .907 r
.51372 .44474 .51466 .44577 .52037 .44393 .51943 .4429 Metetra
.664 .741 .907 r
.51943 .4429 .52037 .44393 .52609 .44208 .52515 .44105 Metetra
.664 .741 .907 r
.52515 .44105 .52609 .44208 .53182 .44023 .53088 .4392 Metetra
.664 .741 .907 r
.53088 .4392 .53182 .44023 .53756 .43838 .53663 .43734 Metetra
.664 .741 .907 r
.53663 .43734 .53756 .43838 .54332 .43652 .54239 .43548 Metetra
.664 .741 .907 r
.54239 .43548 .54332 .43652 .54909 .43466 .54816 .43362 Metetra
.664 .741 .907 r
.54816 .43362 .54909 .43466 .55487 .43279 .55394 .43175 Metetra
.664 .741 .907 r
.55394 .43175 .55487 .43279 .56066 .43092 .55974 .42988 Metetra
.664 .741 .907 r
.55974 .42988 .56066 .43092 .56646 .42905 .56554 .428 Metetra
.664 .741 .907 r
.56554 .428 .56646 .42905 .57228 .42717 .57136 .42612 Metetra
.664 .741 .907 r
.57136 .42612 .57228 .42717 .57811 .42529 .57719 .42424 Metetra
.664 .741 .907 r
.57719 .42424 .57811 .42529 .58395 .4234 .58304 .42235 Metetra
.664 .741 .907 r
.58304 .42235 .58395 .4234 .5898 .42151 .58889 .42046 Metetra
.664 .741 .907 r
.58889 .42046 .5898 .42151 .59567 .41962 .59476 .41856 Metetra
.664 .741 .907 r
.59476 .41856 .59567 .41962 .60154 .41772 .60064 .41666 Metetra
.664 .741 .907 r
.60064 .41666 .60154 .41772 .60743 .41582 .60653 .41476 Metetra
0 .092 .616 r
.60653 .41476 .60743 .41582 .61334 .41392 .61264 .42054 Metetra
.361 .122 .411 r
.61264 .42054 .61334 .41392 .61925 .41201 .61835 .41094 Metetra
.664 .741 .907 r
.61835 .41094 .61925 .41201 .62518 .41009 .62428 .40903 Metetra
.664 .741 .907 r
.62428 .40903 .62518 .41009 .6314 .41679 .63023 .40711 Metetra
.584 .407 .608 r
.63023 .40711 .6314 .41679 .63707 .40626 .63618 .40518 Metetra
.664 .741 .907 r
.63618 .40518 .63707 .40626 .64304 .40433 .64215 .40325 Metetra
.664 .741 .907 r
.64215 .40325 .64304 .40433 .64902 .4024 .64813 .40132 Metetra
.664 .741 .907 r
.64813 .40132 .64902 .4024 .65501 .40047 .65413 .39939 Metetra
.664 .741 .907 r
.65413 .39939 .65501 .40047 .66101 .39853 .66013 .39745 Metetra
.664 .741 .907 r
.66013 .39745 .66101 .39853 .66703 .39659 .66615 .3955 Metetra
.664 .741 .907 r
.66615 .3955 .66703 .39659 .67306 .39464 .67218 .39355 Metetra
.664 .741 .907 r
.67218 .39355 .67306 .39464 .6791 .39269 .67823 .3916 Metetra
.664 .741 .907 r
.67823 .3916 .6791 .39269 .68516 .39074 .68429 .38964 Metetra
.664 .741 .907 r
.68429 .38964 .68516 .39074 .69122 .38878 .69036 .38768 Metetra
.664 .741 .907 r
.69036 .38768 .69122 .38878 .6973 .38681 .69644 .38572 Metetra
.664 .741 .907 r
.69644 .38572 .6973 .38681 .7034 .38485 .70254 .38375 Metetra
.664 .741 .907 r
.70254 .38375 .7034 .38485 .70951 .38287 .70865 .38177 Metetra
.664 .741 .907 r
.70865 .38177 .70951 .38287 .71563 .3809 .71477 .3798 Metetra
.664 .741 .907 r
.71477 .3798 .71563 .3809 .72176 .37892 .72091 .37781 Metetra
.664 .741 .907 r
.72091 .37781 .72176 .37892 .72791 .37694 .72706 .37583 Metetra
.664 .741 .907 r
.72706 .37583 .72791 .37694 .73407 .37495 .73322 .37384 Metetra
.664 .741 .907 r
.73322 .37384 .73407 .37495 .74024 .37295 .7394 .37184 Metetra
.664 .741 .907 r
.7394 .37184 .74024 .37295 .74643 .37096 .74559 .36984 Metetra
.664 .741 .907 r
.74559 .36984 .74643 .37096 .75263 .36896 .75179 .36784 Metetra
.664 .741 .907 r
.75179 .36784 .75263 .36896 .76139 .4017 .75801 .36583 Metetra
.565 .362 .564 r
.75801 .36583 .76139 .4017 .76507 .36494 .76424 .36382 Metetra
.664 .741 .907 r
.76424 .36382 .76507 .36494 .77131 .36293 .77048 .3618 Metetra
.664 .741 .907 r
.77048 .3618 .77131 .36293 .77757 .36091 .77674 .35978 Metetra
.664 .741 .907 r
.77674 .35978 .77757 .36091 .78383 .35888 .78301 .35775 Metetra
.664 .741 .907 r
.78301 .35775 .78383 .35888 .79012 .35686 .78929 .35572 Metetra
.664 .741 .907 r
.78929 .35572 .79012 .35686 .79641 .35482 .79559 .35369 Metetra
.664 .741 .907 r
.79559 .35369 .79641 .35482 .80272 .35279 .80191 .35165 Metetra
.664 .741 .907 r
.80191 .35165 .80272 .35279 .80904 .35075 .80823 .34961 Metetra
.664 .741 .907 r
.80823 .34961 .80904 .35075 .81538 .3487 .81457 .34756 Metetra
.664 .741 .907 r
.81457 .34756 .81538 .3487 .82173 .34665 .82093 .34551 Metetra
.664 .741 .907 r
.82093 .34551 .82173 .34665 .8281 .3446 .82729 .34345 Metetra
.664 .741 .907 r
.82729 .34345 .8281 .3446 .83447 .34254 .83367 .34139 Metetra
.664 .741 .907 r
.83367 .34139 .83447 .34254 .84087 .34047 .84007 .33932 Metetra
.664 .741 .907 r
.84007 .33932 .84087 .34047 .84727 .33841 .84648 .33725 Metetra
.664 .741 .907 r
.84648 .33725 .84727 .33841 .8537 .33633 .8529 .33518 Metetra
.664 .741 .907 r
.8529 .33518 .8537 .33633 .86013 .33426 .85934 .3331 Metetra
.664 .741 .907 r
.85934 .3331 .86013 .33426 .86658 .33217 .8658 .33101 Metetra
.664 .741 .907 r
.8658 .33101 .86658 .33217 .87304 .33009 .87226 .32892 Metetra
.664 .741 .907 r
.87226 .32892 .87304 .33009 .87952 .328 .87874 .32683 Metetra
.664 .741 .907 r
.87874 .32683 .87952 .328 .88601 .3259 .88524 .32473 Metetra
.664 .741 .907 r
.88524 .32473 .88601 .3259 .89252 .3238 .89175 .32263 Metetra
.664 .741 .907 r
.89175 .32263 .89252 .3238 .89904 .3217 .89827 .32052 Metetra
.664 .741 .907 r
.30945 .50944 .31047 .5104 .31577 .50868 .31475 .50773 Metetra
.664 .741 .907 r
.31475 .50773 .31577 .50868 .32107 .50697 .32006 .50601 Metetra
.664 .741 .907 r
.32006 .50601 .32107 .50697 .32639 .50525 .32537 .50429 Metetra
.664 .741 .907 r
.32537 .50429 .32639 .50525 .33172 .50353 .3307 .50257 Metetra
.664 .741 .907 r
.3307 .50257 .33172 .50353 .33705 .50181 .33604 .50085 Metetra
.664 .741 .907 r
.33604 .50085 .33705 .50181 .3424 .50008 .34139 .49912 Metetra
.664 .741 .907 r
.34139 .49912 .3424 .50008 .34776 .49835 .34675 .49738 Metetra
.664 .741 .907 r
.34675 .49738 .34776 .49835 .35313 .49662 .35213 .49565 Metetra
.664 .741 .907 r
.35213 .49565 .35313 .49662 .35851 .49488 .35751 .49391 Metetra
.664 .741 .907 r
.35751 .49391 .35851 .49488 .3639 .49314 .3629 .49216 Metetra
.318 .598 .946 r
.3629 .49216 .3639 .49314 .36895 .49907 .36817 .49334 Metetra
.642 .475 .643 r
.36817 .49334 .36895 .49907 .37419 .50136 .37372 .48866 Metetra
.577 .391 .593 r
.37372 .48866 .37419 .50136 .38014 .48789 .37915 .48691 Metetra
.664 .741 .907 r
.37915 .48691 .38014 .48789 .38558 .48613 .38459 .48515 Metetra
.664 .741 .907 r
.38459 .48515 .38558 .48613 .39103 .48437 .39004 .48339 Metetra
.664 .741 .907 r
.39004 .48339 .39103 .48437 .39648 .48261 .3955 .48163 Metetra
.664 .741 .907 r
.3955 .48163 .39648 .48261 .40195 .48084 .40097 .47986 Metetra
.664 .741 .907 r
.40097 .47986 .40195 .48084 .40743 .47907 .40645 .47808 Metetra
.664 .741 .907 r
.40645 .47808 .40743 .47907 .41292 .4773 .41194 .47631 Metetra
.664 .741 .907 r
.41194 .47631 .41292 .4773 .41843 .47552 .41745 .47453 Metetra
.664 .741 .907 r
.41745 .47453 .41843 .47552 .42394 .47374 .42296 .47275 Metetra
.664 .741 .907 r
.42296 .47275 .42394 .47374 .42947 .47196 .42849 .47096 Metetra
.664 .741 .907 r
.42849 .47096 .42947 .47196 .435 .47017 .43403 .46917 Metetra
.664 .741 .907 r
.43403 .46917 .435 .47017 .44055 .46838 .43958 .46738 Metetra
.664 .741 .907 r
.43958 .46738 .44055 .46838 .44611 .46658 .44514 .46558 Metetra
.664 .741 .907 r
.44514 .46558 .44611 .46658 .45168 .46478 .45071 .46378 Metetra
.664 .741 .907 r
.45071 .46378 .45168 .46478 .45726 .46298 .4563 .46197 Metetra
.664 .741 .907 r
.4563 .46197 .45726 .46298 .46285 .46117 .46189 .46016 Metetra
.664 .741 .907 r
.46189 .46016 .46285 .46117 .46846 .45936 .4675 .45835 Metetra
.664 .741 .907 r
.4675 .45835 .46846 .45936 .47408 .45755 .47312 .45653 Metetra
.664 .741 .907 r
.47312 .45653 .47408 .45755 .4797 .45573 .47875 .45471 Metetra
.664 .741 .907 r
.47875 .45471 .4797 .45573 .48534 .45391 .48439 .45289 Metetra
.664 .741 .907 r
.48439 .45289 .48534 .45391 .491 .45208 .49004 .45106 Metetra
.664 .741 .907 r
.49004 .45106 .491 .45208 .49614 .51087 .49571 .44923 Metetra
.52 .321 .551 r
.49571 .44923 .49614 .51087 .50214 .47614 .50122 .47029 Metetra
.796 .581 .61 r
.50122 .47029 .50214 .47614 .50802 .44658 .50708 .44556 Metetra
.664 .741 .907 r
.50708 .44556 .50802 .44658 .51372 .44474 .51278 .44371 Metetra
.664 .741 .907 r
.51278 .44371 .51372 .44474 .51943 .4429 .51849 .44187 Metetra
.664 .741 .907 r
.51849 .44187 .51943 .4429 .52515 .44105 .52421 .44002 Metetra
0 .027 .544 r
.52421 .44002 .52515 .44105 .53088 .4392 .52996 .4458 Metetra
.352 .112 .403 r
.52996 .4458 .53088 .4392 .53663 .43734 .5357 .4363 Metetra
.664 .741 .907 r
.5357 .4363 .53663 .43734 .54239 .43548 .54146 .43444 Metetra
.664 .741 .907 r
.54146 .43444 .54239 .43548 .54816 .43362 .54723 .43257 Metetra
.664 .741 .907 r
.54723 .43257 .54816 .43362 .55394 .43175 .55302 .4307 Metetra
.664 .741 .907 r
.55302 .4307 .55394 .43175 .55974 .42988 .55881 .42883 Metetra
.664 .741 .907 r
.55881 .42883 .55974 .42988 .56554 .428 .56462 .42695 Metetra
.664 .741 .907 r
.56462 .42695 .56554 .428 .57136 .42612 .57044 .42507 Metetra
.664 .741 .907 r
.57044 .42507 .57136 .42612 .57719 .42424 .57628 .42319 Metetra
.664 .741 .907 r
.57628 .42319 .57719 .42424 .58304 .42235 .58212 .4213 Metetra
.664 .741 .907 r
.58212 .4213 .58304 .42235 .58889 .42046 .58798 .4194 Metetra
.664 .741 .907 r
.58798 .4194 .58889 .42046 .59476 .41856 .59385 .4175 Metetra
.664 .741 .907 r
.59385 .4175 .59476 .41856 .60064 .41666 .59973 .4156 Metetra
.664 .741 .907 r
.59973 .4156 .60064 .41666 .60653 .41476 .60563 .4137 Metetra
.664 .741 .907 r
.60563 .4137 .60653 .41476 .61264 .42054 .61154 .41179 Metetra
.586 .413 .614 r
.61154 .41179 .61264 .42054 .61835 .41094 .61746 .40987 Metetra
.664 .741 .907 r
.61746 .40987 .61835 .41094 .62428 .40903 .62339 .40796 Metetra
.664 .741 .907 r
.62339 .40796 .62428 .40903 .63023 .40711 .62933 .40603 Metetra
.664 .741 .907 r
.62933 .40603 .63023 .40711 .63618 .40518 .63529 .40411 Metetra
.664 .741 .907 r
.63529 .40411 .63618 .40518 .64215 .40325 .64126 .40218 Metetra
.664 .741 .907 r
.64126 .40218 .64215 .40325 .64813 .40132 .64725 .40024 Metetra
.664 .741 .907 r
.64725 .40024 .64813 .40132 .65413 .39939 .65324 .3983 Metetra
.664 .741 .907 r
.65324 .3983 .65413 .39939 .66013 .39745 .65925 .39636 Metetra
.664 .741 .907 r
.65925 .39636 .66013 .39745 .66615 .3955 .66527 .39442 Metetra
.664 .741 .907 r
.66527 .39442 .66615 .3955 .67218 .39355 .67131 .39246 Metetra
.664 .741 .907 r
.67131 .39246 .67218 .39355 .67823 .3916 .67736 .39051 Metetra
.664 .741 .907 r
.67736 .39051 .67823 .3916 .68429 .38964 .68342 .38855 Metetra
.664 .741 .907 r
.68342 .38855 .68429 .38964 .69036 .38768 .68949 .38659 Metetra
.664 .741 .907 r
.68949 .38659 .69036 .38768 .69644 .38572 .69558 .38462 Metetra
.664 .741 .907 r
.69558 .38462 .69644 .38572 .70254 .38375 .70168 .38265 Metetra
.664 .741 .907 r
.70168 .38265 .70254 .38375 .70865 .38177 .70779 .38067 Metetra
.664 .741 .907 r
.70779 .38067 .70865 .38177 .71477 .3798 .71392 .37869 Metetra
.664 .741 .907 r
.71392 .37869 .71477 .3798 .72091 .37781 .72006 .37671 Metetra
.664 .741 .907 r
.72006 .37671 .72091 .37781 .72706 .37583 .72621 .37472 Metetra
.664 .741 .907 r
.72621 .37472 .72706 .37583 .73322 .37384 .73237 .37272 Metetra
.664 .741 .907 r
.73237 .37272 .73322 .37384 .7394 .37184 .73855 .37073 Metetra
.664 .741 .907 r
.73855 .37073 .7394 .37184 .74559 .36984 .74475 .36872 Metetra
.664 .741 .907 r
.74475 .36872 .74559 .36984 .75179 .36784 .75095 .36672 Metetra
.664 .741 .907 r
.75095 .36672 .75179 .36784 .75801 .36583 .75717 .36471 Metetra
.664 .741 .907 r
.75717 .36471 .75801 .36583 .76424 .36382 .7634 .36269 Metetra
.664 .741 .907 r
.7634 .36269 .76424 .36382 .77048 .3618 .76965 .36067 Metetra
.664 .741 .907 r
.76965 .36067 .77048 .3618 .77674 .35978 .77591 .35865 Metetra
.664 .741 .907 r
.77591 .35865 .77674 .35978 .78301 .35775 .78219 .35662 Metetra
.664 .741 .907 r
.78219 .35662 .78301 .35775 .78929 .35572 .78847 .35459 Metetra
.664 .741 .907 r
.78847 .35459 .78929 .35572 .79559 .35369 .79477 .35255 Metetra
.664 .741 .907 r
.79477 .35255 .79559 .35369 .80191 .35165 .80109 .35051 Metetra
.664 .741 .907 r
.80109 .35051 .80191 .35165 .80823 .34961 .80742 .34846 Metetra
.664 .741 .907 r
.80742 .34846 .80823 .34961 .81457 .34756 .81376 .34641 Metetra
.664 .741 .907 r
.81376 .34641 .81457 .34756 .82093 .34551 .82012 .34436 Metetra
.664 .741 .907 r
.82012 .34436 .82093 .34551 .82729 .34345 .82649 .3423 Metetra
.664 .741 .907 r
.82649 .3423 .82729 .34345 .83367 .34139 .83287 .34024 Metetra
.664 .741 .907 r
.83287 .34024 .83367 .34139 .84007 .33932 .83927 .33817 Metetra
.664 .741 .907 r
.83927 .33817 .84007 .33932 .84648 .33725 .84569 .33609 Metetra
.664 .741 .907 r
.84569 .33609 .84648 .33725 .8529 .33518 .85211 .33402 Metetra
.664 .741 .907 r
.85211 .33402 .8529 .33518 .85934 .3331 .85855 .33193 Metetra
.664 .741 .907 r
.85855 .33193 .85934 .3331 .8658 .33101 .86501 .32985 Metetra
.664 .741 .907 r
.86501 .32985 .8658 .33101 .87226 .32892 .87148 .32775 Metetra
.664 .741 .907 r
.87148 .32775 .87226 .32892 .87874 .32683 .87796 .32566 Metetra
.664 .741 .907 r
.87796 .32566 .87874 .32683 .88524 .32473 .88446 .32356 Metetra
.664 .741 .907 r
.88446 .32356 .88524 .32473 .89175 .32263 .89098 .32145 Metetra
.664 .741 .907 r
.89098 .32145 .89175 .32263 .89827 .32052 .8975 .31934 Metetra
.664 .741 .907 r
.30843 .50849 .30945 .50944 .31475 .50773 .31373 .50677 Metetra
.664 .741 .907 r
.31373 .50677 .31475 .50773 .32006 .50601 .31904 .50505 Metetra
.664 .741 .907 r
.31904 .50505 .32006 .50601 .32537 .50429 .32436 .50333 Metetra
.664 .741 .907 r
.32436 .50333 .32537 .50429 .3307 .50257 .32969 .50161 Metetra
.664 .741 .907 r
.32969 .50161 .3307 .50257 .33604 .50085 .33503 .49988 Metetra
.664 .741 .907 r
.33503 .49988 .33604 .50085 .34139 .49912 .34038 .49815 Metetra
.664 .741 .907 r
.34038 .49815 .34139 .49912 .34675 .49738 .34575 .49641 Metetra
.664 .741 .907 r
.34575 .49641 .34675 .49738 .35213 .49565 .35112 .49468 Metetra
.664 .741 .907 r
.35112 .49468 .35213 .49565 .35751 .49391 .3565 .49293 Metetra
.664 .741 .907 r
.3565 .49293 .35751 .49391 .3629 .49216 .3619 .49119 Metetra
.664 .741 .907 r
.3619 .49119 .3629 .49216 .36817 .49334 .36731 .48944 Metetra
.613 .487 .685 r
.36731 .48944 .36817 .49334 .37372 .48866 .37272 .48769 Metetra
.664 .741 .907 r
.37272 .48769 .37372 .48866 .37915 .48691 .37815 .48593 Metetra
.664 .741 .907 r
.37815 .48593 .37915 .48691 .38459 .48515 .38359 .48417 Metetra
.664 .741 .907 r
.38359 .48417 .38459 .48515 .39004 .48339 .38904 .48241 Metetra
.664 .741 .907 r
.38904 .48241 .39004 .48339 .3955 .48163 .39451 .48064 Metetra
.664 .741 .907 r
.39451 .48064 .3955 .48163 .40097 .47986 .39998 .47887 Metetra
.664 .741 .907 r
.39998 .47887 .40097 .47986 .40645 .47808 .40546 .47709 Metetra
.664 .741 .907 r
.40546 .47709 .40645 .47808 .41194 .47631 .41096 .47532 Metetra
.664 .741 .907 r
.41096 .47532 .41194 .47631 .41745 .47453 .41647 .47354 Metetra
.664 .741 .907 r
.41647 .47354 .41745 .47453 .42296 .47275 .42198 .47175 Metetra
.664 .741 .907 r
.42198 .47175 .42296 .47275 .42849 .47096 .42751 .46996 Metetra
.664 .741 .907 r
.42751 .46996 .42849 .47096 .43403 .46917 .43305 .46817 Metetra
.664 .741 .907 r
.43305 .46817 .43403 .46917 .43958 .46738 .43861 .46637 Metetra
.664 .741 .907 r
.43861 .46637 .43958 .46738 .44514 .46558 .44417 .46457 Metetra
.664 .741 .907 r
.44417 .46457 .44514 .46558 .45071 .46378 .44974 .46277 Metetra
.664 .741 .907 r
.44974 .46277 .45071 .46378 .4563 .46197 .45533 .46096 Metetra
.664 .741 .907 r
.45533 .46096 .4563 .46197 .46189 .46016 .46093 .45915 Metetra
.664 .741 .907 r
.46093 .45915 .46189 .46016 .4675 .45835 .46654 .45734 Metetra
.664 .741 .907 r
.46654 .45734 .4675 .45835 .47312 .45653 .47216 .45552 Metetra
.664 .741 .907 r
.47216 .45552 .47312 .45653 .47875 .45471 .47779 .4537 Metetra
.664 .741 .907 r
.47779 .4537 .47875 .45471 .48439 .45289 .48343 .45187 Metetra
.664 .741 .907 r
.48343 .45187 .48439 .45289 .49004 .45106 .48909 .45004 Metetra
.664 .741 .907 r
.48909 .45004 .49004 .45106 .49571 .44923 .49476 .44821 Metetra
.664 .741 .907 r
.49476 .44821 .49571 .44923 .50122 .47029 .50044 .44637 Metetra
.568 .369 .571 r
.50044 .44637 .50122 .47029 .50708 .44556 .50613 .44453 Metetra
.664 .741 .907 r
.50613 .44453 .50708 .44556 .51278 .44371 .51183 .44268 Metetra
.664 .741 .907 r
.51183 .44268 .51278 .44371 .51849 .44187 .51755 .44083 Metetra
.664 .741 .907 r
.51755 .44083 .51849 .44187 .52421 .44002 .52327 .43898 Metetra
.962 .676 .446 r
.52327 .43898 .52421 .44002 .52996 .4458 .52922 .59956 Metetra
.422 .235 .52 r
.52922 .59956 .52996 .4458 .5357 .4363 .53476 .43526 Metetra
.465 .661 .946 r
.53476 .43526 .5357 .4363 .54146 .43444 .54054 .4356 Metetra
.54054 .4356 .54146 .43444 .54723 .43257 .5463 .43153 Metetra
.664 .741 .907 r
.5463 .43153 .54723 .43257 .55302 .4307 .55209 .42966 Metetra
.664 .741 .907 r
.55209 .42966 .55302 .4307 .55881 .42883 .55789 .42778 Metetra
.664 .741 .907 r
.55789 .42778 .55881 .42883 .56462 .42695 .5637 .4259 Metetra
.664 .741 .907 r
.5637 .4259 .56462 .42695 .57044 .42507 .56952 .42402 Metetra
.664 .741 .907 r
.56952 .42402 .57044 .42507 .57628 .42319 .57536 .42213 Metetra
.664 .741 .907 r
.57536 .42213 .57628 .42319 .58212 .4213 .58121 .42024 Metetra
.664 .741 .907 r
.58121 .42024 .58212 .4213 .58798 .4194 .58707 .41834 Metetra
.664 .741 .907 r
.58707 .41834 .58798 .4194 .59385 .4175 .59294 .41644 Metetra
.664 .741 .907 r
.59294 .41644 .59385 .4175 .59973 .4156 .59883 .41454 Metetra
.664 .741 .907 r
.59883 .41454 .59973 .4156 .60563 .4137 .60472 .41263 Metetra
.664 .741 .907 r
.60472 .41263 .60563 .4137 .61154 .41179 .61063 .41072 Metetra
.664 .741 .907 r
.61063 .41072 .61154 .41179 .61746 .40987 .61656 .4088 Metetra
.664 .741 .907 r
.61656 .4088 .61746 .40987 .62339 .40796 .62249 .40688 Metetra
.664 .741 .907 r
.62249 .40688 .62339 .40796 .62933 .40603 .62844 .40496 Metetra
.664 .741 .907 r
.62844 .40496 .62933 .40603 .63529 .40411 .6344 .40303 Metetra
.664 .741 .907 r
.6344 .40303 .63529 .40411 .64126 .40218 .64037 .4011 Metetra
.664 .741 .907 r
.64037 .4011 .64126 .40218 .64725 .40024 .64636 .39916 Metetra
.664 .741 .907 r
.64636 .39916 .64725 .40024 .65324 .3983 .65236 .39722 Metetra
.664 .741 .907 r
.65236 .39722 .65324 .3983 .65925 .39636 .65837 .39528 Metetra
.664 .741 .907 r
.65837 .39528 .65925 .39636 .66527 .39442 .66439 .39333 Metetra
.664 .741 .907 r
.66439 .39333 .66527 .39442 .67131 .39246 .67043 .39137 Metetra
.664 .741 .907 r
.67043 .39137 .67131 .39246 .67736 .39051 .67648 .38942 Metetra
.664 .741 .907 r
.67648 .38942 .67736 .39051 .68342 .38855 .68255 .38746 Metetra
.664 .741 .907 r
.68255 .38746 .68342 .38855 .68949 .38659 .68862 .38549 Metetra
.664 .741 .907 r
.68862 .38549 .68949 .38659 .69558 .38462 .69471 .38352 Metetra
.664 .741 .907 r
.69471 .38352 .69558 .38462 .70168 .38265 .70081 .38155 Metetra
.664 .741 .907 r
.70081 .38155 .70168 .38265 .70779 .38067 .70693 .37957 Metetra
.664 .741 .907 r
.70693 .37957 .70779 .38067 .71392 .37869 .71306 .37758 Metetra
.664 .741 .907 r
.71306 .37758 .71392 .37869 .72006 .37671 .7192 .3756 Metetra
.664 .741 .907 r
.7192 .3756 .72006 .37671 .72621 .37472 .72536 .37361 Metetra
.664 .741 .907 r
.72536 .37361 .72621 .37472 .73237 .37272 .73152 .37161 Metetra
.664 .741 .907 r
.73152 .37161 .73237 .37272 .73855 .37073 .73771 .36961 Metetra
.664 .741 .907 r
.73771 .36961 .73855 .37073 .74475 .36872 .7439 .36761 Metetra
.664 .741 .907 r
.7439 .36761 .74475 .36872 .75095 .36672 .75011 .3656 Metetra
.664 .741 .907 r
.75011 .3656 .75095 .36672 .75717 .36471 .75633 .36358 Metetra
.664 .741 .907 r
.75633 .36358 .75717 .36471 .7634 .36269 .76257 .36157 Metetra
.664 .741 .907 r
.76257 .36157 .7634 .36269 .76965 .36067 .76882 .35954 Metetra
.664 .741 .907 r
.76882 .35954 .76965 .36067 .77591 .35865 .77508 .35752 Metetra
.664 .741 .907 r
.77508 .35752 .77591 .35865 .78219 .35662 .78136 .35549 Metetra
.664 .741 .907 r
.78136 .35549 .78219 .35662 .78847 .35459 .78765 .35345 Metetra
.664 .741 .907 r
.78765 .35345 .78847 .35459 .79477 .35255 .79395 .35141 Metetra
.664 .741 .907 r
.79395 .35141 .79477 .35255 .80109 .35051 .80027 .34937 Metetra
.664 .741 .907 r
.80027 .34937 .80109 .35051 .80742 .34846 .8066 .34732 Metetra
.664 .741 .907 r
.8066 .34732 .80742 .34846 .81376 .34641 .81295 .34527 Metetra
.664 .741 .907 r
.81295 .34527 .81376 .34641 .82012 .34436 .81931 .34321 Metetra
.664 .741 .907 r
.81931 .34321 .82012 .34436 .82649 .3423 .82568 .34115 Metetra
.035 .373 .84 r
.82568 .34115 .82649 .3423 .83287 .34024 .83269 .3454 Metetra
.808 .479 .431 r
.83269 .3454 .83287 .34024 .83927 .33817 .84213 .37381 Metetra
.44 .246 .519 r
.84213 .37381 .83927 .33817 .84569 .33609 .84489 .33494 Metetra
.664 .741 .907 r
.84489 .33494 .84569 .33609 .85211 .33402 .85132 .33285 Metetra
.664 .741 .907 r
.85132 .33285 .85211 .33402 .85855 .33193 .85776 .33077 Metetra
.664 .741 .907 r
.85776 .33077 .85855 .33193 .86501 .32985 .86422 .32868 Metetra
.664 .741 .907 r
.86422 .32868 .86501 .32985 .87148 .32775 .8707 .32659 Metetra
.664 .741 .907 r
.8707 .32659 .87148 .32775 .87796 .32566 .87718 .32449 Metetra
.664 .741 .907 r
.87718 .32449 .87796 .32566 .88446 .32356 .88369 .32238 Metetra
.664 .741 .907 r
.88369 .32238 .88446 .32356 .89098 .32145 .8902 .32028 Metetra
.664 .741 .907 r
.8902 .32028 .89098 .32145 .8975 .31934 .89673 .31816 Metetra
.664 .741 .907 r
.30741 .50753 .30843 .50849 .31373 .50677 .31271 .50582 Metetra
.664 .741 .907 r
.31271 .50582 .31373 .50677 .31904 .50505 .31802 .5041 Metetra
.664 .741 .907 r
.31802 .5041 .31904 .50505 .32436 .50333 .32334 .50237 Metetra
.664 .741 .907 r
.32334 .50237 .32436 .50333 .32969 .50161 .32867 .50065 Metetra
.664 .741 .907 r
.32867 .50065 .32969 .50161 .33503 .49988 .33402 .49892 Metetra
.664 .741 .907 r
.33402 .49892 .33503 .49988 .34038 .49815 .33937 .49718 Metetra
.664 .741 .907 r
.33937 .49718 .34038 .49815 .34575 .49641 .34474 .49545 Metetra
.664 .741 .907 r
.34474 .49545 .34575 .49641 .35112 .49468 .35011 .4937 Metetra
.664 .741 .907 r
.35011 .4937 .35112 .49468 .3565 .49293 .3555 .49196 Metetra
.664 .741 .907 r
.3555 .49196 .3565 .49293 .3619 .49119 .3609 .49021 Metetra
.664 .741 .907 r
.3609 .49021 .3619 .49119 .36731 .48944 .36631 .48846 Metetra
.664 .741 .907 r
.36631 .48846 .36731 .48944 .37272 .48769 .37173 .48671 Metetra
.664 .741 .907 r
.37173 .48671 .37272 .48769 .37815 .48593 .37716 .48495 Metetra
.664 .741 .907 r
.37716 .48495 .37815 .48593 .38359 .48417 .3826 .48319 Metetra
.664 .741 .907 r
.3826 .48319 .38359 .48417 .38904 .48241 .38805 .48142 Metetra
.664 .741 .907 r
.38805 .48142 .38904 .48241 .39451 .48064 .39351 .47965 Metetra
.664 .741 .907 r
.39351 .47965 .39451 .48064 .39998 .47887 .39899 .47788 Metetra
.664 .741 .907 r
.39899 .47788 .39998 .47887 .40546 .47709 .40448 .4761 Metetra
.664 .741 .907 r
.40448 .4761 .40546 .47709 .41096 .47532 .40997 .47432 Metetra
.664 .741 .907 r
.40997 .47432 .41096 .47532 .41647 .47354 .41548 .47254 Metetra
.664 .741 .907 r
.41548 .47254 .41647 .47354 .42198 .47175 .421 .47075 Metetra
.664 .741 .907 r
.421 .47075 .42198 .47175 .42751 .46996 .42653 .46896 Metetra
.664 .741 .907 r
.42653 .46896 .42751 .46996 .43305 .46817 .43208 .46717 Metetra
.664 .741 .907 r
.43208 .46717 .43305 .46817 .43861 .46637 .43763 .46537 Metetra
.664 .741 .907 r
.43763 .46537 .43861 .46637 .44417 .46457 .4432 .46357 Metetra
.664 .741 .907 r
.4432 .46357 .44417 .46457 .44974 .46277 .44877 .46176 Metetra
.664 .741 .907 r
.44877 .46176 .44974 .46277 .45533 .46096 .45436 .45995 Metetra
.664 .741 .907 r
.45436 .45995 .45533 .46096 .46093 .45915 .45996 .45814 Metetra
.664 .741 .907 r
.45996 .45814 .46093 .45915 .46654 .45734 .46557 .45632 Metetra
.664 .741 .907 r
.46557 .45632 .46654 .45734 .47216 .45552 .4712 .4545 Metetra
.664 .741 .907 r
.4712 .4545 .47216 .45552 .47779 .4537 .47683 .45268 Metetra
.664 .741 .907 r
.47683 .45268 .47779 .4537 .48343 .45187 .48248 .45085 Metetra
.664 .741 .907 r
.48248 .45085 .48343 .45187 .48909 .45004 .48814 .44902 Metetra
.664 .741 .907 r
.48814 .44902 .48909 .45004 .49476 .44821 .49381 .44718 Metetra
.664 .741 .907 r
.49381 .44718 .49476 .44821 .50044 .44637 .49949 .44534 Metetra
.664 .741 .907 r
.49949 .44534 .50044 .44637 .50613 .44453 .50518 .4435 Metetra
.664 .741 .907 r
.50518 .4435 .50613 .44453 .51183 .44268 .51089 .44165 Metetra
.664 .741 .907 r
.51089 .44165 .51183 .44268 .51755 .44083 .51661 .4398 Metetra
.959 .637 .365 r
.51661 .4398 .51755 .44083 .52327 .43898 .5223 .48181 Metetra
.776 .515 .542 r
.5223 .48181 .52327 .43898 .52922 .59956 .52829 .6599 Metetra
0 0 .282 r
.52829 .6599 .52922 .59956 .53476 .43526 .53383 .43423 Metetra
.664 .741 .907 r
.53383 .43423 .53476 .43526 .54054 .4356 .53959 .43236 Metetra
.622 .517 .713 r
.53959 .43236 .54054 .4356 .5463 .43153 .54537 .43049 Metetra
.664 .741 .907 r
.54537 .43049 .5463 .43153 .55209 .42966 .55116 .42861 Metetra
.664 .741 .907 r
.55116 .42861 .55209 .42966 .55789 .42778 .55696 .42674 Metetra
.664 .741 .907 r
.55696 .42674 .55789 .42778 .5637 .4259 .56278 .42485 Metetra
.664 .741 .907 r
.56278 .42485 .5637 .4259 .56952 .42402 .5686 .42297 Metetra
.664 .741 .907 r
.5686 .42297 .56952 .42402 .57536 .42213 .57444 .42108 Metetra
.664 .741 .907 r
.57444 .42108 .57536 .42213 .58121 .42024 .58029 .41918 Metetra
.664 .741 .907 r
.58029 .41918 .58121 .42024 .58707 .41834 .58615 .41728 Metetra
.664 .741 .907 r
.58615 .41728 .58707 .41834 .59294 .41644 .59203 .41538 Metetra
.664 .741 .907 r
.59203 .41538 .59294 .41644 .59883 .41454 .59792 .41348 Metetra
.664 .741 .907 r
.59792 .41348 .59883 .41454 .60472 .41263 .60382 .41157 Metetra
.664 .741 .907 r
.60382 .41157 .60472 .41263 .61063 .41072 .60973 .40965 Metetra
.664 .741 .907 r
.60973 .40965 .61063 .41072 .61656 .4088 .61566 .40773 Metetra
.664 .741 .907 r
.61566 .40773 .61656 .4088 .62249 .40688 .62159 .40581 Metetra
.664 .741 .907 r
.62159 .40581 .62249 .40688 .62844 .40496 .62754 .40388 Metetra
.664 .741 .907 r
.62754 .40388 .62844 .40496 .6344 .40303 .63351 .40195 Metetra
.664 .741 .907 r
.63351 .40195 .6344 .40303 .64037 .4011 .63948 .40002 Metetra
.664 .741 .907 r
.63948 .40002 .64037 .4011 .64636 .39916 .64547 .39808 Metetra
.664 .741 .907 r
.64547 .39808 .64636 .39916 .65236 .39722 .65147 .39614 Metetra
.664 .741 .907 r
.65147 .39614 .65236 .39722 .65837 .39528 .65749 .39419 Metetra
.664 .741 .907 r
.65749 .39419 .65837 .39528 .66439 .39333 .66351 .39224 Metetra
.664 .741 .907 r
.66351 .39224 .66439 .39333 .67043 .39137 .66956 .39028 Metetra
.664 .741 .907 r
.66956 .39028 .67043 .39137 .67648 .38942 .67561 .38832 Metetra
.664 .741 .907 r
.67561 .38832 .67648 .38942 .68255 .38746 .68167 .38636 Metetra
.664 .741 .907 r
.68167 .38636 .68255 .38746 .68862 .38549 .68775 .38439 Metetra
.664 .741 .907 r
.68775 .38439 .68862 .38549 .69471 .38352 .69385 .38242 Metetra
.664 .741 .907 r
.69385 .38242 .69471 .38352 .70081 .38155 .69995 .38044 Metetra
.664 .741 .907 r
.69995 .38044 .70081 .38155 .70693 .37957 .70607 .37846 Metetra
.664 .741 .907 r
.70607 .37846 .70693 .37957 .71306 .37758 .7122 .37648 Metetra
.664 .741 .907 r
.7122 .37648 .71306 .37758 .7192 .3756 .71835 .37449 Metetra
.664 .741 .907 r
.71835 .37449 .7192 .3756 .72536 .37361 .7245 .37249 Metetra
.664 .741 .907 r
.7245 .37249 .72536 .37361 .73152 .37161 .73068 .3705 Metetra
.664 .741 .907 r
.73068 .3705 .73152 .37161 .73771 .36961 .73686 .36849 Metetra
.664 .741 .907 r
.73686 .36849 .73771 .36961 .7439 .36761 .74306 .36649 Metetra
.664 .741 .907 r
.74306 .36649 .7439 .36761 .75011 .3656 .74927 .36447 Metetra
.664 .741 .907 r
.74927 .36447 .75011 .3656 .75633 .36358 .7555 .36246 Metetra
.664 .741 .907 r
.7555 .36246 .75633 .36358 .76257 .36157 .76173 .36044 Metetra
.664 .741 .907 r
.76173 .36044 .76257 .36157 .76882 .35954 .76799 .35842 Metetra
.664 .741 .907 r
.76799 .35842 .76882 .35954 .77508 .35752 .77425 .35639 Metetra
.664 .741 .907 r
.77425 .35639 .77508 .35752 .78136 .35549 .78053 .35435 Metetra
.664 .741 .907 r
.78053 .35435 .78136 .35549 .78765 .35345 .78683 .35232 Metetra
.664 .741 .907 r
.78683 .35232 .78765 .35345 .79395 .35141 .79313 .35027 Metetra
.664 .741 .907 r
.79313 .35027 .79395 .35141 .80027 .34937 .79945 .34823 Metetra
.664 .741 .907 r
.79945 .34823 .80027 .34937 .8066 .34732 .80579 .34618 Metetra
.664 .741 .907 r
.80579 .34618 .8066 .34732 .81295 .34527 .81214 .34412 Metetra
.664 .741 .907 r
.81214 .34412 .81295 .34527 .81931 .34321 .8185 .34206 Metetra
.664 .741 .907 r
.8185 .34206 .81931 .34321 .82568 .34115 .82488 .34 Metetra
.664 .741 .907 r
.82488 .34 .82568 .34115 .83269 .3454 .83127 .33793 Metetra
.15 .128 .576 r
.83127 .33793 .83269 .3454 .84213 .37381 .84017 .3611 Metetra
.719 .491 .579 r
.84017 .3611 .84213 .37381 .84489 .33494 .84409 .33378 Metetra
.664 .741 .907 r
.84409 .33378 .84489 .33494 .85132 .33285 .85053 .33169 Metetra
.664 .741 .907 r
.85053 .33169 .85132 .33285 .85776 .33077 .85697 .32961 Metetra
.664 .741 .907 r
.85697 .32961 .85776 .33077 .86422 .32868 .86344 .32751 Metetra
.664 .741 .907 r
.86344 .32751 .86422 .32868 .8707 .32659 .86991 .32542 Metetra
.664 .741 .907 r
.86991 .32542 .8707 .32659 .87718 .32449 .8764 .32331 Metetra
.664 .741 .907 r
.8764 .32331 .87718 .32449 .88369 .32238 .88291 .32121 Metetra
.664 .741 .907 r
.88291 .32121 .88369 .32238 .8902 .32028 .88943 .3191 Metetra
.664 .741 .907 r
.88943 .3191 .8902 .32028 .89673 .31816 .89596 .31698 Metetra
.664 .741 .907 r
.30638 .50657 .30741 .50753 .31271 .50582 .31168 .50486 Metetra
.664 .741 .907 r
.31168 .50486 .31271 .50582 .31802 .5041 .317 .50313 Metetra
.664 .741 .907 r
.317 .50313 .31802 .5041 .32334 .50237 .32232 .50141 Metetra
.664 .741 .907 r
.32232 .50141 .32334 .50237 .32867 .50065 .32766 .49968 Metetra
.664 .741 .907 r
.32766 .49968 .32867 .50065 .33402 .49892 .333 .49795 Metetra
.664 .741 .907 r
.333 .49795 .33402 .49892 .33937 .49718 .33836 .49621 Metetra
.664 .741 .907 r
.33836 .49621 .33937 .49718 .34474 .49545 .34373 .49447 Metetra
.664 .741 .907 r
.34373 .49447 .34474 .49545 .35011 .4937 .3491 .49273 Metetra
.664 .741 .907 r
.3491 .49273 .35011 .4937 .3555 .49196 .35449 .49099 Metetra
.664 .741 .907 r
.35449 .49099 .3555 .49196 .3609 .49021 .35989 .48924 Metetra
.664 .741 .907 r
.35989 .48924 .3609 .49021 .36631 .48846 .3653 .48748 Metetra
.664 .741 .907 r
.3653 .48748 .36631 .48846 .37173 .48671 .37072 .48573 Metetra
.664 .741 .907 r
.37072 .48573 .37173 .48671 .37716 .48495 .37616 .48397 Metetra
.745 .257 0 r
.37616 .48397 .37716 .48495 .3826 .48319 .38121 .49124 Metetra
.628 .36 .494 r
.38121 .49124 .3826 .48319 .38805 .48142 .3863 .49862 Metetra
.391 .181 .471 r
.3863 .49862 .38805 .48142 .39351 .47965 .39252 .47866 Metetra
.664 .741 .907 r
.39252 .47866 .39351 .47965 .39899 .47788 .398 .47689 Metetra
.664 .741 .907 r
.398 .47689 .39899 .47788 .40448 .4761 .40349 .47511 Metetra
.664 .741 .907 r
.40349 .47511 .40448 .4761 .40997 .47432 .40899 .47333 Metetra
.664 .741 .907 r
.40899 .47333 .40997 .47432 .41548 .47254 .4145 .47154 Metetra
.664 .741 .907 r
.4145 .47154 .41548 .47254 .421 .47075 .42002 .46975 Metetra
.664 .741 .907 r
.42002 .46975 .421 .47075 .42653 .46896 .42555 .46796 Metetra
.664 .741 .907 r
.42555 .46796 .42653 .46896 .43208 .46717 .4311 .46617 Metetra
.664 .741 .907 r
.4311 .46617 .43208 .46717 .43763 .46537 .43666 .46437 Metetra
.664 .741 .907 r
.43666 .46437 .43763 .46537 .4432 .46357 .44222 .46256 Metetra
.664 .741 .907 r
.44222 .46256 .4432 .46357 .44877 .46176 .4478 .46075 Metetra
.664 .741 .907 r
.4478 .46075 .44877 .46176 .45436 .45995 .45339 .45894 Metetra
.664 .741 .907 r
.45339 .45894 .45436 .45995 .45996 .45814 .459 .45713 Metetra
.664 .741 .907 r
.459 .45713 .45996 .45814 .46557 .45632 .46461 .45531 Metetra
.664 .741 .907 r
.46461 .45531 .46557 .45632 .4712 .4545 .47024 .45349 Metetra
.664 .741 .907 r
.47024 .45349 .4712 .4545 .47683 .45268 .47587 .45166 Metetra
.664 .741 .907 r
.47587 .45166 .47683 .45268 .48248 .45085 .48152 .44983 Metetra
.664 .741 .907 r
.48152 .44983 .48248 .45085 .48814 .44902 .48718 .44799 Metetra
.664 .741 .907 r
.48718 .44799 .48814 .44902 .49381 .44718 .49285 .44616 Metetra
.664 .741 .907 r
.49285 .44616 .49381 .44718 .49949 .44534 .49854 .44432 Metetra
.664 .741 .907 r
.49854 .44432 .49949 .44534 .50518 .4435 .50423 .44247 Metetra
.664 .741 .907 r
.50423 .44247 .50518 .4435 .51089 .44165 .50994 .44062 Metetra
.664 .741 .907 r
.50994 .44062 .51089 .44165 .51661 .4398 .51566 .43877 Metetra
.961 .667 .428 r
.51566 .43877 .51661 .4398 .5223 .48181 .52129 .53156 Metetra
.686 .44 .545 r
.52129 .53156 .5223 .48181 .52829 .6599 .52726 .6198 Metetra
.807 .553 .554 r
.52726 .6198 .52829 .6599 .53383 .43423 .53289 .43318 Metetra
.664 .741 .907 r
.53289 .43318 .53383 .43423 .53959 .43236 .53866 .43132 Metetra
.664 .741 .907 r
.53866 .43132 .53959 .43236 .54537 .43049 .54444 .42944 Metetra
.664 .741 .907 r
.54444 .42944 .54537 .43049 .55116 .42861 .55023 .42757 Metetra
.664 .741 .907 r
.55023 .42757 .55116 .42861 .55696 .42674 .55604 .42569 Metetra
.664 .741 .907 r
.55604 .42569 .55696 .42674 .56278 .42485 .56185 .4238 Metetra
.664 .741 .907 r
.56185 .4238 .56278 .42485 .5686 .42297 .56768 .42191 Metetra
.664 .741 .907 r
.56768 .42191 .5686 .42297 .57444 .42108 .57352 .42002 Metetra
.664 .741 .907 r
.57352 .42002 .57444 .42108 .58029 .41918 .57937 .41812 Metetra
.664 .741 .907 r
.57937 .41812 .58029 .41918 .58615 .41728 .58524 .41622 Metetra
.664 .741 .907 r
.58524 .41622 .58615 .41728 .59203 .41538 .59112 .41432 Metetra
.664 .741 .907 r
.59112 .41432 .59203 .41538 .59792 .41348 .59701 .41241 Metetra
.664 .741 .907 r
.59701 .41241 .59792 .41348 .60382 .41157 .60291 .4105 Metetra
.664 .741 .907 r
.60291 .4105 .60382 .41157 .60973 .40965 .60883 .40858 Metetra
.664 .741 .907 r
.60883 .40858 .60973 .40965 .61566 .40773 .61475 .40666 Metetra
.664 .741 .907 r
.61475 .40666 .61566 .40773 .62159 .40581 .62069 .40474 Metetra
.664 .741 .907 r
.62069 .40474 .62159 .40581 .62754 .40388 .62665 .40281 Metetra
.664 .741 .907 r
.62665 .40281 .62754 .40388 .63351 .40195 .63261 .40088 Metetra
.664 .741 .907 r
.63261 .40088 .63351 .40195 .63948 .40002 .63859 .39894 Metetra
.664 .741 .907 r
.63859 .39894 .63948 .40002 .64547 .39808 .64458 .397 Metetra
.664 .741 .907 r
.64458 .397 .64547 .39808 .65147 .39614 .65059 .39505 Metetra
.664 .741 .907 r
.65059 .39505 .65147 .39614 .65749 .39419 .6566 .3931 Metetra
.664 .741 .907 r
.6566 .3931 .65749 .39419 .66351 .39224 .66263 .39115 Metetra
.664 .741 .907 r
.66263 .39115 .66351 .39224 .66956 .39028 .66868 .38919 Metetra
.664 .741 .907 r
.66868 .38919 .66956 .39028 .67561 .38832 .67473 .38723 Metetra
.664 .741 .907 r
.67473 .38723 .67561 .38832 .68167 .38636 .6808 .38526 Metetra
.664 .741 .907 r
.6808 .38526 .68167 .38636 .68775 .38439 .68688 .38329 Metetra
.664 .741 .907 r
.68688 .38329 .68775 .38439 .69385 .38242 .69298 .38132 Metetra
.664 .741 .907 r
.69298 .38132 .69385 .38242 .69995 .38044 .69909 .37934 Metetra
.664 .741 .907 r
.69909 .37934 .69995 .38044 .70607 .37846 .70521 .37735 Metetra
.664 .741 .907 r
.70521 .37735 .70607 .37846 .7122 .37648 .71134 .37537 Metetra
.664 .741 .907 r
.71134 .37537 .7122 .37648 .71835 .37449 .71749 .37338 Metetra
.664 .741 .907 r
.71749 .37338 .71835 .37449 .7245 .37249 .72365 .37138 Metetra
.664 .741 .907 r
.72365 .37138 .7245 .37249 .73068 .3705 .72982 .36938 Metetra
.664 .741 .907 r
.72982 .36938 .73068 .3705 .73686 .36849 .73601 .36737 Metetra
.664 .741 .907 r
.73601 .36737 .73686 .36849 .74306 .36649 .74221 .36536 Metetra
.664 .741 .907 r
.74221 .36536 .74306 .36649 .74927 .36447 .74843 .36335 Metetra
.664 .741 .907 r
.74843 .36335 .74927 .36447 .7555 .36246 .75466 .36133 Metetra
.664 .741 .907 r
.75466 .36133 .7555 .36246 .76173 .36044 .7609 .35931 Metetra
.664 .741 .907 r
.7609 .35931 .76173 .36044 .76799 .35842 .76715 .35728 Metetra
.664 .741 .907 r
.76715 .35728 .76799 .35842 .77425 .35639 .77342 .35525 Metetra
.664 .741 .907 r
.77342 .35525 .77425 .35639 .78053 .35435 .7797 .35322 Metetra
.664 .741 .907 r
.7797 .35322 .78053 .35435 .78683 .35232 .786 .35118 Metetra
.664 .741 .907 r
.786 .35118 .78683 .35232 .79313 .35027 .79231 .34913 Metetra
.664 .741 .907 r
.79231 .34913 .79313 .35027 .79945 .34823 .79864 .34708 Metetra
.664 .741 .907 r
.79864 .34708 .79945 .34823 .80579 .34618 .80497 .34503 Metetra
.664 .741 .907 r
.80497 .34503 .80579 .34618 .81214 .34412 .81133 .34297 Metetra
.664 .741 .907 r
.81133 .34297 .81214 .34412 .8185 .34206 .81769 .34091 Metetra
.664 .741 .907 r
.81769 .34091 .8185 .34206 .82488 .34 .82407 .33884 Metetra
.664 .741 .907 r
.82407 .33884 .82488 .34 .83127 .33793 .83047 .33677 Metetra
.664 .741 .907 r
.83047 .33677 .83127 .33793 .84017 .3611 .83687 .33469 Metetra
.567 .367 .569 r
.83687 .33469 .84017 .3611 .84409 .33378 .8433 .33261 Metetra
.664 .741 .907 r
.8433 .33261 .84409 .33378 .85053 .33169 .84973 .33053 Metetra
.664 .741 .907 r
.84973 .33053 .85053 .33169 .85697 .32961 .85618 .32844 Metetra
.664 .741 .907 r
.85618 .32844 .85697 .32961 .86344 .32751 .86265 .32634 Metetra
.664 .741 .907 r
.86265 .32634 .86344 .32751 .86991 .32542 .86913 .32424 Metetra
.664 .741 .907 r
.86913 .32424 .86991 .32542 .8764 .32331 .87562 .32214 Metetra
.664 .741 .907 r
.87562 .32214 .8764 .32331 .88291 .32121 .88213 .32003 Metetra
.664 .741 .907 r
.88213 .32003 .88291 .32121 .88943 .3191 .88865 .31792 Metetra
.664 .741 .907 r
.88865 .31792 .88943 .3191 .89596 .31698 .89519 .3158 Metetra
.664 .741 .907 r
.30536 .50562 .30638 .50657 .31168 .50486 .31066 .5039 Metetra
.664 .741 .907 r
.31066 .5039 .31168 .50486 .317 .50313 .31598 .50217 Metetra
.664 .741 .907 r
.31598 .50217 .317 .50313 .32232 .50141 .3213 .50045 Metetra
.664 .741 .907 r
.3213 .50045 .32232 .50141 .32766 .49968 .32664 .49872 Metetra
.664 .741 .907 r
.32664 .49872 .32766 .49968 .333 .49795 .33199 .49698 Metetra
.664 .741 .907 r
.33199 .49698 .333 .49795 .33836 .49621 .33734 .49524 Metetra
.664 .741 .907 r
.33734 .49524 .33836 .49621 .34373 .49447 .34271 .4935 Metetra
.664 .741 .907 r
.34271 .4935 .34373 .49447 .3491 .49273 .34809 .49176 Metetra
.664 .741 .907 r
.34809 .49176 .3491 .49273 .35449 .49099 .35348 .49001 Metetra
.664 .741 .907 r
.35348 .49001 .35449 .49099 .35989 .48924 .35889 .48826 Metetra
.664 .741 .907 r
.35889 .48826 .35989 .48924 .3653 .48748 .3643 .4865 Metetra
.664 .741 .907 r
.3643 .4865 .3653 .48748 .37072 .48573 .36972 .48475 Metetra
.664 .741 .907 r
.36972 .48475 .37072 .48573 .37616 .48397 .37516 .48298 Metetra
.95 .633 .398 r
.37516 .48298 .37616 .48397 .38121 .49124 .37912 .51528 Metetra
.345 .151 .468 r
.37912 .51528 .38121 .49124 .3863 .49862 .38597 .48156 Metetra
.584 .388 .582 r
.38597 .48156 .3863 .49862 .39252 .47866 .39153 .47768 Metetra
.664 .741 .907 r
.39153 .47768 .39252 .47866 .398 .47689 .39701 .4759 Metetra
.664 .741 .907 r
.39701 .4759 .398 .47689 .40349 .47511 .4025 .47412 Metetra
.664 .741 .907 r
.4025 .47412 .40349 .47511 .40899 .47333 .408 .47233 Metetra
.664 .741 .907 r
.408 .47233 .40899 .47333 .4145 .47154 .41351 .47055 Metetra
.664 .741 .907 r
.41351 .47055 .4145 .47154 .42002 .46975 .41904 .46876 Metetra
.664 .741 .907 r
.41904 .46876 .42002 .46975 .42555 .46796 .42457 .46696 Metetra
.664 .741 .907 r
.42457 .46696 .42555 .46796 .4311 .46617 .43012 .46516 Metetra
.664 .741 .907 r
.43012 .46516 .4311 .46617 .43666 .46437 .43568 .46336 Metetra
.664 .741 .907 r
.43568 .46336 .43666 .46437 .44222 .46256 .44125 .46155 Metetra
.664 .741 .907 r
.44125 .46155 .44222 .46256 .4478 .46075 .44683 .45974 Metetra
.664 .741 .907 r
.44683 .45974 .4478 .46075 .45339 .45894 .45242 .45793 Metetra
.664 .741 .907 r
.45242 .45793 .45339 .45894 .459 .45713 .45803 .45611 Metetra
.664 .741 .907 r
.45803 .45611 .459 .45713 .46461 .45531 .46364 .45429 Metetra
.664 .741 .907 r
.46364 .45429 .46461 .45531 .47024 .45349 .46927 .45247 Metetra
.664 .741 .907 r
.46927 .45247 .47024 .45349 .47587 .45166 .47491 .45064 Metetra
.664 .741 .907 r
.47491 .45064 .47587 .45166 .48152 .44983 .48056 .44881 Metetra
.664 .741 .907 r
.48056 .44881 .48152 .44983 .48718 .44799 .48623 .44697 Metetra
.664 .741 .907 r
.48623 .44697 .48718 .44799 .49285 .44616 .4919 .44513 Metetra
.664 .741 .907 r
.4919 .44513 .49285 .44616 .49854 .44432 .49759 .44329 Metetra
.664 .741 .907 r
.49759 .44329 .49854 .44432 .50423 .44247 .50329 .44144 Metetra
.664 .741 .907 r
.50329 .44144 .50423 .44247 .50994 .44062 .509 .43959 Metetra
.664 .741 .907 r
.509 .43959 .50994 .44062 .51566 .43877 .51472 .43773 Metetra
.896 .482 .094 r
.51472 .43773 .51566 .43877 .52129 .53156 .52043 .45214 Metetra
.434 .252 .534 r
.52043 .45214 .52129 .53156 .52726 .6198 .52624 .53107 Metetra
.657 .427 .559 r
.52624 .53107 .52726 .6198 .53289 .43318 .53196 .43214 Metetra
.664 .741 .907 r
.53196 .43214 .53289 .43318 .53866 .43132 .53773 .43027 Metetra
.664 .741 .907 r
.53773 .43027 .53866 .43132 .54444 .42944 .54351 .4284 Metetra
.664 .741 .907 r
.54351 .4284 .54444 .42944 .55023 .42757 .5493 .42652 Metetra
.664 .741 .907 r
.5493 .42652 .55023 .42757 .55604 .42569 .55511 .42464 Metetra
.664 .741 .907 r
.55511 .42464 .55604 .42569 .56185 .4238 .56093 .42275 Metetra
.664 .741 .907 r
.56093 .42275 .56185 .4238 .56768 .42191 .56676 .42086 Metetra
.664 .741 .907 r
.56676 .42086 .56768 .42191 .57352 .42002 .5726 .41896 Metetra
.664 .741 .907 r
.5726 .41896 .57352 .42002 .57937 .41812 .57846 .41707 Metetra
.664 .741 .907 r
.57846 .41707 .57937 .41812 .58524 .41622 .58432 .41516 Metetra
.664 .741 .907 r
.58432 .41516 .58524 .41622 .59112 .41432 .5902 .41326 Metetra
.664 .741 .907 r
.5902 .41326 .59112 .41432 .59701 .41241 .5961 .41135 Metetra
.664 .741 .907 r
.5961 .41135 .59701 .41241 .60291 .4105 .602 .40943 Metetra
.664 .741 .907 r
.602 .40943 .60291 .4105 .60883 .40858 .60792 .40751 Metetra
.664 .741 .907 r
.60792 .40751 .60883 .40858 .61475 .40666 .61385 .40559 Metetra
.664 .741 .907 r
.61385 .40559 .61475 .40666 .62069 .40474 .61979 .40366 Metetra
.664 .741 .907 r
.61979 .40366 .62069 .40474 .62665 .40281 .62575 .40173 Metetra
.664 .741 .907 r
.62575 .40173 .62665 .40281 .63261 .40088 .63172 .3998 Metetra
.664 .741 .907 r
.63172 .3998 .63261 .40088 .63859 .39894 .6377 .39786 Metetra
.664 .741 .907 r
.6377 .39786 .63859 .39894 .64458 .397 .64369 .39591 Metetra
.664 .741 .907 r
.64369 .39591 .64458 .397 .65059 .39505 .6497 .39396 Metetra
.664 .741 .907 r
.6497 .39396 .65059 .39505 .6566 .3931 .65572 .39201 Metetra
.664 .741 .907 r
.65572 .39201 .6566 .3931 .66263 .39115 .66175 .39006 Metetra
.612 .721 .923 r
.66175 .39006 .66263 .39115 .66868 .38919 .66783 .38885 Metetra
.674 .923 .973 r
.66783 .38885 .66868 .38919 .67473 .38723 .67386 .38613 Metetra
.664 .741 .907 r
.67386 .38613 .67473 .38723 .6808 .38526 .67993 .38416 Metetra
.664 .741 .907 r
.67993 .38416 .6808 .38526 .68688 .38329 .68601 .38219 Metetra
.664 .741 .907 r
.68601 .38219 .68688 .38329 .69298 .38132 .69211 .38021 Metetra
.664 .741 .907 r
.69211 .38021 .69298 .38132 .69909 .37934 .69822 .37823 Metetra
.664 .741 .907 r
.69822 .37823 .69909 .37934 .70521 .37735 .70434 .37625 Metetra
.664 .741 .907 r
.70434 .37625 .70521 .37735 .71134 .37537 .71048 .37426 Metetra
.664 .741 .907 r
.71048 .37426 .71134 .37537 .71749 .37338 .71663 .37226 Metetra
.664 .741 .907 r
.71663 .37226 .71749 .37338 .72365 .37138 .7228 .37026 Metetra
.664 .741 .907 r
.7228 .37026 .72365 .37138 .72982 .36938 .72897 .36826 Metetra
.664 .741 .907 r
.72897 .36826 .72982 .36938 .73601 .36737 .73516 .36625 Metetra
.664 .741 .907 r
.73516 .36625 .73601 .36737 .74221 .36536 .74137 .36424 Metetra
.664 .741 .907 r
.74137 .36424 .74221 .36536 .74843 .36335 .74758 .36223 Metetra
.664 .741 .907 r
.74758 .36223 .74843 .36335 .75466 .36133 .75382 .36021 Metetra
.664 .741 .907 r
.75382 .36021 .75466 .36133 .7609 .35931 .76006 .35818 Metetra
.664 .741 .907 r
.76006 .35818 .7609 .35931 .76715 .35728 .76632 .35615 Metetra
.664 .741 .907 r
.76632 .35615 .76715 .35728 .77342 .35525 .77259 .35412 Metetra
.664 .741 .907 r
.77259 .35412 .77342 .35525 .7797 .35322 .77888 .35208 Metetra
.664 .741 .907 r
.77888 .35208 .7797 .35322 .786 .35118 .78518 .35004 Metetra
.664 .741 .907 r
.78518 .35004 .786 .35118 .79231 .34913 .79149 .34799 Metetra
.664 .741 .907 r
.79149 .34799 .79231 .34913 .79864 .34708 .79782 .34594 Metetra
.664 .741 .907 r
.79782 .34594 .79864 .34708 .80497 .34503 .80416 .34388 Metetra
.664 .741 .907 r
.80416 .34388 .80497 .34503 .81133 .34297 .81051 .34182 Metetra
.664 .741 .907 r
.81051 .34182 .81133 .34297 .81769 .34091 .81688 .33976 Metetra
.664 .741 .907 r
.81688 .33976 .81769 .34091 .82407 .33884 .82326 .33769 Metetra
.664 .741 .907 r
.82326 .33769 .82407 .33884 .83047 .33677 .82966 .33561 Metetra
.664 .741 .907 r
.82966 .33561 .83047 .33677 .83687 .33469 .83607 .33353 Metetra
.664 .741 .907 r
.83607 .33353 .83687 .33469 .8433 .33261 .8425 .33145 Metetra
.664 .741 .907 r
.8425 .33145 .8433 .33261 .84973 .33053 .84894 .32936 Metetra
.664 .741 .907 r
.84894 .32936 .84973 .33053 .85618 .32844 .85539 .32727 Metetra
.664 .741 .907 r
.85539 .32727 .85618 .32844 .86265 .32634 .86186 .32517 Metetra
.664 .741 .907 r
.86186 .32517 .86265 .32634 .86913 .32424 .86834 .32307 Metetra
.664 .741 .907 r
.86834 .32307 .86913 .32424 .87562 .32214 .87484 .32097 Metetra
.664 .741 .907 r
.87484 .32097 .87562 .32214 .88213 .32003 .88135 .31885 Metetra
.664 .741 .907 r
.88135 .31885 .88213 .32003 .88865 .31792 .88787 .31674 Metetra
.664 .741 .907 r
.88787 .31674 .88865 .31792 .89519 .3158 .89442 .31462 Metetra
.664 .741 .907 r
.30433 .50466 .30536 .50562 .31066 .5039 .30963 .50294 Metetra
.664 .741 .907 r
.30963 .50294 .31066 .5039 .31598 .50217 .31495 .50121 Metetra
.664 .741 .907 r
.31495 .50121 .31598 .50217 .3213 .50045 .32028 .49948 Metetra
.664 .741 .907 r
.32028 .49948 .3213 .50045 .32664 .49872 .32562 .49775 Metetra
.664 .741 .907 r
.32562 .49775 .32664 .49872 .33199 .49698 .33097 .49601 Metetra
.664 .741 .907 r
.33097 .49601 .33199 .49698 .33734 .49524 .33633 .49427 Metetra
.664 .741 .907 r
.33633 .49427 .33734 .49524 .34271 .4935 .3417 .49253 Metetra
.664 .741 .907 r
.3417 .49253 .34271 .4935 .34809 .49176 .34708 .49078 Metetra
.664 .741 .907 r
.34708 .49078 .34809 .49176 .35348 .49001 .35248 .48903 Metetra
.664 .741 .907 r
.35248 .48903 .35348 .49001 .35889 .48826 .35788 .48728 Metetra
.664 .741 .907 r
.35788 .48728 .35889 .48826 .3643 .4865 .36329 .48552 Metetra
.664 .741 .907 r
.36329 .48552 .3643 .4865 .36972 .48475 .36872 .48376 Metetra
.664 .741 .907 r
.36872 .48376 .36972 .48475 .37516 .48298 .37416 .482 Metetra
.95 .642 .417 r
.37416 .482 .37516 .48298 .37912 .51528 .37786 .51994 Metetra
.98 .829 .429 r
.37786 .51994 .37912 .51528 .38597 .48156 .38506 .47846 Metetra
.623 .52 .716 r
.38506 .47846 .38597 .48156 .39153 .47768 .39053 .47668 Metetra
.664 .741 .907 r
.39053 .47668 .39153 .47768 .39701 .4759 .39602 .47491 Metetra
.664 .741 .907 r
.39602 .47491 .39701 .4759 .4025 .47412 .40151 .47312 Metetra
.664 .741 .907 r
.40151 .47312 .4025 .47412 .408 .47233 .40701 .47134 Metetra
.664 .741 .907 r
.40701 .47134 .408 .47233 .41351 .47055 .41253 .46955 Metetra
.664 .741 .907 r
.41253 .46955 .41351 .47055 .41904 .46876 .41805 .46775 Metetra
.664 .741 .907 r
.41805 .46775 .41904 .46876 .42457 .46696 .42359 .46596 Metetra
.664 .741 .907 r
.42359 .46596 .42457 .46696 .43012 .46516 .42914 .46416 Metetra
.664 .741 .907 r
.42914 .46416 .43012 .46516 .43568 .46336 .4347 .46235 Metetra
.664 .741 .907 r
.4347 .46235 .43568 .46336 .44125 .46155 .44027 .46054 Metetra
.664 .741 .907 r
.44027 .46054 .44125 .46155 .44683 .45974 .44586 .45873 Metetra
.664 .741 .907 r
.44586 .45873 .44683 .45974 .45242 .45793 .45145 .45692 Metetra
.664 .741 .907 r
.45145 .45692 .45242 .45793 .45803 .45611 .45706 .4551 Metetra
.664 .741 .907 r
.45706 .4551 .45803 .45611 .46364 .45429 .46268 .45327 Metetra
.304 .582 .94 r
.46268 .45327 .46364 .45429 .46927 .45247 .46825 .45467 Metetra
.145 0 .105 r
.46825 .45467 .46927 .45247 .47491 .45064 .47395 .44962 Metetra
.664 .741 .907 r
.47395 .44962 .47491 .45064 .48056 .44881 .4796 .44778 Metetra
.664 .741 .907 r
.4796 .44778 .48056 .44881 .48623 .44697 .48527 .44594 Metetra
.664 .741 .907 r
.48527 .44594 .48623 .44697 .4919 .44513 .49095 .4441 Metetra
.664 .741 .907 r
.49095 .4441 .4919 .44513 .49759 .44329 .49663 .44226 Metetra
.664 .741 .907 r
.49663 .44226 .49759 .44329 .50329 .44144 .50233 .44041 Metetra
.664 .741 .907 r
.50233 .44041 .50329 .44144 .509 .43959 .50805 .43855 Metetra
.664 .741 .907 r
.50805 .43855 .509 .43959 .51472 .43773 .51377 .4367 Metetra
.664 .741 .907 r
.51377 .4367 .51472 .43773 .52043 .45214 .51951 .43483 Metetra
.572 .378 .58 r
.51951 .43483 .52043 .45214 .52624 .53107 .52526 .43297 Metetra
.554 .344 .551 r
.52526 .43297 .52624 .53107 .53196 .43214 .53103 .43652 Metetra
.303 .035 .331 r
.53103 .43652 .53196 .43214 .53773 .43027 .53679 .42923 Metetra
.664 .741 .907 r
.53679 .42923 .53773 .43027 .54351 .4284 .54257 .42735 Metetra
.664 .741 .907 r
.54257 .42735 .54351 .4284 .5493 .42652 .54837 .42547 Metetra
.664 .741 .907 r
.54837 .42547 .5493 .42652 .55511 .42464 .55418 .42358 Metetra
.664 .741 .907 r
.55418 .42358 .55511 .42464 .56093 .42275 .56 .42169 Metetra
.664 .741 .907 r
.56 .42169 .56093 .42275 .56676 .42086 .56583 .4198 Metetra
.664 .741 .907 r
.56583 .4198 .56676 .42086 .5726 .41896 .57168 .41791 Metetra
.664 .741 .907 r
.57168 .41791 .5726 .41896 .57846 .41707 .57754 .416 Metetra
.664 .741 .907 r
.57754 .416 .57846 .41707 .58432 .41516 .58341 .4141 Metetra
.664 .741 .907 r
.58341 .4141 .58432 .41516 .5902 .41326 .58929 .41219 Metetra
.664 .741 .907 r
.58929 .41219 .5902 .41326 .5961 .41135 .59519 .41028 Metetra
.664 .741 .907 r
.59519 .41028 .5961 .41135 .602 .40943 .60109 .40836 Metetra
.664 .741 .907 r
.60109 .40836 .602 .40943 .60792 .40751 .60701 .40644 Metetra
.664 .741 .907 r
.60701 .40644 .60792 .40751 .61385 .40559 .61295 .40451 Metetra
.664 .741 .907 r
.61295 .40451 .61385 .40559 .61979 .40366 .61889 .40258 Metetra
.664 .741 .907 r
.61889 .40258 .61979 .40366 .62575 .40173 .62485 .40065 Metetra
.664 .741 .907 r
.62485 .40065 .62575 .40173 .63172 .3998 .63082 .39871 Metetra
.664 .741 .907 r
.63082 .39871 .63172 .3998 .6377 .39786 .63681 .39677 Metetra
.664 .741 .907 r
.63681 .39677 .6377 .39786 .64369 .39591 .6428 .39483 Metetra
.664 .741 .907 r
.6428 .39483 .64369 .39591 .6497 .39396 .64881 .39288 Metetra
.664 .741 .907 r
.64881 .39288 .6497 .39396 .65572 .39201 .65483 .39092 Metetra
.664 .741 .907 r
.65483 .39092 .65572 .39201 .66175 .39006 .66087 .38896 Metetra
.664 .741 .907 r
.66087 .38896 .66175 .39006 .66783 .38885 .66692 .387 Metetra
.651 .625 .811 r
.66692 .387 .66783 .38885 .67386 .38613 .67298 .38503 Metetra
.664 .741 .907 r
.67298 .38503 .67386 .38613 .67993 .38416 .67905 .38306 Metetra
.664 .741 .907 r
.67905 .38306 .67993 .38416 .68601 .38219 .68514 .38109 Metetra
.664 .741 .907 r
.68514 .38109 .68601 .38219 .69211 .38021 .69124 .37911 Metetra
.664 .741 .907 r
.69124 .37911 .69211 .38021 .69822 .37823 .69735 .37713 Metetra
.664 .741 .907 r
.69735 .37713 .69822 .37823 .70434 .37625 .70348 .37514 Metetra
.664 .741 .907 r
.70348 .37514 .70434 .37625 .71048 .37426 .70962 .37315 Metetra
.664 .741 .907 r
.70962 .37315 .71048 .37426 .71663 .37226 .71577 .37115 Metetra
.664 .741 .907 r
.71577 .37115 .71663 .37226 .7228 .37026 .72194 .36915 Metetra
.664 .741 .907 r
.72194 .36915 .7228 .37026 .72897 .36826 .72812 .36714 Metetra
.664 .741 .907 r
.72812 .36714 .72897 .36826 .73516 .36625 .73431 .36513 Metetra
.664 .741 .907 r
.73431 .36513 .73516 .36625 .74137 .36424 .74052 .36312 Metetra
.664 .741 .907 r
.74052 .36312 .74137 .36424 .74758 .36223 .74674 .3611 Metetra
.664 .741 .907 r
.74674 .3611 .74758 .36223 .75382 .36021 .75297 .35908 Metetra
.664 .741 .907 r
.75297 .35908 .75382 .36021 .76006 .35818 .75922 .35705 Metetra
.664 .741 .907 r
.75922 .35705 .76006 .35818 .76632 .35615 .76548 .35502 Metetra
.664 .741 .907 r
.76548 .35502 .76632 .35615 .77259 .35412 .77176 .35298 Metetra
.664 .741 .907 r
.77176 .35298 .77259 .35412 .77888 .35208 .77805 .35094 Metetra
.664 .741 .907 r
.77805 .35094 .77888 .35208 .78518 .35004 .78435 .3489 Metetra
.664 .741 .907 r
.78435 .3489 .78518 .35004 .79149 .34799 .79066 .34685 Metetra
.664 .741 .907 r
.79066 .34685 .79149 .34799 .79782 .34594 .79699 .34479 Metetra
.664 .741 .907 r
.79699 .34479 .79782 .34594 .80416 .34388 .80334 .34273 Metetra
.664 .741 .907 r
.80334 .34273 .80416 .34388 .81051 .34182 .8097 .34067 Metetra
.664 .741 .907 r
.8097 .34067 .81051 .34182 .81688 .33976 .81607 .3386 Metetra
.664 .741 .907 r
.81607 .3386 .81688 .33976 .82326 .33769 .82245 .33653 Metetra
.664 .741 .907 r
.82245 .33653 .82326 .33769 .82966 .33561 .82885 .33445 Metetra
.664 .741 .907 r
.82885 .33445 .82966 .33561 .83607 .33353 .83527 .33237 Metetra
.664 .741 .907 r
.83527 .33237 .83607 .33353 .8425 .33145 .8417 .33029 Metetra
.664 .741 .907 r
.8417 .33029 .8425 .33145 .84894 .32936 .84814 .3282 Metetra
.664 .741 .907 r
.84814 .3282 .84894 .32936 .85539 .32727 .8546 .3261 Metetra
.664 .741 .907 r
.8546 .3261 .85539 .32727 .86186 .32517 .86107 .324 Metetra
.664 .741 .907 r
.86107 .324 .86186 .32517 .86834 .32307 .86755 .3219 Metetra
.664 .741 .907 r
.86755 .3219 .86834 .32307 .87484 .32097 .87405 .31979 Metetra
.664 .741 .907 r
.87405 .31979 .87484 .32097 .88135 .31885 .88057 .31767 Metetra
.664 .741 .907 r
.88057 .31767 .88135 .31885 .88787 .31674 .8871 .31556 Metetra
.664 .741 .907 r
.8871 .31556 .88787 .31674 .89442 .31462 .89364 .31343 Metetra
.664 .741 .907 r
.3033 .5037 .30433 .50466 .30963 .50294 .30861 .50197 Metetra
.664 .741 .907 r
.30861 .50197 .30963 .50294 .31495 .50121 .31393 .50025 Metetra
.664 .741 .907 r
.31393 .50025 .31495 .50121 .32028 .49948 .31926 .49852 Metetra
.664 .741 .907 r
.31926 .49852 .32028 .49948 .32562 .49775 .3246 .49678 Metetra
.664 .741 .907 r
.3246 .49678 .32562 .49775 .33097 .49601 .32995 .49504 Metetra
.664 .741 .907 r
.32995 .49504 .33097 .49601 .33633 .49427 .33531 .4933 Metetra
.664 .741 .907 r
.33531 .4933 .33633 .49427 .3417 .49253 .34069 .49156 Metetra
.664 .741 .907 r
.34069 .49156 .3417 .49253 .34708 .49078 .34607 .48981 Metetra
.664 .741 .907 r
.34607 .48981 .34708 .49078 .35248 .48903 .35147 .48806 Metetra
.664 .741 .907 r
.35147 .48806 .35248 .48903 .35788 .48728 .35687 .4863 Metetra
.664 .741 .907 r
.35687 .4863 .35788 .48728 .36329 .48552 .36229 .48454 Metetra
.664 .741 .907 r
.36229 .48454 .36329 .48552 .36872 .48376 .36772 .48278 Metetra
.664 .741 .907 r
.36772 .48278 .36872 .48376 .37416 .482 .37316 .48101 Metetra
.944 .597 .328 r
.37316 .48101 .37416 .482 .37786 .51994 .37758 .50245 Metetra
.678 .462 .586 r
.37758 .50245 .37786 .51994 .38506 .47846 .38407 .47747 Metetra
.664 .741 .907 r
.38407 .47747 .38506 .47846 .39053 .47668 .38954 .47569 Metetra
.664 .741 .907 r
.38954 .47569 .39053 .47668 .39602 .47491 .39502 .47391 Metetra
.664 .741 .907 r
.39502 .47391 .39602 .47491 .40151 .47312 .40052 .47213 Metetra
.664 .741 .907 r
.40052 .47213 .40151 .47312 .40701 .47134 .40602 .47034 Metetra
.664 .741 .907 r
.40602 .47034 .40701 .47134 .41253 .46955 .41154 .46855 Metetra
.664 .741 .907 r
.41154 .46855 .41253 .46955 .41805 .46775 .41707 .46675 Metetra
.664 .741 .907 r
.41707 .46675 .41805 .46775 .42359 .46596 .42261 .46495 Metetra
.664 .741 .907 r
.42261 .46495 .42359 .46596 .42914 .46416 .42816 .46315 Metetra
.664 .741 .907 r
.42816 .46315 .42914 .46416 .4347 .46235 .43372 .46134 Metetra
.664 .741 .907 r
.43372 .46134 .4347 .46235 .44027 .46054 .4393 .45953 Metetra
.664 .741 .907 r
.4393 .45953 .44027 .46054 .44586 .45873 .44488 .45772 Metetra
.664 .741 .907 r
.44488 .45772 .44586 .45873 .45145 .45692 .45048 .4559 Metetra
.664 .741 .907 r
.45048 .4559 .45145 .45692 .45706 .4551 .45609 .45408 Metetra
.664 .741 .907 r
.45609 .45408 .45706 .4551 .46268 .45327 .46171 .45226 Metetra
.957 .669 .449 r
.46171 .45226 .46268 .45327 .46825 .45467 .46562 .54836 Metetra
.416 .226 .512 r
.46562 .54836 .46825 .45467 .47395 .44962 .47299 .44859 Metetra
.664 .741 .907 r
.47299 .44859 .47395 .44962 .4796 .44778 .47864 .44676 Metetra
.664 .741 .907 r
.47864 .44676 .4796 .44778 .48527 .44594 .48431 .44492 Metetra
.664 .741 .907 r
.48431 .44492 .48527 .44594 .49095 .4441 .48999 .44307 Metetra
.664 .741 .907 r
.48999 .44307 .49095 .4441 .49663 .44226 .49568 .44123 Metetra
.664 .741 .907 r
.49568 .44123 .49663 .44226 .50233 .44041 .50138 .43937 Metetra
.664 .741 .907 r
.50138 .43937 .50233 .44041 .50805 .43855 .5071 .43752 Metetra
.664 .741 .907 r
.5071 .43752 .50805 .43855 .51377 .4367 .51282 .43566 Metetra
.664 .741 .907 r
.51282 .43566 .51377 .4367 .51951 .43483 .51856 .43379 Metetra
.664 .741 .907 r
.51856 .43379 .51951 .43483 .52526 .43297 .52431 .43193 Metetra
.664 .741 .907 r
.52431 .43193 .52526 .43297 .53103 .43652 .53008 .43006 Metetra
.594 .435 .636 r
.53008 .43006 .53103 .43652 .53679 .42923 .53585 .42818 Metetra
.664 .741 .907 r
.53585 .42818 .53679 .42923 .54257 .42735 .54164 .4263 Metetra
.664 .741 .907 r
.54164 .4263 .54257 .42735 .54837 .42547 .54744 .42442 Metetra
.664 .741 .907 r
.54744 .42442 .54837 .42547 .55418 .42358 .55325 .42253 Metetra
.664 .741 .907 r
.55325 .42253 .55418 .42358 .56 .42169 .55907 .42064 Metetra
.664 .741 .907 r
.55907 .42064 .56 .42169 .56583 .4198 .56491 .41874 Metetra
.664 .741 .907 r
.56491 .41874 .56583 .4198 .57168 .41791 .57076 .41685 Metetra
.664 .741 .907 r
.57076 .41685 .57168 .41791 .57754 .416 .57662 .41494 Metetra
.664 .741 .907 r
.57662 .41494 .57754 .416 .58341 .4141 .58249 .41304 Metetra
.664 .741 .907 r
.58249 .41304 .58341 .4141 .58929 .41219 .58838 .41112 Metetra
.664 .741 .907 r
.58838 .41112 .58929 .41219 .59519 .41028 .59427 .40921 Metetra
.664 .741 .907 r
.59427 .40921 .59519 .41028 .60109 .40836 .60018 .40729 Metetra
.664 .741 .907 r
.60018 .40729 .60109 .40836 .60701 .40644 .60611 .40537 Metetra
.664 .741 .907 r
.60611 .40537 .60701 .40644 .61295 .40451 .61204 .40344 Metetra
.664 .741 .907 r
.61204 .40344 .61295 .40451 .61889 .40258 .61799 .40151 Metetra
.664 .741 .907 r
.61799 .40151 .61889 .40258 .62485 .40065 .62395 .39957 Metetra
.664 .741 .907 r
.62395 .39957 .62485 .40065 .63082 .39871 .62993 .39763 Metetra
.664 .741 .907 r
.62993 .39763 .63082 .39871 .63681 .39677 .63591 .39569 Metetra
.664 .741 .907 r
.63591 .39569 .63681 .39677 .6428 .39483 .64191 .39374 Metetra
.664 .741 .907 r
.64191 .39374 .6428 .39483 .64881 .39288 .64792 .39179 Metetra
.664 .741 .907 r
.64792 .39179 .64881 .39288 .65483 .39092 .65395 .38983 Metetra
.664 .741 .907 r
.65395 .38983 .65483 .39092 .66087 .38896 .65999 .38787 Metetra
.664 .741 .907 r
.65999 .38787 .66087 .38896 .66692 .387 .66604 .38591 Metetra
.664 .741 .907 r
.66604 .38591 .66692 .387 .67298 .38503 .6721 .38394 Metetra
.664 .741 .907 r
.6721 .38394 .67298 .38503 .67905 .38306 .67818 .38196 Metetra
.664 .741 .907 r
.67818 .38196 .67905 .38306 .68514 .38109 .68427 .37999 Metetra
.664 .741 .907 r
.68427 .37999 .68514 .38109 .69124 .37911 .69037 .378 Metetra
.664 .741 .907 r
.69037 .378 .69124 .37911 .69735 .37713 .69649 .37602 Metetra
.963 .63 .299 r
.69649 .37602 .69735 .37713 .70348 .37514 .70593 .43367 Metetra
.435 .243 .52 r
.70593 .43367 .70348 .37514 .70962 .37315 .70876 .37203 Metetra
.664 .741 .907 r
.70876 .37203 .70962 .37315 .71577 .37115 .71491 .37003 Metetra
.664 .741 .907 r
.71491 .37003 .71577 .37115 .72194 .36915 .72108 .36803 Metetra
.664 .741 .907 r
.72108 .36803 .72194 .36915 .72812 .36714 .72727 .36602 Metetra
.664 .741 .907 r
.72727 .36602 .72812 .36714 .73431 .36513 .73346 .36401 Metetra
.664 .741 .907 r
.73346 .36401 .73431 .36513 .74052 .36312 .73967 .36199 Metetra
.664 .741 .907 r
.73967 .36199 .74052 .36312 .74674 .3611 .74589 .35997 Metetra
.664 .741 .907 r
.74589 .35997 .74674 .3611 .75297 .35908 .75213 .35795 Metetra
.664 .741 .907 r
.75213 .35795 .75297 .35908 .75922 .35705 .75838 .35592 Metetra
.664 .741 .907 r
.75838 .35592 .75922 .35705 .76548 .35502 .76465 .35388 Metetra
.664 .741 .907 r
.76465 .35388 .76548 .35502 .77176 .35298 .77092 .35184 Metetra
.664 .741 .907 r
.77092 .35184 .77176 .35298 .77805 .35094 .77722 .3498 Metetra
.664 .741 .907 r
.77722 .3498 .77805 .35094 .78435 .3489 .78352 .34775 Metetra
.664 .741 .907 r
.78352 .34775 .78435 .3489 .79066 .34685 .78984 .3457 Metetra
.664 .741 .907 r
.78984 .3457 .79066 .34685 .79699 .34479 .79617 .34365 Metetra
.664 .741 .907 r
.79617 .34365 .79699 .34479 .80334 .34273 .80252 .34158 Metetra
.664 .741 .907 r
.80252 .34158 .80334 .34273 .8097 .34067 .80888 .33952 Metetra
.664 .741 .907 r
.80888 .33952 .8097 .34067 .81607 .3386 .81526 .33745 Metetra
.664 .741 .907 r
.81526 .33745 .81607 .3386 .82245 .33653 .82164 .33537 Metetra
.664 .741 .907 r
.82164 .33537 .82245 .33653 .82885 .33445 .82805 .33329 Metetra
.664 .741 .907 r
.82805 .33329 .82885 .33445 .83527 .33237 .83446 .33121 Metetra
.664 .741 .907 r
.83446 .33121 .83527 .33237 .8417 .33029 .8409 .32912 Metetra
.664 .741 .907 r
.8409 .32912 .8417 .33029 .84814 .3282 .84734 .32703 Metetra
.664 .741 .907 r
.84734 .32703 .84814 .3282 .8546 .3261 .8538 .32493 Metetra
.664 .741 .907 r
.8538 .32493 .8546 .3261 .86107 .324 .86028 .32283 Metetra
.664 .741 .907 r
.86028 .32283 .86107 .324 .86755 .3219 .86676 .32072 Metetra
.664 .741 .907 r
.86676 .32072 .86755 .3219 .87405 .31979 .87327 .31861 Metetra
.664 .741 .907 r
.87327 .31861 .87405 .31979 .88057 .31767 .87979 .31649 Metetra
.664 .741 .907 r
.87979 .31649 .88057 .31767 .8871 .31556 .88632 .31437 Metetra
.664 .741 .907 r
.88632 .31437 .8871 .31556 .89364 .31343 .89286 .31225 Metetra
.664 .741 .907 r
.30227 .50274 .3033 .5037 .30861 .50197 .30758 .50101 Metetra
.664 .741 .907 r
.30758 .50101 .30861 .50197 .31393 .50025 .3129 .49928 Metetra
.664 .741 .907 r
.3129 .49928 .31393 .50025 .31926 .49852 .31824 .49755 Metetra
.664 .741 .907 r
.31824 .49755 .31926 .49852 .3246 .49678 .32358 .49581 Metetra
.664 .741 .907 r
.32358 .49581 .3246 .49678 .32995 .49504 .32893 .49407 Metetra
.664 .741 .907 r
.32893 .49407 .32995 .49504 .33531 .4933 .3343 .49233 Metetra
.664 .741 .907 r
.3343 .49233 .33531 .4933 .34069 .49156 .33967 .49058 Metetra
.664 .741 .907 r
.33967 .49058 .34069 .49156 .34607 .48981 .34506 .48883 Metetra
.664 .741 .907 r
.34506 .48883 .34607 .48981 .35147 .48806 .35045 .48708 Metetra
.664 .741 .907 r
.35045 .48708 .35147 .48806 .35687 .4863 .35586 .48532 Metetra
.664 .741 .907 r
.35586 .48532 .35687 .4863 .36229 .48454 .36128 .48356 Metetra
.664 .741 .907 r
.36128 .48356 .36229 .48454 .36772 .48278 .36671 .48179 Metetra
.664 .741 .907 r
.36671 .48179 .36772 .48278 .37316 .48101 .37215 .48003 Metetra
.664 .741 .907 r
.37215 .48003 .37316 .48101 .37758 .50245 .3776 .47825 Metetra
.567 .367 .57 r
.3776 .47825 .37758 .50245 .38407 .47747 .38307 .47648 Metetra
.664 .741 .907 r
.38307 .47648 .38407 .47747 .38954 .47569 .38854 .4747 Metetra
.664 .741 .907 r
.38854 .4747 .38954 .47569 .39502 .47391 .39403 .47292 Metetra
.664 .741 .907 r
.39403 .47292 .39502 .47391 .40052 .47213 .39953 .47113 Metetra
.664 .741 .907 r
.39953 .47113 .40052 .47213 .40602 .47034 .40503 .46934 Metetra
.664 .741 .907 r
.40503 .46934 .40602 .47034 .41154 .46855 .41055 .46755 Metetra
.664 .741 .907 r
.41055 .46755 .41154 .46855 .41707 .46675 .41608 .46575 Metetra
.664 .741 .907 r
.41608 .46575 .41707 .46675 .42261 .46495 .42163 .46395 Metetra
.664 .741 .907 r
.42163 .46395 .42261 .46495 .42816 .46315 .42718 .46214 Metetra
.664 .741 .907 r
.42718 .46214 .42816 .46315 .43372 .46134 .43274 .46034 Metetra
.664 .741 .907 r
.43274 .46034 .43372 .46134 .4393 .45953 .43832 .45852 Metetra
.664 .741 .907 r
.43832 .45852 .4393 .45953 .44488 .45772 .44391 .45671 Metetra
.664 .741 .907 r
.44391 .45671 .44488 .45772 .45048 .4559 .44951 .45489 Metetra
.586 .715 .932 r
.44951 .45489 .45048 .4559 .45609 .45408 .4551 .45406 Metetra
.95 .671 .473 r
.4551 .45406 .45609 .45408 .46171 .45226 .45761 .6112 Metetra
.591 .368 .546 r
.45761 .6112 .46171 .45226 .46562 .54836 .46239 .67234 Metetra
.267 .11 .474 r
.46239 .67234 .46562 .54836 .47299 .44859 .47202 .44757 Metetra
.664 .741 .907 r
.47202 .44757 .47299 .44859 .47864 .44676 .47768 .44573 Metetra
.664 .741 .907 r
.47768 .44573 .47864 .44676 .48431 .44492 .48335 .44389 Metetra
.664 .741 .907 r
.48335 .44389 .48431 .44492 .48999 .44307 .48903 .44204 Metetra
.664 .741 .907 r
.48903 .44204 .48999 .44307 .49568 .44123 .49473 .44019 Metetra
.664 .741 .907 r
.49473 .44019 .49568 .44123 .50138 .43937 .50043 .43834 Metetra
.664 .741 .907 r
.50043 .43834 .50138 .43937 .5071 .43752 .50615 .43648 Metetra
.664 .741 .907 r
.50615 .43648 .5071 .43752 .51282 .43566 .51188 .43462 Metetra
.664 .741 .907 r
.51188 .43462 .51282 .43566 .51856 .43379 .51762 .43275 Metetra
.664 .741 .907 r
.51762 .43275 .51856 .43379 .52431 .43193 .52337 .43088 Metetra
.664 .741 .907 r
.52337 .43088 .52431 .43193 .53008 .43006 .52914 .42901 Metetra
.664 .741 .907 r
.52914 .42901 .53008 .43006 .53585 .42818 .53491 .42713 Metetra
.664 .741 .907 r
.53491 .42713 .53585 .42818 .54164 .4263 .5407 .42525 Metetra
.664 .741 .907 r
.5407 .42525 .54164 .4263 .54744 .42442 .5465 .42337 Metetra
.664 .741 .907 r
.5465 .42337 .54744 .42442 .55325 .42253 .55232 .42148 Metetra
.664 .741 .907 r
.55232 .42148 .55325 .42253 .55907 .42064 .55814 .41958 Metetra
.664 .741 .907 r
.55814 .41958 .55907 .42064 .56491 .41874 .56398 .41769 Metetra
.664 .741 .907 r
.56398 .41769 .56491 .41874 .57076 .41685 .56983 .41578 Metetra
.664 .741 .907 r
.56983 .41578 .57076 .41685 .57662 .41494 .5757 .41388 Metetra
.664 .741 .907 r
.5757 .41388 .57662 .41494 .58249 .41304 .58157 .41197 Metetra
.664 .741 .907 r
.58157 .41197 .58249 .41304 .58838 .41112 .58746 .41006 Metetra
.664 .741 .907 r
.58746 .41006 .58838 .41112 .59427 .40921 .59336 .40814 Metetra
.664 .741 .907 r
.59336 .40814 .59427 .40921 .60018 .40729 .59927 .40622 Metetra
.664 .741 .907 r
.59927 .40622 .60018 .40729 .60611 .40537 .6052 .40429 Metetra
.664 .741 .907 r
.6052 .40429 .60611 .40537 .61204 .40344 .61114 .40236 Metetra
.664 .741 .907 r
.61114 .40236 .61204 .40344 .61799 .40151 .61709 .40043 Metetra
.664 .741 .907 r
.61709 .40043 .61799 .40151 .62395 .39957 .62305 .39849 Metetra
.664 .741 .907 r
.62305 .39849 .62395 .39957 .62993 .39763 .62903 .39655 Metetra
.664 .741 .907 r
.62903 .39655 .62993 .39763 .63591 .39569 .63502 .3946 Metetra
.664 .741 .907 r
.63502 .3946 .63591 .39569 .64191 .39374 .64102 .39265 Metetra
.664 .741 .907 r
.64102 .39265 .64191 .39374 .64792 .39179 .64703 .3907 Metetra
.664 .741 .907 r
.64703 .3907 .64792 .39179 .65395 .38983 .65306 .38874 Metetra
.664 .741 .907 r
.65306 .38874 .65395 .38983 .65999 .38787 .6591 .38677 Metetra
.664 .741 .907 r
.6591 .38677 .65999 .38787 .66604 .38591 .66515 .38481 Metetra
.664 .741 .907 r
.66515 .38481 .66604 .38591 .6721 .38394 .67122 .38284 Metetra
.664 .741 .907 r
.67122 .38284 .6721 .38394 .67818 .38196 .6773 .38086 Metetra
.664 .741 .907 r
.6773 .38086 .67818 .38196 .68427 .37999 .68339 .37888 Metetra
.89 .485 .057 r
.68339 .37888 .68427 .37999 .69037 .378 .69059 .39819 Metetra
.418 .214 .495 r
.69059 .39819 .69037 .378 .69649 .37602 .69562 .37491 Metetra
.938 .571 .193 r
.69562 .37491 .69649 .37602 .70593 .43367 .70356 .40558 Metetra
.661 .436 .567 r
.70356 .40558 .70593 .43367 .70876 .37203 .70789 .37092 Metetra
.664 .741 .907 r
.70789 .37092 .70876 .37203 .71491 .37003 .71405 .36892 Metetra
.664 .741 .907 r
.71405 .36892 .71491 .37003 .72108 .36803 .72023 .36691 Metetra
.664 .741 .907 r
.72023 .36691 .72108 .36803 .72727 .36602 .72641 .3649 Metetra
.664 .741 .907 r
.72641 .3649 .72727 .36602 .73346 .36401 .73261 .36289 Metetra
.664 .741 .907 r
.73261 .36289 .73346 .36401 .73967 .36199 .73882 .36087 Metetra
.664 .741 .907 r
.73882 .36087 .73967 .36199 .74589 .35997 .74505 .35884 Metetra
.664 .741 .907 r
.74505 .35884 .74589 .35997 .75213 .35795 .75129 .35682 Metetra
.664 .741 .907 r
.75129 .35682 .75213 .35795 .75838 .35592 .75754 .35478 Metetra
.664 .741 .907 r
.75754 .35478 .75838 .35592 .76465 .35388 .76381 .35275 Metetra
.664 .741 .907 r
.76381 .35275 .76465 .35388 .77092 .35184 .77009 .35071 Metetra
.664 .741 .907 r
.77009 .35071 .77092 .35184 .77722 .3498 .77638 .34866 Metetra
.664 .741 .907 r
.77638 .34866 .77722 .3498 .78352 .34775 .78269 .34661 Metetra
.664 .741 .907 r
.78269 .34661 .78352 .34775 .78984 .3457 .78901 .34456 Metetra
.664 .741 .907 r
.78901 .34456 .78984 .3457 .79617 .34365 .79535 .3425 Metetra
.664 .741 .907 r
.79535 .3425 .79617 .34365 .80252 .34158 .8017 .34043 Metetra
.664 .741 .907 r
.8017 .34043 .80252 .34158 .80888 .33952 .80806 .33836 Metetra
.664 .741 .907 r
.80806 .33836 .80888 .33952 .81526 .33745 .81444 .33629 Metetra
.664 .741 .907 r
.81444 .33629 .81526 .33745 .82164 .33537 .82083 .33421 Metetra
.664 .741 .907 r
.82083 .33421 .82164 .33537 .82805 .33329 .82724 .33213 Metetra
.664 .741 .907 r
.82724 .33213 .82805 .33329 .83446 .33121 .83366 .33005 Metetra
.664 .741 .907 r
.83366 .33005 .83446 .33121 .8409 .32912 .84009 .32796 Metetra
.664 .741 .907 r
.84009 .32796 .8409 .32912 .84734 .32703 .84654 .32586 Metetra
.664 .741 .907 r
.84654 .32586 .84734 .32703 .8538 .32493 .85301 .32376 Metetra
.664 .741 .907 r
.85301 .32376 .8538 .32493 .86028 .32283 .85948 .32165 Metetra
.664 .741 .907 r
.85948 .32165 .86028 .32283 .86676 .32072 .86598 .31954 Metetra
.664 .741 .907 r
.86598 .31954 .86676 .32072 .87327 .31861 .87248 .31743 Metetra
.664 .741 .907 r
.87248 .31743 .87327 .31861 .87979 .31649 .879 .31531 Metetra
.664 .741 .907 r
.879 .31531 .87979 .31649 .88632 .31437 .88554 .31319 Metetra
.664 .741 .907 r
.88554 .31319 .88632 .31437 .89286 .31225 .89209 .31106 Metetra
.664 .741 .907 r
.30124 .50177 .30227 .50274 .30758 .50101 .30655 .50005 Metetra
.664 .741 .907 r
.30655 .50005 .30758 .50101 .3129 .49928 .31188 .49832 Metetra
.664 .741 .907 r
.31188 .49832 .3129 .49928 .31824 .49755 .31721 .49658 Metetra
.664 .741 .907 r
.31721 .49658 .31824 .49755 .32358 .49581 .32256 .49484 Metetra
.664 .741 .907 r
.32256 .49484 .32358 .49581 .32893 .49407 .32791 .4931 Metetra
.664 .741 .907 r
.32791 .4931 .32893 .49407 .3343 .49233 .33328 .49136 Metetra
.664 .741 .907 r
.33328 .49136 .3343 .49233 .33967 .49058 .33865 .48961 Metetra
.664 .741 .907 r
.33865 .48961 .33967 .49058 .34506 .48883 .34404 .48785 Metetra
.928 .547 .245 r
.34404 .48785 .34506 .48883 .35045 .48708 .34856 .50282 Metetra
.522 .287 .5 r
.34856 .50282 .35045 .48708 .35586 .48532 .3541 .4989 Metetra
.377 .16 .453 r
.3541 .4989 .35586 .48532 .36128 .48356 .36027 .48258 Metetra
.664 .741 .907 r
.36027 .48258 .36128 .48356 .36671 .48179 .36571 .48081 Metetra
.664 .741 .907 r
.36571 .48081 .36671 .48179 .37215 .48003 .37115 .47904 Metetra
.664 .741 .907 r
.37115 .47904 .37215 .48003 .3776 .47825 .3766 .47727 Metetra
.664 .741 .907 r
.3766 .47727 .3776 .47825 .38307 .47648 .38207 .47549 Metetra
.664 .741 .907 r
.38207 .47549 .38307 .47648 .38854 .4747 .38754 .47371 Metetra
.664 .741 .907 r
.38754 .47371 .38854 .4747 .39403 .47292 .39303 .47192 Metetra
.664 .741 .907 r
.39303 .47192 .39403 .47292 .39953 .47113 .39853 .47013 Metetra
.664 .741 .907 r
.39853 .47013 .39953 .47113 .40503 .46934 .40404 .46834 Metetra
.664 .741 .907 r
.40404 .46834 .40503 .46934 .41055 .46755 .40956 .46655 Metetra
.664 .741 .907 r
.40956 .46655 .41055 .46755 .41608 .46575 .4151 .46475 Metetra
.664 .741 .907 r
.4151 .46475 .41608 .46575 .42163 .46395 .42064 .46294 Metetra
.664 .741 .907 r
.42064 .46294 .42163 .46395 .42718 .46214 .4262 .46114 Metetra
.664 .741 .907 r
.4262 .46114 .42718 .46214 .43274 .46034 .43176 .45933 Metetra
.664 .741 .907 r
.43176 .45933 .43274 .46034 .43832 .45852 .43734 .45751 Metetra
.664 .741 .907 r
.43734 .45751 .43832 .45852 .44391 .45671 .44293 .45569 Metetra
.664 .741 .907 r
.44293 .45569 .44391 .45671 .44951 .45489 .44853 .45387 Metetra
.664 .741 .907 r
.44853 .45387 .44951 .45489 .4551 .45406 .45415 .45205 Metetra
.961 .682 .459 r
.45415 .45205 .4551 .45406 .45761 .6112 .45669 .60519 Metetra
.836 .609 .595 r
.45669 .60519 .45761 .6112 .46239 .67234 .46324 .56757 Metetra
.661 .43 .56 r
.46324 .56757 .46239 .67234 .47202 .44757 .47106 .44655 Metetra
.664 .741 .907 r
.47106 .44655 .47202 .44757 .47768 .44573 .47672 .4447 Metetra
.664 .741 .907 r
.47672 .4447 .47768 .44573 .48335 .44389 .48239 .44286 Metetra
.664 .741 .907 r
.48239 .44286 .48335 .44389 .48903 .44204 .48807 .44101 Metetra
.664 .741 .907 r
.48807 .44101 .48903 .44204 .49473 .44019 .49377 .43916 Metetra
.664 .741 .907 r
.49377 .43916 .49473 .44019 .50043 .43834 .49948 .4373 Metetra
.664 .741 .907 r
.49948 .4373 .50043 .43834 .50615 .43648 .5052 .43544 Metetra
.664 .741 .907 r
.5052 .43544 .50615 .43648 .51188 .43462 .51093 .43358 Metetra
.664 .741 .907 r
.51093 .43358 .51188 .43462 .51762 .43275 .51667 .43171 Metetra
.664 .741 .907 r
.51667 .43171 .51762 .43275 .52337 .43088 .52243 .42984 Metetra
.664 .741 .907 r
.52243 .42984 .52337 .43088 .52914 .42901 .52819 .42796 Metetra
.664 .741 .907 r
.52819 .42796 .52914 .42901 .53491 .42713 .53397 .42608 Metetra
.664 .741 .907 r
.53397 .42608 .53491 .42713 .5407 .42525 .53977 .4242 Metetra
.664 .741 .907 r
.53977 .4242 .5407 .42525 .5465 .42337 .54557 .42231 Metetra
.664 .741 .907 r
.54557 .42231 .5465 .42337 .55232 .42148 .55139 .42042 Metetra
.664 .741 .907 r
.55139 .42042 .55232 .42148 .55814 .41958 .55721 .41853 Metetra
.664 .741 .907 r
.55721 .41853 .55814 .41958 .56398 .41769 .56306 .41663 Metetra
.664 .741 .907 r
.56306 .41663 .56398 .41769 .56983 .41578 .56891 .41472 Metetra
.664 .741 .907 r
.56891 .41472 .56983 .41578 .5757 .41388 .57477 .41281 Metetra
.664 .741 .907 r
.57477 .41281 .5757 .41388 .58157 .41197 .58065 .4109 Metetra
.664 .741 .907 r
.58065 .4109 .58157 .41197 .58746 .41006 .58654 .40899 Metetra
.664 .741 .907 r
.58654 .40899 .58746 .41006 .59336 .40814 .59245 .40707 Metetra
.664 .741 .907 r
.59245 .40707 .59336 .40814 .59927 .40622 .59836 .40514 Metetra
.664 .741 .907 r
.59836 .40514 .59927 .40622 .6052 .40429 .60429 .40322 Metetra
.664 .741 .907 r
.60429 .40322 .6052 .40429 .61114 .40236 .61023 .40128 Metetra
.664 .741 .907 r
.61023 .40128 .61114 .40236 .61709 .40043 .61618 .39935 Metetra
.664 .741 .907 r
.61618 .39935 .61709 .40043 .62305 .39849 .62215 .39741 Metetra
.664 .741 .907 r
.62215 .39741 .62305 .39849 .62903 .39655 .62813 .39546 Metetra
.664 .741 .907 r
.62813 .39546 .62903 .39655 .63502 .3946 .63412 .39351 Metetra
.664 .741 .907 r
.63412 .39351 .63502 .3946 .64102 .39265 .64012 .39156 Metetra
.664 .741 .907 r
.64012 .39156 .64102 .39265 .64703 .3907 .64614 .3896 Metetra
.664 .741 .907 r
.64614 .3896 .64703 .3907 .65306 .38874 .65217 .38764 Metetra
.664 .741 .907 r
.65217 .38764 .65306 .38874 .6591 .38677 .65821 .38568 Metetra
.664 .741 .907 r
.65821 .38568 .6591 .38677 .66515 .38481 .66427 .38371 Metetra
.664 .741 .907 r
.66427 .38371 .66515 .38481 .67122 .38284 .67034 .38173 Metetra
.411 .625 .941 r
.67034 .38173 .67122 .38284 .6773 .38086 .67656 .38261 Metetra
.119 0 .052 r
.67656 .38261 .6773 .38086 .68339 .37888 .68252 .37777 Metetra
.956 .61 .265 r
.68252 .37777 .68339 .37888 .69059 .39819 .69089 .41999 Metetra
.265 .101 .463 r
.69089 .41999 .69059 .39819 .69562 .37491 .69475 .3738 Metetra
.664 .741 .907 r
.69475 .3738 .69562 .37491 .70356 .40558 .70088 .3718 Metetra
.564 .361 .563 r
.70088 .3718 .70356 .40558 .70789 .37092 .70703 .3698 Metetra
.664 .741 .907 r
.70703 .3698 .70789 .37092 .71405 .36892 .71319 .3678 Metetra
.664 .741 .907 r
.71319 .3678 .71405 .36892 .72023 .36691 .71937 .36579 Metetra
.664 .741 .907 r
.71937 .36579 .72023 .36691 .72641 .3649 .72555 .36378 Metetra
.664 .741 .907 r
.72555 .36378 .72641 .3649 .73261 .36289 .73176 .36176 Metetra
.664 .741 .907 r
.73176 .36176 .73261 .36289 .73882 .36087 .73797 .35974 Metetra
.664 .741 .907 r
.73797 .35974 .73882 .36087 .74505 .35884 .7442 .35771 Metetra
.664 .741 .907 r
.7442 .35771 .74505 .35884 .75129 .35682 .75044 .35568 Metetra
.664 .741 .907 r
.75044 .35568 .75129 .35682 .75754 .35478 .7567 .35365 Metetra
.664 .741 .907 r
.7567 .35365 .75754 .35478 .76381 .35275 .76297 .35161 Metetra
.664 .741 .907 r
.76297 .35161 .76381 .35275 .77009 .35071 .76925 .34957 Metetra
.664 .741 .907 r
.76925 .34957 .77009 .35071 .77638 .34866 .77555 .34752 Metetra
.664 .741 .907 r
.77555 .34752 .77638 .34866 .78269 .34661 .78186 .34546 Metetra
.664 .741 .907 r
.78186 .34546 .78269 .34661 .78901 .34456 .78819 .34341 Metetra
.664 .741 .907 r
.78819 .34341 .78901 .34456 .79535 .3425 .79453 .34135 Metetra
.664 .741 .907 r
.79453 .34135 .79535 .3425 .8017 .34043 .80088 .33928 Metetra
.664 .741 .907 r
.80088 .33928 .8017 .34043 .80806 .33836 .80725 .33721 Metetra
.664 .741 .907 r
.80725 .33721 .80806 .33836 .81444 .33629 .81363 .33513 Metetra
.664 .741 .907 r
.81363 .33513 .81444 .33629 .82083 .33421 .82002 .33305 Metetra
.664 .741 .907 r
.82002 .33305 .82083 .33421 .82724 .33213 .82643 .33097 Metetra
.664 .741 .907 r
.82643 .33097 .82724 .33213 .83366 .33005 .83285 .32888 Metetra
.664 .741 .907 r
.83285 .32888 .83366 .33005 .84009 .32796 .83929 .32679 Metetra
.664 .741 .907 r
.83929 .32679 .84009 .32796 .84654 .32586 .84574 .32469 Metetra
.664 .741 .907 r
.84574 .32469 .84654 .32586 .85301 .32376 .85221 .32259 Metetra
.664 .741 .907 r
.85221 .32259 .85301 .32376 .85948 .32165 .85869 .32048 Metetra
.664 .741 .907 r
.85869 .32048 .85948 .32165 .86598 .31954 .86519 .31837 Metetra
.664 .741 .907 r
.86519 .31837 .86598 .31954 .87248 .31743 .87169 .31625 Metetra
.664 .741 .907 r
.87169 .31625 .87248 .31743 .879 .31531 .87822 .31413 Metetra
.664 .741 .907 r
.87822 .31413 .879 .31531 .88554 .31319 .88476 .312 Metetra
.664 .741 .907 r
.88476 .312 .88554 .31319 .89209 .31106 .89131 .30987 Metetra
.664 .741 .907 r
.30021 .50081 .30124 .50177 .30655 .50005 .30552 .49908 Metetra
.664 .741 .907 r
.30552 .49908 .30655 .50005 .31188 .49832 .31085 .49735 Metetra
.664 .741 .907 r
.31085 .49735 .31188 .49832 .31721 .49658 .31619 .49561 Metetra
.664 .741 .907 r
.31619 .49561 .31721 .49658 .32256 .49484 .32153 .49387 Metetra
.664 .741 .907 r
.32153 .49387 .32256 .49484 .32791 .4931 .32689 .49213 Metetra
.664 .741 .907 r
.32689 .49213 .32791 .4931 .33328 .49136 .33226 .49038 Metetra
.664 .741 .907 r
.33226 .49038 .33328 .49136 .33865 .48961 .33764 .48863 Metetra
.664 .741 .907 r
.33764 .48863 .33865 .48961 .34404 .48785 .34303 .48688 Metetra
.948 .651 .443 r
.34303 .48688 .34404 .48785 .34856 .50282 .34595 .53162 Metetra
.278 .098 .448 r
.34595 .53162 .34856 .50282 .3541 .4989 .35384 .48336 Metetra
.572 .381 .583 r
.35384 .48336 .3541 .4989 .36027 .48258 .35926 .48159 Metetra
.664 .741 .907 r
.35926 .48159 .36027 .48258 .36571 .48081 .3647 .47982 Metetra
.664 .741 .907 r
.3647 .47982 .36571 .48081 .37115 .47904 .37014 .47805 Metetra
.664 .741 .907 r
.37014 .47805 .37115 .47904 .3766 .47727 .3756 .47627 Metetra
.664 .741 .907 r
.3756 .47627 .3766 .47727 .38207 .47549 .38107 .47449 Metetra
.664 .741 .907 r
.38107 .47449 .38207 .47549 .38754 .47371 .38655 .47271 Metetra
.664 .741 .907 r
.38655 .47271 .38754 .47371 .39303 .47192 .39204 .47092 Metetra
.664 .741 .907 r
.39204 .47092 .39303 .47192 .39853 .47013 .39754 .46913 Metetra
.664 .741 .907 r
.39754 .46913 .39853 .47013 .40404 .46834 .40305 .46734 Metetra
.664 .741 .907 r
.40305 .46734 .40404 .46834 .40956 .46655 .40857 .46554 Metetra
.664 .741 .907 r
.40857 .46554 .40956 .46655 .4151 .46475 .41411 .46374 Metetra
.664 .741 .907 r
.41411 .46374 .4151 .46475 .42064 .46294 .41965 .46194 Metetra
.664 .741 .907 r
.41965 .46194 .42064 .46294 .4262 .46114 .42521 .46013 Metetra
.664 .741 .907 r
.42521 .46013 .4262 .46114 .43176 .45933 .43078 .45831 Metetra
.664 .741 .907 r
.43078 .45831 .43176 .45933 .43734 .45751 .43636 .4565 Metetra
.664 .741 .907 r
.43636 .4565 .43734 .45751 .44293 .45569 .44196 .45468 Metetra
.664 .741 .907 r
.44196 .45468 .44293 .45569 .44853 .45387 .44756 .45285 Metetra
.664 .741 .907 r
.44756 .45285 .44853 .45387 .45415 .45205 .45318 .45103 Metetra
.957 .661 .432 r
.45318 .45103 .45415 .45205 .45669 .60519 .45741 .518 Metetra
.552 .344 .551 r
.45741 .518 .45669 .60519 .46324 .56757 .46307 .52142 Metetra
.69 .458 .566 r
.46307 .52142 .46324 .56757 .47106 .44655 .47009 .44552 Metetra
.664 .741 .907 r
.47009 .44552 .47106 .44655 .47672 .4447 .47575 .44368 Metetra
.664 .741 .907 r
.47575 .44368 .47672 .4447 .48239 .44286 .48143 .44183 Metetra
.664 .741 .907 r
.48143 .44183 .48239 .44286 .48807 .44101 .48712 .43998 Metetra
.664 .741 .907 r
.48712 .43998 .48807 .44101 .49377 .43916 .49281 .43812 Metetra
.664 .741 .907 r
.49281 .43812 .49377 .43916 .49948 .4373 .49852 .43627 Metetra
.664 .741 .907 r
.49852 .43627 .49948 .4373 .5052 .43544 .50424 .4344 Metetra
.664 .741 .907 r
.50424 .4344 .5052 .43544 .51093 .43358 .50998 .43254 Metetra
.664 .741 .907 r
.50998 .43254 .51093 .43358 .51667 .43171 .51572 .43067 Metetra
.664 .741 .907 r
.51572 .43067 .51667 .43171 .52243 .42984 .52148 .42879 Metetra
.664 .741 .907 r
.52148 .42879 .52243 .42984 .52819 .42796 .52725 .42692 Metetra
.664 .741 .907 r
.52725 .42692 .52819 .42796 .53397 .42608 .53303 .42503 Metetra
.664 .741 .907 r
.53303 .42503 .53397 .42608 .53977 .4242 .53883 .42315 Metetra
.664 .741 .907 r
.53883 .42315 .53977 .4242 .54557 .42231 .54463 .42126 Metetra
.664 .741 .907 r
.54463 .42126 .54557 .42231 .55139 .42042 .55045 .41936 Metetra
.664 .741 .907 r
.55045 .41936 .55139 .42042 .55721 .41853 .55628 .41747 Metetra
.88 .458 .046 r
.55628 .41747 .55721 .41853 .56306 .41663 .56231 .4318 Metetra
.399 .188 .474 r
.56231 .4318 .56306 .41663 .56891 .41472 .56798 .41366 Metetra
.664 .741 .907 r
.56798 .41366 .56891 .41472 .57477 .41281 .57385 .41175 Metetra
.664 .741 .907 r
.57385 .41175 .57477 .41281 .58065 .4109 .57973 .40984 Metetra
.664 .741 .907 r
.57973 .40984 .58065 .4109 .58654 .40899 .58562 .40792 Metetra
.664 .741 .907 r
.58562 .40792 .58654 .40899 .59245 .40707 .59153 .406 Metetra
.664 .741 .907 r
.59153 .406 .59245 .40707 .59836 .40514 .59745 .40407 Metetra
.664 .741 .907 r
.59745 .40407 .59836 .40514 .60429 .40322 .60338 .40214 Metetra
.664 .741 .907 r
.60338 .40214 .60429 .40322 .61023 .40128 .60932 .4002 Metetra
.664 .741 .907 r
.60932 .4002 .61023 .40128 .61618 .39935 .61528 .39827 Metetra
.664 .741 .907 r
.61528 .39827 .61618 .39935 .62215 .39741 .62125 .39632 Metetra
.664 .741 .907 r
.62125 .39632 .62215 .39741 .62813 .39546 .62723 .39438 Metetra
.664 .741 .907 r
.62723 .39438 .62813 .39546 .63412 .39351 .63322 .39243 Metetra
.664 .741 .907 r
.63322 .39243 .63412 .39351 .64012 .39156 .63923 .39047 Metetra
.664 .741 .907 r
.63923 .39047 .64012 .39156 .64614 .3896 .64525 .38851 Metetra
.664 .741 .907 r
.64525 .38851 .64614 .3896 .65217 .38764 .65128 .38655 Metetra
.664 .741 .907 r
.65128 .38655 .65217 .38764 .65821 .38568 .65733 .38458 Metetra
.664 .741 .907 r
.65733 .38458 .65821 .38568 .66427 .38371 .66339 .38261 Metetra
.664 .741 .907 r
.66339 .38261 .66427 .38371 .67034 .38173 .66946 .38063 Metetra
.664 .741 .907 r
.66946 .38063 .67034 .38173 .67656 .38261 .67554 .37865 Metetra
.614 .491 .689 r
.67554 .37865 .67656 .38261 .68252 .37777 .68164 .37667 Metetra
.664 .741 .907 r
.68164 .37667 .68252 .37777 .69089 .41999 .68775 .37468 Metetra
.562 .356 .558 r
.68775 .37468 .69089 .41999 .69475 .3738 .69388 .37268 Metetra
.664 .741 .907 r
.69388 .37268 .69475 .3738 .70088 .3718 .70001 .37069 Metetra
.664 .741 .907 r
.70001 .37069 .70088 .3718 .70703 .3698 .70616 .36868 Metetra
.664 .741 .907 r
.70616 .36868 .70703 .3698 .71319 .3678 .71233 .36668 Metetra
.664 .741 .907 r
.71233 .36668 .71319 .3678 .71937 .36579 .71851 .36467 Metetra
.664 .741 .907 r
.71851 .36467 .71937 .36579 .72555 .36378 .7247 .36265 Metetra
.664 .741 .907 r
.7247 .36265 .72555 .36378 .73176 .36176 .7309 .36063 Metetra
.664 .741 .907 r
.7309 .36063 .73176 .36176 .73797 .35974 .73712 .35861 Metetra
.664 .741 .907 r
.73712 .35861 .73797 .35974 .7442 .35771 .74335 .35658 Metetra
.664 .741 .907 r
.74335 .35658 .7442 .35771 .75044 .35568 .7496 .35455 Metetra
.664 .741 .907 r
.7496 .35455 .75044 .35568 .7567 .35365 .75586 .35251 Metetra
.664 .741 .907 r
.75586 .35251 .7567 .35365 .76297 .35161 .76213 .35047 Metetra
.664 .741 .907 r
.76213 .35047 .76297 .35161 .76925 .34957 .76842 .34842 Metetra
.664 .741 .907 r
.76842 .34842 .76925 .34957 .77555 .34752 .77472 .34637 Metetra
.664 .741 .907 r
.77472 .34637 .77555 .34752 .78186 .34546 .78103 .34432 Metetra
.664 .741 .907 r
.78103 .34432 .78186 .34546 .78819 .34341 .78736 .34226 Metetra
.664 .741 .907 r
.78736 .34226 .78819 .34341 .79453 .34135 .7937 .34019 Metetra
.664 .741 .907 r
.7937 .34019 .79453 .34135 .80088 .33928 .80006 .33813 Metetra
.664 .741 .907 r
.80006 .33813 .80088 .33928 .80725 .33721 .80643 .33605 Metetra
.664 .741 .907 r
.80643 .33605 .80725 .33721 .81363 .33513 .81281 .33397 Metetra
.664 .741 .907 r
.81281 .33397 .81363 .33513 .82002 .33305 .81921 .33189 Metetra
.664 .741 .907 r
.81921 .33189 .82002 .33305 .82643 .33097 .82562 .32981 Metetra
.664 .741 .907 r
.82562 .32981 .82643 .33097 .83285 .32888 .83205 .32771 Metetra
.664 .741 .907 r
.83205 .32771 .83285 .32888 .83929 .32679 .83849 .32562 Metetra
.664 .741 .907 r
.83849 .32562 .83929 .32679 .84574 .32469 .84494 .32352 Metetra
.664 .741 .907 r
.84494 .32352 .84574 .32469 .85221 .32259 .85141 .32141 Metetra
.664 .741 .907 r
.85141 .32141 .85221 .32259 .85869 .32048 .8579 .3193 Metetra
.664 .741 .907 r
.8579 .3193 .85869 .32048 .86519 .31837 .86439 .31719 Metetra
.664 .741 .907 r
.86439 .31719 .86519 .31837 .87169 .31625 .87091 .31507 Metetra
.664 .741 .907 r
.87091 .31507 .87169 .31625 .87822 .31413 .87743 .31294 Metetra
.664 .741 .907 r
.87743 .31294 .87822 .31413 .88476 .312 .88398 .31081 Metetra
.664 .741 .907 r
.88398 .31081 .88476 .312 .89131 .30987 .89053 .30868 Metetra
.664 .741 .907 r
.29918 .49985 .30021 .50081 .30552 .49908 .30449 .49812 Metetra
.664 .741 .907 r
.30449 .49812 .30552 .49908 .31085 .49735 .30982 .49638 Metetra
.664 .741 .907 r
.30982 .49638 .31085 .49735 .31619 .49561 .31516 .49464 Metetra
.664 .741 .907 r
.31516 .49464 .31619 .49561 .32153 .49387 .32051 .4929 Metetra
.664 .741 .907 r
.32051 .4929 .32153 .49387 .32689 .49213 .32587 .49115 Metetra
.664 .741 .907 r
.32587 .49115 .32689 .49213 .33226 .49038 .33124 .4894 Metetra
.664 .741 .907 r
.33124 .4894 .33226 .49038 .33764 .48863 .33662 .48765 Metetra
.664 .741 .907 r
.33662 .48765 .33764 .48863 .34303 .48688 .34201 .4859 Metetra
.947 .659 .461 r
.34201 .4859 .34303 .48688 .34595 .53162 .34425 .54302 Metetra
.775 .702 .162 r
.34425 .54302 .34595 .53162 .35384 .48336 .35283 .48237 Metetra
.664 .741 .907 r
.35283 .48237 .35384 .48336 .35926 .48159 .35825 .4806 Metetra
.664 .741 .907 r
.35825 .4806 .35926 .48159 .3647 .47982 .36369 .47883 Metetra
.664 .741 .907 r
.36369 .47883 .3647 .47982 .37014 .47805 .36914 .47706 Metetra
.664 .741 .907 r
.36914 .47706 .37014 .47805 .3756 .47627 .3746 .47528 Metetra
.664 .741 .907 r
.3746 .47528 .3756 .47627 .38107 .47449 .38006 .4735 Metetra
.664 .741 .907 r
.38006 .4735 .38107 .47449 .38655 .47271 .38555 .47172 Metetra
.664 .741 .907 r
.38555 .47172 .38655 .47271 .39204 .47092 .39104 .46993 Metetra
.664 .741 .907 r
.39104 .46993 .39204 .47092 .39754 .46913 .39654 .46813 Metetra
.664 .741 .907 r
.39654 .46813 .39754 .46913 .40305 .46734 .40206 .46634 Metetra
.664 .741 .907 r
.40206 .46634 .40305 .46734 .40857 .46554 .40758 .46454 Metetra
.664 .741 .907 r
.40758 .46454 .40857 .46554 .41411 .46374 .41312 .46273 Metetra
.664 .741 .907 r
.41312 .46273 .41411 .46374 .41965 .46194 .41867 .46093 Metetra
.664 .741 .907 r
.41867 .46093 .41965 .46194 .42521 .46013 .42423 .45912 Metetra
.664 .741 .907 r
.42423 .45912 .42521 .46013 .43078 .45831 .4298 .4573 Metetra
.664 .741 .907 r
.4298 .4573 .43078 .45831 .43636 .4565 .43538 .45548 Metetra
.664 .741 .907 r
.43538 .45548 .43636 .4565 .44196 .45468 .44098 .45366 Metetra
.664 .741 .907 r
.44098 .45366 .44196 .45468 .44756 .45285 .44658 .45183 Metetra
.664 .741 .907 r
.44658 .45183 .44756 .45285 .45318 .45103 .4522 .45 Metetra
.664 .741 .907 r
.4522 .45 .45318 .45103 .45741 .518 .45783 .44817 Metetra
.493 .297 .543 r
.45783 .44817 .45741 .518 .46307 .52142 .46274 .48549 Metetra
.657 .434 .569 r
.46274 .48549 .46307 .52142 .47009 .44552 .46913 .44449 Metetra
.664 .741 .907 r
.46913 .44449 .47009 .44552 .47575 .44368 .47479 .44265 Metetra
.664 .741 .907 r
.47479 .44265 .47575 .44368 .48143 .44183 .48047 .4408 Metetra
.664 .741 .907 r
.48047 .4408 .48143 .44183 .48712 .43998 .48615 .43895 Metetra
.957 .635 .368 r
.48615 .43895 .48712 .43998 .49281 .43812 .49144 .47823 Metetra
.415 .218 .502 r
.49144 .47823 .49281 .43812 .49852 .43627 .49757 .43523 Metetra
.664 .741 .907 r
.49757 .43523 .49852 .43627 .50424 .4344 .50329 .43336 Metetra
.664 .741 .907 r
.50329 .43336 .50424 .4344 .50998 .43254 .50903 .4315 Metetra
.664 .741 .907 r
.50903 .4315 .50998 .43254 .51572 .43067 .51478 .42962 Metetra
.664 .741 .907 r
.51478 .42962 .51572 .43067 .52148 .42879 .52054 .42775 Metetra
.664 .741 .907 r
.52054 .42775 .52148 .42879 .52725 .42692 .52631 .42587 Metetra
.664 .741 .907 r
.52631 .42587 .52725 .42692 .53303 .42503 .53209 .42398 Metetra
.664 .741 .907 r
.53209 .42398 .53303 .42503 .53883 .42315 .53789 .42209 Metetra
.664 .741 .907 r
.53789 .42209 .53883 .42315 .54463 .42126 .5437 .4202 Metetra
.664 .741 .907 r
.5437 .4202 .54463 .42126 .55045 .41936 .54952 .41831 Metetra
.664 .741 .907 r
.54952 .41831 .55045 .41936 .55628 .41747 .55535 .41641 Metetra
.664 .741 .907 r
.55535 .41641 .55628 .41747 .56231 .4318 .5612 .4145 Metetra
.571 .377 .58 r
.5612 .4145 .56231 .4318 .56798 .41366 .56706 .41259 Metetra
.664 .741 .907 r
.56706 .41259 .56798 .41366 .57385 .41175 .57293 .41068 Metetra
.664 .741 .907 r
.57293 .41068 .57385 .41175 .57973 .40984 .57881 .40877 Metetra
.664 .741 .907 r
.57881 .40877 .57973 .40984 .58562 .40792 .5847 .40685 Metetra
.664 .741 .907 r
.5847 .40685 .58562 .40792 .59153 .406 .59061 .40492 Metetra
.664 .741 .907 r
.59061 .40492 .59153 .406 .59745 .40407 .59653 .40299 Metetra
.664 .741 .907 r
.59653 .40299 .59745 .40407 .60338 .40214 .60247 .40106 Metetra
.664 .741 .907 r
.60247 .40106 .60338 .40214 .60932 .4002 .60841 .39912 Metetra
.664 .741 .907 r
.60841 .39912 .60932 .4002 .61528 .39827 .61437 .39718 Metetra
.664 .741 .907 r
.61437 .39718 .61528 .39827 .62125 .39632 .62034 .39524 Metetra
.664 .741 .907 r
.62034 .39524 .62125 .39632 .62723 .39438 .62633 .39329 Metetra
.664 .741 .907 r
.62633 .39329 .62723 .39438 .63322 .39243 .63232 .39134 Metetra
.664 .741 .907 r
.63232 .39134 .63322 .39243 .63923 .39047 .63833 .38938 Metetra
.664 .741 .907 r
.63833 .38938 .63923 .39047 .64525 .38851 .64435 .38742 Metetra
.664 .741 .907 r
.64435 .38742 .64525 .38851 .65128 .38655 .65039 .38545 Metetra
.664 .741 .907 r
.65039 .38545 .65128 .38655 .65733 .38458 .65644 .38348 Metetra
.664 .741 .907 r
.65644 .38348 .65733 .38458 .66339 .38261 .6625 .38151 Metetra
.664 .741 .907 r
.6625 .38151 .66339 .38261 .66946 .38063 .66857 .37953 Metetra
.664 .741 .907 r
.66857 .37953 .66946 .38063 .67554 .37865 .67466 .37754 Metetra
.664 .741 .907 r
.67466 .37754 .67554 .37865 .68164 .37667 .68076 .37556 Metetra
.664 .741 .907 r
.68076 .37556 .68164 .37667 .68775 .37468 .68688 .37357 Metetra
.664 .741 .907 r
.68688 .37357 .68775 .37468 .69388 .37268 .693 .37157 Metetra
.664 .741 .907 r
.693 .37157 .69388 .37268 .70001 .37069 .69914 .36957 Metetra
.664 .741 .907 r
.69914 .36957 .70001 .37069 .70616 .36868 .7053 .36757 Metetra
.664 .741 .907 r
.7053 .36757 .70616 .36868 .71233 .36668 .71147 .36556 Metetra
.664 .741 .907 r
.71147 .36556 .71233 .36668 .71851 .36467 .71765 .36354 Metetra
.664 .741 .907 r
.71765 .36354 .71851 .36467 .7247 .36265 .72384 .36153 Metetra
.664 .741 .907 r
.72384 .36153 .7247 .36265 .7309 .36063 .73005 .3595 Metetra
.664 .741 .907 r
.73005 .3595 .7309 .36063 .73712 .35861 .73627 .35748 Metetra
.664 .741 .907 r
.73627 .35748 .73712 .35861 .74335 .35658 .7425 .35545 Metetra
.664 .741 .907 r
.7425 .35545 .74335 .35658 .7496 .35455 .74875 .35341 Metetra
.664 .741 .907 r
.74875 .35341 .7496 .35455 .75586 .35251 .75501 .35137 Metetra
.664 .741 .907 r
.75501 .35137 .75586 .35251 .76213 .35047 .76129 .34933 Metetra
.664 .741 .907 r
.76129 .34933 .76213 .35047 .76842 .34842 .76758 .34728 Metetra
.664 .741 .907 r
.76758 .34728 .76842 .34842 .77472 .34637 .77388 .34523 Metetra
.664 .741 .907 r
.77388 .34523 .77472 .34637 .78103 .34432 .7802 .34317 Metetra
.664 .741 .907 r
.7802 .34317 .78103 .34432 .78736 .34226 .78653 .34111 Metetra
.664 .741 .907 r
.78653 .34111 .78736 .34226 .7937 .34019 .79287 .33904 Metetra
.664 .741 .907 r
.79287 .33904 .7937 .34019 .80006 .33813 .79923 .33697 Metetra
.664 .741 .907 r
.79923 .33697 .80006 .33813 .80643 .33605 .80561 .33489 Metetra
.664 .741 .907 r
.80561 .33489 .80643 .33605 .81281 .33397 .81199 .33281 Metetra
.664 .741 .907 r
.81199 .33281 .81281 .33397 .81921 .33189 .81839 .33073 Metetra
.664 .741 .907 r
.81839 .33073 .81921 .33189 .82562 .32981 .82481 .32864 Metetra
.664 .741 .907 r
.82481 .32864 .82562 .32981 .83205 .32771 .83124 .32654 Metetra
.664 .741 .907 r
.83124 .32654 .83205 .32771 .83849 .32562 .83768 .32445 Metetra
.664 .741 .907 r
.83768 .32445 .83849 .32562 .84494 .32352 .84414 .32234 Metetra
.664 .741 .907 r
.84414 .32234 .84494 .32352 .85141 .32141 .85061 .32023 Metetra
.664 .741 .907 r
.85061 .32023 .85141 .32141 .8579 .3193 .8571 .31812 Metetra
.664 .741 .907 r
.8571 .31812 .8579 .3193 .86439 .31719 .8636 .316 Metetra
.664 .741 .907 r
.8636 .316 .86439 .31719 .87091 .31507 .87012 .31388 Metetra
.664 .741 .907 r
.87012 .31388 .87091 .31507 .87743 .31294 .87665 .31175 Metetra
.664 .741 .907 r
.87665 .31175 .87743 .31294 .88398 .31081 .88319 .30962 Metetra
.664 .741 .907 r
.88319 .30962 .88398 .31081 .89053 .30868 .88975 .30749 Metetra
.664 .741 .907 r
.29814 .49888 .29918 .49985 .30449 .49812 .30346 .49715 Metetra
.664 .741 .907 r
.30346 .49715 .30449 .49812 .30982 .49638 .30879 .49541 Metetra
.664 .741 .907 r
.30879 .49541 .30982 .49638 .31516 .49464 .31413 .49367 Metetra
.664 .741 .907 r
.31413 .49367 .31516 .49464 .32051 .4929 .31948 .49193 Metetra
.664 .741 .907 r
.31948 .49193 .32051 .4929 .32587 .49115 .32484 .49018 Metetra
.664 .741 .907 r
.32484 .49018 .32587 .49115 .33124 .4894 .33022 .48843 Metetra
.664 .741 .907 r
.33022 .48843 .33124 .4894 .33662 .48765 .3356 .48667 Metetra
.664 .741 .907 r
.3356 .48667 .33662 .48765 .34201 .4859 .34099 .48491 Metetra
.947 .625 .388 r
.34099 .48491 .34201 .4859 .34425 .54302 .34481 .51265 Metetra
.651 .432 .573 r
.34481 .51265 .34425 .54302 .35283 .48237 .35181 .48139 Metetra
.664 .741 .907 r
.35181 .48139 .35283 .48237 .35825 .4806 .35724 .47962 Metetra
.664 .741 .907 r
.35724 .47962 .35825 .4806 .36369 .47883 .36268 .47785 Metetra
.664 .741 .907 r
.36268 .47785 .36369 .47883 .36914 .47706 .36813 .47607 Metetra
.664 .741 .907 r
.36813 .47607 .36914 .47706 .3746 .47528 .37359 .47429 Metetra
.664 .741 .907 r
.37359 .47429 .3746 .47528 .38006 .4735 .37906 .47251 Metetra
.664 .741 .907 r
.37906 .47251 .38006 .4735 .38555 .47172 .38454 .47072 Metetra
.664 .741 .907 r
.38454 .47072 .38555 .47172 .39104 .46993 .39004 .46893 Metetra
.664 .741 .907 r
.39004 .46893 .39104 .46993 .39654 .46813 .39554 .46713 Metetra
.664 .741 .907 r
.39554 .46713 .39654 .46813 .40206 .46634 .40106 .46533 Metetra
.664 .741 .907 r
.40106 .46533 .40206 .46634 .40758 .46454 .40659 .46353 Metetra
.664 .741 .907 r
.40659 .46353 .40758 .46454 .41312 .46273 .41213 .46173 Metetra
.664 .741 .907 r
.41213 .46173 .41312 .46273 .41867 .46093 .41768 .45992 Metetra
.664 .741 .907 r
.41768 .45992 .41867 .46093 .42423 .45912 .42324 .4581 Metetra
.664 .741 .907 r
.42324 .4581 .42423 .45912 .4298 .4573 .42882 .45629 Metetra
.664 .741 .907 r
.42882 .45629 .4298 .4573 .43538 .45548 .4344 .45447 Metetra
.664 .741 .907 r
.4344 .45447 .43538 .45548 .44098 .45366 .44 .45264 Metetra
.664 .741 .907 r
.44 .45264 .44098 .45366 .44658 .45183 .44561 .45081 Metetra
.664 .741 .907 r
.44561 .45081 .44658 .45183 .4522 .45 .45123 .44898 Metetra
.664 .741 .907 r
.45123 .44898 .4522 .45 .45783 .44817 .45686 .44715 Metetra
.664 .741 .907 r
.45686 .44715 .45783 .44817 .46274 .48549 .4625 .44531 Metetra
.562 .357 .559 r
.4625 .44531 .46274 .48549 .46913 .44449 .46816 .44346 Metetra
.664 .741 .907 r
.46816 .44346 .46913 .44449 .47479 .44265 .47382 .44162 Metetra
.664 .741 .907 r
.47382 .44162 .47479 .44265 .48047 .4408 .4795 .43976 Metetra
.664 .741 .907 r
.4795 .43976 .48047 .4408 .48615 .43895 .48519 .43791 Metetra
.959 .674 .452 r
.48519 .43791 .48615 .43895 .49144 .47823 .48943 .57657 Metetra
.349 .173 .496 r
.48943 .57657 .49144 .47823 .49757 .43523 .49661 .43419 Metetra
.664 .741 .907 r
.49661 .43419 .49757 .43523 .50329 .43336 .50234 .43232 Metetra
.664 .741 .907 r
.50234 .43232 .50329 .43336 .50903 .4315 .50808 .43045 Metetra
.664 .741 .907 r
.50808 .43045 .50903 .4315 .51478 .42962 .51383 .42858 Metetra
.664 .741 .907 r
.51383 .42858 .51478 .42962 .52054 .42775 .51959 .4267 Metetra
.664 .741 .907 r
.51959 .4267 .52054 .42775 .52631 .42587 .52536 .42482 Metetra
.664 .741 .907 r
.52536 .42482 .52631 .42587 .53209 .42398 .53115 .42293 Metetra
.664 .741 .907 r
.53115 .42293 .53209 .42398 .53789 .42209 .53695 .42104 Metetra
.664 .741 .907 r
.53695 .42104 .53789 .42209 .5437 .4202 .54276 .41915 Metetra
.664 .741 .907 r
.54276 .41915 .5437 .4202 .54952 .41831 .54858 .41725 Metetra
.664 .741 .907 r
.54858 .41725 .54952 .41831 .55535 .41641 .55442 .41534 Metetra
.664 .741 .907 r
.55442 .41534 .55535 .41641 .5612 .4145 .56027 .41344 Metetra
.664 .741 .907 r
.56027 .41344 .5612 .4145 .56706 .41259 .56613 .41153 Metetra
.664 .741 .907 r
.56613 .41153 .56706 .41259 .57293 .41068 .572 .40961 Metetra
.664 .741 .907 r
.572 .40961 .57293 .41068 .57881 .40877 .57789 .4077 Metetra
.664 .741 .907 r
.57789 .4077 .57881 .40877 .5847 .40685 .58378 .40577 Metetra
.664 .741 .907 r
.58378 .40577 .5847 .40685 .59061 .40492 .58969 .40385 Metetra
.664 .741 .907 r
.58969 .40385 .59061 .40492 .59653 .40299 .59562 .40192 Metetra
.664 .741 .907 r
.59562 .40192 .59653 .40299 .60247 .40106 .60155 .39998 Metetra
.664 .741 .907 r
.60155 .39998 .60247 .40106 .60841 .39912 .6075 .39804 Metetra
.664 .741 .907 r
.6075 .39804 .60841 .39912 .61437 .39718 .61346 .3961 Metetra
.664 .741 .907 r
.61346 .3961 .61437 .39718 .62034 .39524 .61944 .39415 Metetra
.664 .741 .907 r
.61944 .39415 .62034 .39524 .62633 .39329 .62542 .3922 Metetra
.664 .741 .907 r
.62542 .3922 .62633 .39329 .63232 .39134 .63142 .39024 Metetra
.664 .741 .907 r
.63142 .39024 .63232 .39134 .63833 .38938 .63743 .38828 Metetra
.664 .741 .907 r
.63743 .38828 .63833 .38938 .64435 .38742 .64346 .38632 Metetra
.664 .741 .907 r
.64346 .38632 .64435 .38742 .65039 .38545 .6495 .38435 Metetra
.664 .741 .907 r
.6495 .38435 .65039 .38545 .65644 .38348 .65555 .38238 Metetra
.664 .741 .907 r
.65555 .38238 .65644 .38348 .6625 .38151 .66161 .3804 Metetra
.664 .741 .907 r
.66161 .3804 .6625 .38151 .66857 .37953 .66769 .37842 Metetra
.664 .741 .907 r
.66769 .37842 .66857 .37953 .67466 .37754 .67378 .37644 Metetra
.664 .741 .907 r
.67378 .37644 .67466 .37754 .68076 .37556 .67988 .37445 Metetra
.664 .741 .907 r
.67988 .37445 .68076 .37556 .68688 .37357 .686 .37245 Metetra
.664 .741 .907 r
.686 .37245 .68688 .37357 .693 .37157 .69213 .37046 Metetra
.664 .741 .907 r
.69213 .37046 .693 .37157 .69914 .36957 .69827 .36845 Metetra
.664 .741 .907 r
.69827 .36845 .69914 .36957 .7053 .36757 .70443 .36645 Metetra
.664 .741 .907 r
.70443 .36645 .7053 .36757 .71147 .36556 .7106 .36444 Metetra
.664 .741 .907 r
.7106 .36444 .71147 .36556 .71765 .36354 .71678 .36242 Metetra
.664 .741 .907 r
.71678 .36242 .71765 .36354 .72384 .36153 .72298 .3604 Metetra
.664 .741 .907 r
.72298 .3604 .72384 .36153 .73005 .3595 .72919 .35838 Metetra
.664 .741 .907 r
.72919 .35838 .73005 .3595 .73627 .35748 .73542 .35635 Metetra
.664 .741 .907 r
.73542 .35635 .73627 .35748 .7425 .35545 .74165 .35431 Metetra
.664 .741 .907 r
.74165 .35431 .7425 .35545 .74875 .35341 .7479 .35228 Metetra
.664 .741 .907 r
.7479 .35228 .74875 .35341 .75501 .35137 .75417 .35023 Metetra
.961 .625 .272 r
.75417 .35023 .75501 .35137 .76129 .34933 .76542 .41512 Metetra
.438 .247 .523 r
.76542 .41512 .76129 .34933 .76758 .34728 .76674 .34614 Metetra
.664 .741 .907 r
.76674 .34614 .76758 .34728 .77388 .34523 .77305 .34408 Metetra
.664 .741 .907 r
.77305 .34408 .77388 .34523 .7802 .34317 .77937 .34202 Metetra
.664 .741 .907 r
.77937 .34202 .7802 .34317 .78653 .34111 .7857 .33996 Metetra
.664 .741 .907 r
.7857 .33996 .78653 .34111 .79287 .33904 .79205 .33789 Metetra
.664 .741 .907 r
.79205 .33789 .79287 .33904 .79923 .33697 .79841 .33581 Metetra
.664 .741 .907 r
.79841 .33581 .79923 .33697 .80561 .33489 .80479 .33373 Metetra
.664 .741 .907 r
.80479 .33373 .80561 .33489 .81199 .33281 .81118 .33165 Metetra
.664 .741 .907 r
.81118 .33165 .81199 .33281 .81839 .33073 .81758 .32956 Metetra
.664 .741 .907 r
.81758 .32956 .81839 .33073 .82481 .32864 .824 .32747 Metetra
.664 .741 .907 r
.824 .32747 .82481 .32864 .83124 .32654 .83043 .32537 Metetra
.664 .741 .907 r
.83043 .32537 .83124 .32654 .83768 .32445 .83688 .32327 Metetra
.664 .741 .907 r
.83688 .32327 .83768 .32445 .84414 .32234 .84334 .32117 Metetra
.664 .741 .907 r
.84334 .32117 .84414 .32234 .85061 .32023 .84981 .31906 Metetra
.664 .741 .907 r
.84981 .31906 .85061 .32023 .8571 .31812 .8563 .31694 Metetra
.664 .741 .907 r
.8563 .31694 .8571 .31812 .8636 .316 .86281 .31482 Metetra
.664 .741 .907 r
.86281 .31482 .8636 .316 .87012 .31388 .86933 .3127 Metetra
.664 .741 .907 r
.86933 .3127 .87012 .31388 .87665 .31175 .87586 .31057 Metetra
.664 .741 .907 r
.87586 .31057 .87665 .31175 .88319 .30962 .88241 .30843 Metetra
.664 .741 .907 r
.88241 .30843 .88319 .30962 .88975 .30749 .88897 .30629 Metetra
.664 .741 .907 r
.29711 .49792 .29814 .49888 .30346 .49715 .30243 .49618 Metetra
.664 .741 .907 r
.30243 .49618 .30346 .49715 .30879 .49541 .30776 .49444 Metetra
.664 .741 .907 r
.30776 .49444 .30879 .49541 .31413 .49367 .3131 .4927 Metetra
.664 .741 .907 r
.3131 .4927 .31413 .49367 .31948 .49193 .31845 .49095 Metetra
.664 .741 .907 r
.31845 .49095 .31948 .49193 .32484 .49018 .32382 .4892 Metetra
.664 .741 .907 r
.32382 .4892 .32484 .49018 .33022 .48843 .32919 .48745 Metetra
.664 .741 .907 r
.32919 .48745 .33022 .48843 .3356 .48667 .33458 .48569 Metetra
.664 .741 .907 r
.33458 .48569 .3356 .48667 .34099 .48491 .33997 .48393 Metetra
.664 .741 .907 r
.33997 .48393 .34099 .48491 .34481 .51265 .34538 .48217 Metetra
.564 .361 .564 r
.34538 .48217 .34481 .51265 .35181 .48139 .3508 .4804 Metetra
.664 .741 .907 r
.3508 .4804 .35181 .48139 .35724 .47962 .35623 .47863 Metetra
.664 .741 .907 r
.35623 .47863 .35724 .47962 .36268 .47785 .36167 .47685 Metetra
.664 .741 .907 r
.36167 .47685 .36268 .47785 .36813 .47607 .36712 .47508 Metetra
.664 .741 .907 r
.36712 .47508 .36813 .47607 .37359 .47429 .37258 .47329 Metetra
.664 .741 .907 r
.37258 .47329 .37359 .47429 .37906 .47251 .37806 .47151 Metetra
.664 .741 .907 r
.37806 .47151 .37906 .47251 .38454 .47072 .38354 .46972 Metetra
.664 .741 .907 r
.38354 .46972 .38454 .47072 .39004 .46893 .38904 .46793 Metetra
.664 .741 .907 r
.38904 .46793 .39004 .46893 .39554 .46713 .39455 .46613 Metetra
.664 .741 .907 r
.39455 .46613 .39554 .46713 .40106 .46533 .40006 .46433 Metetra
.664 .741 .907 r
.40006 .46433 .40106 .46533 .40659 .46353 .40559 .46253 Metetra
.664 .741 .907 r
.40559 .46253 .40659 .46353 .41213 .46173 .41114 .46072 Metetra
.664 .741 .907 r
.41114 .46072 .41213 .46173 .41768 .45992 .41669 .45891 Metetra
.664 .741 .907 r
.41669 .45891 .41768 .45992 .42324 .4581 .42225 .45709 Metetra
.664 .741 .907 r
.42225 .45709 .42324 .4581 .42882 .45629 .42783 .45527 Metetra
.664 .741 .907 r
.42783 .45527 .42882 .45629 .4344 .45447 .43342 .45345 Metetra
.664 .741 .907 r
.43342 .45345 .4344 .45447 .44 .45264 .43902 .45162 Metetra
.664 .741 .907 r
.43902 .45162 .44 .45264 .44561 .45081 .44463 .44979 Metetra
.664 .741 .907 r
.44463 .44979 .44561 .45081 .45123 .44898 .45025 .44796 Metetra
.664 .741 .907 r
.45025 .44796 .45123 .44898 .45686 .44715 .45588 .44612 Metetra
.664 .741 .907 r
.45588 .44612 .45686 .44715 .4625 .44531 .46153 .44428 Metetra
.664 .741 .907 r
.46153 .44428 .4625 .44531 .46816 .44346 .46719 .44243 Metetra
.664 .741 .907 r
.46719 .44243 .46816 .44346 .47382 .44162 .47286 .44058 Metetra
.664 .741 .907 r
.47286 .44058 .47382 .44162 .4795 .43976 .47854 .43873 Metetra
.959 .675 .456 r
.47854 .43873 .4795 .43976 .48519 .43791 .48237 .586 Metetra
.599 .373 .545 r
.48237 .586 .48519 .43791 .48943 .57657 .48753 .6589 Metetra
.03 0 .391 r
.48753 .6589 .48943 .57657 .49661 .43419 .49565 .43315 Metetra
.664 .741 .907 r
.49565 .43315 .49661 .43419 .50234 .43232 .50138 .43128 Metetra
.664 .741 .907 r
.50138 .43128 .50234 .43232 .50808 .43045 .50712 .42941 Metetra
.664 .741 .907 r
.50712 .42941 .50808 .43045 .51383 .42858 .51287 .42753 Metetra
.664 .741 .907 r
.51287 .42753 .51383 .42858 .51959 .4267 .51864 .42565 Metetra
.664 .741 .907 r
.51864 .42565 .51959 .4267 .52536 .42482 .52442 .42376 Metetra
.664 .741 .907 r
.52442 .42376 .52536 .42482 .53115 .42293 .53021 .42188 Metetra
.664 .741 .907 r
.53021 .42188 .53115 .42293 .53695 .42104 .53601 .41998 Metetra
.664 .741 .907 r
.53601 .41998 .53695 .42104 .54276 .41915 .54182 .41809 Metetra
.664 .741 .907 r
.54182 .41809 .54276 .41915 .54858 .41725 .54765 .41619 Metetra
.664 .741 .907 r
.54765 .41619 .54858 .41725 .55442 .41534 .55349 .41428 Metetra
.664 .741 .907 r
.55349 .41428 .55442 .41534 .56027 .41344 .55934 .41237 Metetra
.664 .741 .907 r
.55934 .41237 .56027 .41344 .56613 .41153 .5652 .41046 Metetra
.664 .741 .907 r
.5652 .41046 .56613 .41153 .572 .40961 .57107 .40854 Metetra
.664 .741 .907 r
.57107 .40854 .572 .40961 .57789 .4077 .57696 .40662 Metetra
.664 .741 .907 r
.57696 .40662 .57789 .4077 .58378 .40577 .58286 .4047 Metetra
.664 .741 .907 r
.58286 .4047 .58378 .40577 .58969 .40385 .58878 .40277 Metetra
.664 .741 .907 r
.58878 .40277 .58969 .40385 .59562 .40192 .5947 .40084 Metetra
.664 .741 .907 r
.5947 .40084 .59562 .40192 .60155 .39998 .60064 .3989 Metetra
.664 .741 .907 r
.60064 .3989 .60155 .39998 .6075 .39804 .60659 .39696 Metetra
.664 .741 .907 r
.60659 .39696 .6075 .39804 .61346 .3961 .61255 .39501 Metetra
.664 .741 .907 r
.61255 .39501 .61346 .3961 .61944 .39415 .61853 .39306 Metetra
.664 .741 .907 r
.61853 .39306 .61944 .39415 .62542 .3922 .62452 .39111 Metetra
.664 .741 .907 r
.62452 .39111 .62542 .3922 .63142 .39024 .63052 .38915 Metetra
.664 .741 .907 r
.63052 .38915 .63142 .39024 .63743 .38828 .63654 .38719 Metetra
.664 .741 .907 r
.63654 .38719 .63743 .38828 .64346 .38632 .64256 .38522 Metetra
.664 .741 .907 r
.64256 .38522 .64346 .38632 .6495 .38435 .6486 .38325 Metetra
.664 .741 .907 r
.6486 .38325 .6495 .38435 .65555 .38238 .65466 .38128 Metetra
.664 .741 .907 r
.65466 .38128 .65555 .38238 .66161 .3804 .66073 .3793 Metetra
.664 .741 .907 r
.66073 .3793 .66161 .3804 .66769 .37842 .66681 .37732 Metetra
.664 .741 .907 r
.66681 .37732 .66769 .37842 .67378 .37644 .6729 .37533 Metetra
.664 .741 .907 r
.6729 .37533 .67378 .37644 .67988 .37445 .679 .37334 Metetra
.664 .741 .907 r
.679 .37334 .67988 .37445 .686 .37245 .68512 .37134 Metetra
.664 .741 .907 r
.68512 .37134 .686 .37245 .69213 .37046 .69126 .36934 Metetra
.664 .741 .907 r
.69126 .36934 .69213 .37046 .69827 .36845 .6974 .36733 Metetra
.664 .741 .907 r
.6974 .36733 .69827 .36845 .70443 .36645 .70356 .36533 Metetra
.664 .741 .907 r
.70356 .36533 .70443 .36645 .7106 .36444 .70973 .36331 Metetra
.664 .741 .907 r
.70973 .36331 .7106 .36444 .71678 .36242 .71592 .36129 Metetra
.664 .741 .907 r
.71592 .36129 .71678 .36242 .72298 .3604 .72212 .35927 Metetra
.664 .741 .907 r
.72212 .35927 .72298 .3604 .72919 .35838 .72833 .35724 Metetra
.664 .741 .907 r
.72833 .35724 .72919 .35838 .73542 .35635 .73456 .35521 Metetra
.664 .741 .907 r
.73456 .35521 .73542 .35635 .74165 .35431 .7408 .35318 Metetra
.664 .741 .907 r
.7408 .35318 .74165 .35431 .7479 .35228 .74705 .35114 Metetra
.664 .741 .907 r
.74705 .35114 .7479 .35228 .75417 .35023 .75332 .34909 Metetra
.963 .631 .282 r
.75332 .34909 .75417 .35023 .76542 .41512 .76505 .42054 Metetra
.919 .713 .22 r
.76505 .42054 .76542 .41512 .76674 .34614 .7659 .34499 Metetra
.664 .741 .907 r
.7659 .34499 .76674 .34614 .77305 .34408 .77221 .34293 Metetra
.664 .741 .907 r
.77221 .34293 .77305 .34408 .77937 .34202 .77853 .34087 Metetra
.664 .741 .907 r
.77853 .34087 .77937 .34202 .7857 .33996 .78487 .3388 Metetra
.664 .741 .907 r
.78487 .3388 .7857 .33996 .79205 .33789 .79122 .33673 Metetra
.664 .741 .907 r
.79122 .33673 .79205 .33789 .79841 .33581 .79758 .33465 Metetra
.664 .741 .907 r
.79758 .33465 .79841 .33581 .80479 .33373 .80396 .33257 Metetra
.664 .741 .907 r
.80396 .33257 .80479 .33373 .81118 .33165 .81036 .33049 Metetra
.664 .741 .907 r
.81036 .33049 .81118 .33165 .81758 .32956 .81676 .3284 Metetra
.664 .741 .907 r
.81676 .3284 .81758 .32956 .824 .32747 .82318 .3263 Metetra
.664 .741 .907 r
.82318 .3263 .824 .32747 .83043 .32537 .82962 .3242 Metetra
.664 .741 .907 r
.82962 .3242 .83043 .32537 .83688 .32327 .83607 .3221 Metetra
.664 .741 .907 r
.83607 .3221 .83688 .32327 .84334 .32117 .84253 .31999 Metetra
.664 .741 .907 r
.84253 .31999 .84334 .32117 .84981 .31906 .84901 .31788 Metetra
.664 .741 .907 r
.84901 .31788 .84981 .31906 .8563 .31694 .85551 .31576 Metetra
.664 .741 .907 r
.85551 .31576 .8563 .31694 .86281 .31482 .86201 .31364 Metetra
.664 .741 .907 r
.86201 .31364 .86281 .31482 .86933 .3127 .86854 .31151 Metetra
.664 .741 .907 r
.86854 .31151 .86933 .3127 .87586 .31057 .87507 .30938 Metetra
.664 .741 .907 r
.87507 .30938 .87586 .31057 .88241 .30843 .88163 .30724 Metetra
.664 .741 .907 r
.88163 .30724 .88241 .30843 .88897 .30629 .88819 .3051 Metetra
.664 .741 .907 r
.29607 .49695 .29711 .49792 .30243 .49618 .3014 .49521 Metetra
.664 .741 .907 r
.3014 .49521 .30243 .49618 .30776 .49444 .30673 .49347 Metetra
.664 .741 .907 r
.30673 .49347 .30776 .49444 .3131 .4927 .31207 .49172 Metetra
.664 .741 .907 r
.31207 .49172 .3131 .4927 .31845 .49095 .31743 .48998 Metetra
.664 .741 .907 r
.31743 .48998 .31845 .49095 .32382 .4892 .32279 .48822 Metetra
.664 .741 .907 r
.32279 .48822 .32382 .4892 .32919 .48745 .32817 .48647 Metetra
.664 .741 .907 r
.32817 .48647 .32919 .48745 .33458 .48569 .33356 .48471 Metetra
.664 .741 .907 r
.33356 .48471 .33458 .48569 .33997 .48393 .33895 .48295 Metetra
.664 .741 .907 r
.33895 .48295 .33997 .48393 .34538 .48217 .34436 .48118 Metetra
.664 .741 .907 r
.34436 .48118 .34538 .48217 .3508 .4804 .34978 .47941 Metetra
.664 .741 .907 r
.34978 .47941 .3508 .4804 .35623 .47863 .35521 .47764 Metetra
.648 .736 .914 r
.35521 .47764 .35623 .47863 .36167 .47685 .36065 .47609 Metetra
.679 .795 .936 r
.36065 .47609 .36167 .47685 .36712 .47508 .36611 .47408 Metetra
.664 .741 .907 r
.36611 .47408 .36712 .47508 .37258 .47329 .37158 .4723 Metetra
.664 .741 .907 r
.37158 .4723 .37258 .47329 .37806 .47151 .37705 .47051 Metetra
.664 .741 .907 r
.37705 .47051 .37806 .47151 .38354 .46972 .38254 .46872 Metetra
.664 .741 .907 r
.38254 .46872 .38354 .46972 .38904 .46793 .38804 .46692 Metetra
.664 .741 .907 r
.38804 .46692 .38904 .46793 .39455 .46613 .39355 .46513 Metetra
.664 .741 .907 r
.39355 .46513 .39455 .46613 .40006 .46433 .39907 .46332 Metetra
.664 .741 .907 r
.39907 .46332 .40006 .46433 .40559 .46253 .4046 .46152 Metetra
.664 .741 .907 r
.4046 .46152 .40559 .46253 .41114 .46072 .41014 .45971 Metetra
.664 .741 .907 r
.41014 .45971 .41114 .46072 .41669 .45891 .4157 .45789 Metetra
.664 .741 .907 r
.4157 .45789 .41669 .45891 .42225 .45709 .42127 .45608 Metetra
.664 .741 .907 r
.42127 .45608 .42225 .45709 .42783 .45527 .42684 .45426 Metetra
.664 .741 .907 r
.42684 .45426 .42783 .45527 .43342 .45345 .43243 .45243 Metetra
.664 .741 .907 r
.43243 .45243 .43342 .45345 .43902 .45162 .43803 .4506 Metetra
.664 .741 .907 r
.43803 .4506 .43902 .45162 .44463 .44979 .44365 .44877 Metetra
.664 .741 .907 r
.44365 .44877 .44463 .44979 .45025 .44796 .44927 .44693 Metetra
.664 .741 .907 r
.44927 .44693 .45025 .44796 .45588 .44612 .45491 .44509 Metetra
.664 .741 .907 r
.45491 .44509 .45588 .44612 .46153 .44428 .46056 .44325 Metetra
.664 .741 .907 r
.46056 .44325 .46153 .44428 .46719 .44243 .46622 .4414 Metetra
.664 .741 .907 r
.46622 .4414 .46719 .44243 .47286 .44058 .47189 .43955 Metetra
.664 .741 .907 r
.47189 .43955 .47286 .44058 .47854 .43873 .47757 .4377 Metetra
.959 .677 .459 r
.47757 .4377 .47854 .43873 .48237 .586 .4811 .60543 Metetra
0 0 .301 r
.4811 .60543 .48237 .586 .48753 .6589 .48778 .5419 Metetra
.644 .415 .557 r
.48778 .5419 .48753 .6589 .49565 .43315 .49469 .43211 Metetra
.664 .741 .907 r
.49469 .43211 .49565 .43315 .50138 .43128 .50042 .43023 Metetra
.664 .741 .907 r
.50042 .43023 .50138 .43128 .50712 .42941 .50617 .42836 Metetra
.664 .741 .907 r
.50617 .42836 .50712 .42941 .51287 .42753 .51192 .42648 Metetra
.664 .741 .907 r
.51192 .42648 .51287 .42753 .51864 .42565 .51769 .4246 Metetra
.664 .741 .907 r
.51769 .4246 .51864 .42565 .52442 .42376 .52347 .42271 Metetra
.664 .741 .907 r
.52347 .42271 .52442 .42376 .53021 .42188 .52926 .42082 Metetra
.664 .741 .907 r
.52926 .42082 .53021 .42188 .53601 .41998 .53506 .41893 Metetra
.664 .741 .907 r
.53506 .41893 .53601 .41998 .54182 .41809 .54088 .41703 Metetra
.664 .741 .907 r
.54088 .41703 .54182 .41809 .54765 .41619 .54671 .41512 Metetra
.664 .741 .907 r
.54671 .41512 .54765 .41619 .55349 .41428 .55255 .41322 Metetra
.664 .741 .907 r
.55255 .41322 .55349 .41428 .55934 .41237 .5584 .41131 Metetra
.664 .741 .907 r
.5584 .41131 .55934 .41237 .5652 .41046 .56427 .40939 Metetra
.664 .741 .907 r
.56427 .40939 .5652 .41046 .57107 .40854 .57015 .40747 Metetra
.664 .741 .907 r
.57015 .40747 .57107 .40854 .57696 .40662 .57604 .40555 Metetra
.664 .741 .907 r
.57604 .40555 .57696 .40662 .58286 .4047 .58194 .40362 Metetra
.664 .741 .907 r
.58194 .40362 .58286 .4047 .58878 .40277 .58786 .40169 Metetra
.664 .741 .907 r
.58786 .40169 .58878 .40277 .5947 .40084 .59378 .39976 Metetra
.664 .741 .907 r
.59378 .39976 .5947 .40084 .60064 .3989 .59972 .39782 Metetra
.664 .741 .907 r
.59972 .39782 .60064 .3989 .60659 .39696 .60568 .39587 Metetra
.664 .741 .907 r
.60568 .39587 .60659 .39696 .61255 .39501 .61164 .39393 Metetra
.664 .741 .907 r
.61164 .39393 .61255 .39501 .61853 .39306 .61762 .39197 Metetra
.664 .741 .907 r
.61762 .39197 .61853 .39306 .62452 .39111 .62361 .39002 Metetra
.664 .741 .907 r
.62361 .39002 .62452 .39111 .63052 .38915 .62962 .38806 Metetra
.664 .741 .907 r
.62962 .38806 .63052 .38915 .63654 .38719 .63564 .38609 Metetra
.664 .741 .907 r
.63564 .38609 .63654 .38719 .64256 .38522 .64167 .38412 Metetra
.664 .741 .907 r
.64167 .38412 .64256 .38522 .6486 .38325 .64771 .38215 Metetra
.664 .741 .907 r
.64771 .38215 .6486 .38325 .65466 .38128 .65377 .38017 Metetra
.664 .741 .907 r
.65377 .38017 .65466 .38128 .66073 .3793 .65984 .37819 Metetra
.664 .741 .907 r
.65984 .37819 .66073 .3793 .66681 .37732 .66592 .37621 Metetra
.664 .741 .907 r
.66592 .37621 .66681 .37732 .6729 .37533 .67201 .37422 Metetra
.664 .741 .907 r
.67201 .37422 .6729 .37533 .679 .37334 .67812 .37222 Metetra
.664 .741 .907 r
.67812 .37222 .679 .37334 .68512 .37134 .68425 .37022 Metetra
.664 .741 .907 r
.68425 .37022 .68512 .37134 .69126 .36934 .69038 .36822 Metetra
.664 .741 .907 r
.69038 .36822 .69126 .36934 .6974 .36733 .69653 .36621 Metetra
.664 .741 .907 r
.69653 .36621 .6974 .36733 .70356 .36533 .70269 .3642 Metetra
.664 .741 .907 r
.70269 .3642 .70356 .36533 .70973 .36331 .70887 .36219 Metetra
.664 .741 .907 r
.70887 .36219 .70973 .36331 .71592 .36129 .71506 .36017 Metetra
.664 .741 .907 r
.71506 .36017 .71592 .36129 .72212 .35927 .72126 .35814 Metetra
.664 .741 .907 r
.72126 .35814 .72212 .35927 .72833 .35724 .72748 .35611 Metetra
.664 .741 .907 r
.72748 .35611 .72833 .35724 .73456 .35521 .73371 .35408 Metetra
.664 .741 .907 r
.73371 .35408 .73456 .35521 .7408 .35318 .73995 .35204 Metetra
.83 .408 0 r
.73995 .35204 .7408 .35318 .74705 .35114 .74753 .36893 Metetra
.416 .211 .491 r
.74753 .36893 .74705 .35114 .75332 .34909 .75248 .34795 Metetra
.776 .343 0 r
.75248 .34795 .75332 .34909 .76505 .42054 .75999 .3626 Metetra
.587 .372 .555 r
.75999 .3626 .76505 .42054 .7659 .34499 .76506 .34384 Metetra
.664 .741 .907 r
.76506 .34384 .7659 .34499 .77221 .34293 .77137 .34178 Metetra
.664 .741 .907 r
.77137 .34178 .77221 .34293 .77853 .34087 .7777 .33972 Metetra
.664 .741 .907 r
.7777 .33972 .77853 .34087 .78487 .3388 .78404 .33765 Metetra
.664 .741 .907 r
.78404 .33765 .78487 .3388 .79122 .33673 .79039 .33557 Metetra
.664 .741 .907 r
.79039 .33557 .79122 .33673 .79758 .33465 .79676 .33349 Metetra
.664 .741 .907 r
.79676 .33349 .79758 .33465 .80396 .33257 .80314 .33141 Metetra
.664 .741 .907 r
.80314 .33141 .80396 .33257 .81036 .33049 .80954 .32932 Metetra
.664 .741 .907 r
.80954 .32932 .81036 .33049 .81676 .3284 .81595 .32723 Metetra
.664 .741 .907 r
.81595 .32723 .81676 .3284 .82318 .3263 .82237 .32513 Metetra
.664 .741 .907 r
.82237 .32513 .82318 .3263 .82962 .3242 .82881 .32303 Metetra
.664 .741 .907 r
.82881 .32303 .82962 .3242 .83607 .3221 .83526 .32092 Metetra
.664 .741 .907 r
.83526 .32092 .83607 .3221 .84253 .31999 .84173 .31881 Metetra
.664 .741 .907 r
.84173 .31881 .84253 .31999 .84901 .31788 .84821 .3167 Metetra
.664 .741 .907 r
.84821 .3167 .84901 .31788 .85551 .31576 .85471 .31458 Metetra
.664 .741 .907 r
.85471 .31458 .85551 .31576 .86201 .31364 .86122 .31245 Metetra
.664 .741 .907 r
.86122 .31245 .86201 .31364 .86854 .31151 .86774 .31032 Metetra
.664 .741 .907 r
.86774 .31032 .86854 .31151 .87507 .30938 .87428 .30818 Metetra
.664 .741 .907 r
.87428 .30818 .87507 .30938 .88163 .30724 .88084 .30604 Metetra
.664 .741 .907 r
.88084 .30604 .88163 .30724 .88819 .3051 .88741 .3039 Metetra
.664 .741 .907 r
.29504 .49598 .29607 .49695 .3014 .49521 .30036 .49424 Metetra
.664 .741 .907 r
.30036 .49424 .3014 .49521 .30673 .49347 .30569 .4925 Metetra
.664 .741 .907 r
.30569 .4925 .30673 .49347 .31207 .49172 .31104 .49075 Metetra
.664 .741 .907 r
.31104 .49075 .31207 .49172 .31743 .48998 .3164 .489 Metetra
.664 .741 .907 r
.3164 .489 .31743 .48998 .32279 .48822 .32176 .48725 Metetra
.664 .741 .907 r
.32176 .48725 .32279 .48822 .32817 .48647 .32714 .48549 Metetra
.664 .741 .907 r
.32714 .48549 .32817 .48647 .33356 .48471 .33253 .48373 Metetra
.664 .741 .907 r
.33253 .48373 .33356 .48471 .33895 .48295 .33793 .48196 Metetra
.664 .741 .907 r
.33793 .48196 .33895 .48295 .34436 .48118 .34334 .4802 Metetra
.664 .741 .907 r
.34334 .4802 .34436 .48118 .34978 .47941 .34877 .47842 Metetra
.103 .473 .894 r
.34877 .47842 .34978 .47941 .35521 .47764 .35399 .48063 Metetra
.866 .574 .493 r
.35399 .48063 .35521 .47764 .36065 .47609 .35742 .51927 Metetra
.403 .205 .494 r
.35742 .51927 .36065 .47609 .36611 .47408 .3651 .47309 Metetra
.664 .741 .907 r
.3651 .47309 .36611 .47408 .37158 .4723 .37057 .4713 Metetra
.664 .741 .907 r
.37057 .4713 .37158 .4723 .37705 .47051 .37604 .46951 Metetra
.664 .741 .907 r
.37604 .46951 .37705 .47051 .38254 .46872 .38153 .46772 Metetra
.664 .741 .907 r
.38153 .46772 .38254 .46872 .38804 .46692 .38703 .46592 Metetra
.664 .741 .907 r
.38703 .46592 .38804 .46692 .39355 .46513 .39255 .46412 Metetra
.664 .741 .907 r
.39255 .46412 .39355 .46513 .39907 .46332 .39807 .46232 Metetra
.664 .741 .907 r
.39807 .46232 .39907 .46332 .4046 .46152 .4036 .46051 Metetra
.664 .741 .907 r
.4036 .46051 .4046 .46152 .41014 .45971 .40915 .4587 Metetra
.664 .741 .907 r
.40915 .4587 .41014 .45971 .4157 .45789 .41471 .45688 Metetra
.664 .741 .907 r
.41471 .45688 .4157 .45789 .42127 .45608 .42028 .45506 Metetra
.664 .741 .907 r
.42028 .45506 .42127 .45608 .42684 .45426 .42586 .45324 Metetra
.664 .741 .907 r
.42586 .45324 .42684 .45426 .43243 .45243 .43145 .45141 Metetra
.664 .741 .907 r
.43145 .45141 .43243 .45243 .43803 .4506 .43705 .44958 Metetra
.664 .741 .907 r
.43705 .44958 .43803 .4506 .44365 .44877 .44267 .44775 Metetra
.664 .741 .907 r
.44267 .44775 .44365 .44877 .44927 .44693 .44829 .44591 Metetra
.664 .741 .907 r
.44829 .44591 .44927 .44693 .45491 .44509 .45393 .44407 Metetra
.664 .741 .907 r
.45393 .44407 .45491 .44509 .46056 .44325 .45958 .44222 Metetra
.664 .741 .907 r
.45958 .44222 .46056 .44325 .46622 .4414 .46524 .44037 Metetra
.664 .741 .907 r
.46524 .44037 .46622 .4414 .47189 .43955 .47092 .43852 Metetra
.664 .741 .907 r
.47092 .43852 .47189 .43955 .47757 .4377 .4766 .43666 Metetra
.959 .672 .448 r
.4766 .43666 .47757 .4377 .4811 .60543 .48075 .55314 Metetra
.655 .428 .563 r
.48075 .55314 .4811 .60543 .48778 .5419 .48731 .49496 Metetra
.672 .442 .564 r
.48731 .49496 .48778 .5419 .49469 .43211 .49373 .43106 Metetra
.664 .741 .907 r
.49373 .43106 .49469 .43211 .50042 .43023 .49947 .42919 Metetra
.664 .741 .907 r
.49947 .42919 .50042 .43023 .50617 .42836 .50521 .42731 Metetra
.664 .741 .907 r
.50521 .42731 .50617 .42836 .51192 .42648 .51097 .42543 Metetra
.664 .741 .907 r
.51097 .42543 .51192 .42648 .51769 .4246 .51674 .42355 Metetra
.664 .741 .907 r
.51674 .42355 .51769 .4246 .52347 .42271 .52252 .42166 Metetra
.664 .741 .907 r
.52252 .42166 .52347 .42271 .52926 .42082 .52831 .41976 Metetra
.664 .741 .907 r
.52831 .41976 .52926 .42082 .53506 .41893 .53412 .41787 Metetra
.664 .741 .907 r
.53412 .41787 .53506 .41893 .54088 .41703 .53994 .41597 Metetra
.664 .741 .907 r
.53994 .41597 .54088 .41703 .54671 .41512 .54577 .41406 Metetra
.664 .741 .907 r
.54577 .41406 .54671 .41512 .55255 .41322 .55161 .41215 Metetra
.664 .741 .907 r
.55161 .41215 .55255 .41322 .5584 .41131 .55747 .41024 Metetra
.664 .741 .907 r
.55747 .41024 .5584 .41131 .56427 .40939 .56334 .40832 Metetra
.664 .741 .907 r
.56334 .40832 .56427 .40939 .57015 .40747 .56922 .4064 Metetra
.664 .741 .907 r
.56922 .4064 .57015 .40747 .57604 .40555 .57511 .40448 Metetra
.664 .741 .907 r
.57511 .40448 .57604 .40555 .58194 .40362 .58102 .40255 Metetra
.664 .741 .907 r
.58102 .40255 .58194 .40362 .58786 .40169 .58693 .40061 Metetra
.664 .741 .907 r
.58693 .40061 .58786 .40169 .59378 .39976 .59286 .39868 Metetra
.664 .741 .907 r
.59286 .39868 .59378 .39976 .59972 .39782 .59881 .39673 Metetra
.664 .741 .907 r
.59881 .39673 .59972 .39782 .60568 .39587 .60476 .39479 Metetra
.664 .741 .907 r
.60476 .39479 .60568 .39587 .61164 .39393 .61073 .39284 Metetra
.664 .741 .907 r
.61073 .39284 .61164 .39393 .61762 .39197 .61671 .39088 Metetra
.664 .741 .907 r
.61671 .39088 .61762 .39197 .62361 .39002 .62271 .38893 Metetra
.664 .741 .907 r
.62271 .38893 .62361 .39002 .62962 .38806 .62872 .38696 Metetra
.664 .741 .907 r
.62872 .38696 .62962 .38806 .63564 .38609 .63474 .385 Metetra
.664 .741 .907 r
.63474 .385 .63564 .38609 .64167 .38412 .64077 .38302 Metetra
.664 .741 .907 r
.64077 .38302 .64167 .38412 .64771 .38215 .64682 .38105 Metetra
.664 .741 .907 r
.64682 .38105 .64771 .38215 .65377 .38017 .65287 .37907 Metetra
.664 .741 .907 r
.65287 .37907 .65377 .38017 .65984 .37819 .65895 .37709 Metetra
.664 .741 .907 r
.65895 .37709 .65984 .37819 .66592 .37621 .66503 .3751 Metetra
.664 .741 .907 r
.66503 .3751 .66592 .37621 .67201 .37422 .67113 .37311 Metetra
.664 .741 .907 r
.67113 .37311 .67201 .37422 .67812 .37222 .67724 .37111 Metetra
.664 .741 .907 r
.67724 .37111 .67812 .37222 .68425 .37022 .68337 .36911 Metetra
.664 .741 .907 r
.68337 .36911 .68425 .37022 .69038 .36822 .68951 .3671 Metetra
.664 .741 .907 r
.68951 .3671 .69038 .36822 .69653 .36621 .69566 .36509 Metetra
.664 .741 .907 r
.69566 .36509 .69653 .36621 .70269 .3642 .70182 .36308 Metetra
.664 .741 .907 r
.70182 .36308 .70269 .3642 .70887 .36219 .708 .36106 Metetra
.664 .741 .907 r
.708 .36106 .70887 .36219 .71506 .36017 .71419 .35904 Metetra
.664 .741 .907 r
.71419 .35904 .71506 .36017 .72126 .35814 .7204 .35701 Metetra
.664 .741 .907 r
.7204 .35701 .72126 .35814 .72748 .35611 .72662 .35498 Metetra
.664 .741 .907 r
.72662 .35498 .72748 .35611 .73371 .35408 .73285 .35294 Metetra
.664 .741 .907 r
.73285 .35294 .73371 .35408 .73995 .35204 .73909 .3509 Metetra
.888 .489 .049 r
.73909 .3509 .73995 .35204 .74753 .36893 .74704 .37304 Metetra
0 0 .031 r
.74704 .37304 .74753 .36893 .75248 .34795 .75163 .34681 Metetra
.664 .741 .907 r
.75163 .34681 .75248 .34795 .75999 .3626 .75792 .34475 Metetra
.57 .376 .579 r
.75792 .34475 .75999 .3626 .76506 .34384 .76422 .34269 Metetra
.664 .741 .907 r
.76422 .34269 .76506 .34384 .77137 .34178 .77053 .34063 Metetra
.664 .741 .907 r
.77053 .34063 .77137 .34178 .7777 .33972 .77686 .33856 Metetra
.664 .741 .907 r
.77686 .33856 .7777 .33972 .78404 .33765 .7832 .33649 Metetra
.664 .741 .907 r
.7832 .33649 .78404 .33765 .79039 .33557 .78956 .33441 Metetra
.664 .741 .907 r
.78956 .33441 .79039 .33557 .79676 .33349 .79593 .33233 Metetra
.664 .741 .907 r
.79593 .33233 .79676 .33349 .80314 .33141 .80232 .33025 Metetra
.664 .741 .907 r
.80232 .33025 .80314 .33141 .80954 .32932 .80872 .32816 Metetra
.664 .741 .907 r
.80872 .32816 .80954 .32932 .81595 .32723 .81513 .32606 Metetra
.664 .741 .907 r
.81513 .32606 .81595 .32723 .82237 .32513 .82156 .32396 Metetra
.664 .741 .907 r
.82156 .32396 .82237 .32513 .82881 .32303 .828 .32186 Metetra
.664 .741 .907 r
.828 .32186 .82881 .32303 .83526 .32092 .83445 .31975 Metetra
.664 .741 .907 r
.83445 .31975 .83526 .32092 .84173 .31881 .84092 .31763 Metetra
.664 .741 .907 r
.84092 .31763 .84173 .31881 .84821 .3167 .84741 .31551 Metetra
.664 .741 .907 r
.84741 .31551 .84821 .3167 .85471 .31458 .85391 .31339 Metetra
.664 .741 .907 r
.85391 .31339 .85471 .31458 .86122 .31245 .86042 .31126 Metetra
.664 .741 .907 r
.86042 .31126 .86122 .31245 .86774 .31032 .86695 .30913 Metetra
.664 .741 .907 r
.86695 .30913 .86774 .31032 .87428 .30818 .87349 .30699 Metetra
.664 .741 .907 r
.87349 .30699 .87428 .30818 .88084 .30604 .88005 .30485 Metetra
.664 .741 .907 r
.88005 .30485 .88084 .30604 .88741 .3039 .88663 .3027 Metetra
.664 .741 .907 r
.294 .49501 .29504 .49598 .30036 .49424 .29932 .49327 Metetra
.664 .741 .907 r
.29932 .49327 .30036 .49424 .30569 .4925 .30466 .49152 Metetra
.664 .741 .907 r
.30466 .49152 .30569 .4925 .31104 .49075 .31001 .48977 Metetra
.664 .741 .907 r
.31001 .48977 .31104 .49075 .3164 .489 .31537 .48802 Metetra
.664 .741 .907 r
.31537 .48802 .3164 .489 .32176 .48725 .32074 .48627 Metetra
.664 .741 .907 r
.32074 .48627 .32176 .48725 .32714 .48549 .32612 .48451 Metetra
.664 .741 .907 r
.32612 .48451 .32714 .48549 .33253 .48373 .33151 .48274 Metetra
.664 .741 .907 r
.33151 .48274 .33253 .48373 .33793 .48196 .33691 .48098 Metetra
.664 .741 .907 r
.33691 .48098 .33793 .48196 .34334 .4802 .34232 .47921 Metetra
.664 .741 .907 r
.34232 .47921 .34334 .4802 .34877 .47842 .34775 .47744 Metetra
.945 .607 .351 r
.34775 .47744 .34877 .47842 .35399 .48063 .35189 .50046 Metetra
.447 .228 .488 r
.35189 .50046 .35399 .48063 .35742 .51927 .35808 .48487 Metetra
.595 .384 .565 r
.35808 .48487 .35742 .51927 .3651 .47309 .36409 .47209 Metetra
.664 .741 .907 r
.36409 .47209 .3651 .47309 .37057 .4713 .36956 .4703 Metetra
.664 .741 .907 r
.36956 .4703 .37057 .4713 .37604 .46951 .37504 .46851 Metetra
.664 .741 .907 r
.37504 .46851 .37604 .46951 .38153 .46772 .38053 .46672 Metetra
.664 .741 .907 r
.38053 .46672 .38153 .46772 .38703 .46592 .38603 .46492 Metetra
.664 .741 .907 r
.38603 .46492 .38703 .46592 .39255 .46412 .39154 .46312 Metetra
.664 .741 .907 r
.39154 .46312 .39255 .46412 .39807 .46232 .39707 .46131 Metetra
.664 .741 .907 r
.39707 .46131 .39807 .46232 .4036 .46051 .40261 .4595 Metetra
.664 .741 .907 r
.40261 .4595 .4036 .46051 .40915 .4587 .40815 .45768 Metetra
.664 .741 .907 r
.40815 .45768 .40915 .4587 .41471 .45688 .41371 .45587 Metetra
.664 .741 .907 r
.41371 .45587 .41471 .45688 .42028 .45506 .41929 .45405 Metetra
.664 .741 .907 r
.41929 .45405 .42028 .45506 .42586 .45324 .42487 .45222 Metetra
.664 .741 .907 r
.42487 .45222 .42586 .45324 .43145 .45141 .43046 .45039 Metetra
.664 .741 .907 r
.43046 .45039 .43145 .45141 .43705 .44958 .43607 .44856 Metetra
.664 .741 .907 r
.43607 .44856 .43705 .44958 .44267 .44775 .44168 .44672 Metetra
.664 .741 .907 r
.44168 .44672 .44267 .44775 .44829 .44591 .44731 .44488 Metetra
.664 .741 .907 r
.44731 .44488 .44829 .44591 .45393 .44407 .45295 .44304 Metetra
.664 .741 .907 r
.45295 .44304 .45393 .44407 .45958 .44222 .45861 .44119 Metetra
.664 .741 .907 r
.45861 .44119 .45958 .44222 .46524 .44037 .46427 .43934 Metetra
.664 .741 .907 r
.46427 .43934 .46524 .44037 .47092 .43852 .46995 .43748 Metetra
.664 .741 .907 r
.46995 .43748 .47092 .43852 .4766 .43666 .47564 .43562 Metetra
.544 .054 0 r
.47564 .43562 .4766 .43666 .48075 .55314 .48123 .44183 Metetra
.531 .324 .545 r
.48123 .44183 .48075 .55314 .48731 .49496 .48665 .46615 Metetra
.665 .441 .571 r
.48665 .46615 .48731 .49496 .49373 .43106 .49277 .43002 Metetra
.664 .741 .907 r
.49277 .43002 .49373 .43106 .49947 .42919 .49851 .42814 Metetra
.664 .741 .907 r
.49851 .42814 .49947 .42919 .50521 .42731 .50426 .42626 Metetra
.664 .741 .907 r
.50426 .42626 .50521 .42731 .51097 .42543 .51002 .42438 Metetra
.664 .741 .907 r
.51002 .42438 .51097 .42543 .51674 .42355 .51579 .42249 Metetra
.664 .741 .907 r
.51579 .42249 .51674 .42355 .52252 .42166 .52157 .4206 Metetra
.664 .741 .907 r
.52157 .4206 .52252 .42166 .52831 .41976 .52737 .41871 Metetra
.664 .741 .907 r
.52737 .41871 .52831 .41976 .53412 .41787 .53318 .41681 Metetra
.664 .741 .907 r
.53318 .41681 .53412 .41787 .53994 .41597 .539 .4149 Metetra
.664 .741 .907 r
.539 .4149 .53994 .41597 .54577 .41406 .54483 .413 Metetra
.664 .741 .907 r
.54483 .413 .54577 .41406 .55161 .41215 .55068 .41109 Metetra
.664 .741 .907 r
.55068 .41109 .55161 .41215 .55747 .41024 .55653 .40917 Metetra
.664 .741 .907 r
.55653 .40917 .55747 .41024 .56334 .40832 .5624 .40725 Metetra
.664 .741 .907 r
.5624 .40725 .56334 .40832 .56922 .4064 .56829 .40533 Metetra
.664 .741 .907 r
.56829 .40533 .56922 .4064 .57511 .40448 .57418 .4034 Metetra
.664 .741 .907 r
.57418 .4034 .57511 .40448 .58102 .40255 .58009 .40147 Metetra
.664 .741 .907 r
.58009 .40147 .58102 .40255 .58693 .40061 .58601 .39953 Metetra
.664 .741 .907 r
.58601 .39953 .58693 .40061 .59286 .39868 .59194 .39759 Metetra
.664 .741 .907 r
.59194 .39759 .59286 .39868 .59881 .39673 .59789 .39565 Metetra
.664 .741 .907 r
.59789 .39565 .59881 .39673 .60476 .39479 .60385 .3937 Metetra
.664 .741 .907 r
.60385 .3937 .60476 .39479 .61073 .39284 .60982 .39175 Metetra
.664 .741 .907 r
.60982 .39175 .61073 .39284 .61671 .39088 .6158 .38979 Metetra
.664 .741 .907 r
.6158 .38979 .61671 .39088 .62271 .38893 .6218 .38783 Metetra
.664 .741 .907 r
.6218 .38783 .62271 .38893 .62872 .38696 .62781 .38587 Metetra
.664 .741 .907 r
.62781 .38587 .62872 .38696 .63474 .385 .63383 .3839 Metetra
.664 .741 .907 r
.63383 .3839 .63474 .385 .64077 .38302 .63987 .38192 Metetra
.664 .741 .907 r
.63987 .38192 .64077 .38302 .64682 .38105 .64592 .37995 Metetra
.664 .741 .907 r
.64592 .37995 .64682 .38105 .65287 .37907 .65198 .37796 Metetra
.664 .741 .907 r
.65198 .37796 .65287 .37907 .65895 .37709 .65806 .37598 Metetra
.664 .741 .907 r
.65806 .37598 .65895 .37709 .66503 .3751 .66414 .37399 Metetra
.664 .741 .907 r
.66414 .37399 .66503 .3751 .67113 .37311 .67024 .37199 Metetra
.664 .741 .907 r
.67024 .37199 .67113 .37311 .67724 .37111 .67636 .36999 Metetra
.664 .741 .907 r
.67636 .36999 .67724 .37111 .68337 .36911 .68249 .36799 Metetra
.664 .741 .907 r
.68249 .36799 .68337 .36911 .68951 .3671 .68863 .36598 Metetra
.664 .741 .907 r
.68863 .36598 .68951 .3671 .69566 .36509 .69478 .36397 Metetra
.664 .741 .907 r
.69478 .36397 .69566 .36509 .70182 .36308 .70095 .36195 Metetra
.664 .741 .907 r
.70095 .36195 .70182 .36308 .708 .36106 .70713 .35993 Metetra
.664 .741 .907 r
.70713 .35993 .708 .36106 .71419 .35904 .71333 .35791 Metetra
.664 .741 .907 r
.71333 .35791 .71419 .35904 .7204 .35701 .71953 .35588 Metetra
.664 .741 .907 r
.71953 .35588 .7204 .35701 .72662 .35498 .72576 .35384 Metetra
.664 .741 .907 r
.72576 .35384 .72662 .35498 .73285 .35294 .73199 .3518 Metetra
.664 .741 .907 r
.73199 .3518 .73285 .35294 .73909 .3509 .73824 .34976 Metetra
.664 .741 .907 r
.73824 .34976 .73909 .3509 .74704 .37304 .7445 .34771 Metetra
.566 .365 .568 r
.7445 .34771 .74704 .37304 .75163 .34681 .75078 .34566 Metetra
.664 .741 .907 r
.75078 .34566 .75163 .34681 .75792 .34475 .75707 .3436 Metetra
.664 .741 .907 r
.75707 .3436 .75792 .34475 .76422 .34269 .76337 .34154 Metetra
.664 .741 .907 r
.76337 .34154 .76422 .34269 .77053 .34063 .76969 .33948 Metetra
.664 .741 .907 r
.76969 .33948 .77053 .34063 .77686 .33856 .77602 .33741 Metetra
.664 .741 .907 r
.77602 .33741 .77686 .33856 .7832 .33649 .78237 .33533 Metetra
.664 .741 .907 r
.78237 .33533 .7832 .33649 .78956 .33441 .78873 .33325 Metetra
.664 .741 .907 r
.78873 .33325 .78956 .33441 .79593 .33233 .7951 .33117 Metetra
.664 .741 .907 r
.7951 .33117 .79593 .33233 .80232 .33025 .80149 .32908 Metetra
.664 .741 .907 r
.80149 .32908 .80232 .33025 .80872 .32816 .80789 .32699 Metetra
.664 .741 .907 r
.80789 .32699 .80872 .32816 .81513 .32606 .81431 .32489 Metetra
.664 .741 .907 r
.81431 .32489 .81513 .32606 .82156 .32396 .82074 .32279 Metetra
.664 .741 .907 r
.82074 .32279 .82156 .32396 .828 .32186 .82718 .32068 Metetra
.664 .741 .907 r
.82718 .32068 .828 .32186 .83445 .31975 .83364 .31857 Metetra
.664 .741 .907 r
.83364 .31857 .83445 .31975 .84092 .31763 .84012 .31645 Metetra
.664 .741 .907 r
.84012 .31645 .84092 .31763 .84741 .31551 .84661 .31433 Metetra
.664 .741 .907 r
.84661 .31433 .84741 .31551 .85391 .31339 .85311 .3122 Metetra
.664 .741 .907 r
.85311 .3122 .85391 .31339 .86042 .31126 .85963 .31007 Metetra
.664 .741 .907 r
.85963 .31007 .86042 .31126 .86695 .30913 .86616 .30794 Metetra
.664 .741 .907 r
.86616 .30794 .86695 .30913 .87349 .30699 .8727 .3058 Metetra
.664 .741 .907 r
.8727 .3058 .87349 .30699 .88005 .30485 .87927 .30365 Metetra
.664 .741 .907 r
.87927 .30365 .88005 .30485 .88663 .3027 .88584 .3015 Metetra
.664 .741 .907 r
.29296 .49404 .294 .49501 .29932 .49327 .29829 .49229 Metetra
.664 .741 .907 r
.29829 .49229 .29932 .49327 .30466 .49152 .30362 .49055 Metetra
.664 .741 .907 r
.30362 .49055 .30466 .49152 .31001 .48977 .30897 .4888 Metetra
.664 .741 .907 r
.30897 .4888 .31001 .48977 .31537 .48802 .31434 .48704 Metetra
.664 .741 .907 r
.31434 .48704 .31537 .48802 .32074 .48627 .31971 .48529 Metetra
.664 .741 .907 r
.31971 .48529 .32074 .48627 .32612 .48451 .32509 .48352 Metetra
.664 .741 .907 r
.32509 .48352 .32612 .48451 .33151 .48274 .33048 .48176 Metetra
.664 .741 .907 r
.33048 .48176 .33151 .48274 .33691 .48098 .33589 .47999 Metetra
.664 .741 .907 r
.33589 .47999 .33691 .48098 .34232 .47921 .3413 .47822 Metetra
.664 .741 .907 r
.3413 .47822 .34232 .47921 .34775 .47744 .34673 .47644 Metetra
.946 .613 .362 r
.34673 .47644 .34775 .47744 .35189 .50046 .3508 .50082 Metetra
.964 .778 .603 r
.3508 .50082 .35189 .50046 .35808 .48487 .35761 .47288 Metetra
.576 .391 .593 r
.35761 .47288 .35808 .48487 .36409 .47209 .36307 .4711 Metetra
.664 .741 .907 r
.36307 .4711 .36409 .47209 .36956 .4703 .36855 .46931 Metetra
.664 .741 .907 r
.36855 .46931 .36956 .4703 .37504 .46851 .37403 .46751 Metetra
.664 .741 .907 r
.37403 .46751 .37504 .46851 .38053 .46672 .37952 .46571 Metetra
.664 .741 .907 r
.37952 .46571 .38053 .46672 .38603 .46492 .38503 .46391 Metetra
.664 .741 .907 r
.38503 .46391 .38603 .46492 .39154 .46312 .39054 .46211 Metetra
.664 .741 .907 r
.39054 .46211 .39154 .46312 .39707 .46131 .39607 .4603 Metetra
.664 .741 .907 r
.39607 .4603 .39707 .46131 .40261 .4595 .40161 .45849 Metetra
.664 .741 .907 r
.40161 .45849 .40261 .4595 .40815 .45768 .40716 .45667 Metetra
.664 .741 .907 r
.40716 .45667 .40815 .45768 .41371 .45587 .41272 .45485 Metetra
.664 .741 .907 r
.41272 .45485 .41371 .45587 .41929 .45405 .41829 .45303 Metetra
.664 .741 .907 r
.41829 .45303 .41929 .45405 .42487 .45222 .42388 .4512 Metetra
.664 .741 .907 r
.42388 .4512 .42487 .45222 .43046 .45039 .42947 .44937 Metetra
.664 .741 .907 r
.42947 .44937 .43046 .45039 .43607 .44856 .43508 .44753 Metetra
.62 .727 .923 r
.43508 .44753 .43607 .44856 .44168 .44672 .44069 .44629 Metetra
.949 .653 .443 r
.44069 .44629 .44168 .44672 .44731 .44488 .44469 .51236 Metetra
.415 .221 .506 r
.44469 .51236 .44731 .44488 .45295 .44304 .45198 .44201 Metetra
.664 .741 .907 r
.45198 .44201 .45295 .44304 .45861 .44119 .45763 .44016 Metetra
.664 .741 .907 r
.45763 .44016 .45861 .44119 .46427 .43934 .4633 .4383 Metetra
.664 .741 .907 r
.4633 .4383 .46427 .43934 .46995 .43748 .46898 .43644 Metetra
.664 .741 .907 r
.46898 .43644 .46995 .43748 .47564 .43562 .47467 .43458 Metetra
.664 .741 .907 r
.47467 .43458 .47564 .43562 .48123 .44183 .48037 .43272 Metetra
.543 .378 .608 r
.48037 .43272 .48123 .44183 .48665 .46615 .48604 .43422 Metetra
.574 .368 .564 r
.48604 .43422 .48665 .46615 .49277 .43002 .49181 .42897 Metetra
.664 .741 .907 r
.49181 .42897 .49277 .43002 .49851 .42814 .49755 .4271 Metetra
.664 .741 .907 r
.49755 .4271 .49851 .42814 .50426 .42626 .5033 .42521 Metetra
.664 .741 .907 r
.5033 .42521 .50426 .42626 .51002 .42438 .50906 .42333 Metetra
.664 .741 .907 r
.50906 .42333 .51002 .42438 .51579 .42249 .51483 .42144 Metetra
.664 .741 .907 r
.51483 .42144 .51579 .42249 .52157 .4206 .52062 .41955 Metetra
.664 .741 .907 r
.52062 .41955 .52157 .4206 .52737 .41871 .52642 .41765 Metetra
.664 .741 .907 r
.52642 .41765 .52737 .41871 .53318 .41681 .53223 .41575 Metetra
.664 .741 .907 r
.53223 .41575 .53318 .41681 .539 .4149 .53805 .41384 Metetra
.664 .741 .907 r
.53805 .41384 .539 .4149 .54483 .413 .54389 .41193 Metetra
.664 .741 .907 r
.54389 .41193 .54483 .413 .55068 .41109 .54974 .41002 Metetra
.664 .741 .907 r
.54974 .41002 .55068 .41109 .55653 .40917 .5556 .4081 Metetra
.664 .741 .907 r
.5556 .4081 .55653 .40917 .5624 .40725 .56147 .40618 Metetra
.664 .741 .907 r
.56147 .40618 .5624 .40725 .56829 .40533 .56736 .40425 Metetra
.664 .741 .907 r
.56736 .40425 .56829 .40533 .57418 .4034 .57325 .40232 Metetra
.664 .741 .907 r
.57325 .40232 .57418 .4034 .58009 .40147 .57917 .40039 Metetra
.664 .741 .907 r
.57917 .40039 .58009 .40147 .58601 .39953 .58509 .39845 Metetra
.664 .741 .907 r
.58509 .39845 .58601 .39953 .59194 .39759 .59102 .39651 Metetra
.664 .741 .907 r
.59102 .39651 .59194 .39759 .59789 .39565 .59697 .39456 Metetra
.664 .741 .907 r
.59697 .39456 .59789 .39565 .60385 .3937 .60293 .39261 Metetra
.664 .741 .907 r
.60293 .39261 .60385 .3937 .60982 .39175 .60891 .39066 Metetra
.664 .741 .907 r
.60891 .39066 .60982 .39175 .6158 .38979 .61489 .3887 Metetra
.664 .741 .907 r
.61489 .3887 .6158 .38979 .6218 .38783 .62089 .38674 Metetra
.664 .741 .907 r
.62089 .38674 .6218 .38783 .62781 .38587 .62691 .38477 Metetra
.664 .741 .907 r
.62691 .38477 .62781 .38587 .63383 .3839 .63293 .3828 Metetra
.664 .741 .907 r
.63293 .3828 .63383 .3839 .63987 .38192 .63897 .38082 Metetra
.664 .741 .907 r
.63897 .38082 .63987 .38192 .64592 .37995 .64502 .37884 Metetra
.664 .741 .907 r
.64502 .37884 .64592 .37995 .65198 .37796 .65109 .37686 Metetra
.664 .741 .907 r
.65109 .37686 .65198 .37796 .65806 .37598 .65716 .37487 Metetra
.887 .479 .053 r
.65716 .37487 .65806 .37598 .66414 .37399 .66413 .3932 Metetra
.411 .206 .488 r
.66413 .3932 .66414 .37399 .67024 .37199 .66936 .37088 Metetra
.664 .741 .907 r
.66936 .37088 .67024 .37199 .67636 .36999 .67548 .36888 Metetra
.664 .741 .907 r
.67548 .36888 .67636 .36999 .68249 .36799 .68161 .36687 Metetra
.664 .741 .907 r
.68161 .36687 .68249 .36799 .68863 .36598 .68775 .36486 Metetra
.664 .741 .907 r
.68775 .36486 .68863 .36598 .69478 .36397 .69391 .36285 Metetra
.664 .741 .907 r
.69391 .36285 .69478 .36397 .70095 .36195 .70008 .36083 Metetra
.664 .741 .907 r
.70008 .36083 .70095 .36195 .70713 .35993 .70626 .3588 Metetra
.664 .741 .907 r
.70626 .3588 .70713 .35993 .71333 .35791 .71246 .35678 Metetra
.664 .741 .907 r
.71246 .35678 .71333 .35791 .71953 .35588 .71867 .35474 Metetra
.664 .741 .907 r
.71867 .35474 .71953 .35588 .72576 .35384 .72489 .35271 Metetra
.664 .741 .907 r
.72489 .35271 .72576 .35384 .73199 .3518 .73113 .35067 Metetra
.664 .741 .907 r
.73113 .35067 .73199 .3518 .73824 .34976 .73738 .34862 Metetra
.664 .741 .907 r
.73738 .34862 .73824 .34976 .7445 .34771 .74365 .34657 Metetra
.664 .741 .907 r
.74365 .34657 .7445 .34771 .75078 .34566 .74993 .34451 Metetra
.664 .741 .907 r
.74993 .34451 .75078 .34566 .75707 .3436 .75622 .34246 Metetra
.664 .741 .907 r
.75622 .34246 .75707 .3436 .76337 .34154 .76253 .34039 Metetra
.664 .741 .907 r
.76253 .34039 .76337 .34154 .76969 .33948 .76885 .33832 Metetra
.664 .741 .907 r
.76885 .33832 .76969 .33948 .77602 .33741 .77519 .33625 Metetra
.664 .741 .907 r
.77519 .33625 .77602 .33741 .78237 .33533 .78153 .33417 Metetra
.664 .741 .907 r
.78153 .33417 .78237 .33533 .78873 .33325 .7879 .33209 Metetra
.664 .741 .907 r
.7879 .33209 .78873 .33325 .7951 .33117 .79427 .33001 Metetra
.664 .741 .907 r
.79427 .33001 .7951 .33117 .80149 .32908 .80066 .32791 Metetra
.664 .741 .907 r
.80066 .32791 .80149 .32908 .80789 .32699 .80707 .32582 Metetra
.664 .741 .907 r
.80707 .32582 .80789 .32699 .81431 .32489 .81349 .32372 Metetra
.664 .741 .907 r
.81349 .32372 .81431 .32489 .82074 .32279 .81992 .32161 Metetra
.664 .741 .907 r
.81992 .32161 .82074 .32279 .82718 .32068 .82637 .3195 Metetra
.664 .741 .907 r
.82637 .3195 .82718 .32068 .83364 .31857 .83283 .31739 Metetra
.664 .741 .907 r
.83283 .31739 .83364 .31857 .84012 .31645 .83931 .31527 Metetra
.664 .741 .907 r
.83931 .31527 .84012 .31645 .84661 .31433 .8458 .31314 Metetra
.664 .741 .907 r
.8458 .31314 .84661 .31433 .85311 .3122 .85231 .31102 Metetra
.664 .741 .907 r
.85231 .31102 .85311 .3122 .85963 .31007 .85883 .30888 Metetra
.664 .741 .907 r
.85883 .30888 .85963 .31007 .86616 .30794 .86536 .30674 Metetra
.664 .741 .907 r
.86536 .30674 .86616 .30794 .8727 .3058 .87191 .3046 Metetra
.664 .741 .907 r
.87191 .3046 .8727 .3058 .87927 .30365 .87848 .30245 Metetra
.664 .741 .907 r
.87848 .30245 .87927 .30365 .88584 .3015 .88506 .3003 Metetra
.664 .741 .907 r
.29192 .49307 .29296 .49404 .29829 .49229 .29725 .49132 Metetra
.664 .741 .907 r
.29725 .49132 .29829 .49229 .30362 .49055 .30259 .48957 Metetra
.664 .741 .907 r
.30259 .48957 .30362 .49055 .30897 .4888 .30794 .48782 Metetra
.664 .741 .907 r
.30794 .48782 .30897 .4888 .31434 .48704 .3133 .48606 Metetra
.664 .741 .907 r
.3133 .48606 .31434 .48704 .31971 .48529 .31868 .4843 Metetra
.664 .741 .907 r
.31868 .4843 .31971 .48529 .32509 .48352 .32406 .48254 Metetra
.664 .741 .907 r
.32406 .48254 .32509 .48352 .33048 .48176 .32946 .48077 Metetra
.664 .741 .907 r
.32946 .48077 .33048 .48176 .33589 .47999 .33486 .479 Metetra
.664 .741 .907 r
.33486 .479 .33589 .47999 .3413 .47822 .34028 .47723 Metetra
.664 .741 .907 r
.34028 .47723 .3413 .47822 .34673 .47644 .34571 .47545 Metetra
.664 .741 .907 r
.34571 .47545 .34673 .47644 .3508 .50082 .35115 .47367 Metetra
.564 .362 .566 r
.35115 .47367 .3508 .50082 .35761 .47288 .3566 .47189 Metetra
.664 .741 .907 r
.3566 .47189 .35761 .47288 .36307 .4711 .36206 .4701 Metetra
.664 .741 .907 r
.36206 .4701 .36307 .4711 .36855 .46931 .36753 .46831 Metetra
.664 .741 .907 r
.36753 .46831 .36855 .46931 .37403 .46751 .37302 .46651 Metetra
.664 .741 .907 r
.37302 .46651 .37403 .46751 .37952 .46571 .37851 .46471 Metetra
.664 .741 .907 r
.37851 .46471 .37952 .46571 .38503 .46391 .38402 .46291 Metetra
.664 .741 .907 r
.38402 .46291 .38503 .46391 .39054 .46211 .38954 .4611 Metetra
.664 .741 .907 r
.38954 .4611 .39054 .46211 .39607 .4603 .39507 .45929 Metetra
.664 .741 .907 r
.39507 .45929 .39607 .4603 .40161 .45849 .40061 .45747 Metetra
.664 .741 .907 r
.40061 .45747 .40161 .45849 .40716 .45667 .40616 .45566 Metetra
.664 .741 .907 r
.40616 .45566 .40716 .45667 .41272 .45485 .41172 .45383 Metetra
.664 .741 .907 r
.41172 .45383 .41272 .45485 .41829 .45303 .4173 .45201 Metetra
.664 .741 .907 r
.4173 .45201 .41829 .45303 .42388 .4512 .42289 .45018 Metetra
.664 .741 .907 r
.42289 .45018 .42388 .4512 .42947 .44937 .42849 .44835 Metetra
.664 .741 .907 r
.42849 .44835 .42947 .44937 .43508 .44753 .4341 .44651 Metetra
.955 .678 .473 r
.4341 .44651 .43508 .44753 .44069 .44629 .43511 .62146 Metetra
.558 .34 .54 r
.43511 .62146 .44069 .44629 .44469 .51236 .4408 .62952 Metetra
.304 .137 .482 r
.4408 .62952 .44469 .51236 .45198 .44201 .451 .44098 Metetra
.664 .741 .907 r
.451 .44098 .45198 .44201 .45763 .44016 .45665 .43912 Metetra
.664 .741 .907 r
.45665 .43912 .45763 .44016 .4633 .4383 .46232 .43727 Metetra
.664 .741 .907 r
.46232 .43727 .4633 .4383 .46898 .43644 .468 .43541 Metetra
.664 .741 .907 r
.468 .43541 .46898 .43644 .47467 .43458 .4737 .43354 Metetra
.664 .741 .907 r
.4737 .43354 .47467 .43458 .48037 .43272 .4794 .43167 Metetra
.664 .741 .907 r
.4794 .43167 .48037 .43272 .48604 .43422 .48512 .4298 Metetra
.607 .473 .673 r
.48512 .4298 .48604 .43422 .49181 .42897 .49085 .42793 Metetra
.664 .741 .907 r
.49085 .42793 .49181 .42897 .49755 .4271 .49659 .42605 Metetra
.664 .741 .907 r
.49659 .42605 .49755 .4271 .5033 .42521 .50234 .42416 Metetra
.664 .741 .907 r
.50234 .42416 .5033 .42521 .50906 .42333 .5081 .42228 Metetra
.664 .741 .907 r
.5081 .42228 .50906 .42333 .51483 .42144 .51388 .42038 Metetra
.664 .741 .907 r
.51388 .42038 .51483 .42144 .52062 .41955 .51967 .41849 Metetra
.664 .741 .907 r
.51967 .41849 .52062 .41955 .52642 .41765 .52547 .41659 Metetra
.664 .741 .907 r
.52547 .41659 .52642 .41765 .53223 .41575 .53128 .41468 Metetra
.664 .741 .907 r
.53128 .41468 .53223 .41575 .53805 .41384 .53711 .41278 Metetra
.664 .741 .907 r
.53711 .41278 .53805 .41384 .54389 .41193 .54295 .41087 Metetra
.664 .741 .907 r
.54295 .41087 .54389 .41193 .54974 .41002 .5488 .40895 Metetra
.664 .741 .907 r
.5488 .40895 .54974 .41002 .5556 .4081 .55466 .40703 Metetra
.664 .741 .907 r
.55466 .40703 .5556 .4081 .56147 .40618 .56054 .40511 Metetra
.664 .741 .907 r
.56054 .40511 .56147 .40618 .56736 .40425 .56642 .40318 Metetra
.664 .741 .907 r
.56642 .40318 .56736 .40425 .57325 .40232 .57232 .40125 Metetra
.664 .741 .907 r
.57232 .40125 .57325 .40232 .57917 .40039 .57824 .39931 Metetra
.664 .741 .907 r
.57824 .39931 .57917 .40039 .58509 .39845 .58416 .39737 Metetra
.664 .741 .907 r
.58416 .39737 .58509 .39845 .59102 .39651 .5901 .39542 Metetra
.664 .741 .907 r
.5901 .39542 .59102 .39651 .59697 .39456 .59605 .39348 Metetra
.664 .741 .907 r
.59605 .39348 .59697 .39456 .60293 .39261 .60202 .39152 Metetra
.664 .741 .907 r
.60202 .39152 .60293 .39261 .60891 .39066 .60799 .38957 Metetra
.664 .741 .907 r
.60799 .38957 .60891 .39066 .61489 .3887 .61398 .3876 Metetra
.664 .741 .907 r
.61398 .3876 .61489 .3887 .62089 .38674 .61998 .38564 Metetra
.664 .741 .907 r
.61998 .38564 .62089 .38674 .62691 .38477 .626 .38367 Metetra
.664 .741 .907 r
.626 .38367 .62691 .38477 .63293 .3828 .63203 .3817 Metetra
.664 .741 .907 r
.63203 .3817 .63293 .3828 .63897 .38082 .63807 .37972 Metetra
.664 .741 .907 r
.63807 .37972 .63897 .38082 .64502 .37884 .64412 .37773 Metetra
.664 .741 .907 r
.64412 .37773 .64502 .37884 .65109 .37686 .65019 .37575 Metetra
.664 .741 .907 r
.65019 .37575 .65109 .37686 .65716 .37487 .65627 .37376 Metetra
.955 .61 .269 r
.65627 .37376 .65716 .37487 .66413 .3932 .66419 .41408 Metetra
.468 .251 .501 r
.66419 .41408 .66413 .3932 .66936 .37088 .66977 .39867 Metetra
.419 .22 .501 r
.66977 .39867 .66936 .37088 .67548 .36888 .67459 .36776 Metetra
.664 .741 .907 r
.67459 .36776 .67548 .36888 .68161 .36687 .68072 .36575 Metetra
.664 .741 .907 r
.68072 .36575 .68161 .36687 .68775 .36486 .68687 .36374 Metetra
.664 .741 .907 r
.68687 .36374 .68775 .36486 .69391 .36285 .69303 .36172 Metetra
.664 .741 .907 r
.69303 .36172 .69391 .36285 .70008 .36083 .6992 .3597 Metetra
.664 .741 .907 r
.6992 .3597 .70008 .36083 .70626 .3588 .70539 .35767 Metetra
.664 .741 .907 r
.70539 .35767 .70626 .3588 .71246 .35678 .71159 .35564 Metetra
.664 .741 .907 r
.71159 .35564 .71246 .35678 .71867 .35474 .7178 .35361 Metetra
.664 .741 .907 r
.7178 .35361 .71867 .35474 .72489 .35271 .72403 .35157 Metetra
.664 .741 .907 r
.72403 .35157 .72489 .35271 .73113 .35067 .73027 .34952 Metetra
.664 .741 .907 r
.73027 .34952 .73113 .35067 .73738 .34862 .73653 .34748 Metetra
.664 .741 .907 r
.73653 .34748 .73738 .34862 .74365 .34657 .7428 .34542 Metetra
.664 .741 .907 r
.7428 .34542 .74365 .34657 .74993 .34451 .74908 .34337 Metetra
.664 .741 .907 r
.74908 .34337 .74993 .34451 .75622 .34246 .75537 .34131 Metetra
.664 .741 .907 r
.75537 .34131 .75622 .34246 .76253 .34039 .76168 .33924 Metetra
.664 .741 .907 r
.76168 .33924 .76253 .34039 .76885 .33832 .76801 .33717 Metetra
.664 .741 .907 r
.76801 .33717 .76885 .33832 .77519 .33625 .77435 .33509 Metetra
.664 .741 .907 r
.77435 .33509 .77519 .33625 .78153 .33417 .7807 .33301 Metetra
.664 .741 .907 r
.7807 .33301 .78153 .33417 .7879 .33209 .78706 .33093 Metetra
.664 .741 .907 r
.78706 .33093 .7879 .33209 .79427 .33001 .79344 .32884 Metetra
.664 .741 .907 r
.79344 .32884 .79427 .33001 .80066 .32791 .79984 .32675 Metetra
.664 .741 .907 r
.79984 .32675 .80066 .32791 .80707 .32582 .80625 .32465 Metetra
.664 .741 .907 r
.80625 .32465 .80707 .32582 .81349 .32372 .81267 .32254 Metetra
.664 .741 .907 r
.81267 .32254 .81349 .32372 .81992 .32161 .81911 .32044 Metetra
.664 .741 .907 r
.81911 .32044 .81992 .32161 .82637 .3195 .82556 .31832 Metetra
.664 .741 .907 r
.82556 .31832 .82637 .3195 .83283 .31739 .83202 .31621 Metetra
.664 .741 .907 r
.83202 .31621 .83283 .31739 .83931 .31527 .8385 .31408 Metetra
.664 .741 .907 r
.8385 .31408 .83931 .31527 .8458 .31314 .845 .31196 Metetra
.664 .741 .907 r
.845 .31196 .8458 .31314 .85231 .31102 .85151 .30983 Metetra
.664 .741 .907 r
.85151 .30983 .85231 .31102 .85883 .30888 .85803 .30769 Metetra
.664 .741 .907 r
.85803 .30769 .85883 .30888 .86536 .30674 .86457 .30555 Metetra
.664 .741 .907 r
.86457 .30555 .86536 .30674 .87191 .3046 .87112 .3034 Metetra
.664 .741 .907 r
.87112 .3034 .87191 .3046 .87848 .30245 .87769 .30125 Metetra
.664 .741 .907 r
.87769 .30125 .87848 .30245 .88506 .3003 .88427 .2991 Metetra
.664 .741 .907 r
.29088 .49209 .29192 .49307 .29725 .49132 .29621 .49035 Metetra
.664 .741 .907 r
.29621 .49035 .29725 .49132 .30259 .48957 .30155 .4886 Metetra
.664 .741 .907 r
.30155 .4886 .30259 .48957 .30794 .48782 .3069 .48684 Metetra
.664 .741 .907 r
.3069 .48684 .30794 .48782 .3133 .48606 .31227 .48508 Metetra
.664 .741 .907 r
.31227 .48508 .3133 .48606 .31868 .4843 .31764 .48332 Metetra
.664 .741 .907 r
.31764 .48332 .31868 .4843 .32406 .48254 .32303 .48156 Metetra
.664 .741 .907 r
.32303 .48156 .32406 .48254 .32946 .48077 .32843 .47979 Metetra
.664 .741 .907 r
.32843 .47979 .32946 .48077 .33486 .479 .33384 .47801 Metetra
.664 .741 .907 r
.33384 .47801 .33486 .479 .34028 .47723 .33926 .47624 Metetra
.664 .741 .907 r
.33926 .47624 .34028 .47723 .34571 .47545 .34469 .47446 Metetra
.664 .741 .907 r
.34469 .47446 .34571 .47545 .35115 .47367 .35013 .47268 Metetra
.664 .741 .907 r
.35013 .47268 .35115 .47367 .3566 .47189 .35558 .47089 Metetra
.664 .741 .907 r
.35558 .47089 .3566 .47189 .36206 .4701 .36104 .4691 Metetra
.664 .741 .907 r
.36104 .4691 .36206 .4701 .36753 .46831 .36652 .4673 Metetra
.664 .741 .907 r
.36652 .4673 .36753 .46831 .37302 .46651 .37201 .46551 Metetra
.664 .741 .907 r
.37201 .46551 .37302 .46651 .37851 .46471 .3775 .4637 Metetra
.664 .741 .907 r
.3775 .4637 .37851 .46471 .38402 .46291 .38301 .4619 Metetra
.664 .741 .907 r
.38301 .4619 .38402 .46291 .38954 .4611 .38853 .46009 Metetra
.664 .741 .907 r
.38853 .46009 .38954 .4611 .39507 .45929 .39406 .45828 Metetra
.664 .741 .907 r
.39406 .45828 .39507 .45929 .40061 .45747 .39961 .45646 Metetra
.664 .741 .907 r
.39961 .45646 .40061 .45747 .40616 .45566 .40516 .45464 Metetra
.664 .741 .907 r
.40516 .45464 .40616 .45566 .41172 .45383 .41073 .45282 Metetra
.664 .741 .907 r
.41073 .45282 .41172 .45383 .4173 .45201 .41631 .45099 Metetra
.664 .741 .907 r
.41631 .45099 .4173 .45201 .42289 .45018 .42189 .44916 Metetra
.664 .741 .907 r
.42189 .44916 .42289 .45018 .42849 .44835 .4275 .44732 Metetra
.664 .741 .907 r
.4275 .44732 .42849 .44835 .4341 .44651 .43311 .44548 Metetra
.954 .679 .475 r
.43311 .44548 .4341 .44651 .43511 .62146 .43355 .64017 Metetra
.714 .63 .066 r
.43355 .64017 .43511 .62146 .4408 .62952 .44199 .53827 Metetra
.654 .424 .559 r
.44199 .53827 .4408 .62952 .451 .44098 .45002 .43994 Metetra
.664 .741 .907 r
.45002 .43994 .451 .44098 .45665 .43912 .45567 .43809 Metetra
.664 .741 .907 r
.45567 .43809 .45665 .43912 .46232 .43727 .46135 .43623 Metetra
.664 .741 .907 r
.46135 .43623 .46232 .43727 .468 .43541 .46703 .43437 Metetra
.664 .741 .907 r
.46703 .43437 .468 .43541 .4737 .43354 .47272 .4325 Metetra
.664 .741 .907 r
.47272 .4325 .4737 .43354 .4794 .43167 .47843 .43063 Metetra
.664 .741 .907 r
.47843 .43063 .4794 .43167 .48512 .4298 .48415 .42876 Metetra
.664 .741 .907 r
.48415 .42876 .48512 .4298 .49085 .42793 .48988 .42688 Metetra
.664 .741 .907 r
.48988 .42688 .49085 .42793 .49659 .42605 .49562 .425 Metetra
.664 .741 .907 r
.49562 .425 .49659 .42605 .50234 .42416 .50138 .42311 Metetra
.664 .741 .907 r
.50138 .42311 .50234 .42416 .5081 .42228 .50715 .42122 Metetra
.664 .741 .907 r
.50715 .42122 .5081 .42228 .51388 .42038 .51292 .41933 Metetra
.664 .741 .907 r
.51292 .41933 .51388 .42038 .51967 .41849 .51872 .41743 Metetra
.664 .741 .907 r
.51872 .41743 .51967 .41849 .52547 .41659 .52452 .41553 Metetra
.664 .741 .907 r
.52452 .41553 .52547 .41659 .53128 .41468 .53034 .41362 Metetra
.664 .741 .907 r
.53034 .41362 .53128 .41468 .53711 .41278 .53616 .41171 Metetra
.664 .741 .907 r
.53616 .41171 .53711 .41278 .54295 .41087 .542 .4098 Metetra
.664 .741 .907 r
.542 .4098 .54295 .41087 .5488 .40895 .54786 .40788 Metetra
.664 .741 .907 r
.54786 .40788 .5488 .40895 .55466 .40703 .55372 .40596 Metetra
.664 .741 .907 r
.55372 .40596 .55466 .40703 .56054 .40511 .5596 .40403 Metetra
.664 .741 .907 r
.5596 .40403 .56054 .40511 .56642 .40318 .56549 .4021 Metetra
.664 .741 .907 r
.56549 .4021 .56642 .40318 .57232 .40125 .57139 .40017 Metetra
.664 .741 .907 r
.57139 .40017 .57232 .40125 .57824 .39931 .57731 .39823 Metetra
.664 .741 .907 r
.57731 .39823 .57824 .39931 .58416 .39737 .58324 .39628 Metetra
.664 .741 .907 r
.58324 .39628 .58416 .39737 .5901 .39542 .58918 .39434 Metetra
.664 .741 .907 r
.58918 .39434 .5901 .39542 .59605 .39348 .59513 .39239 Metetra
.664 .741 .907 r
.59513 .39239 .59605 .39348 .60202 .39152 .6011 .39043 Metetra
.664 .741 .907 r
.6011 .39043 .60202 .39152 .60799 .38957 .60708 .38847 Metetra
.664 .741 .907 r
.60708 .38847 .60799 .38957 .61398 .3876 .61307 .38651 Metetra
.664 .741 .907 r
.61307 .38651 .61398 .3876 .61998 .38564 .61907 .38454 Metetra
.664 .741 .907 r
.61907 .38454 .61998 .38564 .626 .38367 .62509 .38257 Metetra
.664 .741 .907 r
.62509 .38257 .626 .38367 .63203 .3817 .63112 .38059 Metetra
.664 .741 .907 r
.63112 .38059 .63203 .3817 .63807 .37972 .63717 .37861 Metetra
.664 .741 .907 r
.63717 .37861 .63807 .37972 .64412 .37773 .64322 .37663 Metetra
.664 .741 .907 r
.64322 .37663 .64412 .37773 .65019 .37575 .64929 .37464 Metetra
.922 .538 .146 r
.64929 .37464 .65019 .37575 .65627 .37376 .65641 .3979 Metetra
.431 .226 .499 r
.65641 .3979 .65627 .37376 .66419 .41408 .66159 .3734 Metetra
.564 .357 .559 r
.66159 .3734 .66419 .41408 .66977 .39867 .66765 .37017 Metetra
.569 .366 .565 r
.66765 .37017 .66977 .39867 .67459 .36776 .6737 .36664 Metetra
.664 .741 .907 r
.6737 .36664 .67459 .36776 .68072 .36575 .67984 .36463 Metetra
.664 .741 .907 r
.67984 .36463 .68072 .36575 .68687 .36374 .68599 .36261 Metetra
.664 .741 .907 r
.68599 .36261 .68687 .36374 .69303 .36172 .69215 .36059 Metetra
.664 .741 .907 r
.69215 .36059 .69303 .36172 .6992 .3597 .69833 .35857 Metetra
.664 .741 .907 r
.69833 .35857 .6992 .3597 .70539 .35767 .70452 .35654 Metetra
.664 .741 .907 r
.70452 .35654 .70539 .35767 .71159 .35564 .71072 .35451 Metetra
.664 .741 .907 r
.71072 .35451 .71159 .35564 .7178 .35361 .71694 .35247 Metetra
.664 .741 .907 r
.71694 .35247 .7178 .35361 .72403 .35157 .72317 .35043 Metetra
.664 .741 .907 r
.72317 .35043 .72403 .35157 .73027 .34952 .72941 .34838 Metetra
.664 .741 .907 r
.72941 .34838 .73027 .34952 .73653 .34748 .73567 .34633 Metetra
.664 .741 .907 r
.73567 .34633 .73653 .34748 .7428 .34542 .74194 .34428 Metetra
.664 .741 .907 r
.74194 .34428 .7428 .34542 .74908 .34337 .74823 .34222 Metetra
.664 .741 .907 r
.74823 .34222 .74908 .34337 .75537 .34131 .75453 .34015 Metetra
.664 .741 .907 r
.75453 .34015 .75537 .34131 .76168 .33924 .76084 .33808 Metetra
.664 .741 .907 r
.76084 .33808 .76168 .33924 .76801 .33717 .76716 .33601 Metetra
.664 .741 .907 r
.76716 .33601 .76801 .33717 .77435 .33509 .77351 .33393 Metetra
.664 .741 .907 r
.77351 .33393 .77435 .33509 .7807 .33301 .77986 .33185 Metetra
.664 .741 .907 r
.77986 .33185 .7807 .33301 .78706 .33093 .78623 .32976 Metetra
.664 .741 .907 r
.78623 .32976 .78706 .33093 .79344 .32884 .79261 .32767 Metetra
.664 .741 .907 r
.79261 .32767 .79344 .32884 .79984 .32675 .79901 .32558 Metetra
.664 .741 .907 r
.79901 .32558 .79984 .32675 .80625 .32465 .80542 .32347 Metetra
.664 .741 .907 r
.80542 .32347 .80625 .32465 .81267 .32254 .81185 .32137 Metetra
.664 .741 .907 r
.81185 .32137 .81267 .32254 .81911 .32044 .81829 .31926 Metetra
.664 .741 .907 r
.81829 .31926 .81911 .32044 .82556 .31832 .82474 .31714 Metetra
.664 .741 .907 r
.82474 .31714 .82556 .31832 .83202 .31621 .83121 .31502 Metetra
.664 .741 .907 r
.83121 .31502 .83202 .31621 .8385 .31408 .83769 .3129 Metetra
.664 .741 .907 r
.83769 .3129 .8385 .31408 .845 .31196 .84419 .31077 Metetra
.664 .741 .907 r
.84419 .31077 .845 .31196 .85151 .30983 .8507 .30864 Metetra
.664 .741 .907 r
.8507 .30864 .85151 .30983 .85803 .30769 .85723 .3065 Metetra
.664 .741 .907 r
.85723 .3065 .85803 .30769 .86457 .30555 .86377 .30435 Metetra
.664 .741 .907 r
.86377 .30435 .86457 .30555 .87112 .3034 .87033 .30221 Metetra
.664 .741 .907 r
.87033 .30221 .87112 .3034 .87769 .30125 .8769 .30005 Metetra
.664 .741 .907 r
.8769 .30005 .87769 .30125 .88427 .2991 .88348 .29789 Metetra
.664 .741 .907 r
.28983 .49112 .29088 .49209 .29621 .49035 .29517 .48937 Metetra
.664 .741 .907 r
.29517 .48937 .29621 .49035 .30155 .4886 .30051 .48762 Metetra
.664 .741 .907 r
.30051 .48762 .30155 .4886 .3069 .48684 .30587 .48586 Metetra
.664 .741 .907 r
.30587 .48586 .3069 .48684 .31227 .48508 .31123 .4841 Metetra
.664 .741 .907 r
.31123 .4841 .31227 .48508 .31764 .48332 .31661 .48234 Metetra
.664 .741 .907 r
.31661 .48234 .31764 .48332 .32303 .48156 .322 .48057 Metetra
.664 .741 .907 r
.322 .48057 .32303 .48156 .32843 .47979 .3274 .4788 Metetra
.947 .639 .419 r
.3274 .4788 .32843 .47979 .33384 .47801 .3307 .5133 Metetra
.396 .196 .487 r
.3307 .5133 .33384 .47801 .33926 .47624 .33823 .47525 Metetra
.664 .741 .907 r
.33823 .47525 .33926 .47624 .34469 .47446 .34366 .47347 Metetra
.664 .741 .907 r
.34366 .47347 .34469 .47446 .35013 .47268 .34911 .47168 Metetra
.664 .741 .907 r
.34911 .47168 .35013 .47268 .35558 .47089 .35456 .46989 Metetra
.664 .741 .907 r
.35456 .46989 .35558 .47089 .36104 .4691 .36003 .4681 Metetra
.664 .741 .907 r
.36003 .4681 .36104 .4691 .36652 .4673 .3655 .4663 Metetra
.664 .741 .907 r
.3655 .4663 .36652 .4673 .37201 .46551 .37099 .4645 Metetra
.664 .741 .907 r
.37099 .4645 .37201 .46551 .3775 .4637 .37649 .4627 Metetra
.664 .741 .907 r
.37649 .4627 .3775 .4637 .38301 .4619 .382 .46089 Metetra
.664 .741 .907 r
.382 .46089 .38301 .4619 .38853 .46009 .38753 .45908 Metetra
.664 .741 .907 r
.38753 .45908 .38853 .46009 .39406 .45828 .39306 .45727 Metetra
.664 .741 .907 r
.39306 .45727 .39406 .45828 .39961 .45646 .39861 .45545 Metetra
.664 .741 .907 r
.39861 .45545 .39961 .45646 .40516 .45464 .40416 .45362 Metetra
.664 .741 .907 r
.40416 .45362 .40516 .45464 .41073 .45282 .40973 .4518 Metetra
.664 .741 .907 r
.40973 .4518 .41073 .45282 .41631 .45099 .41531 .44997 Metetra
.664 .741 .907 r
.41531 .44997 .41631 .45099 .42189 .44916 .4209 .44813 Metetra
.664 .741 .907 r
.4209 .44813 .42189 .44916 .4275 .44732 .4265 .4463 Metetra
.664 .741 .907 r
.4265 .4463 .4275 .44732 .43311 .44548 .43212 .44446 Metetra
.955 .676 .468 r
.43212 .44446 .43311 .44548 .43355 .64017 .43382 .58972 Metetra
.718 .48 .565 r
.43382 .58972 .43355 .64017 .44199 .53827 .44237 .48136 Metetra
.627 .404 .561 r
.44237 .48136 .44199 .53827 .45002 .43994 .44903 .43891 Metetra
.664 .741 .907 r
.44903 .43891 .45002 .43994 .45567 .43809 .4547 .43705 Metetra
.664 .741 .907 r
.4547 .43705 .45567 .43809 .46135 .43623 .46037 .43519 Metetra
.664 .741 .907 r
.46037 .43519 .46135 .43623 .46703 .43437 .46605 .43333 Metetra
.664 .741 .907 r
.46605 .43333 .46703 .43437 .47272 .4325 .47175 .43146 Metetra
.664 .741 .907 r
.47175 .43146 .47272 .4325 .47843 .43063 .47746 .42959 Metetra
.664 .741 .907 r
.47746 .42959 .47843 .43063 .48415 .42876 .48318 .42771 Metetra
.664 .741 .907 r
.48318 .42771 .48415 .42876 .48988 .42688 .48891 .42583 Metetra
.664 .741 .907 r
.48891 .42583 .48988 .42688 .49562 .425 .49466 .42395 Metetra
.664 .741 .907 r
.49466 .42395 .49562 .425 .50138 .42311 .50042 .42206 Metetra
.664 .741 .907 r
.50042 .42206 .50138 .42311 .50715 .42122 .50619 .42016 Metetra
.664 .741 .907 r
.50619 .42016 .50715 .42122 .51292 .41933 .51197 .41827 Metetra
.664 .741 .907 r
.51197 .41827 .51292 .41933 .51872 .41743 .51776 .41637 Metetra
.664 .741 .907 r
.51776 .41637 .51872 .41743 .52452 .41553 .52357 .41446 Metetra
.664 .741 .907 r
.52357 .41446 .52452 .41553 .53034 .41362 .52939 .41256 Metetra
.664 .741 .907 r
.52939 .41256 .53034 .41362 .53616 .41171 .53522 .41064 Metetra
.664 .741 .907 r
.53522 .41064 .53616 .41171 .542 .4098 .54106 .40873 Metetra
.664 .741 .907 r
.54106 .40873 .542 .4098 .54786 .40788 .54692 .40681 Metetra
.664 .741 .907 r
.54692 .40681 .54786 .40788 .55372 .40596 .55278 .40488 Metetra
.664 .741 .907 r
.55278 .40488 .55372 .40596 .5596 .40403 .55866 .40295 Metetra
.664 .741 .907 r
.55866 .40295 .5596 .40403 .56549 .4021 .56456 .40102 Metetra
.664 .741 .907 r
.56456 .40102 .56549 .4021 .57139 .40017 .57046 .39909 Metetra
.664 .741 .907 r
.57046 .39909 .57139 .40017 .57731 .39823 .57638 .39714 Metetra
.664 .741 .907 r
.57638 .39714 .57731 .39823 .58324 .39628 .58231 .3952 Metetra
.664 .741 .907 r
.58231 .3952 .58324 .39628 .58918 .39434 .58825 .39325 Metetra
.664 .741 .907 r
.58825 .39325 .58918 .39434 .59513 .39239 .59421 .3913 Metetra
.664 .741 .907 r
.59421 .3913 .59513 .39239 .6011 .39043 .60018 .38934 Metetra
.664 .741 .907 r
.60018 .38934 .6011 .39043 .60708 .38847 .60616 .38738 Metetra
.664 .741 .907 r
.60616 .38738 .60708 .38847 .61307 .38651 .61216 .38541 Metetra
.664 .741 .907 r
.61216 .38541 .61307 .38651 .61907 .38454 .61816 .38344 Metetra
.664 .741 .907 r
.61816 .38344 .61907 .38454 .62509 .38257 .62418 .38147 Metetra
.664 .741 .907 r
.62418 .38147 .62509 .38257 .63112 .38059 .63022 .37949 Metetra
.664 .741 .907 r
.63022 .37949 .63112 .38059 .63717 .37861 .63626 .37751 Metetra
.664 .741 .907 r
.63626 .37751 .63717 .37861 .64322 .37663 .64232 .37552 Metetra
.664 .741 .907 r
.64232 .37552 .64322 .37663 .64929 .37464 .6484 .37353 Metetra
0 .106 .634 r
.6484 .37353 .64929 .37464 .65641 .3979 .65481 .37956 Metetra
.477 .307 .57 r
.65481 .37956 .65641 .3979 .66159 .3734 .66156 .39258 Metetra
.389 .188 .483 r
.66156 .39258 .66159 .3734 .66765 .37017 .66669 .36753 Metetra
.633 .556 .75 r
.66669 .36753 .66765 .37017 .6737 .36664 .67282 .36552 Metetra
.664 .741 .907 r
.67282 .36552 .6737 .36664 .67984 .36463 .67896 .3635 Metetra
.664 .741 .907 r
.67896 .3635 .67984 .36463 .68599 .36261 .68511 .36149 Metetra
.664 .741 .907 r
.68511 .36149 .68599 .36261 .69215 .36059 .69127 .35946 Metetra
.664 .741 .907 r
.69127 .35946 .69215 .36059 .69833 .35857 .69745 .35744 Metetra
.664 .741 .907 r
.69745 .35744 .69833 .35857 .70452 .35654 .70364 .35541 Metetra
.664 .741 .907 r
.70364 .35541 .70452 .35654 .71072 .35451 .70985 .35337 Metetra
.664 .741 .907 r
.70985 .35337 .71072 .35451 .71694 .35247 .71607 .35133 Metetra
.664 .741 .907 r
.71607 .35133 .71694 .35247 .72317 .35043 .7223 .34929 Metetra
.664 .741 .907 r
.7223 .34929 .72317 .35043 .72941 .34838 .72855 .34724 Metetra
.664 .741 .907 r
.72855 .34724 .72941 .34838 .73567 .34633 .73481 .34519 Metetra
.664 .741 .907 r
.73481 .34519 .73567 .34633 .74194 .34428 .74109 .34313 Metetra
.664 .741 .907 r
.74109 .34313 .74194 .34428 .74823 .34222 .74737 .34107 Metetra
.664 .741 .907 r
.74737 .34107 .74823 .34222 .75453 .34015 .75368 .339 Metetra
.664 .741 .907 r
.75368 .339 .75453 .34015 .76084 .33808 .75999 .33693 Metetra
.664 .741 .907 r
.75999 .33693 .76084 .33808 .76716 .33601 .76632 .33485 Metetra
.664 .741 .907 r
.76632 .33485 .76716 .33601 .77351 .33393 .77266 .33277 Metetra
.664 .741 .907 r
.77266 .33277 .77351 .33393 .77986 .33185 .77902 .33069 Metetra
.664 .741 .907 r
.77902 .33069 .77986 .33185 .78623 .32976 .78539 .3286 Metetra
.664 .741 .907 r
.78539 .3286 .78623 .32976 .79261 .32767 .79178 .3265 Metetra
.664 .741 .907 r
.79178 .3265 .79261 .32767 .79901 .32558 .79818 .3244 Metetra
.664 .741 .907 r
.79818 .3244 .79901 .32558 .80542 .32347 .80459 .3223 Metetra
.664 .741 .907 r
.80459 .3223 .80542 .32347 .81185 .32137 .81102 .32019 Metetra
.664 .741 .907 r
.81102 .32019 .81185 .32137 .81829 .31926 .81747 .31808 Metetra
.664 .741 .907 r
.81747 .31808 .81829 .31926 .82474 .31714 .82392 .31596 Metetra
.664 .741 .907 r
.82392 .31596 .82474 .31714 .83121 .31502 .8304 .31384 Metetra
.664 .741 .907 r
.8304 .31384 .83121 .31502 .83769 .3129 .83688 .31171 Metetra
.664 .741 .907 r
.83688 .31171 .83769 .3129 .84419 .31077 .84338 .30958 Metetra
.664 .741 .907 r
.84338 .30958 .84419 .31077 .8507 .30864 .8499 .30744 Metetra
.664 .741 .907 r
.8499 .30744 .8507 .30864 .85723 .3065 .85643 .3053 Metetra
.664 .741 .907 r
.85643 .3053 .85723 .3065 .86377 .30435 .86297 .30316 Metetra
.664 .741 .907 r
.86297 .30316 .86377 .30435 .87033 .30221 .86953 .301 Metetra
.664 .741 .907 r
.86953 .301 .87033 .30221 .8769 .30005 .87611 .29885 Metetra
.664 .741 .907 r
.87611 .29885 .8769 .30005 .88348 .29789 .88269 .29669 Metetra
.664 .741 .907 r
.28879 .49014 .28983 .49112 .29517 .48937 .29412 .48839 Metetra
.664 .741 .907 r
.29412 .48839 .29517 .48937 .30051 .48762 .29947 .48664 Metetra
.664 .741 .907 r
.29947 .48664 .30051 .48762 .30587 .48586 .30483 .48488 Metetra
.664 .741 .907 r
.30483 .48488 .30587 .48586 .31123 .4841 .3102 .48312 Metetra
.664 .741 .907 r
.3102 .48312 .31123 .4841 .31661 .48234 .31558 .48135 Metetra
.664 .741 .907 r
.31558 .48135 .31661 .48234 .322 .48057 .32097 .47958 Metetra
.664 .741 .907 r
.32097 .47958 .322 .48057 .3274 .4788 .32637 .47781 Metetra
.947 .654 .45 r
.32637 .47781 .3274 .4788 .3307 .5133 .32888 .52556 Metetra
0 0 .011 r
.32888 .52556 .3307 .5133 .33823 .47525 .3372 .47425 Metetra
.664 .741 .907 r
.3372 .47425 .33823 .47525 .34366 .47347 .34264 .47247 Metetra
.664 .741 .907 r
.34264 .47247 .34366 .47347 .34911 .47168 .34808 .47068 Metetra
.664 .741 .907 r
.34808 .47068 .34911 .47168 .35456 .46989 .35354 .46889 Metetra
.664 .741 .907 r
.35354 .46889 .35456 .46989 .36003 .4681 .35901 .4671 Metetra
.664 .741 .907 r
.35901 .4671 .36003 .4681 .3655 .4663 .36449 .4653 Metetra
.664 .741 .907 r
.36449 .4653 .3655 .4663 .37099 .4645 .36998 .4635 Metetra
.664 .741 .907 r
.36998 .4635 .37099 .4645 .37649 .4627 .37548 .46169 Metetra
.664 .741 .907 r
.37548 .46169 .37649 .4627 .382 .46089 .38099 .45988 Metetra
.664 .741 .907 r
.38099 .45988 .382 .46089 .38753 .45908 .38652 .45807 Metetra
.664 .741 .907 r
.38652 .45807 .38753 .45908 .39306 .45727 .39205 .45625 Metetra
.664 .741 .907 r
.39205 .45625 .39306 .45727 .39861 .45545 .3976 .45443 Metetra
.664 .741 .907 r
.3976 .45443 .39861 .45545 .40416 .45362 .40316 .45261 Metetra
.664 .741 .907 r
.40316 .45261 .40416 .45362 .40973 .4518 .40873 .45078 Metetra
.664 .741 .907 r
.40873 .45078 .40973 .4518 .41531 .44997 .41431 .44895 Metetra
.664 .741 .907 r
.41431 .44895 .41531 .44997 .4209 .44813 .41991 .44711 Metetra
.664 .741 .907 r
.41991 .44711 .4209 .44813 .4265 .4463 .42551 .44527 Metetra
.664 .741 .907 r
.42551 .44527 .4265 .4463 .43212 .44446 .43113 .44343 Metetra
.954 .63 .372 r
.43113 .44343 .43212 .44446 .43382 .58972 .43579 .4776 Metetra
.558 .345 .548 r
.43579 .4776 .43382 .58972 .44237 .48136 .44152 .47429 Metetra
.816 .588 .594 r
.44152 .47429 .44237 .48136 .44903 .43891 .44805 .43787 Metetra
.664 .741 .907 r
.44805 .43787 .44903 .43891 .4547 .43705 .45371 .43601 Metetra
.664 .741 .907 r
.45371 .43601 .4547 .43705 .46037 .43519 .45939 .43415 Metetra
.664 .741 .907 r
.45939 .43415 .46037 .43519 .46605 .43333 .46508 .43228 Metetra
.664 .741 .907 r
.46508 .43228 .46605 .43333 .47175 .43146 .47078 .43041 Metetra
.664 .741 .907 r
.47078 .43041 .47175 .43146 .47746 .42959 .47649 .42854 Metetra
.664 .741 .907 r
.47649 .42854 .47746 .42959 .48318 .42771 .48221 .42666 Metetra
.664 .741 .907 r
.48221 .42666 .48318 .42771 .48891 .42583 .48795 .42478 Metetra
.664 .741 .907 r
.48795 .42478 .48891 .42583 .49466 .42395 .4937 .42289 Metetra
.664 .741 .907 r
.4937 .42289 .49466 .42395 .50042 .42206 .49945 .421 Metetra
.664 .741 .907 r
.49945 .421 .50042 .42206 .50619 .42016 .50523 .41911 Metetra
.664 .741 .907 r
.50523 .41911 .50619 .42016 .51197 .41827 .51101 .41721 Metetra
.664 .741 .907 r
.51101 .41721 .51197 .41827 .51776 .41637 .51681 .41531 Metetra
.664 .741 .907 r
.51681 .41531 .51776 .41637 .52357 .41446 .52262 .4134 Metetra
.664 .741 .907 r
.52262 .4134 .52357 .41446 .52939 .41256 .52844 .41149 Metetra
.785 .325 0 r
.52844 .41149 .52939 .41256 .53522 .41064 .5343 .42166 Metetra
.378 .157 .447 r
.5343 .42166 .53522 .41064 .54106 .40873 .54011 .40766 Metetra
.664 .741 .907 r
.54011 .40766 .54106 .40873 .54692 .40681 .54597 .40573 Metetra
.664 .741 .907 r
.54597 .40573 .54692 .40681 .55278 .40488 .55184 .40381 Metetra
.664 .741 .907 r
.55184 .40381 .55278 .40488 .55866 .40295 .55773 .40188 Metetra
.664 .741 .907 r
.55773 .40188 .55866 .40295 .56456 .40102 .56362 .39994 Metetra
.664 .741 .907 r
.56362 .39994 .56456 .40102 .57046 .39909 .56953 .398 Metetra
.664 .741 .907 r
.56953 .398 .57046 .39909 .57638 .39714 .57545 .39606 Metetra
.664 .741 .907 r
.57545 .39606 .57638 .39714 .58231 .3952 .58138 .39411 Metetra
.664 .741 .907 r
.58138 .39411 .58231 .3952 .58825 .39325 .58733 .39216 Metetra
.664 .741 .907 r
.58733 .39216 .58825 .39325 .59421 .3913 .59329 .39021 Metetra
.664 .741 .907 r
.59329 .39021 .59421 .3913 .60018 .38934 .59926 .38825 Metetra
.664 .741 .907 r
.59926 .38825 .60018 .38934 .60616 .38738 .60524 .38628 Metetra
.664 .741 .907 r
.60524 .38628 .60616 .38738 .61216 .38541 .61124 .38431 Metetra
.664 .741 .907 r
.61124 .38431 .61216 .38541 .61816 .38344 .61725 .38234 Metetra
.664 .741 .907 r
.61725 .38234 .61816 .38344 .62418 .38147 .62327 .38036 Metetra
.664 .741 .907 r
.62327 .38036 .62418 .38147 .63022 .37949 .62931 .37838 Metetra
.664 .741 .907 r
.62931 .37838 .63022 .37949 .63626 .37751 .63536 .3764 Metetra
.664 .741 .907 r
.63536 .3764 .63626 .37751 .64232 .37552 .64142 .37441 Metetra
.664 .741 .907 r
.64142 .37441 .64232 .37552 .6484 .37353 .6475 .37241 Metetra
.664 .741 .907 r
.6475 .37241 .6484 .37353 .65481 .37956 .65358 .37042 Metetra
.583 .408 .61 r
.65358 .37042 .65481 .37956 .66156 .39258 .65969 .36841 Metetra
.565 .365 .569 r
.65969 .36841 .66156 .39258 .66669 .36753 .6658 .36641 Metetra
.664 .741 .907 r
.6658 .36641 .66669 .36753 .67282 .36552 .67193 .3644 Metetra
.664 .741 .907 r
.67193 .3644 .67282 .36552 .67896 .3635 .67807 .36238 Metetra
.664 .741 .907 r
.67807 .36238 .67896 .3635 .68511 .36149 .68423 .36036 Metetra
.664 .741 .907 r
.68423 .36036 .68511 .36149 .69127 .35946 .69039 .35834 Metetra
.664 .741 .907 r
.69039 .35834 .69127 .35946 .69745 .35744 .69658 .35631 Metetra
.664 .741 .907 r
.69658 .35631 .69745 .35744 .70364 .35541 .70277 .35427 Metetra
.664 .741 .907 r
.70277 .35427 .70364 .35541 .70985 .35337 .70898 .35224 Metetra
.664 .741 .907 r
.70898 .35224 .70985 .35337 .71607 .35133 .7152 .35019 Metetra
.664 .741 .907 r
.7152 .35019 .71607 .35133 .7223 .34929 .72144 .34815 Metetra
.664 .741 .907 r
.72144 .34815 .7223 .34929 .72855 .34724 .72769 .3461 Metetra
.664 .741 .907 r
.72769 .3461 .72855 .34724 .73481 .34519 .73395 .34404 Metetra
.664 .741 .907 r
.73395 .34404 .73481 .34519 .74109 .34313 .74023 .34198 Metetra
.664 .741 .907 r
.74023 .34198 .74109 .34313 .74737 .34107 .74652 .33991 Metetra
.664 .741 .907 r
.74652 .33991 .74737 .34107 .75368 .339 .75282 .33785 Metetra
.664 .741 .907 r
.75282 .33785 .75368 .339 .75999 .33693 .75914 .33577 Metetra
.664 .741 .907 r
.75914 .33577 .75999 .33693 .76632 .33485 .76548 .33369 Metetra
.664 .741 .907 r
.76548 .33369 .76632 .33485 .77266 .33277 .77182 .33161 Metetra
.664 .741 .907 r
.77182 .33161 .77266 .33277 .77902 .33069 .77818 .32952 Metetra
.664 .741 .907 r
.77818 .32952 .77902 .33069 .78539 .3286 .78456 .32743 Metetra
.664 .741 .907 r
.78456 .32743 .78539 .3286 .79178 .3265 .79095 .32533 Metetra
.664 .741 .907 r
.79095 .32533 .79178 .3265 .79818 .3244 .79735 .32323 Metetra
.664 .741 .907 r
.79735 .32323 .79818 .3244 .80459 .3223 .80377 .32113 Metetra
.664 .741 .907 r
.80377 .32113 .80459 .3223 .81102 .32019 .8102 .31901 Metetra
.664 .741 .907 r
.8102 .31901 .81102 .32019 .81747 .31808 .81665 .3169 Metetra
.664 .741 .907 r
.81665 .3169 .81747 .31808 .82392 .31596 .82311 .31478 Metetra
.664 .741 .907 r
.82311 .31478 .82392 .31596 .8304 .31384 .82958 .31265 Metetra
.664 .741 .907 r
.82958 .31265 .8304 .31384 .83688 .31171 .83607 .31052 Metetra
.664 .741 .907 r
.83607 .31052 .83688 .31171 .84338 .30958 .84257 .30839 Metetra
.664 .741 .907 r
.84257 .30839 .84338 .30958 .8499 .30744 .84909 .30625 Metetra
.664 .741 .907 r
.84909 .30625 .8499 .30744 .85643 .3053 .85563 .30411 Metetra
.664 .741 .907 r
.85563 .30411 .85643 .3053 .86297 .30316 .86217 .30196 Metetra
.664 .741 .907 r
.86217 .30196 .86297 .30316 .86953 .301 .86874 .2998 Metetra
.664 .741 .907 r
.86874 .2998 .86953 .301 .87611 .29885 .87531 .29764 Metetra
.664 .741 .907 r
.87531 .29764 .87611 .29885 .88269 .29669 .8819 .29548 Metetra
.664 .741 .907 r
.28774 .48917 .28879 .49014 .29412 .48839 .29308 .48741 Metetra
.664 .741 .907 r
.29308 .48741 .29412 .48839 .29947 .48664 .29843 .48566 Metetra
.664 .741 .907 r
.29843 .48566 .29947 .48664 .30483 .48488 .30379 .4839 Metetra
.664 .741 .907 r
.30379 .4839 .30483 .48488 .3102 .48312 .30916 .48213 Metetra
.664 .741 .907 r
.30916 .48213 .3102 .48312 .31558 .48135 .31454 .48037 Metetra
.664 .741 .907 r
.31454 .48037 .31558 .48135 .32097 .47958 .31993 .47859 Metetra
.664 .741 .907 r
.31993 .47859 .32097 .47958 .32637 .47781 .32534 .47682 Metetra
.945 .613 .367 r
.32534 .47682 .32637 .47781 .32888 .52556 .32923 .50083 Metetra
.657 .439 .576 r
.32923 .50083 .32888 .52556 .3372 .47425 .33618 .47326 Metetra
.664 .741 .907 r
.33618 .47326 .3372 .47425 .34264 .47247 .34161 .47147 Metetra
.664 .741 .907 r
.34161 .47147 .34264 .47247 .34808 .47068 .34706 .46968 Metetra
.664 .741 .907 r
.34706 .46968 .34808 .47068 .35354 .46889 .35252 .46789 Metetra
.664 .741 .907 r
.35252 .46789 .35354 .46889 .35901 .4671 .35799 .46609 Metetra
.664 .741 .907 r
.35799 .46609 .35901 .4671 .36449 .4653 .36347 .46429 Metetra
.664 .741 .907 r
.36347 .46429 .36449 .4653 .36998 .4635 .36896 .46249 Metetra
.664 .741 .907 r
.36896 .46249 .36998 .4635 .37548 .46169 .37447 .46068 Metetra
.664 .741 .907 r
.37447 .46068 .37548 .46169 .38099 .45988 .37998 .45887 Metetra
.664 .741 .907 r
.37998 .45887 .38099 .45988 .38652 .45807 .38551 .45706 Metetra
.664 .741 .907 r
.38551 .45706 .38652 .45807 .39205 .45625 .39105 .45524 Metetra
.664 .741 .907 r
.39105 .45524 .39205 .45625 .3976 .45443 .3966 .45341 Metetra
.664 .741 .907 r
.3966 .45341 .3976 .45443 .40316 .45261 .40216 .45159 Metetra
.664 .741 .907 r
.40216 .45159 .40316 .45261 .40873 .45078 .40773 .44976 Metetra
.664 .741 .907 r
.40773 .44976 .40873 .45078 .41431 .44895 .41332 .44792 Metetra
.664 .741 .907 r
.41332 .44792 .41431 .44895 .41991 .44711 .41891 .44608 Metetra
.664 .741 .907 r
.41891 .44608 .41991 .44711 .42551 .44527 .42452 .44424 Metetra
.664 .741 .907 r
.42452 .44424 .42551 .44527 .43113 .44343 .43014 .4424 Metetra
.664 .741 .907 r
.43014 .4424 .43113 .44343 .43579 .4776 .43577 .44055 Metetra
.519 .322 .553 r
.43577 .44055 .43579 .4776 .44152 .47429 .44107 .45208 Metetra
.622 .411 .575 r
.44107 .45208 .44152 .47429 .44805 .43787 .44707 .43684 Metetra
.957 .667 .443 r
.44707 .43684 .44805 .43787 .45371 .43601 .4508 .5223 Metetra
.415 .222 .508 r
.4508 .5223 .45371 .43601 .45939 .43415 .45841 .43311 Metetra
.664 .741 .907 r
.45841 .43311 .45939 .43415 .46508 .43228 .4641 .43124 Metetra
.664 .741 .907 r
.4641 .43124 .46508 .43228 .47078 .43041 .4698 .42937 Metetra
.664 .741 .907 r
.4698 .42937 .47078 .43041 .47649 .42854 .47552 .42749 Metetra
.664 .741 .907 r
.47552 .42749 .47649 .42854 .48221 .42666 .48124 .42561 Metetra
.664 .741 .907 r
.48124 .42561 .48221 .42666 .48795 .42478 .48698 .42373 Metetra
.664 .741 .907 r
.48698 .42373 .48795 .42478 .4937 .42289 .49273 .42184 Metetra
.664 .741 .907 r
.49273 .42184 .4937 .42289 .49945 .421 .49849 .41995 Metetra
.664 .741 .907 r
.49849 .41995 .49945 .421 .50523 .41911 .50427 .41805 Metetra
.664 .741 .907 r
.50427 .41805 .50523 .41911 .51101 .41721 .51005 .41615 Metetra
.664 .741 .907 r
.51005 .41615 .51101 .41721 .51681 .41531 .51585 .41424 Metetra
.664 .741 .907 r
.51585 .41424 .51681 .41531 .52262 .4134 .52166 .41234 Metetra
.664 .741 .907 r
.52166 .41234 .52262 .4134 .52844 .41149 .52748 .41042 Metetra
.664 .741 .907 r
.52748 .41042 .52844 .41149 .5343 .42166 .53332 .40851 Metetra
.574 .386 .589 r
.53332 .40851 .5343 .42166 .54011 .40766 .53917 .40659 Metetra
.664 .741 .907 r
.53917 .40659 .54011 .40766 .54597 .40573 .54503 .40466 Metetra
.664 .741 .907 r
.54503 .40466 .54597 .40573 .55184 .40381 .5509 .40273 Metetra
.664 .741 .907 r
.5509 .40273 .55184 .40381 .55773 .40188 .55679 .4008 Metetra
.664 .741 .907 r
.55679 .4008 .55773 .40188 .56362 .39994 .56268 .39886 Metetra
.664 .741 .907 r
.56268 .39886 .56362 .39994 .56953 .398 .5686 .39692 Metetra
.664 .741 .907 r
.5686 .39692 .56953 .398 .57545 .39606 .57452 .39497 Metetra
.664 .741 .907 r
.57452 .39497 .57545 .39606 .58138 .39411 .58045 .39302 Metetra
.664 .741 .907 r
.58045 .39302 .58138 .39411 .58733 .39216 .5864 .39107 Metetra
.664 .741 .907 r
.5864 .39107 .58733 .39216 .59329 .39021 .59236 .38911 Metetra
.664 .741 .907 r
.59236 .38911 .59329 .39021 .59926 .38825 .59834 .38715 Metetra
.664 .741 .907 r
.59834 .38715 .59926 .38825 .60524 .38628 .60433 .38518 Metetra
.664 .741 .907 r
.60433 .38518 .60524 .38628 .61124 .38431 .61032 .38321 Metetra
.664 .741 .907 r
.61032 .38321 .61124 .38431 .61725 .38234 .61634 .38124 Metetra
.664 .741 .907 r
.61634 .38124 .61725 .38234 .62327 .38036 .62236 .37926 Metetra
.664 .741 .907 r
.62236 .37926 .62327 .38036 .62931 .37838 .6284 .37728 Metetra
.664 .741 .907 r
.6284 .37728 .62931 .37838 .63536 .3764 .63445 .37529 Metetra
.664 .741 .907 r
.63445 .37529 .63536 .3764 .64142 .37441 .64052 .3733 Metetra
.664 .741 .907 r
.64052 .3733 .64142 .37441 .6475 .37241 .6466 .3713 Metetra
.664 .741 .907 r
.6466 .3713 .6475 .37241 .65358 .37042 .65269 .3693 Metetra
.664 .741 .907 r
.65269 .3693 .65358 .37042 .65969 .36841 .65879 .36729 Metetra
.664 .741 .907 r
.65879 .36729 .65969 .36841 .6658 .36641 .66491 .36529 Metetra
.664 .741 .907 r
.66491 .36529 .6658 .36641 .67193 .3644 .67104 .36327 Metetra
.664 .741 .907 r
.67104 .36327 .67193 .3644 .67807 .36238 .67718 .36125 Metetra
.664 .741 .907 r
.67718 .36125 .67807 .36238 .68423 .36036 .68334 .35923 Metetra
.934 .562 .178 r
.68334 .35923 .68423 .36036 .69039 .35834 .69112 .38821 Metetra
.421 .222 .503 r
.69112 .38821 .69039 .35834 .69658 .35631 .6957 .35517 Metetra
.664 .741 .907 r
.6957 .35517 .69658 .35631 .70277 .35427 .7019 .35314 Metetra
.664 .741 .907 r
.7019 .35314 .70277 .35427 .70898 .35224 .70811 .3511 Metetra
.664 .741 .907 r
.70811 .3511 .70898 .35224 .7152 .35019 .71433 .34905 Metetra
.664 .741 .907 r
.71433 .34905 .7152 .35019 .72144 .34815 .72057 .347 Metetra
.664 .741 .907 r
.72057 .347 .72144 .34815 .72769 .3461 .72682 .34495 Metetra
.664 .741 .907 r
.72682 .34495 .72769 .3461 .73395 .34404 .73309 .34289 Metetra
.664 .741 .907 r
.73309 .34289 .73395 .34404 .74023 .34198 .73937 .34083 Metetra
.664 .741 .907 r
.73937 .34083 .74023 .34198 .74652 .33991 .74566 .33876 Metetra
.664 .741 .907 r
.74566 .33876 .74652 .33991 .75282 .33785 .75197 .33669 Metetra
.664 .741 .907 r
.75197 .33669 .75282 .33785 .75914 .33577 .75829 .33461 Metetra
.664 .741 .907 r
.75829 .33461 .75914 .33577 .76548 .33369 .76463 .33253 Metetra
.664 .741 .907 r
.76463 .33253 .76548 .33369 .77182 .33161 .77098 .33045 Metetra
.664 .741 .907 r
.77098 .33045 .77182 .33161 .77818 .32952 .77734 .32836 Metetra
.664 .741 .907 r
.77734 .32836 .77818 .32952 .78456 .32743 .78372 .32626 Metetra
.664 .741 .907 r
.78372 .32626 .78456 .32743 .79095 .32533 .79011 .32416 Metetra
.664 .741 .907 r
.79011 .32416 .79095 .32533 .79735 .32323 .79652 .32206 Metetra
.664 .741 .907 r
.79652 .32206 .79735 .32323 .80377 .32113 .80294 .31995 Metetra
.664 .741 .907 r
.80294 .31995 .80377 .32113 .8102 .31901 .80937 .31784 Metetra
.664 .741 .907 r
.80937 .31784 .8102 .31901 .81665 .3169 .81582 .31572 Metetra
.664 .741 .907 r
.81582 .31572 .81665 .3169 .82311 .31478 .82229 .31359 Metetra
.664 .741 .907 r
.82229 .31359 .82311 .31478 .82958 .31265 .82876 .31147 Metetra
.664 .741 .907 r
.82876 .31147 .82958 .31265 .83607 .31052 .83526 .30933 Metetra
.664 .741 .907 r
.83526 .30933 .83607 .31052 .84257 .30839 .84176 .3072 Metetra
.664 .741 .907 r
.84176 .3072 .84257 .30839 .84909 .30625 .84829 .30505 Metetra
.664 .741 .907 r
.84829 .30505 .84909 .30625 .85563 .30411 .85482 .30291 Metetra
.664 .741 .907 r
.85482 .30291 .85563 .30411 .86217 .30196 .86137 .30076 Metetra
.664 .741 .907 r
.86137 .30076 .86217 .30196 .86874 .2998 .86794 .2986 Metetra
.664 .741 .907 r
.86794 .2986 .86874 .2998 .87531 .29764 .87452 .29644 Metetra
.664 .741 .907 r
.87452 .29644 .87531 .29764 .8819 .29548 .88111 .29427 Metetra
.664 .741 .907 r
.2867 .48819 .28774 .48917 .29308 .48741 .29204 .48643 Metetra
.664 .741 .907 r
.29204 .48643 .29308 .48741 .29843 .48566 .29739 .48468 Metetra
.664 .741 .907 r
.29739 .48468 .29843 .48566 .30379 .4839 .30275 .48291 Metetra
.664 .741 .907 r
.30275 .48291 .30379 .4839 .30916 .48213 .30812 .48115 Metetra
.664 .741 .907 r
.30812 .48115 .30916 .48213 .31454 .48037 .3135 .47938 Metetra
.664 .741 .907 r
.3135 .47938 .31454 .48037 .31993 .47859 .3189 .4776 Metetra
.664 .741 .907 r
.3189 .4776 .31993 .47859 .32534 .47682 .3243 .47583 Metetra
.664 .741 .907 r
.3243 .47583 .32534 .47682 .32923 .50083 .32972 .47405 Metetra
.563 .361 .565 r
.32972 .47405 .32923 .50083 .33618 .47326 .33515 .47226 Metetra
.664 .741 .907 r
.33515 .47226 .33618 .47326 .34161 .47147 .34059 .47048 Metetra
.664 .741 .907 r
.34059 .47048 .34161 .47147 .34706 .46968 .34604 .46868 Metetra
.664 .741 .907 r
.34604 .46868 .34706 .46968 .35252 .46789 .3515 .46689 Metetra
.664 .741 .907 r
.3515 .46689 .35252 .46789 .35799 .46609 .35697 .46509 Metetra
.664 .741 .907 r
.35697 .46509 .35799 .46609 .36347 .46429 .36245 .46329 Metetra
.664 .741 .907 r
.36245 .46329 .36347 .46429 .36896 .46249 .36795 .46148 Metetra
.664 .741 .907 r
.36795 .46148 .36896 .46249 .37447 .46068 .37345 .45967 Metetra
.664 .741 .907 r
.37345 .45967 .37447 .46068 .37998 .45887 .37897 .45786 Metetra
.664 .741 .907 r
.37897 .45786 .37998 .45887 .38551 .45706 .3845 .45604 Metetra
.664 .741 .907 r
.3845 .45604 .38551 .45706 .39105 .45524 .39004 .45422 Metetra
.664 .741 .907 r
.39004 .45422 .39105 .45524 .3966 .45341 .39559 .4524 Metetra
.664 .741 .907 r
.39559 .4524 .3966 .45341 .40216 .45159 .40116 .45057 Metetra
.664 .741 .907 r
.40116 .45057 .40216 .45159 .40773 .44976 .40673 .44873 Metetra
.664 .741 .907 r
.40673 .44873 .40773 .44976 .41332 .44792 .41232 .4469 Metetra
.664 .741 .907 r
.41232 .4469 .41332 .44792 .41891 .44608 .41792 .44506 Metetra
.664 .741 .907 r
.41792 .44506 .41891 .44608 .42452 .44424 .42352 .44321 Metetra
.664 .741 .907 r
.42352 .44321 .42452 .44424 .43014 .4424 .42915 .44137 Metetra
.664 .741 .907 r
.42915 .44137 .43014 .4424 .43577 .44055 .43478 .43951 Metetra
.664 .741 .907 r
.43478 .43951 .43577 .44055 .44107 .45208 .44042 .43766 Metetra
.956 .713 .26 r
.44042 .43766 .44107 .45208 .44707 .43684 .44277 .57272 Metetra
.609 .38 .545 r
.44277 .57272 .44707 .43684 .4508 .5223 .44672 .65789 Metetra
.297 .132 .48 r
.44672 .65789 .4508 .5223 .45841 .43311 .45733 .43663 Metetra
.245 0 .256 r
.45733 .43663 .45841 .43311 .4641 .43124 .46312 .4302 Metetra
.664 .741 .907 r
.46312 .4302 .4641 .43124 .4698 .42937 .46883 .42832 Metetra
.664 .741 .907 r
.46883 .42832 .4698 .42937 .47552 .42749 .47454 .42644 Metetra
.664 .741 .907 r
.47454 .42644 .47552 .42749 .48124 .42561 .48027 .42456 Metetra
.664 .741 .907 r
.48027 .42456 .48124 .42561 .48698 .42373 .48601 .42267 Metetra
.664 .741 .907 r
.48601 .42267 .48698 .42373 .49273 .42184 .49176 .42078 Metetra
.664 .741 .907 r
.49176 .42078 .49273 .42184 .49849 .41995 .49753 .41889 Metetra
.664 .741 .907 r
.49753 .41889 .49849 .41995 .50427 .41805 .5033 .41699 Metetra
.664 .741 .907 r
.5033 .41699 .50427 .41805 .51005 .41615 .50909 .41509 Metetra
.664 .741 .907 r
.50909 .41509 .51005 .41615 .51585 .41424 .51489 .41318 Metetra
.664 .741 .907 r
.51489 .41318 .51585 .41424 .52166 .41234 .52071 .41127 Metetra
.664 .741 .907 r
.52071 .41127 .52166 .41234 .52748 .41042 .52653 .40935 Metetra
.664 .741 .907 r
.52653 .40935 .52748 .41042 .53332 .40851 .53237 .40744 Metetra
.664 .741 .907 r
.53237 .40744 .53332 .40851 .53917 .40659 .53822 .40551 Metetra
.664 .741 .907 r
.53822 .40551 .53917 .40659 .54503 .40466 .54408 .40359 Metetra
.664 .741 .907 r
.54408 .40359 .54503 .40466 .5509 .40273 .54996 .40165 Metetra
.664 .741 .907 r
.54996 .40165 .5509 .40273 .55679 .4008 .55585 .39972 Metetra
.664 .741 .907 r
.55585 .39972 .55679 .4008 .56268 .39886 .56175 .39778 Metetra
.664 .741 .907 r
.56175 .39778 .56268 .39886 .5686 .39692 .56766 .39584 Metetra
.664 .741 .907 r
.56766 .39584 .5686 .39692 .57452 .39497 .57359 .39389 Metetra
.664 .741 .907 r
.57359 .39389 .57452 .39497 .58045 .39302 .57952 .39194 Metetra
.664 .741 .907 r
.57952 .39194 .58045 .39302 .5864 .39107 .58548 .38998 Metetra
.664 .741 .907 r
.58548 .38998 .5864 .39107 .59236 .38911 .59144 .38802 Metetra
.664 .741 .907 r
.59144 .38802 .59236 .38911 .59834 .38715 .59742 .38605 Metetra
.664 .741 .907 r
.59742 .38605 .59834 .38715 .60433 .38518 .60341 .38409 Metetra
.664 .741 .907 r
.60341 .38409 .60433 .38518 .61032 .38321 .60941 .38211 Metetra
.664 .741 .907 r
.60941 .38211 .61032 .38321 .61634 .38124 .61542 .38014 Metetra
.664 .741 .907 r
.61542 .38014 .61634 .38124 .62236 .37926 .62145 .37815 Metetra
.664 .741 .907 r
.62145 .37815 .62236 .37926 .6284 .37728 .62749 .37617 Metetra
.664 .741 .907 r
.62749 .37617 .6284 .37728 .63445 .37529 .63355 .37418 Metetra
.664 .741 .907 r
.63355 .37418 .63445 .37529 .64052 .3733 .63961 .37218 Metetra
.664 .741 .907 r
.63961 .37218 .64052 .3733 .6466 .3713 .6457 .37018 Metetra
.664 .741 .907 r
.6457 .37018 .6466 .3713 .65269 .3693 .65179 .36818 Metetra
.664 .741 .907 r
.65179 .36818 .65269 .3693 .65879 .36729 .6579 .36617 Metetra
.664 .741 .907 r
.6579 .36617 .65879 .36729 .66491 .36529 .66402 .36416 Metetra
.664 .741 .907 r
.66402 .36416 .66491 .36529 .67104 .36327 .67015 .36215 Metetra
0 .203 .718 r
.67015 .36215 .67104 .36327 .67718 .36125 .67665 .36745 Metetra
.35 .106 .396 r
.67665 .36745 .67718 .36125 .68334 .35923 .68246 .3581 Metetra
.969 .654 .345 r
.68246 .3581 .68334 .35923 .69112 .38821 .69383 .457 Metetra
.363 .188 .506 r
.69383 .457 .69112 .38821 .6957 .35517 .69482 .35404 Metetra
.664 .741 .907 r
.69482 .35404 .6957 .35517 .7019 .35314 .70102 .352 Metetra
.664 .741 .907 r
.70102 .352 .7019 .35314 .70811 .3511 .70723 .34996 Metetra
.664 .741 .907 r
.70723 .34996 .70811 .3511 .71433 .34905 .71346 .34791 Metetra
.664 .741 .907 r
.71346 .34791 .71433 .34905 .72057 .347 .7197 .34586 Metetra
.664 .741 .907 r
.7197 .34586 .72057 .347 .72682 .34495 .72596 .3438 Metetra
.664 .741 .907 r
.72596 .3438 .72682 .34495 .73309 .34289 .73223 .34174 Metetra
.664 .741 .907 r
.73223 .34174 .73309 .34289 .73937 .34083 .73851 .33968 Metetra
.664 .741 .907 r
.73851 .33968 .73937 .34083 .74566 .33876 .74481 .33761 Metetra
.664 .741 .907 r
.74481 .33761 .74566 .33876 .75197 .33669 .75112 .33553 Metetra
.664 .741 .907 r
.75112 .33553 .75197 .33669 .75829 .33461 .75744 .33345 Metetra
.664 .741 .907 r
.75744 .33345 .75829 .33461 .76463 .33253 .76378 .33137 Metetra
.664 .741 .907 r
.76378 .33137 .76463 .33253 .77098 .33045 .77013 .32928 Metetra
.664 .741 .907 r
.77013 .32928 .77098 .33045 .77734 .32836 .7765 .32719 Metetra
.664 .741 .907 r
.7765 .32719 .77734 .32836 .78372 .32626 .78288 .32509 Metetra
.664 .741 .907 r
.78288 .32509 .78372 .32626 .79011 .32416 .78928 .32299 Metetra
.664 .741 .907 r
.78928 .32299 .79011 .32416 .79652 .32206 .79569 .32088 Metetra
.664 .741 .907 r
.79569 .32088 .79652 .32206 .80294 .31995 .80211 .31877 Metetra
.664 .741 .907 r
.80211 .31877 .80294 .31995 .80937 .31784 .80855 .31665 Metetra
.664 .741 .907 r
.80855 .31665 .80937 .31784 .81582 .31572 .815 .31453 Metetra
.664 .741 .907 r
.815 .31453 .81582 .31572 .82229 .31359 .82147 .31241 Metetra
.664 .741 .907 r
.82147 .31241 .82229 .31359 .82876 .31147 .82795 .31028 Metetra
.664 .741 .907 r
.82795 .31028 .82876 .31147 .83526 .30933 .83444 .30814 Metetra
.664 .741 .907 r
.83444 .30814 .83526 .30933 .84176 .3072 .84095 .306 Metetra
.664 .741 .907 r
.84095 .306 .84176 .3072 .84829 .30505 .84748 .30386 Metetra
.664 .741 .907 r
.84748 .30386 .84829 .30505 .85482 .30291 .85402 .30171 Metetra
.664 .741 .907 r
.85402 .30171 .85482 .30291 .86137 .30076 .86057 .29955 Metetra
.664 .741 .907 r
.86057 .29955 .86137 .30076 .86794 .2986 .86714 .29739 Metetra
.664 .741 .907 r
.86714 .29739 .86794 .2986 .87452 .29644 .87372 .29523 Metetra
.664 .741 .907 r
.87372 .29523 .87452 .29644 .88111 .29427 .88032 .29306 Metetra
.664 .741 .907 r
.28565 .48721 .2867 .48819 .29204 .48643 .29099 .48545 Metetra
.664 .741 .907 r
.29099 .48545 .29204 .48643 .29739 .48468 .29634 .48369 Metetra
.664 .741 .907 r
.29634 .48369 .29739 .48468 .30275 .48291 .30171 .48193 Metetra
.664 .741 .907 r
.30171 .48193 .30275 .48291 .30812 .48115 .30708 .48016 Metetra
.664 .741 .907 r
.30708 .48016 .30812 .48115 .3135 .47938 .31247 .47839 Metetra
.664 .741 .907 r
.31247 .47839 .3135 .47938 .3189 .4776 .31786 .47661 Metetra
.664 .741 .907 r
.31786 .47661 .3189 .4776 .3243 .47583 .32327 .47484 Metetra
.664 .741 .907 r
.32327 .47484 .3243 .47583 .32972 .47405 .32869 .47305 Metetra
.664 .741 .907 r
.32869 .47305 .32972 .47405 .33515 .47226 .33412 .47127 Metetra
.664 .741 .907 r
.33412 .47127 .33515 .47226 .34059 .47048 .33956 .46948 Metetra
.664 .741 .907 r
.33956 .46948 .34059 .47048 .34604 .46868 .34501 .46768 Metetra
.664 .741 .907 r
.34501 .46768 .34604 .46868 .3515 .46689 .35047 .46589 Metetra
.664 .741 .907 r
.35047 .46589 .3515 .46689 .35697 .46509 .35595 .46409 Metetra
.664 .741 .907 r
.35595 .46409 .35697 .46509 .36245 .46329 .36143 .46228 Metetra
.664 .741 .907 r
.36143 .46228 .36245 .46329 .36795 .46148 .36693 .46047 Metetra
.664 .741 .907 r
.36693 .46047 .36795 .46148 .37345 .45967 .37244 .45866 Metetra
.664 .741 .907 r
.37244 .45866 .37345 .45967 .37897 .45786 .37796 .45685 Metetra
.664 .741 .907 r
.37796 .45685 .37897 .45786 .3845 .45604 .38349 .45503 Metetra
.664 .741 .907 r
.38349 .45503 .3845 .45604 .39004 .45422 .38903 .4532 Metetra
.664 .741 .907 r
.38903 .4532 .39004 .45422 .39559 .4524 .39459 .45138 Metetra
.664 .741 .907 r
.39459 .45138 .39559 .4524 .40116 .45057 .40015 .44954 Metetra
.664 .741 .907 r
.40015 .44954 .40116 .45057 .40673 .44873 .40573 .44771 Metetra
.664 .741 .907 r
.40573 .44771 .40673 .44873 .41232 .4469 .41132 .44587 Metetra
.664 .741 .907 r
.41132 .44587 .41232 .4469 .41792 .44506 .41692 .44403 Metetra
.664 .741 .907 r
.41692 .44403 .41792 .44506 .42352 .44321 .42253 .44218 Metetra
.664 .741 .907 r
.42253 .44218 .42352 .44321 .42915 .44137 .42815 .44033 Metetra
.664 .741 .907 r
.42815 .44033 .42915 .44137 .43478 .43951 .43379 .43848 Metetra
.664 .741 .907 r
.43379 .43848 .43478 .43951 .44042 .43766 .43944 .43662 Metetra
.956 .677 .468 r
.43944 .43662 .44042 .43766 .44277 .57272 .44108 .59872 Metetra
.612 .37 .527 r
.44108 .59872 .44277 .57272 .44672 .65789 .4466 .616 Metetra
.8 .549 .558 r
.4466 .616 .44672 .65789 .45733 .43663 .45645 .43103 Metetra
.597 .446 .647 r
.45645 .43103 .45733 .43663 .46312 .4302 .46214 .42915 Metetra
.664 .741 .907 r
.46214 .42915 .46312 .4302 .46883 .42832 .46785 .42728 Metetra
.664 .741 .907 r
.46785 .42728 .46883 .42832 .47454 .42644 .47357 .42539 Metetra
.664 .741 .907 r
.47357 .42539 .47454 .42644 .48027 .42456 .4793 .42351 Metetra
.664 .741 .907 r
.4793 .42351 .48027 .42456 .48601 .42267 .48504 .42162 Metetra
.664 .741 .907 r
.48504 .42162 .48601 .42267 .49176 .42078 .49079 .41973 Metetra
.664 .741 .907 r
.49079 .41973 .49176 .42078 .49753 .41889 .49656 .41783 Metetra
.664 .741 .907 r
.49656 .41783 .49753 .41889 .5033 .41699 .50234 .41593 Metetra
.664 .741 .907 r
.50234 .41593 .5033 .41699 .50909 .41509 .50813 .41402 Metetra
.664 .741 .907 r
.50813 .41402 .50909 .41509 .51489 .41318 .51393 .41212 Metetra
.664 .741 .907 r
.51393 .41212 .51489 .41318 .52071 .41127 .51975 .4102 Metetra
.664 .741 .907 r
.51975 .4102 .52071 .41127 .52653 .40935 .52558 .40828 Metetra
.664 .741 .907 r
.52558 .40828 .52653 .40935 .53237 .40744 .53142 .40636 Metetra
.664 .741 .907 r
.53142 .40636 .53237 .40744 .53822 .40551 .53727 .40444 Metetra
.664 .741 .907 r
.53727 .40444 .53822 .40551 .54408 .40359 .54314 .40251 Metetra
.664 .741 .907 r
.54314 .40251 .54408 .40359 .54996 .40165 .54902 .40058 Metetra
.664 .741 .907 r
.54902 .40058 .54996 .40165 .55585 .39972 .55491 .39864 Metetra
.664 .741 .907 r
.55491 .39864 .55585 .39972 .56175 .39778 .56081 .3967 Metetra
.664 .741 .907 r
.56081 .3967 .56175 .39778 .56766 .39584 .56672 .39475 Metetra
.664 .741 .907 r
.56672 .39475 .56766 .39584 .57359 .39389 .57265 .3928 Metetra
.664 .741 .907 r
.57265 .3928 .57359 .39389 .57952 .39194 .57859 .39085 Metetra
.664 .741 .907 r
.57859 .39085 .57952 .39194 .58548 .38998 .58455 .38889 Metetra
.664 .741 .907 r
.58455 .38889 .58548 .38998 .59144 .38802 .59051 .38692 Metetra
.664 .741 .907 r
.59051 .38692 .59144 .38802 .59742 .38605 .59649 .38496 Metetra
.664 .741 .907 r
.59649 .38496 .59742 .38605 .60341 .38409 .60248 .38299 Metetra
.664 .741 .907 r
.60248 .38299 .60341 .38409 .60941 .38211 .60849 .38101 Metetra
.664 .741 .907 r
.60849 .38101 .60941 .38211 .61542 .38014 .61451 .37903 Metetra
.664 .741 .907 r
.61451 .37903 .61542 .38014 .62145 .37815 .62054 .37705 Metetra
.664 .741 .907 r
.62054 .37705 .62145 .37815 .62749 .37617 .62658 .37506 Metetra
.664 .741 .907 r
.62658 .37506 .62749 .37617 .63355 .37418 .63264 .37307 Metetra
.664 .741 .907 r
.63264 .37307 .63355 .37418 .63961 .37218 .63871 .37107 Metetra
.664 .741 .907 r
.63871 .37107 .63961 .37218 .6457 .37018 .64479 .36907 Metetra
.664 .741 .907 r
.64479 .36907 .6457 .37018 .65179 .36818 .65089 .36706 Metetra
.664 .741 .907 r
.65089 .36706 .65179 .36818 .6579 .36617 .657 .36505 Metetra
.664 .741 .907 r
.657 .36505 .6579 .36617 .66402 .36416 .66312 .36304 Metetra
.664 .741 .907 r
.66312 .36304 .66402 .36416 .67015 .36215 .66926 .36102 Metetra
.952 .602 .25 r
.66926 .36102 .67015 .36215 .67665 .36745 .67734 .39982 Metetra
.387 .198 .498 r
.67734 .39982 .67665 .36745 .68246 .3581 .68157 .35697 Metetra
.948 .593 .23 r
.68157 .35697 .68246 .3581 .69383 .457 .68973 .39359 Metetra
.614 .391 .554 r
.68973 .39359 .69383 .457 .69482 .35404 .69394 .3529 Metetra
.664 .741 .907 r
.69394 .3529 .69482 .35404 .70102 .352 .70014 .35086 Metetra
.664 .741 .907 r
.70014 .35086 .70102 .352 .70723 .34996 .70636 .34882 Metetra
.664 .741 .907 r
.70636 .34882 .70723 .34996 .71346 .34791 .71259 .34677 Metetra
.664 .741 .907 r
.71259 .34677 .71346 .34791 .7197 .34586 .71883 .34471 Metetra
.664 .741 .907 r
.71883 .34471 .7197 .34586 .72596 .3438 .72509 .34265 Metetra
.664 .741 .907 r
.72509 .34265 .72596 .3438 .73223 .34174 .73136 .34059 Metetra
.664 .741 .907 r
.73136 .34059 .73223 .34174 .73851 .33968 .73765 .33852 Metetra
.664 .741 .907 r
.73765 .33852 .73851 .33968 .74481 .33761 .74395 .33645 Metetra
.664 .741 .907 r
.74395 .33645 .74481 .33761 .75112 .33553 .75026 .33437 Metetra
.664 .741 .907 r
.75026 .33437 .75112 .33553 .75744 .33345 .75659 .33229 Metetra
.664 .741 .907 r
.75659 .33229 .75744 .33345 .76378 .33137 .76293 .33021 Metetra
.664 .741 .907 r
.76293 .33021 .76378 .33137 .77013 .32928 .76929 .32811 Metetra
.664 .741 .907 r
.76929 .32811 .77013 .32928 .7765 .32719 .77566 .32602 Metetra
.664 .741 .907 r
.77566 .32602 .7765 .32719 .78288 .32509 .78204 .32392 Metetra
.664 .741 .907 r
.78204 .32392 .78288 .32509 .78928 .32299 .78844 .32181 Metetra
.664 .741 .907 r
.78844 .32181 .78928 .32299 .79569 .32088 .79485 .3197 Metetra
.664 .741 .907 r
.79485 .3197 .79569 .32088 .80211 .31877 .80128 .31759 Metetra
.664 .741 .907 r
.80128 .31759 .80211 .31877 .80855 .31665 .80772 .31547 Metetra
.664 .741 .907 r
.80772 .31547 .80855 .31665 .815 .31453 .81418 .31335 Metetra
.664 .741 .907 r
.81418 .31335 .815 .31453 .82147 .31241 .82065 .31122 Metetra
.664 .741 .907 r
.82065 .31122 .82147 .31241 .82795 .31028 .82713 .30909 Metetra
.664 .741 .907 r
.82713 .30909 .82795 .31028 .83444 .30814 .83363 .30695 Metetra
.664 .741 .907 r
.83363 .30695 .83444 .30814 .84095 .306 .84014 .30481 Metetra
.664 .741 .907 r
.84014 .30481 .84095 .306 .84748 .30386 .84667 .30266 Metetra
.664 .741 .907 r
.84667 .30266 .84748 .30386 .85402 .30171 .85321 .30051 Metetra
.664 .741 .907 r
.85321 .30051 .85402 .30171 .86057 .29955 .85977 .29835 Metetra
.664 .741 .907 r
.85977 .29835 .86057 .29955 .86714 .29739 .86634 .29619 Metetra
.664 .741 .907 r
.86634 .29619 .86714 .29739 .87372 .29523 .87293 .29402 Metetra
.664 .741 .907 r
.87293 .29402 .87372 .29523 .88032 .29306 .87953 .29185 Metetra
.664 .741 .907 r
.2846 .48623 .28565 .48721 .29099 .48545 .28994 .48447 Metetra
.664 .741 .907 r
.28994 .48447 .29099 .48545 .29634 .48369 .2953 .48271 Metetra
.664 .741 .907 r
.2953 .48271 .29634 .48369 .30171 .48193 .30066 .48094 Metetra
.664 .741 .907 r
.30066 .48094 .30171 .48193 .30708 .48016 .30604 .47917 Metetra
.664 .741 .907 r
.30604 .47917 .30708 .48016 .31247 .47839 .31143 .4774 Metetra
.664 .741 .907 r
.31143 .4774 .31247 .47839 .31786 .47661 .31683 .47562 Metetra
.664 .741 .907 r
.31683 .47562 .31786 .47661 .32327 .47484 .32224 .47384 Metetra
.664 .741 .907 r
.32224 .47384 .32327 .47484 .32869 .47305 .32766 .47206 Metetra
.944 .607 .353 r
.32766 .47206 .32869 .47305 .33412 .47127 .33166 .49476 Metetra
.41 .199 .48 r
.33166 .49476 .33412 .47127 .33956 .46948 .33836 .47155 Metetra
.075 0 .024 r
.33836 .47155 .33956 .46948 .34501 .46768 .34398 .46668 Metetra
.664 .741 .907 r
.34398 .46668 .34501 .46768 .35047 .46589 .34945 .46488 Metetra
.664 .741 .907 r
.34945 .46488 .35047 .46589 .35595 .46409 .35493 .46308 Metetra
.664 .741 .907 r
.35493 .46308 .35595 .46409 .36143 .46228 .36041 .46127 Metetra
.664 .741 .907 r
.36041 .46127 .36143 .46228 .36693 .46047 .36591 .45946 Metetra
.664 .741 .907 r
.36591 .45946 .36693 .46047 .37244 .45866 .37142 .45765 Metetra
.664 .741 .907 r
.37142 .45765 .37244 .45866 .37796 .45685 .37694 .45583 Metetra
.664 .741 .907 r
.37694 .45583 .37796 .45685 .38349 .45503 .38248 .45401 Metetra
.664 .741 .907 r
.38248 .45401 .38349 .45503 .38903 .4532 .38802 .45218 Metetra
.664 .741 .907 r
.38802 .45218 .38903 .4532 .39459 .45138 .39358 .45035 Metetra
.664 .741 .907 r
.39358 .45035 .39459 .45138 .40015 .44954 .39915 .44852 Metetra
.664 .741 .907 r
.39915 .44852 .40015 .44954 .40573 .44771 .40473 .44669 Metetra
.664 .741 .907 r
.40473 .44669 .40573 .44771 .41132 .44587 .41032 .44484 Metetra
.664 .741 .907 r
.41032 .44484 .41132 .44587 .41692 .44403 .41592 .443 Metetra
.664 .741 .907 r
.41592 .443 .41692 .44403 .42253 .44218 .42153 .44115 Metetra
.664 .741 .907 r
.42153 .44115 .42253 .44218 .42815 .44033 .42716 .4393 Metetra
.664 .741 .907 r
.42716 .4393 .42815 .44033 .43379 .43848 .4328 .43744 Metetra
.664 .741 .907 r
.4328 .43744 .43379 .43848 .43944 .43662 .43845 .43558 Metetra
.956 .672 .457 r
.43845 .43558 .43944 .43662 .44108 .59872 .44126 .54836 Metetra
.607 .389 .56 r
.44126 .54836 .44108 .59872 .4466 .616 .4477 .52211 Metetra
.646 .417 .557 r
.4477 .52211 .4466 .616 .45645 .43103 .45546 .42998 Metetra
.664 .741 .907 r
.45546 .42998 .45645 .43103 .46214 .42915 .46116 .42811 Metetra
.664 .741 .907 r
.46116 .42811 .46214 .42915 .46785 .42728 .46687 .42623 Metetra
.664 .741 .907 r
.46687 .42623 .46785 .42728 .47357 .42539 .47259 .42434 Metetra
.664 .741 .907 r
.47259 .42434 .47357 .42539 .4793 .42351 .47832 .42246 Metetra
.664 .741 .907 r
.47832 .42246 .4793 .42351 .48504 .42162 .48407 .42056 Metetra
.664 .741 .907 r
.48407 .42056 .48504 .42162 .49079 .41973 .48983 .41867 Metetra
.664 .741 .907 r
.48983 .41867 .49079 .41973 .49656 .41783 .49559 .41677 Metetra
.664 .741 .907 r
.49559 .41677 .49656 .41783 .50234 .41593 .50138 .41487 Metetra
.664 .741 .907 r
.50138 .41487 .50234 .41593 .50813 .41402 .50717 .41296 Metetra
.664 .741 .907 r
.50717 .41296 .50813 .41402 .51393 .41212 .51298 .41105 Metetra
.664 .741 .907 r
.51298 .41105 .51393 .41212 .51975 .4102 .51879 .40913 Metetra
.664 .741 .907 r
.51879 .40913 .51975 .4102 .52558 .40828 .52462 .40721 Metetra
.664 .741 .907 r
.52462 .40721 .52558 .40828 .53142 .40636 .53047 .40529 Metetra
.664 .741 .907 r
.53047 .40529 .53142 .40636 .53727 .40444 .53632 .40336 Metetra
.664 .741 .907 r
.53632 .40336 .53727 .40444 .54314 .40251 .54219 .40143 Metetra
.775 .314 0 r
.54219 .40143 .54314 .40251 .54902 .40058 .54816 .41163 Metetra
.377 .156 .446 r
.54816 .41163 .54902 .40058 .55491 .39864 .55396 .39755 Metetra
.664 .741 .907 r
.55396 .39755 .55491 .39864 .56081 .3967 .55987 .39561 Metetra
.664 .741 .907 r
.55987 .39561 .56081 .3967 .56672 .39475 .56579 .39366 Metetra
.664 .741 .907 r
.56579 .39366 .56672 .39475 .57265 .3928 .57172 .39171 Metetra
.664 .741 .907 r
.57172 .39171 .57265 .3928 .57859 .39085 .57766 .38975 Metetra
.664 .741 .907 r
.57766 .38975 .57859 .39085 .58455 .38889 .58362 .38779 Metetra
.664 .741 .907 r
.58362 .38779 .58455 .38889 .59051 .38692 .58959 .38583 Metetra
.664 .741 .907 r
.58959 .38583 .59051 .38692 .59649 .38496 .59557 .38386 Metetra
.664 .741 .907 r
.59557 .38386 .59649 .38496 .60248 .38299 .60156 .38188 Metetra
.664 .741 .907 r
.60156 .38188 .60248 .38299 .60849 .38101 .60757 .37991 Metetra
.664 .741 .907 r
.60757 .37991 .60849 .38101 .61451 .37903 .61359 .37792 Metetra
.664 .741 .907 r
.61359 .37792 .61451 .37903 .62054 .37705 .61962 .37594 Metetra
.664 .741 .907 r
.61962 .37594 .62054 .37705 .62658 .37506 .62567 .37395 Metetra
.664 .741 .907 r
.62567 .37395 .62658 .37506 .63264 .37307 .63173 .37195 Metetra
.664 .741 .907 r
.63173 .37195 .63264 .37307 .63871 .37107 .6378 .36995 Metetra
.664 .741 .907 r
.6378 .36995 .63871 .37107 .64479 .36907 .64389 .36795 Metetra
.664 .741 .907 r
.64389 .36795 .64479 .36907 .65089 .36706 .64999 .36594 Metetra
.664 .741 .907 r
.64999 .36594 .65089 .36706 .657 .36505 .6561 .36393 Metetra
.664 .741 .907 r
.6561 .36393 .657 .36505 .66312 .36304 .66223 .36191 Metetra
.664 .741 .907 r
.66223 .36191 .66312 .36304 .66926 .36102 .66837 .35989 Metetra
.89 .486 .059 r
.66837 .35989 .66926 .36102 .67734 .39982 .67553 .37936 Metetra
.655 .435 .572 r
.67553 .37936 .67734 .39982 .68157 .35697 .68068 .35584 Metetra
.662 .74 .908 r
.68068 .35584 .68157 .35697 .68973 .39359 .68687 .35383 Metetra
.56 .354 .558 r
.68687 .35383 .68973 .39359 .69394 .3529 .69306 .35176 Metetra
.664 .741 .907 r
.69306 .35176 .69394 .3529 .70014 .35086 .69926 .34972 Metetra
.664 .741 .907 r
.69926 .34972 .70014 .35086 .70636 .34882 .70548 .34767 Metetra
.664 .741 .907 r
.70548 .34767 .70636 .34882 .71259 .34677 .71172 .34562 Metetra
.664 .741 .907 r
.71172 .34562 .71259 .34677 .71883 .34471 .71796 .34356 Metetra
.664 .741 .907 r
.71796 .34356 .71883 .34471 .72509 .34265 .72423 .3415 Metetra
.664 .741 .907 r
.72423 .3415 .72509 .34265 .73136 .34059 .7305 .33944 Metetra
.664 .741 .907 r
.7305 .33944 .73136 .34059 .73765 .33852 .73679 .33737 Metetra
.664 .741 .907 r
.73679 .33737 .73765 .33852 .74395 .33645 .74309 .33529 Metetra
.664 .741 .907 r
.74309 .33529 .74395 .33645 .75026 .33437 .74941 .33321 Metetra
.664 .741 .907 r
.74941 .33321 .75026 .33437 .75659 .33229 .75574 .33113 Metetra
.664 .741 .907 r
.75574 .33113 .75659 .33229 .76293 .33021 .76208 .32904 Metetra
.664 .741 .907 r
.76208 .32904 .76293 .33021 .76929 .32811 .76844 .32695 Metetra
.664 .741 .907 r
.76844 .32695 .76929 .32811 .77566 .32602 .77482 .32485 Metetra
.664 .741 .907 r
.77482 .32485 .77566 .32602 .78204 .32392 .7812 .32275 Metetra
.664 .741 .907 r
.7812 .32275 .78204 .32392 .78844 .32181 .7876 .32064 Metetra
.664 .741 .907 r
.7876 .32064 .78844 .32181 .79485 .3197 .79402 .31853 Metetra
.664 .741 .907 r
.79402 .31853 .79485 .3197 .80128 .31759 .80045 .31641 Metetra
.664 .741 .907 r
.80045 .31641 .80128 .31759 .80772 .31547 .80689 .31429 Metetra
.664 .741 .907 r
.80689 .31429 .80772 .31547 .81418 .31335 .81335 .31216 Metetra
.664 .741 .907 r
.81335 .31216 .81418 .31335 .82065 .31122 .81982 .31003 Metetra
.664 .741 .907 r
.81982 .31003 .82065 .31122 .82713 .30909 .82631 .3079 Metetra
.664 .741 .907 r
.82631 .3079 .82713 .30909 .83363 .30695 .83281 .30575 Metetra
.664 .741 .907 r
.83281 .30575 .83363 .30695 .84014 .30481 .83933 .30361 Metetra
.664 .741 .907 r
.83933 .30361 .84014 .30481 .84667 .30266 .84586 .30146 Metetra
.664 .741 .907 r
.84586 .30146 .84667 .30266 .85321 .30051 .85241 .2993 Metetra
.664 .741 .907 r
.85241 .2993 .85321 .30051 .85977 .29835 .85897 .29714 Metetra
.664 .741 .907 r
.85897 .29714 .85977 .29835 .86634 .29619 .86554 .29498 Metetra
.664 .741 .907 r
.86554 .29498 .86634 .29619 .87293 .29402 .87213 .29281 Metetra
.664 .741 .907 r
.87213 .29281 .87293 .29402 .87953 .29185 .87874 .29064 Metetra
.664 .741 .907 r
.28355 .48525 .2846 .48623 .28994 .48447 .28889 .48349 Metetra
.664 .741 .907 r
.28889 .48349 .28994 .48447 .2953 .48271 .29425 .48173 Metetra
.664 .741 .907 r
.29425 .48173 .2953 .48271 .30066 .48094 .29962 .47996 Metetra
.664 .741 .907 r
.29962 .47996 .30066 .48094 .30604 .47917 .305 .47818 Metetra
.664 .741 .907 r
.305 .47818 .30604 .47917 .31143 .4774 .31039 .47641 Metetra
.664 .741 .907 r
.31039 .47641 .31143 .4774 .31683 .47562 .31579 .47463 Metetra
.664 .741 .907 r
.31579 .47463 .31683 .47562 .32224 .47384 .3212 .47285 Metetra
.664 .741 .907 r
.3212 .47285 .32224 .47384 .32766 .47206 .32662 .47106 Metetra
.946 .664 .472 r
.32662 .47106 .32766 .47206 .33166 .49476 .32789 .5403 Metetra
.284 .107 .456 r
.32789 .5403 .33166 .49476 .33836 .47155 .3375 .46748 Metetra
.59 .468 .682 r
.3375 .46748 .33836 .47155 .34398 .46668 .34291 .46649 Metetra
.682 .93 .969 r
.34291 .46649 .34398 .46668 .34945 .46488 .34842 .46388 Metetra
.664 .741 .907 r
.34842 .46388 .34945 .46488 .35493 .46308 .3539 .46207 Metetra
.664 .741 .907 r
.3539 .46207 .35493 .46308 .36041 .46127 .35939 .46026 Metetra
.664 .741 .907 r
.35939 .46026 .36041 .46127 .36591 .45946 .36489 .45845 Metetra
.664 .741 .907 r
.36489 .45845 .36591 .45946 .37142 .45765 .37041 .45664 Metetra
.664 .741 .907 r
.37041 .45664 .37142 .45765 .37694 .45583 .37593 .45482 Metetra
.664 .741 .907 r
.37593 .45482 .37694 .45583 .38248 .45401 .38146 .45299 Metetra
.664 .741 .907 r
.38146 .45299 .38248 .45401 .38802 .45218 .38701 .45116 Metetra
.664 .741 .907 r
.38701 .45116 .38802 .45218 .39358 .45035 .39257 .44933 Metetra
.664 .741 .907 r
.39257 .44933 .39358 .45035 .39915 .44852 .39814 .4475 Metetra
.664 .741 .907 r
.39814 .4475 .39915 .44852 .40473 .44669 .40372 .44566 Metetra
.664 .741 .907 r
.40372 .44566 .40473 .44669 .41032 .44484 .40931 .44382 Metetra
.664 .741 .907 r
.40931 .44382 .41032 .44484 .41592 .443 .41492 .44197 Metetra
.664 .741 .907 r
.41492 .44197 .41592 .443 .42153 .44115 .42053 .44012 Metetra
.664 .741 .907 r
.42053 .44012 .42153 .44115 .42716 .4393 .42616 .43827 Metetra
.664 .741 .907 r
.42616 .43827 .42716 .4393 .4328 .43744 .4318 .43641 Metetra
.664 .741 .907 r
.4318 .43641 .4328 .43744 .43845 .43558 .43745 .43455 Metetra
.935 .559 .236 r
.43745 .43455 .43845 .43558 .44126 .54836 .4426 .45314 Metetra
.5 .299 .539 r
.4426 .45314 .44126 .54836 .4477 .52211 .44728 .49552 Metetra
.734 .497 .57 r
.44728 .49552 .4477 .52211 .45546 .42998 .45448 .42894 Metetra
.664 .741 .907 r
.45448 .42894 .45546 .42998 .46116 .42811 .46018 .42706 Metetra
.664 .741 .907 r
.46018 .42706 .46116 .42811 .46687 .42623 .46589 .42518 Metetra
.664 .741 .907 r
.46589 .42518 .46687 .42623 .47259 .42434 .47161 .42329 Metetra
.664 .741 .907 r
.47161 .42329 .47259 .42434 .47832 .42246 .47735 .4214 Metetra
.664 .741 .907 r
.47735 .4214 .47832 .42246 .48407 .42056 .4831 .41951 Metetra
.664 .741 .907 r
.4831 .41951 .48407 .42056 .48983 .41867 .48885 .41761 Metetra
.664 .741 .907 r
.48885 .41761 .48983 .41867 .49559 .41677 .49463 .41571 Metetra
.664 .741 .907 r
.49463 .41571 .49559 .41677 .50138 .41487 .50041 .4138 Metetra
.664 .741 .907 r
.50041 .4138 .50138 .41487 .50717 .41296 .50621 .41189 Metetra
.664 .741 .907 r
.50621 .41189 .50717 .41296 .51298 .41105 .51201 .40998 Metetra
.664 .741 .907 r
.51201 .40998 .51298 .41105 .51879 .40913 .51783 .40806 Metetra
.664 .741 .907 r
.51783 .40806 .51879 .40913 .52462 .40721 .52367 .40614 Metetra
.664 .741 .907 r
.52367 .40614 .52462 .40721 .53047 .40529 .52951 .40422 Metetra
.664 .741 .907 r
.52951 .40422 .53047 .40529 .53632 .40336 .53537 .40229 Metetra
.664 .741 .907 r
.53537 .40229 .53632 .40336 .54219 .40143 .54124 .40035 Metetra
.681 .205 0 r
.54124 .40035 .54219 .40143 .54816 .41163 .5472 .40882 Metetra
.81 .638 .669 r
.5472 .40882 .54816 .41163 .55396 .39755 .55302 .39647 Metetra
.664 .741 .907 r
.55302 .39647 .55396 .39755 .55987 .39561 .55893 .39452 Metetra
.664 .741 .907 r
.55893 .39452 .55987 .39561 .56579 .39366 .56485 .39257 Metetra
.664 .741 .907 r
.56485 .39257 .56579 .39366 .57172 .39171 .57078 .39062 Metetra
.664 .741 .907 r
.57078 .39062 .57172 .39171 .57766 .38975 .57673 .38866 Metetra
.664 .741 .907 r
.57673 .38866 .57766 .38975 .58362 .38779 .58269 .3867 Metetra
.664 .741 .907 r
.58269 .3867 .58362 .38779 .58959 .38583 .58866 .38473 Metetra
.664 .741 .907 r
.58866 .38473 .58959 .38583 .59557 .38386 .59464 .38276 Metetra
.664 .741 .907 r
.59464 .38276 .59557 .38386 .60156 .38188 .60064 .38078 Metetra
.664 .741 .907 r
.60064 .38078 .60156 .38188 .60757 .37991 .60665 .3788 Metetra
.664 .741 .907 r
.60665 .3788 .60757 .37991 .61359 .37792 .61267 .37682 Metetra
.664 .741 .907 r
.61267 .37682 .61359 .37792 .61962 .37594 .61871 .37483 Metetra
.664 .741 .907 r
.61871 .37483 .61962 .37594 .62567 .37395 .62476 .37284 Metetra
.664 .741 .907 r
.62476 .37284 .62567 .37395 .63173 .37195 .63082 .37084 Metetra
.664 .741 .907 r
.63082 .37084 .63173 .37195 .6378 .36995 .6369 .36884 Metetra
.664 .741 .907 r
.6369 .36884 .6378 .36995 .64389 .36795 .64298 .36683 Metetra
.664 .741 .907 r
.64298 .36683 .64389 .36795 .64999 .36594 .64909 .36482 Metetra
.664 .741 .907 r
.64909 .36482 .64999 .36594 .6561 .36393 .6552 .36281 Metetra
.664 .741 .907 r
.6552 .36281 .6561 .36393 .66223 .36191 .66133 .36079 Metetra
.664 .741 .907 r
.66133 .36079 .66223 .36191 .66837 .35989 .66747 .35876 Metetra
.664 .741 .907 r
.66747 .35876 .66837 .35989 .67553 .37936 .67363 .35674 Metetra
.565 .366 .57 r
.67363 .35674 .67553 .37936 .68068 .35584 .6798 .3547 Metetra
.236 .522 .915 r
.6798 .3547 .68068 .35584 .68687 .35383 .6862 .35695 Metetra
.254 0 .255 r
.6862 .35695 .68687 .35383 .69306 .35176 .69217 .35062 Metetra
.664 .741 .907 r
.69217 .35062 .69306 .35176 .69926 .34972 .69838 .34858 Metetra
.664 .741 .907 r
.69838 .34858 .69926 .34972 .70548 .34767 .70461 .34653 Metetra
.664 .741 .907 r
.70461 .34653 .70548 .34767 .71172 .34562 .71084 .34447 Metetra
.664 .741 .907 r
.71084 .34447 .71172 .34562 .71796 .34356 .71709 .34241 Metetra
.664 .741 .907 r
.71709 .34241 .71796 .34356 .72423 .3415 .72336 .34035 Metetra
.664 .741 .907 r
.72336 .34035 .72423 .3415 .7305 .33944 .72964 .33828 Metetra
.664 .741 .907 r
.72964 .33828 .7305 .33944 .73679 .33737 .73593 .33621 Metetra
.664 .741 .907 r
.73593 .33621 .73679 .33737 .74309 .33529 .74223 .33413 Metetra
.664 .741 .907 r
.74223 .33413 .74309 .33529 .74941 .33321 .74855 .33205 Metetra
.664 .741 .907 r
.74855 .33205 .74941 .33321 .75574 .33113 .75489 .32996 Metetra
.664 .741 .907 r
.75489 .32996 .75574 .33113 .76208 .32904 .76123 .32787 Metetra
.664 .741 .907 r
.76123 .32787 .76208 .32904 .76844 .32695 .76759 .32578 Metetra
.664 .741 .907 r
.76759 .32578 .76844 .32695 .77482 .32485 .77397 .32368 Metetra
.664 .741 .907 r
.77397 .32368 .77482 .32485 .7812 .32275 .78036 .32157 Metetra
.664 .741 .907 r
.78036 .32157 .7812 .32275 .7876 .32064 .78676 .31946 Metetra
.664 .741 .907 r
.78676 .31946 .7876 .32064 .79402 .31853 .79318 .31735 Metetra
.664 .741 .907 r
.79318 .31735 .79402 .31853 .80045 .31641 .79962 .31523 Metetra
.664 .741 .907 r
.79962 .31523 .80045 .31641 .80689 .31429 .80606 .3131 Metetra
.664 .741 .907 r
.80606 .3131 .80689 .31429 .81335 .31216 .81252 .31097 Metetra
.664 .741 .907 r
.81252 .31097 .81335 .31216 .81982 .31003 .819 .30884 Metetra
.664 .741 .907 r
.819 .30884 .81982 .31003 .82631 .3079 .82549 .3067 Metetra
.664 .741 .907 r
.82549 .3067 .82631 .3079 .83281 .30575 .832 .30456 Metetra
.664 .741 .907 r
.832 .30456 .83281 .30575 .83933 .30361 .83852 .30241 Metetra
.664 .741 .907 r
.83852 .30241 .83933 .30361 .84586 .30146 .84505 .30026 Metetra
.664 .741 .907 r
.84505 .30026 .84586 .30146 .85241 .2993 .8516 .2981 Metetra
.664 .741 .907 r
.8516 .2981 .85241 .2993 .85897 .29714 .85816 .29594 Metetra
.664 .741 .907 r
.85816 .29594 .85897 .29714 .86554 .29498 .86474 .29377 Metetra
.664 .741 .907 r
.86474 .29377 .86554 .29498 .87213 .29281 .87134 .2916 Metetra
.664 .741 .907 r
.87134 .2916 .87213 .29281 .87874 .29064 .87794 .28942 Metetra
.664 .741 .907 r
.2825 .48427 .28355 .48525 .28889 .48349 .28785 .48251 Metetra
.664 .741 .907 r
.28785 .48251 .28889 .48349 .29425 .48173 .2932 .48074 Metetra
.664 .741 .907 r
.2932 .48074 .29425 .48173 .29962 .47996 .29857 .47897 Metetra
.664 .741 .907 r
.29857 .47897 .29962 .47996 .305 .47818 .30395 .47719 Metetra
.664 .741 .907 r
.30395 .47719 .305 .47818 .31039 .47641 .30935 .47542 Metetra
.664 .741 .907 r
.30935 .47542 .31039 .47641 .31579 .47463 .31475 .47364 Metetra
.664 .741 .907 r
.31475 .47364 .31579 .47463 .3212 .47285 .32016 .47185 Metetra
.664 .741 .907 r
.32016 .47185 .3212 .47285 .32662 .47106 .32559 .47006 Metetra
.948 .647 .434 r
.32559 .47006 .32662 .47106 .32789 .5403 .32852 .51078 Metetra
.682 .457 .574 r
.32852 .51078 .32789 .5403 .3375 .46748 .33647 .46647 Metetra
.664 .741 .907 r
.33647 .46647 .3375 .46748 .34291 .46649 .34193 .46467 Metetra
.648 .617 .805 r
.34193 .46467 .34291 .46649 .34842 .46388 .3474 .46287 Metetra
.664 .741 .907 r
.3474 .46287 .34842 .46388 .3539 .46207 .35288 .46106 Metetra
.664 .741 .907 r
.35288 .46106 .3539 .46207 .35939 .46026 .35837 .45925 Metetra
.664 .741 .907 r
.35837 .45925 .35939 .46026 .36489 .45845 .36387 .45744 Metetra
.664 .741 .907 r
.36387 .45744 .36489 .45845 .37041 .45664 .36939 .45562 Metetra
.664 .741 .907 r
.36939 .45562 .37041 .45664 .37593 .45482 .37491 .4538 Metetra
.664 .741 .907 r
.37491 .4538 .37593 .45482 .38146 .45299 .38045 .45197 Metetra
.664 .741 .907 r
.38045 .45197 .38146 .45299 .38701 .45116 .386 .45014 Metetra
.664 .741 .907 r
.386 .45014 .38701 .45116 .39257 .44933 .39156 .44831 Metetra
.664 .741 .907 r
.39156 .44831 .39257 .44933 .39814 .4475 .39713 .44647 Metetra
.664 .741 .907 r
.39713 .44647 .39814 .4475 .40372 .44566 .40272 .44463 Metetra
.94 .575 .273 r
.40272 .44463 .40372 .44566 .40931 .44382 .40755 .46413 Metetra
.595 .353 .519 r
.40755 .46413 .40931 .44382 .41492 .44197 .4128 .4738 Metetra
.399 .198 .488 r
.4128 .4738 .41492 .44197 .42053 .44012 .41954 .43909 Metetra
.664 .741 .907 r
.41954 .43909 .42053 .44012 .42616 .43827 .42517 .43723 Metetra
.664 .741 .907 r
.42517 .43723 .42616 .43827 .4318 .43641 .43081 .43537 Metetra
.664 .741 .907 r
.43081 .43537 .4318 .43641 .43745 .43455 .43646 .43351 Metetra
.664 .741 .907 r
.43646 .43351 .43745 .43455 .4426 .45314 .44213 .43164 Metetra
.473 .295 .558 r
.44213 .43164 .4426 .45314 .44728 .49552 .44742 .44586 Metetra
.591 .376 .558 r
.44742 .44586 .44728 .49552 .45448 .42894 .45349 .42789 Metetra
.664 .741 .907 r
.45349 .42789 .45448 .42894 .46018 .42706 .4592 .42601 Metetra
.664 .741 .907 r
.4592 .42601 .46018 .42706 .46589 .42518 .46491 .42413 Metetra
.664 .741 .907 r
.46491 .42413 .46589 .42518 .47161 .42329 .47063 .42224 Metetra
.664 .741 .907 r
.47063 .42224 .47161 .42329 .47735 .4214 .47637 .42035 Metetra
.664 .741 .907 r
.47637 .42035 .47735 .4214 .4831 .41951 .48212 .41845 Metetra
.664 .741 .907 r
.48212 .41845 .4831 .41951 .48885 .41761 .48788 .41655 Metetra
.664 .741 .907 r
.48788 .41655 .48885 .41761 .49463 .41571 .49366 .41465 Metetra
.664 .741 .907 r
.49366 .41465 .49463 .41571 .50041 .4138 .49944 .41274 Metetra
.664 .741 .907 r
.49944 .41274 .50041 .4138 .50621 .41189 .50524 .41083 Metetra
.664 .741 .907 r
.50524 .41083 .50621 .41189 .51201 .40998 .51105 .40891 Metetra
.664 .741 .907 r
.51105 .40891 .51201 .40998 .51783 .40806 .51688 .40699 Metetra
.664 .741 .907 r
.51688 .40699 .51783 .40806 .52367 .40614 .52271 .40507 Metetra
.664 .741 .907 r
.52271 .40507 .52367 .40614 .52951 .40422 .52856 .40314 Metetra
.664 .741 .907 r
.52856 .40314 .52951 .40422 .53537 .40229 .53442 .40121 Metetra
.664 .741 .907 r
.53442 .40121 .53537 .40229 .54124 .40035 .54029 .39927 Metetra
.664 .741 .907 r
.54029 .39927 .54124 .40035 .5472 .40882 .54618 .39733 Metetra
.576 .392 .596 r
.54618 .39733 .5472 .40882 .55302 .39647 .55207 .39539 Metetra
.664 .741 .907 r
.55207 .39539 .55302 .39647 .55893 .39452 .55799 .39344 Metetra
.664 .741 .907 r
.55799 .39344 .55893 .39452 .56485 .39257 .56391 .39148 Metetra
.664 .741 .907 r
.56391 .39148 .56485 .39257 .57078 .39062 .56984 .38953 Metetra
.664 .741 .907 r
.56984 .38953 .57078 .39062 .57673 .38866 .57579 .38757 Metetra
.664 .741 .907 r
.57579 .38757 .57673 .38866 .58269 .3867 .58175 .3856 Metetra
.664 .741 .907 r
.58175 .3856 .58269 .3867 .58866 .38473 .58773 .38363 Metetra
.664 .741 .907 r
.58773 .38363 .58866 .38473 .59464 .38276 .59372 .38166 Metetra
.664 .741 .907 r
.59372 .38166 .59464 .38276 .60064 .38078 .59972 .37968 Metetra
.963 .638 .336 r
.59972 .37968 .60064 .38078 .60665 .3788 .60712 .43288 Metetra
.421 .227 .509 r
.60712 .43288 .60665 .3788 .61267 .37682 .61175 .37571 Metetra
.664 .741 .907 r
.61175 .37571 .61267 .37682 .61871 .37483 .61779 .37372 Metetra
.664 .741 .907 r
.61779 .37372 .61871 .37483 .62476 .37284 .62384 .37172 Metetra
.664 .741 .907 r
.62384 .37172 .62476 .37284 .63082 .37084 .62991 .36972 Metetra
.664 .741 .907 r
.62991 .36972 .63082 .37084 .6369 .36884 .63599 .36772 Metetra
.664 .741 .907 r
.63599 .36772 .6369 .36884 .64298 .36683 .64208 .36571 Metetra
.664 .741 .907 r
.64208 .36571 .64298 .36683 .64909 .36482 .64818 .3637 Metetra
.664 .741 .907 r
.64818 .3637 .64909 .36482 .6552 .36281 .6543 .36168 Metetra
.664 .741 .907 r
.6543 .36168 .6552 .36281 .66133 .36079 .66043 .35966 Metetra
.664 .741 .907 r
.66043 .35966 .66133 .36079 .66747 .35876 .66658 .35763 Metetra
.664 .741 .907 r
.66658 .35763 .66747 .35876 .67363 .35674 .67274 .3556 Metetra
.664 .741 .907 r
.67274 .3556 .67363 .35674 .6798 .3547 .67891 .35357 Metetra
.664 .741 .907 r
.67891 .35357 .6798 .3547 .6862 .35695 .68509 .35153 Metetra
.599 .453 .654 r
.68509 .35153 .6862 .35695 .69217 .35062 .69129 .34948 Metetra
.664 .741 .907 r
.69129 .34948 .69217 .35062 .69838 .34858 .6975 .34744 Metetra
.664 .741 .907 r
.6975 .34744 .69838 .34858 .70461 .34653 .70373 .34538 Metetra
.664 .741 .907 r
.70373 .34538 .70461 .34653 .71084 .34447 .70997 .34333 Metetra
.664 .741 .907 r
.70997 .34333 .71084 .34447 .71709 .34241 .71622 .34126 Metetra
.664 .741 .907 r
.71622 .34126 .71709 .34241 .72336 .34035 .72249 .3392 Metetra
.664 .741 .907 r
.72249 .3392 .72336 .34035 .72964 .33828 .72877 .33713 Metetra
.664 .741 .907 r
.72877 .33713 .72964 .33828 .73593 .33621 .73506 .33505 Metetra
.664 .741 .907 r
.73506 .33505 .73593 .33621 .74223 .33413 .74137 .33297 Metetra
.664 .741 .907 r
.74137 .33297 .74223 .33413 .74855 .33205 .74769 .33089 Metetra
.664 .741 .907 r
.74769 .33089 .74855 .33205 .75489 .32996 .75403 .3288 Metetra
.664 .741 .907 r
.75403 .3288 .75489 .32996 .76123 .32787 .76038 .3267 Metetra
.664 .741 .907 r
.76038 .3267 .76123 .32787 .76759 .32578 .76675 .32461 Metetra
.664 .741 .907 r
.76675 .32461 .76759 .32578 .77397 .32368 .77313 .3225 Metetra
.664 .741 .907 r
.77313 .3225 .77397 .32368 .78036 .32157 .77952 .32039 Metetra
.664 .741 .907 r
.77952 .32039 .78036 .32157 .78676 .31946 .78593 .31828 Metetra
.664 .741 .907 r
.78593 .31828 .78676 .31946 .79318 .31735 .79235 .31616 Metetra
.664 .741 .907 r
.79235 .31616 .79318 .31735 .79962 .31523 .79878 .31404 Metetra
.664 .741 .907 r
.79878 .31404 .79962 .31523 .80606 .3131 .80523 .31192 Metetra
.664 .741 .907 r
.80523 .31192 .80606 .3131 .81252 .31097 .8117 .30978 Metetra
.605 .169 0 r
.8117 .30978 .81252 .31097 .819 .30884 .81946 .32138 Metetra
.404 .19 .472 r
.81946 .32138 .819 .30884 .82549 .3067 .82467 .30551 Metetra
.664 .741 .907 r
.82467 .30551 .82549 .3067 .832 .30456 .83118 .30336 Metetra
.664 .741 .907 r
.83118 .30336 .832 .30456 .83852 .30241 .8377 .30121 Metetra
.664 .741 .907 r
.8377 .30121 .83852 .30241 .84505 .30026 .84424 .29906 Metetra
.664 .741 .907 r
.84424 .29906 .84505 .30026 .8516 .2981 .85079 .29689 Metetra
.664 .741 .907 r
.85079 .29689 .8516 .2981 .85816 .29594 .85736 .29473 Metetra
.664 .741 .907 r
.85736 .29473 .85816 .29594 .86474 .29377 .86394 .29256 Metetra
.664 .741 .907 r
.86394 .29256 .86474 .29377 .87134 .2916 .87054 .29038 Metetra
.664 .741 .907 r
.87054 .29038 .87134 .2916 .87794 .28942 .87715 .2882 Metetra
.664 .741 .907 r
.28145 .48329 .2825 .48427 .28785 .48251 .2868 .48152 Metetra
.664 .741 .907 r
.2868 .48152 .28785 .48251 .2932 .48074 .29216 .47975 Metetra
.664 .741 .907 r
.29216 .47975 .2932 .48074 .29857 .47897 .29753 .47798 Metetra
.664 .741 .907 r
.29753 .47798 .29857 .47897 .30395 .47719 .30291 .4762 Metetra
.664 .741 .907 r
.30291 .4762 .30395 .47719 .30935 .47542 .3083 .47442 Metetra
.664 .741 .907 r
.3083 .47442 .30935 .47542 .31475 .47364 .31371 .47264 Metetra
.664 .741 .907 r
.31371 .47264 .31475 .47364 .32016 .47185 .31912 .47085 Metetra
.664 .741 .907 r
.31912 .47085 .32016 .47185 .32559 .47006 .32455 .46906 Metetra
.664 .741 .907 r
.32455 .46906 .32559 .47006 .32852 .51078 .32999 .46727 Metetra
.559 .351 .555 r
.32999 .46727 .32852 .51078 .33647 .46647 .33544 .46547 Metetra
.664 .741 .907 r
.33544 .46547 .33647 .46647 .34193 .46467 .3409 .46367 Metetra
.664 .741 .907 r
.3409 .46367 .34193 .46467 .3474 .46287 .34637 .46186 Metetra
.664 .741 .907 r
.34637 .46186 .3474 .46287 .35288 .46106 .35185 .46005 Metetra
.664 .741 .907 r
.35185 .46005 .35288 .46106 .35837 .45925 .35734 .45824 Metetra
.664 .741 .907 r
.35734 .45824 .35837 .45925 .36387 .45744 .36285 .45643 Metetra
.664 .741 .907 r
.36285 .45643 .36387 .45744 .36939 .45562 .36837 .45461 Metetra
.664 .741 .907 r
.36837 .45461 .36939 .45562 .37491 .4538 .3739 .45278 Metetra
.664 .741 .907 r
.3739 .45278 .37491 .4538 .38045 .45197 .37943 .45095 Metetra
.664 .741 .907 r
.37943 .45095 .38045 .45197 .386 .45014 .38499 .44912 Metetra
.664 .741 .907 r
.38499 .44912 .386 .45014 .39156 .44831 .39055 .44729 Metetra
.664 .741 .907 r
.39055 .44729 .39156 .44831 .39713 .44647 .39612 .44545 Metetra
.664 .741 .907 r
.39612 .44545 .39713 .44647 .40272 .44463 .40171 .4436 Metetra
.952 .679 .483 r
.40171 .4436 .40272 .44463 .40755 .46413 .39973 .65198 Metetra
.49 .283 .526 r
.39973 .65198 .40755 .46413 .4128 .4738 .40899 .55425 Metetra
.331 .153 .483 r
.40899 .55425 .4128 .4738 .41954 .43909 .41854 .43805 Metetra
.664 .741 .907 r
.41854 .43805 .41954 .43909 .42517 .43723 .42417 .43619 Metetra
.664 .741 .907 r
.42417 .43619 .42517 .43723 .43081 .43537 .42981 .43433 Metetra
.664 .741 .907 r
.42981 .43433 .43081 .43537 .43646 .43351 .43547 .43246 Metetra
.664 .741 .907 r
.43547 .43246 .43646 .43351 .44213 .43164 .44114 .43059 Metetra
.664 .741 .907 r
.44114 .43059 .44213 .43164 .44742 .44586 .44682 .42872 Metetra
.568 .374 .577 r
.44682 .42872 .44742 .44586 .45349 .42789 .45251 .42684 Metetra
.664 .741 .907 r
.45251 .42684 .45349 .42789 .4592 .42601 .45821 .42496 Metetra
.664 .741 .907 r
.45821 .42496 .4592 .42601 .46491 .42413 .46393 .42307 Metetra
.664 .741 .907 r
.46393 .42307 .46491 .42413 .47063 .42224 .46965 .42118 Metetra
.664 .741 .907 r
.46965 .42118 .47063 .42224 .47637 .42035 .47539 .41929 Metetra
.664 .741 .907 r
.47539 .41929 .47637 .42035 .48212 .41845 .48115 .41739 Metetra
.664 .741 .907 r
.48115 .41739 .48212 .41845 .48788 .41655 .48691 .41549 Metetra
.664 .741 .907 r
.48691 .41549 .48788 .41655 .49366 .41465 .49269 .41358 Metetra
.664 .741 .907 r
.49269 .41358 .49366 .41465 .49944 .41274 .49848 .41167 Metetra
.664 .741 .907 r
.49848 .41167 .49944 .41274 .50524 .41083 .50428 .40976 Metetra
.664 .741 .907 r
.50428 .40976 .50524 .41083 .51105 .40891 .51009 .40784 Metetra
.664 .741 .907 r
.51009 .40784 .51105 .40891 .51688 .40699 .51591 .40592 Metetra
.664 .741 .907 r
.51591 .40592 .51688 .40699 .52271 .40507 .52175 .40399 Metetra
.664 .741 .907 r
.52175 .40399 .52271 .40507 .52856 .40314 .5276 .40206 Metetra
.664 .741 .907 r
.5276 .40206 .52856 .40314 .53442 .40121 .53347 .40013 Metetra
.664 .741 .907 r
.53347 .40013 .53442 .40121 .54029 .39927 .53934 .39819 Metetra
.664 .741 .907 r
.53934 .39819 .54029 .39927 .54618 .39733 .54523 .39625 Metetra
.664 .741 .907 r
.54523 .39625 .54618 .39733 .55207 .39539 .55113 .3943 Metetra
.664 .741 .907 r
.55113 .3943 .55207 .39539 .55799 .39344 .55704 .39235 Metetra
.664 .741 .907 r
.55704 .39235 .55799 .39344 .56391 .39148 .56297 .39039 Metetra
.664 .741 .907 r
.56297 .39039 .56391 .39148 .56984 .38953 .56891 .38843 Metetra
.664 .741 .907 r
.56891 .38843 .56984 .38953 .57579 .38757 .57486 .38647 Metetra
.664 .741 .907 r
.57486 .38647 .57579 .38757 .58175 .3856 .58082 .3845 Metetra
.664 .741 .907 r
.58082 .3845 .58175 .3856 .58773 .38363 .5868 .38253 Metetra
.664 .741 .907 r
.5868 .38253 .58773 .38363 .59372 .38166 .59279 .38055 Metetra
.664 .741 .907 r
.59279 .38055 .59372 .38166 .59972 .37968 .59879 .37857 Metetra
.968 .662 .385 r
.59879 .37857 .59972 .37968 .60712 .43288 .60732 .47709 Metetra
.191 .051 .449 r
.60732 .47709 .60712 .43288 .61175 .37571 .61083 .3746 Metetra
.664 .741 .907 r
.61083 .3746 .61175 .37571 .61779 .37372 .61688 .37261 Metetra
.664 .741 .907 r
.61688 .37261 .61779 .37372 .62384 .37172 .62293 .37061 Metetra
.664 .741 .907 r
.62293 .37061 .62384 .37172 .62991 .36972 .629 .36861 Metetra
.664 .741 .907 r
.629 .36861 .62991 .36972 .63599 .36772 .63508 .3666 Metetra
.664 .741 .907 r
.63508 .3666 .63599 .36772 .64208 .36571 .64117 .36459 Metetra
.664 .741 .907 r
.64117 .36459 .64208 .36571 .64818 .3637 .64728 .36257 Metetra
.664 .741 .907 r
.64728 .36257 .64818 .3637 .6543 .36168 .6534 .36055 Metetra
.664 .741 .907 r
.6534 .36055 .6543 .36168 .66043 .35966 .65953 .35853 Metetra
.664 .741 .907 r
.65953 .35853 .66043 .35966 .66658 .35763 .66568 .3565 Metetra
.664 .741 .907 r
.66568 .3565 .66658 .35763 .67274 .3556 .67184 .35447 Metetra
.664 .741 .907 r
.67184 .35447 .67274 .3556 .67891 .35357 .67802 .35243 Metetra
.664 .741 .907 r
.67802 .35243 .67891 .35357 .68509 .35153 .6842 .35039 Metetra
.664 .741 .907 r
.6842 .35039 .68509 .35153 .69129 .34948 .69041 .34834 Metetra
.664 .741 .907 r
.69041 .34834 .69129 .34948 .6975 .34744 .69662 .34629 Metetra
.664 .741 .907 r
.69662 .34629 .6975 .34744 .70373 .34538 .70285 .34424 Metetra
.664 .741 .907 r
.70285 .34424 .70373 .34538 .70997 .34333 .70909 .34218 Metetra
.664 .741 .907 r
.70909 .34218 .70997 .34333 .71622 .34126 .71535 .34011 Metetra
.664 .741 .907 r
.71535 .34011 .71622 .34126 .72249 .3392 .72162 .33804 Metetra
.664 .741 .907 r
.72162 .33804 .72249 .3392 .72877 .33713 .7279 .33597 Metetra
.664 .741 .907 r
.7279 .33597 .72877 .33713 .73506 .33505 .7342 .33389 Metetra
.664 .741 .907 r
.7342 .33389 .73506 .33505 .74137 .33297 .74051 .33181 Metetra
.664 .741 .907 r
.74051 .33181 .74137 .33297 .74769 .33089 .74684 .32972 Metetra
.664 .741 .907 r
.74684 .32972 .74769 .33089 .75403 .3288 .75318 .32763 Metetra
.664 .741 .907 r
.75318 .32763 .75403 .3288 .76038 .3267 .75953 .32553 Metetra
.664 .741 .907 r
.75953 .32553 .76038 .3267 .76675 .32461 .7659 .32343 Metetra
.664 .741 .907 r
.7659 .32343 .76675 .32461 .77313 .3225 .77228 .32133 Metetra
.664 .741 .907 r
.77228 .32133 .77313 .3225 .77952 .32039 .77867 .31922 Metetra
.664 .741 .907 r
.77867 .31922 .77952 .32039 .78593 .31828 .78508 .3171 Metetra
.664 .741 .907 r
.78508 .3171 .78593 .31828 .79235 .31616 .79151 .31498 Metetra
.664 .741 .907 r
.79151 .31498 .79235 .31616 .79878 .31404 .79795 .31286 Metetra
.664 .741 .907 r
.79795 .31286 .79878 .31404 .80523 .31192 .8044 .31073 Metetra
.664 .741 .907 r
.8044 .31073 .80523 .31192 .8117 .30978 .81087 .30859 Metetra
.948 .601 .209 r
.81087 .30859 .8117 .30978 .81946 .32138 .82309 .36788 Metetra
.394 .211 .512 r
.82309 .36788 .81946 .32138 .82467 .30551 .82385 .30431 Metetra
.664 .741 .907 r
.82385 .30431 .82467 .30551 .83118 .30336 .83036 .30216 Metetra
.664 .741 .907 r
.83036 .30216 .83118 .30336 .8377 .30121 .83689 .30001 Metetra
.664 .741 .907 r
.83689 .30001 .8377 .30121 .84424 .29906 .84343 .29785 Metetra
.664 .741 .907 r
.84343 .29785 .84424 .29906 .85079 .29689 .84998 .29569 Metetra
.664 .741 .907 r
.84998 .29569 .85079 .29689 .85736 .29473 .85655 .29352 Metetra
.664 .741 .907 r
.85655 .29352 .85736 .29473 .86394 .29256 .86314 .29135 Metetra
.664 .741 .907 r
.86314 .29135 .86394 .29256 .87054 .29038 .86974 .28917 Metetra
.664 .741 .907 r
.86974 .28917 .87054 .29038 .87715 .2882 .87635 .28699 Metetra
.664 .741 .907 r
.28039 .4823 .28145 .48329 .2868 .48152 .28574 .48053 Metetra
.664 .741 .907 r
.28574 .48053 .2868 .48152 .29216 .47975 .29111 .47876 Metetra
.664 .741 .907 r
.29111 .47876 .29216 .47975 .29753 .47798 .29648 .47699 Metetra
.664 .741 .907 r
.29648 .47699 .29753 .47798 .30291 .4762 .30186 .47521 Metetra
.664 .741 .907 r
.30186 .47521 .30291 .4762 .3083 .47442 .30726 .47343 Metetra
.664 .741 .907 r
.30726 .47343 .3083 .47442 .31371 .47264 .31267 .47164 Metetra
.664 .741 .907 r
.31267 .47164 .31371 .47264 .31912 .47085 .31808 .46986 Metetra
.664 .741 .907 r
.31808 .46986 .31912 .47085 .32455 .46906 .32351 .46806 Metetra
.664 .741 .907 r
.32351 .46806 .32455 .46906 .32999 .46727 .32895 .46627 Metetra
.664 .741 .907 r
.32895 .46627 .32999 .46727 .33544 .46547 .3344 .46447 Metetra
.664 .741 .907 r
.3344 .46447 .33544 .46547 .3409 .46367 .33987 .46266 Metetra
.664 .741 .907 r
.33987 .46266 .3409 .46367 .34637 .46186 .34534 .46086 Metetra
.664 .741 .907 r
.34534 .46086 .34637 .46186 .35185 .46005 .35082 .45904 Metetra
.664 .741 .907 r
.35082 .45904 .35185 .46005 .35734 .45824 .35632 .45723 Metetra
.664 .741 .907 r
.35632 .45723 .35734 .45824 .36285 .45643 .36183 .45541 Metetra
.664 .741 .907 r
.36183 .45541 .36285 .45643 .36837 .45461 .36735 .45359 Metetra
.664 .741 .907 r
.36735 .45359 .36837 .45461 .3739 .45278 .37288 .45176 Metetra
.664 .741 .907 r
.37288 .45176 .3739 .45278 .37943 .45095 .37842 .44993 Metetra
.664 .741 .907 r
.37842 .44993 .37943 .45095 .38499 .44912 .38397 .4481 Metetra
.664 .741 .907 r
.38397 .4481 .38499 .44912 .39055 .44729 .38954 .44626 Metetra
.664 .741 .907 r
.38954 .44626 .39055 .44729 .39612 .44545 .39511 .44442 Metetra
.664 .741 .907 r
.39511 .44442 .39612 .44545 .40171 .4436 .4007 .44257 Metetra
.952 .68 .484 r
.4007 .44257 .40171 .4436 .39973 .65198 .39818 .66423 Metetra
.995 .759 .444 r
.39818 .66423 .39973 .65198 .40899 .55425 .41037 .48347 Metetra
.618 .396 .557 r
.41037 .48347 .40899 .55425 .41854 .43805 .41753 .43701 Metetra
.664 .741 .907 r
.41753 .43701 .41854 .43805 .42417 .43619 .42317 .43515 Metetra
.664 .741 .907 r
.42317 .43515 .42417 .43619 .42981 .43433 .42882 .43329 Metetra
.664 .741 .907 r
.42882 .43329 .42981 .43433 .43547 .43246 .43447 .43142 Metetra
.664 .741 .907 r
.43447 .43142 .43547 .43246 .44114 .43059 .44014 .42955 Metetra
.664 .741 .907 r
.44014 .42955 .44114 .43059 .44682 .42872 .44583 .42767 Metetra
.664 .741 .907 r
.44583 .42767 .44682 .42872 .45251 .42684 .45152 .42579 Metetra
.664 .741 .907 r
.45152 .42579 .45251 .42684 .45821 .42496 .45723 .42391 Metetra
.664 .741 .907 r
.45723 .42391 .45821 .42496 .46393 .42307 .46294 .42202 Metetra
.664 .741 .907 r
.46294 .42202 .46393 .42307 .46965 .42118 .46867 .42013 Metetra
.664 .741 .907 r
.46867 .42013 .46965 .42118 .47539 .41929 .47442 .41823 Metetra
.664 .741 .907 r
.47442 .41823 .47539 .41929 .48115 .41739 .48017 .41633 Metetra
.664 .741 .907 r
.48017 .41633 .48115 .41739 .48691 .41549 .48594 .41443 Metetra
.664 .741 .907 r
.48594 .41443 .48691 .41549 .49269 .41358 .49172 .41252 Metetra
.664 .741 .907 r
.49172 .41252 .49269 .41358 .49848 .41167 .49751 .41061 Metetra
.664 .741 .907 r
.49751 .41061 .49848 .41167 .50428 .40976 .50331 .40869 Metetra
.664 .741 .907 r
.50331 .40869 .50428 .40976 .51009 .40784 .50913 .40677 Metetra
.664 .741 .907 r
.50913 .40677 .51009 .40784 .51591 .40592 .51495 .40485 Metetra
.664 .741 .907 r
.51495 .40485 .51591 .40592 .52175 .40399 .52079 .40292 Metetra
.664 .741 .907 r
.52079 .40292 .52175 .40399 .5276 .40206 .52665 .40098 Metetra
.664 .741 .907 r
.52665 .40098 .5276 .40206 .53347 .40013 .53251 .39905 Metetra
.664 .741 .907 r
.53251 .39905 .53347 .40013 .53934 .39819 .53839 .39711 Metetra
.664 .741 .907 r
.53839 .39711 .53934 .39819 .54523 .39625 .54428 .39516 Metetra
.664 .741 .907 r
.54428 .39516 .54523 .39625 .55113 .3943 .55018 .39321 Metetra
.664 .741 .907 r
.55018 .39321 .55113 .3943 .55704 .39235 .5561 .39126 Metetra
.664 .741 .907 r
.5561 .39126 .55704 .39235 .56297 .39039 .56203 .3893 Metetra
.664 .741 .907 r
.56203 .3893 .56297 .39039 .56891 .38843 .56797 .38734 Metetra
.664 .741 .907 r
.56797 .38734 .56891 .38843 .57486 .38647 .57392 .38537 Metetra
.664 .741 .907 r
.57392 .38537 .57486 .38647 .58082 .3845 .57989 .3834 Metetra
.664 .741 .907 r
.57989 .3834 .58082 .3845 .5868 .38253 .58587 .38143 Metetra
.664 .741 .907 r
.58587 .38143 .5868 .38253 .59279 .38055 .59186 .37945 Metetra
.627 .156 0 r
.59186 .37945 .59279 .38055 .59879 .37857 .5981 .38785 Metetra
.773 .483 .494 r
.5981 .38785 .59879 .37857 .60732 .47709 .60511 .42507 Metetra
.643 .415 .557 r
.60511 .42507 .60732 .47709 .61083 .3746 .60991 .37349 Metetra
.664 .741 .907 r
.60991 .37349 .61083 .3746 .61688 .37261 .61596 .37149 Metetra
.664 .741 .907 r
.61596 .37149 .61688 .37261 .62293 .37061 .62201 .36949 Metetra
.664 .741 .907 r
.62201 .36949 .62293 .37061 .629 .36861 .62808 .36749 Metetra
.664 .741 .907 r
.62808 .36749 .629 .36861 .63508 .3666 .63417 .36548 Metetra
.664 .741 .907 r
.63417 .36548 .63508 .3666 .64117 .36459 .64026 .36346 Metetra
.664 .741 .907 r
.64026 .36346 .64117 .36459 .64728 .36257 .64637 .36145 Metetra
.664 .741 .907 r
.64637 .36145 .64728 .36257 .6534 .36055 .6525 .35942 Metetra
.664 .741 .907 r
.6525 .35942 .6534 .36055 .65953 .35853 .65864 .3574 Metetra
.664 .741 .907 r
.65864 .3574 .65953 .35853 .66568 .3565 .66479 .35537 Metetra
.664 .741 .907 r
.66479 .35537 .66568 .3565 .67184 .35447 .67095 .35333 Metetra
.664 .741 .907 r
.67095 .35333 .67184 .35447 .67802 .35243 .67713 .35129 Metetra
.664 .741 .907 r
.67713 .35129 .67802 .35243 .6842 .35039 .68332 .34925 Metetra
.664 .741 .907 r
.68332 .34925 .6842 .35039 .69041 .34834 .68952 .3472 Metetra
.664 .741 .907 r
.68952 .3472 .69041 .34834 .69662 .34629 .69574 .34515 Metetra
.664 .741 .907 r
.69574 .34515 .69662 .34629 .70285 .34424 .70197 .34309 Metetra
.664 .741 .907 r
.70197 .34309 .70285 .34424 .70909 .34218 .70822 .34103 Metetra
.664 .741 .907 r
.70822 .34103 .70909 .34218 .71535 .34011 .71447 .33896 Metetra
.664 .741 .907 r
.71447 .33896 .71535 .34011 .72162 .33804 .72075 .33689 Metetra
.664 .741 .907 r
.72075 .33689 .72162 .33804 .7279 .33597 .72703 .33481 Metetra
.664 .741 .907 r
.72703 .33481 .7279 .33597 .7342 .33389 .73333 .33273 Metetra
.664 .741 .907 r
.73333 .33273 .7342 .33389 .74051 .33181 .73965 .33065 Metetra
.664 .741 .907 r
.73965 .33065 .74051 .33181 .74684 .32972 .74598 .32856 Metetra
.664 .741 .907 r
.74598 .32856 .74684 .32972 .75318 .32763 .75232 .32646 Metetra
.664 .741 .907 r
.75232 .32646 .75318 .32763 .75953 .32553 .75868 .32436 Metetra
.664 .741 .907 r
.75868 .32436 .75953 .32553 .7659 .32343 .76505 .32226 Metetra
.664 .741 .907 r
.76505 .32226 .7659 .32343 .77228 .32133 .77143 .32015 Metetra
.664 .741 .907 r
.77143 .32015 .77228 .32133 .77867 .31922 .77783 .31804 Metetra
.664 .741 .907 r
.77783 .31804 .77867 .31922 .78508 .3171 .78424 .31592 Metetra
.664 .741 .907 r
.78424 .31592 .78508 .3171 .79151 .31498 .79067 .3138 Metetra
.664 .741 .907 r
.79067 .3138 .79151 .31498 .79795 .31286 .79711 .31167 Metetra
.63 .192 0 r
.79711 .31167 .79795 .31286 .8044 .31073 .80481 .32352 Metetra
.403 .189 .472 r
.80481 .32352 .8044 .31073 .81087 .30859 .81004 .3074 Metetra
.664 .741 .907 r
.81004 .3074 .81087 .30859 .82309 .36788 .81653 .30526 Metetra
.557 .347 .551 r
.81653 .30526 .82309 .36788 .82385 .30431 .82303 .30311 Metetra
.664 .741 .907 r
.82303 .30311 .82385 .30431 .83036 .30216 .82954 .30096 Metetra
.664 .741 .907 r
.82954 .30096 .83036 .30216 .83689 .30001 .83607 .29881 Metetra
.664 .741 .907 r
.83607 .29881 .83689 .30001 .84343 .29785 .84261 .29665 Metetra
.664 .741 .907 r
.84261 .29665 .84343 .29785 .84998 .29569 .84917 .29448 Metetra
.664 .741 .907 r
.84917 .29448 .84998 .29569 .85655 .29352 .85574 .29231 Metetra
.664 .741 .907 r
.85574 .29231 .85655 .29352 .86314 .29135 .86233 .29013 Metetra
.664 .741 .907 r
.86233 .29013 .86314 .29135 .86974 .28917 .86894 .28795 Metetra
.664 .741 .907 r
.86894 .28795 .86974 .28917 .87635 .28699 .87555 .28577 Metetra
.664 .741 .907 r
.27934 .48132 .28039 .4823 .28574 .48053 .28469 .47955 Metetra
.664 .741 .907 r
.28469 .47955 .28574 .48053 .29111 .47876 .29005 .47777 Metetra
.664 .741 .907 r
.29005 .47777 .29111 .47876 .29648 .47699 .29543 .476 Metetra
.664 .741 .907 r
.29543 .476 .29648 .47699 .30186 .47521 .30082 .47422 Metetra
.664 .741 .907 r
.30082 .47422 .30186 .47521 .30726 .47343 .30621 .47243 Metetra
.946 .633 .41 r
.30621 .47243 .30726 .47343 .31267 .47164 .3095 .50336 Metetra
.405 .2 .485 r
.3095 .50336 .31267 .47164 .31808 .46986 .31686 .47176 Metetra
.032 0 0 r
.31686 .47176 .31808 .46986 .32351 .46806 .32247 .46706 Metetra
.664 .741 .907 r
.32247 .46706 .32351 .46806 .32895 .46627 .32792 .46526 Metetra
.664 .741 .907 r
.32792 .46526 .32895 .46627 .3344 .46447 .33337 .46346 Metetra
.664 .741 .907 r
.33337 .46346 .3344 .46447 .33987 .46266 .33883 .46166 Metetra
.664 .741 .907 r
.33883 .46166 .33987 .46266 .34534 .46086 .34431 .45985 Metetra
.664 .741 .907 r
.34431 .45985 .34534 .46086 .35082 .45904 .34979 .45803 Metetra
.664 .741 .907 r
.34979 .45803 .35082 .45904 .35632 .45723 .35529 .45622 Metetra
.664 .741 .907 r
.35529 .45622 .35632 .45723 .36183 .45541 .3608 .45439 Metetra
.664 .741 .907 r
.3608 .45439 .36183 .45541 .36735 .45359 .36632 .45257 Metetra
.664 .741 .907 r
.36632 .45257 .36735 .45359 .37288 .45176 .37186 .45074 Metetra
.664 .741 .907 r
.37186 .45074 .37288 .45176 .37842 .44993 .3774 .44891 Metetra
.664 .741 .907 r
.3774 .44891 .37842 .44993 .38397 .4481 .38296 .44707 Metetra
.664 .741 .907 r
.38296 .44707 .38397 .4481 .38954 .44626 .38852 .44523 Metetra
.664 .741 .907 r
.38852 .44523 .38954 .44626 .39511 .44442 .3941 .44339 Metetra
.664 .741 .907 r
.3941 .44339 .39511 .44442 .4007 .44257 .39969 .44154 Metetra
.952 .678 .48 r
.39969 .44154 .4007 .44257 .39818 .66423 .39871 .61931 Metetra
.788 .54 .562 r
.39871 .61931 .39818 .66423 .41037 .48347 .41084 .43974 Metetra
.563 .354 .556 r
.41084 .43974 .41037 .48347 .41753 .43701 .41653 .43598 Metetra
.664 .741 .907 r
.41653 .43598 .41753 .43701 .42317 .43515 .42217 .43411 Metetra
.664 .741 .907 r
.42217 .43411 .42317 .43515 .42882 .43329 .42782 .43225 Metetra
.664 .741 .907 r
.42782 .43225 .42882 .43329 .43447 .43142 .43348 .43038 Metetra
.664 .741 .907 r
.43348 .43038 .43447 .43142 .44014 .42955 .43915 .4285 Metetra
.664 .741 .907 r
.43915 .4285 .44014 .42955 .44583 .42767 .44483 .42662 Metetra
.664 .741 .907 r
.44483 .42662 .44583 .42767 .45152 .42579 .45053 .42474 Metetra
.664 .741 .907 r
.45053 .42474 .45152 .42579 .45723 .42391 .45624 .42286 Metetra
.664 .741 .907 r
.45624 .42286 .45723 .42391 .46294 .42202 .46196 .42096 Metetra
.664 .741 .907 r
.46196 .42096 .46294 .42202 .46867 .42013 .46769 .41907 Metetra
.664 .741 .907 r
.46769 .41907 .46867 .42013 .47442 .41823 .47344 .41717 Metetra
.664 .741 .907 r
.47344 .41717 .47442 .41823 .48017 .41633 .47919 .41527 Metetra
.664 .741 .907 r
.47919 .41527 .48017 .41633 .48594 .41443 .48496 .41336 Metetra
.811 .354 0 r
.48496 .41336 .48594 .41443 .49172 .41252 .49061 .42367 Metetra
.37 .148 .441 r
.49061 .42367 .49172 .41252 .49751 .41061 .49654 .40954 Metetra
.664 .741 .907 r
.49654 .40954 .49751 .41061 .50331 .40869 .50234 .40762 Metetra
.664 .741 .907 r
.50234 .40762 .50331 .40869 .50913 .40677 .50816 .4057 Metetra
.664 .741 .907 r
.50816 .4057 .50913 .40677 .51495 .40485 .51399 .40377 Metetra
.664 .741 .907 r
.51399 .40377 .51495 .40485 .52079 .40292 .51983 .40184 Metetra
.664 .741 .907 r
.51983 .40184 .52079 .40292 .52665 .40098 .52569 .3999 Metetra
.664 .741 .907 r
.52569 .3999 .52665 .40098 .53251 .39905 .53156 .39797 Metetra
.664 .741 .907 r
.53156 .39797 .53251 .39905 .53839 .39711 .53744 .39602 Metetra
.664 .741 .907 r
.53744 .39602 .53839 .39711 .54428 .39516 .54333 .39407 Metetra
.664 .741 .907 r
.54333 .39407 .54428 .39516 .55018 .39321 .54923 .39212 Metetra
.664 .741 .907 r
.54923 .39212 .55018 .39321 .5561 .39126 .55515 .39017 Metetra
.664 .741 .907 r
.55515 .39017 .5561 .39126 .56203 .3893 .56108 .38821 Metetra
.664 .741 .907 r
.56108 .38821 .56203 .3893 .56797 .38734 .56703 .38624 Metetra
.664 .741 .907 r
.56703 .38624 .56797 .38734 .57392 .38537 .57298 .38427 Metetra
.664 .741 .907 r
.57298 .38427 .57392 .38537 .57989 .3834 .57895 .3823 Metetra
.664 .741 .907 r
.57895 .3823 .57989 .3834 .58587 .38143 .58493 .38033 Metetra
.664 .741 .907 r
.58493 .38033 .58587 .38143 .59186 .37945 .59093 .37834 Metetra
.682 .214 0 r
.59093 .37834 .59186 .37945 .5981 .38785 .59719 .38755 Metetra
.936 .571 .289 r
.59719 .38755 .5981 .38785 .60511 .42507 .60394 .41459 Metetra
.794 .555 .575 r
.60394 .41459 .60511 .42507 .60991 .37349 .60899 .37237 Metetra
.664 .741 .907 r
.60899 .37237 .60991 .37349 .61596 .37149 .61504 .37038 Metetra
.664 .741 .907 r
.61504 .37038 .61596 .37149 .62201 .36949 .6211 .36837 Metetra
.664 .741 .907 r
.6211 .36837 .62201 .36949 .62808 .36749 .62717 .36637 Metetra
.664 .741 .907 r
.62717 .36637 .62808 .36749 .63417 .36548 .63326 .36436 Metetra
.664 .741 .907 r
.63326 .36436 .63417 .36548 .64026 .36346 .63936 .36234 Metetra
.664 .741 .907 r
.63936 .36234 .64026 .36346 .64637 .36145 .64547 .36032 Metetra
.664 .741 .907 r
.64547 .36032 .64637 .36145 .6525 .35942 .65159 .3583 Metetra
.664 .741 .907 r
.65159 .3583 .6525 .35942 .65864 .3574 .65773 .35627 Metetra
.664 .741 .907 r
.65773 .35627 .65864 .3574 .66479 .35537 .66389 .35423 Metetra
.664 .741 .907 r
.66389 .35423 .66479 .35537 .67095 .35333 .67005 .3522 Metetra
.664 .741 .907 r
.67005 .3522 .67095 .35333 .67713 .35129 .67623 .35015 Metetra
.587 .71 .928 r
.67623 .35015 .67713 .35129 .68332 .34925 .68248 .3492 Metetra
.614 .953 .914 r
.68248 .3492 .68332 .34925 .68952 .3472 .68863 .34605 Metetra
.664 .741 .907 r
.68863 .34605 .68952 .3472 .69574 .34515 .69485 .344 Metetra
.664 .741 .907 r
.69485 .344 .69574 .34515 .70197 .34309 .70109 .34194 Metetra
.664 .741 .907 r
.70109 .34194 .70197 .34309 .70822 .34103 .70734 .33987 Metetra
.664 .741 .907 r
.70734 .33987 .70822 .34103 .71447 .33896 .7136 .3378 Metetra
.664 .741 .907 r
.7136 .3378 .71447 .33896 .72075 .33689 .71987 .33573 Metetra
.664 .741 .907 r
.71987 .33573 .72075 .33689 .72703 .33481 .72616 .33365 Metetra
.664 .741 .907 r
.72616 .33365 .72703 .33481 .73333 .33273 .73247 .33157 Metetra
.664 .741 .907 r
.73247 .33157 .73333 .33273 .73965 .33065 .73878 .32948 Metetra
.664 .741 .907 r
.73878 .32948 .73965 .33065 .74598 .32856 .74512 .32739 Metetra
.664 .741 .907 r
.74512 .32739 .74598 .32856 .75232 .32646 .75146 .32529 Metetra
.664 .741 .907 r
.75146 .32529 .75232 .32646 .75868 .32436 .75782 .32319 Metetra
.664 .741 .907 r
.75782 .32319 .75868 .32436 .76505 .32226 .76419 .32108 Metetra
.664 .741 .907 r
.76419 .32108 .76505 .32226 .77143 .32015 .77058 .31897 Metetra
.664 .741 .907 r
.77058 .31897 .77143 .32015 .77783 .31804 .77698 .31686 Metetra
.664 .741 .907 r
.77698 .31686 .77783 .31804 .78424 .31592 .7834 .31474 Metetra
.664 .741 .907 r
.7834 .31474 .78424 .31592 .79067 .3138 .78983 .31261 Metetra
.664 .741 .907 r
.78983 .31261 .79067 .3138 .79711 .31167 .79628 .31048 Metetra
.339 .574 .927 r
.79628 .31048 .79711 .31167 .80481 .32352 .80307 .31215 Metetra
.606 .415 .596 r
.80307 .31215 .80481 .32352 .81004 .3074 .80921 .30621 Metetra
.664 .741 .907 r
.80921 .30621 .81004 .3074 .81653 .30526 .8157 .30406 Metetra
.664 .741 .907 r
.8157 .30406 .81653 .30526 .82303 .30311 .8222 .30191 Metetra
.664 .741 .907 r
.8222 .30191 .82303 .30311 .82954 .30096 .82872 .29976 Metetra
.664 .741 .907 r
.82872 .29976 .82954 .30096 .83607 .29881 .83525 .2976 Metetra
.664 .741 .907 r
.83525 .2976 .83607 .29881 .84261 .29665 .8418 .29544 Metetra
.664 .741 .907 r
.8418 .29544 .84261 .29665 .84917 .29448 .84836 .29327 Metetra
.664 .741 .907 r
.84836 .29327 .84917 .29448 .85574 .29231 .85494 .2911 Metetra
.664 .741 .907 r
.85494 .2911 .85574 .29231 .86233 .29013 .86153 .28892 Metetra
.664 .741 .907 r
.86153 .28892 .86233 .29013 .86894 .28795 .86813 .28673 Metetra
.664 .741 .907 r
.86813 .28673 .86894 .28795 .87555 .28577 .87476 .28455 Metetra
.664 .741 .907 r
.27828 .48033 .27934 .48132 .28469 .47955 .28364 .47856 Metetra
.664 .741 .907 r
.28364 .47856 .28469 .47955 .29005 .47777 .289 .47678 Metetra
.664 .741 .907 r
.289 .47678 .29005 .47777 .29543 .476 .29438 .47501 Metetra
.664 .741 .907 r
.29438 .47501 .29543 .476 .30082 .47422 .29977 .47322 Metetra
.664 .741 .907 r
.29977 .47322 .30082 .47422 .30621 .47243 .30517 .47144 Metetra
.945 .664 .476 r
.30517 .47144 .30621 .47243 .3095 .50336 .30605 .53918 Metetra
.173 .013 .409 r
.30605 .53918 .3095 .50336 .31686 .47176 .316 .46786 Metetra
.611 .486 .685 r
.316 .46786 .31686 .47176 .32247 .46706 .32143 .46606 Metetra
.664 .741 .907 r
.32143 .46606 .32247 .46706 .32792 .46526 .32688 .46426 Metetra
.664 .741 .907 r
.32688 .46426 .32792 .46526 .33337 .46346 .33233 .46245 Metetra
.664 .741 .907 r
.33233 .46245 .33337 .46346 .33883 .46166 .3378 .46065 Metetra
.664 .741 .907 r
.3378 .46065 .33883 .46166 .34431 .45985 .34328 .45883 Metetra
.664 .741 .907 r
.34328 .45883 .34431 .45985 .34979 .45803 .34877 .45702 Metetra
.664 .741 .907 r
.34877 .45702 .34979 .45803 .35529 .45622 .35427 .4552 Metetra
.664 .741 .907 r
.35427 .4552 .35529 .45622 .3608 .45439 .35978 .45338 Metetra
.664 .741 .907 r
.35978 .45338 .3608 .45439 .36632 .45257 .3653 .45155 Metetra
.664 .741 .907 r
.3653 .45155 .36632 .45257 .37186 .45074 .37083 .44972 Metetra
.664 .741 .907 r
.37083 .44972 .37186 .45074 .3774 .44891 .37638 .44789 Metetra
.664 .741 .907 r
.37638 .44789 .3774 .44891 .38296 .44707 .38194 .44605 Metetra
.664 .741 .907 r
.38194 .44605 .38296 .44707 .38852 .44523 .38751 .44421 Metetra
.664 .741 .907 r
.38751 .44421 .38852 .44523 .3941 .44339 .39309 .44236 Metetra
.664 .741 .907 r
.39309 .44236 .3941 .44339 .39969 .44154 .39868 .44051 Metetra
.954 .648 .415 r
.39868 .44051 .39969 .44154 .39871 .61931 .40253 .48622 Metetra
.584 .365 .549 r
.40253 .48622 .39871 .61931 .41084 .43974 .40953 .44739 Metetra
.286 .055 .378 r
.40953 .44739 .41084 .43974 .41653 .43598 .41553 .43494 Metetra
.664 .741 .907 r
.41553 .43494 .41653 .43598 .42217 .43411 .42117 .43307 Metetra
.664 .741 .907 r
.42117 .43307 .42217 .43411 .42782 .43225 .42682 .43121 Metetra
.664 .741 .907 r
.42682 .43121 .42782 .43225 .43348 .43038 .43248 .42933 Metetra
.664 .741 .907 r
.43248 .42933 .43348 .43038 .43915 .4285 .43816 .42746 Metetra
.664 .741 .907 r
.43816 .42746 .43915 .4285 .44483 .42662 .44384 .42557 Metetra
.664 .741 .907 r
.44384 .42557 .44483 .42662 .45053 .42474 .44954 .42369 Metetra
.664 .741 .907 r
.44954 .42369 .45053 .42474 .45624 .42286 .45525 .4218 Metetra
.664 .741 .907 r
.45525 .4218 .45624 .42286 .46196 .42096 .46097 .41991 Metetra
.664 .741 .907 r
.46097 .41991 .46196 .42096 .46769 .41907 .46671 .41801 Metetra
.664 .741 .907 r
.46671 .41801 .46769 .41907 .47344 .41717 .47246 .41611 Metetra
.664 .741 .907 r
.47246 .41611 .47344 .41717 .47919 .41527 .47821 .41421 Metetra
.664 .741 .907 r
.47821 .41421 .47919 .41527 .48496 .41336 .48399 .4123 Metetra
.618 .725 .923 r
.48399 .4123 .48496 .41336 .49061 .42367 .48976 .41103 Metetra
.579 .39 .59 r
.48976 .41103 .49061 .42367 .49654 .40954 .49557 .40847 Metetra
.664 .741 .907 r
.49557 .40847 .49654 .40954 .50234 .40762 .50137 .40655 Metetra
.664 .741 .907 r
.50137 .40655 .50234 .40762 .50816 .4057 .50719 .40462 Metetra
.664 .741 .907 r
.50719 .40462 .50816 .4057 .51399 .40377 .51303 .40269 Metetra
.664 .741 .907 r
.51303 .40269 .51399 .40377 .51983 .40184 .51887 .40076 Metetra
.664 .741 .907 r
.51887 .40076 .51983 .40184 .52569 .3999 .52473 .39882 Metetra
.664 .741 .907 r
.52473 .39882 .52569 .3999 .53156 .39797 .5306 .39688 Metetra
.664 .741 .907 r
.5306 .39688 .53156 .39797 .53744 .39602 .53648 .39494 Metetra
.664 .741 .907 r
.53648 .39494 .53744 .39602 .54333 .39407 .54238 .39299 Metetra
.664 .741 .907 r
.54238 .39299 .54333 .39407 .54923 .39212 .54828 .39103 Metetra
.664 .741 .907 r
.54828 .39103 .54923 .39212 .55515 .39017 .55421 .38907 Metetra
.664 .741 .907 r
.55421 .38907 .55515 .39017 .56108 .38821 .56014 .38711 Metetra
.664 .741 .907 r
.56014 .38711 .56108 .38821 .56703 .38624 .56608 .38515 Metetra
.664 .741 .907 r
.56608 .38515 .56703 .38624 .57298 .38427 .57204 .38317 Metetra
.664 .741 .907 r
.57204 .38317 .57298 .38427 .57895 .3823 .57802 .3812 Metetra
.664 .741 .907 r
.57802 .3812 .57895 .3823 .58493 .38033 .584 .37922 Metetra
.664 .741 .907 r
.584 .37922 .58493 .38033 .59093 .37834 .59 .37724 Metetra
.664 .741 .907 r
.59 .37724 .59093 .37834 .59719 .38755 .59601 .37525 Metetra
.437 .289 .581 r
.59601 .37525 .59719 .38755 .60394 .41459 .60237 .38721 Metetra
.61 .396 .566 r
.60237 .38721 .60394 .41459 .60899 .37237 .60807 .37126 Metetra
.664 .741 .907 r
.60807 .37126 .60899 .37237 .61504 .37038 .61412 .36926 Metetra
.664 .741 .907 r
.61412 .36926 .61504 .37038 .6211 .36837 .62018 .36726 Metetra
.664 .741 .907 r
.62018 .36726 .6211 .36837 .62717 .36637 .62625 .36525 Metetra
.664 .741 .907 r
.62625 .36525 .62717 .36637 .63326 .36436 .63234 .36323 Metetra
.664 .741 .907 r
.63234 .36323 .63326 .36436 .63936 .36234 .63845 .36121 Metetra
.664 .741 .907 r
.63845 .36121 .63936 .36234 .64547 .36032 .64456 .35919 Metetra
.664 .741 .907 r
.64456 .35919 .64547 .36032 .65159 .3583 .65069 .35716 Metetra
.664 .741 .907 r
.65069 .35716 .65159 .3583 .65773 .35627 .65683 .35513 Metetra
.664 .741 .907 r
.65683 .35513 .65773 .35627 .66389 .35423 .66299 .3531 Metetra
.664 .741 .907 r
.66299 .3531 .66389 .35423 .67005 .3522 .66916 .35106 Metetra
.664 .741 .907 r
.66916 .35106 .67005 .3522 .67623 .35015 .67534 .34901 Metetra
.664 .741 .907 r
.67534 .34901 .67623 .35015 .68248 .3492 .68154 .34696 Metetra
.642 .591 .782 r
.68154 .34696 .68248 .3492 .68863 .34605 .68775 .34491 Metetra
.664 .741 .907 r
.68775 .34491 .68863 .34605 .69485 .344 .69397 .34285 Metetra
.664 .741 .907 r
.69397 .34285 .69485 .344 .70109 .34194 .70021 .34079 Metetra
.664 .741 .907 r
.70021 .34079 .70109 .34194 .70734 .33987 .70646 .33872 Metetra
.664 .741 .907 r
.70646 .33872 .70734 .33987 .7136 .3378 .71272 .33665 Metetra
.664 .741 .907 r
.71272 .33665 .7136 .3378 .71987 .33573 .719 .33457 Metetra
.664 .741 .907 r
.719 .33457 .71987 .33573 .72616 .33365 .72529 .33249 Metetra
.664 .741 .907 r
.72529 .33249 .72616 .33365 .73247 .33157 .7316 .33041 Metetra
.664 .741 .907 r
.7316 .33041 .73247 .33157 .73878 .32948 .73792 .32831 Metetra
.664 .741 .907 r
.73792 .32831 .73878 .32948 .74512 .32739 .74425 .32622 Metetra
.664 .741 .907 r
.74425 .32622 .74512 .32739 .75146 .32529 .7506 .32412 Metetra
.664 .741 .907 r
.7506 .32412 .75146 .32529 .75782 .32319 .75697 .32202 Metetra
.664 .741 .907 r
.75697 .32202 .75782 .32319 .76419 .32108 .76334 .31991 Metetra
.664 .741 .907 r
.76334 .31991 .76419 .32108 .77058 .31897 .76973 .31779 Metetra
.664 .741 .907 r
.76973 .31779 .77058 .31897 .77698 .31686 .77614 .31568 Metetra
.664 .741 .907 r
.77614 .31568 .77698 .31686 .7834 .31474 .78256 .31355 Metetra
.664 .741 .907 r
.78256 .31355 .7834 .31474 .78983 .31261 .78899 .31142 Metetra
.664 .741 .907 r
.78899 .31142 .78983 .31261 .79628 .31048 .79544 .30929 Metetra
.664 .741 .907 r
.79544 .30929 .79628 .31048 .80307 .31215 .8019 .30715 Metetra
.603 .464 .664 r
.8019 .30715 .80307 .31215 .80921 .30621 .80838 .30501 Metetra
.664 .741 .907 r
.80838 .30501 .80921 .30621 .8157 .30406 .81487 .30287 Metetra
.664 .741 .907 r
.81487 .30287 .8157 .30406 .8222 .30191 .82138 .30071 Metetra
.664 .741 .907 r
.82138 .30071 .8222 .30191 .82872 .29976 .8279 .29856 Metetra
.664 .741 .907 r
.8279 .29856 .82872 .29976 .83525 .2976 .83443 .2964 Metetra
.664 .741 .907 r
.83443 .2964 .83525 .2976 .8418 .29544 .84098 .29423 Metetra
.664 .741 .907 r
.84098 .29423 .8418 .29544 .84836 .29327 .84755 .29206 Metetra
.664 .741 .907 r
.84755 .29206 .84836 .29327 .85494 .2911 .85413 .28988 Metetra
.664 .741 .907 r
.85413 .28988 .85494 .2911 .86153 .28892 .86072 .2877 Metetra
.664 .741 .907 r
.86072 .2877 .86153 .28892 .86813 .28673 .86733 .28551 Metetra
.664 .741 .907 r
.86733 .28551 .86813 .28673 .87476 .28455 .87396 .28332 Metetra
.664 .741 .907 r
.27722 .47934 .27828 .48033 .28364 .47856 .28258 .47757 Metetra
.664 .741 .907 r
.28258 .47757 .28364 .47856 .289 .47678 .28795 .47579 Metetra
.664 .741 .907 r
.28795 .47579 .289 .47678 .29438 .47501 .29333 .47401 Metetra
.664 .741 .907 r
.29333 .47401 .29438 .47501 .29977 .47322 .29872 .47223 Metetra
.664 .741 .907 r
.29872 .47223 .29977 .47322 .30517 .47144 .30412 .47044 Metetra
.946 .65 .444 r
.30412 .47044 .30517 .47144 .30605 .53918 .30663 .51306 Metetra
.697 .471 .576 r
.30663 .51306 .30605 .53918 .316 .46786 .31496 .46685 Metetra
.664 .741 .907 r
.31496 .46685 .316 .46786 .32143 .46606 .32039 .46506 Metetra
.637 .734 .918 r
.32039 .46506 .32143 .46606 .32688 .46426 .32582 .46362 Metetra
.686 .827 .951 r
.32582 .46362 .32688 .46426 .33233 .46245 .3313 .46145 Metetra
.664 .741 .907 r
.3313 .46145 .33233 .46245 .3378 .46065 .33676 .45964 Metetra
.664 .741 .907 r
.33676 .45964 .3378 .46065 .34328 .45883 .34224 .45782 Metetra
.664 .741 .907 r
.34224 .45782 .34328 .45883 .34877 .45702 .34773 .45601 Metetra
.664 .741 .907 r
.34773 .45601 .34877 .45702 .35427 .4552 .35324 .45418 Metetra
.664 .741 .907 r
.35324 .45418 .35427 .4552 .35978 .45338 .35875 .45236 Metetra
.664 .741 .907 r
.35875 .45236 .35978 .45338 .3653 .45155 .36428 .45053 Metetra
.664 .741 .907 r
.36428 .45053 .3653 .45155 .37083 .44972 .36981 .4487 Metetra
.664 .741 .907 r
.36981 .4487 .37083 .44972 .37638 .44789 .37536 .44686 Metetra
.664 .741 .907 r
.37536 .44686 .37638 .44789 .38194 .44605 .38092 .44502 Metetra
.664 .741 .907 r
.38092 .44502 .38194 .44605 .38751 .44421 .38649 .44318 Metetra
.664 .741 .907 r
.38649 .44318 .38751 .44421 .39309 .44236 .39207 .44133 Metetra
.664 .741 .907 r
.39207 .44133 .39309 .44236 .39868 .44051 .39767 .43948 Metetra
.664 .741 .907 r
.39767 .43948 .39868 .44051 .40253 .48622 .40328 .43762 Metetra
.512 .312 .546 r
.40328 .43762 .40253 .48622 .40953 .44739 .40823 .45432 Metetra
0 0 .224 r
.40823 .45432 .40953 .44739 .41553 .43494 .41452 .4339 Metetra
.664 .741 .907 r
.41452 .4339 .41553 .43494 .42117 .43307 .42016 .43203 Metetra
.664 .741 .907 r
.42016 .43203 .42117 .43307 .42682 .43121 .42582 .43016 Metetra
.956 .658 .427 r
.42582 .43016 .42682 .43121 .43248 .42933 .42969 .49085 Metetra
.407 .211 .5 r
.42969 .49085 .43248 .42933 .43816 .42746 .43716 .42641 Metetra
.664 .741 .907 r
.43716 .42641 .43816 .42746 .44384 .42557 .44285 .42452 Metetra
.664 .741 .907 r
.44285 .42452 .44384 .42557 .44954 .42369 .44855 .42264 Metetra
.664 .741 .907 r
.44855 .42264 .44954 .42369 .45525 .4218 .45426 .42075 Metetra
.664 .741 .907 r
.45426 .42075 .45525 .4218 .46097 .41991 .45999 .41885 Metetra
.664 .741 .907 r
.45999 .41885 .46097 .41991 .46671 .41801 .46572 .41695 Metetra
.664 .741 .907 r
.46572 .41695 .46671 .41801 .47246 .41611 .47147 .41505 Metetra
.664 .741 .907 r
.47147 .41505 .47246 .41611 .47821 .41421 .47724 .41314 Metetra
.664 .741 .907 r
.47724 .41314 .47821 .41421 .48399 .4123 .48301 .41123 Metetra
.664 .741 .907 r
.48301 .41123 .48399 .4123 .48976 .41103 .48879 .40932 Metetra
.652 .638 .823 r
.48879 .40932 .48976 .41103 .49557 .40847 .49459 .4074 Metetra
.664 .741 .907 r
.49459 .4074 .49557 .40847 .50137 .40655 .5004 .40547 Metetra
.664 .741 .907 r
.5004 .40547 .50137 .40655 .50719 .40462 .50623 .40355 Metetra
.664 .741 .907 r
.50623 .40355 .50719 .40462 .51303 .40269 .51206 .40162 Metetra
.664 .741 .907 r
.51206 .40162 .51303 .40269 .51887 .40076 .51791 .39968 Metetra
.664 .741 .907 r
.51791 .39968 .51887 .40076 .52473 .39882 .52377 .39774 Metetra
.664 .741 .907 r
.52377 .39774 .52473 .39882 .5306 .39688 .52964 .3958 Metetra
.664 .741 .907 r
.52964 .3958 .5306 .39688 .53648 .39494 .53553 .39385 Metetra
.664 .741 .907 r
.53553 .39385 .53648 .39494 .54238 .39299 .54142 .3919 Metetra
.664 .741 .907 r
.54142 .3919 .54238 .39299 .54828 .39103 .54733 .38994 Metetra
.664 .741 .907 r
.54733 .38994 .54828 .39103 .55421 .38907 .55326 .38798 Metetra
.664 .741 .907 r
.55326 .38798 .55421 .38907 .56014 .38711 .55919 .38602 Metetra
.664 .741 .907 r
.55919 .38602 .56014 .38711 .56608 .38515 .56514 .38405 Metetra
.664 .741 .907 r
.56514 .38405 .56608 .38515 .57204 .38317 .5711 .38207 Metetra
.664 .741 .907 r
.5711 .38207 .57204 .38317 .57802 .3812 .57708 .3801 Metetra
.664 .741 .907 r
.57708 .3801 .57802 .3812 .584 .37922 .58306 .37811 Metetra
.664 .741 .907 r
.58306 .37811 .584 .37922 .59 .37724 .58906 .37613 Metetra
.664 .741 .907 r
.58906 .37613 .59 .37724 .59601 .37525 .59508 .37414 Metetra
.664 .741 .907 r
.59508 .37414 .59601 .37525 .60237 .38721 .6011 .37214 Metetra
.57 .379 .583 r
.6011 .37214 .60237 .38721 .60807 .37126 .60714 .37015 Metetra
.664 .741 .907 r
.60714 .37015 .60807 .37126 .61412 .36926 .61319 .36814 Metetra
.664 .741 .907 r
.61319 .36814 .61412 .36926 .62018 .36726 .61926 .36613 Metetra
.664 .741 .907 r
.61926 .36613 .62018 .36726 .62625 .36525 .62534 .36412 Metetra
.664 .741 .907 r
.62534 .36412 .62625 .36525 .63234 .36323 .63143 .36211 Metetra
.664 .741 .907 r
.63143 .36211 .63234 .36323 .63845 .36121 .63753 .36009 Metetra
.664 .741 .907 r
.63753 .36009 .63845 .36121 .64456 .35919 .64365 .35806 Metetra
.924 .541 .149 r
.64365 .35806 .64456 .35919 .65069 .35716 .65081 .38203 Metetra
.41 .208 .493 r
.65081 .38203 .65069 .35716 .65683 .35513 .65593 .354 Metetra
.664 .741 .907 r
.65593 .354 .65683 .35513 .66299 .3531 .66209 .35196 Metetra
.664 .741 .907 r
.66209 .35196 .66299 .3531 .66916 .35106 .66826 .34992 Metetra
.664 .741 .907 r
.66826 .34992 .66916 .35106 .67534 .34901 .67445 .34787 Metetra
.664 .741 .907 r
.67445 .34787 .67534 .34901 .68154 .34696 .68064 .34582 Metetra
.664 .741 .907 r
.68064 .34582 .68154 .34696 .68775 .34491 .68686 .34376 Metetra
.664 .741 .907 r
.68686 .34376 .68775 .34491 .69397 .34285 .69308 .3417 Metetra
.664 .741 .907 r
.69308 .3417 .69397 .34285 .70021 .34079 .69932 .33964 Metetra
.664 .741 .907 r
.69932 .33964 .70021 .34079 .70646 .33872 .70558 .33757 Metetra
.664 .741 .907 r
.70558 .33757 .70646 .33872 .71272 .33665 .71184 .33549 Metetra
.664 .741 .907 r
.71184 .33549 .71272 .33665 .719 .33457 .71813 .33341 Metetra
.664 .741 .907 r
.71813 .33341 .719 .33457 .72529 .33249 .72442 .33133 Metetra
.664 .741 .907 r
.72442 .33133 .72529 .33249 .7316 .33041 .73073 .32924 Metetra
.664 .741 .907 r
.73073 .32924 .7316 .33041 .73792 .32831 .73705 .32715 Metetra
.664 .741 .907 r
.73705 .32715 .73792 .32831 .74425 .32622 .74339 .32505 Metetra
.664 .741 .907 r
.74339 .32505 .74425 .32622 .7506 .32412 .74974 .32295 Metetra
.664 .741 .907 r
.74974 .32295 .7506 .32412 .75697 .32202 .75611 .32084 Metetra
.664 .741 .907 r
.75611 .32084 .75697 .32202 .76334 .31991 .76249 .31873 Metetra
.664 .741 .907 r
.76249 .31873 .76334 .31991 .76973 .31779 .76888 .31661 Metetra
.664 .741 .907 r
.76888 .31661 .76973 .31779 .77614 .31568 .77529 .31449 Metetra
.664 .741 .907 r
.77529 .31449 .77614 .31568 .78256 .31355 .78171 .31237 Metetra
.664 .741 .907 r
.78171 .31237 .78256 .31355 .78899 .31142 .78815 .31024 Metetra
.664 .741 .907 r
.78815 .31024 .78899 .31142 .79544 .30929 .7946 .3081 Metetra
.664 .741 .907 r
.7946 .3081 .79544 .30929 .8019 .30715 .80107 .30596 Metetra
.664 .741 .907 r
.80107 .30596 .8019 .30715 .80838 .30501 .80755 .30382 Metetra
.664 .741 .907 r
.80755 .30382 .80838 .30501 .81487 .30287 .81404 .30167 Metetra
.664 .741 .907 r
.81404 .30167 .81487 .30287 .82138 .30071 .82055 .29951 Metetra
.664 .741 .907 r
.82055 .29951 .82138 .30071 .8279 .29856 .82707 .29735 Metetra
.664 .741 .907 r
.82707 .29735 .8279 .29856 .83443 .2964 .83361 .29519 Metetra
.664 .741 .907 r
.83361 .29519 .83443 .2964 .84098 .29423 .84017 .29302 Metetra
.664 .741 .907 r
.84017 .29302 .84098 .29423 .84755 .29206 .84673 .29084 Metetra
.664 .741 .907 r
.84673 .29084 .84755 .29206 .85413 .28988 .85332 .28867 Metetra
.664 .741 .907 r
.85332 .28867 .85413 .28988 .86072 .2877 .85992 .28648 Metetra
.664 .741 .907 r
.85992 .28648 .86072 .2877 .86733 .28551 .86653 .28429 Metetra
.664 .741 .907 r
.86653 .28429 .86733 .28551 .87396 .28332 .87316 .2821 Metetra
.664 .741 .907 r
.27616 .47835 .27722 .47934 .28258 .47757 .28152 .47658 Metetra
.664 .741 .907 r
.28152 .47658 .28258 .47757 .28795 .47579 .28689 .4748 Metetra
.664 .741 .907 r
.28689 .4748 .28795 .47579 .29333 .47401 .29228 .47302 Metetra
.664 .741 .907 r
.29228 .47302 .29333 .47401 .29872 .47223 .29767 .47123 Metetra
.664 .741 .907 r
.29767 .47123 .29872 .47223 .30412 .47044 .30307 .46944 Metetra
.664 .741 .907 r
.30307 .46944 .30412 .47044 .30663 .51306 .30849 .46765 Metetra
.558 .349 .554 r
.30849 .46765 .30663 .51306 .31496 .46685 .31391 .46585 Metetra
.664 .741 .907 r
.31391 .46585 .31496 .46685 .32039 .46506 .31935 .46405 Metetra
.664 .741 .907 r
.31935 .46405 .32039 .46506 .32582 .46362 .3248 .46225 Metetra
.659 .676 .855 r
.3248 .46225 .32582 .46362 .3313 .46145 .33026 .46044 Metetra
.664 .741 .907 r
.33026 .46044 .3313 .46145 .33676 .45964 .33573 .45863 Metetra
.664 .741 .907 r
.33573 .45863 .33676 .45964 .34224 .45782 .34121 .45681 Metetra
.664 .741 .907 r
.34121 .45681 .34224 .45782 .34773 .45601 .3467 .45499 Metetra
.664 .741 .907 r
.3467 .45499 .34773 .45601 .35324 .45418 .35221 .45317 Metetra
.664 .741 .907 r
.35221 .45317 .35324 .45418 .35875 .45236 .35772 .45134 Metetra
.664 .741 .907 r
.35772 .45134 .35875 .45236 .36428 .45053 .36325 .44951 Metetra
.664 .741 .907 r
.36325 .44951 .36428 .45053 .36981 .4487 .36879 .44767 Metetra
.664 .741 .907 r
.36879 .44767 .36981 .4487 .37536 .44686 .37434 .44584 Metetra
.664 .741 .907 r
.37434 .44584 .37536 .44686 .38092 .44502 .3799 .44399 Metetra
.664 .741 .907 r
.3799 .44399 .38092 .44502 .38649 .44318 .38547 .44215 Metetra
.664 .741 .907 r
.38547 .44215 .38649 .44318 .39207 .44133 .39106 .4403 Metetra
.664 .741 .907 r
.39106 .4403 .39207 .44133 .39767 .43948 .39666 .43844 Metetra
.664 .741 .907 r
.39666 .43844 .39767 .43948 .40328 .43762 .40226 .43659 Metetra
.664 .741 .907 r
.40226 .43659 .40328 .43762 .40823 .45432 .40788 .43472 Metetra
.566 .368 .572 r
.40788 .43472 .40823 .45432 .41452 .4339 .41352 .43286 Metetra
.664 .741 .907 r
.41352 .43286 .41452 .4339 .42016 .43203 .41916 .43099 Metetra
.955 .678 .473 r
.41916 .43099 .42016 .43203 .42582 .43016 .41926 .60962 Metetra
.555 .336 .537 r
.41926 .60962 .42582 .43016 .42969 .49085 .42496 .61739 Metetra
.321 .147 .483 r
.42496 .61739 .42969 .49085 .43716 .42641 .43606 .42898 Metetra
.159 0 .138 r
.43606 .42898 .43716 .42641 .44285 .42452 .44185 .42347 Metetra
.664 .741 .907 r
.44185 .42347 .44285 .42452 .44855 .42264 .44756 .42158 Metetra
.664 .741 .907 r
.44756 .42158 .44855 .42264 .45426 .42075 .45327 .41969 Metetra
.664 .741 .907 r
.45327 .41969 .45426 .42075 .45999 .41885 .459 .41779 Metetra
.664 .741 .907 r
.459 .41779 .45999 .41885 .46572 .41695 .46474 .41589 Metetra
.664 .741 .907 r
.46474 .41589 .46572 .41695 .47147 .41505 .47049 .41399 Metetra
.664 .741 .907 r
.47049 .41399 .47147 .41505 .47724 .41314 .47625 .41208 Metetra
.664 .741 .907 r
.47625 .41208 .47724 .41314 .48301 .41123 .48203 .41016 Metetra
.664 .741 .907 r
.48203 .41016 .48301 .41123 .48879 .40932 .48782 .40825 Metetra
.664 .741 .907 r
.48782 .40825 .48879 .40932 .49459 .4074 .49362 .40633 Metetra
.664 .741 .907 r
.49362 .40633 .49459 .4074 .5004 .40547 .49943 .4044 Metetra
.664 .741 .907 r
.49943 .4044 .5004 .40547 .50623 .40355 .50526 .40247 Metetra
.664 .741 .907 r
.50526 .40247 .50623 .40355 .51206 .40162 .51109 .40054 Metetra
.664 .741 .907 r
.51109 .40054 .51206 .40162 .51791 .39968 .51694 .3986 Metetra
.664 .741 .907 r
.51694 .3986 .51791 .39968 .52377 .39774 .52281 .39666 Metetra
.664 .741 .907 r
.52281 .39666 .52377 .39774 .52964 .3958 .52868 .39471 Metetra
.664 .741 .907 r
.52868 .39471 .52964 .3958 .53553 .39385 .53457 .39276 Metetra
.664 .741 .907 r
.53457 .39276 .53553 .39385 .54142 .3919 .54047 .39081 Metetra
.664 .741 .907 r
.54047 .39081 .54142 .3919 .54733 .38994 .54638 .38885 Metetra
.664 .741 .907 r
.54638 .38885 .54733 .38994 .55326 .38798 .55231 .38689 Metetra
.664 .741 .907 r
.55231 .38689 .55326 .38798 .55919 .38602 .55825 .38492 Metetra
.664 .741 .907 r
.55825 .38492 .55919 .38602 .56514 .38405 .5642 .38295 Metetra
.664 .741 .907 r
.5642 .38295 .56514 .38405 .5711 .38207 .57016 .38097 Metetra
.664 .741 .907 r
.57016 .38097 .5711 .38207 .57708 .3801 .57614 .37899 Metetra
.664 .741 .907 r
.57614 .37899 .57708 .3801 .58306 .37811 .58213 .37701 Metetra
.664 .741 .907 r
.58213 .37701 .58306 .37811 .58906 .37613 .58813 .37502 Metetra
.664 .741 .907 r
.58813 .37502 .58906 .37613 .59508 .37414 .59415 .37303 Metetra
.664 .741 .907 r
.59415 .37303 .59508 .37414 .6011 .37214 .60018 .37103 Metetra
.664 .741 .907 r
.60018 .37103 .6011 .37214 .60714 .37015 .60622 .36903 Metetra
.664 .741 .907 r
.60622 .36903 .60714 .37015 .61319 .36814 .61227 .36702 Metetra
.664 .741 .907 r
.61227 .36702 .61319 .36814 .61926 .36613 .61834 .36501 Metetra
.664 .741 .907 r
.61834 .36501 .61926 .36613 .62534 .36412 .62442 .363 Metetra
.664 .741 .907 r
.62442 .363 .62534 .36412 .63143 .36211 .63052 .36098 Metetra
.664 .741 .907 r
.63052 .36098 .63143 .36211 .63753 .36009 .63662 .35896 Metetra
.664 .741 .907 r
.63662 .35896 .63753 .36009 .64365 .35806 .64274 .35693 Metetra
.954 .605 .26 r
.64274 .35693 .64365 .35806 .65081 .38203 .65045 .39529 Metetra
.497 .258 .483 r
.65045 .39529 .65081 .38203 .65593 .354 .65653 .38954 Metetra
.417 .219 .502 r
.65653 .38954 .65593 .354 .66209 .35196 .66119 .35082 Metetra
.664 .741 .907 r
.66119 .35082 .66209 .35196 .66826 .34992 .66736 .34878 Metetra
.664 .741 .907 r
.66736 .34878 .66826 .34992 .67445 .34787 .67355 .34673 Metetra
.664 .741 .907 r
.67355 .34673 .67445 .34787 .68064 .34582 .67975 .34467 Metetra
.664 .741 .907 r
.67975 .34467 .68064 .34582 .68686 .34376 .68597 .34261 Metetra
.664 .741 .907 r
.68597 .34261 .68686 .34376 .69308 .3417 .6922 .34055 Metetra
.664 .741 .907 r
.6922 .34055 .69308 .3417 .69932 .33964 .69844 .33848 Metetra
.664 .741 .907 r
.69844 .33848 .69932 .33964 .70558 .33757 .7047 .33641 Metetra
.664 .741 .907 r
.7047 .33641 .70558 .33757 .71184 .33549 .71097 .33433 Metetra
.664 .741 .907 r
.71097 .33433 .71184 .33549 .71813 .33341 .71725 .33225 Metetra
.664 .741 .907 r
.71725 .33225 .71813 .33341 .72442 .33133 .72355 .33016 Metetra
.664 .741 .907 r
.72355 .33016 .72442 .33133 .73073 .32924 .72986 .32807 Metetra
.664 .741 .907 r
.72986 .32807 .73073 .32924 .73705 .32715 .73619 .32598 Metetra
.664 .741 .907 r
.73619 .32598 .73705 .32715 .74339 .32505 .74253 .32388 Metetra
.664 .741 .907 r
.74253 .32388 .74339 .32505 .74974 .32295 .74888 .32177 Metetra
.664 .741 .907 r
.74888 .32177 .74974 .32295 .75611 .32084 .75525 .31966 Metetra
.664 .741 .907 r
.75525 .31966 .75611 .32084 .76249 .31873 .76163 .31755 Metetra
.664 .741 .907 r
.76163 .31755 .76249 .31873 .76888 .31661 .76803 .31543 Metetra
.664 .741 .907 r
.76803 .31543 .76888 .31661 .77529 .31449 .77444 .31331 Metetra
.664 .741 .907 r
.77444 .31331 .77529 .31449 .78171 .31237 .78087 .31118 Metetra
.664 .741 .907 r
.78087 .31118 .78171 .31237 .78815 .31024 .78731 .30904 Metetra
.664 .741 .907 r
.78731 .30904 .78815 .31024 .7946 .3081 .79376 .30691 Metetra
.664 .741 .907 r
.79376 .30691 .7946 .3081 .80107 .30596 .80023 .30476 Metetra
.664 .741 .907 r
.80023 .30476 .80107 .30596 .80755 .30382 .80671 .30262 Metetra
.664 .741 .907 r
.80671 .30262 .80755 .30382 .81404 .30167 .81321 .30046 Metetra
.664 .741 .907 r
.81321 .30046 .81404 .30167 .82055 .29951 .81972 .29831 Metetra
.664 .741 .907 r
.81972 .29831 .82055 .29951 .82707 .29735 .82625 .29615 Metetra
.664 .741 .907 r
.82625 .29615 .82707 .29735 .83361 .29519 .83279 .29398 Metetra
.664 .741 .907 r
.83279 .29398 .83361 .29519 .84017 .29302 .83935 .29181 Metetra
.664 .741 .907 r
.83935 .29181 .84017 .29302 .84673 .29084 .84592 .28963 Metetra
.664 .741 .907 r
.84592 .28963 .84673 .29084 .85332 .28867 .85251 .28745 Metetra
.664 .741 .907 r
.85251 .28745 .85332 .28867 .85992 .28648 .85911 .28526 Metetra
.664 .741 .907 r
.85911 .28526 .85992 .28648 .86653 .28429 .86572 .28307 Metetra
.664 .741 .907 r
.86572 .28307 .86653 .28429 .87316 .2821 .87236 .28087 Metetra
.664 .741 .907 r
.27511 .47736 .27616 .47835 .28152 .47658 .28047 .47559 Metetra
.664 .741 .907 r
.28047 .47559 .28152 .47658 .28689 .4748 .28584 .47381 Metetra
.664 .741 .907 r
.28584 .47381 .28689 .4748 .29228 .47302 .29122 .47202 Metetra
.664 .741 .907 r
.29122 .47202 .29228 .47302 .29767 .47123 .29662 .47023 Metetra
.664 .741 .907 r
.29662 .47023 .29767 .47123 .30307 .46944 .30202 .46844 Metetra
.664 .741 .907 r
.30202 .46844 .30307 .46944 .30849 .46765 .30744 .46665 Metetra
.664 .741 .907 r
.30744 .46665 .30849 .46765 .31391 .46585 .31287 .46485 Metetra
.664 .741 .907 r
.31287 .46485 .31391 .46585 .31935 .46405 .31831 .46304 Metetra
.664 .741 .907 r
.31831 .46304 .31935 .46405 .3248 .46225 .32376 .46124 Metetra
.664 .741 .907 r
.32376 .46124 .3248 .46225 .33026 .46044 .32922 .45943 Metetra
.664 .741 .907 r
.32922 .45943 .33026 .46044 .33573 .45863 .33469 .45761 Metetra
.664 .741 .907 r
.33469 .45761 .33573 .45863 .34121 .45681 .34017 .4558 Metetra
.664 .741 .907 r
.34017 .4558 .34121 .45681 .3467 .45499 .34567 .45397 Metetra
.664 .741 .907 r
.34567 .45397 .3467 .45499 .35221 .45317 .35118 .45215 Metetra
.664 .741 .907 r
.35118 .45215 .35221 .45317 .35772 .45134 .35669 .45032 Metetra
.664 .741 .907 r
.35669 .45032 .35772 .45134 .36325 .44951 .36222 .44849 Metetra
.664 .741 .907 r
.36222 .44849 .36325 .44951 .36879 .44767 .36776 .44665 Metetra
.664 .741 .907 r
.36776 .44665 .36879 .44767 .37434 .44584 .37332 .44481 Metetra
.664 .741 .907 r
.37332 .44481 .37434 .44584 .3799 .44399 .37888 .44296 Metetra
.664 .741 .907 r
.37888 .44296 .3799 .44399 .38547 .44215 .38446 .44112 Metetra
.664 .741 .907 r
.38446 .44112 .38547 .44215 .39106 .4403 .39004 .43926 Metetra
.664 .741 .907 r
.39004 .43926 .39106 .4403 .39666 .43844 .39564 .43741 Metetra
.664 .741 .907 r
.39564 .43741 .39666 .43844 .40226 .43659 .40125 .43555 Metetra
.664 .741 .907 r
.40125 .43555 .40226 .43659 .40788 .43472 .40688 .43368 Metetra
.664 .741 .907 r
.40688 .43368 .40788 .43472 .41352 .43286 .41251 .43182 Metetra
.664 .741 .907 r
.41251 .43182 .41352 .43286 .41916 .43099 .41816 .42994 Metetra
.954 .679 .475 r
.41816 .42994 .41916 .43099 .41926 .60962 .4177 .62457 Metetra
.887 .739 .232 r
.4177 .62457 .41926 .60962 .42496 .61739 .42666 .52217 Metetra
.648 .418 .556 r
.42666 .52217 .42496 .61739 .43606 .42898 .43511 .42615 Metetra
.678 .567 .723 r
.43511 .42615 .43606 .42898 .44185 .42347 .44086 .42242 Metetra
.664 .741 .907 r
.44086 .42242 .44185 .42347 .44756 .42158 .44656 .42053 Metetra
.664 .741 .907 r
.44656 .42053 .44756 .42158 .45327 .41969 .45228 .41863 Metetra
.664 .741 .907 r
.45228 .41863 .45327 .41969 .459 .41779 .45801 .41673 Metetra
.664 .741 .907 r
.45801 .41673 .459 .41779 .46474 .41589 .46375 .41483 Metetra
.664 .741 .907 r
.46375 .41483 .46474 .41589 .47049 .41399 .46951 .41292 Metetra
.664 .741 .907 r
.46951 .41292 .47049 .41399 .47625 .41208 .47527 .41101 Metetra
.664 .741 .907 r
.47527 .41101 .47625 .41208 .48203 .41016 .48105 .4091 Metetra
.664 .741 .907 r
.48105 .4091 .48203 .41016 .48782 .40825 .48684 .40718 Metetra
.664 .741 .907 r
.48684 .40718 .48782 .40825 .49362 .40633 .49264 .40525 Metetra
.664 .741 .907 r
.49264 .40525 .49362 .40633 .49943 .4044 .49846 .40332 Metetra
.664 .741 .907 r
.49846 .40332 .49943 .4044 .50526 .40247 .50429 .40139 Metetra
.664 .741 .907 r
.50429 .40139 .50526 .40247 .51109 .40054 .51013 .39946 Metetra
.664 .741 .907 r
.51013 .39946 .51109 .40054 .51694 .3986 .51598 .39752 Metetra
.664 .741 .907 r
.51598 .39752 .51694 .3986 .52281 .39666 .52184 .39557 Metetra
.664 .741 .907 r
.52184 .39557 .52281 .39666 .52868 .39471 .52772 .39362 Metetra
.664 .741 .907 r
.52772 .39362 .52868 .39471 .53457 .39276 .53361 .39167 Metetra
.664 .741 .907 r
.53361 .39167 .53457 .39276 .54047 .39081 .53952 .38971 Metetra
.664 .741 .907 r
.53952 .38971 .54047 .39081 .54638 .38885 .54543 .38775 Metetra
.664 .741 .907 r
.54543 .38775 .54638 .38885 .55231 .38689 .55136 .38579 Metetra
.664 .741 .907 r
.55136 .38579 .55231 .38689 .55825 .38492 .5573 .38382 Metetra
.664 .741 .907 r
.5573 .38382 .55825 .38492 .5642 .38295 .56325 .38185 Metetra
.664 .741 .907 r
.56325 .38185 .5642 .38295 .57016 .38097 .56922 .37987 Metetra
.664 .741 .907 r
.56922 .37987 .57016 .38097 .57614 .37899 .5752 .37789 Metetra
.664 .741 .907 r
.5752 .37789 .57614 .37899 .58213 .37701 .58119 .3759 Metetra
.664 .741 .907 r
.58119 .3759 .58213 .37701 .58813 .37502 .5872 .37391 Metetra
.664 .741 .907 r
.5872 .37391 .58813 .37502 .59415 .37303 .59321 .37191 Metetra
.664 .741 .907 r
.59321 .37191 .59415 .37303 .60018 .37103 .59925 .36991 Metetra
.664 .741 .907 r
.59925 .36991 .60018 .37103 .60622 .36903 .60529 .36791 Metetra
.664 .741 .907 r
.60529 .36791 .60622 .36903 .61227 .36702 .61135 .3659 Metetra
.664 .741 .907 r
.61135 .3659 .61227 .36702 .61834 .36501 .61742 .36389 Metetra
.664 .741 .907 r
.61742 .36389 .61834 .36501 .62442 .363 .6235 .36187 Metetra
.664 .741 .907 r
.6235 .36187 .62442 .363 .63052 .36098 .6296 .35985 Metetra
.664 .741 .907 r
.6296 .35985 .63052 .36098 .63662 .35896 .63571 .35783 Metetra
.885 .476 .049 r
.63571 .35783 .63662 .35896 .64274 .35693 .64257 .37578 Metetra
.402 .195 .481 r
.64257 .37578 .64274 .35693 .65045 .39529 .64797 .35376 Metetra
.549 .344 .555 r
.64797 .35376 .65045 .39529 .65653 .38954 .65427 .35534 Metetra
.57 .362 .559 r
.65427 .35534 .65653 .38954 .66119 .35082 .66028 .34968 Metetra
.664 .741 .907 r
.66028 .34968 .66119 .35082 .66736 .34878 .66646 .34763 Metetra
.664 .741 .907 r
.66646 .34763 .66736 .34878 .67355 .34673 .67265 .34558 Metetra
.664 .741 .907 r
.67265 .34558 .67355 .34673 .67975 .34467 .67886 .34352 Metetra
.664 .741 .907 r
.67886 .34352 .67975 .34467 .68597 .34261 .68508 .34146 Metetra
.664 .741 .907 r
.68508 .34146 .68597 .34261 .6922 .34055 .69131 .3394 Metetra
.664 .741 .907 r
.69131 .3394 .6922 .34055 .69844 .33848 .69755 .33733 Metetra
.664 .741 .907 r
.69755 .33733 .69844 .33848 .7047 .33641 .70381 .33525 Metetra
.664 .741 .907 r
.70381 .33525 .7047 .33641 .71097 .33433 .71009 .33317 Metetra
.664 .741 .907 r
.71009 .33317 .71097 .33433 .71725 .33225 .71637 .33109 Metetra
.664 .741 .907 r
.71637 .33109 .71725 .33225 .72355 .33016 .72268 .329 Metetra
.664 .741 .907 r
.72268 .329 .72355 .33016 .72986 .32807 .72899 .3269 Metetra
.664 .741 .907 r
.72899 .3269 .72986 .32807 .73619 .32598 .73532 .32481 Metetra
.664 .741 .907 r
.73532 .32481 .73619 .32598 .74253 .32388 .74166 .3227 Metetra
.664 .741 .907 r
.74166 .3227 .74253 .32388 .74888 .32177 .74802 .3206 Metetra
.664 .741 .907 r
.74802 .3206 .74888 .32177 .75525 .31966 .75439 .31848 Metetra
.664 .741 .907 r
.75439 .31848 .75525 .31966 .76163 .31755 .76078 .31637 Metetra
.664 .741 .907 r
.76078 .31637 .76163 .31755 .76803 .31543 .76718 .31425 Metetra
.664 .741 .907 r
.76718 .31425 .76803 .31543 .77444 .31331 .77359 .31212 Metetra
.664 .741 .907 r
.77359 .31212 .77444 .31331 .78087 .31118 .78002 .30999 Metetra
.664 .741 .907 r
.78002 .30999 .78087 .31118 .78731 .30904 .78646 .30785 Metetra
.664 .741 .907 r
.78646 .30785 .78731 .30904 .79376 .30691 .79292 .30571 Metetra
.664 .741 .907 r
.79292 .30571 .79376 .30691 .80023 .30476 .79939 .30357 Metetra
.664 .741 .907 r
.79939 .30357 .80023 .30476 .80671 .30262 .80588 .30142 Metetra
.664 .741 .907 r
.80588 .30142 .80671 .30262 .81321 .30046 .81238 .29926 Metetra
.664 .741 .907 r
.81238 .29926 .81321 .30046 .81972 .29831 .81889 .2971 Metetra
.664 .741 .907 r
.81889 .2971 .81972 .29831 .82625 .29615 .82543 .29494 Metetra
.664 .741 .907 r
.82543 .29494 .82625 .29615 .83279 .29398 .83197 .29277 Metetra
.664 .741 .907 r
.83197 .29277 .83279 .29398 .83935 .29181 .83853 .29059 Metetra
.664 .741 .907 r
.83853 .29059 .83935 .29181 .84592 .28963 .8451 .28841 Metetra
.664 .741 .907 r
.8451 .28841 .84592 .28963 .85251 .28745 .85169 .28623 Metetra
.664 .741 .907 r
.85169 .28623 .85251 .28745 .85911 .28526 .8583 .28404 Metetra
.664 .741 .907 r
.8583 .28404 .85911 .28526 .86572 .28307 .86492 .28185 Metetra
.664 .741 .907 r
.86492 .28185 .86572 .28307 .87236 .28087 .87155 .27965 Metetra
.664 .741 .907 r
.27404 .47637 .27511 .47736 .28047 .47559 .27941 .47459 Metetra
.664 .741 .907 r
.27941 .47459 .28047 .47559 .28584 .47381 .28478 .47281 Metetra
.664 .741 .907 r
.28478 .47281 .28584 .47381 .29122 .47202 .29017 .47103 Metetra
.664 .741 .907 r
.29017 .47103 .29122 .47202 .29662 .47023 .29556 .46923 Metetra
.664 .741 .907 r
.29556 .46923 .29662 .47023 .30202 .46844 .30097 .46744 Metetra
.664 .741 .907 r
.30097 .46744 .30202 .46844 .30744 .46665 .30639 .46564 Metetra
.664 .741 .907 r
.30639 .46564 .30744 .46665 .31287 .46485 .31182 .46384 Metetra
.947 .637 .416 r
.31182 .46384 .31287 .46485 .31831 .46304 .31502 .49742 Metetra
.388 .186 .481 r
.31502 .49742 .31831 .46304 .32376 .46124 .32271 .46023 Metetra
.664 .741 .907 r
.32271 .46023 .32376 .46124 .32922 .45943 .32818 .45842 Metetra
.664 .741 .907 r
.32818 .45842 .32922 .45943 .33469 .45761 .33365 .4566 Metetra
.664 .741 .907 r
.33365 .4566 .33469 .45761 .34017 .4558 .33914 .45478 Metetra
.664 .741 .907 r
.33914 .45478 .34017 .4558 .34567 .45397 .34463 .45296 Metetra
.664 .741 .907 r
.34463 .45296 .34567 .45397 .35118 .45215 .35014 .45113 Metetra
.664 .741 .907 r
.35014 .45113 .35118 .45215 .35669 .45032 .35566 .4493 Metetra
.664 .741 .907 r
.35566 .4493 .35669 .45032 .36222 .44849 .3612 .44746 Metetra
.664 .741 .907 r
.3612 .44746 .36222 .44849 .36776 .44665 .36674 .44562 Metetra
.664 .741 .907 r
.36674 .44562 .36776 .44665 .37332 .44481 .37229 .44378 Metetra
.664 .741 .907 r
.37229 .44378 .37332 .44481 .37888 .44296 .37786 .44193 Metetra
.664 .741 .907 r
.37786 .44193 .37888 .44296 .38446 .44112 .38344 .44008 Metetra
.664 .741 .907 r
.38344 .44008 .38446 .44112 .39004 .43926 .38903 .43823 Metetra
.664 .741 .907 r
.38903 .43823 .39004 .43926 .39564 .43741 .39463 .43637 Metetra
.664 .741 .907 r
.39463 .43637 .39564 .43741 .40125 .43555 .40024 .43451 Metetra
.664 .741 .907 r
.40024 .43451 .40125 .43555 .40688 .43368 .40586 .43264 Metetra
.664 .741 .907 r
.40586 .43264 .40688 .43368 .41251 .43182 .4115 .43077 Metetra
.664 .741 .907 r
.4115 .43077 .41251 .43182 .41816 .42994 .41715 .4289 Metetra
.955 .676 .468 r
.41715 .4289 .41816 .42994 .4177 .62457 .41826 .57193 Metetra
.703 .467 .563 r
.41826 .57193 .4177 .62457 .42666 .52217 .42705 .47338 Metetra
.648 .421 .561 r
.42705 .47338 .42666 .52217 .43511 .42615 .43417 .42325 Metetra
.626 .534 .73 r
.43417 .42325 .43511 .42615 .44086 .42242 .43986 .42136 Metetra
.664 .741 .907 r
.43986 .42136 .44086 .42242 .44656 .42053 .44557 .41947 Metetra
.664 .741 .907 r
.44557 .41947 .44656 .42053 .45228 .41863 .45129 .41757 Metetra
.664 .741 .907 r
.45129 .41757 .45228 .41863 .45801 .41673 .45702 .41567 Metetra
.664 .741 .907 r
.45702 .41567 .45801 .41673 .46375 .41483 .46276 .41377 Metetra
.664 .741 .907 r
.46276 .41377 .46375 .41483 .46951 .41292 .46852 .41186 Metetra
.664 .741 .907 r
.46852 .41186 .46951 .41292 .47527 .41101 .47429 .40994 Metetra
.664 .741 .907 r
.47429 .40994 .47527 .41101 .48105 .4091 .48007 .40803 Metetra
.664 .741 .907 r
.48007 .40803 .48105 .4091 .48684 .40718 .48586 .4061 Metetra
.664 .741 .907 r
.48586 .4061 .48684 .40718 .49264 .40525 .49167 .40418 Metetra
.664 .741 .907 r
.49167 .40418 .49264 .40525 .49846 .40332 .49749 .40225 Metetra
.664 .741 .907 r
.49749 .40225 .49846 .40332 .50429 .40139 .50332 .40031 Metetra
.664 .741 .907 r
.50332 .40031 .50429 .40139 .51013 .39946 .50916 .39838 Metetra
.664 .741 .907 r
.50916 .39838 .51013 .39946 .51598 .39752 .51501 .39643 Metetra
.664 .741 .907 r
.51501 .39643 .51598 .39752 .52184 .39557 .52088 .39449 Metetra
.664 .741 .907 r
.52088 .39449 .52184 .39557 .52772 .39362 .52676 .39254 Metetra
.664 .741 .907 r
.52676 .39254 .52772 .39362 .53361 .39167 .53265 .39058 Metetra
.664 .741 .907 r
.53265 .39058 .53361 .39167 .53952 .38971 .53856 .38862 Metetra
.664 .741 .907 r
.53856 .38862 .53952 .38971 .54543 .38775 .54448 .38666 Metetra
.664 .741 .907 r
.54448 .38666 .54543 .38775 .55136 .38579 .55041 .38469 Metetra
.664 .741 .907 r
.55041 .38469 .55136 .38579 .5573 .38382 .55635 .38272 Metetra
.664 .741 .907 r
.55635 .38272 .5573 .38382 .56325 .38185 .56231 .38074 Metetra
.664 .741 .907 r
.56231 .38074 .56325 .38185 .56922 .37987 .56828 .37876 Metetra
.664 .741 .907 r
.56828 .37876 .56922 .37987 .5752 .37789 .57426 .37678 Metetra
.664 .741 .907 r
.57426 .37678 .5752 .37789 .58119 .3759 .58025 .37479 Metetra
.664 .741 .907 r
.58025 .37479 .58119 .3759 .5872 .37391 .58626 .3728 Metetra
.664 .741 .907 r
.58626 .3728 .5872 .37391 .59321 .37191 .59228 .3708 Metetra
.664 .741 .907 r
.59228 .3708 .59321 .37191 .59925 .36991 .59832 .3688 Metetra
.664 .741 .907 r
.59832 .3688 .59925 .36991 .60529 .36791 .60436 .36679 Metetra
.664 .741 .907 r
.60436 .36679 .60529 .36791 .61135 .3659 .61042 .36478 Metetra
.664 .741 .907 r
.61042 .36478 .61135 .3659 .61742 .36389 .6165 .36277 Metetra
.664 .741 .907 r
.6165 .36277 .61742 .36389 .6235 .36187 .62258 .36075 Metetra
.664 .741 .907 r
.62258 .36075 .6235 .36187 .6296 .35985 .62868 .35872 Metetra
.664 .741 .907 r
.62868 .35872 .6296 .35985 .63571 .35783 .63479 .3567 Metetra
0 .294 .786 r
.63479 .3567 .63571 .35783 .64257 .37578 .64116 .36107 Metetra
.598 .4 .584 r
.64116 .36107 .64257 .37578 .64797 .35376 .64714 .35471 Metetra
.64714 .35471 .64797 .35376 .65427 .35534 .65321 .35058 Metetra
.604 .467 .668 r
.65321 .35058 .65427 .35534 .66028 .34968 .65938 .34854 Metetra
.664 .741 .907 r
.65938 .34854 .66028 .34968 .66646 .34763 .66556 .34649 Metetra
.664 .741 .907 r
.66556 .34649 .66646 .34763 .67265 .34558 .67176 .34443 Metetra
.664 .741 .907 r
.67176 .34443 .67265 .34558 .67886 .34352 .67796 .34237 Metetra
.664 .741 .907 r
.67796 .34237 .67886 .34352 .68508 .34146 .68418 .34031 Metetra
.664 .741 .907 r
.68418 .34031 .68508 .34146 .69131 .3394 .69042 .33824 Metetra
.664 .741 .907 r
.69042 .33824 .69131 .3394 .69755 .33733 .69667 .33617 Metetra
.664 .741 .907 r
.69667 .33617 .69755 .33733 .70381 .33525 .70293 .33409 Metetra
.664 .741 .907 r
.70293 .33409 .70381 .33525 .71009 .33317 .70921 .33201 Metetra
.664 .741 .907 r
.70921 .33201 .71009 .33317 .71637 .33109 .7155 .32992 Metetra
.664 .741 .907 r
.7155 .32992 .71637 .33109 .72268 .329 .7218 .32783 Metetra
.664 .741 .907 r
.7218 .32783 .72268 .329 .72899 .3269 .72812 .32574 Metetra
.664 .741 .907 r
.72812 .32574 .72899 .3269 .73532 .32481 .73445 .32363 Metetra
.664 .741 .907 r
.73445 .32363 .73532 .32481 .74166 .3227 .7408 .32153 Metetra
.664 .741 .907 r
.7408 .32153 .74166 .3227 .74802 .3206 .74716 .31942 Metetra
.664 .741 .907 r
.74716 .31942 .74802 .3206 .75439 .31848 .75353 .3173 Metetra
.664 .741 .907 r
.75353 .3173 .75439 .31848 .76078 .31637 .75992 .31519 Metetra
.664 .741 .907 r
.75992 .31519 .76078 .31637 .76718 .31425 .76632 .31306 Metetra
.664 .741 .907 r
.76632 .31306 .76718 .31425 .77359 .31212 .77274 .31093 Metetra
.664 .741 .907 r
.77274 .31093 .77359 .31212 .78002 .30999 .77917 .3088 Metetra
.664 .741 .907 r
.77917 .3088 .78002 .30999 .78646 .30785 .78562 .30666 Metetra
.664 .741 .907 r
.78562 .30666 .78646 .30785 .79292 .30571 .79208 .30452 Metetra
.664 .741 .907 r
.79208 .30452 .79292 .30571 .79939 .30357 .79855 .30237 Metetra
.664 .741 .907 r
.79855 .30237 .79939 .30357 .80588 .30142 .80504 .30022 Metetra
.664 .741 .907 r
.80504 .30022 .80588 .30142 .81238 .29926 .81155 .29806 Metetra
.664 .741 .907 r
.81155 .29806 .81238 .29926 .81889 .2971 .81807 .2959 Metetra
.664 .741 .907 r
.81807 .2959 .81889 .2971 .82543 .29494 .8246 .29373 Metetra
.664 .741 .907 r
.8246 .29373 .82543 .29494 .83197 .29277 .83115 .29156 Metetra
.664 .741 .907 r
.83115 .29156 .83197 .29277 .83853 .29059 .83771 .28938 Metetra
.664 .741 .907 r
.83771 .28938 .83853 .29059 .8451 .28841 .84429 .2872 Metetra
.664 .741 .907 r
.84429 .2872 .8451 .28841 .85169 .28623 .85088 .28501 Metetra
.664 .741 .907 r
.85088 .28501 .85169 .28623 .8583 .28404 .85749 .28282 Metetra
.664 .741 .907 r
.85749 .28282 .8583 .28404 .86492 .28185 .86411 .28062 Metetra
.664 .741 .907 r
.86411 .28062 .86492 .28185 .87155 .27965 .87075 .27842 Metetra
.664 .741 .907 r
.27298 .47538 .27404 .47637 .27941 .47459 .27835 .4736 Metetra
.664 .741 .907 r
.27835 .4736 .27941 .47459 .28478 .47281 .28372 .47182 Metetra
.664 .741 .907 r
.28372 .47182 .28478 .47281 .29017 .47103 .28911 .47003 Metetra
.664 .741 .907 r
.28911 .47003 .29017 .47103 .29556 .46923 .29451 .46823 Metetra
.664 .741 .907 r
.29451 .46823 .29556 .46923 .30097 .46744 .29992 .46644 Metetra
.664 .741 .907 r
.29992 .46644 .30097 .46744 .30639 .46564 .30534 .46464 Metetra
.664 .741 .907 r
.30534 .46464 .30639 .46564 .31182 .46384 .31077 .46284 Metetra
.947 .653 .449 r
.31077 .46284 .31182 .46384 .31502 .49742 .31308 .51039 Metetra
0 0 .041 r
.31308 .51039 .31502 .49742 .32271 .46023 .32167 .45922 Metetra
.664 .741 .907 r
.32167 .45922 .32271 .46023 .32818 .45842 .32713 .4574 Metetra
.664 .741 .907 r
.32713 .4574 .32818 .45842 .33365 .4566 .33261 .45558 Metetra
.664 .741 .907 r
.33261 .45558 .33365 .4566 .33914 .45478 .3381 .45376 Metetra
.664 .741 .907 r
.3381 .45376 .33914 .45478 .34463 .45296 .3436 .45194 Metetra
.664 .741 .907 r
.3436 .45194 .34463 .45296 .35014 .45113 .34911 .45011 Metetra
.664 .741 .907 r
.34911 .45011 .35014 .45113 .35566 .4493 .35463 .44827 Metetra
.664 .741 .907 r
.35463 .44827 .35566 .4493 .3612 .44746 .36017 .44644 Metetra
.664 .741 .907 r
.36017 .44644 .3612 .44746 .36674 .44562 .36571 .4446 Metetra
.664 .741 .907 r
.36571 .4446 .36674 .44562 .37229 .44378 .37127 .44275 Metetra
.664 .741 .907 r
.37127 .44275 .37229 .44378 .37786 .44193 .37684 .4409 Metetra
.664 .741 .907 r
.37684 .4409 .37786 .44193 .38344 .44008 .38242 .43905 Metetra
.664 .741 .907 r
.38242 .43905 .38344 .44008 .38903 .43823 .38801 .43719 Metetra
.664 .741 .907 r
.38801 .43719 .38903 .43823 .39463 .43637 .39361 .43533 Metetra
.664 .741 .907 r
.39361 .43533 .39463 .43637 .40024 .43451 .39923 .43347 Metetra
.664 .741 .907 r
.39923 .43347 .40024 .43451 .40586 .43264 .40485 .4316 Metetra
.664 .741 .907 r
.40485 .4316 .40586 .43264 .4115 .43077 .41049 .42973 Metetra
.664 .741 .907 r
.41049 .42973 .4115 .43077 .41715 .4289 .41614 .42785 Metetra
.953 .621 .354 r
.41614 .42785 .41715 .4289 .41826 .57193 .42078 .45826 Metetra
.554 .34 .545 r
.42078 .45826 .41826 .57193 .42705 .47338 .42652 .45591 Metetra
.706 .481 .58 r
.42652 .45591 .42705 .47338 .43417 .42325 .43316 .4222 Metetra
.664 .741 .907 r
.43316 .4222 .43417 .42325 .43986 .42136 .43886 .42031 Metetra
.664 .741 .907 r
.43886 .42031 .43986 .42136 .44557 .41947 .44457 .41841 Metetra
.664 .741 .907 r
.44457 .41841 .44557 .41947 .45129 .41757 .45029 .41651 Metetra
.664 .741 .907 r
.45029 .41651 .45129 .41757 .45702 .41567 .45603 .41461 Metetra
.664 .741 .907 r
.45603 .41461 .45702 .41567 .46276 .41377 .46178 .4127 Metetra
.664 .741 .907 r
.46178 .4127 .46276 .41377 .46852 .41186 .46753 .41079 Metetra
.664 .741 .907 r
.46753 .41079 .46852 .41186 .47429 .40994 .47331 .40887 Metetra
.664 .741 .907 r
.47331 .40887 .47429 .40994 .48007 .40803 .47909 .40695 Metetra
.664 .741 .907 r
.47909 .40695 .48007 .40803 .48586 .4061 .48488 .40503 Metetra
.664 .741 .907 r
.48488 .40503 .48586 .4061 .49167 .40418 .49069 .4031 Metetra
.664 .741 .907 r
.49069 .4031 .49167 .40418 .49749 .40225 .49651 .40117 Metetra
.664 .741 .907 r
.49651 .40117 .49749 .40225 .50332 .40031 .50234 .39923 Metetra
.664 .741 .907 r
.50234 .39923 .50332 .40031 .50916 .39838 .50819 .39729 Metetra
.664 .741 .907 r
.50819 .39729 .50916 .39838 .51501 .39643 .51405 .39535 Metetra
.658 .178 0 r
.51405 .39535 .51501 .39643 .52088 .39449 .5199 .40329 Metetra
.356 .124 .419 r
.5199 .40329 .52088 .39449 .52676 .39254 .5258 .39145 Metetra
.664 .741 .907 r
.5258 .39145 .52676 .39254 .53265 .39058 .53169 .38949 Metetra
.664 .741 .907 r
.53169 .38949 .53265 .39058 .53856 .38862 .5376 .38753 Metetra
.664 .741 .907 r
.5376 .38753 .53856 .38862 .54448 .38666 .54352 .38556 Metetra
.664 .741 .907 r
.54352 .38556 .54448 .38666 .55041 .38469 .54945 .38359 Metetra
.664 .741 .907 r
.54945 .38359 .55041 .38469 .55635 .38272 .5554 .38162 Metetra
.664 .741 .907 r
.5554 .38162 .55635 .38272 .56231 .38074 .56136 .37964 Metetra
.664 .741 .907 r
.56136 .37964 .56231 .38074 .56828 .37876 .56733 .37766 Metetra
.664 .741 .907 r
.56733 .37766 .56828 .37876 .57426 .37678 .57332 .37567 Metetra
.664 .741 .907 r
.57332 .37567 .57426 .37678 .58025 .37479 .57931 .37368 Metetra
.664 .741 .907 r
.57931 .37368 .58025 .37479 .58626 .3728 .58532 .37168 Metetra
.664 .741 .907 r
.58532 .37168 .58626 .3728 .59228 .3708 .59135 .36968 Metetra
.664 .741 .907 r
.59135 .36968 .59228 .3708 .59832 .3688 .59738 .36768 Metetra
.664 .741 .907 r
.59738 .36768 .59832 .3688 .60436 .36679 .60343 .36567 Metetra
.664 .741 .907 r
.60343 .36567 .60436 .36679 .61042 .36478 .6095 .36366 Metetra
.664 .741 .907 r
.6095 .36366 .61042 .36478 .6165 .36277 .61557 .36164 Metetra
.664 .741 .907 r
.61557 .36164 .6165 .36277 .62258 .36075 .62166 .35962 Metetra
.664 .741 .907 r
.62166 .35962 .62258 .36075 .62868 .35872 .62776 .35759 Metetra
.664 .741 .907 r
.62776 .35759 .62868 .35872 .63479 .3567 .63388 .35556 Metetra
.664 .741 .907 r
.63388 .35556 .63479 .3567 .64116 .36107 .64001 .35353 Metetra
.586 .42 .623 r
.64001 .35353 .64116 .36107 .64714 .35471 .64615 .35149 Metetra
.623 .523 .72 r
.64615 .35149 .64714 .35471 .65321 .35058 .65231 .34944 Metetra
.664 .741 .907 r
.65231 .34944 .65321 .35058 .65938 .34854 .65848 .3474 Metetra
.664 .741 .907 r
.65848 .3474 .65938 .34854 .66556 .34649 .66466 .34534 Metetra
.664 .741 .907 r
.66466 .34534 .66556 .34649 .67176 .34443 .67086 .34329 Metetra
.664 .741 .907 r
.67086 .34329 .67176 .34443 .67796 .34237 .67707 .34122 Metetra
.664 .741 .907 r
.67707 .34122 .67796 .34237 .68418 .34031 .68329 .33916 Metetra
.664 .741 .907 r
.68329 .33916 .68418 .34031 .69042 .33824 .68953 .33709 Metetra
.664 .741 .907 r
.68953 .33709 .69042 .33824 .69667 .33617 .69578 .33501 Metetra
.664 .741 .907 r
.69578 .33501 .69667 .33617 .70293 .33409 .70205 .33293 Metetra
.664 .741 .907 r
.70205 .33293 .70293 .33409 .70921 .33201 .70832 .33085 Metetra
.664 .741 .907 r
.70832 .33085 .70921 .33201 .7155 .32992 .71462 .32876 Metetra
.664 .741 .907 r
.71462 .32876 .7155 .32992 .7218 .32783 .72092 .32666 Metetra
.664 .741 .907 r
.72092 .32666 .7218 .32783 .72812 .32574 .72725 .32456 Metetra
.664 .741 .907 r
.72725 .32456 .72812 .32574 .73445 .32363 .73358 .32246 Metetra
.664 .741 .907 r
.73358 .32246 .73445 .32363 .7408 .32153 .73993 .32035 Metetra
.664 .741 .907 r
.73993 .32035 .7408 .32153 .74716 .31942 .74629 .31824 Metetra
.664 .741 .907 r
.74629 .31824 .74716 .31942 .75353 .3173 .75267 .31612 Metetra
.664 .741 .907 r
.75267 .31612 .75353 .3173 .75992 .31519 .75906 .314 Metetra
.664 .741 .907 r
.75906 .314 .75992 .31519 .76632 .31306 .76547 .31187 Metetra
.664 .741 .907 r
.76547 .31187 .76632 .31306 .77274 .31093 .77189 .30974 Metetra
.664 .741 .907 r
.77189 .30974 .77274 .31093 .77917 .3088 .77832 .30761 Metetra
.664 .741 .907 r
.77832 .30761 .77917 .3088 .78562 .30666 .78477 .30547 Metetra
.664 .741 .907 r
.78477 .30547 .78562 .30666 .79208 .30452 .79124 .30332 Metetra
.664 .741 .907 r
.79124 .30332 .79208 .30452 .79855 .30237 .79771 .30117 Metetra
.664 .741 .907 r
.79771 .30117 .79855 .30237 .80504 .30022 .80421 .29901 Metetra
.664 .741 .907 r
.80421 .29901 .80504 .30022 .81155 .29806 .81071 .29685 Metetra
.664 .741 .907 r
.81071 .29685 .81155 .29806 .81807 .2959 .81724 .29469 Metetra
.664 .741 .907 r
.81724 .29469 .81807 .2959 .8246 .29373 .82377 .29252 Metetra
.664 .741 .907 r
.82377 .29252 .8246 .29373 .83115 .29156 .83032 .29034 Metetra
.664 .741 .907 r
.83032 .29034 .83115 .29156 .83771 .28938 .83689 .28816 Metetra
.664 .741 .907 r
.83689 .28816 .83771 .28938 .84429 .2872 .84347 .28598 Metetra
.664 .741 .907 r
.84347 .28598 .84429 .2872 .85088 .28501 .85007 .28379 Metetra
.664 .741 .907 r
.85007 .28379 .85088 .28501 .85749 .28282 .85668 .28159 Metetra
.664 .741 .907 r
.85668 .28159 .85749 .28282 .86411 .28062 .8633 .27939 Metetra
.664 .741 .907 r
.8633 .27939 .86411 .28062 .87075 .27842 .86995 .27719 Metetra
.664 .741 .907 r
.27192 .47439 .27298 .47538 .27835 .4736 .27729 .47261 Metetra
.664 .741 .907 r
.27729 .47261 .27835 .4736 .28372 .47182 .28266 .47082 Metetra
.664 .741 .907 r
.28266 .47082 .28372 .47182 .28911 .47003 .28805 .46903 Metetra
.664 .741 .907 r
.28805 .46903 .28911 .47003 .29451 .46823 .29345 .46723 Metetra
.939 .587 .322 r
.29345 .46723 .29451 .46823 .29992 .46644 .29745 .48598 Metetra
.372 .161 .458 r
.29745 .48598 .29992 .46644 .30534 .46464 .30429 .46363 Metetra
.664 .741 .907 r
.30429 .46363 .30534 .46464 .31077 .46284 .30972 .46183 Metetra
.947 .637 .414 r
.30972 .46183 .31077 .46284 .31308 .51039 .31293 .49498 Metetra
.729 .504 .586 r
.31293 .49498 .31308 .51039 .32167 .45922 .32062 .45821 Metetra
.664 .741 .907 r
.32062 .45821 .32167 .45922 .32713 .4574 .32609 .45639 Metetra
.664 .741 .907 r
.32609 .45639 .32713 .4574 .33261 .45558 .33157 .45457 Metetra
.664 .741 .907 r
.33157 .45457 .33261 .45558 .3381 .45376 .33706 .45274 Metetra
.664 .741 .907 r
.33706 .45274 .3381 .45376 .3436 .45194 .34256 .45092 Metetra
.664 .741 .907 r
.34256 .45092 .3436 .45194 .34911 .45011 .34807 .44909 Metetra
.664 .741 .907 r
.34807 .44909 .34911 .45011 .35463 .44827 .3536 .44725 Metetra
.664 .741 .907 r
.3536 .44725 .35463 .44827 .36017 .44644 .35914 .44541 Metetra
.664 .741 .907 r
.35914 .44541 .36017 .44644 .36571 .4446 .36468 .44357 Metetra
.664 .741 .907 r
.36468 .44357 .36571 .4446 .37127 .44275 .37024 .44172 Metetra
.664 .741 .907 r
.37024 .44172 .37127 .44275 .37684 .4409 .37581 .43987 Metetra
.952 .67 .467 r
.37581 .43987 .37684 .4409 .38242 .43905 .37708 .53602 Metetra
.404 .21 .501 r
.37708 .53602 .38242 .43905 .38801 .43719 .38699 .43616 Metetra
.664 .741 .907 r
.38699 .43616 .38801 .43719 .39361 .43533 .39259 .43429 Metetra
.664 .741 .907 r
.39259 .43429 .39361 .43533 .39923 .43347 .39821 .43243 Metetra
.664 .741 .907 r
.39821 .43243 .39923 .43347 .40485 .4316 .40384 .43056 Metetra
.664 .741 .907 r
.40384 .43056 .40485 .4316 .41049 .42973 .40948 .42868 Metetra
.664 .741 .907 r
.40948 .42868 .41049 .42973 .41614 .42785 .41513 .4268 Metetra
.664 .741 .907 r
.41513 .4268 .41614 .42785 .42078 .45826 .4208 .42492 Metetra
.525 .327 .554 r
.4208 .42492 .42078 .45826 .42652 .45591 .42618 .43276 Metetra
.605 .395 .571 r
.42618 .43276 .42652 .45591 .43316 .4222 .43216 .42115 Metetra
.664 .741 .907 r
.43216 .42115 .43316 .4222 .43886 .42031 .43786 .41925 Metetra
.664 .741 .907 r
.43786 .41925 .43886 .42031 .44457 .41841 .44358 .41735 Metetra
.664 .741 .907 r
.44358 .41735 .44457 .41841 .45029 .41651 .4493 .41545 Metetra
.664 .741 .907 r
.4493 .41545 .45029 .41651 .45603 .41461 .45504 .41355 Metetra
.664 .741 .907 r
.45504 .41355 .45603 .41461 .46178 .4127 .46079 .41164 Metetra
.664 .741 .907 r
.46079 .41164 .46178 .4127 .46753 .41079 .46655 .40972 Metetra
.664 .741 .907 r
.46655 .40972 .46753 .41079 .47331 .40887 .47232 .4078 Metetra
.664 .741 .907 r
.47232 .4078 .47331 .40887 .47909 .40695 .47811 .40588 Metetra
.664 .741 .907 r
.47811 .40588 .47909 .40695 .48488 .40503 .4839 .40395 Metetra
.664 .741 .907 r
.4839 .40395 .48488 .40503 .49069 .4031 .48971 .40202 Metetra
.664 .741 .907 r
.48971 .40202 .49069 .4031 .49651 .40117 .49554 .40009 Metetra
.664 .741 .907 r
.49554 .40009 .49651 .40117 .50234 .39923 .50137 .39815 Metetra
.664 .741 .907 r
.50137 .39815 .50234 .39923 .50819 .39729 .50722 .39621 Metetra
.664 .741 .907 r
.50722 .39621 .50819 .39729 .51405 .39535 .51308 .39426 Metetra
.664 .741 .907 r
.51308 .39426 .51405 .39535 .5199 .40329 .51895 .39231 Metetra
.576 .393 .597 r
.51895 .39231 .5199 .40329 .5258 .39145 .52483 .39035 Metetra
.664 .741 .907 r
.52483 .39035 .5258 .39145 .53169 .38949 .53073 .38839 Metetra
.664 .741 .907 r
.53073 .38839 .53169 .38949 .5376 .38753 .53664 .38643 Metetra
.664 .741 .907 r
.53664 .38643 .5376 .38753 .54352 .38556 .54257 .38446 Metetra
.664 .741 .907 r
.54257 .38446 .54352 .38556 .54945 .38359 .5485 .38249 Metetra
.959 .627 .327 r
.5485 .38249 .54945 .38359 .5554 .38162 .55485 .42353 Metetra
.41 .213 .499 r
.55485 .42353 .5554 .38162 .56136 .37964 .56041 .37853 Metetra
.664 .741 .907 r
.56041 .37853 .56136 .37964 .56733 .37766 .56639 .37655 Metetra
.664 .741 .907 r
.56639 .37655 .56733 .37766 .57332 .37567 .57237 .37456 Metetra
.664 .741 .907 r
.57237 .37456 .57332 .37567 .57931 .37368 .57837 .37257 Metetra
.664 .741 .907 r
.57837 .37257 .57931 .37368 .58532 .37168 .58439 .37057 Metetra
.664 .741 .907 r
.58439 .37057 .58532 .37168 .59135 .36968 .59041 .36857 Metetra
.664 .741 .907 r
.59041 .36857 .59135 .36968 .59738 .36768 .59645 .36656 Metetra
.664 .741 .907 r
.59645 .36656 .59738 .36768 .60343 .36567 .6025 .36455 Metetra
.664 .741 .907 r
.6025 .36455 .60343 .36567 .6095 .36366 .60857 .36253 Metetra
.664 .741 .907 r
.60857 .36253 .6095 .36366 .61557 .36164 .61465 .36051 Metetra
.664 .741 .907 r
.61465 .36051 .61557 .36164 .62166 .35962 .62074 .35849 Metetra
.664 .741 .907 r
.62074 .35849 .62166 .35962 .62776 .35759 .62684 .35646 Metetra
.664 .741 .907 r
.62684 .35646 .62776 .35759 .63388 .35556 .63296 .35443 Metetra
.664 .741 .907 r
.63296 .35443 .63388 .35556 .64001 .35353 .63909 .35239 Metetra
.664 .741 .907 r
.63909 .35239 .64001 .35353 .64615 .35149 .64524 .35035 Metetra
.664 .741 .907 r
.64524 .35035 .64615 .35149 .65231 .34944 .6514 .3483 Metetra
.664 .741 .907 r
.6514 .3483 .65231 .34944 .65848 .3474 .65757 .34625 Metetra
.664 .741 .907 r
.65757 .34625 .65848 .3474 .66466 .34534 .66376 .3442 Metetra
.664 .741 .907 r
.66376 .3442 .66466 .34534 .67086 .34329 .66996 .34214 Metetra
.664 .741 .907 r
.66996 .34214 .67086 .34329 .67707 .34122 .67617 .34007 Metetra
.664 .741 .907 r
.67617 .34007 .67707 .34122 .68329 .33916 .6824 .338 Metetra
.664 .741 .907 r
.6824 .338 .68329 .33916 .68953 .33709 .68864 .33593 Metetra
.664 .741 .907 r
.68864 .33593 .68953 .33709 .69578 .33501 .69489 .33385 Metetra
.664 .741 .907 r
.69489 .33385 .69578 .33501 .70205 .33293 .70116 .33177 Metetra
.664 .741 .907 r
.70116 .33177 .70205 .33293 .70832 .33085 .70744 .32968 Metetra
.664 .741 .907 r
.70744 .32968 .70832 .33085 .71462 .32876 .71374 .32759 Metetra
.664 .741 .907 r
.71374 .32759 .71462 .32876 .72092 .32666 .72005 .32549 Metetra
.664 .741 .907 r
.72005 .32549 .72092 .32666 .72725 .32456 .72637 .32339 Metetra
.664 .741 .907 r
.72637 .32339 .72725 .32456 .73358 .32246 .73271 .32129 Metetra
.664 .741 .907 r
.73271 .32129 .73358 .32246 .73993 .32035 .73906 .31918 Metetra
.664 .741 .907 r
.73906 .31918 .73993 .32035 .74629 .31824 .74543 .31706 Metetra
.664 .741 .907 r
.74543 .31706 .74629 .31824 .75267 .31612 .75181 .31494 Metetra
.664 .741 .907 r
.75181 .31494 .75267 .31612 .75906 .314 .7582 .31282 Metetra
.664 .741 .907 r
.7582 .31282 .75906 .314 .76547 .31187 .76461 .31069 Metetra
.664 .741 .907 r
.76461 .31069 .76547 .31187 .77189 .30974 .77104 .30855 Metetra
.664 .741 .907 r
.77104 .30855 .77189 .30974 .77832 .30761 .77747 .30641 Metetra
.664 .741 .907 r
.77747 .30641 .77832 .30761 .78477 .30547 .78393 .30427 Metetra
.664 .741 .907 r
.78393 .30427 .78477 .30547 .79124 .30332 .79039 .30212 Metetra
.664 .741 .907 r
.79039 .30212 .79124 .30332 .79771 .30117 .79687 .29997 Metetra
.664 .741 .907 r
.79687 .29997 .79771 .30117 .80421 .29901 .80337 .29781 Metetra
.664 .741 .907 r
.80337 .29781 .80421 .29901 .81071 .29685 .80988 .29565 Metetra
.664 .741 .907 r
.80988 .29565 .81071 .29685 .81724 .29469 .8164 .29348 Metetra
.664 .741 .907 r
.8164 .29348 .81724 .29469 .82377 .29252 .82294 .2913 Metetra
.664 .741 .907 r
.82294 .2913 .82377 .29252 .83032 .29034 .8295 .28913 Metetra
.664 .741 .907 r
.8295 .28913 .83032 .29034 .83689 .28816 .83607 .28694 Metetra
.664 .741 .907 r
.83607 .28694 .83689 .28816 .84347 .28598 .84265 .28476 Metetra
.664 .741 .907 r
.84265 .28476 .84347 .28598 .85007 .28379 .84925 .28256 Metetra
.664 .741 .907 r
.84925 .28256 .85007 .28379 .85668 .28159 .85587 .28037 Metetra
.664 .741 .907 r
.85587 .28037 .85668 .28159 .8633 .27939 .8625 .27816 Metetra
.664 .741 .907 r
.8625 .27816 .8633 .27939 .86995 .27719 .86914 .27596 Metetra
.664 .741 .907 r
.27085 .47339 .27192 .47439 .27729 .47261 .27622 .47161 Metetra
.664 .741 .907 r
.27622 .47161 .27729 .47261 .28266 .47082 .2816 .46982 Metetra
.664 .741 .907 r
.2816 .46982 .28266 .47082 .28805 .46903 .287 .46803 Metetra
.664 .741 .907 r
.287 .46803 .28805 .46903 .29345 .46723 .2924 .46623 Metetra
.664 .741 .907 r
.2924 .46623 .29345 .46723 .29745 .48598 .29781 .46443 Metetra
.563 .363 .568 r
.29781 .46443 .29745 .48598 .30429 .46363 .30324 .46263 Metetra
.664 .741 .907 r
.30324 .46263 .30429 .46363 .30972 .46183 .30867 .46082 Metetra
.664 .741 .907 r
.30867 .46082 .30972 .46183 .31293 .49498 .31412 .45901 Metetra
.558 .352 .556 r
.31412 .45901 .31293 .49498 .32062 .45821 .31958 .45719 Metetra
.664 .741 .907 r
.31958 .45719 .32062 .45821 .32609 .45639 .32505 .45537 Metetra
.664 .741 .907 r
.32505 .45537 .32609 .45639 .33157 .45457 .33053 .45355 Metetra
.664 .741 .907 r
.33053 .45355 .33157 .45457 .33706 .45274 .33602 .45173 Metetra
.664 .741 .907 r
.33602 .45173 .33706 .45274 .34256 .45092 .34152 .4499 Metetra
.664 .741 .907 r
.34152 .4499 .34256 .45092 .34807 .44909 .34704 .44806 Metetra
.664 .741 .907 r
.34704 .44806 .34807 .44909 .3536 .44725 .35257 .44622 Metetra
.664 .741 .907 r
.35257 .44622 .3536 .44725 .35914 .44541 .3581 .44438 Metetra
.664 .741 .907 r
.3581 .44438 .35914 .44541 .36468 .44357 .36365 .44254 Metetra
.664 .741 .907 r
.36365 .44254 .36468 .44357 .37024 .44172 .36921 .44069 Metetra
.952 .666 .46 r
.36921 .44069 .37024 .44172 .37581 .43987 .3711 .51891 Metetra
.686 .442 .548 r
.3711 .51891 .37581 .43987 .37708 .53602 .37045 .66073 Metetra
.23 .073 .451 r
.37045 .66073 .37708 .53602 .38699 .43616 .38597 .43512 Metetra
.664 .741 .907 r
.38597 .43512 .38699 .43616 .39259 .43429 .39157 .43325 Metetra
.664 .741 .907 r
.39157 .43325 .39259 .43429 .39821 .43243 .39719 .43138 Metetra
.664 .741 .907 r
.39719 .43138 .39821 .43243 .40384 .43056 .40283 .42951 Metetra
.664 .741 .907 r
.40283 .42951 .40384 .43056 .40948 .42868 .40847 .42764 Metetra
.664 .741 .907 r
.40847 .42764 .40948 .42868 .41513 .4268 .41412 .42575 Metetra
.664 .741 .907 r
.41412 .42575 .41513 .4268 .4208 .42492 .41979 .42387 Metetra
.664 .741 .907 r
.41979 .42387 .4208 .42492 .42618 .43276 .42547 .42198 Metetra
.576 .393 .597 r
.42547 .42198 .42618 .43276 .43216 .42115 .43116 .42009 Metetra
.664 .741 .907 r
.43116 .42009 .43216 .42115 .43786 .41925 .43686 .41819 Metetra
.664 .741 .907 r
.43686 .41819 .43786 .41925 .44358 .41735 .44258 .41629 Metetra
.664 .741 .907 r
.44258 .41629 .44358 .41735 .4493 .41545 .4483 .41439 Metetra
.664 .741 .907 r
.4483 .41439 .4493 .41545 .45504 .41355 .45404 .41248 Metetra
.664 .741 .907 r
.45404 .41248 .45504 .41355 .46079 .41164 .45979 .41057 Metetra
.664 .741 .907 r
.45979 .41057 .46079 .41164 .46655 .40972 .46556 .40865 Metetra
.664 .741 .907 r
.46556 .40865 .46655 .40972 .47232 .4078 .47133 .40673 Metetra
.664 .741 .907 r
.47133 .40673 .47232 .4078 .47811 .40588 .47712 .40481 Metetra
.664 .741 .907 r
.47712 .40481 .47811 .40588 .4839 .40395 .48292 .40288 Metetra
.664 .741 .907 r
.48292 .40288 .4839 .40395 .48971 .40202 .48873 .40095 Metetra
.664 .741 .907 r
.48873 .40095 .48971 .40202 .49554 .40009 .49456 .39901 Metetra
.664 .741 .907 r
.49456 .39901 .49554 .40009 .50137 .39815 .5004 .39707 Metetra
.664 .741 .907 r
.5004 .39707 .50137 .39815 .50722 .39621 .50625 .39512 Metetra
.664 .741 .907 r
.50625 .39512 .50722 .39621 .51308 .39426 .51211 .39317 Metetra
.664 .741 .907 r
.51211 .39317 .51308 .39426 .51895 .39231 .51798 .39122 Metetra
.664 .741 .907 r
.51798 .39122 .51895 .39231 .52483 .39035 .52387 .38926 Metetra
.664 .741 .907 r
.52387 .38926 .52483 .39035 .53073 .38839 .52977 .3873 Metetra
.664 .741 .907 r
.52977 .3873 .53073 .38839 .53664 .38643 .53568 .38533 Metetra
.664 .741 .907 r
.53568 .38533 .53664 .38643 .54257 .38446 .54161 .38336 Metetra
.558 .701 .936 r
.54161 .38336 .54257 .38446 .5485 .38249 .54756 .38275 Metetra
.952 .644 .413 r
.54756 .38275 .5485 .38249 .55485 .42353 .55419 .45699 Metetra
.156 .016 .425 r
.55419 .45699 .55485 .42353 .56041 .37853 .55946 .37743 Metetra
.664 .741 .907 r
.55946 .37743 .56041 .37853 .56639 .37655 .56544 .37544 Metetra
.664 .741 .907 r
.56544 .37544 .56639 .37655 .57237 .37456 .57143 .37345 Metetra
.664 .741 .907 r
.57143 .37345 .57237 .37456 .57837 .37257 .57743 .37145 Metetra
.664 .741 .907 r
.57743 .37145 .57837 .37257 .58439 .37057 .58345 .36945 Metetra
.664 .741 .907 r
.58345 .36945 .58439 .37057 .59041 .36857 .58948 .36745 Metetra
.664 .741 .907 r
.58948 .36745 .59041 .36857 .59645 .36656 .59552 .36544 Metetra
.664 .741 .907 r
.59552 .36544 .59645 .36656 .6025 .36455 .60157 .36342 Metetra
.664 .741 .907 r
.60157 .36342 .6025 .36455 .60857 .36253 .60764 .36141 Metetra
.664 .741 .907 r
.60764 .36141 .60857 .36253 .61465 .36051 .61372 .35938 Metetra
.664 .741 .907 r
.61372 .35938 .61465 .36051 .62074 .35849 .61982 .35736 Metetra
.664 .741 .907 r
.61982 .35736 .62074 .35849 .62684 .35646 .62592 .35533 Metetra
.664 .741 .907 r
.62592 .35533 .62684 .35646 .63296 .35443 .63205 .35329 Metetra
.664 .741 .907 r
.63205 .35329 .63296 .35443 .63909 .35239 .63818 .35125 Metetra
.664 .741 .907 r
.63818 .35125 .63909 .35239 .64524 .35035 .64433 .34921 Metetra
.664 .741 .907 r
.64433 .34921 .64524 .35035 .6514 .3483 .65049 .34716 Metetra
.664 .741 .907 r
.65049 .34716 .6514 .3483 .65757 .34625 .65666 .34511 Metetra
.664 .741 .907 r
.65666 .34511 .65757 .34625 .66376 .3442 .66285 .34305 Metetra
.664 .741 .907 r
.66285 .34305 .66376 .3442 .66996 .34214 .66906 .34099 Metetra
.664 .741 .907 r
.66906 .34099 .66996 .34214 .67617 .34007 .67527 .33892 Metetra
.664 .741 .907 r
.67527 .33892 .67617 .34007 .6824 .338 .6815 .33685 Metetra
.664 .741 .907 r
.6815 .33685 .6824 .338 .68864 .33593 .68774 .33477 Metetra
.664 .741 .907 r
.68774 .33477 .68864 .33593 .69489 .33385 .694 .33269 Metetra
.664 .741 .907 r
.694 .33269 .69489 .33385 .70116 .33177 .70027 .3306 Metetra
.664 .741 .907 r
.70027 .3306 .70116 .33177 .70744 .32968 .70656 .32852 Metetra
.664 .741 .907 r
.70656 .32852 .70744 .32968 .71374 .32759 .71286 .32642 Metetra
.664 .741 .907 r
.71286 .32642 .71374 .32759 .72005 .32549 .71917 .32432 Metetra
0 0 .522 r
.71917 .32432 .72005 .32549 .72637 .32339 .72615 .33244 Metetra
.375 .148 .437 r
.72615 .33244 .72637 .32339 .73271 .32129 .73184 .32011 Metetra
.933 .566 .167 r
.73184 .32011 .73271 .32129 .73906 .31918 .74067 .35448 Metetra
.421 .223 .505 r
.74067 .35448 .73906 .31918 .74543 .31706 .74456 .31588 Metetra
.664 .741 .907 r
.74456 .31588 .74543 .31706 .75181 .31494 .75094 .31376 Metetra
.664 .741 .907 r
.75094 .31376 .75181 .31494 .7582 .31282 .75734 .31163 Metetra
.664 .741 .907 r
.75734 .31163 .7582 .31282 .76461 .31069 .76375 .3095 Metetra
.664 .741 .907 r
.76375 .3095 .76461 .31069 .77104 .30855 .77018 .30736 Metetra
.664 .741 .907 r
.77018 .30736 .77104 .30855 .77747 .30641 .77662 .30522 Metetra
.664 .741 .907 r
.77662 .30522 .77747 .30641 .78393 .30427 .78308 .30307 Metetra
.664 .741 .907 r
.78308 .30307 .78393 .30427 .79039 .30212 .78955 .30092 Metetra
.664 .741 .907 r
.78955 .30092 .79039 .30212 .79687 .29997 .79603 .29876 Metetra
.664 .741 .907 r
.79603 .29876 .79687 .29997 .80337 .29781 .80253 .2966 Metetra
.664 .741 .907 r
.80253 .2966 .80337 .29781 .80988 .29565 .80904 .29444 Metetra
.664 .741 .907 r
.80904 .29444 .80988 .29565 .8164 .29348 .81557 .29227 Metetra
.664 .741 .907 r
.81557 .29227 .8164 .29348 .82294 .2913 .82211 .29009 Metetra
.664 .741 .907 r
.82211 .29009 .82294 .2913 .8295 .28913 .82867 .28791 Metetra
.664 .741 .907 r
.82867 .28791 .8295 .28913 .83607 .28694 .83525 .28572 Metetra
.664 .741 .907 r
.83525 .28572 .83607 .28694 .84265 .28476 .84183 .28353 Metetra
.664 .741 .907 r
.84183 .28353 .84265 .28476 .84925 .28256 .84844 .28134 Metetra
.664 .741 .907 r
.84844 .28134 .84925 .28256 .85587 .28037 .85505 .27914 Metetra
.664 .741 .907 r
.85505 .27914 .85587 .28037 .8625 .27816 .86169 .27693 Metetra
.664 .741 .907 r
.86169 .27693 .8625 .27816 .86914 .27596 .86833 .27472 Metetra
.664 .741 .907 r
.26979 .4724 .27085 .47339 .27622 .47161 .27516 .47061 Metetra
.664 .741 .907 r
.27516 .47061 .27622 .47161 .2816 .46982 .28054 .46882 Metetra
.664 .741 .907 r
.28054 .46882 .2816 .46982 .287 .46803 .28594 .46703 Metetra
.664 .741 .907 r
.28594 .46703 .287 .46803 .2924 .46623 .29134 .46523 Metetra
.828 .363 0 r
.29134 .46523 .2924 .46623 .29781 .46443 .29605 .47354 Metetra
.332 .098 .401 r
.29605 .47354 .29781 .46443 .30324 .46263 .30218 .46162 Metetra
.664 .741 .907 r
.30218 .46162 .30324 .46263 .30867 .46082 .30762 .45981 Metetra
.664 .741 .907 r
.30762 .45981 .30867 .46082 .31412 .45901 .31307 .458 Metetra
.664 .741 .907 r
.31307 .458 .31412 .45901 .31958 .45719 .31853 .45618 Metetra
.664 .741 .907 r
.31853 .45618 .31958 .45719 .32505 .45537 .324 .45436 Metetra
.664 .741 .907 r
.324 .45436 .32505 .45537 .33053 .45355 .32948 .45253 Metetra
.664 .741 .907 r
.32948 .45253 .33053 .45355 .33602 .45173 .33498 .45071 Metetra
.664 .741 .907 r
.33498 .45071 .33602 .45173 .34152 .4499 .34048 .44887 Metetra
.664 .741 .907 r
.34048 .44887 .34152 .4499 .34704 .44806 .346 .44704 Metetra
.664 .741 .907 r
.346 .44704 .34704 .44806 .35257 .44622 .35153 .4452 Metetra
.664 .741 .907 r
.35153 .4452 .35257 .44622 .3581 .44438 .35707 .44335 Metetra
.664 .741 .907 r
.35707 .44335 .3581 .44438 .36365 .44254 .36262 .44151 Metetra
.664 .741 .907 r
.36262 .44151 .36365 .44254 .36921 .44069 .36819 .43966 Metetra
.951 .674 .477 r
.36819 .43966 .36921 .44069 .3711 .51891 .36807 .56065 Metetra
.674 .428 .541 r
.36807 .56065 .3711 .51891 .37045 .66073 .37089 .62522 Metetra
.819 .568 .56 r
.37089 .62522 .37045 .66073 .38597 .43512 .38495 .43408 Metetra
.664 .741 .907 r
.38495 .43408 .38597 .43512 .39157 .43325 .39056 .43221 Metetra
.664 .741 .907 r
.39056 .43221 .39157 .43325 .39719 .43138 .39618 .43034 Metetra
.664 .741 .907 r
.39618 .43034 .39719 .43138 .40283 .42951 .40181 .42847 Metetra
.664 .741 .907 r
.40181 .42847 .40283 .42951 .40847 .42764 .40746 .42659 Metetra
.664 .741 .907 r
.40746 .42659 .40847 .42764 .41412 .42575 .41311 .4247 Metetra
.664 .741 .907 r
.41311 .4247 .41412 .42575 .41979 .42387 .41878 .42282 Metetra
.664 .741 .907 r
.41878 .42282 .41979 .42387 .42547 .42198 .42446 .42093 Metetra
.664 .741 .907 r
.42446 .42093 .42547 .42198 .43116 .42009 .43016 .41903 Metetra
.664 .741 .907 r
.43016 .41903 .43116 .42009 .43686 .41819 .43586 .41713 Metetra
.664 .741 .907 r
.43586 .41713 .43686 .41819 .44258 .41629 .44158 .41523 Metetra
.664 .741 .907 r
.44158 .41523 .44258 .41629 .4483 .41439 .44731 .41333 Metetra
.664 .741 .907 r
.44731 .41333 .4483 .41439 .45404 .41248 .45305 .41141 Metetra
.664 .741 .907 r
.45305 .41141 .45404 .41248 .45979 .41057 .4588 .4095 Metetra
.664 .741 .907 r
.4588 .4095 .45979 .41057 .46556 .40865 .46457 .40758 Metetra
.664 .741 .907 r
.46457 .40758 .46556 .40865 .47133 .40673 .47035 .40566 Metetra
.664 .741 .907 r
.47035 .40566 .47133 .40673 .47712 .40481 .47614 .40373 Metetra
.664 .741 .907 r
.47614 .40373 .47712 .40481 .48292 .40288 .48194 .4018 Metetra
.664 .741 .907 r
.48194 .4018 .48292 .40288 .48873 .40095 .48775 .39987 Metetra
.664 .741 .907 r
.48775 .39987 .48873 .40095 .49456 .39901 .49358 .39793 Metetra
.664 .741 .907 r
.49358 .39793 .49456 .39901 .5004 .39707 .49942 .39598 Metetra
.664 .741 .907 r
.49942 .39598 .5004 .39707 .50625 .39512 .50527 .39404 Metetra
.664 .741 .907 r
.50527 .39404 .50625 .39512 .51211 .39317 .51114 .39208 Metetra
.664 .741 .907 r
.51114 .39208 .51211 .39317 .51798 .39122 .51701 .39013 Metetra
.664 .741 .907 r
.51701 .39013 .51798 .39122 .52387 .38926 .5229 .38817 Metetra
.664 .741 .907 r
.5229 .38817 .52387 .38926 .52977 .3873 .52881 .3862 Metetra
.664 .741 .907 r
.52881 .3862 .52977 .3873 .53568 .38533 .53472 .38424 Metetra
.664 .741 .907 r
.53472 .38424 .53568 .38533 .54161 .38336 .54065 .38226 Metetra
.929 .546 .183 r
.54065 .38226 .54161 .38336 .54756 .38275 .54674 .403 Metetra
.601 .354 .514 r
.54674 .403 .54756 .38275 .55419 .45699 .55286 .41497 Metetra
.637 .412 .559 r
.55286 .41497 .55419 .45699 .55946 .37743 .55851 .37632 Metetra
.664 .741 .907 r
.55851 .37632 .55946 .37743 .56544 .37544 .56449 .37433 Metetra
.664 .741 .907 r
.56449 .37433 .56544 .37544 .57143 .37345 .57048 .37234 Metetra
.664 .741 .907 r
.57048 .37234 .57143 .37345 .57743 .37145 .57649 .37034 Metetra
.664 .741 .907 r
.57649 .37034 .57743 .37145 .58345 .36945 .58251 .36833 Metetra
.664 .741 .907 r
.58251 .36833 .58345 .36945 .58948 .36745 .58854 .36633 Metetra
.664 .741 .907 r
.58854 .36633 .58948 .36745 .59552 .36544 .59458 .36432 Metetra
.664 .741 .907 r
.59458 .36432 .59552 .36544 .60157 .36342 .60064 .3623 Metetra
.664 .741 .907 r
.60064 .3623 .60157 .36342 .60764 .36141 .60671 .36028 Metetra
.664 .741 .907 r
.60671 .36028 .60764 .36141 .61372 .35938 .61279 .35826 Metetra
.664 .741 .907 r
.61279 .35826 .61372 .35938 .61982 .35736 .61889 .35623 Metetra
.664 .741 .907 r
.61889 .35623 .61982 .35736 .62592 .35533 .625 .35419 Metetra
.664 .741 .907 r
.625 .35419 .62592 .35533 .63205 .35329 .63113 .35215 Metetra
.664 .741 .907 r
.63113 .35215 .63205 .35329 .63818 .35125 .63726 .35011 Metetra
.664 .741 .907 r
.63726 .35011 .63818 .35125 .64433 .34921 .64341 .34807 Metetra
.664 .741 .907 r
.64341 .34807 .64433 .34921 .65049 .34716 .64958 .34601 Metetra
.664 .741 .907 r
.64958 .34601 .65049 .34716 .65666 .34511 .65576 .34396 Metetra
.664 .741 .907 r
.65576 .34396 .65666 .34511 .66285 .34305 .66195 .3419 Metetra
.664 .741 .907 r
.66195 .3419 .66285 .34305 .66906 .34099 .66815 .33983 Metetra
.664 .741 .907 r
.66815 .33983 .66906 .34099 .67527 .33892 .67437 .33776 Metetra
.664 .741 .907 r
.67437 .33776 .67527 .33892 .6815 .33685 .6806 .33569 Metetra
.664 .741 .907 r
.6806 .33569 .6815 .33685 .68774 .33477 .68685 .33361 Metetra
.664 .741 .907 r
.68685 .33361 .68774 .33477 .694 .33269 .69311 .33153 Metetra
.664 .741 .907 r
.69311 .33153 .694 .33269 .70027 .3306 .69938 .32944 Metetra
.664 .741 .907 r
.69938 .32944 .70027 .3306 .70656 .32852 .70567 .32735 Metetra
.664 .741 .907 r
.70567 .32735 .70656 .32852 .71286 .32642 .71197 .32525 Metetra
.664 .741 .907 r
.71197 .32525 .71286 .32642 .71917 .32432 .71829 .32315 Metetra
.952 .603 .235 r
.71829 .32315 .71917 .32432 .72615 .33244 .72769 .36944 Metetra
.381 .194 .498 r
.72769 .36944 .72615 .33244 .73184 .32011 .73096 .31893 Metetra
.664 .741 .907 r
.73096 .31893 .73184 .32011 .74067 .35448 .73732 .31682 Metetra
.558 .351 .556 r
.73732 .31682 .74067 .35448 .74456 .31588 .74369 .31469 Metetra
.664 .741 .907 r
.74369 .31469 .74456 .31588 .75094 .31376 .75008 .31257 Metetra
.664 .741 .907 r
.75008 .31257 .75094 .31376 .75734 .31163 .75648 .31044 Metetra
.664 .741 .907 r
.75648 .31044 .75734 .31163 .76375 .3095 .7629 .3083 Metetra
.664 .741 .907 r
.7629 .3083 .76375 .3095 .77018 .30736 .76933 .30617 Metetra
.664 .741 .907 r
.76933 .30617 .77018 .30736 .77662 .30522 .77577 .30402 Metetra
.664 .741 .907 r
.77577 .30402 .77662 .30522 .78308 .30307 .78223 .30187 Metetra
.664 .741 .907 r
.78223 .30187 .78308 .30307 .78955 .30092 .7887 .29972 Metetra
.664 .741 .907 r
.7887 .29972 .78955 .30092 .79603 .29876 .79519 .29756 Metetra
.664 .741 .907 r
.79519 .29756 .79603 .29876 .80253 .2966 .80169 .29539 Metetra
.664 .741 .907 r
.80169 .29539 .80253 .2966 .80904 .29444 .80821 .29323 Metetra
.664 .741 .907 r
.80821 .29323 .80904 .29444 .81557 .29227 .81474 .29105 Metetra
.664 .741 .907 r
.81474 .29105 .81557 .29227 .82211 .29009 .82128 .28887 Metetra
.664 .741 .907 r
.82128 .28887 .82211 .29009 .82867 .28791 .82785 .28669 Metetra
.664 .741 .907 r
.82785 .28669 .82867 .28791 .83525 .28572 .83442 .2845 Metetra
.664 .741 .907 r
.83442 .2845 .83525 .28572 .84183 .28353 .84101 .28231 Metetra
.664 .741 .907 r
.84101 .28231 .84183 .28353 .84844 .28134 .84762 .28011 Metetra
.664 .741 .907 r
.84762 .28011 .84844 .28134 .85505 .27914 .85424 .27791 Metetra
.664 .741 .907 r
.85424 .27791 .85505 .27914 .86169 .27693 .86088 .2757 Metetra
.664 .741 .907 r
.86088 .2757 .86169 .27693 .86833 .27472 .86753 .27349 Metetra
.664 .741 .907 r
.26872 .4714 .26979 .4724 .27516 .47061 .27409 .46961 Metetra
.664 .741 .907 r
.27409 .46961 .27516 .47061 .28054 .46882 .27948 .46782 Metetra
.664 .741 .907 r
.27948 .46782 .28054 .46882 .28594 .46703 .28487 .46602 Metetra
0 .406 .852 r
.28487 .46602 .28594 .46703 .29134 .46523 .28997 .46857 Metetra
.805 .504 .481 r
.28997 .46857 .29134 .46523 .29605 .47354 .29379 .48984 Metetra
.22 .029 .396 r
.29379 .48984 .29605 .47354 .30218 .46162 .30113 .46061 Metetra
.664 .741 .907 r
.30113 .46061 .30218 .46162 .30762 .45981 .30657 .4588 Metetra
.664 .741 .907 r
.30657 .4588 .30762 .45981 .31307 .458 .31202 .45698 Metetra
.664 .741 .907 r
.31202 .45698 .31307 .458 .31853 .45618 .31748 .45516 Metetra
.664 .741 .907 r
.31748 .45516 .31853 .45618 .324 .45436 .32295 .45334 Metetra
.664 .741 .907 r
.32295 .45334 .324 .45436 .32948 .45253 .32844 .45151 Metetra
.664 .741 .907 r
.32844 .45151 .32948 .45253 .33498 .45071 .33394 .44968 Metetra
.664 .741 .907 r
.33394 .44968 .33498 .45071 .34048 .44887 .33944 .44785 Metetra
.664 .741 .907 r
.33944 .44785 .34048 .44887 .346 .44704 .34496 .44601 Metetra
.664 .741 .907 r
.34496 .44601 .346 .44704 .35153 .4452 .35049 .44417 Metetra
.664 .741 .907 r
.35049 .44417 .35153 .4452 .35707 .44335 .35604 .44232 Metetra
.664 .741 .907 r
.35604 .44232 .35707 .44335 .36262 .44151 .36159 .44047 Metetra
.664 .741 .907 r
.36159 .44047 .36262 .44151 .36819 .43966 .36716 .43862 Metetra
.951 .67 .469 r
.36716 .43862 .36819 .43966 .36807 .56065 .36819 .53407 Metetra
.539 .341 .56 r
.36819 .53407 .36807 .56065 .37089 .62522 .37372 .53724 Metetra
.661 .429 .558 r
.37372 .53724 .37089 .62522 .38495 .43408 .38392 .43304 Metetra
.664 .741 .907 r
.38392 .43304 .38495 .43408 .39056 .43221 .38953 .43117 Metetra
.664 .741 .907 r
.38953 .43117 .39056 .43221 .39618 .43034 .39516 .4293 Metetra
.664 .741 .907 r
.39516 .4293 .39618 .43034 .40181 .42847 .40079 .42742 Metetra
.664 .741 .907 r
.40079 .42742 .40181 .42847 .40746 .42659 .40644 .42554 Metetra
.664 .741 .907 r
.40644 .42554 .40746 .42659 .41311 .4247 .4121 .42365 Metetra
.664 .741 .907 r
.4121 .42365 .41311 .4247 .41878 .42282 .41777 .42176 Metetra
.664 .741 .907 r
.41777 .42176 .41878 .42282 .42446 .42093 .42346 .41987 Metetra
.664 .741 .907 r
.42346 .41987 .42446 .42093 .43016 .41903 .42915 .41797 Metetra
.664 .741 .907 r
.42915 .41797 .43016 .41903 .43586 .41713 .43486 .41607 Metetra
.664 .741 .907 r
.43486 .41607 .43586 .41713 .44158 .41523 .44058 .41417 Metetra
.664 .741 .907 r
.44058 .41417 .44158 .41523 .44731 .41333 .44631 .41226 Metetra
.664 .741 .907 r
.44631 .41226 .44731 .41333 .45305 .41141 .45205 .41035 Metetra
.664 .741 .907 r
.45205 .41035 .45305 .41141 .4588 .4095 .45781 .40843 Metetra
.664 .741 .907 r
.45781 .40843 .4588 .4095 .46457 .40758 .46358 .40651 Metetra
.664 .741 .907 r
.46358 .40651 .46457 .40758 .47035 .40566 .46936 .40458 Metetra
.664 .741 .907 r
.46936 .40458 .47035 .40566 .47614 .40373 .47515 .40266 Metetra
.664 .741 .907 r
.47515 .40266 .47614 .40373 .48194 .4018 .48095 .40072 Metetra
.664 .741 .907 r
.48095 .40072 .48194 .4018 .48775 .39987 .48677 .39878 Metetra
.664 .741 .907 r
.48677 .39878 .48775 .39987 .49358 .39793 .4926 .39684 Metetra
.664 .741 .907 r
.4926 .39684 .49358 .39793 .49942 .39598 .49844 .3949 Metetra
.664 .741 .907 r
.49844 .3949 .49942 .39598 .50527 .39404 .5043 .39295 Metetra
.664 .741 .907 r
.5043 .39295 .50527 .39404 .51114 .39208 .51017 .39099 Metetra
.664 .741 .907 r
.51017 .39099 .51114 .39208 .51701 .39013 .51604 .38904 Metetra
.664 .741 .907 r
.51604 .38904 .51701 .39013 .5229 .38817 .52194 .38707 Metetra
.664 .741 .907 r
.52194 .38707 .5229 .38817 .52881 .3862 .52784 .38511 Metetra
.664 .741 .907 r
.52784 .38511 .52881 .3862 .53472 .38424 .53376 .38314 Metetra
.664 .741 .907 r
.53376 .38314 .53472 .38424 .54065 .38226 .53969 .38116 Metetra
.925 .539 .171 r
.53969 .38116 .54065 .38226 .54674 .403 .54578 .40118 Metetra
.82 .696 .728 r
.54578 .40118 .54674 .403 .55286 .41497 .55172 .39257 Metetra
.627 .411 .57 r
.55172 .39257 .55286 .41497 .55851 .37632 .55756 .37521 Metetra
.664 .741 .907 r
.55756 .37521 .55851 .37632 .56449 .37433 .56354 .37322 Metetra
.664 .741 .907 r
.56354 .37322 .56449 .37433 .57048 .37234 .56954 .37122 Metetra
.664 .741 .907 r
.56954 .37122 .57048 .37234 .57649 .37034 .57554 .36922 Metetra
.664 .741 .907 r
.57554 .36922 .57649 .37034 .58251 .36833 .58156 .36722 Metetra
.664 .741 .907 r
.58156 .36722 .58251 .36833 .58854 .36633 .5876 .36521 Metetra
.664 .741 .907 r
.5876 .36521 .58854 .36633 .59458 .36432 .59365 .36319 Metetra
.664 .741 .907 r
.59365 .36319 .59458 .36432 .60064 .3623 .59971 .36117 Metetra
.664 .741 .907 r
.59971 .36117 .60064 .3623 .60671 .36028 .60578 .35915 Metetra
.664 .741 .907 r
.60578 .35915 .60671 .36028 .61279 .35826 .61187 .35712 Metetra
.664 .741 .907 r
.61187 .35712 .61279 .35826 .61889 .35623 .61797 .35509 Metetra
.664 .741 .907 r
.61797 .35509 .61889 .35623 .625 .35419 .62408 .35306 Metetra
.664 .741 .907 r
.62408 .35306 .625 .35419 .63113 .35215 .63021 .35102 Metetra
.664 .741 .907 r
.63021 .35102 .63113 .35215 .63726 .35011 .63635 .34897 Metetra
.664 .741 .907 r
.63635 .34897 .63726 .35011 .64341 .34807 .6425 .34692 Metetra
.664 .741 .907 r
.6425 .34692 .64341 .34807 .64958 .34601 .64867 .34487 Metetra
.664 .741 .907 r
.64867 .34487 .64958 .34601 .65576 .34396 .65485 .34281 Metetra
.664 .741 .907 r
.65485 .34281 .65576 .34396 .66195 .3419 .66104 .34075 Metetra
.664 .741 .907 r
.66104 .34075 .66195 .3419 .66815 .33983 .66725 .33868 Metetra
.664 .741 .907 r
.66725 .33868 .66815 .33983 .67437 .33776 .67347 .33661 Metetra
.664 .741 .907 r
.67347 .33661 .67437 .33776 .6806 .33569 .67971 .33453 Metetra
.664 .741 .907 r
.67971 .33453 .6806 .33569 .68685 .33361 .68596 .33245 Metetra
.664 .741 .907 r
.68596 .33245 .68685 .33361 .69311 .33153 .69222 .33036 Metetra
.664 .741 .907 r
.69222 .33036 .69311 .33153 .69938 .32944 .6985 .32827 Metetra
.664 .741 .907 r
.6985 .32827 .69938 .32944 .70567 .32735 .70479 .32618 Metetra
.664 .741 .907 r
.70479 .32618 .70567 .32735 .71197 .32525 .71109 .32408 Metetra
.664 .741 .907 r
.71109 .32408 .71197 .32525 .71829 .32315 .71741 .32197 Metetra
.949 .597 .224 r
.71741 .32197 .71829 .32315 .72769 .36944 .72663 .36554 Metetra
.924 .669 .534 r
.72663 .36554 .72769 .36944 .73096 .31893 .73009 .31775 Metetra
.664 .741 .907 r
.73009 .31775 .73096 .31893 .73732 .31682 .73645 .31563 Metetra
.664 .741 .907 r
.73645 .31563 .73732 .31682 .74369 .31469 .74283 .31351 Metetra
.664 .741 .907 r
.74283 .31351 .74369 .31469 .75008 .31257 .74922 .31138 Metetra
.664 .741 .907 r
.74922 .31138 .75008 .31257 .75648 .31044 .75562 .30925 Metetra
.664 .741 .907 r
.75562 .30925 .75648 .31044 .7629 .3083 .76204 .30711 Metetra
.664 .741 .907 r
.76204 .30711 .7629 .3083 .76933 .30617 .76847 .30497 Metetra
.664 .741 .907 r
.76847 .30497 .76933 .30617 .77577 .30402 .77492 .30282 Metetra
.664 .741 .907 r
.77492 .30282 .77577 .30402 .78223 .30187 .78138 .30067 Metetra
.664 .741 .907 r
.78138 .30067 .78223 .30187 .7887 .29972 .78785 .29851 Metetra
.664 .741 .907 r
.78785 .29851 .7887 .29972 .79519 .29756 .79434 .29635 Metetra
.664 .741 .907 r
.79434 .29635 .79519 .29756 .80169 .29539 .80085 .29419 Metetra
.664 .741 .907 r
.80085 .29419 .80169 .29539 .80821 .29323 .80737 .29201 Metetra
.664 .741 .907 r
.80737 .29201 .80821 .29323 .81474 .29105 .8139 .28984 Metetra
.664 .741 .907 r
.8139 .28984 .81474 .29105 .82128 .28887 .82045 .28766 Metetra
.664 .741 .907 r
.82045 .28766 .82128 .28887 .82785 .28669 .82702 .28547 Metetra
.664 .741 .907 r
.82702 .28547 .82785 .28669 .83442 .2845 .8336 .28328 Metetra
.664 .741 .907 r
.8336 .28328 .83442 .2845 .84101 .28231 .84019 .28108 Metetra
.664 .741 .907 r
.84019 .28108 .84101 .28231 .84762 .28011 .8468 .27888 Metetra
.664 .741 .907 r
.8468 .27888 .84762 .28011 .85424 .27791 .85342 .27668 Metetra
.664 .741 .907 r
.85342 .27668 .85424 .27791 .86088 .2757 .86006 .27447 Metetra
.664 .741 .907 r
.86006 .27447 .86088 .2757 .86753 .27349 .86672 .27225 Metetra
.664 .741 .907 r
.26765 .47041 .26872 .4714 .27409 .46961 .27303 .46861 Metetra
.664 .741 .907 r
.27303 .46861 .27409 .46961 .27948 .46782 .27841 .46682 Metetra
.664 .741 .907 r
.27841 .46682 .27948 .46782 .28487 .46602 .28381 .46502 Metetra
.943 .607 .36 r
.28381 .46502 .28487 .46602 .28997 .46857 .28751 .48706 Metetra
.317 .113 .437 r
.28751 .48706 .28997 .46857 .29379 .48984 .29464 .46141 Metetra
.56 .356 .561 r
.29464 .46141 .29379 .48984 .30113 .46061 .30007 .4596 Metetra
.664 .741 .907 r
.30007 .4596 .30113 .46061 .30657 .4588 .30551 .45779 Metetra
.664 .741 .907 r
.30551 .45779 .30657 .4588 .31202 .45698 .31097 .45597 Metetra
.664 .741 .907 r
.31097 .45597 .31202 .45698 .31748 .45516 .31643 .45415 Metetra
.664 .741 .907 r
.31643 .45415 .31748 .45516 .32295 .45334 .32191 .45232 Metetra
.664 .741 .907 r
.32191 .45232 .32295 .45334 .32844 .45151 .32739 .45049 Metetra
.664 .741 .907 r
.32739 .45049 .32844 .45151 .33394 .44968 .33289 .44866 Metetra
.664 .741 .907 r
.33289 .44866 .33394 .44968 .33944 .44785 .3384 .44683 Metetra
.664 .741 .907 r
.3384 .44683 .33944 .44785 .34496 .44601 .34392 .44498 Metetra
.664 .741 .907 r
.34392 .44498 .34496 .44601 .35049 .44417 .34946 .44314 Metetra
.664 .741 .907 r
.34946 .44314 .35049 .44417 .35604 .44232 .355 .44129 Metetra
.664 .741 .907 r
.355 .44129 .35604 .44232 .36159 .44047 .36056 .43944 Metetra
.664 .741 .907 r
.36056 .43944 .36159 .44047 .36716 .43862 .36612 .43759 Metetra
.941 .582 .291 r
.36612 .43759 .36716 .43862 .36819 .53407 .37068 .45742 Metetra
.451 .259 .527 r
.37068 .45742 .36819 .53407 .37372 .53724 .37365 .51435 Metetra
.774 .533 .571 r
.37365 .51435 .37372 .53724 .38392 .43304 .3829 .432 Metetra
.664 .741 .907 r
.3829 .432 .38392 .43304 .38953 .43117 .38851 .43012 Metetra
.664 .741 .907 r
.38851 .43012 .38953 .43117 .39516 .4293 .39414 .42825 Metetra
.664 .741 .907 r
.39414 .42825 .39516 .4293 .40079 .42742 .39978 .42637 Metetra
.664 .741 .907 r
.39978 .42637 .40079 .42742 .40644 .42554 .40543 .42449 Metetra
.664 .741 .907 r
.40543 .42449 .40644 .42554 .4121 .42365 .41109 .4226 Metetra
.664 .741 .907 r
.41109 .4226 .4121 .42365 .41777 .42176 .41676 .42071 Metetra
.664 .741 .907 r
.41676 .42071 .41777 .42176 .42346 .41987 .42245 .41881 Metetra
.664 .741 .907 r
.42245 .41881 .42346 .41987 .42915 .41797 .42814 .41691 Metetra
.664 .741 .907 r
.42814 .41691 .42915 .41797 .43486 .41607 .43385 .41501 Metetra
.664 .741 .907 r
.43385 .41501 .43486 .41607 .44058 .41417 .43958 .4131 Metetra
.664 .741 .907 r
.43958 .4131 .44058 .41417 .44631 .41226 .44531 .41119 Metetra
.664 .741 .907 r
.44531 .41119 .44631 .41226 .45205 .41035 .45106 .40928 Metetra
.664 .741 .907 r
.45106 .40928 .45205 .41035 .45781 .40843 .45681 .40736 Metetra
.664 .741 .907 r
.45681 .40736 .45781 .40843 .46358 .40651 .46258 .40544 Metetra
.664 .741 .907 r
.46258 .40544 .46358 .40651 .46936 .40458 .46837 .40351 Metetra
.664 .741 .907 r
.46837 .40351 .46936 .40458 .47515 .40266 .47416 .40158 Metetra
.664 .741 .907 r
.47416 .40158 .47515 .40266 .48095 .40072 .47997 .39964 Metetra
.664 .741 .907 r
.47997 .39964 .48095 .40072 .48677 .39878 .48579 .3977 Metetra
.664 .741 .907 r
.48579 .3977 .48677 .39878 .4926 .39684 .49162 .39576 Metetra
.664 .741 .907 r
.49162 .39576 .4926 .39684 .49844 .3949 .49747 .39381 Metetra
.664 .741 .907 r
.49747 .39381 .49844 .3949 .5043 .39295 .50332 .39186 Metetra
.664 .741 .907 r
.50332 .39186 .5043 .39295 .51017 .39099 .50919 .3899 Metetra
.664 .741 .907 r
.50919 .3899 .51017 .39099 .51604 .38904 .51507 .38794 Metetra
.664 .741 .907 r
.51507 .38794 .51604 .38904 .52194 .38707 .52097 .38598 Metetra
.664 .741 .907 r
.52097 .38598 .52194 .38707 .52784 .38511 .52688 .38401 Metetra
.664 .741 .907 r
.52688 .38401 .52784 .38511 .53376 .38314 .5328 .38203 Metetra
.664 .741 .907 r
.5328 .38203 .53376 .38314 .53969 .38116 .53873 .38006 Metetra
.664 .741 .907 r
.53873 .38006 .53969 .38116 .54578 .40118 .54468 .37808 Metetra
.562 .361 .566 r
.54468 .37808 .54578 .40118 .55172 .39257 .55063 .37609 Metetra
.567 .373 .577 r
.55063 .37609 .55172 .39257 .55756 .37521 .55661 .3741 Metetra
.664 .741 .907 r
.55661 .3741 .55756 .37521 .56354 .37322 .56259 .3721 Metetra
.664 .741 .907 r
.56259 .3721 .56354 .37322 .56954 .37122 .56859 .37011 Metetra
.664 .741 .907 r
.56859 .37011 .56954 .37122 .57554 .36922 .5746 .3681 Metetra
.664 .741 .907 r
.5746 .3681 .57554 .36922 .58156 .36722 .58062 .3661 Metetra
.664 .741 .907 r
.58062 .3661 .58156 .36722 .5876 .36521 .58666 .36408 Metetra
.664 .741 .907 r
.58666 .36408 .5876 .36521 .59365 .36319 .59271 .36207 Metetra
.664 .741 .907 r
.59271 .36207 .59365 .36319 .59971 .36117 .59877 .36005 Metetra
.664 .741 .907 r
.59877 .36005 .59971 .36117 .60578 .35915 .60485 .35802 Metetra
.664 .741 .907 r
.60485 .35802 .60578 .35915 .61187 .35712 .61094 .35599 Metetra
.664 .741 .907 r
.61094 .35599 .61187 .35712 .61797 .35509 .61704 .35396 Metetra
.664 .741 .907 r
.61704 .35396 .61797 .35509 .62408 .35306 .62316 .35192 Metetra
.664 .741 .907 r
.62316 .35192 .62408 .35306 .63021 .35102 .62929 .34988 Metetra
.664 .741 .907 r
.62929 .34988 .63021 .35102 .63635 .34897 .63543 .34783 Metetra
.664 .741 .907 r
.63543 .34783 .63635 .34897 .6425 .34692 .64158 .34578 Metetra
.664 .741 .907 r
.64158 .34578 .6425 .34692 .64867 .34487 .64775 .34372 Metetra
.664 .741 .907 r
.64775 .34372 .64867 .34487 .65485 .34281 .65394 .34166 Metetra
.664 .741 .907 r
.65394 .34166 .65485 .34281 .66104 .34075 .66013 .33959 Metetra
.664 .741 .907 r
.66013 .33959 .66104 .34075 .66725 .33868 .66635 .33752 Metetra
.664 .741 .907 r
.66635 .33752 .66725 .33868 .67347 .33661 .67257 .33545 Metetra
.664 .741 .907 r
.67257 .33545 .67347 .33661 .67971 .33453 .67881 .33337 Metetra
.664 .741 .907 r
.67881 .33337 .67971 .33453 .68596 .33245 .68506 .33129 Metetra
.664 .741 .907 r
.68506 .33129 .68596 .33245 .69222 .33036 .69133 .3292 Metetra
.664 .741 .907 r
.69133 .3292 .69222 .33036 .6985 .32827 .69761 .32711 Metetra
.664 .741 .907 r
.69761 .32711 .6985 .32827 .70479 .32618 .7039 .32501 Metetra
.664 .741 .907 r
.7039 .32501 .70479 .32618 .71109 .32408 .71021 .32291 Metetra
.664 .741 .907 r
.71021 .32291 .71109 .32408 .71741 .32197 .71653 .3208 Metetra
.664 .741 .907 r
.71653 .3208 .71741 .32197 .72663 .36554 .72286 .31869 Metetra
.556 .347 .552 r
.72286 .31869 .72663 .36554 .73009 .31775 .72921 .31657 Metetra
.664 .741 .907 r
.72921 .31657 .73009 .31775 .73645 .31563 .73558 .31445 Metetra
.664 .741 .907 r
.73558 .31445 .73645 .31563 .74283 .31351 .74196 .31232 Metetra
.664 .741 .907 r
.74196 .31232 .74283 .31351 .74922 .31138 .74835 .31019 Metetra
.664 .741 .907 r
.74835 .31019 .74922 .31138 .75562 .30925 .75476 .30806 Metetra
.664 .741 .907 r
.75476 .30806 .75562 .30925 .76204 .30711 .76118 .30592 Metetra
.664 .741 .907 r
.76118 .30592 .76204 .30711 .76847 .30497 .76761 .30377 Metetra
.664 .741 .907 r
.76761 .30377 .76847 .30497 .77492 .30282 .77406 .30162 Metetra
.664 .741 .907 r
.77406 .30162 .77492 .30282 .78138 .30067 .78053 .29947 Metetra
.664 .741 .907 r
.78053 .29947 .78138 .30067 .78785 .29851 .78701 .29731 Metetra
.664 .741 .907 r
.78701 .29731 .78785 .29851 .79434 .29635 .7935 .29514 Metetra
.664 .741 .907 r
.7935 .29514 .79434 .29635 .80085 .29419 .80001 .29298 Metetra
.664 .741 .907 r
.80001 .29298 .80085 .29419 .80737 .29201 .80653 .2908 Metetra
.664 .741 .907 r
.80653 .2908 .80737 .29201 .8139 .28984 .81307 .28862 Metetra
.664 .741 .907 r
.81307 .28862 .8139 .28984 .82045 .28766 .81962 .28644 Metetra
.664 .741 .907 r
.81962 .28644 .82045 .28766 .82702 .28547 .82619 .28425 Metetra
.664 .741 .907 r
.82619 .28425 .82702 .28547 .8336 .28328 .83277 .28206 Metetra
.664 .741 .907 r
.83277 .28206 .8336 .28328 .84019 .28108 .83937 .27986 Metetra
.664 .741 .907 r
.83937 .27986 .84019 .28108 .8468 .27888 .84598 .27765 Metetra
.664 .741 .907 r
.84598 .27765 .8468 .27888 .85342 .27668 .85261 .27544 Metetra
.664 .741 .907 r
.85261 .27544 .85342 .27668 .86006 .27447 .85925 .27323 Metetra
.664 .741 .907 r
.85925 .27323 .86006 .27447 .86672 .27225 .86591 .27101 Metetra
.664 .741 .907 r
.26658 .46941 .26765 .47041 .27303 .46861 .27196 .46761 Metetra
.664 .741 .907 r
.27196 .46761 .27303 .46861 .27841 .46682 .27735 .46582 Metetra
.664 .741 .907 r
.27735 .46582 .27841 .46682 .28381 .46502 .28275 .46401 Metetra
.945 .657 .464 r
.28275 .46401 .28381 .46502 .28751 .48706 .28425 .51652 Metetra
.185 .016 .404 r
.28425 .51652 .28751 .48706 .29464 .46141 .29358 .4604 Metetra
.664 .741 .907 r
.29358 .4604 .29464 .46141 .30007 .4596 .29901 .45859 Metetra
0 .338 .804 r
.29901 .45859 .30007 .4596 .30551 .45779 .30414 .46157 Metetra
.217 0 .236 r
.30414 .46157 .30551 .45779 .31097 .45597 .30991 .45495 Metetra
.664 .741 .907 r
.30991 .45495 .31097 .45597 .31643 .45415 .31538 .45313 Metetra
.664 .741 .907 r
.31538 .45313 .31643 .45415 .32191 .45232 .32086 .4513 Metetra
.664 .741 .907 r
.32086 .4513 .32191 .45232 .32739 .45049 .32635 .44947 Metetra
.664 .741 .907 r
.32635 .44947 .32739 .45049 .33289 .44866 .33185 .44764 Metetra
.664 .741 .907 r
.33185 .44764 .33289 .44866 .3384 .44683 .33736 .4458 Metetra
.664 .741 .907 r
.33736 .4458 .3384 .44683 .34392 .44498 .34288 .44396 Metetra
.664 .741 .907 r
.34288 .44396 .34392 .44498 .34946 .44314 .34842 .44211 Metetra
.664 .741 .907 r
.34842 .44211 .34946 .44314 .355 .44129 .35396 .44026 Metetra
.664 .741 .907 r
.35396 .44026 .355 .44129 .36056 .43944 .35952 .43841 Metetra
.664 .741 .907 r
.35952 .43841 .36056 .43944 .36612 .43759 .36509 .43655 Metetra
.664 .741 .907 r
.36509 .43655 .36612 .43759 .37068 .45742 .37067 .43469 Metetra
.519 .327 .56 r
.37067 .43469 .37068 .45742 .37365 .51435 .37589 .44106 Metetra
.566 .352 .548 r
.37589 .44106 .37365 .51435 .3829 .432 .38187 .43095 Metetra
.664 .741 .907 r
.38187 .43095 .3829 .432 .38851 .43012 .38749 .42908 Metetra
.857 .412 .009 r
.38749 .42908 .38851 .43012 .39414 .42825 .39262 .43955 Metetra
.688 .42 .511 r
.39262 .43955 .39414 .42825 .39978 .42637 .39738 .46072 Metetra
.393 .191 .484 r
.39738 .46072 .39978 .42637 .40543 .42449 .40441 .42343 Metetra
.664 .741 .907 r
.40441 .42343 .40543 .42449 .41109 .4226 .41007 .42155 Metetra
.664 .741 .907 r
.41007 .42155 .41109 .4226 .41676 .42071 .41575 .41965 Metetra
.664 .741 .907 r
.41575 .41965 .41676 .42071 .42245 .41881 .42144 .41776 Metetra
.664 .741 .907 r
.42144 .41776 .42245 .41881 .42814 .41691 .42714 .41585 Metetra
.664 .741 .907 r
.42714 .41585 .42814 .41691 .43385 .41501 .43285 .41395 Metetra
.664 .741 .907 r
.43285 .41395 .43385 .41501 .43958 .4131 .43857 .41204 Metetra
.664 .741 .907 r
.43857 .41204 .43958 .4131 .44531 .41119 .44431 .41013 Metetra
.664 .741 .907 r
.44431 .41013 .44531 .41119 .45106 .40928 .45006 .40821 Metetra
.664 .741 .907 r
.45006 .40821 .45106 .40928 .45681 .40736 .45582 .40629 Metetra
.664 .741 .907 r
.45582 .40629 .45681 .40736 .46258 .40544 .46159 .40436 Metetra
.664 .741 .907 r
.46159 .40436 .46258 .40544 .46837 .40351 .46738 .40243 Metetra
.664 .741 .907 r
.46738 .40243 .46837 .40351 .47416 .40158 .47317 .4005 Metetra
.664 .741 .907 r
.47317 .4005 .47416 .40158 .47997 .39964 .47898 .39856 Metetra
.664 .741 .907 r
.47898 .39856 .47997 .39964 .48579 .3977 .4848 .39662 Metetra
.664 .741 .907 r
.4848 .39662 .48579 .3977 .49162 .39576 .49064 .39467 Metetra
.664 .741 .907 r
.49064 .39467 .49162 .39576 .49747 .39381 .49649 .39272 Metetra
.664 .741 .907 r
.49649 .39272 .49747 .39381 .50332 .39186 .50235 .39077 Metetra
.664 .741 .907 r
.50235 .39077 .50332 .39186 .50919 .3899 .50822 .38881 Metetra
.664 .741 .907 r
.50822 .38881 .50919 .3899 .51507 .38794 .5141 .38685 Metetra
.664 .741 .907 r
.5141 .38685 .51507 .38794 .52097 .38598 .52 .38488 Metetra
.664 .741 .907 r
.52 .38488 .52097 .38598 .52688 .38401 .52591 .38291 Metetra
.664 .741 .907 r
.52591 .38291 .52688 .38401 .5328 .38203 .53183 .38093 Metetra
.664 .741 .907 r
.53183 .38093 .5328 .38203 .53873 .38006 .53777 .37895 Metetra
.664 .741 .907 r
.53777 .37895 .53873 .38006 .54468 .37808 .54372 .37697 Metetra
.664 .741 .907 r
.54372 .37697 .54468 .37808 .55063 .37609 .54968 .37498 Metetra
.664 .741 .907 r
.54968 .37498 .55063 .37609 .55661 .3741 .55565 .37299 Metetra
.664 .741 .907 r
.55565 .37299 .55661 .3741 .56259 .3721 .56164 .37099 Metetra
.664 .741 .907 r
.56164 .37099 .56259 .3721 .56859 .37011 .56764 .36899 Metetra
.664 .741 .907 r
.56764 .36899 .56859 .37011 .5746 .3681 .57365 .36698 Metetra
.664 .741 .907 r
.57365 .36698 .5746 .3681 .58062 .3661 .57968 .36497 Metetra
.664 .741 .907 r
.57968 .36497 .58062 .3661 .58666 .36408 .58572 .36296 Metetra
.961 .628 .317 r
.58572 .36296 .58666 .36408 .59271 .36207 .59277 .40863 Metetra
.413 .216 .502 r
.59277 .40863 .59271 .36207 .59877 .36005 .59784 .35892 Metetra
.664 .741 .907 r
.59784 .35892 .59877 .36005 .60485 .35802 .60391 .35689 Metetra
.664 .741 .907 r
.60391 .35689 .60485 .35802 .61094 .35599 .61001 .35486 Metetra
.664 .741 .907 r
.61001 .35486 .61094 .35599 .61704 .35396 .61611 .35282 Metetra
.664 .741 .907 r
.61611 .35282 .61704 .35396 .62316 .35192 .62223 .35078 Metetra
.664 .741 .907 r
.62223 .35078 .62316 .35192 .62929 .34988 .62836 .34873 Metetra
.664 .741 .907 r
.62836 .34873 .62929 .34988 .63543 .34783 .63451 .34668 Metetra
.664 .741 .907 r
.63451 .34668 .63543 .34783 .64158 .34578 .64067 .34463 Metetra
.664 .741 .907 r
.64067 .34463 .64158 .34578 .64775 .34372 .64684 .34257 Metetra
.664 .741 .907 r
.64684 .34257 .64775 .34372 .65394 .34166 .65303 .34051 Metetra
.664 .741 .907 r
.65303 .34051 .65394 .34166 .66013 .33959 .65923 .33844 Metetra
.664 .741 .907 r
.65923 .33844 .66013 .33959 .66635 .33752 .66544 .33637 Metetra
.664 .741 .907 r
.66544 .33637 .66635 .33752 .67257 .33545 .67167 .33429 Metetra
.664 .741 .907 r
.67167 .33429 .67257 .33545 .67881 .33337 .67791 .33221 Metetra
.664 .741 .907 r
.67791 .33221 .67881 .33337 .68506 .33129 .68416 .33012 Metetra
.664 .741 .907 r
.68416 .33012 .68506 .33129 .69133 .3292 .69043 .32803 Metetra
.664 .741 .907 r
.69043 .32803 .69133 .3292 .69761 .32711 .69671 .32594 Metetra
.664 .741 .907 r
.69671 .32594 .69761 .32711 .7039 .32501 .70301 .32384 Metetra
.664 .741 .907 r
.70301 .32384 .7039 .32501 .71021 .32291 .70932 .32173 Metetra
.664 .741 .907 r
.70932 .32173 .71021 .32291 .71653 .3208 .71565 .31962 Metetra
.664 .741 .907 r
.71565 .31962 .71653 .3208 .72286 .31869 .72198 .31751 Metetra
.664 .741 .907 r
.72198 .31751 .72286 .31869 .72921 .31657 .72834 .31539 Metetra
.664 .741 .907 r
.72834 .31539 .72921 .31657 .73558 .31445 .7347 .31326 Metetra
.664 .741 .907 r
.7347 .31326 .73558 .31445 .74196 .31232 .74109 .31114 Metetra
.664 .741 .907 r
.74109 .31114 .74196 .31232 .74835 .31019 .74748 .309 Metetra
.664 .741 .907 r
.74748 .309 .74835 .31019 .75476 .30806 .75389 .30686 Metetra
.664 .741 .907 r
.75389 .30686 .75476 .30806 .76118 .30592 .76032 .30472 Metetra
.664 .741 .907 r
.76032 .30472 .76118 .30592 .76761 .30377 .76675 .30257 Metetra
.664 .741 .907 r
.76675 .30257 .76761 .30377 .77406 .30162 .77321 .30042 Metetra
.664 .741 .907 r
.77321 .30042 .77406 .30162 .78053 .29947 .77967 .29826 Metetra
.664 .741 .907 r
.77967 .29826 .78053 .29947 .78701 .29731 .78616 .2961 Metetra
.664 .741 .907 r
.78616 .2961 .78701 .29731 .7935 .29514 .79265 .29394 Metetra
.664 .741 .907 r
.79265 .29394 .7935 .29514 .80001 .29298 .79916 .29176 Metetra
0 0 .479 r
.79916 .29176 .80001 .29298 .80653 .2908 .80677 .3016 Metetra
.39 .17 .455 r
.80677 .3016 .80653 .2908 .81307 .28862 .81223 .28741 Metetra
.664 .741 .907 r
.81223 .28741 .81307 .28862 .81962 .28644 .81879 .28522 Metetra
.664 .741 .907 r
.81879 .28522 .81962 .28644 .82619 .28425 .82536 .28303 Metetra
.664 .741 .907 r
.82536 .28303 .82619 .28425 .83277 .28206 .83194 .28083 Metetra
.664 .741 .907 r
.83194 .28083 .83277 .28206 .83937 .27986 .83854 .27863 Metetra
.664 .741 .907 r
.83854 .27863 .83937 .27986 .84598 .27765 .84516 .27642 Metetra
.664 .741 .907 r
.84516 .27642 .84598 .27765 .85261 .27544 .85179 .27421 Metetra
.664 .741 .907 r
.85179 .27421 .85261 .27544 .85925 .27323 .85844 .27199 Metetra
.664 .741 .907 r
.85844 .27199 .85925 .27323 .86591 .27101 .8651 .26977 Metetra
.664 .741 .907 r
.26551 .46841 .26658 .46941 .27196 .46761 .27089 .46661 Metetra
.664 .741 .907 r
.27089 .46661 .27196 .46761 .27735 .46582 .27628 .46481 Metetra
.664 .741 .907 r
.27628 .46481 .27735 .46582 .28275 .46401 .28168 .46301 Metetra
.664 .741 .907 r
.28168 .46301 .28275 .46401 .28425 .51652 .2871 .4612 Metetra
.554 .344 .549 r
.2871 .4612 .28425 .51652 .29358 .4604 .29252 .45939 Metetra
.664 .741 .907 r
.29252 .45939 .29358 .4604 .29901 .45859 .29796 .45758 Metetra
.664 .741 .907 r
.29796 .45758 .29901 .45859 .30414 .46157 .3034 .45576 Metetra
.593 .439 .642 r
.3034 .45576 .30414 .46157 .30991 .45495 .30886 .45394 Metetra
.664 .741 .907 r
.30886 .45394 .30991 .45495 .31538 .45313 .31433 .45211 Metetra
.664 .741 .907 r
.31433 .45211 .31538 .45313 .32086 .4513 .31981 .45028 Metetra
.664 .741 .907 r
.31981 .45028 .32086 .4513 .32635 .44947 .3253 .44845 Metetra
.664 .741 .907 r
.3253 .44845 .32635 .44947 .33185 .44764 .3308 .44661 Metetra
.664 .741 .907 r
.3308 .44661 .33185 .44764 .33736 .4458 .33632 .44477 Metetra
.664 .741 .907 r
.33632 .44477 .33736 .4458 .34288 .44396 .34184 .44293 Metetra
.664 .741 .907 r
.34184 .44293 .34288 .44396 .34842 .44211 .34738 .44108 Metetra
.664 .741 .907 r
.34738 .44108 .34842 .44211 .35396 .44026 .35293 .43923 Metetra
.664 .741 .907 r
.35293 .43923 .35396 .44026 .35952 .43841 .35849 .43737 Metetra
.664 .741 .907 r
.35849 .43737 .35952 .43841 .36509 .43655 .36406 .43551 Metetra
.664 .741 .907 r
.36406 .43551 .36509 .43655 .37067 .43469 .36964 .43365 Metetra
.664 .741 .907 r
.36964 .43365 .37067 .43469 .37589 .44106 .37524 .43178 Metetra
.579 .401 .605 r
.37524 .43178 .37589 .44106 .38187 .43095 .38085 .42991 Metetra
.664 .741 .907 r
.38085 .42991 .38187 .43095 .38749 .42908 .38646 .42803 Metetra
.952 .679 .482 r
.38646 .42803 .38749 .42908 .39262 .43955 .38399 .62434 Metetra
.506 .294 .526 r
.38399 .62434 .39262 .43955 .39738 .46072 .39253 .55712 Metetra
.332 .152 .481 r
.39253 .55712 .39738 .46072 .40441 .42343 .40339 .42238 Metetra
.664 .741 .907 r
.40339 .42238 .40441 .42343 .41007 .42155 .40906 .42049 Metetra
.664 .741 .907 r
.40906 .42049 .41007 .42155 .41575 .41965 .41474 .41859 Metetra
.664 .741 .907 r
.41474 .41859 .41575 .41965 .42144 .41776 .42043 .4167 Metetra
.664 .741 .907 r
.42043 .4167 .42144 .41776 .42714 .41585 .42613 .41479 Metetra
.664 .741 .907 r
.42613 .41479 .42714 .41585 .43285 .41395 .43184 .41288 Metetra
.664 .741 .907 r
.43184 .41288 .43285 .41395 .43857 .41204 .43757 .41097 Metetra
.664 .741 .907 r
.43757 .41097 .43857 .41204 .44431 .41013 .44331 .40906 Metetra
.664 .741 .907 r
.44331 .40906 .44431 .41013 .45006 .40821 .44906 .40714 Metetra
.664 .741 .907 r
.44906 .40714 .45006 .40821 .45582 .40629 .45482 .40521 Metetra
.664 .741 .907 r
.45482 .40521 .45582 .40629 .46159 .40436 .4606 .40329 Metetra
.664 .741 .907 r
.4606 .40329 .46159 .40436 .46738 .40243 .46638 .40135 Metetra
.664 .741 .907 r
.46638 .40135 .46738 .40243 .47317 .4005 .47218 .39942 Metetra
.664 .741 .907 r
.47218 .39942 .47317 .4005 .47898 .39856 .47799 .39748 Metetra
.664 .741 .907 r
.47799 .39748 .47898 .39856 .4848 .39662 .48382 .39553 Metetra
.664 .741 .907 r
.48382 .39553 .4848 .39662 .49064 .39467 .48966 .39359 Metetra
.664 .741 .907 r
.48966 .39359 .49064 .39467 .49649 .39272 .49551 .39163 Metetra
.664 .741 .907 r
.49551 .39163 .49649 .39272 .50235 .39077 .50137 .38968 Metetra
.664 .741 .907 r
.50137 .38968 .50235 .39077 .50822 .38881 .50724 .38771 Metetra
.664 .741 .907 r
.50724 .38771 .50822 .38881 .5141 .38685 .51313 .38575 Metetra
.664 .741 .907 r
.51313 .38575 .5141 .38685 .52 .38488 .51903 .38378 Metetra
.664 .741 .907 r
.51903 .38378 .52 .38488 .52591 .38291 .52494 .38181 Metetra
.664 .741 .907 r
.52494 .38181 .52591 .38291 .53183 .38093 .53087 .37983 Metetra
.664 .741 .907 r
.53087 .37983 .53183 .38093 .53777 .37895 .53681 .37785 Metetra
.664 .741 .907 r
.53681 .37785 .53777 .37895 .54372 .37697 .54276 .37586 Metetra
.664 .741 .907 r
.54276 .37586 .54372 .37697 .54968 .37498 .54872 .37387 Metetra
.664 .741 .907 r
.54872 .37387 .54968 .37498 .55565 .37299 .5547 .37187 Metetra
.664 .741 .907 r
.5547 .37187 .55565 .37299 .56164 .37099 .56069 .36987 Metetra
.664 .741 .907 r
.56069 .36987 .56164 .37099 .56764 .36899 .56669 .36787 Metetra
.664 .741 .907 r
.56669 .36787 .56764 .36899 .57365 .36698 .5727 .36586 Metetra
.664 .741 .907 r
.5727 .36586 .57365 .36698 .57968 .36497 .57873 .36385 Metetra
.664 .741 .907 r
.57873 .36385 .57968 .36497 .58572 .36296 .58478 .36183 Metetra
.969 .671 .405 r
.58478 .36183 .58572 .36296 .59277 .40863 .59415 .52015 Metetra
.347 .173 .497 r
.59415 .52015 .59277 .40863 .59784 .35892 .5969 .35779 Metetra
.664 .741 .907 r
.5969 .35779 .59784 .35892 .60391 .35689 .60298 .35576 Metetra
.664 .741 .907 r
.60298 .35576 .60391 .35689 .61001 .35486 .60907 .35372 Metetra
.664 .741 .907 r
.60907 .35372 .61001 .35486 .61611 .35282 .61518 .35168 Metetra
.664 .741 .907 r
.61518 .35168 .61611 .35282 .62223 .35078 .6213 .34964 Metetra
.664 .741 .907 r
.6213 .34964 .62223 .35078 .62836 .34873 .62744 .34759 Metetra
.664 .741 .907 r
.62744 .34759 .62836 .34873 .63451 .34668 .63359 .34554 Metetra
.664 .741 .907 r
.63359 .34554 .63451 .34668 .64067 .34463 .63975 .34348 Metetra
.664 .741 .907 r
.63975 .34348 .64067 .34463 .64684 .34257 .64593 .34142 Metetra
.664 .741 .907 r
.64593 .34142 .64684 .34257 .65303 .34051 .65211 .33936 Metetra
.664 .741 .907 r
.65211 .33936 .65303 .34051 .65923 .33844 .65832 .33728 Metetra
.664 .741 .907 r
.65832 .33728 .65923 .33844 .66544 .33637 .66453 .33521 Metetra
.664 .741 .907 r
.66453 .33521 .66544 .33637 .67167 .33429 .67076 .33313 Metetra
.664 .741 .907 r
.67076 .33313 .67167 .33429 .67791 .33221 .67701 .33105 Metetra
.664 .741 .907 r
.67701 .33105 .67791 .33221 .68416 .33012 .68326 .32896 Metetra
.664 .741 .907 r
.68326 .32896 .68416 .33012 .69043 .32803 .68954 .32686 Metetra
.664 .741 .907 r
.68954 .32686 .69043 .32803 .69671 .32594 .69582 .32477 Metetra
.664 .741 .907 r
.69582 .32477 .69671 .32594 .70301 .32384 .70212 .32266 Metetra
.664 .741 .907 r
.70212 .32266 .70301 .32384 .70932 .32173 .70843 .32055 Metetra
.664 .741 .907 r
.70843 .32055 .70932 .32173 .71565 .31962 .71476 .31844 Metetra
.664 .741 .907 r
.71476 .31844 .71565 .31962 .72198 .31751 .7211 .31633 Metetra
.664 .741 .907 r
.7211 .31633 .72198 .31751 .72834 .31539 .72746 .3142 Metetra
.664 .741 .907 r
.72746 .3142 .72834 .31539 .7347 .31326 .73383 .31208 Metetra
.664 .741 .907 r
.73383 .31208 .7347 .31326 .74109 .31114 .74021 .30995 Metetra
.664 .741 .907 r
.74021 .30995 .74109 .31114 .74748 .309 .74661 .30781 Metetra
.664 .741 .907 r
.74661 .30781 .74748 .309 .75389 .30686 .75303 .30567 Metetra
.664 .741 .907 r
.75303 .30567 .75389 .30686 .76032 .30472 .75945 .30352 Metetra
.664 .741 .907 r
.75945 .30352 .76032 .30472 .76675 .30257 .76589 .30137 Metetra
.664 .741 .907 r
.76589 .30137 .76675 .30257 .77321 .30042 .77235 .29922 Metetra
.664 .741 .907 r
.77235 .29922 .77321 .30042 .77967 .29826 .77882 .29706 Metetra
.664 .741 .907 r
.77882 .29706 .77967 .29826 .78616 .2961 .78531 .29489 Metetra
.664 .741 .907 r
.78531 .29489 .78616 .2961 .79265 .29394 .79181 .29272 Metetra
.664 .741 .907 r
.79181 .29272 .79265 .29394 .79916 .29176 .79832 .29055 Metetra
.962 .631 .263 r
.79832 .29055 .79916 .29176 .80677 .3016 .81407 .39083 Metetra
.414 .228 .518 r
.81407 .39083 .80677 .3016 .81223 .28741 .81139 .28619 Metetra
.664 .741 .907 r
.81139 .28619 .81223 .28741 .81879 .28522 .81795 .284 Metetra
.664 .741 .907 r
.81795 .284 .81879 .28522 .82536 .28303 .82453 .2818 Metetra
.664 .741 .907 r
.82453 .2818 .82536 .28303 .83194 .28083 .83112 .2796 Metetra
.664 .741 .907 r
.83112 .2796 .83194 .28083 .83854 .27863 .83772 .2774 Metetra
.664 .741 .907 r
.83772 .2774 .83854 .27863 .84516 .27642 .84434 .27519 Metetra
.664 .741 .907 r
.84434 .27519 .84516 .27642 .85179 .27421 .85097 .27297 Metetra
.664 .741 .907 r
.85097 .27297 .85179 .27421 .85844 .27199 .85762 .27075 Metetra
.664 .741 .907 r
.85762 .27075 .85844 .27199 .8651 .26977 .86429 .26853 Metetra
.664 .741 .907 r
.26444 .46741 .26551 .46841 .27089 .46661 .26982 .46561 Metetra
.664 .741 .907 r
.26982 .46561 .27089 .46661 .27628 .46481 .27521 .46381 Metetra
.664 .741 .907 r
.27521 .46381 .27628 .46481 .28168 .46301 .28062 .462 Metetra
.664 .741 .907 r
.28062 .462 .28168 .46301 .2871 .4612 .28603 .46019 Metetra
.664 .741 .907 r
.28603 .46019 .2871 .4612 .29252 .45939 .29146 .45838 Metetra
.664 .741 .907 r
.29146 .45838 .29252 .45939 .29796 .45758 .2969 .45656 Metetra
.664 .741 .907 r
.2969 .45656 .29796 .45758 .3034 .45576 .30234 .45474 Metetra
.664 .741 .907 r
.30234 .45474 .3034 .45576 .30886 .45394 .3078 .45292 Metetra
.664 .741 .907 r
.3078 .45292 .30886 .45394 .31433 .45211 .31327 .45109 Metetra
.664 .741 .907 r
.31327 .45109 .31433 .45211 .31981 .45028 .31876 .44926 Metetra
.664 .741 .907 r
.31876 .44926 .31981 .45028 .3253 .44845 .32425 .44743 Metetra
.664 .741 .907 r
.32425 .44743 .3253 .44845 .3308 .44661 .32975 .44559 Metetra
.664 .741 .907 r
.32975 .44559 .3308 .44661 .33632 .44477 .33527 .44374 Metetra
.664 .741 .907 r
.33527 .44374 .33632 .44477 .34184 .44293 .3408 .4419 Metetra
.664 .741 .907 r
.3408 .4419 .34184 .44293 .34738 .44108 .34634 .44005 Metetra
.664 .741 .907 r
.34634 .44005 .34738 .44108 .35293 .43923 .35189 .43819 Metetra
.664 .741 .907 r
.35189 .43819 .35293 .43923 .35849 .43737 .35745 .43633 Metetra
.664 .741 .907 r
.35745 .43633 .35849 .43737 .36406 .43551 .36302 .43447 Metetra
.664 .741 .907 r
.36302 .43447 .36406 .43551 .36964 .43365 .36861 .43261 Metetra
.664 .741 .907 r
.36861 .43261 .36964 .43365 .37524 .43178 .37421 .43074 Metetra
.664 .741 .907 r
.37421 .43074 .37524 .43178 .38085 .42991 .37982 .42886 Metetra
.664 .741 .907 r
.37982 .42886 .38085 .42991 .38646 .42803 .38544 .42698 Metetra
.952 .679 .483 r
.38544 .42698 .38646 .42803 .38399 .62434 .38263 .62989 Metetra
.985 .744 .488 r
.38263 .62989 .38399 .62434 .39253 .55712 .39394 .49346 Metetra
.656 .426 .559 r
.39394 .49346 .39253 .55712 .40339 .42238 .40237 .42133 Metetra
.664 .741 .907 r
.40237 .42133 .40339 .42238 .40906 .42049 .40804 .41943 Metetra
.664 .741 .907 r
.40804 .41943 .40906 .42049 .41474 .41859 .41372 .41754 Metetra
.664 .741 .907 r
.41372 .41754 .41474 .41859 .42043 .4167 .41941 .41563 Metetra
.664 .741 .907 r
.41941 .41563 .42043 .4167 .42613 .41479 .42512 .41373 Metetra
.664 .741 .907 r
.42512 .41373 .42613 .41479 .43184 .41288 .43083 .41182 Metetra
.664 .741 .907 r
.43083 .41182 .43184 .41288 .43757 .41097 .43656 .4099 Metetra
.664 .741 .907 r
.43656 .4099 .43757 .41097 .44331 .40906 .4423 .40799 Metetra
.664 .741 .907 r
.4423 .40799 .44331 .40906 .44906 .40714 .44806 .40607 Metetra
.664 .741 .907 r
.44806 .40607 .44906 .40714 .45482 .40521 .45382 .40414 Metetra
.664 .741 .907 r
.45382 .40414 .45482 .40521 .4606 .40329 .4596 .40221 Metetra
.664 .741 .907 r
.4596 .40221 .4606 .40329 .46638 .40135 .46539 .40028 Metetra
.664 .741 .907 r
.46539 .40028 .46638 .40135 .47218 .39942 .47119 .39834 Metetra
.664 .741 .907 r
.47119 .39834 .47218 .39942 .47799 .39748 .47701 .39639 Metetra
.664 .741 .907 r
.47701 .39639 .47799 .39748 .48382 .39553 .48283 .39445 Metetra
.664 .741 .907 r
.48283 .39445 .48382 .39553 .48966 .39359 .48867 .3925 Metetra
.664 .741 .907 r
.48867 .3925 .48966 .39359 .49551 .39163 .49452 .39054 Metetra
.664 .741 .907 r
.49452 .39054 .49551 .39163 .50137 .38968 .50039 .38858 Metetra
.664 .741 .907 r
.50039 .38858 .50137 .38968 .50724 .38771 .50627 .38662 Metetra
.664 .741 .907 r
.50627 .38662 .50724 .38771 .51313 .38575 .51216 .38465 Metetra
.664 .741 .907 r
.51216 .38465 .51313 .38575 .51903 .38378 .51806 .38268 Metetra
.664 .741 .907 r
.51806 .38268 .51903 .38378 .52494 .38181 .52397 .3807 Metetra
.664 .741 .907 r
.52397 .3807 .52494 .38181 .53087 .37983 .5299 .37872 Metetra
.664 .741 .907 r
.5299 .37872 .53087 .37983 .53681 .37785 .53584 .37674 Metetra
.664 .741 .907 r
.53584 .37674 .53681 .37785 .54276 .37586 .54179 .37475 Metetra
.664 .741 .907 r
.54179 .37475 .54276 .37586 .54872 .37387 .54776 .37276 Metetra
.664 .741 .907 r
.54776 .37276 .54872 .37387 .5547 .37187 .55374 .37076 Metetra
.664 .741 .907 r
.55374 .37076 .5547 .37187 .56069 .36987 .55973 .36876 Metetra
.664 .741 .907 r
.55973 .36876 .56069 .36987 .56669 .36787 .56574 .36675 Metetra
.664 .741 .907 r
.56574 .36675 .56669 .36787 .5727 .36586 .57176 .36474 Metetra
.664 .741 .907 r
.57176 .36474 .5727 .36586 .57873 .36385 .57779 .36273 Metetra
.664 .741 .907 r
.57779 .36273 .57873 .36385 .58478 .36183 .58383 .36071 Metetra
.963 .635 .331 r
.58383 .36071 .58478 .36183 .59415 .52015 .59098 .41181 Metetra
.601 .376 .547 r
.59098 .41181 .59415 .52015 .5969 .35779 .59596 .35666 Metetra
.664 .741 .907 r
.59596 .35666 .5969 .35779 .60298 .35576 .60204 .35462 Metetra
.664 .741 .907 r
.60204 .35462 .60298 .35576 .60907 .35372 .60814 .35259 Metetra
.664 .741 .907 r
.60814 .35259 .60907 .35372 .61518 .35168 .61425 .35054 Metetra
.664 .741 .907 r
.61425 .35054 .61518 .35168 .6213 .34964 .62038 .3485 Metetra
.664 .741 .907 r
.62038 .3485 .6213 .34964 .62744 .34759 .62651 .34645 Metetra
.664 .741 .907 r
.62651 .34645 .62744 .34759 .63359 .34554 .63267 .34439 Metetra
.664 .741 .907 r
.63267 .34439 .63359 .34554 .63975 .34348 .63883 .34233 Metetra
.664 .741 .907 r
.63883 .34233 .63975 .34348 .64593 .34142 .64501 .34027 Metetra
.664 .741 .907 r
.64501 .34027 .64593 .34142 .65211 .33936 .6512 .3382 Metetra
.664 .741 .907 r
.6512 .3382 .65211 .33936 .65832 .33728 .65741 .33613 Metetra
.664 .741 .907 r
.65741 .33613 .65832 .33728 .66453 .33521 .66363 .33405 Metetra
.664 .741 .907 r
.66363 .33405 .66453 .33521 .67076 .33313 .66986 .33197 Metetra
.664 .741 .907 r
.66986 .33197 .67076 .33313 .67701 .33105 .6761 .32988 Metetra
.664 .741 .907 r
.6761 .32988 .67701 .33105 .68326 .32896 .68237 .32779 Metetra
.664 .741 .907 r
.68237 .32779 .68326 .32896 .68954 .32686 .68864 .32569 Metetra
.664 .741 .907 r
.68864 .32569 .68954 .32686 .69582 .32477 .69493 .32359 Metetra
.664 .741 .907 r
.69493 .32359 .69582 .32477 .70212 .32266 .70123 .32149 Metetra
.664 .741 .907 r
.70123 .32149 .70212 .32266 .70843 .32055 .70755 .31938 Metetra
.664 .741 .907 r
.70755 .31938 .70843 .32055 .71476 .31844 .71388 .31726 Metetra
.664 .741 .907 r
.71388 .31726 .71476 .31844 .7211 .31633 .72022 .31514 Metetra
.664 .741 .907 r
.72022 .31514 .7211 .31633 .72746 .3142 .72658 .31302 Metetra
.664 .741 .907 r
.72658 .31302 .72746 .3142 .73383 .31208 .73295 .31089 Metetra
.664 .741 .907 r
.73295 .31089 .73383 .31208 .74021 .30995 .73934 .30876 Metetra
.664 .741 .907 r
.73934 .30876 .74021 .30995 .74661 .30781 .74574 .30662 Metetra
.664 .741 .907 r
.74574 .30662 .74661 .30781 .75303 .30567 .75216 .30447 Metetra
.664 .741 .907 r
.75216 .30447 .75303 .30567 .75945 .30352 .75859 .30233 Metetra
.664 .741 .907 r
.75859 .30233 .75945 .30352 .76589 .30137 .76503 .30017 Metetra
.664 .741 .907 r
.76503 .30017 .76589 .30137 .77235 .29922 .77149 .29802 Metetra
.664 .741 .907 r
.77149 .29802 .77235 .29922 .77882 .29706 .77797 .29585 Metetra
.664 .741 .907 r
.77797 .29585 .77882 .29706 .78531 .29489 .78446 .29368 Metetra
.664 .741 .907 r
.78446 .29368 .78531 .29489 .79181 .29272 .79096 .29151 Metetra
.664 .741 .907 r
.79096 .29151 .79181 .29272 .79832 .29055 .79748 .28934 Metetra
0 0 .43 r
.79748 .28934 .79832 .29055 .81407 .39083 .80516 .29999 Metetra
.566 .349 .545 r
.80516 .29999 .81407 .39083 .81139 .28619 .81056 .28497 Metetra
.664 .741 .907 r
.81056 .28497 .81139 .28619 .81795 .284 .81712 .28277 Metetra
.664 .741 .907 r
.81712 .28277 .81795 .284 .82453 .2818 .8237 .28058 Metetra
.664 .741 .907 r
.8237 .28058 .82453 .2818 .83112 .2796 .83029 .27837 Metetra
.664 .741 .907 r
.83029 .27837 .83112 .2796 .83772 .2774 .83689 .27617 Metetra
.664 .741 .907 r
.83689 .27617 .83772 .2774 .84434 .27519 .84352 .27395 Metetra
.664 .741 .907 r
.84352 .27395 .84434 .27519 .85097 .27297 .85015 .27174 Metetra
.664 .741 .907 r
.85015 .27174 .85097 .27297 .85762 .27075 .85681 .26951 Metetra
.664 .741 .907 r
.85681 .26951 .85762 .27075 .86429 .26853 .86347 .26729 Metetra
.664 .741 .907 r
.26337 .4664 .26444 .46741 .26982 .46561 .26875 .4646 Metetra
.664 .741 .907 r
.26875 .4646 .26982 .46561 .27521 .46381 .27415 .4628 Metetra
.664 .741 .907 r
.27415 .4628 .27521 .46381 .28062 .462 .27955 .46099 Metetra
.664 .741 .907 r
.27955 .46099 .28062 .462 .28603 .46019 .28497 .45918 Metetra
.664 .741 .907 r
.28497 .45918 .28603 .46019 .29146 .45838 .2904 .45737 Metetra
.808 .335 0 r
.2904 .45737 .29146 .45838 .2969 .45656 .29515 .4653 Metetra
.35 .109 .402 r
.29515 .4653 .2969 .45656 .30234 .45474 .30121 .45476 Metetra
.66 .956 .944 r
.30121 .45476 .30234 .45474 .3078 .45292 .30675 .4519 Metetra
.664 .741 .907 r
.30675 .4519 .3078 .45292 .31327 .45109 .31222 .45007 Metetra
.664 .741 .907 r
.31222 .45007 .31327 .45109 .31876 .44926 .3177 .44824 Metetra
.664 .741 .907 r
.3177 .44824 .31876 .44926 .32425 .44743 .3232 .4464 Metetra
.664 .741 .907 r
.3232 .4464 .32425 .44743 .32975 .44559 .32871 .44456 Metetra
.664 .741 .907 r
.32871 .44456 .32975 .44559 .33527 .44374 .33422 .44271 Metetra
.664 .741 .907 r
.33422 .44271 .33527 .44374 .3408 .4419 .33975 .44087 Metetra
.664 .741 .907 r
.33975 .44087 .3408 .4419 .34634 .44005 .3453 .43901 Metetra
.664 .741 .907 r
.3453 .43901 .34634 .44005 .35189 .43819 .35085 .43716 Metetra
.664 .741 .907 r
.35085 .43716 .35189 .43819 .35745 .43633 .35641 .4353 Metetra
.664 .741 .907 r
.35641 .4353 .35745 .43633 .36302 .43447 .36199 .43343 Metetra
.664 .741 .907 r
.36199 .43343 .36302 .43447 .36861 .43261 .36758 .43156 Metetra
.664 .741 .907 r
.36758 .43156 .36861 .43261 .37421 .43074 .37318 .42969 Metetra
.664 .741 .907 r
.37318 .42969 .37421 .43074 .37982 .42886 .37879 .42782 Metetra
.664 .741 .907 r
.37879 .42782 .37982 .42886 .38544 .42698 .38441 .42594 Metetra
.952 .679 .482 r
.38441 .42594 .38544 .42698 .38263 .62989 .38202 .61721 Metetra
.9 .644 .542 r
.38202 .61721 .38263 .62989 .39394 .49346 .39569 .42216 Metetra
.553 .341 .546 r
.39569 .42216 .39394 .49346 .40237 .42133 .40135 .42027 Metetra
.664 .741 .907 r
.40135 .42027 .40237 .42133 .40804 .41943 .40702 .41838 Metetra
.664 .741 .907 r
.40702 .41838 .40804 .41943 .41372 .41754 .41271 .41648 Metetra
.664 .741 .907 r
.41271 .41648 .41372 .41754 .41941 .41563 .4184 .41457 Metetra
.664 .741 .907 r
.4184 .41457 .41941 .41563 .42512 .41373 .42411 .41266 Metetra
.945 .588 .287 r
.42411 .41266 .42512 .41373 .43083 .41182 .4291 .43545 Metetra
.386 .18 .473 r
.4291 .43545 .43083 .41182 .43656 .4099 .43556 .40884 Metetra
.664 .741 .907 r
.43556 .40884 .43656 .4099 .4423 .40799 .4413 .40692 Metetra
.664 .741 .907 r
.4413 .40692 .4423 .40799 .44806 .40607 .44705 .40499 Metetra
.664 .741 .907 r
.44705 .40499 .44806 .40607 .45382 .40414 .45282 .40306 Metetra
.664 .741 .907 r
.45282 .40306 .45382 .40414 .4596 .40221 .4586 .40113 Metetra
.664 .741 .907 r
.4586 .40113 .4596 .40221 .46539 .40028 .46439 .39919 Metetra
.664 .741 .907 r
.46439 .39919 .46539 .40028 .47119 .39834 .4702 .39725 Metetra
.664 .741 .907 r
.4702 .39725 .47119 .39834 .47701 .39639 .47602 .39531 Metetra
.664 .741 .907 r
.47602 .39531 .47701 .39639 .48283 .39445 .48185 .39336 Metetra
.664 .741 .907 r
.48185 .39336 .48283 .39445 .48867 .3925 .48769 .39141 Metetra
.664 .741 .907 r
.48769 .39141 .48867 .3925 .49452 .39054 .49354 .38945 Metetra
.664 .741 .907 r
.49354 .38945 .49452 .39054 .50039 .38858 .49941 .38749 Metetra
.664 .741 .907 r
.49941 .38749 .50039 .38858 .50627 .38662 .50529 .38552 Metetra
.664 .741 .907 r
.50529 .38552 .50627 .38662 .51216 .38465 .51118 .38355 Metetra
.664 .741 .907 r
.51118 .38355 .51216 .38465 .51806 .38268 .51708 .38158 Metetra
.664 .741 .907 r
.51708 .38158 .51806 .38268 .52397 .3807 .523 .3796 Metetra
.664 .741 .907 r
.523 .3796 .52397 .3807 .5299 .37872 .52893 .37762 Metetra
.664 .741 .907 r
.52893 .37762 .5299 .37872 .53584 .37674 .53488 .37563 Metetra
.664 .741 .907 r
.53488 .37563 .53584 .37674 .54179 .37475 .54083 .37364 Metetra
.664 .741 .907 r
.54083 .37364 .54179 .37475 .54776 .37276 .5468 .37164 Metetra
.664 .741 .907 r
.5468 .37164 .54776 .37276 .55374 .37076 .55278 .36964 Metetra
.664 .741 .907 r
.55278 .36964 .55374 .37076 .55973 .36876 .55878 .36764 Metetra
.664 .741 .907 r
.55878 .36764 .55973 .36876 .56574 .36675 .56479 .36563 Metetra
.664 .741 .907 r
.56479 .36563 .56574 .36675 .57176 .36474 .57081 .36362 Metetra
.664 .741 .907 r
.57081 .36362 .57176 .36474 .57779 .36273 .57684 .3616 Metetra
.951 .598 .263 r
.57684 .3616 .57779 .36273 .58383 .36071 .58351 .39365 Metetra
.501 .28 .511 r
.58351 .39365 .58383 .36071 .59098 .41181 .58941 .38062 Metetra
.627 .406 .562 r
.58941 .38062 .59098 .41181 .59596 .35666 .59502 .35552 Metetra
.664 .741 .907 r
.59502 .35552 .59596 .35666 .60204 .35462 .60111 .35349 Metetra
.664 .741 .907 r
.60111 .35349 .60204 .35462 .60814 .35259 .60721 .35145 Metetra
.664 .741 .907 r
.60721 .35145 .60814 .35259 .61425 .35054 .61332 .3494 Metetra
.664 .741 .907 r
.61332 .3494 .61425 .35054 .62038 .3485 .61945 .34736 Metetra
.664 .741 .907 r
.61945 .34736 .62038 .3485 .62651 .34645 .62559 .3453 Metetra
.664 .741 .907 r
.62559 .3453 .62651 .34645 .63267 .34439 .63174 .34324 Metetra
.664 .741 .907 r
.63174 .34324 .63267 .34439 .63883 .34233 .63791 .34118 Metetra
.664 .741 .907 r
.63791 .34118 .63883 .34233 .64501 .34027 .64409 .33912 Metetra
.664 .741 .907 r
.64409 .33912 .64501 .34027 .6512 .3382 .65029 .33705 Metetra
.664 .741 .907 r
.65029 .33705 .6512 .3382 .65741 .33613 .65649 .33497 Metetra
.664 .741 .907 r
.65649 .33497 .65741 .33613 .66363 .33405 .66272 .33289 Metetra
.664 .741 .907 r
.66272 .33289 .66363 .33405 .66986 .33197 .66895 .3308 Metetra
.664 .741 .907 r
.66895 .3308 .66986 .33197 .6761 .32988 .6752 .32872 Metetra
.664 .741 .907 r
.6752 .32872 .6761 .32988 .68237 .32779 .68147 .32662 Metetra
.664 .741 .907 r
.68147 .32662 .68237 .32779 .68864 .32569 .68774 .32452 Metetra
.664 .741 .907 r
.68774 .32452 .68864 .32569 .69493 .32359 .69403 .32242 Metetra
.664 .741 .907 r
.69403 .32242 .69493 .32359 .70123 .32149 .70034 .32031 Metetra
.664 .741 .907 r
.70034 .32031 .70123 .32149 .70755 .31938 .70666 .3182 Metetra
.664 .741 .907 r
.70666 .3182 .70755 .31938 .71388 .31726 .71299 .31608 Metetra
.664 .741 .907 r
.71299 .31608 .71388 .31726 .72022 .31514 .71934 .31396 Metetra
.664 .741 .907 r
.71934 .31396 .72022 .31514 .72658 .31302 .7257 .31183 Metetra
.664 .741 .907 r
.7257 .31183 .72658 .31302 .73295 .31089 .73208 .3097 Metetra
.664 .741 .907 r
.73208 .3097 .73295 .31089 .73934 .30876 .73847 .30756 Metetra
.664 .741 .907 r
.73847 .30756 .73934 .30876 .74574 .30662 .74487 .30542 Metetra
.664 .741 .907 r
.74487 .30542 .74574 .30662 .75216 .30447 .75129 .30328 Metetra
.664 .741 .907 r
.75129 .30328 .75216 .30447 .75859 .30233 .75772 .30113 Metetra
.664 .741 .907 r
.75772 .30113 .75859 .30233 .76503 .30017 .76417 .29897 Metetra
.664 .741 .907 r
.76417 .29897 .76503 .30017 .77149 .29802 .77063 .29681 Metetra
.664 .741 .907 r
.77063 .29681 .77149 .29802 .77797 .29585 .77711 .29464 Metetra
.664 .741 .907 r
.77711 .29464 .77797 .29585 .78446 .29368 .7836 .29247 Metetra
0 .334 .817 r
.7836 .29247 .78446 .29368 .79096 .29151 .79069 .29709 Metetra
.338 .088 .38 r
.79069 .29709 .79096 .29151 .79748 .28934 .79663 .28812 Metetra
.664 .741 .907 r
.79663 .28812 .79748 .28934 .80516 .29999 .80317 .28593 Metetra
.57 .38 .585 r
.80317 .28593 .80516 .29999 .81056 .28497 .80972 .28374 Metetra
.664 .741 .907 r
.80972 .28374 .81056 .28497 .81712 .28277 .81628 .28155 Metetra
.664 .741 .907 r
.81628 .28155 .81712 .28277 .8237 .28058 .82286 .27935 Metetra
.664 .741 .907 r
.82286 .27935 .8237 .28058 .83029 .27837 .82946 .27714 Metetra
.664 .741 .907 r
.82946 .27714 .83029 .27837 .83689 .27617 .83607 .27493 Metetra
.664 .741 .907 r
.83607 .27493 .83689 .27617 .84352 .27395 .84269 .27272 Metetra
.664 .741 .907 r
.84269 .27272 .84352 .27395 .85015 .27174 .84933 .2705 Metetra
.664 .741 .907 r
.84933 .2705 .85015 .27174 .85681 .26951 .85599 .26827 Metetra
.664 .741 .907 r
.85599 .26827 .85681 .26951 .86347 .26729 .86266 .26604 Metetra
.664 .741 .907 r
.26229 .4654 .26337 .4664 .26875 .4646 .26768 .4636 Metetra
.664 .741 .907 r
.26768 .4636 .26875 .4646 .27415 .4628 .27308 .46179 Metetra
.664 .741 .907 r
.27308 .46179 .27415 .4628 .27955 .46099 .27848 .45998 Metetra
.664 .741 .907 r
.27848 .45998 .27955 .46099 .28497 .45918 .2839 .45817 Metetra
.664 .741 .907 r
.2839 .45817 .28497 .45918 .2904 .45737 .28933 .45635 Metetra
.946 .625 .394 r
.28933 .45635 .2904 .45737 .29515 .4653 .2927 .48406 Metetra
.248 .056 .412 r
.2927 .48406 .29515 .4653 .30121 .45476 .30022 .45271 Metetra
.642 .594 .785 r
.30022 .45271 .30121 .45476 .30675 .4519 .30569 .45088 Metetra
.664 .741 .907 r
.30569 .45088 .30675 .4519 .31222 .45007 .31116 .44905 Metetra
.664 .741 .907 r
.31116 .44905 .31222 .45007 .3177 .44824 .31665 .44721 Metetra
.664 .741 .907 r
.31665 .44721 .3177 .44824 .3232 .4464 .32215 .44537 Metetra
.664 .741 .907 r
.32215 .44537 .3232 .4464 .32871 .44456 .32766 .44353 Metetra
.664 .741 .907 r
.32766 .44353 .32871 .44456 .33422 .44271 .33318 .44168 Metetra
.664 .741 .907 r
.33318 .44168 .33422 .44271 .33975 .44087 .33871 .43983 Metetra
.664 .741 .907 r
.33871 .43983 .33975 .44087 .3453 .43901 .34425 .43798 Metetra
.664 .741 .907 r
.34425 .43798 .3453 .43901 .35085 .43716 .34981 .43612 Metetra
.664 .741 .907 r
.34981 .43612 .35085 .43716 .35641 .4353 .35537 .43426 Metetra
.664 .741 .907 r
.35537 .43426 .35641 .4353 .36199 .43343 .36095 .43239 Metetra
.664 .741 .907 r
.36095 .43239 .36199 .43343 .36758 .43156 .36654 .43052 Metetra
.664 .741 .907 r
.36654 .43052 .36758 .43156 .37318 .42969 .37214 .42865 Metetra
.664 .741 .907 r
.37214 .42865 .37318 .42969 .37879 .42782 .37776 .42677 Metetra
.664 .741 .907 r
.37776 .42677 .37879 .42782 .38441 .42594 .38338 .42488 Metetra
.953 .669 .461 r
.38338 .42488 .38441 .42594 .38202 .61721 .38502 .51848 Metetra
.642 .412 .554 r
.38502 .51848 .38202 .61721 .39569 .42216 .39449 .42559 Metetra
.21 0 .219 r
.39449 .42559 .39569 .42216 .40135 .42027 .40033 .41921 Metetra
.664 .741 .907 r
.40033 .41921 .40135 .42027 .40702 .41838 .406 .41732 Metetra
.664 .741 .907 r
.406 .41732 .40702 .41838 .41271 .41648 .41169 .41541 Metetra
.664 .741 .907 r
.41169 .41541 .41271 .41648 .4184 .41457 .41739 .41351 Metetra
.664 .741 .907 r
.41739 .41351 .4184 .41457 .42411 .41266 .42309 .4116 Metetra
.952 .616 .338 r
.42309 .4116 .42411 .41266 .4291 .43545 .42789 .44082 Metetra
.798 .749 .229 r
.42789 .44082 .4291 .43545 .43556 .40884 .43455 .40777 Metetra
.664 .741 .907 r
.43455 .40777 .43556 .40884 .4413 .40692 .44029 .40584 Metetra
.664 .741 .907 r
.44029 .40584 .4413 .40692 .44705 .40499 .44605 .40392 Metetra
.664 .741 .907 r
.44605 .40392 .44705 .40499 .45282 .40306 .45182 .40199 Metetra
.664 .741 .907 r
.45182 .40199 .45282 .40306 .4586 .40113 .4576 .40005 Metetra
.664 .741 .907 r
.4576 .40005 .4586 .40113 .46439 .39919 .4634 .39811 Metetra
.664 .741 .907 r
.4634 .39811 .46439 .39919 .4702 .39725 .46921 .39617 Metetra
.903 .493 .113 r
.46921 .39617 .4702 .39725 .47602 .39531 .47476 .41113 Metetra
.377 .163 .457 r
.47476 .41113 .47602 .39531 .48185 .39336 .48086 .39227 Metetra
.664 .741 .907 r
.48086 .39227 .48185 .39336 .48769 .39141 .4867 .39032 Metetra
.664 .741 .907 r
.4867 .39032 .48769 .39141 .49354 .38945 .49256 .38836 Metetra
.664 .741 .907 r
.49256 .38836 .49354 .38945 .49941 .38749 .49843 .38639 Metetra
.664 .741 .907 r
.49843 .38639 .49941 .38749 .50529 .38552 .50431 .38442 Metetra
.664 .741 .907 r
.50431 .38442 .50529 .38552 .51118 .38355 .5102 .38245 Metetra
.664 .741 .907 r
.5102 .38245 .51118 .38355 .51708 .38158 .51611 .38048 Metetra
.664 .741 .907 r
.51611 .38048 .51708 .38158 .523 .3796 .52203 .37849 Metetra
.664 .741 .907 r
.52203 .37849 .523 .3796 .52893 .37762 .52796 .37651 Metetra
.664 .741 .907 r
.52796 .37651 .52893 .37762 .53488 .37563 .53391 .37452 Metetra
.664 .741 .907 r
.53391 .37452 .53488 .37563 .54083 .37364 .53987 .37253 Metetra
.664 .741 .907 r
.53987 .37253 .54083 .37364 .5468 .37164 .54584 .37053 Metetra
.664 .741 .907 r
.54584 .37053 .5468 .37164 .55278 .36964 .55182 .36853 Metetra
.664 .741 .907 r
.55182 .36853 .55278 .36964 .55878 .36764 .55782 .36652 Metetra
.664 .741 .907 r
.55782 .36652 .55878 .36764 .56479 .36563 .56383 .36451 Metetra
.664 .741 .907 r
.56383 .36451 .56479 .36563 .57081 .36362 .56986 .36249 Metetra
.664 .741 .907 r
.56986 .36249 .57081 .36362 .57684 .3616 .57589 .36047 Metetra
.664 .741 .907 r
.57589 .36047 .57684 .3616 .58351 .39365 .58194 .35845 Metetra
.54 .338 .554 r
.58194 .35845 .58351 .39365 .58941 .38062 .58811 .36186 Metetra
.593 .388 .573 r
.58811 .36186 .58941 .38062 .59502 .35552 .59408 .35439 Metetra
.664 .741 .907 r
.59408 .35439 .59502 .35552 .60111 .35349 .60017 .35235 Metetra
.664 .741 .907 r
.60017 .35235 .60111 .35349 .60721 .35145 .60627 .35031 Metetra
.664 .741 .907 r
.60627 .35031 .60721 .35145 .61332 .3494 .61239 .34826 Metetra
.664 .741 .907 r
.61239 .34826 .61332 .3494 .61945 .34736 .61852 .34621 Metetra
.664 .741 .907 r
.61852 .34621 .61945 .34736 .62559 .3453 .62466 .34416 Metetra
.664 .741 .907 r
.62466 .34416 .62559 .3453 .63174 .34324 .63082 .3421 Metetra
.664 .741 .907 r
.63082 .3421 .63174 .34324 .63791 .34118 .63699 .34003 Metetra
.664 .741 .907 r
.63699 .34003 .63791 .34118 .64409 .33912 .64317 .33796 Metetra
.664 .741 .907 r
.64317 .33796 .64409 .33912 .65029 .33705 .64937 .33589 Metetra
.664 .741 .907 r
.64937 .33589 .65029 .33705 .65649 .33497 .65558 .33381 Metetra
.664 .741 .907 r
.65558 .33381 .65649 .33497 .66272 .33289 .66181 .33173 Metetra
.664 .741 .907 r
.66181 .33173 .66272 .33289 .66895 .3308 .66804 .32964 Metetra
.664 .741 .907 r
.66804 .32964 .66895 .3308 .6752 .32872 .6743 .32755 Metetra
.664 .741 .907 r
.6743 .32755 .6752 .32872 .68147 .32662 .68056 .32545 Metetra
.664 .741 .907 r
.68056 .32545 .68147 .32662 .68774 .32452 .68684 .32335 Metetra
.664 .741 .907 r
.68684 .32335 .68774 .32452 .69403 .32242 .69314 .32124 Metetra
.664 .741 .907 r
.69314 .32124 .69403 .32242 .70034 .32031 .69945 .31913 Metetra
.664 .741 .907 r
.69945 .31913 .70034 .32031 .70666 .3182 .70577 .31702 Metetra
.664 .741 .907 r
.70577 .31702 .70666 .3182 .71299 .31608 .7121 .3149 Metetra
.664 .741 .907 r
.7121 .3149 .71299 .31608 .71934 .31396 .71846 .31277 Metetra
.664 .741 .907 r
.71846 .31277 .71934 .31396 .7257 .31183 .72482 .31064 Metetra
.664 .741 .907 r
.72482 .31064 .7257 .31183 .73208 .3097 .7312 .30851 Metetra
.664 .741 .907 r
.7312 .30851 .73208 .3097 .73847 .30756 .73759 .30637 Metetra
.664 .741 .907 r
.73759 .30637 .73847 .30756 .74487 .30542 .744 .30423 Metetra
.664 .741 .907 r
.744 .30423 .74487 .30542 .75129 .30328 .75042 .30208 Metetra
.664 .741 .907 r
.75042 .30208 .75129 .30328 .75772 .30113 .75686 .29992 Metetra
.664 .741 .907 r
.75686 .29992 .75772 .30113 .76417 .29897 .76331 .29777 Metetra
.664 .741 .907 r
.76331 .29777 .76417 .29897 .77063 .29681 .76977 .2956 Metetra
.664 .741 .907 r
.76977 .2956 .77063 .29681 .77711 .29464 .77625 .29343 Metetra
.664 .741 .907 r
.77625 .29343 .77711 .29464 .7836 .29247 .78275 .29126 Metetra
.664 .741 .907 r
.78275 .29126 .7836 .29247 .79069 .29709 .78926 .28908 Metetra
.584 .415 .619 r
.78926 .28908 .79069 .29709 .79663 .28812 .79578 .2869 Metetra
.664 .741 .907 r
.79578 .2869 .79663 .28812 .80317 .28593 .80232 .28471 Metetra
.664 .741 .907 r
.80232 .28471 .80317 .28593 .80972 .28374 .80888 .28252 Metetra
.664 .741 .907 r
.80888 .28252 .80972 .28374 .81628 .28155 .81544 .28032 Metetra
.664 .741 .907 r
.81544 .28032 .81628 .28155 .82286 .27935 .82203 .27812 Metetra
.664 .741 .907 r
.82203 .27812 .82286 .27935 .82946 .27714 .82863 .27591 Metetra
.664 .741 .907 r
.82863 .27591 .82946 .27714 .83607 .27493 .83524 .2737 Metetra
.664 .741 .907 r
.83524 .2737 .83607 .27493 .84269 .27272 .84187 .27148 Metetra
.664 .741 .907 r
.84187 .27148 .84269 .27272 .84933 .2705 .84851 .26926 Metetra
.664 .741 .907 r
.84851 .26926 .84933 .2705 .85599 .26827 .85517 .26703 Metetra
.664 .741 .907 r
.85517 .26703 .85599 .26827 .86266 .26604 .86185 .2648 Metetra
.664 .741 .907 r
.26122 .4644 .26229 .4654 .26768 .4636 .26661 .46259 Metetra
.664 .741 .907 r
.26661 .46259 .26768 .4636 .27308 .46179 .272 .46078 Metetra
.664 .741 .907 r
.272 .46078 .27308 .46179 .27848 .45998 .27741 .45897 Metetra
.664 .741 .907 r
.27741 .45897 .27848 .45998 .2839 .45817 .28283 .45716 Metetra
.664 .741 .907 r
.28283 .45716 .2839 .45817 .28933 .45635 .28827 .45534 Metetra
.664 .741 .907 r
.28827 .45534 .28933 .45635 .2927 .48406 .29371 .45352 Metetra
.558 .352 .558 r
.29371 .45352 .2927 .48406 .30022 .45271 .29916 .45169 Metetra
.664 .741 .907 r
.29916 .45169 .30022 .45271 .30569 .45088 .30463 .44986 Metetra
.664 .741 .907 r
.30463 .44986 .30569 .45088 .31116 .44905 .31011 .44803 Metetra
.393 .636 .953 r
.31011 .44803 .31116 .44905 .31665 .44721 .31543 .4487 Metetra
.31543 .4487 .31665 .44721 .32215 .44537 .32109 .44435 Metetra
.664 .741 .907 r
.32109 .44435 .32215 .44537 .32766 .44353 .3266 .4425 Metetra
.664 .741 .907 r
.3266 .4425 .32766 .44353 .33318 .44168 .33213 .44065 Metetra
.664 .741 .907 r
.33213 .44065 .33318 .44168 .33871 .43983 .33766 .4388 Metetra
.664 .741 .907 r
.33766 .4388 .33871 .43983 .34425 .43798 .34321 .43694 Metetra
.664 .741 .907 r
.34321 .43694 .34425 .43798 .34981 .43612 .34876 .43508 Metetra
.664 .741 .907 r
.34876 .43508 .34981 .43612 .35537 .43426 .35433 .43322 Metetra
.664 .741 .907 r
.35433 .43322 .35537 .43426 .36095 .43239 .35991 .43135 Metetra
.664 .741 .907 r
.35991 .43135 .36095 .43239 .36654 .43052 .36551 .42947 Metetra
.664 .741 .907 r
.36551 .42947 .36654 .43052 .37214 .42865 .37111 .4276 Metetra
.664 .741 .907 r
.37111 .4276 .37214 .42865 .37776 .42677 .37673 .42572 Metetra
.664 .741 .907 r
.37673 .42572 .37776 .42677 .38338 .42488 .38235 .42383 Metetra
.664 .741 .907 r
.38235 .42383 .38338 .42488 .38502 .51848 .38799 .42194 Metetra
.551 .338 .543 r
.38799 .42194 .38502 .51848 .39449 .42559 .39364 .42005 Metetra
.595 .445 .648 r
.39364 .42005 .39449 .42559 .40033 .41921 .39931 .41816 Metetra
.664 .741 .907 r
.39931 .41816 .40033 .41921 .406 .41732 .40498 .41626 Metetra
.664 .741 .907 r
.40498 .41626 .406 .41732 .41169 .41541 .41067 .41435 Metetra
.664 .741 .907 r
.41067 .41435 .41169 .41541 .41739 .41351 .41637 .41244 Metetra
.664 .741 .907 r
.41637 .41244 .41739 .41351 .42309 .4116 .42208 .41053 Metetra
.957 .669 .448 r
.42208 .41053 .42309 .4116 .42789 .44082 .4249 .50528 Metetra
.308 .131 .471 r
.4249 .50528 .42789 .44082 .43455 .40777 .43354 .40669 Metetra
.664 .741 .907 r
.43354 .40669 .43455 .40777 .44029 .40584 .43929 .40477 Metetra
.664 .741 .907 r
.43929 .40477 .44029 .40584 .44605 .40392 .44505 .40284 Metetra
.664 .741 .907 r
.44505 .40284 .44605 .40392 .45182 .40199 .45082 .40091 Metetra
.664 .741 .907 r
.45082 .40091 .45182 .40199 .4576 .40005 .4566 .39897 Metetra
.664 .741 .907 r
.4566 .39897 .4576 .40005 .4634 .39811 .4624 .39703 Metetra
.664 .741 .907 r
.4624 .39703 .4634 .39811 .46921 .39617 .46821 .39508 Metetra
.664 .741 .907 r
.46821 .39508 .46921 .39617 .47476 .41113 .47403 .39313 Metetra
.565 .368 .573 r
.47403 .39313 .47476 .41113 .48086 .39227 .47987 .39118 Metetra
.664 .741 .907 r
.47987 .39118 .48086 .39227 .4867 .39032 .48571 .38922 Metetra
.664 .741 .907 r
.48571 .38922 .4867 .39032 .49256 .38836 .49157 .38726 Metetra
.664 .741 .907 r
.49157 .38726 .49256 .38836 .49843 .38639 .49744 .3853 Metetra
.664 .741 .907 r
.49744 .3853 .49843 .38639 .50431 .38442 .50333 .38332 Metetra
.664 .741 .907 r
.50333 .38332 .50431 .38442 .5102 .38245 .50923 .38135 Metetra
.664 .741 .907 r
.50923 .38135 .5102 .38245 .51611 .38048 .51514 .37937 Metetra
.664 .741 .907 r
.51514 .37937 .51611 .38048 .52203 .37849 .52106 .37739 Metetra
.664 .741 .907 r
.52106 .37739 .52203 .37849 .52796 .37651 .52699 .3754 Metetra
.664 .741 .907 r
.52699 .3754 .52796 .37651 .53391 .37452 .53294 .37341 Metetra
.664 .741 .907 r
.53294 .37341 .53391 .37452 .53987 .37253 .5389 .37141 Metetra
.664 .741 .907 r
.5389 .37141 .53987 .37253 .54584 .37053 .54488 .36941 Metetra
.664 .741 .907 r
.54488 .36941 .54584 .37053 .55182 .36853 .55086 .36741 Metetra
.664 .741 .907 r
.55086 .36741 .55182 .36853 .55782 .36652 .55686 .3654 Metetra
.664 .741 .907 r
.55686 .3654 .55782 .36652 .56383 .36451 .56288 .36338 Metetra
.664 .741 .907 r
.56288 .36338 .56383 .36451 .56986 .36249 .5689 .36137 Metetra
.664 .741 .907 r
.5689 .36137 .56986 .36249 .57589 .36047 .57494 .35934 Metetra
.664 .741 .907 r
.57494 .35934 .57589 .36047 .58194 .35845 .581 .35732 Metetra
.664 .741 .907 r
.581 .35732 .58194 .35845 .58811 .36186 .58706 .35529 Metetra
.59 .43 .634 r
.58706 .35529 .58811 .36186 .59408 .35439 .59314 .35325 Metetra
.664 .741 .907 r
.59314 .35325 .59408 .35439 .60017 .35235 .59923 .35121 Metetra
.664 .741 .907 r
.59923 .35121 .60017 .35235 .60627 .35031 .60534 .34917 Metetra
.664 .741 .907 r
.60534 .34917 .60627 .35031 .61239 .34826 .61146 .34712 Metetra
.664 .741 .907 r
.61146 .34712 .61239 .34826 .61852 .34621 .61759 .34506 Metetra
.664 .741 .907 r
.61759 .34506 .61852 .34621 .62466 .34416 .62373 .34301 Metetra
.664 .741 .907 r
.62373 .34301 .62466 .34416 .63082 .3421 .62989 .34094 Metetra
.664 .741 .907 r
.62989 .34094 .63082 .3421 .63699 .34003 .63607 .33888 Metetra
.664 .741 .907 r
.63607 .33888 .63699 .34003 .64317 .33796 .64225 .33681 Metetra
.664 .741 .907 r
.64225 .33681 .64317 .33796 .64937 .33589 .64845 .33473 Metetra
.664 .741 .907 r
.64845 .33473 .64937 .33589 .65558 .33381 .65467 .33265 Metetra
.664 .741 .907 r
.65467 .33265 .65558 .33381 .66181 .33173 .6609 .33056 Metetra
.664 .741 .907 r
.6609 .33056 .66181 .33173 .66804 .32964 .66714 .32847 Metetra
.664 .741 .907 r
.66714 .32847 .66804 .32964 .6743 .32755 .67339 .32638 Metetra
.664 .741 .907 r
.67339 .32638 .6743 .32755 .68056 .32545 .67966 .32428 Metetra
.664 .741 .907 r
.67966 .32428 .68056 .32545 .68684 .32335 .68594 .32218 Metetra
.664 .741 .907 r
.68594 .32218 .68684 .32335 .69314 .32124 .69224 .32007 Metetra
.664 .741 .907 r
.69224 .32007 .69314 .32124 .69945 .31913 .69855 .31795 Metetra
.664 .741 .907 r
.69855 .31795 .69945 .31913 .70577 .31702 .70488 .31584 Metetra
.664 .741 .907 r
.70488 .31584 .70577 .31702 .7121 .3149 .71122 .31371 Metetra
.664 .741 .907 r
.71122 .31371 .7121 .3149 .71846 .31277 .71757 .31159 Metetra
.664 .741 .907 r
.71757 .31159 .71846 .31277 .72482 .31064 .72394 .30945 Metetra
.664 .741 .907 r
.72394 .30945 .72482 .31064 .7312 .30851 .73032 .30732 Metetra
.664 .741 .907 r
.73032 .30732 .7312 .30851 .73759 .30637 .73672 .30518 Metetra
.664 .741 .907 r
.73672 .30518 .73759 .30637 .744 .30423 .74313 .30303 Metetra
.664 .741 .907 r
.74313 .30303 .744 .30423 .75042 .30208 .74955 .30088 Metetra
.664 .741 .907 r
.74955 .30088 .75042 .30208 .75686 .29992 .75599 .29872 Metetra
.664 .741 .907 r
.75599 .29872 .75686 .29992 .76331 .29777 .76245 .29656 Metetra
.664 .741 .907 r
.76245 .29656 .76331 .29777 .76977 .2956 .76891 .29439 Metetra
.664 .741 .907 r
.76891 .29439 .76977 .2956 .77625 .29343 .7754 .29222 Metetra
.664 .741 .907 r
.7754 .29222 .77625 .29343 .78275 .29126 .78189 .29005 Metetra
.664 .741 .907 r
.78189 .29005 .78275 .29126 .78926 .28908 .78841 .28787 Metetra
.664 .741 .907 r
.78841 .28787 .78926 .28908 .79578 .2869 .79493 .28568 Metetra
.664 .741 .907 r
.79493 .28568 .79578 .2869 .80232 .28471 .80148 .28349 Metetra
.664 .741 .907 r
.80148 .28349 .80232 .28471 .80888 .28252 .80803 .28129 Metetra
.664 .741 .907 r
.80803 .28129 .80888 .28252 .81544 .28032 .81461 .27909 Metetra
.664 .741 .907 r
.81461 .27909 .81544 .28032 .82203 .27812 .82119 .27689 Metetra
.664 .741 .907 r
.82119 .27689 .82203 .27812 .82863 .27591 .82779 .27468 Metetra
.664 .741 .907 r
.82779 .27468 .82863 .27591 .83524 .2737 .83441 .27246 Metetra
.664 .741 .907 r
.83441 .27246 .83524 .2737 .84187 .27148 .84104 .27024 Metetra
.664 .741 .907 r
.84104 .27024 .84187 .27148 .84851 .26926 .84769 .26802 Metetra
.664 .741 .907 r
.84769 .26802 .84851 .26926 .85517 .26703 .85435 .26578 Metetra
.664 .741 .907 r
.85435 .26578 .85517 .26703 .86185 .2648 .86103 .26355 Metetra
.664 .741 .907 r
.26014 .46339 .26122 .4644 .26661 .46259 .26553 .46158 Metetra
.664 .741 .907 r
.26553 .46158 .26661 .46259 .272 .46078 .27093 .45977 Metetra
.664 .741 .907 r
.27093 .45977 .272 .46078 .27741 .45897 .27634 .45796 Metetra
.664 .741 .907 r
.27634 .45796 .27741 .45897 .28283 .45716 .28176 .45614 Metetra
.664 .741 .907 r
.28176 .45614 .28283 .45716 .28827 .45534 .2872 .45432 Metetra
.664 .741 .907 r
.2872 .45432 .28827 .45534 .29371 .45352 .29264 .4525 Metetra
.664 .741 .907 r
.29264 .4525 .29371 .45352 .29916 .45169 .2981 .45067 Metetra
.664 .741 .907 r
.2981 .45067 .29916 .45169 .30463 .44986 .30357 .44884 Metetra
.664 .741 .907 r
.30357 .44884 .30463 .44986 .31011 .44803 .30905 .447 Metetra
.79 .312 0 r
.30905 .447 .31011 .44803 .31543 .4487 .31392 .4548 Metetra
.192 0 .3 r
.31392 .4548 .31543 .4487 .32109 .44435 .32004 .44332 Metetra
.664 .741 .907 r
.32004 .44332 .32109 .44435 .3266 .4425 .32555 .44147 Metetra
.664 .741 .907 r
.32555 .44147 .3266 .4425 .33213 .44065 .33108 .43962 Metetra
.664 .741 .907 r
.33108 .43962 .33213 .44065 .33766 .4388 .33661 .43776 Metetra
.664 .741 .907 r
.33661 .43776 .33766 .4388 .34321 .43694 .34216 .4359 Metetra
.664 .741 .907 r
.34216 .4359 .34321 .43694 .34876 .43508 .34772 .43404 Metetra
.664 .741 .907 r
.34772 .43404 .34876 .43508 .35433 .43322 .35329 .43217 Metetra
.664 .741 .907 r
.35329 .43217 .35433 .43322 .35991 .43135 .35887 .4303 Metetra
.664 .741 .907 r
.35887 .4303 .35991 .43135 .36551 .42947 .36447 .42843 Metetra
.664 .741 .907 r
.36447 .42843 .36551 .42947 .37111 .4276 .37007 .42655 Metetra
.664 .741 .907 r
.37007 .42655 .37111 .4276 .37673 .42572 .37569 .42467 Metetra
.664 .741 .907 r
.37569 .42467 .37673 .42572 .38235 .42383 .38132 .42278 Metetra
.664 .741 .907 r
.38132 .42278 .38235 .42383 .38799 .42194 .38696 .42089 Metetra
.664 .741 .907 r
.38696 .42089 .38799 .42194 .39364 .42005 .39262 .419 Metetra
.664 .741 .907 r
.39262 .419 .39364 .42005 .39931 .41816 .39828 .4171 Metetra
.664 .741 .907 r
.39828 .4171 .39931 .41816 .40498 .41626 .40396 .41519 Metetra
.664 .741 .907 r
.40396 .41519 .40498 .41626 .41067 .41435 .40965 .41329 Metetra
.664 .741 .907 r
.40965 .41329 .41067 .41435 .41637 .41244 .41535 .41138 Metetra
.878 .448 .055 r
.41535 .41138 .41637 .41244 .42208 .41053 .42062 .42341 Metetra
.895 .62 .513 r
.42062 .42341 .42208 .41053 .4249 .50528 .41994 .6332 Metetra
.245 .086 .458 r
.41994 .6332 .4249 .50528 .43354 .40669 .43253 .40562 Metetra
.664 .741 .907 r
.43253 .40562 .43354 .40669 .43929 .40477 .43828 .40369 Metetra
.664 .741 .907 r
.43828 .40369 .43929 .40477 .44505 .40284 .44404 .40176 Metetra
.664 .741 .907 r
.44404 .40176 .44505 .40284 .45082 .40091 .44982 .39983 Metetra
.664 .741 .907 r
.44982 .39983 .45082 .40091 .4566 .39897 .4556 .39789 Metetra
.664 .741 .907 r
.4556 .39789 .4566 .39897 .4624 .39703 .4614 .39594 Metetra
.664 .741 .907 r
.4614 .39594 .4624 .39703 .46821 .39508 .46721 .394 Metetra
.664 .741 .907 r
.46721 .394 .46821 .39508 .47403 .39313 .47304 .39205 Metetra
.664 .741 .907 r
.47304 .39205 .47403 .39313 .47987 .39118 .47888 .39009 Metetra
.664 .741 .907 r
.47888 .39009 .47987 .39118 .48571 .38922 .48472 .38813 Metetra
.664 .741 .907 r
.48472 .38813 .48571 .38922 .49157 .38726 .49059 .38617 Metetra
.664 .741 .907 r
.49059 .38617 .49157 .38726 .49744 .3853 .49646 .3842 Metetra
.664 .741 .907 r
.49646 .3842 .49744 .3853 .50333 .38332 .50235 .38222 Metetra
.664 .741 .907 r
.50235 .38222 .50333 .38332 .50923 .38135 .50825 .38025 Metetra
.664 .741 .907 r
.50825 .38025 .50923 .38135 .51514 .37937 .51416 .37827 Metetra
.664 .741 .907 r
.51416 .37827 .51514 .37937 .52106 .37739 .52008 .37628 Metetra
.664 .741 .907 r
.52008 .37628 .52106 .37739 .52699 .3754 .52602 .37429 Metetra
.664 .741 .907 r
.52602 .37429 .52699 .3754 .53294 .37341 .53197 .3723 Metetra
.664 .741 .907 r
.53197 .3723 .53294 .37341 .5389 .37141 .53794 .3703 Metetra
.664 .741 .907 r
.53794 .3703 .5389 .37141 .54488 .36941 .54391 .36829 Metetra
.664 .741 .907 r
.54391 .36829 .54488 .36941 .55086 .36741 .5499 .36629 Metetra
.664 .741 .907 r
.5499 .36629 .55086 .36741 .55686 .3654 .55591 .36428 Metetra
.664 .741 .907 r
.55591 .36428 .55686 .3654 .56288 .36338 .56192 .36226 Metetra
.664 .741 .907 r
.56192 .36226 .56288 .36338 .5689 .36137 .56795 .36024 Metetra
.664 .741 .907 r
.56795 .36024 .5689 .36137 .57494 .35934 .57399 .35822 Metetra
.664 .741 .907 r
.57399 .35822 .57494 .35934 .581 .35732 .58005 .35619 Metetra
.664 .741 .907 r
.58005 .35619 .581 .35732 .58706 .35529 .58612 .35415 Metetra
.664 .741 .907 r
.58612 .35415 .58706 .35529 .59314 .35325 .5922 .35211 Metetra
.664 .741 .907 r
.5922 .35211 .59314 .35325 .59923 .35121 .59829 .35007 Metetra
.664 .741 .907 r
.59829 .35007 .59923 .35121 .60534 .34917 .6044 .34803 Metetra
.664 .741 .907 r
.6044 .34803 .60534 .34917 .61146 .34712 .61052 .34597 Metetra
.664 .741 .907 r
.61052 .34597 .61146 .34712 .61759 .34506 .61666 .34392 Metetra
.664 .741 .907 r
.61666 .34392 .61759 .34506 .62373 .34301 .62281 .34186 Metetra
.664 .741 .907 r
.62281 .34186 .62373 .34301 .62989 .34094 .62897 .33979 Metetra
.664 .741 .907 r
.62897 .33979 .62989 .34094 .63607 .33888 .63514 .33772 Metetra
.664 .741 .907 r
.63514 .33772 .63607 .33888 .64225 .33681 .64133 .33565 Metetra
.664 .741 .907 r
.64133 .33565 .64225 .33681 .64845 .33473 .64754 .33357 Metetra
.664 .741 .907 r
.64754 .33357 .64845 .33473 .65467 .33265 .65375 .33149 Metetra
.664 .741 .907 r
.65375 .33149 .65467 .33265 .6609 .33056 .65998 .3294 Metetra
.965 .636 .31 r
.65998 .3294 .6609 .33056 .66714 .32847 .66923 .39427 Metetra
.419 .225 .509 r
.66923 .39427 .66714 .32847 .67339 .32638 .67249 .32521 Metetra
.664 .741 .907 r
.67249 .32521 .67339 .32638 .67966 .32428 .67876 .32311 Metetra
.664 .741 .907 r
.67876 .32311 .67966 .32428 .68594 .32218 .68504 .321 Metetra
.664 .741 .907 r
.68504 .321 .68594 .32218 .69224 .32007 .69134 .31889 Metetra
.664 .741 .907 r
.69134 .31889 .69224 .32007 .69855 .31795 .69766 .31677 Metetra
.664 .741 .907 r
.69766 .31677 .69855 .31795 .70488 .31584 .70399 .31465 Metetra
.664 .741 .907 r
.70399 .31465 .70488 .31584 .71122 .31371 .71033 .31253 Metetra
.664 .741 .907 r
.71033 .31253 .71122 .31371 .71757 .31159 .71668 .3104 Metetra
.664 .741 .907 r
.71668 .3104 .71757 .31159 .72394 .30945 .72305 .30826 Metetra
.664 .741 .907 r
.72305 .30826 .72394 .30945 .73032 .30732 .72944 .30612 Metetra
.664 .741 .907 r
.72944 .30612 .73032 .30732 .73672 .30518 .73584 .30398 Metetra
.664 .741 .907 r
.73584 .30398 .73672 .30518 .74313 .30303 .74225 .30183 Metetra
.664 .741 .907 r
.74225 .30183 .74313 .30303 .74955 .30088 .74868 .29967 Metetra
.664 .741 .907 r
.74868 .29967 .74955 .30088 .75599 .29872 .75512 .29752 Metetra
.664 .741 .907 r
.75512 .29752 .75599 .29872 .76245 .29656 .76158 .29535 Metetra
.664 .741 .907 r
.76158 .29535 .76245 .29656 .76891 .29439 .76805 .29318 Metetra
.664 .741 .907 r
.76805 .29318 .76891 .29439 .7754 .29222 .77454 .29101 Metetra
.664 .741 .907 r
.77454 .29101 .7754 .29222 .78189 .29005 .78104 .28883 Metetra
.664 .741 .907 r
.78104 .28883 .78189 .29005 .78841 .28787 .78755 .28665 Metetra
.664 .741 .907 r
.78755 .28665 .78841 .28787 .79493 .28568 .79409 .28446 Metetra
.664 .741 .907 r
.79409 .28446 .79493 .28568 .80148 .28349 .80063 .28227 Metetra
.664 .741 .907 r
.80063 .28227 .80148 .28349 .80803 .28129 .80719 .28007 Metetra
.664 .741 .907 r
.80719 .28007 .80803 .28129 .81461 .27909 .81377 .27786 Metetra
.664 .741 .907 r
.81377 .27786 .81461 .27909 .82119 .27689 .82036 .27566 Metetra
.664 .741 .907 r
.82036 .27566 .82119 .27689 .82779 .27468 .82696 .27344 Metetra
.664 .741 .907 r
.82696 .27344 .82779 .27468 .83441 .27246 .83358 .27122 Metetra
.664 .741 .907 r
.83358 .27122 .83441 .27246 .84104 .27024 .84022 .269 Metetra
.664 .741 .907 r
.84022 .269 .84104 .27024 .84769 .26802 .84687 .26677 Metetra
.664 .741 .907 r
.84687 .26677 .84769 .26802 .85435 .26578 .85353 .26454 Metetra
.664 .741 .907 r
.85353 .26454 .85435 .26578 .86103 .26355 .86021 .2623 Metetra
.664 .741 .907 r
.25906 .46238 .26014 .46339 .26553 .46158 .26445 .46057 Metetra
.664 .741 .907 r
.26445 .46057 .26553 .46158 .27093 .45977 .26986 .45876 Metetra
.664 .741 .907 r
.26986 .45876 .27093 .45977 .27634 .45796 .27527 .45695 Metetra
.664 .741 .907 r
.27527 .45695 .27634 .45796 .28176 .45614 .28069 .45513 Metetra
.664 .741 .907 r
.28069 .45513 .28176 .45614 .2872 .45432 .28613 .45331 Metetra
.664 .741 .907 r
.28613 .45331 .2872 .45432 .29264 .4525 .29158 .45148 Metetra
.664 .741 .907 r
.29158 .45148 .29264 .4525 .2981 .45067 .29704 .44965 Metetra
.664 .741 .907 r
.29704 .44965 .2981 .45067 .30357 .44884 .30251 .44781 Metetra
.664 .741 .907 r
.30251 .44781 .30357 .44884 .30905 .447 .30799 .44598 Metetra
.664 .741 .907 r
.30799 .44598 .30905 .447 .31392 .4548 .31348 .44413 Metetra
.574 .391 .596 r
.31348 .44413 .31392 .4548 .32004 .44332 .31898 .44229 Metetra
.664 .741 .907 r
.31898 .44229 .32004 .44332 .32555 .44147 .3245 .44044 Metetra
.664 .741 .907 r
.3245 .44044 .32555 .44147 .33108 .43962 .33003 .43858 Metetra
.664 .741 .907 r
.33003 .43858 .33108 .43962 .33661 .43776 .33556 .43673 Metetra
.664 .741 .907 r
.33556 .43673 .33661 .43776 .34216 .4359 .34111 .43487 Metetra
.664 .741 .907 r
.34111 .43487 .34216 .4359 .34772 .43404 .34668 .433 Metetra
.664 .741 .907 r
.34668 .433 .34772 .43404 .35329 .43217 .35225 .43113 Metetra
.664 .741 .907 r
.35225 .43113 .35329 .43217 .35887 .4303 .35783 .42926 Metetra
.664 .741 .907 r
.35783 .42926 .35887 .4303 .36447 .42843 .36343 .42738 Metetra
.664 .741 .907 r
.36343 .42738 .36447 .42843 .37007 .42655 .36904 .4255 Metetra
.664 .741 .907 r
.36904 .4255 .37007 .42655 .37569 .42467 .37466 .42362 Metetra
.664 .741 .907 r
.37466 .42362 .37569 .42467 .38132 .42278 .38029 .42173 Metetra
.664 .741 .907 r
.38029 .42173 .38132 .42278 .38696 .42089 .38593 .41983 Metetra
.664 .741 .907 r
.38593 .41983 .38696 .42089 .39262 .419 .39159 .41794 Metetra
.664 .741 .907 r
.39159 .41794 .39262 .419 .39828 .4171 .39726 .41604 Metetra
.664 .741 .907 r
.39726 .41604 .39828 .4171 .40396 .41519 .40294 .41413 Metetra
.664 .741 .907 r
.40294 .41413 .40396 .41519 .40965 .41329 .40863 .41222 Metetra
0 .34 .811 r
.40863 .41222 .40965 .41329 .41535 .41138 .41416 .4155 Metetra
.927 .648 .492 r
.41416 .4155 .41535 .41138 .42062 .42341 .41458 .57696 Metetra
.583 .356 .537 r
.41458 .57696 .42062 .42341 .41994 .6332 .41885 .6322 Metetra
.954 .695 .505 r
.41885 .6322 .41994 .6332 .43253 .40562 .43152 .40455 Metetra
.664 .741 .907 r
.43152 .40455 .43253 .40562 .43828 .40369 .43727 .40262 Metetra
.664 .741 .907 r
.43727 .40262 .43828 .40369 .44404 .40176 .44304 .40068 Metetra
.664 .741 .907 r
.44304 .40068 .44404 .40176 .44982 .39983 .44881 .39875 Metetra
.664 .741 .907 r
.44881 .39875 .44982 .39983 .4556 .39789 .4546 .3968 Metetra
.664 .741 .907 r
.4546 .3968 .4556 .39789 .4614 .39594 .4604 .39486 Metetra
.664 .741 .907 r
.4604 .39486 .4614 .39594 .46721 .394 .46622 .39291 Metetra
.664 .741 .907 r
.46622 .39291 .46721 .394 .47304 .39205 .47204 .39096 Metetra
.664 .741 .907 r
.47204 .39096 .47304 .39205 .47888 .39009 .47788 .389 Metetra
.664 .741 .907 r
.47788 .389 .47888 .39009 .48472 .38813 .48373 .38703 Metetra
.664 .741 .907 r
.48373 .38703 .48472 .38813 .49059 .38617 .4896 .38507 Metetra
.664 .741 .907 r
.4896 .38507 .49059 .38617 .49646 .3842 .49548 .3831 Metetra
.664 .741 .907 r
.49548 .3831 .49646 .3842 .50235 .38222 .50136 .38112 Metetra
.664 .741 .907 r
.50136 .38112 .50235 .38222 .50825 .38025 .50727 .37914 Metetra
.664 .741 .907 r
.50727 .37914 .50825 .38025 .51416 .37827 .51318 .37716 Metetra
.664 .741 .907 r
.51318 .37716 .51416 .37827 .52008 .37628 .51911 .37517 Metetra
.664 .741 .907 r
.51911 .37517 .52008 .37628 .52602 .37429 .52505 .37318 Metetra
.664 .741 .907 r
.52505 .37318 .52602 .37429 .53197 .3723 .531 .37118 Metetra
.664 .741 .907 r
.531 .37118 .53197 .3723 .53794 .3703 .53697 .36918 Metetra
.664 .741 .907 r
.53697 .36918 .53794 .3703 .54391 .36829 .54295 .36718 Metetra
.664 .741 .907 r
.54295 .36718 .54391 .36829 .5499 .36629 .54894 .36517 Metetra
.664 .741 .907 r
.54894 .36517 .5499 .36629 .55591 .36428 .55495 .36315 Metetra
.664 .741 .907 r
.55495 .36315 .55591 .36428 .56192 .36226 .56096 .36113 Metetra
.664 .741 .907 r
.56096 .36113 .56192 .36226 .56795 .36024 .567 .35911 Metetra
.664 .741 .907 r
.567 .35911 .56795 .36024 .57399 .35822 .57304 .35708 Metetra
.664 .741 .907 r
.57304 .35708 .57399 .35822 .58005 .35619 .5791 .35505 Metetra
.664 .741 .907 r
.5791 .35505 .58005 .35619 .58612 .35415 .58517 .35302 Metetra
.664 .741 .907 r
.58517 .35302 .58612 .35415 .5922 .35211 .59125 .35098 Metetra
.664 .741 .907 r
.59125 .35098 .5922 .35211 .59829 .35007 .59735 .34893 Metetra
.664 .741 .907 r
.59735 .34893 .59829 .35007 .6044 .34803 .60346 .34688 Metetra
.664 .741 .907 r
.60346 .34688 .6044 .34803 .61052 .34597 .60959 .34483 Metetra
.664 .741 .907 r
.60959 .34483 .61052 .34597 .61666 .34392 .61572 .34277 Metetra
.664 .741 .907 r
.61572 .34277 .61666 .34392 .62281 .34186 .62188 .34071 Metetra
.664 .741 .907 r
.62188 .34071 .62281 .34186 .62897 .33979 .62804 .33864 Metetra
.664 .741 .907 r
.62804 .33864 .62897 .33979 .63514 .33772 .63422 .33657 Metetra
.664 .741 .907 r
.63422 .33657 .63514 .33772 .64133 .33565 .64041 .33449 Metetra
.664 .741 .907 r
.64041 .33449 .64133 .33565 .64754 .33357 .64662 .33241 Metetra
.892 .489 .063 r
.64662 .33241 .64754 .33357 .65375 .33149 .65372 .35215 Metetra
.399 .193 .481 r
.65372 .35215 .65375 .33149 .65998 .3294 .65907 .32823 Metetra
.93 .555 .166 r
.65907 .32823 .65998 .3294 .66923 .39427 .66665 .35608 Metetra
.628 .403 .556 r
.66665 .35608 .66923 .39427 .67249 .32521 .67158 .32404 Metetra
.664 .741 .907 r
.67158 .32404 .67249 .32521 .67876 .32311 .67785 .32193 Metetra
.664 .741 .907 r
.67785 .32193 .67876 .32311 .68504 .321 .68414 .31982 Metetra
.664 .741 .907 r
.68414 .31982 .68504 .321 .69134 .31889 .69044 .31771 Metetra
.664 .741 .907 r
.69044 .31771 .69134 .31889 .69766 .31677 .69676 .31559 Metetra
.664 .741 .907 r
.69676 .31559 .69766 .31677 .70399 .31465 .70309 .31347 Metetra
.664 .741 .907 r
.70309 .31347 .70399 .31465 .71033 .31253 .70944 .31134 Metetra
.664 .741 .907 r
.70944 .31134 .71033 .31253 .71668 .3104 .7158 .30921 Metetra
.664 .741 .907 r
.7158 .30921 .71668 .3104 .72305 .30826 .72217 .30707 Metetra
.664 .741 .907 r
.72217 .30707 .72305 .30826 .72944 .30612 .72856 .30493 Metetra
.664 .741 .907 r
.72856 .30493 .72944 .30612 .73584 .30398 .73496 .30278 Metetra
.664 .741 .907 r
.73496 .30278 .73584 .30398 .74225 .30183 .74138 .30063 Metetra
.664 .741 .907 r
.74138 .30063 .74225 .30183 .74868 .29967 .74781 .29847 Metetra
.664 .741 .907 r
.74781 .29847 .74868 .29967 .75512 .29752 .75425 .29631 Metetra
.664 .741 .907 r
.75425 .29631 .75512 .29752 .76158 .29535 .76071 .29414 Metetra
.664 .741 .907 r
.76071 .29414 .76158 .29535 .76805 .29318 .76719 .29197 Metetra
.664 .741 .907 r
.76719 .29197 .76805 .29318 .77454 .29101 .77368 .2898 Metetra
.664 .741 .907 r
.77368 .2898 .77454 .29101 .78104 .28883 .78018 .28761 Metetra
.664 .741 .907 r
.78018 .28761 .78104 .28883 .78755 .28665 .7867 .28543 Metetra
.664 .741 .907 r
.7867 .28543 .78755 .28665 .79409 .28446 .79324 .28324 Metetra
.664 .741 .907 r
.79324 .28324 .79409 .28446 .80063 .28227 .79978 .28104 Metetra
.664 .741 .907 r
.79978 .28104 .80063 .28227 .80719 .28007 .80635 .27884 Metetra
.664 .741 .907 r
.80635 .27884 .80719 .28007 .81377 .27786 .81292 .27663 Metetra
.664 .741 .907 r
.81292 .27663 .81377 .27786 .82036 .27566 .81952 .27442 Metetra
.664 .741 .907 r
.81952 .27442 .82036 .27566 .82696 .27344 .82613 .27221 Metetra
.664 .741 .907 r
.82613 .27221 .82696 .27344 .83358 .27122 .83275 .26998 Metetra
.664 .741 .907 r
.83275 .26998 .83358 .27122 .84022 .269 .83939 .26776 Metetra
.664 .741 .907 r
.83939 .26776 .84022 .269 .84687 .26677 .84604 .26553 Metetra
.664 .741 .907 r
.84604 .26553 .84687 .26677 .85353 .26454 .85271 .26329 Metetra
.664 .741 .907 r
.85271 .26329 .85353 .26454 .86021 .2623 .8594 .26105 Metetra
.664 .741 .907 r
.25798 .46137 .25906 .46238 .26445 .46057 .26338 .45956 Metetra
.664 .741 .907 r
.26338 .45956 .26445 .46057 .26986 .45876 .26878 .45775 Metetra
.664 .741 .907 r
.26878 .45775 .26986 .45876 .27527 .45695 .2742 .45593 Metetra
.664 .741 .907 r
.2742 .45593 .27527 .45695 .28069 .45513 .27962 .45411 Metetra
.664 .741 .907 r
.27962 .45411 .28069 .45513 .28613 .45331 .28506 .45229 Metetra
.664 .741 .907 r
.28506 .45229 .28613 .45331 .29158 .45148 .29051 .45046 Metetra
.664 .741 .907 r
.29051 .45046 .29158 .45148 .29704 .44965 .29597 .44863 Metetra
.664 .741 .907 r
.29597 .44863 .29704 .44965 .30251 .44781 .30144 .44679 Metetra
.664 .741 .907 r
.30144 .44679 .30251 .44781 .30799 .44598 .30693 .44495 Metetra
0 .101 .598 r
.30693 .44495 .30799 .44598 .31348 .44413 .31202 .44931 Metetra
.267 0 .309 r
.31202 .44931 .31348 .44413 .31898 .44229 .31793 .44126 Metetra
.664 .741 .907 r
.31793 .44126 .31898 .44229 .3245 .44044 .32344 .4394 Metetra
.664 .741 .907 r
.32344 .4394 .3245 .44044 .33003 .43858 .32897 .43755 Metetra
.664 .741 .907 r
.32897 .43755 .33003 .43858 .33556 .43673 .33451 .43569 Metetra
.664 .741 .907 r
.33451 .43569 .33556 .43673 .34111 .43487 .34007 .43383 Metetra
.664 .741 .907 r
.34007 .43383 .34111 .43487 .34668 .433 .34563 .43196 Metetra
.664 .741 .907 r
.34563 .43196 .34668 .433 .35225 .43113 .3512 .43009 Metetra
.664 .741 .907 r
.3512 .43009 .35225 .43113 .35783 .42926 .35679 .42821 Metetra
.664 .741 .907 r
.35679 .42821 .35783 .42926 .36343 .42738 .36239 .42633 Metetra
.664 .741 .907 r
.36239 .42633 .36343 .42738 .36904 .4255 .368 .42445 Metetra
.664 .741 .907 r
.368 .42445 .36904 .4255 .37466 .42362 .37362 .42256 Metetra
.664 .741 .907 r
.37362 .42256 .37466 .42362 .38029 .42173 .37926 .42067 Metetra
.664 .741 .907 r
.37926 .42067 .38029 .42173 .38593 .41983 .3849 .41878 Metetra
.664 .741 .907 r
.3849 .41878 .38593 .41983 .39159 .41794 .39056 .41688 Metetra
.664 .741 .907 r
.39056 .41688 .39159 .41794 .39726 .41604 .39623 .41497 Metetra
.664 .741 .907 r
.39623 .41497 .39726 .41604 .40294 .41413 .40191 .41307 Metetra
.664 .741 .907 r
.40191 .41307 .40294 .41413 .40863 .41222 .40761 .41116 Metetra
.664 .741 .907 r
.40761 .41116 .40863 .41222 .41416 .4155 .41331 .40924 Metetra
.982 .706 .419 r
.41331 .40924 .41416 .4155 .41458 .57696 .41431 .55149 Metetra
.714 .481 .57 r
.41431 .55149 .41458 .57696 .41885 .6322 .42188 .49824 Metetra
.622 .393 .55 r
.42188 .49824 .41885 .6322 .43152 .40455 .43051 .40347 Metetra
.664 .741 .907 r
.43051 .40347 .43152 .40455 .43727 .40262 .43626 .40154 Metetra
.664 .741 .907 r
.43626 .40154 .43727 .40262 .44304 .40068 .44203 .3996 Metetra
.664 .741 .907 r
.44203 .3996 .44304 .40068 .44881 .39875 .44781 .39766 Metetra
.664 .741 .907 r
.44781 .39766 .44881 .39875 .4546 .3968 .4536 .39572 Metetra
.664 .741 .907 r
.4536 .39572 .4546 .3968 .4604 .39486 .4594 .39377 Metetra
.664 .741 .907 r
.4594 .39377 .4604 .39486 .46622 .39291 .46522 .39182 Metetra
.664 .741 .907 r
.46522 .39182 .46622 .39291 .47204 .39096 .47105 .38986 Metetra
.664 .741 .907 r
.47105 .38986 .47204 .39096 .47788 .389 .47689 .3879 Metetra
.664 .741 .907 r
.47689 .3879 .47788 .389 .48373 .38703 .48274 .38594 Metetra
.664 .741 .907 r
.48274 .38594 .48373 .38703 .4896 .38507 .48861 .38397 Metetra
.664 .741 .907 r
.48861 .38397 .4896 .38507 .49548 .3831 .49449 .382 Metetra
.664 .741 .907 r
.49449 .382 .49548 .3831 .50136 .38112 .50038 .38002 Metetra
.664 .741 .907 r
.50038 .38002 .50136 .38112 .50727 .37914 .50629 .37804 Metetra
.664 .741 .907 r
.50629 .37804 .50727 .37914 .51318 .37716 .5122 .37605 Metetra
.664 .741 .907 r
.5122 .37605 .51318 .37716 .51911 .37517 .51813 .37406 Metetra
.664 .741 .907 r
.51813 .37406 .51911 .37517 .52505 .37318 .52408 .37207 Metetra
.664 .741 .907 r
.52408 .37207 .52505 .37318 .531 .37118 .53003 .37007 Metetra
.664 .741 .907 r
.53003 .37007 .531 .37118 .53697 .36918 .536 .36806 Metetra
.664 .741 .907 r
.536 .36806 .53697 .36918 .54295 .36718 .54198 .36606 Metetra
.664 .741 .907 r
.54198 .36606 .54295 .36718 .54894 .36517 .54798 .36404 Metetra
.664 .741 .907 r
.54798 .36404 .54894 .36517 .55495 .36315 .55399 .36203 Metetra
.664 .741 .907 r
.55399 .36203 .55495 .36315 .56096 .36113 .56001 .36001 Metetra
.664 .741 .907 r
.56001 .36001 .56096 .36113 .567 .35911 .56604 .35798 Metetra
.664 .741 .907 r
.56604 .35798 .567 .35911 .57304 .35708 .57209 .35595 Metetra
.664 .741 .907 r
.57209 .35595 .57304 .35708 .5791 .35505 .57815 .35392 Metetra
.664 .741 .907 r
.57815 .35392 .5791 .35505 .58517 .35302 .58422 .35188 Metetra
.664 .741 .907 r
.58422 .35188 .58517 .35302 .59125 .35098 .59031 .34984 Metetra
.664 .741 .907 r
.59031 .34984 .59125 .35098 .59735 .34893 .59641 .34779 Metetra
.664 .741 .907 r
.59641 .34779 .59735 .34893 .60346 .34688 .60252 .34574 Metetra
.664 .741 .907 r
.60252 .34574 .60346 .34688 .60959 .34483 .60865 .34368 Metetra
.664 .741 .907 r
.60865 .34368 .60959 .34483 .61572 .34277 .61479 .34162 Metetra
.664 .741 .907 r
.61479 .34162 .61572 .34277 .62188 .34071 .62094 .33955 Metetra
.664 .741 .907 r
.62094 .33955 .62188 .34071 .62804 .33864 .62711 .33748 Metetra
.664 .741 .907 r
.62711 .33748 .62804 .33864 .63422 .33657 .63329 .33541 Metetra
.664 .741 .907 r
.63329 .33541 .63422 .33657 .64041 .33449 .63949 .33333 Metetra
.664 .741 .907 r
.63949 .33333 .64041 .33449 .64662 .33241 .6457 .33125 Metetra
.516 .678 .938 r
.6457 .33125 .64662 .33241 .65372 .35215 .652 .33106 Metetra
.468 .293 .56 r
.652 .33106 .65372 .35215 .65907 .32823 .65896 .34611 Metetra
.395 .186 .474 r
.65896 .34611 .65907 .32823 .66665 .35608 .6644 .32497 Metetra
.557 .352 .558 r
.6644 .32497 .66665 .35608 .67158 .32404 .67067 .32286 Metetra
.664 .741 .907 r
.67067 .32286 .67158 .32404 .67785 .32193 .67695 .32076 Metetra
.664 .741 .907 r
.67695 .32076 .67785 .32193 .68414 .31982 .68324 .31865 Metetra
.664 .741 .907 r
.68324 .31865 .68414 .31982 .69044 .31771 .68954 .31653 Metetra
.664 .741 .907 r
.68954 .31653 .69044 .31771 .69676 .31559 .69586 .31441 Metetra
.664 .741 .907 r
.69586 .31441 .69676 .31559 .70309 .31347 .7022 .31228 Metetra
.664 .741 .907 r
.7022 .31228 .70309 .31347 .70944 .31134 .70855 .31015 Metetra
.664 .741 .907 r
.70855 .31015 .70944 .31134 .7158 .30921 .71491 .30802 Metetra
.664 .741 .907 r
.71491 .30802 .7158 .30921 .72217 .30707 .72129 .30588 Metetra
.664 .741 .907 r
.72129 .30588 .72217 .30707 .72856 .30493 .72768 .30373 Metetra
.664 .741 .907 r
.72768 .30373 .72856 .30493 .73496 .30278 .73408 .30158 Metetra
.664 .741 .907 r
.73408 .30158 .73496 .30278 .74138 .30063 .7405 .29943 Metetra
.664 .741 .907 r
.7405 .29943 .74138 .30063 .74781 .29847 .74694 .29727 Metetra
.664 .741 .907 r
.74694 .29727 .74781 .29847 .75425 .29631 .75338 .2951 Metetra
.664 .741 .907 r
.75338 .2951 .75425 .29631 .76071 .29414 .75985 .29293 Metetra
.664 .741 .907 r
.75985 .29293 .76071 .29414 .76719 .29197 .76633 .29076 Metetra
.664 .741 .907 r
.76633 .29076 .76719 .29197 .77368 .2898 .77282 .28858 Metetra
.664 .741 .907 r
.77282 .28858 .77368 .2898 .78018 .28761 .77932 .2864 Metetra
.664 .741 .907 r
.77932 .2864 .78018 .28761 .7867 .28543 .78585 .28421 Metetra
.664 .741 .907 r
.78585 .28421 .7867 .28543 .79324 .28324 .79238 .28201 Metetra
.664 .741 .907 r
.79238 .28201 .79324 .28324 .79978 .28104 .79894 .27981 Metetra
.664 .741 .907 r
.79894 .27981 .79978 .28104 .80635 .27884 .8055 .27761 Metetra
.664 .741 .907 r
.8055 .27761 .80635 .27884 .81292 .27663 .81208 .2754 Metetra
.664 .741 .907 r
.81208 .2754 .81292 .27663 .81952 .27442 .81868 .27319 Metetra
.664 .741 .907 r
.81868 .27319 .81952 .27442 .82613 .27221 .82529 .27097 Metetra
.664 .741 .907 r
.82529 .27097 .82613 .27221 .83275 .26998 .83192 .26874 Metetra
.664 .741 .907 r
.83192 .26874 .83275 .26998 .83939 .26776 .83856 .26651 Metetra
.664 .741 .907 r
.83856 .26651 .83939 .26776 .84604 .26553 .84522 .26428 Metetra
.664 .741 .907 r
.84522 .26428 .84604 .26553 .85271 .26329 .85189 .26204 Metetra
.664 .741 .907 r
.85189 .26204 .85271 .26329 .8594 .26105 .85858 .2598 Metetra
.664 .741 .907 r
.2569 .46037 .25798 .46137 .26338 .45956 .2623 .45855 Metetra
.664 .741 .907 r
.2623 .45855 .26338 .45956 .26878 .45775 .26771 .45674 Metetra
.664 .741 .907 r
.26771 .45674 .26878 .45775 .2742 .45593 .27312 .45492 Metetra
.664 .741 .907 r
.27312 .45492 .2742 .45593 .27962 .45411 .27855 .45309 Metetra
.664 .741 .907 r
.27855 .45309 .27962 .45411 .28506 .45229 .28399 .45127 Metetra
.664 .741 .907 r
.28399 .45127 .28506 .45229 .29051 .45046 .28944 .44944 Metetra
.664 .741 .907 r
.28944 .44944 .29051 .45046 .29597 .44863 .2949 .4476 Metetra
.664 .741 .907 r
.2949 .4476 .29597 .44863 .30144 .44679 .30038 .44576 Metetra
.948 .64 .42 r
.30038 .44576 .30144 .44679 .30693 .44495 .30334 .48153 Metetra
.381 .179 .476 r
.30334 .48153 .30693 .44495 .31202 .44931 .31136 .44207 Metetra
.585 .418 .622 r
.31136 .44207 .31202 .44931 .31793 .44126 .31687 .44022 Metetra
.664 .741 .907 r
.31687 .44022 .31793 .44126 .32344 .4394 .32239 .43837 Metetra
.664 .741 .907 r
.32239 .43837 .32344 .4394 .32897 .43755 .32792 .43651 Metetra
.664 .741 .907 r
.32792 .43651 .32897 .43755 .33451 .43569 .33346 .43465 Metetra
.664 .741 .907 r
.33346 .43465 .33451 .43569 .34007 .43383 .33902 .43278 Metetra
.664 .741 .907 r
.33902 .43278 .34007 .43383 .34563 .43196 .34458 .43092 Metetra
.664 .741 .907 r
.34458 .43092 .34563 .43196 .3512 .43009 .35016 .42904 Metetra
.664 .741 .907 r
.35016 .42904 .3512 .43009 .35679 .42821 .35575 .42716 Metetra
.664 .741 .907 r
.35575 .42716 .35679 .42821 .36239 .42633 .36135 .42528 Metetra
.664 .741 .907 r
.36135 .42528 .36239 .42633 .368 .42445 .36696 .4234 Metetra
.664 .741 .907 r
.36696 .4234 .368 .42445 .37362 .42256 .37259 .42151 Metetra
.664 .741 .907 r
.37259 .42151 .37362 .42256 .37926 .42067 .37822 .41961 Metetra
.664 .741 .907 r
.37822 .41961 .37926 .42067 .3849 .41878 .38387 .41772 Metetra
.664 .741 .907 r
.38387 .41772 .3849 .41878 .39056 .41688 .38953 .41582 Metetra
.664 .741 .907 r
.38953 .41582 .39056 .41688 .39623 .41497 .3952 .41391 Metetra
.664 .741 .907 r
.3952 .41391 .39623 .41497 .40191 .41307 .40089 .412 Metetra
.664 .741 .907 r
.40089 .412 .40191 .41307 .40761 .41116 .40659 .41009 Metetra
.664 .741 .907 r
.40659 .41009 .40761 .41116 .41331 .40924 .41229 .40817 Metetra
.957 .652 .414 r
.41229 .40817 .41331 .40924 .41431 .55149 .41619 .46125 Metetra
.543 .33 .542 r
.41619 .46125 .41431 .55149 .42188 .49824 .42182 .4658 Metetra
.707 .471 .565 r
.42182 .4658 .42188 .49824 .43051 .40347 .42949 .40239 Metetra
.664 .741 .907 r
.42949 .40239 .43051 .40347 .43626 .40154 .43525 .40046 Metetra
.664 .741 .907 r
.43525 .40046 .43626 .40154 .44203 .3996 .44102 .39852 Metetra
.664 .741 .907 r
.44102 .39852 .44203 .3996 .44781 .39766 .4468 .39658 Metetra
.664 .741 .907 r
.4468 .39658 .44781 .39766 .4536 .39572 .45259 .39463 Metetra
.664 .741 .907 r
.45259 .39463 .4536 .39572 .4594 .39377 .4584 .39268 Metetra
.664 .741 .907 r
.4584 .39268 .4594 .39377 .46522 .39182 .46422 .39073 Metetra
.664 .741 .907 r
.46422 .39073 .46522 .39182 .47105 .38986 .47005 .38877 Metetra
.664 .741 .907 r
.47005 .38877 .47105 .38986 .47689 .3879 .47589 .38681 Metetra
.664 .741 .907 r
.47589 .38681 .47689 .3879 .48274 .38594 .48175 .38484 Metetra
.664 .741 .907 r
.48175 .38484 .48274 .38594 .48861 .38397 .48762 .38287 Metetra
.664 .741 .907 r
.48762 .38287 .48861 .38397 .49449 .382 .4935 .38089 Metetra
.664 .741 .907 r
.4935 .38089 .49449 .382 .50038 .38002 .4994 .37891 Metetra
.664 .741 .907 r
.4994 .37891 .50038 .38002 .50629 .37804 .5053 .37693 Metetra
.664 .741 .907 r
.5053 .37693 .50629 .37804 .5122 .37605 .51122 .37494 Metetra
.664 .741 .907 r
.51122 .37494 .5122 .37605 .51813 .37406 .51716 .37295 Metetra
.664 .741 .907 r
.51716 .37295 .51813 .37406 .52408 .37207 .5231 .37095 Metetra
.664 .741 .907 r
.5231 .37095 .52408 .37207 .53003 .37007 .52906 .36895 Metetra
.664 .741 .907 r
.52906 .36895 .53003 .37007 .536 .36806 .53503 .36694 Metetra
.664 .741 .907 r
.53503 .36694 .536 .36806 .54198 .36606 .54102 .36493 Metetra
.664 .741 .907 r
.54102 .36493 .54198 .36606 .54798 .36404 .54701 .36292 Metetra
.664 .741 .907 r
.54701 .36292 .54798 .36404 .55399 .36203 .55302 .3609 Metetra
.664 .741 .907 r
.55302 .3609 .55399 .36203 .56001 .36001 .55905 .35888 Metetra
.664 .741 .907 r
.55905 .35888 .56001 .36001 .56604 .35798 .56508 .35685 Metetra
.664 .741 .907 r
.56508 .35685 .56604 .35798 .57209 .35595 .57113 .35482 Metetra
.664 .741 .907 r
.57113 .35482 .57209 .35595 .57815 .35392 .5772 .35278 Metetra
.664 .741 .907 r
.5772 .35278 .57815 .35392 .58422 .35188 .58327 .35074 Metetra
.664 .741 .907 r
.58327 .35074 .58422 .35188 .59031 .34984 .58936 .34869 Metetra
.664 .741 .907 r
.58936 .34869 .59031 .34984 .59641 .34779 .59547 .34664 Metetra
.664 .741 .907 r
.59547 .34664 .59641 .34779 .60252 .34574 .60158 .34459 Metetra
.664 .741 .907 r
.60158 .34459 .60252 .34574 .60865 .34368 .60771 .34253 Metetra
.664 .741 .907 r
.60771 .34253 .60865 .34368 .61479 .34162 .61385 .34047 Metetra
.664 .741 .907 r
.61385 .34047 .61479 .34162 .62094 .33955 .62001 .3384 Metetra
.664 .741 .907 r
.62001 .3384 .62094 .33955 .62711 .33748 .62618 .33633 Metetra
.664 .741 .907 r
.62618 .33633 .62711 .33748 .63329 .33541 .63237 .33425 Metetra
.664 .741 .907 r
.63237 .33425 .63329 .33541 .63949 .33333 .63856 .33217 Metetra
.664 .741 .907 r
.63856 .33217 .63949 .33333 .6457 .33125 .64478 .33008 Metetra
.664 .741 .907 r
.64478 .33008 .6457 .33125 .652 .33106 .651 .32799 Metetra
.625 .532 .729 r
.651 .32799 .652 .33106 .65896 .34611 .65724 .32589 Metetra
.562 .363 .569 r
.65724 .32589 .65896 .34611 .6644 .32497 .66349 .32379 Metetra
.664 .741 .907 r
.66349 .32379 .6644 .32497 .67067 .32286 .66976 .32169 Metetra
.664 .741 .907 r
.66976 .32169 .67067 .32286 .67695 .32076 .67604 .31958 Metetra
.664 .741 .907 r
.67604 .31958 .67695 .32076 .68324 .31865 .68233 .31747 Metetra
.664 .741 .907 r
.68233 .31747 .68324 .31865 .68954 .31653 .68864 .31535 Metetra
.664 .741 .907 r
.68864 .31535 .68954 .31653 .69586 .31441 .69497 .31322 Metetra
.664 .741 .907 r
.69497 .31322 .69586 .31441 .7022 .31228 .7013 .31109 Metetra
.664 .741 .907 r
.7013 .31109 .7022 .31228 .70855 .31015 .70765 .30896 Metetra
.664 .741 .907 r
.70765 .30896 .70855 .31015 .71491 .30802 .71402 .30682 Metetra
.664 .741 .907 r
.71402 .30682 .71491 .30802 .72129 .30588 .7204 .30468 Metetra
.664 .741 .907 r
.7204 .30468 .72129 .30588 .72768 .30373 .72679 .30253 Metetra
.664 .741 .907 r
.72679 .30253 .72768 .30373 .73408 .30158 .7332 .30038 Metetra
.664 .741 .907 r
.7332 .30038 .73408 .30158 .7405 .29943 .73962 .29822 Metetra
.664 .741 .907 r
.73962 .29822 .7405 .29943 .74694 .29727 .74606 .29606 Metetra
.664 .741 .907 r
.74606 .29606 .74694 .29727 .75338 .2951 .75251 .29389 Metetra
.664 .741 .907 r
.75251 .29389 .75338 .2951 .75985 .29293 .75898 .29172 Metetra
.664 .741 .907 r
.75898 .29172 .75985 .29293 .76633 .29076 .76546 .28954 Metetra
.664 .741 .907 r
.76546 .28954 .76633 .29076 .77282 .28858 .77196 .28736 Metetra
.664 .741 .907 r
.77196 .28736 .77282 .28858 .77932 .2864 .77847 .28518 Metetra
.664 .741 .907 r
.77847 .28518 .77932 .2864 .78585 .28421 .78499 .28298 Metetra
.664 .741 .907 r
.78499 .28298 .78585 .28421 .79238 .28201 .79153 .28079 Metetra
.664 .741 .907 r
.79153 .28079 .79238 .28201 .79894 .27981 .79809 .27858 Metetra
.664 .741 .907 r
.79809 .27858 .79894 .27981 .8055 .27761 .80466 .27638 Metetra
.664 .741 .907 r
.80466 .27638 .8055 .27761 .81208 .2754 .81124 .27417 Metetra
.664 .741 .907 r
.81124 .27417 .81208 .2754 .81868 .27319 .81784 .27195 Metetra
.664 .741 .907 r
.81784 .27195 .81868 .27319 .82529 .27097 .82445 .26973 Metetra
.664 .741 .907 r
.82445 .26973 .82529 .27097 .83192 .26874 .83108 .2675 Metetra
.664 .741 .907 r
.83108 .2675 .83192 .26874 .83856 .26651 .83773 .26527 Metetra
.664 .741 .907 r
.83773 .26527 .83856 .26651 .84522 .26428 .84439 .26303 Metetra
.664 .741 .907 r
.84439 .26303 .84522 .26428 .85189 .26204 .85107 .26079 Metetra
.664 .741 .907 r
.85107 .26079 .85189 .26204 .85858 .2598 .85776 .25854 Metetra
.664 .741 .907 r
.25582 .45936 .2569 .46037 .2623 .45855 .26122 .45754 Metetra
.664 .741 .907 r
.26122 .45754 .2623 .45855 .26771 .45674 .26663 .45572 Metetra
.664 .741 .907 r
.26663 .45572 .26771 .45674 .27312 .45492 .27205 .4539 Metetra
.664 .741 .907 r
.27205 .4539 .27312 .45492 .27855 .45309 .27748 .45208 Metetra
.664 .741 .907 r
.27748 .45208 .27855 .45309 .28399 .45127 .28292 .45025 Metetra
.664 .741 .907 r
.28292 .45025 .28399 .45127 .28944 .44944 .28837 .44841 Metetra
.664 .741 .907 r
.28837 .44841 .28944 .44944 .2949 .4476 .29384 .44658 Metetra
.664 .741 .907 r
.29384 .44658 .2949 .4476 .30038 .44576 .29931 .44474 Metetra
.948 .644 .428 r
.29931 .44474 .30038 .44576 .30334 .48153 .30209 .48312 Metetra
.98 .779 .562 r
.30209 .48312 .30334 .48153 .31136 .44207 .3103 .44104 Metetra
.664 .741 .907 r
.3103 .44104 .31136 .44207 .31687 .44022 .31581 .43919 Metetra
.664 .741 .907 r
.31581 .43919 .31687 .44022 .32239 .43837 .32133 .43733 Metetra
.664 .741 .907 r
.32133 .43733 .32239 .43837 .32792 .43651 .32686 .43547 Metetra
.664 .741 .907 r
.32686 .43547 .32792 .43651 .33346 .43465 .33241 .43361 Metetra
.664 .741 .907 r
.33241 .43361 .33346 .43465 .33902 .43278 .33797 .43174 Metetra
.664 .741 .907 r
.33797 .43174 .33902 .43278 .34458 .43092 .34353 .42987 Metetra
.664 .741 .907 r
.34353 .42987 .34458 .43092 .35016 .42904 .34911 .42799 Metetra
.664 .741 .907 r
.34911 .42799 .35016 .42904 .35575 .42716 .3547 .42612 Metetra
.664 .741 .907 r
.3547 .42612 .35575 .42716 .36135 .42528 .36031 .42423 Metetra
.664 .741 .907 r
.36031 .42423 .36135 .42528 .36696 .4234 .36592 .42234 Metetra
.664 .741 .907 r
.36592 .42234 .36696 .4234 .37259 .42151 .37155 .42045 Metetra
.664 .741 .907 r
.37155 .42045 .37259 .42151 .37822 .41961 .37719 .41856 Metetra
.664 .741 .907 r
.37719 .41856 .37822 .41961 .38387 .41772 .38284 .41666 Metetra
.664 .741 .907 r
.38284 .41666 .38387 .41772 .38953 .41582 .3885 .41475 Metetra
.664 .741 .907 r
.3885 .41475 .38953 .41582 .3952 .41391 .39418 .41285 Metetra
.664 .741 .907 r
.39418 .41285 .3952 .41391 .40089 .412 .39986 .41094 Metetra
.664 .741 .907 r
.39986 .41094 .40089 .412 .40659 .41009 .40556 .40902 Metetra
.664 .741 .907 r
.40556 .40902 .40659 .41009 .41229 .40817 .41127 .4071 Metetra
.664 .741 .907 r
.41127 .4071 .41229 .40817 .41619 .46125 .41699 .40518 Metetra
.519 .315 .542 r
.41699 .40518 .41619 .46125 .42182 .4658 .42223 .41894 Metetra
.589 .372 .554 r
.42223 .41894 .42182 .4658 .42949 .40239 .42848 .40132 Metetra
.664 .741 .907 r
.42848 .40132 .42949 .40239 .43525 .40046 .43424 .39938 Metetra
.664 .741 .907 r
.43424 .39938 .43525 .40046 .44102 .39852 .44001 .39744 Metetra
.664 .741 .907 r
.44001 .39744 .44102 .39852 .4468 .39658 .44579 .3955 Metetra
.948 .594 .29 r
.44579 .3955 .4468 .39658 .45259 .39463 .45098 .42046 Metetra
.387 .182 .475 r
.45098 .42046 .45259 .39463 .4584 .39268 .4574 .39159 Metetra
.664 .741 .907 r
.4574 .39159 .4584 .39268 .46422 .39073 .46322 .38964 Metetra
.664 .741 .907 r
.46322 .38964 .46422 .39073 .47005 .38877 .46905 .38768 Metetra
.664 .741 .907 r
.46905 .38768 .47005 .38877 .47589 .38681 .4749 .38571 Metetra
.664 .741 .907 r
.4749 .38571 .47589 .38681 .48175 .38484 .48076 .38374 Metetra
.664 .741 .907 r
.48076 .38374 .48175 .38484 .48762 .38287 .48663 .38177 Metetra
.664 .741 .907 r
.48663 .38177 .48762 .38287 .4935 .38089 .49251 .37979 Metetra
.664 .741 .907 r
.49251 .37979 .4935 .38089 .4994 .37891 .49841 .37781 Metetra
.664 .741 .907 r
.49841 .37781 .4994 .37891 .5053 .37693 .50432 .37582 Metetra
.664 .741 .907 r
.50432 .37582 .5053 .37693 .51122 .37494 .51024 .37383 Metetra
.664 .741 .907 r
.51024 .37383 .51122 .37494 .51716 .37295 .51618 .37183 Metetra
.664 .741 .907 r
.51618 .37183 .51716 .37295 .5231 .37095 .52213 .36984 Metetra
.664 .741 .907 r
.52213 .36984 .5231 .37095 .52906 .36895 .52809 .36783 Metetra
.664 .741 .907 r
.52809 .36783 .52906 .36895 .53503 .36694 .53406 .36582 Metetra
.664 .741 .907 r
.53406 .36582 .53503 .36694 .54102 .36493 .54005 .36381 Metetra
.664 .741 .907 r
.54005 .36381 .54102 .36493 .54701 .36292 .54605 .36179 Metetra
.664 .741 .907 r
.54605 .36179 .54701 .36292 .55302 .3609 .55206 .35977 Metetra
.664 .741 .907 r
.55206 .35977 .55302 .3609 .55905 .35888 .55809 .35775 Metetra
.664 .741 .907 r
.55809 .35775 .55905 .35888 .56508 .35685 .56413 .35572 Metetra
.664 .741 .907 r
.56413 .35572 .56508 .35685 .57113 .35482 .57018 .35368 Metetra
.664 .741 .907 r
.57018 .35368 .57113 .35482 .5772 .35278 .57624 .35164 Metetra
.664 .741 .907 r
.57624 .35164 .5772 .35278 .58327 .35074 .58232 .3496 Metetra
.664 .741 .907 r
.58232 .3496 .58327 .35074 .58936 .34869 .58841 .34755 Metetra
.664 .741 .907 r
.58841 .34755 .58936 .34869 .59547 .34664 .59452 .3455 Metetra
.664 .741 .907 r
.59452 .3455 .59547 .34664 .60158 .34459 .60064 .34344 Metetra
.664 .741 .907 r
.60064 .34344 .60158 .34459 .60771 .34253 .60677 .34138 Metetra
.664 .741 .907 r
.60677 .34138 .60771 .34253 .61385 .34047 .61292 .33931 Metetra
.664 .741 .907 r
.61292 .33931 .61385 .34047 .62001 .3384 .61908 .33724 Metetra
.664 .741 .907 r
.61908 .33724 .62001 .3384 .62618 .33633 .62525 .33517 Metetra
.664 .741 .907 r
.62525 .33517 .62618 .33633 .63237 .33425 .63144 .33309 Metetra
.664 .741 .907 r
.63144 .33309 .63237 .33425 .63856 .33217 .63764 .331 Metetra
.664 .741 .907 r
.63764 .331 .63856 .33217 .64478 .33008 .64385 .32892 Metetra
.664 .741 .907 r
.64385 .32892 .64478 .33008 .651 .32799 .65008 .32682 Metetra
.664 .741 .907 r
.65008 .32682 .651 .32799 .65724 .32589 .65632 .32472 Metetra
.664 .741 .907 r
.65632 .32472 .65724 .32589 .66349 .32379 .66258 .32262 Metetra
.664 .741 .907 r
.66258 .32262 .66349 .32379 .66976 .32169 .66885 .32051 Metetra
.664 .741 .907 r
.66885 .32051 .66976 .32169 .67604 .31958 .67513 .3184 Metetra
.664 .741 .907 r
.67513 .3184 .67604 .31958 .68233 .31747 .68143 .31628 Metetra
.664 .741 .907 r
.68143 .31628 .68233 .31747 .68864 .31535 .68774 .31416 Metetra
.664 .741 .907 r
.68774 .31416 .68864 .31535 .69497 .31322 .69407 .31204 Metetra
.664 .741 .907 r
.69407 .31204 .69497 .31322 .7013 .31109 .70041 .3099 Metetra
.664 .741 .907 r
.70041 .3099 .7013 .31109 .70765 .30896 .70676 .30777 Metetra
.664 .741 .907 r
.70676 .30777 .70765 .30896 .71402 .30682 .71313 .30563 Metetra
.664 .741 .907 r
.71313 .30563 .71402 .30682 .7204 .30468 .71951 .30348 Metetra
.664 .741 .907 r
.71951 .30348 .7204 .30468 .72679 .30253 .72591 .30133 Metetra
.664 .741 .907 r
.72591 .30133 .72679 .30253 .7332 .30038 .73232 .29918 Metetra
.664 .741 .907 r
.73232 .29918 .7332 .30038 .73962 .29822 .73875 .29702 Metetra
.664 .741 .907 r
.73875 .29702 .73962 .29822 .74606 .29606 .74519 .29485 Metetra
.664 .741 .907 r
.74519 .29485 .74606 .29606 .75251 .29389 .75164 .29268 Metetra
.664 .741 .907 r
.75164 .29268 .75251 .29389 .75898 .29172 .75811 .29051 Metetra
.664 .741 .907 r
.75811 .29051 .75898 .29172 .76546 .28954 .76459 .28833 Metetra
.664 .741 .907 r
.76459 .28833 .76546 .28954 .77196 .28736 .77109 .28614 Metetra
.664 .741 .907 r
.77109 .28614 .77196 .28736 .77847 .28518 .77761 .28395 Metetra
.664 .741 .907 r
.77761 .28395 .77847 .28518 .78499 .28298 .78413 .28176 Metetra
.664 .741 .907 r
.78413 .28176 .78499 .28298 .79153 .28079 .79068 .27956 Metetra
.664 .741 .907 r
.79068 .27956 .79153 .28079 .79809 .27858 .79724 .27735 Metetra
.664 .741 .907 r
.79724 .27735 .79809 .27858 .80466 .27638 .80381 .27515 Metetra
.664 .741 .907 r
.80381 .27515 .80466 .27638 .81124 .27417 .8104 .27293 Metetra
.664 .741 .907 r
.8104 .27293 .81124 .27417 .81784 .27195 .817 .27071 Metetra
.664 .741 .907 r
.817 .27071 .81784 .27195 .82445 .26973 .82362 .26849 Metetra
.664 .741 .907 r
.82362 .26849 .82445 .26973 .83108 .2675 .83025 .26626 Metetra
.664 .741 .907 r
.83025 .26626 .83108 .2675 .83773 .26527 .8369 .26402 Metetra
.664 .741 .907 r
.8369 .26402 .83773 .26527 .84439 .26303 .84356 .26178 Metetra
.664 .741 .907 r
.84356 .26178 .84439 .26303 .85107 .26079 .85024 .25954 Metetra
.664 .741 .907 r
.85024 .25954 .85107 .26079 .85776 .25854 .85694 .25729 Metetra
.664 .741 .907 r
.25474 .45834 .25582 .45936 .26122 .45754 .26014 .45653 Metetra
.664 .741 .907 r
.26014 .45653 .26122 .45754 .26663 .45572 .26555 .45471 Metetra
.664 .741 .907 r
.26555 .45471 .26663 .45572 .27205 .4539 .27097 .45288 Metetra
.664 .741 .907 r
.27097 .45288 .27205 .4539 .27748 .45208 .2764 .45106 Metetra
.664 .741 .907 r
.2764 .45106 .27748 .45208 .28292 .45025 .28185 .44922 Metetra
.664 .741 .907 r
.28185 .44922 .28292 .45025 .28837 .44841 .2873 .44739 Metetra
.664 .741 .907 r
.2873 .44739 .28837 .44841 .29384 .44658 .29277 .44555 Metetra
.664 .741 .907 r
.29277 .44555 .29384 .44658 .29931 .44474 .29825 .44371 Metetra
.635 .129 0 r
.29825 .44371 .29931 .44474 .30209 .48312 .30321 .44957 Metetra
.581 .37 .559 r
.30321 .44957 .30209 .48312 .3103 .44104 .30924 .44001 Metetra
.664 .741 .907 r
.30924 .44001 .3103 .44104 .31581 .43919 .31475 .43816 Metetra
.664 .741 .907 r
.31475 .43816 .31581 .43919 .32133 .43733 .32027 .4363 Metetra
.664 .741 .907 r
.32027 .4363 .32133 .43733 .32686 .43547 .32581 .43443 Metetra
.664 .741 .907 r
.32581 .43443 .32686 .43547 .33241 .43361 .33135 .43257 Metetra
.664 .741 .907 r
.33135 .43257 .33241 .43361 .33797 .43174 .33691 .4307 Metetra
.664 .741 .907 r
.33691 .4307 .33797 .43174 .34353 .42987 .34248 .42882 Metetra
.664 .741 .907 r
.34248 .42882 .34353 .42987 .34911 .42799 .34807 .42695 Metetra
.664 .741 .907 r
.34807 .42695 .34911 .42799 .3547 .42612 .35366 .42507 Metetra
.664 .741 .907 r
.35366 .42507 .3547 .42612 .36031 .42423 .35926 .42318 Metetra
.664 .741 .907 r
.35926 .42318 .36031 .42423 .36592 .42234 .36488 .42129 Metetra
.664 .741 .907 r
.36488 .42129 .36592 .42234 .37155 .42045 .37051 .4194 Metetra
.664 .741 .907 r
.37051 .4194 .37155 .42045 .37719 .41856 .37615 .4175 Metetra
.664 .741 .907 r
.37615 .4175 .37719 .41856 .38284 .41666 .3818 .4156 Metetra
.664 .741 .907 r
.3818 .4156 .38284 .41666 .3885 .41475 .38747 .41369 Metetra
.664 .741 .907 r
.38747 .41369 .3885 .41475 .39418 .41285 .39315 .41178 Metetra
.664 .741 .907 r
.39315 .41178 .39418 .41285 .39986 .41094 .39883 .40987 Metetra
.664 .741 .907 r
.39883 .40987 .39986 .41094 .40556 .40902 .40454 .40795 Metetra
.664 .741 .907 r
.40454 .40795 .40556 .40902 .41127 .4071 .41025 .40603 Metetra
.664 .741 .907 r
.41025 .40603 .41127 .4071 .41699 .40518 .41597 .4041 Metetra
.664 .741 .907 r
.41597 .4041 .41699 .40518 .42223 .41894 .42171 .40217 Metetra
.565 .369 .575 r
.42171 .40217 .42223 .41894 .42848 .40132 .42746 .40024 Metetra
.664 .741 .907 r
.42746 .40024 .42848 .40132 .43424 .39938 .43322 .3983 Metetra
.664 .741 .907 r
.43322 .3983 .43424 .39938 .44001 .39744 .439 .39636 Metetra
0 0 .486 r
.439 .39636 .44001 .39744 .44579 .3955 .44459 .40232 Metetra
.903 .619 .495 r
.44459 .40232 .44579 .3955 .45098 .42046 .44748 .52681 Metetra
.358 .174 .489 r
.44748 .52681 .45098 .42046 .4574 .39159 .45639 .3905 Metetra
.664 .741 .907 r
.45639 .3905 .4574 .39159 .46322 .38964 .46222 .38854 Metetra
.664 .741 .907 r
.46222 .38854 .46322 .38964 .46905 .38768 .46805 .38658 Metetra
.664 .741 .907 r
.46805 .38658 .46905 .38768 .4749 .38571 .4739 .38461 Metetra
.664 .741 .907 r
.4739 .38461 .4749 .38571 .48076 .38374 .47976 .38264 Metetra
.664 .741 .907 r
.47976 .38264 .48076 .38374 .48663 .38177 .48564 .38066 Metetra
.664 .741 .907 r
.48564 .38066 .48663 .38177 .49251 .37979 .49152 .37868 Metetra
.664 .741 .907 r
.49152 .37868 .49251 .37979 .49841 .37781 .49742 .3767 Metetra
.664 .741 .907 r
.49742 .3767 .49841 .37781 .50432 .37582 .50334 .37471 Metetra
.664 .741 .907 r
.50334 .37471 .50432 .37582 .51024 .37383 .50926 .37272 Metetra
.664 .741 .907 r
.50926 .37272 .51024 .37383 .51618 .37183 .5152 .37072 Metetra
.664 .741 .907 r
.5152 .37072 .51618 .37183 .52213 .36984 .52115 .36872 Metetra
.664 .741 .907 r
.52115 .36872 .52213 .36984 .52809 .36783 .52711 .36671 Metetra
.664 .741 .907 r
.52711 .36671 .52809 .36783 .53406 .36582 .53309 .3647 Metetra
.664 .741 .907 r
.53309 .3647 .53406 .36582 .54005 .36381 .53908 .36269 Metetra
.664 .741 .907 r
.53908 .36269 .54005 .36381 .54605 .36179 .54508 .36067 Metetra
.664 .741 .907 r
.54508 .36067 .54605 .36179 .55206 .35977 .5511 .35864 Metetra
.664 .741 .907 r
.5511 .35864 .55206 .35977 .55809 .35775 .55712 .35661 Metetra
.664 .741 .907 r
.55712 .35661 .55809 .35775 .56413 .35572 .56317 .35458 Metetra
.664 .741 .907 r
.56317 .35458 .56413 .35572 .57018 .35368 .56922 .35255 Metetra
.664 .741 .907 r
.56922 .35255 .57018 .35368 .57624 .35164 .57529 .3505 Metetra
.664 .741 .907 r
.57529 .3505 .57624 .35164 .58232 .3496 .58137 .34846 Metetra
.664 .741 .907 r
.58137 .34846 .58232 .3496 .58841 .34755 .58747 .34641 Metetra
.664 .741 .907 r
.58747 .34641 .58841 .34755 .59452 .3455 .59357 .34435 Metetra
.664 .741 .907 r
.59357 .34435 .59452 .3455 .60064 .34344 .5997 .34229 Metetra
.664 .741 .907 r
.5997 .34229 .60064 .34344 .60677 .34138 .60583 .34023 Metetra
.664 .741 .907 r
.60583 .34023 .60677 .34138 .61292 .33931 .61198 .33816 Metetra
.664 .741 .907 r
.61198 .33816 .61292 .33931 .61908 .33724 .61814 .33609 Metetra
.664 .741 .907 r
.61814 .33609 .61908 .33724 .62525 .33517 .62432 .33401 Metetra
.664 .741 .907 r
.62432 .33401 .62525 .33517 .63144 .33309 .63051 .33193 Metetra
.664 .741 .907 r
.63051 .33193 .63144 .33309 .63764 .331 .63671 .32984 Metetra
.664 .741 .907 r
.63671 .32984 .63764 .331 .64385 .32892 .64293 .32775 Metetra
.664 .741 .907 r
.64293 .32775 .64385 .32892 .65008 .32682 .64916 .32565 Metetra
.664 .741 .907 r
.64916 .32565 .65008 .32682 .65632 .32472 .6554 .32355 Metetra
.664 .741 .907 r
.6554 .32355 .65632 .32472 .66258 .32262 .66166 .32145 Metetra
.664 .741 .907 r
.66166 .32145 .66258 .32262 .66885 .32051 .66794 .31934 Metetra
.664 .741 .907 r
.66794 .31934 .66885 .32051 .67513 .3184 .67422 .31722 Metetra
.664 .741 .907 r
.67422 .31722 .67513 .3184 .68143 .31628 .68052 .3151 Metetra
.664 .741 .907 r
.68052 .3151 .68143 .31628 .68774 .31416 .68684 .31298 Metetra
.664 .741 .907 r
.68684 .31298 .68774 .31416 .69407 .31204 .69317 .31085 Metetra
.664 .741 .907 r
.69317 .31085 .69407 .31204 .70041 .3099 .69951 .30871 Metetra
.664 .741 .907 r
.69951 .30871 .70041 .3099 .70676 .30777 .70587 .30658 Metetra
.664 .741 .907 r
.70587 .30658 .70676 .30777 .71313 .30563 .71224 .30443 Metetra
.376 .6 .935 r
.71224 .30443 .71313 .30563 .71951 .30348 .71883 .30563 Metetra
.917 .57 .365 r
.71883 .30563 .71951 .30348 .72591 .30133 .7282 .34975 Metetra
.418 .223 .506 r
.7282 .34975 .72591 .30133 .73232 .29918 .73144 .29797 Metetra
.664 .741 .907 r
.73144 .29797 .73232 .29918 .73875 .29702 .73787 .29581 Metetra
.664 .741 .907 r
.73787 .29581 .73875 .29702 .74519 .29485 .74431 .29364 Metetra
.664 .741 .907 r
.74431 .29364 .74519 .29485 .75164 .29268 .75077 .29147 Metetra
.664 .741 .907 r
.75077 .29147 .75164 .29268 .75811 .29051 .75724 .28929 Metetra
.664 .741 .907 r
.75724 .28929 .75811 .29051 .76459 .28833 .76373 .28711 Metetra
.664 .741 .907 r
.76373 .28711 .76459 .28833 .77109 .28614 .77023 .28492 Metetra
.664 .741 .907 r
.77023 .28492 .77109 .28614 .77761 .28395 .77675 .28273 Metetra
.664 .741 .907 r
.77675 .28273 .77761 .28395 .78413 .28176 .78328 .28053 Metetra
.664 .741 .907 r
.78328 .28053 .78413 .28176 .79068 .27956 .78982 .27833 Metetra
.664 .741 .907 r
.78982 .27833 .79068 .27956 .79724 .27735 .79638 .27612 Metetra
.664 .741 .907 r
.79638 .27612 .79724 .27735 .80381 .27515 .80296 .27391 Metetra
.664 .741 .907 r
.80296 .27391 .80381 .27515 .8104 .27293 .80955 .27169 Metetra
.664 .741 .907 r
.80955 .27169 .8104 .27293 .817 .27071 .81616 .26947 Metetra
.664 .741 .907 r
.81616 .26947 .817 .27071 .82362 .26849 .82278 .26724 Metetra
.664 .741 .907 r
.82278 .26724 .82362 .26849 .83025 .26626 .82942 .26501 Metetra
.664 .741 .907 r
.82942 .26501 .83025 .26626 .8369 .26402 .83607 .26277 Metetra
.664 .741 .907 r
.83607 .26277 .8369 .26402 .84356 .26178 .84273 .26053 Metetra
.664 .741 .907 r
.84273 .26053 .84356 .26178 .85024 .25954 .84942 .25828 Metetra
.664 .741 .907 r
.84942 .25828 .85024 .25954 .85694 .25729 .85611 .25603 Metetra
.664 .741 .907 r
.25365 .45733 .25474 .45834 .26014 .45653 .25906 .45551 Metetra
.664 .741 .907 r
.25906 .45551 .26014 .45653 .26555 .45471 .26447 .45369 Metetra
.664 .741 .907 r
.26447 .45369 .26555 .45471 .27097 .45288 .26989 .45186 Metetra
.664 .741 .907 r
.26989 .45186 .27097 .45288 .2764 .45106 .27533 .45003 Metetra
.664 .741 .907 r
.27533 .45003 .2764 .45106 .28185 .44922 .28077 .4482 Metetra
.664 .741 .907 r
.28077 .4482 .28185 .44922 .2873 .44739 .28623 .44636 Metetra
.664 .741 .907 r
.28623 .44636 .2873 .44739 .29277 .44555 .2917 .44452 Metetra
.664 .741 .907 r
.2917 .44452 .29277 .44555 .29825 .44371 .29718 .44268 Metetra
.664 .741 .907 r
.29718 .44268 .29825 .44371 .30321 .44957 .30267 .44083 Metetra
.579 .403 .608 r
.30267 .44083 .30321 .44957 .30924 .44001 .30817 .43898 Metetra
.664 .741 .907 r
.30817 .43898 .30924 .44001 .31475 .43816 .31369 .43712 Metetra
.664 .741 .907 r
.31369 .43712 .31475 .43816 .32027 .4363 .31921 .43526 Metetra
.664 .741 .907 r
.31921 .43526 .32027 .4363 .32581 .43443 .32475 .43339 Metetra
.664 .741 .907 r
.32475 .43339 .32581 .43443 .33135 .43257 .3303 .43153 Metetra
.664 .741 .907 r
.3303 .43153 .33135 .43257 .33691 .4307 .33586 .42965 Metetra
.664 .741 .907 r
.33586 .42965 .33691 .4307 .34248 .42882 .34143 .42778 Metetra
.664 .741 .907 r
.34143 .42778 .34248 .42882 .34807 .42695 .34702 .4259 Metetra
.664 .741 .907 r
.34702 .4259 .34807 .42695 .35366 .42507 .35261 .42401 Metetra
.664 .741 .907 r
.35261 .42401 .35366 .42507 .35926 .42318 .35822 .42213 Metetra
.664 .741 .907 r
.35822 .42213 .35926 .42318 .36488 .42129 .36384 .42023 Metetra
.664 .741 .907 r
.36384 .42023 .36488 .42129 .37051 .4194 .36947 .41834 Metetra
.664 .741 .907 r
.36947 .41834 .37051 .4194 .37615 .4175 .37511 .41644 Metetra
.664 .741 .907 r
.37511 .41644 .37615 .4175 .3818 .4156 .38077 .41453 Metetra
.664 .741 .907 r
.38077 .41453 .3818 .4156 .38747 .41369 .38644 .41263 Metetra
.664 .741 .907 r
.38644 .41263 .38747 .41369 .39315 .41178 .39211 .41071 Metetra
.664 .741 .907 r
.39211 .41071 .39315 .41178 .39883 .40987 .39781 .4088 Metetra
.664 .741 .907 r
.39781 .4088 .39883 .40987 .40454 .40795 .40351 .40688 Metetra
.664 .741 .907 r
.40351 .40688 .40454 .40795 .41025 .40603 .40922 .40495 Metetra
.664 .741 .907 r
.40922 .40495 .41025 .40603 .41597 .4041 .41495 .40303 Metetra
.664 .741 .907 r
.41495 .40303 .41597 .4041 .42171 .40217 .42069 .40109 Metetra
.664 .741 .907 r
.42069 .40109 .42171 .40217 .42746 .40024 .42644 .39916 Metetra
.664 .741 .907 r
.42644 .39916 .42746 .40024 .43322 .3983 .43221 .39722 Metetra
.664 .741 .907 r
.43221 .39722 .43322 .3983 .439 .39636 .43798 .39527 Metetra
.959 .675 .455 r
.43798 .39527 .439 .39636 .44459 .40232 .44006 .5405 Metetra
.543 .322 .529 r
.44006 .5405 .44459 .40232 .44748 .52681 .44617 .53642 Metetra
.995 .759 .422 r
.44617 .53642 .44748 .52681 .45639 .3905 .45539 .38941 Metetra
.664 .741 .907 r
.45539 .38941 .45639 .3905 .46222 .38854 .46121 .38745 Metetra
.664 .741 .907 r
.46121 .38745 .46222 .38854 .46805 .38658 .46705 .38548 Metetra
.664 .741 .907 r
.46705 .38548 .46805 .38658 .4739 .38461 .4729 .38351 Metetra
.664 .741 .907 r
.4729 .38351 .4739 .38461 .47976 .38264 .47877 .38154 Metetra
.664 .741 .907 r
.47877 .38154 .47976 .38264 .48564 .38066 .48464 .37956 Metetra
.664 .741 .907 r
.48464 .37956 .48564 .38066 .49152 .37868 .49053 .37758 Metetra
.664 .741 .907 r
.49053 .37758 .49152 .37868 .49742 .3767 .49643 .37559 Metetra
.664 .741 .907 r
.49643 .37559 .49742 .3767 .50334 .37471 .50235 .3736 Metetra
.664 .741 .907 r
.50235 .3736 .50334 .37471 .50926 .37272 .50828 .3716 Metetra
.664 .741 .907 r
.50828 .3716 .50926 .37272 .5152 .37072 .51422 .3696 Metetra
.664 .741 .907 r
.51422 .3696 .5152 .37072 .52115 .36872 .52017 .3676 Metetra
.664 .741 .907 r
.52017 .3676 .52115 .36872 .52711 .36671 .52614 .36559 Metetra
.664 .741 .907 r
.52614 .36559 .52711 .36671 .53309 .3647 .53212 .36358 Metetra
.664 .741 .907 r
.53212 .36358 .53309 .3647 .53908 .36269 .53811 .36156 Metetra
.664 .741 .907 r
.53811 .36156 .53908 .36269 .54508 .36067 .54411 .35954 Metetra
.664 .741 .907 r
.54411 .35954 .54508 .36067 .5511 .35864 .55013 .35751 Metetra
.664 .741 .907 r
.55013 .35751 .5511 .35864 .55712 .35661 .55616 .35548 Metetra
.664 .741 .907 r
.55616 .35548 .55712 .35661 .56317 .35458 .56221 .35345 Metetra
.664 .741 .907 r
.56221 .35345 .56317 .35458 .56922 .35255 .56826 .35141 Metetra
.664 .741 .907 r
.56826 .35141 .56922 .35255 .57529 .3505 .57433 .34936 Metetra
.664 .741 .907 r
.57433 .34936 .57529 .3505 .58137 .34846 .58042 .34731 Metetra
.664 .741 .907 r
.58042 .34731 .58137 .34846 .58747 .34641 .58652 .34526 Metetra
.664 .741 .907 r
.58652 .34526 .58747 .34641 .59357 .34435 .59263 .3432 Metetra
.664 .741 .907 r
.59263 .3432 .59357 .34435 .5997 .34229 .59875 .34114 Metetra
.664 .741 .907 r
.59875 .34114 .5997 .34229 .60583 .34023 .60489 .33908 Metetra
.664 .741 .907 r
.60489 .33908 .60583 .34023 .61198 .33816 .61104 .337 Metetra
.664 .741 .907 r
.61104 .337 .61198 .33816 .61814 .33609 .61721 .33493 Metetra
.664 .741 .907 r
.61721 .33493 .61814 .33609 .62432 .33401 .62339 .33285 Metetra
.664 .741 .907 r
.62339 .33285 .62432 .33401 .63051 .33193 .62958 .33076 Metetra
.664 .741 .907 r
.62958 .33076 .63051 .33193 .63671 .32984 .63578 .32867 Metetra
.664 .741 .907 r
.63578 .32867 .63671 .32984 .64293 .32775 .642 .32658 Metetra
.664 .741 .907 r
.642 .32658 .64293 .32775 .64916 .32565 .64824 .32448 Metetra
.664 .741 .907 r
.64824 .32448 .64916 .32565 .6554 .32355 .65449 .32238 Metetra
.664 .741 .907 r
.65449 .32238 .6554 .32355 .66166 .32145 .66075 .32027 Metetra
.664 .741 .907 r
.66075 .32027 .66166 .32145 .66794 .31934 .66702 .31816 Metetra
.664 .741 .907 r
.66702 .31816 .66794 .31934 .67422 .31722 .67331 .31604 Metetra
.664 .741 .907 r
.67331 .31604 .67422 .31722 .68052 .3151 .67962 .31392 Metetra
.664 .741 .907 r
.67962 .31392 .68052 .3151 .68684 .31298 .68593 .31179 Metetra
.664 .741 .907 r
.68593 .31179 .68684 .31298 .69317 .31085 .69226 .30966 Metetra
.664 .741 .907 r
.69226 .30966 .69317 .31085 .69951 .30871 .69861 .30752 Metetra
.664 .741 .907 r
.69861 .30752 .69951 .30871 .70587 .30658 .70497 .30538 Metetra
.664 .741 .907 r
.70497 .30538 .70587 .30658 .71224 .30443 .71134 .30323 Metetra
.664 .741 .907 r
.71134 .30323 .71224 .30443 .71883 .30563 .71773 .30108 Metetra
0 0 .341 r
.71773 .30108 .71883 .30563 .7282 .34975 .72603 .32868 Metetra
.678 .447 .564 r
.72603 .32868 .7282 .34975 .73144 .29797 .73055 .29677 Metetra
.664 .741 .907 r
.73055 .29677 .73144 .29797 .73787 .29581 .73699 .2946 Metetra
.664 .741 .907 r
.73699 .2946 .73787 .29581 .74431 .29364 .74343 .29243 Metetra
.664 .741 .907 r
.74343 .29243 .74431 .29364 .75077 .29147 .74989 .29026 Metetra
.664 .741 .907 r
.74989 .29026 .75077 .29147 .75724 .28929 .75637 .28808 Metetra
.664 .741 .907 r
.75637 .28808 .75724 .28929 .76373 .28711 .76286 .28589 Metetra
.664 .741 .907 r
.76286 .28589 .76373 .28711 .77023 .28492 .76936 .2837 Metetra
.664 .741 .907 r
.76936 .2837 .77023 .28492 .77675 .28273 .77588 .2815 Metetra
.664 .741 .907 r
.77588 .2815 .77675 .28273 .78328 .28053 .78242 .2793 Metetra
.664 .741 .907 r
.78242 .2793 .78328 .28053 .78982 .27833 .78897 .2771 Metetra
.664 .741 .907 r
.78897 .2771 .78982 .27833 .79638 .27612 .79553 .27489 Metetra
.664 .741 .907 r
.79553 .27489 .79638 .27612 .80296 .27391 .80211 .27267 Metetra
.664 .741 .907 r
.80211 .27267 .80296 .27391 .80955 .27169 .80871 .27045 Metetra
.664 .741 .907 r
.80871 .27045 .80955 .27169 .81616 .26947 .81531 .26823 Metetra
.664 .741 .907 r
.81531 .26823 .81616 .26947 .82278 .26724 .82194 .266 Metetra
.664 .741 .907 r
.82194 .266 .82278 .26724 .82942 .26501 .82858 .26376 Metetra
.664 .741 .907 r
.82858 .26376 .82942 .26501 .83607 .26277 .83523 .26152 Metetra
.664 .741 .907 r
.83523 .26152 .83607 .26277 .84273 .26053 .8419 .25928 Metetra
.664 .741 .907 r
.8419 .25928 .84273 .26053 .84942 .25828 .84859 .25703 Metetra
.664 .741 .907 r
.84859 .25703 .84942 .25828 .85611 .25603 .85529 .25477 Metetra
.664 .741 .907 r
.25257 .45632 .25365 .45733 .25906 .45551 .25797 .4545 Metetra
.664 .741 .907 r
.25797 .4545 .25906 .45551 .26447 .45369 .26339 .45267 Metetra
.664 .741 .907 r
.26339 .45267 .26447 .45369 .26989 .45186 .26881 .45084 Metetra
.664 .741 .907 r
.26881 .45084 .26989 .45186 .27533 .45003 .27425 .44901 Metetra
.664 .741 .907 r
.27425 .44901 .27533 .45003 .28077 .4482 .2797 .44718 Metetra
.664 .741 .907 r
.2797 .44718 .28077 .4482 .28623 .44636 .28516 .44534 Metetra
.664 .741 .907 r
.28516 .44534 .28623 .44636 .2917 .44452 .29063 .44349 Metetra
.664 .741 .907 r
.29063 .44349 .2917 .44452 .29718 .44268 .29611 .44165 Metetra
.664 .741 .907 r
.29611 .44165 .29718 .44268 .30267 .44083 .3016 .4398 Metetra
.664 .741 .907 r
.3016 .4398 .30267 .44083 .30817 .43898 .30711 .43794 Metetra
.664 .741 .907 r
.30711 .43794 .30817 .43898 .31369 .43712 .31262 .43608 Metetra
.949 .651 .438 r
.31262 .43608 .31369 .43712 .31921 .43526 .31515 .48157 Metetra
.384 .184 .481 r
.31515 .48157 .31921 .43526 .32475 .43339 .32369 .43235 Metetra
.664 .741 .907 r
.32369 .43235 .32475 .43339 .3303 .43153 .32924 .43048 Metetra
.664 .741 .907 r
.32924 .43048 .3303 .43153 .33586 .42965 .33481 .42861 Metetra
.664 .741 .907 r
.33481 .42861 .33586 .42965 .34143 .42778 .34038 .42673 Metetra
.664 .741 .907 r
.34038 .42673 .34143 .42778 .34702 .4259 .34597 .42485 Metetra
.664 .741 .907 r
.34597 .42485 .34702 .4259 .35261 .42401 .35156 .42296 Metetra
.664 .741 .907 r
.35156 .42296 .35261 .42401 .35822 .42213 .35717 .42107 Metetra
.664 .741 .907 r
.35717 .42107 .35822 .42213 .36384 .42023 .3628 .41918 Metetra
.664 .741 .907 r
.3628 .41918 .36384 .42023 .36947 .41834 .36843 .41728 Metetra
.664 .741 .907 r
.36843 .41728 .36947 .41834 .37511 .41644 .37407 .41538 Metetra
.664 .741 .907 r
.37407 .41538 .37511 .41644 .38077 .41453 .37973 .41347 Metetra
.664 .741 .907 r
.37973 .41347 .38077 .41453 .38644 .41263 .3854 .41156 Metetra
.664 .741 .907 r
.3854 .41156 .38644 .41263 .39211 .41071 .39108 .40965 Metetra
.664 .741 .907 r
.39108 .40965 .39211 .41071 .39781 .4088 .39678 .40773 Metetra
.664 .741 .907 r
.39678 .40773 .39781 .4088 .40351 .40688 .40248 .40581 Metetra
.664 .741 .907 r
.40248 .40581 .40351 .40688 .40922 .40495 .4082 .40388 Metetra
.664 .741 .907 r
.4082 .40388 .40922 .40495 .41495 .40303 .41393 .40195 Metetra
.664 .741 .907 r
.41393 .40195 .41495 .40303 .42069 .40109 .41967 .40001 Metetra
.664 .741 .907 r
.41967 .40001 .42069 .40109 .42644 .39916 .42542 .39807 Metetra
.664 .741 .907 r
.42542 .39807 .42644 .39916 .43221 .39722 .43119 .39613 Metetra
.664 .741 .907 r
.43119 .39613 .43221 .39722 .43798 .39527 .43697 .39418 Metetra
.959 .677 .459 r
.43697 .39418 .43798 .39527 .44006 .5405 .43845 .56086 Metetra
.43845 .56086 .44006 .5405 .44617 .53642 .44701 .45575 Metetra
.631 .402 .552 r
.44701 .45575 .44617 .53642 .45539 .38941 .45438 .38832 Metetra
.664 .741 .907 r
.45438 .38832 .45539 .38941 .46121 .38745 .46021 .38635 Metetra
.664 .741 .907 r
.46021 .38635 .46121 .38745 .46705 .38548 .46605 .38439 Metetra
.664 .741 .907 r
.46605 .38439 .46705 .38548 .4729 .38351 .4719 .38241 Metetra
.664 .741 .907 r
.4719 .38241 .4729 .38351 .47877 .38154 .47777 .38044 Metetra
.664 .741 .907 r
.47777 .38044 .47877 .38154 .48464 .37956 .48365 .37846 Metetra
.664 .741 .907 r
.48365 .37846 .48464 .37956 .49053 .37758 .48954 .37647 Metetra
.664 .741 .907 r
.48954 .37647 .49053 .37758 .49643 .37559 .49545 .37448 Metetra
.664 .741 .907 r
.49545 .37448 .49643 .37559 .50235 .3736 .50136 .37249 Metetra
.664 .741 .907 r
.50136 .37249 .50235 .3736 .50828 .3716 .50729 .37049 Metetra
.664 .741 .907 r
.50729 .37049 .50828 .3716 .51422 .3696 .51323 .36849 Metetra
.664 .741 .907 r
.51323 .36849 .51422 .3696 .52017 .3676 .51919 .36648 Metetra
.664 .741 .907 r
.51919 .36648 .52017 .3676 .52614 .36559 .52516 .36447 Metetra
.664 .741 .907 r
.52516 .36447 .52614 .36559 .53212 .36358 .53114 .36245 Metetra
.664 .741 .907 r
.53114 .36245 .53212 .36358 .53811 .36156 .53714 .36043 Metetra
.664 .741 .907 r
.53714 .36043 .53811 .36156 .54411 .35954 .54314 .35841 Metetra
.664 .741 .907 r
.54314 .35841 .54411 .35954 .55013 .35751 .54916 .35638 Metetra
.664 .741 .907 r
.54916 .35638 .55013 .35751 .55616 .35548 .5552 .35435 Metetra
.664 .741 .907 r
.5552 .35435 .55616 .35548 .56221 .35345 .56124 .35231 Metetra
.664 .741 .907 r
.56124 .35231 .56221 .35345 .56826 .35141 .56731 .35027 Metetra
.664 .741 .907 r
.56731 .35027 .56826 .35141 .57433 .34936 .57338 .34822 Metetra
.664 .741 .907 r
.57338 .34822 .57433 .34936 .58042 .34731 .57947 .34617 Metetra
.664 .741 .907 r
.57947 .34617 .58042 .34731 .58652 .34526 .58557 .34411 Metetra
.664 .741 .907 r
.58557 .34411 .58652 .34526 .59263 .3432 .59168 .34205 Metetra
.664 .741 .907 r
.59168 .34205 .59263 .3432 .59875 .34114 .59781 .33999 Metetra
.664 .741 .907 r
.59781 .33999 .59875 .34114 .60489 .33908 .60395 .33792 Metetra
.664 .741 .907 r
.60395 .33792 .60489 .33908 .61104 .337 .6101 .33585 Metetra
.664 .741 .907 r
.6101 .33585 .61104 .337 .61721 .33493 .61627 .33377 Metetra
.664 .741 .907 r
.61627 .33377 .61721 .33493 .62339 .33285 .62245 .33169 Metetra
.664 .741 .907 r
.62245 .33169 .62339 .33285 .62958 .33076 .62865 .3296 Metetra
.664 .741 .907 r
.62865 .3296 .62958 .33076 .63578 .32867 .63486 .32751 Metetra
.664 .741 .907 r
.63486 .32751 .63578 .32867 .642 .32658 .64108 .32541 Metetra
.664 .741 .907 r
.64108 .32541 .642 .32658 .64824 .32448 .64731 .32331 Metetra
.664 .741 .907 r
.64731 .32331 .64824 .32448 .65449 .32238 .65357 .3212 Metetra
.664 .741 .907 r
.65357 .3212 .65449 .32238 .66075 .32027 .65983 .31909 Metetra
.664 .741 .907 r
.65983 .31909 .66075 .32027 .66702 .31816 .66611 .31698 Metetra
.664 .741 .907 r
.66611 .31698 .66702 .31816 .67331 .31604 .6724 .31486 Metetra
.664 .741 .907 r
.6724 .31486 .67331 .31604 .67962 .31392 .67871 .31273 Metetra
.664 .741 .907 r
.67871 .31273 .67962 .31392 .68593 .31179 .68503 .3106 Metetra
.664 .741 .907 r
.68503 .3106 .68593 .31179 .69226 .30966 .69136 .30847 Metetra
.664 .741 .907 r
.69136 .30847 .69226 .30966 .69861 .30752 .69771 .30633 Metetra
.664 .741 .907 r
.69771 .30633 .69861 .30752 .70497 .30538 .70407 .30418 Metetra
.934 .566 .172 r
.70407 .30418 .70497 .30538 .71134 .30323 .71257 .33777 Metetra
.412 .213 .498 r
.71257 .33777 .71134 .30323 .71773 .30108 .71684 .29988 Metetra
.664 .741 .907 r
.71684 .29988 .71773 .30108 .72603 .32868 .72325 .29772 Metetra
.557 .351 .557 r
.72325 .29772 .72603 .32868 .73055 .29677 .72967 .29556 Metetra
.664 .741 .907 r
.72967 .29556 .73055 .29677 .73699 .2946 .7361 .29339 Metetra
.664 .741 .907 r
.7361 .29339 .73699 .2946 .74343 .29243 .74255 .29122 Metetra
.664 .741 .907 r
.74255 .29122 .74343 .29243 .74989 .29026 .74902 .28904 Metetra
.664 .741 .907 r
.74902 .28904 .74989 .29026 .75637 .28808 .7555 .28686 Metetra
.664 .741 .907 r
.7555 .28686 .75637 .28808 .76286 .28589 .76199 .28467 Metetra
.664 .741 .907 r
.76199 .28467 .76286 .28589 .76936 .2837 .7685 .28248 Metetra
.664 .741 .907 r
.7685 .28248 .76936 .2837 .77588 .2815 .77502 .28028 Metetra
.664 .741 .907 r
.77502 .28028 .77588 .2815 .78242 .2793 .78156 .27808 Metetra
.664 .741 .907 r
.78156 .27808 .78242 .2793 .78897 .2771 .78811 .27587 Metetra
.664 .741 .907 r
.78811 .27587 .78897 .2771 .79553 .27489 .79468 .27365 Metetra
.664 .741 .907 r
.79468 .27365 .79553 .27489 .80211 .27267 .80126 .27144 Metetra
.664 .741 .907 r
.80126 .27144 .80211 .27267 .80871 .27045 .80786 .26921 Metetra
.664 .741 .907 r
.80786 .26921 .80871 .27045 .81531 .26823 .81447 .26699 Metetra
.664 .741 .907 r
.81447 .26699 .81531 .26823 .82194 .266 .8211 .26475 Metetra
.664 .741 .907 r
.8211 .26475 .82194 .266 .82858 .26376 .82774 .26251 Metetra
.664 .741 .907 r
.82774 .26251 .82858 .26376 .83523 .26152 .8344 .26027 Metetra
.664 .741 .907 r
.8344 .26027 .83523 .26152 .8419 .25928 .84107 .25802 Metetra
.664 .741 .907 r
.84107 .25802 .8419 .25928 .84859 .25703 .84776 .25577 Metetra
.664 .741 .907 r
.84776 .25577 .84859 .25703 .85529 .25477 .85447 .25351 Metetra
.664 .741 .907 r
.25148 .4553 .25257 .45632 .25797 .4545 .25689 .45348 Metetra
.664 .741 .907 r
.25689 .45348 .25797 .4545 .26339 .45267 .2623 .45165 Metetra
.664 .741 .907 r
.2623 .45165 .26339 .45267 .26881 .45084 .26773 .44982 Metetra
.664 .741 .907 r
.26773 .44982 .26881 .45084 .27425 .44901 .27317 .44799 Metetra
.664 .741 .907 r
.27317 .44799 .27425 .44901 .2797 .44718 .27862 .44615 Metetra
.664 .741 .907 r
.27862 .44615 .2797 .44718 .28516 .44534 .28408 .44431 Metetra
.664 .741 .907 r
.28408 .44431 .28516 .44534 .29063 .44349 .28955 .44246 Metetra
.664 .741 .907 r
.28955 .44246 .29063 .44349 .29611 .44165 .29504 .44062 Metetra
.664 .741 .907 r
.29504 .44062 .29611 .44165 .3016 .4398 .30053 .43876 Metetra
.664 .741 .907 r
.30053 .43876 .3016 .4398 .30711 .43794 .30604 .4369 Metetra
.941 .588 .315 r
.30604 .4369 .30711 .43794 .31262 .43608 .31015 .45661 Metetra
.535 .297 .501 r
.31015 .45661 .31262 .43608 .31515 .48157 .31567 .45537 Metetra
.639 .42 .569 r
.31567 .45537 .31515 .48157 .32369 .43235 .32263 .43131 Metetra
.664 .741 .907 r
.32263 .43131 .32369 .43235 .32924 .43048 .32818 .42944 Metetra
.664 .741 .907 r
.32818 .42944 .32924 .43048 .33481 .42861 .33375 .42756 Metetra
.664 .741 .907 r
.33375 .42756 .33481 .42861 .34038 .42673 .33933 .42568 Metetra
.664 .741 .907 r
.33933 .42568 .34038 .42673 .34597 .42485 .34491 .4238 Metetra
.664 .741 .907 r
.34491 .4238 .34597 .42485 .35156 .42296 .35051 .42191 Metetra
.664 .741 .907 r
.35051 .42191 .35156 .42296 .35717 .42107 .35613 .42002 Metetra
.664 .741 .907 r
.35613 .42002 .35717 .42107 .3628 .41918 .36175 .41812 Metetra
.664 .741 .907 r
.36175 .41812 .3628 .41918 .36843 .41728 .36739 .41622 Metetra
.664 .741 .907 r
.36739 .41622 .36843 .41728 .37407 .41538 .37303 .41431 Metetra
.664 .741 .907 r
.37303 .41431 .37407 .41538 .37973 .41347 .37869 .41241 Metetra
.664 .741 .907 r
.37869 .41241 .37973 .41347 .3854 .41156 .38437 .41049 Metetra
.664 .741 .907 r
.38437 .41049 .3854 .41156 .39108 .40965 .39005 .40858 Metetra
.664 .741 .907 r
.39005 .40858 .39108 .40965 .39678 .40773 .39574 .40666 Metetra
.664 .741 .907 r
.39574 .40666 .39678 .40773 .40248 .40581 .40145 .40473 Metetra
.664 .741 .907 r
.40145 .40473 .40248 .40581 .4082 .40388 .40717 .4028 Metetra
.664 .741 .907 r
.40717 .4028 .4082 .40388 .41393 .40195 .4129 .40087 Metetra
.664 .741 .907 r
.4129 .40087 .41393 .40195 .41967 .40001 .41865 .39893 Metetra
.664 .741 .907 r
.41865 .39893 .41967 .40001 .42542 .39807 .4244 .39699 Metetra
.664 .741 .907 r
.4244 .39699 .42542 .39807 .43119 .39613 .43017 .39505 Metetra
.664 .741 .907 r
.43017 .39505 .43119 .39613 .43697 .39418 .43595 .3931 Metetra
.958 .647 .394 r
.43595 .3931 .43697 .39418 .43845 .56086 .44044 .44179 Metetra
.567 .348 .543 r
.44044 .44179 .43845 .56086 .44701 .45575 .44678 .42144 Metetra
.643 .418 .562 r
.44678 .42144 .44701 .45575 .45438 .38832 .45337 .38722 Metetra
.664 .741 .907 r
.45337 .38722 .45438 .38832 .46021 .38635 .4592 .38526 Metetra
.664 .741 .907 r
.4592 .38526 .46021 .38635 .46605 .38439 .46505 .38329 Metetra
.664 .741 .907 r
.46505 .38329 .46605 .38439 .4719 .38241 .4709 .38131 Metetra
.664 .741 .907 r
.4709 .38131 .4719 .38241 .47777 .38044 .47677 .37933 Metetra
.664 .741 .907 r
.47677 .37933 .47777 .38044 .48365 .37846 .48265 .37735 Metetra
.664 .741 .907 r
.48265 .37735 .48365 .37846 .48954 .37647 .48855 .37536 Metetra
.664 .741 .907 r
.48855 .37536 .48954 .37647 .49545 .37448 .49445 .37337 Metetra
.664 .741 .907 r
.49445 .37337 .49545 .37448 .50136 .37249 .50037 .37137 Metetra
.664 .741 .907 r
.50037 .37137 .50136 .37249 .50729 .37049 .50631 .36937 Metetra
.664 .741 .907 r
.50631 .36937 .50729 .37049 .51323 .36849 .51225 .36737 Metetra
.664 .741 .907 r
.51225 .36737 .51323 .36849 .51919 .36648 .51821 .36536 Metetra
.664 .741 .907 r
.51821 .36536 .51919 .36648 .52516 .36447 .52418 .36335 Metetra
.664 .741 .907 r
.52418 .36335 .52516 .36447 .53114 .36245 .53017 .36133 Metetra
.664 .741 .907 r
.53017 .36133 .53114 .36245 .53714 .36043 .53616 .3593 Metetra
.664 .741 .907 r
.53616 .3593 .53714 .36043 .54314 .35841 .54217 .35728 Metetra
.664 .741 .907 r
.54217 .35728 .54314 .35841 .54916 .35638 .5482 .35525 Metetra
.664 .741 .907 r
.5482 .35525 .54916 .35638 .5552 .35435 .55423 .35321 Metetra
.664 .741 .907 r
.55423 .35321 .5552 .35435 .56124 .35231 .56028 .35117 Metetra
.664 .741 .907 r
.56028 .35117 .56124 .35231 .56731 .35027 .56635 .34913 Metetra
.664 .741 .907 r
.56635 .34913 .56731 .35027 .57338 .34822 .57242 .34708 Metetra
.664 .741 .907 r
.57242 .34708 .57338 .34822 .57947 .34617 .57851 .34502 Metetra
.664 .741 .907 r
.57851 .34502 .57947 .34617 .58557 .34411 .58461 .34297 Metetra
.664 .741 .907 r
.58461 .34297 .58557 .34411 .59168 .34205 .59073 .3409 Metetra
.664 .741 .907 r
.59073 .3409 .59168 .34205 .59781 .33999 .59686 .33884 Metetra
.664 .741 .907 r
.59686 .33884 .59781 .33999 .60395 .33792 .603 .33676 Metetra
.664 .741 .907 r
.603 .33676 .60395 .33792 .6101 .33585 .60916 .33469 Metetra
.664 .741 .907 r
.60916 .33469 .6101 .33585 .61627 .33377 .61533 .33261 Metetra
.664 .741 .907 r
.61533 .33261 .61627 .33377 .62245 .33169 .62152 .33052 Metetra
.664 .741 .907 r
.62152 .33052 .62245 .33169 .62865 .3296 .62771 .32843 Metetra
.664 .741 .907 r
.62771 .32843 .62865 .3296 .63486 .32751 .63393 .32634 Metetra
.664 .741 .907 r
.63393 .32634 .63486 .32751 .64108 .32541 .64015 .32424 Metetra
.664 .741 .907 r
.64015 .32424 .64108 .32541 .64731 .32331 .64639 .32213 Metetra
.664 .741 .907 r
.64639 .32213 .64731 .32331 .65357 .3212 .65264 .32003 Metetra
.664 .741 .907 r
.65264 .32003 .65357 .3212 .65983 .31909 .65891 .31791 Metetra
.664 .741 .907 r
.65891 .31791 .65983 .31909 .66611 .31698 .66519 .31579 Metetra
.664 .741 .907 r
.66519 .31579 .66611 .31698 .6724 .31486 .67149 .31367 Metetra
.664 .741 .907 r
.67149 .31367 .6724 .31486 .67871 .31273 .6778 .31154 Metetra
.664 .741 .907 r
.6778 .31154 .67871 .31273 .68503 .3106 .68412 .30941 Metetra
.664 .741 .907 r
.68412 .30941 .68503 .3106 .69136 .30847 .69046 .30727 Metetra
.664 .741 .907 r
.69046 .30727 .69136 .30847 .69771 .30633 .69681 .30513 Metetra
.664 .741 .907 r
.69681 .30513 .69771 .30633 .70407 .30418 .70318 .30299 Metetra
.664 .741 .907 r
.70318 .30299 .70407 .30418 .71257 .33777 .70956 .30083 Metetra
.555 .347 .553 r
.70956 .30083 .71257 .33777 .71684 .29988 .71595 .29868 Metetra
.664 .741 .907 r
.71595 .29868 .71684 .29988 .72325 .29772 .72236 .29652 Metetra
.664 .741 .907 r
.72236 .29652 .72325 .29772 .72967 .29556 .72878 .29435 Metetra
.664 .741 .907 r
.72878 .29435 .72967 .29556 .7361 .29339 .73522 .29218 Metetra
.664 .741 .907 r
.73522 .29218 .7361 .29339 .74255 .29122 .74167 .29 Metetra
.664 .741 .907 r
.74167 .29 .74255 .29122 .74902 .28904 .74814 .28782 Metetra
.664 .741 .907 r
.74814 .28782 .74902 .28904 .7555 .28686 .75462 .28564 Metetra
.664 .741 .907 r
.75462 .28564 .7555 .28686 .76199 .28467 .76112 .28345 Metetra
.664 .741 .907 r
.76112 .28345 .76199 .28467 .7685 .28248 .76763 .28125 Metetra
.664 .741 .907 r
.76763 .28125 .7685 .28248 .77502 .28028 .77416 .27905 Metetra
.664 .741 .907 r
.77416 .27905 .77502 .28028 .78156 .27808 .7807 .27684 Metetra
.664 .741 .907 r
.7807 .27684 .78156 .27808 .78811 .27587 .78725 .27463 Metetra
.664 .741 .907 r
.78725 .27463 .78811 .27587 .79468 .27365 .79382 .27242 Metetra
.664 .741 .907 r
.79382 .27242 .79468 .27365 .80126 .27144 .80041 .2702 Metetra
.664 .741 .907 r
.80041 .2702 .80126 .27144 .80786 .26921 .80701 .26797 Metetra
.664 .741 .907 r
.80701 .26797 .80786 .26921 .81447 .26699 .81363 .26574 Metetra
.664 .741 .907 r
.81363 .26574 .81447 .26699 .8211 .26475 .82026 .2635 Metetra
.664 .741 .907 r
.82026 .2635 .8211 .26475 .82774 .26251 .8269 .26126 Metetra
.664 .741 .907 r
.8269 .26126 .82774 .26251 .8344 .26027 .83356 .25902 Metetra
.664 .741 .907 r
.83356 .25902 .8344 .26027 .84107 .25802 .84024 .25677 Metetra
.664 .741 .907 r
.84024 .25677 .84107 .25802 .84776 .25577 .84693 .25451 Metetra
.664 .741 .907 r
.84693 .25451 .84776 .25577 .85447 .25351 .85364 .25225 Metetra
.664 .741 .907 r
.25039 .45429 .25148 .4553 .25689 .45348 .2558 .45246 Metetra
.664 .741 .907 r
.2558 .45246 .25689 .45348 .2623 .45165 .26122 .45063 Metetra
.664 .741 .907 r
.26122 .45063 .2623 .45165 .26773 .44982 .26665 .4488 Metetra
.664 .741 .907 r
.26665 .4488 .26773 .44982 .27317 .44799 .27209 .44696 Metetra
.664 .741 .907 r
.27209 .44696 .27317 .44799 .27862 .44615 .27754 .44512 Metetra
.664 .741 .907 r
.27754 .44512 .27862 .44615 .28408 .44431 .28301 .44328 Metetra
.664 .741 .907 r
.28301 .44328 .28408 .44431 .28955 .44246 .28848 .44143 Metetra
.664 .741 .907 r
.28848 .44143 .28955 .44246 .29504 .44062 .29397 .43958 Metetra
.664 .741 .907 r
.29397 .43958 .29504 .44062 .30053 .43876 .29946 .43773 Metetra
.664 .741 .907 r
.29946 .43773 .30053 .43876 .30604 .4369 .30497 .43587 Metetra
.927 .544 .236 r
.30497 .43587 .30604 .4369 .31015 .45661 .30938 .4509 Metetra
.763 .561 .624 r
.30938 .4509 .31015 .45661 .31567 .45537 .31598 .43288 Metetra
.563 .361 .564 r
.31598 .43288 .31567 .45537 .32263 .43131 .32157 .43027 Metetra
.664 .741 .907 r
.32157 .43027 .32263 .43131 .32818 .42944 .32713 .42839 Metetra
.664 .741 .907 r
.32713 .42839 .32818 .42944 .33375 .42756 .33269 .42651 Metetra
.664 .741 .907 r
.33269 .42651 .33375 .42756 .33933 .42568 .33827 .42463 Metetra
.664 .741 .907 r
.33827 .42463 .33933 .42568 .34491 .4238 .34386 .42274 Metetra
.664 .741 .907 r
.34386 .42274 .34491 .4238 .35051 .42191 .34946 .42085 Metetra
.664 .741 .907 r
.34946 .42085 .35051 .42191 .35613 .42002 .35508 .41896 Metetra
.664 .741 .907 r
.35508 .41896 .35613 .42002 .36175 .41812 .3607 .41706 Metetra
.664 .741 .907 r
.3607 .41706 .36175 .41812 .36739 .41622 .36634 .41516 Metetra
.664 .741 .907 r
.36634 .41516 .36739 .41622 .37303 .41431 .37199 .41325 Metetra
.664 .741 .907 r
.37199 .41325 .37303 .41431 .37869 .41241 .37765 .41134 Metetra
.664 .741 .907 r
.37765 .41134 .37869 .41241 .38437 .41049 .38333 .40942 Metetra
.664 .741 .907 r
.38333 .40942 .38437 .41049 .39005 .40858 .38901 .40751 Metetra
.664 .741 .907 r
.38901 .40751 .39005 .40858 .39574 .40666 .39471 .40558 Metetra
.664 .741 .907 r
.39471 .40558 .39574 .40666 .40145 .40473 .40042 .40366 Metetra
.955 .632 .373 r
.40042 .40366 .40145 .40473 .40717 .4028 .40477 .43897 Metetra
.388 .186 .481 r
.40477 .43897 .40717 .4028 .4129 .40087 .41188 .39979 Metetra
.664 .741 .907 r
.41188 .39979 .4129 .40087 .41865 .39893 .41762 .39785 Metetra
.664 .741 .907 r
.41762 .39785 .41865 .39893 .4244 .39699 .42338 .39591 Metetra
.664 .741 .907 r
.42338 .39591 .4244 .39699 .43017 .39505 .42916 .39396 Metetra
.664 .741 .907 r
.42916 .39396 .43017 .39505 .43595 .3931 .43494 .39201 Metetra
.664 .741 .907 r
.43494 .39201 .43595 .3931 .44044 .44179 .44073 .39005 Metetra
.551 .34 .547 r
.44073 .39005 .44044 .44179 .44678 .42144 .44653 .38866 Metetra
.557 .35 .555 r
.44653 .38866 .44678 .42144 .45337 .38722 .45236 .38613 Metetra
.664 .741 .907 r
.45236 .38613 .45337 .38722 .4592 .38526 .4582 .38416 Metetra
.664 .741 .907 r
.4582 .38416 .4592 .38526 .46505 .38329 .46404 .38218 Metetra
.664 .741 .907 r
.46404 .38218 .46505 .38329 .4709 .38131 .4699 .38021 Metetra
.664 .741 .907 r
.4699 .38021 .4709 .38131 .47677 .37933 .47577 .37823 Metetra
.664 .741 .907 r
.47577 .37823 .47677 .37933 .48265 .37735 .48166 .37624 Metetra
.664 .741 .907 r
.48166 .37624 .48265 .37735 .48855 .37536 .48755 .37425 Metetra
.664 .741 .907 r
.48755 .37425 .48855 .37536 .49445 .37337 .49346 .37226 Metetra
.664 .741 .907 r
.49346 .37226 .49445 .37337 .50037 .37137 .49938 .37026 Metetra
.664 .741 .907 r
.49938 .37026 .50037 .37137 .50631 .36937 .50532 .36826 Metetra
.664 .741 .907 r
.50532 .36826 .50631 .36937 .51225 .36737 .51127 .36625 Metetra
.664 .741 .907 r
.51127 .36625 .51225 .36737 .51821 .36536 .51723 .36424 Metetra
.664 .741 .907 r
.51723 .36424 .51821 .36536 .52418 .36335 .5232 .36222 Metetra
.664 .741 .907 r
.5232 .36222 .52418 .36335 .53017 .36133 .52919 .3602 Metetra
.664 .741 .907 r
.52919 .3602 .53017 .36133 .53616 .3593 .53519 .35818 Metetra
.664 .741 .907 r
.53519 .35818 .53616 .3593 .54217 .35728 .5412 .35615 Metetra
.664 .741 .907 r
.5412 .35615 .54217 .35728 .5482 .35525 .54723 .35411 Metetra
.664 .741 .907 r
.54723 .35411 .5482 .35525 .55423 .35321 .55327 .35207 Metetra
.664 .741 .907 r
.55327 .35207 .55423 .35321 .56028 .35117 .55932 .35003 Metetra
.664 .741 .907 r
.55932 .35003 .56028 .35117 .56635 .34913 .56538 .34798 Metetra
.664 .741 .907 r
.56538 .34798 .56635 .34913 .57242 .34708 .57146 .34593 Metetra
.664 .741 .907 r
.57146 .34593 .57242 .34708 .57851 .34502 .57756 .34388 Metetra
.664 .741 .907 r
.57756 .34388 .57851 .34502 .58461 .34297 .58366 .34182 Metetra
.664 .741 .907 r
.58366 .34182 .58461 .34297 .59073 .3409 .58978 .33975 Metetra
.664 .741 .907 r
.58978 .33975 .59073 .3409 .59686 .33884 .59591 .33768 Metetra
.664 .741 .907 r
.59591 .33768 .59686 .33884 .603 .33676 .60206 .33561 Metetra
.664 .741 .907 r
.60206 .33561 .603 .33676 .60916 .33469 .60822 .33353 Metetra
.664 .741 .907 r
.60822 .33353 .60916 .33469 .61533 .33261 .61439 .33145 Metetra
.664 .741 .907 r
.61439 .33145 .61533 .33261 .62152 .33052 .62058 .32936 Metetra
.608 .719 .924 r
.62058 .32936 .62152 .33052 .62771 .32843 .62681 .32808 Metetra
.68 .928 .97 r
.62681 .32808 .62771 .32843 .63393 .32634 .63299 .32517 Metetra
.664 .741 .907 r
.63299 .32517 .63393 .32634 .64015 .32424 .63922 .32307 Metetra
.664 .741 .907 r
.63922 .32307 .64015 .32424 .64639 .32213 .64547 .32096 Metetra
.664 .741 .907 r
.64547 .32096 .64639 .32213 .65264 .32003 .65172 .31885 Metetra
.664 .741 .907 r
.65172 .31885 .65264 .32003 .65891 .31791 .65799 .31673 Metetra
.664 .741 .907 r
.65799 .31673 .65891 .31791 .66519 .31579 .66428 .31461 Metetra
.664 .741 .907 r
.66428 .31461 .66519 .31579 .67149 .31367 .67057 .31249 Metetra
.664 .741 .907 r
.67057 .31249 .67149 .31367 .6778 .31154 .67689 .31036 Metetra
.664 .741 .907 r
.67689 .31036 .6778 .31154 .68412 .30941 .68321 .30822 Metetra
.664 .741 .907 r
.68321 .30822 .68412 .30941 .69046 .30727 .68955 .30608 Metetra
.664 .741 .907 r
.68955 .30608 .69046 .30727 .69681 .30513 .69591 .30394 Metetra
.664 .741 .907 r
.69591 .30394 .69681 .30513 .70318 .30299 .70228 .30179 Metetra
.664 .741 .907 r
.70228 .30179 .70318 .30299 .70956 .30083 .70866 .29963 Metetra
.664 .741 .907 r
.70866 .29963 .70956 .30083 .71595 .29868 .71506 .29747 Metetra
.664 .741 .907 r
.71506 .29747 .71595 .29868 .72236 .29652 .72147 .29531 Metetra
.664 .741 .907 r
.72147 .29531 .72236 .29652 .72878 .29435 .7279 .29314 Metetra
.664 .741 .907 r
.7279 .29314 .72878 .29435 .73522 .29218 .73434 .29097 Metetra
.664 .741 .907 r
.73434 .29097 .73522 .29218 .74167 .29 .74079 .28879 Metetra
.664 .741 .907 r
.74079 .28879 .74167 .29 .74814 .28782 .74726 .2866 Metetra
.664 .741 .907 r
.74726 .2866 .74814 .28782 .75462 .28564 .75375 .28442 Metetra
.664 .741 .907 r
.75375 .28442 .75462 .28564 .76112 .28345 .76025 .28222 Metetra
.664 .741 .907 r
.76025 .28222 .76112 .28345 .76763 .28125 .76676 .28002 Metetra
.664 .741 .907 r
.76676 .28002 .76763 .28125 .77416 .27905 .77329 .27782 Metetra
.664 .741 .907 r
.77329 .27782 .77416 .27905 .7807 .27684 .77983 .27561 Metetra
.664 .741 .907 r
.77983 .27561 .7807 .27684 .78725 .27463 .78639 .2734 Metetra
.664 .741 .907 r
.78639 .2734 .78725 .27463 .79382 .27242 .79297 .27118 Metetra
.664 .741 .907 r
.79297 .27118 .79382 .27242 .80041 .2702 .79956 .26896 Metetra
.664 .741 .907 r
.79956 .26896 .80041 .2702 .80701 .26797 .80616 .26673 Metetra
.664 .741 .907 r
.80616 .26673 .80701 .26797 .81363 .26574 .81278 .26449 Metetra
.664 .741 .907 r
.81278 .26449 .81363 .26574 .82026 .2635 .81941 .26226 Metetra
.664 .741 .907 r
.81941 .26226 .82026 .2635 .8269 .26126 .82606 .26001 Metetra
.664 .741 .907 r
.82606 .26001 .8269 .26126 .83356 .25902 .83273 .25776 Metetra
.664 .741 .907 r
.83273 .25776 .83356 .25902 .84024 .25677 .83941 .25551 Metetra
.664 .741 .907 r
.83941 .25551 .84024 .25677 .84693 .25451 .8461 .25325 Metetra
.664 .741 .907 r
.8461 .25325 .84693 .25451 .85364 .25225 .85281 .25098 Metetra
.664 .741 .907 r
.24931 .45327 .25039 .45429 .2558 .45246 .25471 .45144 Metetra
.664 .741 .907 r
.25471 .45144 .2558 .45246 .26122 .45063 .26013 .44961 Metetra
.664 .741 .907 r
.26013 .44961 .26122 .45063 .26665 .4488 .26557 .44778 Metetra
.664 .741 .907 r
.26557 .44778 .26665 .4488 .27209 .44696 .27101 .44594 Metetra
.664 .741 .907 r
.27101 .44594 .27209 .44696 .27754 .44512 .27646 .4441 Metetra
.664 .741 .907 r
.27646 .4441 .27754 .44512 .28301 .44328 .28193 .44225 Metetra
.664 .741 .907 r
.28193 .44225 .28301 .44328 .28848 .44143 .28741 .4404 Metetra
.664 .741 .907 r
.28741 .4404 .28848 .44143 .29397 .43958 .29289 .43855 Metetra
.664 .741 .907 r
.29289 .43855 .29397 .43958 .29946 .43773 .29839 .43669 Metetra
.664 .741 .907 r
.29839 .43669 .29946 .43773 .30497 .43587 .3039 .43483 Metetra
.328 .604 .947 r
.3039 .43483 .30497 .43587 .30938 .4509 .30924 .43587 Metetra
.586 .388 .58 r
.30924 .43587 .30938 .4509 .31598 .43288 .31496 .43109 Metetra
.649 .626 .813 r
.31496 .43109 .31598 .43288 .32157 .43027 .32051 .42922 Metetra
.664 .741 .907 r
.32051 .42922 .32157 .43027 .32713 .42839 .32607 .42734 Metetra
.664 .741 .907 r
.32607 .42734 .32713 .42839 .33269 .42651 .33163 .42546 Metetra
.664 .741 .907 r
.33163 .42546 .33269 .42651 .33827 .42463 .33722 .42358 Metetra
.664 .741 .907 r
.33722 .42358 .33827 .42463 .34386 .42274 .34281 .42169 Metetra
.664 .741 .907 r
.34281 .42169 .34386 .42274 .34946 .42085 .34841 .4198 Metetra
.664 .741 .907 r
.34841 .4198 .34946 .42085 .35508 .41896 .35403 .4179 Metetra
.664 .741 .907 r
.35403 .4179 .35508 .41896 .3607 .41706 .35966 .416 Metetra
.664 .741 .907 r
.35966 .416 .3607 .41706 .36634 .41516 .3653 .41409 Metetra
.664 .741 .907 r
.3653 .41409 .36634 .41516 .37199 .41325 .37095 .41218 Metetra
.664 .741 .907 r
.37095 .41218 .37199 .41325 .37765 .41134 .37661 .41027 Metetra
.664 .741 .907 r
.37661 .41027 .37765 .41134 .38333 .40942 .38229 .40835 Metetra
.664 .741 .907 r
.38229 .40835 .38333 .40942 .38901 .40751 .38798 .40643 Metetra
.664 .741 .907 r
.38798 .40643 .38901 .40751 .39471 .40558 .39368 .40451 Metetra
.953 .627 .364 r
.39368 .40451 .39471 .40558 .40042 .40366 .39804 .43718 Metetra
.671 .42 .533 r
.39804 .43718 .40042 .40366 .40477 .43897 .40186 .48827 Metetra
.232 .066 .44 r
.40186 .48827 .40477 .43897 .41188 .39979 .41085 .39871 Metetra
.664 .741 .907 r
.41085 .39871 .41188 .39979 .41762 .39785 .4166 .39677 Metetra
.664 .741 .907 r
.4166 .39677 .41762 .39785 .42338 .39591 .42236 .39482 Metetra
.664 .741 .907 r
.42236 .39482 .42338 .39591 .42916 .39396 .42814 .39287 Metetra
.664 .741 .907 r
.42814 .39287 .42916 .39396 .43494 .39201 .43392 .39092 Metetra
.664 .741 .907 r
.43392 .39092 .43494 .39201 .44073 .39005 .43972 .38896 Metetra
.664 .741 .907 r
.43972 .38896 .44073 .39005 .44653 .38866 .44553 .387 Metetra
.654 .648 .832 r
.44553 .387 .44653 .38866 .45236 .38613 .45135 .38503 Metetra
.664 .741 .907 r
.45135 .38503 .45236 .38613 .4582 .38416 .45719 .38306 Metetra
.664 .741 .907 r
.45719 .38306 .4582 .38416 .46404 .38218 .46304 .38108 Metetra
.664 .741 .907 r
.46304 .38108 .46404 .38218 .4699 .38021 .4689 .3791 Metetra
.664 .741 .907 r
.4689 .3791 .4699 .38021 .47577 .37823 .47477 .37712 Metetra
.664 .741 .907 r
.47477 .37712 .47577 .37823 .48166 .37624 .48066 .37513 Metetra
.664 .741 .907 r
.48066 .37513 .48166 .37624 .48755 .37425 .48656 .37314 Metetra
.664 .741 .907 r
.48656 .37314 .48755 .37425 .49346 .37226 .49247 .37114 Metetra
.664 .741 .907 r
.49247 .37114 .49346 .37226 .49938 .37026 .49839 .36914 Metetra
.664 .741 .907 r
.49839 .36914 .49938 .37026 .50532 .36826 .50433 .36714 Metetra
.664 .741 .907 r
.50433 .36714 .50532 .36826 .51127 .36625 .51028 .36513 Metetra
.664 .741 .907 r
.51028 .36513 .51127 .36625 .51723 .36424 .51624 .36311 Metetra
.664 .741 .907 r
.51624 .36311 .51723 .36424 .5232 .36222 .52222 .36109 Metetra
.664 .741 .907 r
.52222 .36109 .5232 .36222 .52919 .3602 .52821 .35907 Metetra
.664 .741 .907 r
.52821 .35907 .52919 .3602 .53519 .35818 .53421 .35704 Metetra
.664 .741 .907 r
.53421 .35704 .53519 .35818 .5412 .35615 .54023 .35501 Metetra
.664 .741 .907 r
.54023 .35501 .5412 .35615 .54723 .35411 .54626 .35298 Metetra
.664 .741 .907 r
.54626 .35298 .54723 .35411 .55327 .35207 .5523 .35094 Metetra
.664 .741 .907 r
.5523 .35094 .55327 .35207 .55932 .35003 .55835 .34889 Metetra
.664 .741 .907 r
.55835 .34889 .55932 .35003 .56538 .34798 .56442 .34684 Metetra
.664 .741 .907 r
.56442 .34684 .56538 .34798 .57146 .34593 .5705 .34479 Metetra
.664 .741 .907 r
.5705 .34479 .57146 .34593 .57756 .34388 .5766 .34273 Metetra
.664 .741 .907 r
.5766 .34273 .57756 .34388 .58366 .34182 .58271 .34067 Metetra
.664 .741 .907 r
.58271 .34067 .58366 .34182 .58978 .33975 .58883 .3386 Metetra
.664 .741 .907 r
.58883 .3386 .58978 .33975 .59591 .33768 .59496 .33653 Metetra
.664 .741 .907 r
.59496 .33653 .59591 .33768 .60206 .33561 .60111 .33445 Metetra
.664 .741 .907 r
.60111 .33445 .60206 .33561 .60822 .33353 .60728 .33237 Metetra
.664 .741 .907 r
.60728 .33237 .60822 .33353 .61439 .33145 .61345 .33028 Metetra
.664 .741 .907 r
.61345 .33028 .61439 .33145 .62058 .32936 .61964 .32819 Metetra
.965 .64 .326 r
.61964 .32819 .62058 .32936 .62681 .32808 .62795 .39171 Metetra
.41 .216 .504 r
.62795 .39171 .62681 .32808 .63299 .32517 .63206 .324 Metetra
.664 .741 .907 r
.63206 .324 .63299 .32517 .63922 .32307 .63829 .32189 Metetra
.664 .741 .907 r
.63829 .32189 .63922 .32307 .64547 .32096 .64454 .31978 Metetra
.664 .741 .907 r
.64454 .31978 .64547 .32096 .65172 .31885 .6508 .31767 Metetra
.664 .741 .907 r
.6508 .31767 .65172 .31885 .65799 .31673 .65707 .31555 Metetra
.664 .741 .907 r
.65707 .31555 .65799 .31673 .66428 .31461 .66336 .31343 Metetra
.664 .741 .907 r
.66336 .31343 .66428 .31461 .67057 .31249 .66966 .3113 Metetra
.664 .741 .907 r
.66966 .3113 .67057 .31249 .67689 .31036 .67597 .30917 Metetra
.664 .741 .907 r
.67597 .30917 .67689 .31036 .68321 .30822 .6823 .30703 Metetra
.664 .741 .907 r
.6823 .30703 .68321 .30822 .68955 .30608 .68865 .30488 Metetra
.664 .741 .907 r
.68865 .30488 .68955 .30608 .69591 .30394 .695 .30274 Metetra
.664 .741 .907 r
.695 .30274 .69591 .30394 .70228 .30179 .70138 .30059 Metetra
.664 .741 .907 r
.70138 .30059 .70228 .30179 .70866 .29963 .70776 .29843 Metetra
.664 .741 .907 r
.70776 .29843 .70866 .29963 .71506 .29747 .71416 .29627 Metetra
.664 .741 .907 r
.71416 .29627 .71506 .29747 .72147 .29531 .72058 .2941 Metetra
.664 .741 .907 r
.72058 .2941 .72147 .29531 .7279 .29314 .72701 .29193 Metetra
.664 .741 .907 r
.72701 .29193 .7279 .29314 .73434 .29097 .73345 .28975 Metetra
.664 .741 .907 r
.73345 .28975 .73434 .29097 .74079 .28879 .73991 .28757 Metetra
.664 .741 .907 r
.73991 .28757 .74079 .28879 .74726 .2866 .74638 .28538 Metetra
.664 .741 .907 r
.74638 .28538 .74726 .2866 .75375 .28442 .75287 .28319 Metetra
.664 .741 .907 r
.75287 .28319 .75375 .28442 .76025 .28222 .75937 .281 Metetra
.664 .741 .907 r
.75937 .281 .76025 .28222 .76676 .28002 .76589 .2788 Metetra
.664 .741 .907 r
.76589 .2788 .76676 .28002 .77329 .27782 .77242 .27659 Metetra
.664 .741 .907 r
.77242 .27659 .77329 .27782 .77983 .27561 .77897 .27438 Metetra
.664 .741 .907 r
.77897 .27438 .77983 .27561 .78639 .2734 .78553 .27216 Metetra
.664 .741 .907 r
.78553 .27216 .78639 .2734 .79297 .27118 .79211 .26994 Metetra
.664 .741 .907 r
.79211 .26994 .79297 .27118 .79956 .26896 .7987 .26771 Metetra
.664 .741 .907 r
.7987 .26771 .79956 .26896 .80616 .26673 .80531 .26548 Metetra
.664 .741 .907 r
.80531 .26548 .80616 .26673 .81278 .26449 .81193 .26325 Metetra
.664 .741 .907 r
.81193 .26325 .81278 .26449 .81941 .26226 .81857 .261 Metetra
.664 .741 .907 r
.81857 .261 .81941 .26226 .82606 .26001 .82522 .25876 Metetra
.664 .741 .907 r
.82522 .25876 .82606 .26001 .83273 .25776 .83189 .25651 Metetra
.664 .741 .907 r
.83189 .25651 .83273 .25776 .83941 .25551 .83857 .25425 Metetra
.664 .741 .907 r
.83857 .25425 .83941 .25551 .8461 .25325 .84527 .25199 Metetra
.664 .741 .907 r
.84527 .25199 .8461 .25325 .85281 .25098 .85199 .24972 Metetra
.664 .741 .907 r
.24821 .45225 .24931 .45327 .25471 .45144 .25363 .45042 Metetra
.664 .741 .907 r
.25363 .45042 .25471 .45144 .26013 .44961 .25905 .44859 Metetra
.664 .741 .907 r
.25905 .44859 .26013 .44961 .26557 .44778 .26448 .44675 Metetra
.664 .741 .907 r
.26448 .44675 .26557 .44778 .27101 .44594 .26993 .44491 Metetra
.664 .741 .907 r
.26993 .44491 .27101 .44594 .27646 .4441 .27538 .44307 Metetra
.664 .741 .907 r
.27538 .44307 .27646 .4441 .28193 .44225 .28085 .44122 Metetra
.664 .741 .907 r
.28085 .44122 .28193 .44225 .28741 .4404 .28633 .43937 Metetra
.664 .741 .907 r
.28633 .43937 .28741 .4404 .29289 .43855 .29182 .43751 Metetra
.664 .741 .907 r
.29182 .43751 .29289 .43855 .29839 .43669 .29732 .43565 Metetra
.664 .741 .907 r
.29732 .43565 .29839 .43669 .3039 .43483 .30283 .43379 Metetra
.664 .741 .907 r
.30283 .43379 .3039 .43483 .30924 .43587 .30836 .43192 Metetra
.609 .484 .685 r
.30836 .43192 .30924 .43587 .31496 .43109 .3139 .43005 Metetra
.664 .741 .907 r
.3139 .43005 .31496 .43109 .32051 .42922 .31944 .42817 Metetra
.664 .741 .907 r
.31944 .42817 .32051 .42922 .32607 .42734 .325 .4263 Metetra
.664 .741 .907 r
.325 .4263 .32607 .42734 .33163 .42546 .33058 .42441 Metetra
.664 .741 .907 r
.33058 .42441 .33163 .42546 .33722 .42358 .33616 .42253 Metetra
.664 .741 .907 r
.33616 .42253 .33722 .42358 .34281 .42169 .34175 .42063 Metetra
.664 .741 .907 r
.34175 .42063 .34281 .42169 .34841 .4198 .34736 .41874 Metetra
.664 .741 .907 r
.34736 .41874 .34841 .4198 .35403 .4179 .35298 .41684 Metetra
.664 .741 .907 r
.35298 .41684 .35403 .4179 .35966 .416 .35861 .41494 Metetra
.664 .741 .907 r
.35861 .41494 .35966 .416 .3653 .41409 .36425 .41303 Metetra
.664 .741 .907 r
.36425 .41303 .3653 .41409 .37095 .41218 .36991 .41112 Metetra
.664 .741 .907 r
.36991 .41112 .37095 .41218 .37661 .41027 .37557 .4092 Metetra
.664 .741 .907 r
.37557 .4092 .37661 .41027 .38229 .40835 .38125 .40728 Metetra
.664 .741 .907 r
.38125 .40728 .38229 .40835 .38798 .40643 .38694 .40536 Metetra
.664 .741 .907 r
.38694 .40536 .38798 .40643 .39368 .40451 .39264 .40343 Metetra
.954 .678 .474 r
.39264 .40343 .39368 .40451 .39804 .43718 .39104 .58789 Metetra
.493 .28 .519 r
.39104 .58789 .39804 .43718 .40186 .48827 .39946 .52298 Metetra
0 0 .197 r
.39946 .52298 .40186 .48827 .41085 .39871 .40982 .39763 Metetra
.664 .741 .907 r
.40982 .39763 .41085 .39871 .4166 .39677 .41557 .39568 Metetra
.664 .741 .907 r
.41557 .39568 .4166 .39677 .42236 .39482 .42134 .39373 Metetra
.664 .741 .907 r
.42134 .39373 .42236 .39482 .42814 .39287 .42711 .39178 Metetra
.664 .741 .907 r
.42711 .39178 .42814 .39287 .43392 .39092 .4329 .38982 Metetra
.664 .741 .907 r
.4329 .38982 .43392 .39092 .43972 .38896 .4387 .38786 Metetra
.664 .741 .907 r
.4387 .38786 .43972 .38896 .44553 .387 .44452 .3859 Metetra
.664 .741 .907 r
.44452 .3859 .44553 .387 .45135 .38503 .45034 .38393 Metetra
.664 .741 .907 r
.45034 .38393 .45135 .38503 .45719 .38306 .45618 .38196 Metetra
.664 .741 .907 r
.45618 .38196 .45719 .38306 .46304 .38108 .46203 .37998 Metetra
.664 .741 .907 r
.46203 .37998 .46304 .38108 .4689 .3791 .46789 .378 Metetra
.664 .741 .907 r
.46789 .378 .4689 .3791 .47477 .37712 .47377 .37601 Metetra
.664 .741 .907 r
.47377 .37601 .47477 .37712 .48066 .37513 .47966 .37402 Metetra
.664 .741 .907 r
.47966 .37402 .48066 .37513 .48656 .37314 .48556 .37203 Metetra
.664 .741 .907 r
.48556 .37203 .48656 .37314 .49247 .37114 .49147 .37003 Metetra
.664 .741 .907 r
.49147 .37003 .49247 .37114 .49839 .36914 .4974 .36802 Metetra
.664 .741 .907 r
.4974 .36802 .49839 .36914 .50433 .36714 .50334 .36602 Metetra
.664 .741 .907 r
.50334 .36602 .50433 .36714 .51028 .36513 .50929 .364 Metetra
.664 .741 .907 r
.50929 .364 .51028 .36513 .51624 .36311 .51526 .36199 Metetra
.664 .741 .907 r
.51526 .36199 .51624 .36311 .52222 .36109 .52124 .35997 Metetra
.664 .741 .907 r
.52124 .35997 .52222 .36109 .52821 .35907 .52723 .35794 Metetra
.664 .741 .907 r
.52723 .35794 .52821 .35907 .53421 .35704 .53324 .35591 Metetra
.664 .741 .907 r
.53324 .35591 .53421 .35704 .54023 .35501 .53925 .35388 Metetra
.664 .741 .907 r
.53925 .35388 .54023 .35501 .54626 .35298 .54529 .35184 Metetra
.664 .741 .907 r
.54529 .35184 .54626 .35298 .5523 .35094 .55133 .3498 Metetra
.664 .741 .907 r
.55133 .3498 .5523 .35094 .55835 .34889 .55739 .34775 Metetra
.664 .741 .907 r
.55739 .34775 .55835 .34889 .56442 .34684 .56346 .3457 Metetra
.664 .741 .907 r
.56346 .3457 .56442 .34684 .5705 .34479 .56954 .34364 Metetra
.664 .741 .907 r
.56954 .34364 .5705 .34479 .5766 .34273 .57564 .34158 Metetra
.664 .741 .907 r
.57564 .34158 .5766 .34273 .58271 .34067 .58175 .33951 Metetra
.664 .741 .907 r
.58175 .33951 .58271 .34067 .58883 .3386 .58788 .33744 Metetra
.664 .741 .907 r
.58788 .33744 .58883 .3386 .59496 .33653 .59401 .33537 Metetra
.664 .741 .907 r
.59401 .33537 .59496 .33653 .60111 .33445 .60017 .33329 Metetra
.664 .741 .907 r
.60017 .33329 .60111 .33445 .60728 .33237 .60633 .3312 Metetra
.664 .741 .907 r
.60633 .3312 .60728 .33237 .61345 .33028 .61251 .32912 Metetra
.664 .741 .907 r
.61251 .32912 .61345 .33028 .61964 .32819 .6187 .32702 Metetra
.767 .319 0 r
.6187 .32702 .61964 .32819 .62795 .39171 .62536 .33907 Metetra
.568 .353 .548 r
.62536 .33907 .62795 .39171 .63206 .324 .63133 .32866 Metetra
.29 .022 .323 r
.63133 .32866 .63206 .324 .63829 .32189 .63736 .32072 Metetra
.664 .741 .907 r
.63736 .32072 .63829 .32189 .64454 .31978 .64361 .3186 Metetra
.664 .741 .907 r
.64361 .3186 .64454 .31978 .6508 .31767 .64987 .31649 Metetra
.664 .741 .907 r
.64987 .31649 .6508 .31767 .65707 .31555 .65615 .31437 Metetra
.664 .741 .907 r
.65615 .31437 .65707 .31555 .66336 .31343 .66244 .31224 Metetra
.664 .741 .907 r
.66244 .31224 .66336 .31343 .66966 .3113 .66874 .31011 Metetra
.664 .741 .907 r
.66874 .31011 .66966 .3113 .67597 .30917 .67506 .30797 Metetra
.664 .741 .907 r
.67506 .30797 .67597 .30917 .6823 .30703 .68139 .30583 Metetra
.664 .741 .907 r
.68139 .30583 .6823 .30703 .68865 .30488 .68774 .30369 Metetra
.664 .741 .907 r
.68774 .30369 .68865 .30488 .695 .30274 .6941 .30154 Metetra
.664 .741 .907 r
.6941 .30154 .695 .30274 .70138 .30059 .70047 .29938 Metetra
.664 .741 .907 r
.70047 .29938 .70138 .30059 .70776 .29843 .70686 .29722 Metetra
.664 .741 .907 r
.70686 .29722 .70776 .29843 .71416 .29627 .71327 .29506 Metetra
.664 .741 .907 r
.71327 .29506 .71416 .29627 .72058 .2941 .71969 .29289 Metetra
.664 .741 .907 r
.71969 .29289 .72058 .2941 .72701 .29193 .72612 .29072 Metetra
.664 .741 .907 r
.72612 .29072 .72701 .29193 .73345 .28975 .73257 .28854 Metetra
.664 .741 .907 r
.73257 .28854 .73345 .28975 .73991 .28757 .73903 .28635 Metetra
.664 .741 .907 r
.73903 .28635 .73991 .28757 .74638 .28538 .7455 .28416 Metetra
.664 .741 .907 r
.7455 .28416 .74638 .28538 .75287 .28319 .75199 .28197 Metetra
.664 .741 .907 r
.75199 .28197 .75287 .28319 .75937 .281 .7585 .27977 Metetra
.664 .741 .907 r
.7585 .27977 .75937 .281 .76589 .2788 .76502 .27757 Metetra
.664 .741 .907 r
.76502 .27757 .76589 .2788 .77242 .27659 .77156 .27536 Metetra
.664 .741 .907 r
.77156 .27536 .77242 .27659 .77897 .27438 .77811 .27314 Metetra
.664 .741 .907 r
.77811 .27314 .77897 .27438 .78553 .27216 .78467 .27092 Metetra
.664 .741 .907 r
.78467 .27092 .78553 .27216 .79211 .26994 .79125 .2687 Metetra
.664 .741 .907 r
.79125 .2687 .79211 .26994 .7987 .26771 .79785 .26647 Metetra
.664 .741 .907 r
.79785 .26647 .7987 .26771 .80531 .26548 .80446 .26424 Metetra
.664 .741 .907 r
.80446 .26424 .80531 .26548 .81193 .26325 .81108 .262 Metetra
.664 .741 .907 r
.81108 .262 .81193 .26325 .81857 .261 .81772 .25975 Metetra
.664 .741 .907 r
.81772 .25975 .81857 .261 .82522 .25876 .82438 .2575 Metetra
.664 .741 .907 r
.82438 .2575 .82522 .25876 .83189 .25651 .83105 .25525 Metetra
.664 .741 .907 r
.83105 .25525 .83189 .25651 .83857 .25425 .83774 .25299 Metetra
.664 .741 .907 r
.83774 .25299 .83857 .25425 .84527 .25199 .84444 .25072 Metetra
.664 .741 .907 r
.84444 .25072 .84527 .25199 .85199 .24972 .85116 .24845 Metetra
.664 .741 .907 r
.24712 .45123 .24821 .45225 .25363 .45042 .25254 .4494 Metetra
.664 .741 .907 r
.25254 .4494 .25363 .45042 .25905 .44859 .25796 .44757 Metetra
.664 .741 .907 r
.25796 .44757 .25905 .44859 .26448 .44675 .2634 .44573 Metetra
.664 .741 .907 r
.2634 .44573 .26448 .44675 .26993 .44491 .26884 .44388 Metetra
.664 .741 .907 r
.26884 .44388 .26993 .44491 .27538 .44307 .2743 .44204 Metetra
.664 .741 .907 r
.2743 .44204 .27538 .44307 .28085 .44122 .27977 .44019 Metetra
.664 .741 .907 r
.27977 .44019 .28085 .44122 .28633 .43937 .28525 .43833 Metetra
.947 .635 .411 r
.28525 .43833 .28633 .43937 .29182 .43751 .28829 .47069 Metetra
.374 .169 .469 r
.28829 .47069 .29182 .43751 .29732 .43565 .29625 .43461 Metetra
.664 .741 .907 r
.29625 .43461 .29732 .43565 .30283 .43379 .30176 .43275 Metetra
.664 .741 .907 r
.30176 .43275 .30283 .43379 .30836 .43192 .30729 .43088 Metetra
.664 .741 .907 r
.30729 .43088 .30836 .43192 .3139 .43005 .31283 .429 Metetra
.664 .741 .907 r
.31283 .429 .3139 .43005 .31944 .42817 .31838 .42713 Metetra
.664 .741 .907 r
.31838 .42713 .31944 .42817 .325 .4263 .32394 .42525 Metetra
.664 .741 .907 r
.32394 .42525 .325 .4263 .33058 .42441 .32951 .42336 Metetra
.664 .741 .907 r
.32951 .42336 .33058 .42441 .33616 .42253 .3351 .42147 Metetra
.664 .741 .907 r
.3351 .42147 .33616 .42253 .34175 .42063 .3407 .41958 Metetra
.664 .741 .907 r
.3407 .41958 .34175 .42063 .34736 .41874 .34631 .41768 Metetra
.664 .741 .907 r
.34631 .41768 .34736 .41874 .35298 .41684 .35193 .41578 Metetra
.664 .741 .907 r
.35193 .41578 .35298 .41684 .35861 .41494 .35756 .41387 Metetra
.664 .741 .907 r
.35756 .41387 .35861 .41494 .36425 .41303 .3632 .41196 Metetra
.664 .741 .907 r
.3632 .41196 .36425 .41303 .36991 .41112 .36886 .41005 Metetra
.664 .741 .907 r
.36886 .41005 .36991 .41112 .37557 .4092 .37453 .40813 Metetra
.664 .741 .907 r
.37453 .40813 .37557 .4092 .38125 .40728 .38021 .40621 Metetra
.664 .741 .907 r
.38021 .40621 .38125 .40728 .38694 .40536 .3859 .40429 Metetra
.664 .741 .907 r
.3859 .40429 .38694 .40536 .39264 .40343 .39161 .40236 Metetra
.954 .679 .475 r
.39161 .40236 .39264 .40343 .39104 .58789 .38955 .59691 Metetra
.993 .754 .457 r
.38955 .59691 .39104 .58789 .39946 .52298 .40149 .43975 Metetra
.602 .378 .549 r
.40149 .43975 .39946 .52298 .40982 .39763 .40879 .39654 Metetra
.664 .741 .907 r
.40879 .39654 .40982 .39763 .41557 .39568 .41455 .3946 Metetra
.664 .741 .907 r
.41455 .3946 .41557 .39568 .42134 .39373 .42031 .39265 Metetra
.664 .741 .907 r
.42031 .39265 .42134 .39373 .42711 .39178 .42609 .39069 Metetra
.664 .741 .907 r
.42609 .39069 .42711 .39178 .4329 .38982 .43188 .38873 Metetra
.664 .741 .907 r
.43188 .38873 .4329 .38982 .4387 .38786 .43769 .38677 Metetra
.664 .741 .907 r
.43769 .38677 .4387 .38786 .44452 .3859 .4435 .3848 Metetra
.664 .741 .907 r
.4435 .3848 .44452 .3859 .45034 .38393 .44933 .38283 Metetra
.664 .741 .907 r
.44933 .38283 .45034 .38393 .45618 .38196 .45517 .38085 Metetra
.664 .741 .907 r
.45517 .38085 .45618 .38196 .46203 .37998 .46102 .37887 Metetra
.664 .741 .907 r
.46102 .37887 .46203 .37998 .46789 .378 .46689 .37689 Metetra
.664 .741 .907 r
.46689 .37689 .46789 .378 .47377 .37601 .47277 .3749 Metetra
.664 .741 .907 r
.47277 .3749 .47377 .37601 .47966 .37402 .47866 .37291 Metetra
.664 .741 .907 r
.47866 .37291 .47966 .37402 .48556 .37203 .48456 .37091 Metetra
.664 .741 .907 r
.48456 .37091 .48556 .37203 .49147 .37003 .49048 .36891 Metetra
.664 .741 .907 r
.49048 .36891 .49147 .37003 .4974 .36802 .49641 .3669 Metetra
.664 .741 .907 r
.49641 .3669 .4974 .36802 .50334 .36602 .50235 .36489 Metetra
.664 .741 .907 r
.50235 .36489 .50334 .36602 .50929 .364 .50831 .36288 Metetra
.664 .741 .907 r
.50831 .36288 .50929 .364 .51526 .36199 .51427 .36086 Metetra
.664 .741 .907 r
.51427 .36086 .51526 .36199 .52124 .35997 .52026 .35884 Metetra
.664 .741 .907 r
.52026 .35884 .52124 .35997 .52723 .35794 .52625 .35681 Metetra
.664 .741 .907 r
.52625 .35681 .52723 .35794 .53324 .35591 .53226 .35478 Metetra
.664 .741 .907 r
.53226 .35478 .53324 .35591 .53925 .35388 .53828 .35274 Metetra
.664 .741 .907 r
.53828 .35274 .53925 .35388 .54529 .35184 .54431 .3507 Metetra
.664 .741 .907 r
.54431 .3507 .54529 .35184 .55133 .3498 .55036 .34865 Metetra
.664 .741 .907 r
.55036 .34865 .55133 .3498 .55739 .34775 .55642 .3466 Metetra
.664 .741 .907 r
.55642 .3466 .55739 .34775 .56346 .3457 .56249 .34455 Metetra
.664 .741 .907 r
.56249 .34455 .56346 .3457 .56954 .34364 .56858 .34249 Metetra
.664 .741 .907 r
.56858 .34249 .56954 .34364 .57564 .34158 .57468 .34043 Metetra
.664 .741 .907 r
.57468 .34043 .57564 .34158 .58175 .33951 .5808 .33836 Metetra
.664 .741 .907 r
.5808 .33836 .58175 .33951 .58788 .33744 .58692 .33629 Metetra
.664 .741 .907 r
.58692 .33629 .58788 .33744 .59401 .33537 .59306 .33421 Metetra
.664 .741 .907 r
.59306 .33421 .59401 .33537 .60017 .33329 .59922 .33213 Metetra
.664 .741 .907 r
.59922 .33213 .60017 .33329 .60633 .3312 .60539 .33004 Metetra
.664 .741 .907 r
.60539 .33004 .60633 .3312 .61251 .32912 .61157 .32795 Metetra
.943 .58 .218 r
.61157 .32795 .61251 .32912 .6187 .32702 .61873 .3585 Metetra
.475 .257 .502 r
.61873 .3585 .6187 .32702 .62536 .33907 .62449 .34033 Metetra
.958 .884 .489 r
.62449 .34033 .62536 .33907 .63133 .32866 .63019 .32165 Metetra
.586 .424 .628 r
.63019 .32165 .63133 .32866 .63736 .32072 .63643 .31954 Metetra
.664 .741 .907 r
.63643 .31954 .63736 .32072 .64361 .3186 .64268 .31742 Metetra
.664 .741 .907 r
.64268 .31742 .64361 .3186 .64987 .31649 .64895 .3153 Metetra
.664 .741 .907 r
.64895 .3153 .64987 .31649 .65615 .31437 .65523 .31318 Metetra
.664 .741 .907 r
.65523 .31318 .65615 .31437 .66244 .31224 .66152 .31105 Metetra
.664 .741 .907 r
.66152 .31105 .66244 .31224 .66874 .31011 .66783 .30892 Metetra
.664 .741 .907 r
.66783 .30892 .66874 .31011 .67506 .30797 .67415 .30678 Metetra
.664 .741 .907 r
.67415 .30678 .67506 .30797 .68139 .30583 .68048 .30464 Metetra
.664 .741 .907 r
.68048 .30464 .68139 .30583 .68774 .30369 .68683 .30249 Metetra
.664 .741 .907 r
.68683 .30249 .68774 .30369 .6941 .30154 .69319 .30034 Metetra
.664 .741 .907 r
.69319 .30034 .6941 .30154 .70047 .29938 .69957 .29818 Metetra
.664 .741 .907 r
.69957 .29818 .70047 .29938 .70686 .29722 .70596 .29602 Metetra
.664 .741 .907 r
.70596 .29602 .70686 .29722 .71327 .29506 .71237 .29385 Metetra
.664 .741 .907 r
.71237 .29385 .71327 .29506 .71969 .29289 .71879 .29168 Metetra
.664 .741 .907 r
.71879 .29168 .71969 .29289 .72612 .29072 .72523 .2895 Metetra
.664 .741 .907 r
.72523 .2895 .72612 .29072 .73257 .28854 .73168 .28732 Metetra
.664 .741 .907 r
.73168 .28732 .73257 .28854 .73903 .28635 .73814 .28513 Metetra
0 .248 .757 r
.73814 .28513 .73903 .28635 .7455 .28416 .74516 .29051 Metetra
.338 .093 .387 r
.74516 .29051 .7455 .28416 .75199 .28197 .75112 .28074 Metetra
.664 .741 .907 r
.75112 .28074 .75199 .28197 .7585 .27977 .75763 .27854 Metetra
.664 .741 .907 r
.75763 .27854 .7585 .27977 .76502 .27757 .76415 .27633 Metetra
.664 .741 .907 r
.76415 .27633 .76502 .27757 .77156 .27536 .77069 .27412 Metetra
.664 .741 .907 r
.77069 .27412 .77156 .27536 .77811 .27314 .77724 .27191 Metetra
.664 .741 .907 r
.77724 .27191 .77811 .27314 .78467 .27092 .78381 .26968 Metetra
.664 .741 .907 r
.78381 .26968 .78467 .27092 .79125 .2687 .79039 .26746 Metetra
.664 .741 .907 r
.79039 .26746 .79125 .2687 .79785 .26647 .79699 .26522 Metetra
.664 .741 .907 r
.79699 .26522 .79785 .26647 .80446 .26424 .80361 .26299 Metetra
.664 .741 .907 r
.80361 .26299 .80446 .26424 .81108 .262 .81023 .26074 Metetra
.664 .741 .907 r
.81023 .26074 .81108 .262 .81772 .25975 .81688 .2585 Metetra
.664 .741 .907 r
.81688 .2585 .81772 .25975 .82438 .2575 .82354 .25624 Metetra
.664 .741 .907 r
.82354 .25624 .82438 .2575 .83105 .25525 .83021 .25399 Metetra
.664 .741 .907 r
.83021 .25399 .83105 .25525 .83774 .25299 .8369 .25172 Metetra
.664 .741 .907 r
.8369 .25172 .83774 .25299 .84444 .25072 .84361 .24946 Metetra
.664 .741 .907 r
.84361 .24946 .84444 .25072 .85116 .24845 .85033 .24718 Metetra
.664 .741 .907 r
.24603 .45021 .24712 .45123 .25254 .4494 .25145 .44838 Metetra
.664 .741 .907 r
.25145 .44838 .25254 .4494 .25796 .44757 .25687 .44654 Metetra
.664 .741 .907 r
.25687 .44654 .25796 .44757 .2634 .44573 .26231 .4447 Metetra
.664 .741 .907 r
.26231 .4447 .2634 .44573 .26884 .44388 .26776 .44285 Metetra
.664 .741 .907 r
.26776 .44285 .26884 .44388 .2743 .44204 .27322 .44101 Metetra
.664 .741 .907 r
.27322 .44101 .2743 .44204 .27977 .44019 .27869 .43915 Metetra
.664 .741 .907 r
.27869 .43915 .27977 .44019 .28525 .43833 .28417 .4373 Metetra
.946 .659 .462 r
.28417 .4373 .28525 .43833 .28829 .47069 .28544 .49396 Metetra
0 0 .294 r
.28544 .49396 .28829 .47069 .29625 .43461 .29517 .43357 Metetra
.664 .741 .907 r
.29517 .43357 .29625 .43461 .30176 .43275 .30069 .43171 Metetra
.664 .741 .907 r
.30069 .43171 .30176 .43275 .30729 .43088 .30622 .42983 Metetra
.664 .741 .907 r
.30622 .42983 .30729 .43088 .31283 .429 .31176 .42796 Metetra
.664 .741 .907 r
.31176 .42796 .31283 .429 .31838 .42713 .31731 .42608 Metetra
.664 .741 .907 r
.31731 .42608 .31838 .42713 .32394 .42525 .32288 .42419 Metetra
.664 .741 .907 r
.32288 .42419 .32394 .42525 .32951 .42336 .32845 .42231 Metetra
.664 .741 .907 r
.32845 .42231 .32951 .42336 .3351 .42147 .33404 .42042 Metetra
.664 .741 .907 r
.33404 .42042 .3351 .42147 .3407 .41958 .33964 .41852 Metetra
.664 .741 .907 r
.33964 .41852 .3407 .41958 .34631 .41768 .34525 .41662 Metetra
.664 .741 .907 r
.34525 .41662 .34631 .41768 .35193 .41578 .35087 .41472 Metetra
.664 .741 .907 r
.35087 .41472 .35193 .41578 .35756 .41387 .35651 .41281 Metetra
.664 .741 .907 r
.35651 .41281 .35756 .41387 .3632 .41196 .36215 .4109 Metetra
.664 .741 .907 r
.36215 .4109 .3632 .41196 .36886 .41005 .36781 .40898 Metetra
.664 .741 .907 r
.36781 .40898 .36886 .41005 .37453 .40813 .37348 .40706 Metetra
.664 .741 .907 r
.37348 .40706 .37453 .40813 .38021 .40621 .37917 .40514 Metetra
.664 .741 .907 r
.37917 .40514 .38021 .40621 .3859 .40429 .38486 .40321 Metetra
.664 .741 .907 r
.38486 .40321 .3859 .40429 .39161 .40236 .39057 .40128 Metetra
.956 .669 .453 r
.39057 .40128 .39161 .40236 .38955 .59691 .39245 .49557 Metetra
.617 .39 .549 r
.39245 .49557 .38955 .59691 .40149 .43975 .4009 .42679 Metetra
.731 .506 .585 r
.4009 .42679 .40149 .43975 .40879 .39654 .40776 .39546 Metetra
.664 .741 .907 r
.40776 .39546 .40879 .39654 .41455 .3946 .41352 .39351 Metetra
.664 .741 .907 r
.41352 .39351 .41455 .3946 .42031 .39265 .41929 .39156 Metetra
.664 .741 .907 r
.41929 .39156 .42031 .39265 .42609 .39069 .42507 .3896 Metetra
.664 .741 .907 r
.42507 .3896 .42609 .39069 .43188 .38873 .43086 .38764 Metetra
.664 .741 .907 r
.43086 .38764 .43188 .38873 .43769 .38677 .43667 .38567 Metetra
.664 .741 .907 r
.43667 .38567 .43769 .38677 .4435 .3848 .44248 .3837 Metetra
.664 .741 .907 r
.44248 .3837 .4435 .3848 .44933 .38283 .44832 .38173 Metetra
.664 .741 .907 r
.44832 .38173 .44933 .38283 .45517 .38085 .45416 .37975 Metetra
.664 .741 .907 r
.45416 .37975 .45517 .38085 .46102 .37887 .46001 .37777 Metetra
.664 .741 .907 r
.46001 .37777 .46102 .37887 .46689 .37689 .46588 .37578 Metetra
.664 .741 .907 r
.46588 .37578 .46689 .37689 .47277 .3749 .47176 .37379 Metetra
.664 .741 .907 r
.47176 .37379 .47277 .3749 .47866 .37291 .47766 .3718 Metetra
.664 .741 .907 r
.47766 .3718 .47866 .37291 .48456 .37091 .48356 .3698 Metetra
.664 .741 .907 r
.48356 .3698 .48456 .37091 .49048 .36891 .48948 .36779 Metetra
0 0 .513 r
.48948 .36779 .49048 .36891 .49641 .3669 .49534 .374 Metetra
.321 .077 .378 r
.49534 .374 .49641 .3669 .50235 .36489 .50136 .36377 Metetra
.664 .741 .907 r
.50136 .36377 .50235 .36489 .50831 .36288 .50732 .36175 Metetra
.664 .741 .907 r
.50732 .36175 .50831 .36288 .51427 .36086 .51329 .35973 Metetra
.664 .741 .907 r
.51329 .35973 .51427 .36086 .52026 .35884 .51927 .35771 Metetra
.664 .741 .907 r
.51927 .35771 .52026 .35884 .52625 .35681 .52527 .35568 Metetra
.664 .741 .907 r
.52527 .35568 .52625 .35681 .53226 .35478 .53128 .35364 Metetra
.664 .741 .907 r
.53128 .35364 .53226 .35478 .53828 .35274 .5373 .3516 Metetra
.664 .741 .907 r
.5373 .3516 .53828 .35274 .54431 .3507 .54334 .34956 Metetra
.664 .741 .907 r
.54334 .34956 .54431 .3507 .55036 .34865 .54939 .34751 Metetra
.664 .741 .907 r
.54939 .34751 .55036 .34865 .55642 .3466 .55545 .34546 Metetra
.664 .741 .907 r
.55545 .34546 .55642 .3466 .56249 .34455 .56153 .3434 Metetra
.664 .741 .907 r
.56153 .3434 .56249 .34455 .56858 .34249 .56762 .34134 Metetra
.664 .741 .907 r
.56762 .34134 .56858 .34249 .57468 .34043 .57372 .33927 Metetra
.664 .741 .907 r
.57372 .33927 .57468 .34043 .5808 .33836 .57984 .3372 Metetra
.664 .741 .907 r
.57984 .3372 .5808 .33836 .58692 .33629 .58597 .33513 Metetra
.664 .741 .907 r
.58597 .33513 .58692 .33629 .59306 .33421 .59211 .33305 Metetra
.664 .741 .907 r
.59211 .33305 .59306 .33421 .59922 .33213 .59827 .33096 Metetra
.664 .741 .907 r
.59827 .33096 .59922 .33213 .60539 .33004 .60444 .32887 Metetra
.664 .741 .907 r
.60444 .32887 .60539 .33004 .61157 .32795 .61062 .32678 Metetra
.664 .741 .907 r
.61062 .32678 .61157 .32795 .61873 .3585 .61682 .32468 Metetra
.538 .335 .553 r
.61682 .32468 .61873 .3585 .62449 .34033 .62319 .32767 Metetra
.608 .409 .587 r
.62319 .32767 .62449 .34033 .63019 .32165 .62926 .32047 Metetra
.664 .741 .907 r
.62926 .32047 .63019 .32165 .63643 .31954 .6355 .31836 Metetra
.664 .741 .907 r
.6355 .31836 .63643 .31954 .64268 .31742 .64175 .31624 Metetra
.664 .741 .907 r
.64175 .31624 .64268 .31742 .64895 .3153 .64802 .31412 Metetra
.664 .741 .907 r
.64802 .31412 .64895 .3153 .65523 .31318 .6543 .31199 Metetra
.664 .741 .907 r
.6543 .31199 .65523 .31318 .66152 .31105 .6606 .30986 Metetra
.664 .741 .907 r
.6606 .30986 .66152 .31105 .66783 .30892 .66691 .30773 Metetra
.664 .741 .907 r
.66691 .30773 .66783 .30892 .67415 .30678 .67323 .30559 Metetra
.664 .741 .907 r
.67323 .30559 .67415 .30678 .68048 .30464 .67957 .30344 Metetra
.664 .741 .907 r
.67957 .30344 .68048 .30464 .68683 .30249 .68592 .30129 Metetra
.664 .741 .907 r
.68592 .30129 .68683 .30249 .69319 .30034 .69229 .29913 Metetra
.664 .741 .907 r
.69229 .29913 .69319 .30034 .69957 .29818 .69867 .29697 Metetra
.664 .741 .907 r
.69867 .29697 .69957 .29818 .70596 .29602 .70506 .29481 Metetra
.664 .741 .907 r
.70506 .29481 .70596 .29602 .71237 .29385 .71147 .29264 Metetra
.664 .741 .907 r
.71147 .29264 .71237 .29385 .71879 .29168 .7179 .29046 Metetra
.664 .741 .907 r
.7179 .29046 .71879 .29168 .72523 .2895 .72434 .28828 Metetra
.664 .741 .907 r
.72434 .28828 .72523 .2895 .73168 .28732 .73079 .2861 Metetra
.664 .741 .907 r
.73079 .2861 .73168 .28732 .73814 .28513 .73726 .28391 Metetra
.664 .741 .907 r
.73726 .28391 .73814 .28513 .74516 .29051 .74374 .28172 Metetra
.579 .405 .61 r
.74374 .28172 .74516 .29051 .75112 .28074 .75024 .27952 Metetra
.664 .741 .907 r
.75024 .27952 .75112 .28074 .75763 .27854 .75675 .27731 Metetra
.664 .741 .907 r
.75675 .27731 .75763 .27854 .76415 .27633 .76328 .2751 Metetra
.664 .741 .907 r
.76328 .2751 .76415 .27633 .77069 .27412 .76982 .27289 Metetra
.664 .741 .907 r
.76982 .27289 .77069 .27412 .77724 .27191 .77637 .27067 Metetra
.664 .741 .907 r
.77637 .27067 .77724 .27191 .78381 .26968 .78295 .26844 Metetra
.664 .741 .907 r
.78295 .26844 .78381 .26968 .79039 .26746 .78953 .26621 Metetra
.664 .741 .907 r
.78953 .26621 .79039 .26746 .79699 .26522 .79613 .26398 Metetra
.664 .741 .907 r
.79613 .26398 .79699 .26522 .80361 .26299 .80275 .26174 Metetra
.664 .741 .907 r
.80275 .26174 .80361 .26299 .81023 .26074 .80938 .25949 Metetra
.664 .741 .907 r
.80938 .25949 .81023 .26074 .81688 .2585 .81603 .25724 Metetra
.664 .741 .907 r
.81603 .25724 .81688 .2585 .82354 .25624 .82269 .25499 Metetra
.664 .741 .907 r
.82269 .25499 .82354 .25624 .83021 .25399 .82937 .25273 Metetra
.664 .741 .907 r
.82937 .25273 .83021 .25399 .8369 .25172 .83607 .25046 Metetra
.664 .741 .907 r
.83607 .25046 .8369 .25172 .84361 .24946 .84277 .24819 Metetra
.664 .741 .907 r
.84277 .24819 .84361 .24946 .85033 .24718 .8495 .24591 Metetra
.664 .741 .907 r
.24494 .44919 .24603 .45021 .25145 .44838 .25035 .44735 Metetra
.664 .741 .907 r
.25035 .44735 .25145 .44838 .25687 .44654 .25578 .44551 Metetra
.664 .741 .907 r
.25578 .44551 .25687 .44654 .26231 .4447 .26122 .44367 Metetra
.664 .741 .907 r
.26122 .44367 .26231 .4447 .26776 .44285 .26667 .44182 Metetra
.664 .741 .907 r
.26667 .44182 .26776 .44285 .27322 .44101 .27213 .43997 Metetra
.664 .741 .907 r
.27213 .43997 .27322 .44101 .27869 .43915 .27761 .43812 Metetra
.664 .741 .907 r
.27761 .43812 .27869 .43915 .28417 .4373 .28309 .43626 Metetra
.942 .598 .338 r
.28309 .43626 .28417 .4373 .28544 .49396 .28693 .45723 Metetra
.618 .398 .561 r
.28693 .45723 .28544 .49396 .29517 .43357 .2941 .43253 Metetra
.664 .741 .907 r
.2941 .43253 .29517 .43357 .30069 .43171 .29962 .43066 Metetra
.664 .741 .907 r
.29962 .43066 .30069 .43171 .30622 .42983 .30515 .42879 Metetra
.664 .741 .907 r
.30515 .42879 .30622 .42983 .31176 .42796 .31069 .42691 Metetra
.664 .741 .907 r
.31069 .42691 .31176 .42796 .31731 .42608 .31625 .42503 Metetra
.664 .741 .907 r
.31625 .42503 .31731 .42608 .32288 .42419 .32181 .42314 Metetra
.664 .741 .907 r
.32181 .42314 .32288 .42419 .32845 .42231 .32739 .42125 Metetra
.664 .741 .907 r
.32739 .42125 .32845 .42231 .33404 .42042 .33298 .41936 Metetra
.664 .741 .907 r
.33298 .41936 .33404 .42042 .33964 .41852 .33858 .41746 Metetra
.664 .741 .907 r
.33858 .41746 .33964 .41852 .34525 .41662 .34419 .41556 Metetra
.664 .741 .907 r
.34419 .41556 .34525 .41662 .35087 .41472 .34982 .41365 Metetra
.664 .741 .907 r
.34982 .41365 .35087 .41472 .35651 .41281 .35546 .41174 Metetra
.664 .741 .907 r
.35546 .41174 .35651 .41281 .36215 .4109 .3611 .40983 Metetra
.664 .741 .907 r
.3611 .40983 .36215 .4109 .36781 .40898 .36677 .40791 Metetra
.664 .741 .907 r
.36677 .40791 .36781 .40898 .37348 .40706 .37244 .40599 Metetra
.664 .741 .907 r
.37244 .40599 .37348 .40706 .37917 .40514 .37812 .40406 Metetra
.664 .741 .907 r
.37812 .40406 .37917 .40514 .38486 .40321 .38382 .40213 Metetra
.664 .741 .907 r
.38382 .40213 .38486 .40321 .39057 .40128 .38953 .4002 Metetra
.664 .741 .907 r
.38953 .4002 .39057 .40128 .39245 .49557 .39525 .39826 Metetra
.535 .323 .538 r
.39525 .39826 .39245 .49557 .4009 .42679 .40058 .40673 Metetra
.612 .401 .571 r
.40058 .40673 .4009 .42679 .40776 .39546 .40673 .39437 Metetra
.949 .604 .316 r
.40673 .39437 .40776 .39546 .41352 .39351 .41151 .42039 Metetra
.38 .174 .471 r
.41151 .42039 .41352 .39351 .41929 .39156 .41826 .39046 Metetra
.664 .741 .907 r
.41826 .39046 .41929 .39156 .42507 .3896 .42404 .38851 Metetra
.664 .741 .907 r
.42404 .38851 .42507 .3896 .43086 .38764 .42984 .38654 Metetra
.664 .741 .907 r
.42984 .38654 .43086 .38764 .43667 .38567 .43565 .38457 Metetra
.664 .741 .907 r
.43565 .38457 .43667 .38567 .44248 .3837 .44147 .3826 Metetra
.664 .741 .907 r
.44147 .3826 .44248 .3837 .44832 .38173 .4473 .38063 Metetra
.664 .741 .907 r
.4473 .38063 .44832 .38173 .45416 .37975 .45315 .37865 Metetra
.664 .741 .907 r
.45315 .37865 .45416 .37975 .46001 .37777 .459 .37666 Metetra
.664 .741 .907 r
.459 .37666 .46001 .37777 .46588 .37578 .46487 .37467 Metetra
.664 .741 .907 r
.46487 .37467 .46588 .37578 .47176 .37379 .47076 .37268 Metetra
.664 .741 .907 r
.47076 .37268 .47176 .37379 .47766 .3718 .47665 .37068 Metetra
.664 .741 .907 r
.47665 .37068 .47766 .3718 .48356 .3698 .48256 .36868 Metetra
.664 .741 .907 r
.48256 .36868 .48356 .3698 .48948 .36779 .48848 .36667 Metetra
.664 .741 .907 r
.48848 .36667 .48948 .36779 .49534 .374 .49442 .36466 Metetra
.576 .399 .604 r
.49442 .36466 .49534 .374 .50136 .36377 .50037 .36265 Metetra
.664 .741 .907 r
.50037 .36265 .50136 .36377 .50732 .36175 .50633 .36063 Metetra
.664 .741 .907 r
.50633 .36063 .50732 .36175 .51329 .35973 .5123 .3586 Metetra
.664 .741 .907 r
.5123 .3586 .51329 .35973 .51927 .35771 .51829 .35657 Metetra
.664 .741 .907 r
.51829 .35657 .51927 .35771 .52527 .35568 .52429 .35454 Metetra
.664 .741 .907 r
.52429 .35454 .52527 .35568 .53128 .35364 .5303 .35251 Metetra
.664 .741 .907 r
.5303 .35251 .53128 .35364 .5373 .3516 .53633 .35046 Metetra
.664 .741 .907 r
.53633 .35046 .5373 .3516 .54334 .34956 .54236 .34842 Metetra
.664 .741 .907 r
.54236 .34842 .54334 .34956 .54939 .34751 .54842 .34637 Metetra
.664 .741 .907 r
.54842 .34637 .54939 .34751 .55545 .34546 .55448 .34431 Metetra
.664 .741 .907 r
.55448 .34431 .55545 .34546 .56153 .3434 .56056 .34225 Metetra
.664 .741 .907 r
.56056 .34225 .56153 .3434 .56762 .34134 .56665 .34019 Metetra
.664 .741 .907 r
.56665 .34019 .56762 .34134 .57372 .33927 .57276 .33812 Metetra
.664 .741 .907 r
.57276 .33812 .57372 .33927 .57984 .3372 .57888 .33605 Metetra
.664 .741 .907 r
.57888 .33605 .57984 .3372 .58597 .33513 .58501 .33397 Metetra
.664 .741 .907 r
.58501 .33397 .58597 .33513 .59211 .33305 .59116 .33189 Metetra
.664 .741 .907 r
.59116 .33189 .59211 .33305 .59827 .33096 .59732 .3298 Metetra
.664 .741 .907 r
.59732 .3298 .59827 .33096 .60444 .32887 .60349 .32771 Metetra
.664 .741 .907 r
.60349 .32771 .60444 .32887 .61062 .32678 .60968 .32561 Metetra
.664 .741 .907 r
.60968 .32561 .61062 .32678 .61682 .32468 .61588 .32351 Metetra
.664 .741 .907 r
.61588 .32351 .61682 .32468 .62319 .32767 .62209 .3214 Metetra
.59 .434 .638 r
.62209 .3214 .62319 .32767 .62926 .32047 .62832 .31929 Metetra
.664 .741 .907 r
.62832 .31929 .62926 .32047 .6355 .31836 .63456 .31718 Metetra
.664 .741 .907 r
.63456 .31718 .6355 .31836 .64175 .31624 .64082 .31506 Metetra
.664 .741 .907 r
.64082 .31506 .64175 .31624 .64802 .31412 .64709 .31293 Metetra
.664 .741 .907 r
.64709 .31293 .64802 .31412 .6543 .31199 .65338 .31081 Metetra
.664 .741 .907 r
.65338 .31081 .6543 .31199 .6606 .30986 .65967 .30867 Metetra
.664 .741 .907 r
.65967 .30867 .6606 .30986 .66691 .30773 .66599 .30653 Metetra
.664 .741 .907 r
.66599 .30653 .66691 .30773 .67323 .30559 .67231 .30439 Metetra
.664 .741 .907 r
.67231 .30439 .67323 .30559 .67957 .30344 .67865 .30224 Metetra
.664 .741 .907 r
.67865 .30224 .67957 .30344 .68592 .30129 .68501 .30009 Metetra
.664 .741 .907 r
.68501 .30009 .68592 .30129 .69229 .29913 .69138 .29793 Metetra
.664 .741 .907 r
.69138 .29793 .69229 .29913 .69867 .29697 .69776 .29577 Metetra
.664 .741 .907 r
.69776 .29577 .69867 .29697 .70506 .29481 .70416 .2936 Metetra
.664 .741 .907 r
.70416 .2936 .70506 .29481 .71147 .29264 .71057 .29143 Metetra
.664 .741 .907 r
.71057 .29143 .71147 .29264 .7179 .29046 .717 .28925 Metetra
.664 .741 .907 r
.717 .28925 .7179 .29046 .72434 .28828 .72344 .28707 Metetra
.664 .741 .907 r
.72344 .28707 .72434 .28828 .73079 .2861 .7299 .28488 Metetra
.664 .741 .907 r
.7299 .28488 .73079 .2861 .73726 .28391 .73637 .28269 Metetra
.664 .741 .907 r
.73637 .28269 .73726 .28391 .74374 .28172 .74286 .28049 Metetra
.664 .741 .907 r
.74286 .28049 .74374 .28172 .75024 .27952 .74936 .27829 Metetra
.664 .741 .907 r
.74936 .27829 .75024 .27952 .75675 .27731 .75587 .27608 Metetra
.664 .741 .907 r
.75587 .27608 .75675 .27731 .76328 .2751 .7624 .27387 Metetra
.664 .741 .907 r
.7624 .27387 .76328 .2751 .76982 .27289 .76895 .27165 Metetra
.664 .741 .907 r
.76895 .27165 .76982 .27289 .77637 .27067 .77551 .26943 Metetra
.664 .741 .907 r
.77551 .26943 .77637 .27067 .78295 .26844 .78208 .2672 Metetra
.664 .741 .907 r
.78208 .2672 .78295 .26844 .78953 .26621 .78867 .26497 Metetra
.664 .741 .907 r
.78867 .26497 .78953 .26621 .79613 .26398 .79528 .26273 Metetra
.664 .741 .907 r
.79528 .26273 .79613 .26398 .80275 .26174 .8019 .26049 Metetra
.664 .741 .907 r
.8019 .26049 .80275 .26174 .80938 .25949 .80853 .25824 Metetra
.664 .741 .907 r
.80853 .25824 .80938 .25949 .81603 .25724 .81518 .25598 Metetra
.664 .741 .907 r
.81518 .25598 .81603 .25724 .82269 .25499 .82185 .25373 Metetra
.664 .741 .907 r
.82185 .25373 .82269 .25499 .82937 .25273 .82853 .25146 Metetra
.664 .741 .907 r
.82853 .25146 .82937 .25273 .83607 .25046 .83523 .24919 Metetra
.664 .741 .907 r
.83523 .24919 .83607 .25046 .84277 .24819 .84194 .24692 Metetra
.664 .741 .907 r
.84194 .24692 .84277 .24819 .8495 .24591 .84867 .24464 Metetra
.664 .741 .907 r
.24384 .44817 .24494 .44919 .25035 .44735 .24926 .44633 Metetra
.664 .741 .907 r
.24926 .44633 .25035 .44735 .25578 .44551 .25469 .44449 Metetra
.664 .741 .907 r
.25469 .44449 .25578 .44551 .26122 .44367 .26013 .44264 Metetra
.664 .741 .907 r
.26013 .44264 .26122 .44367 .26667 .44182 .26558 .44079 Metetra
.664 .741 .907 r
.26558 .44079 .26667 .44182 .27213 .43997 .27105 .43894 Metetra
.664 .741 .907 r
.27105 .43894 .27213 .43997 .27761 .43812 .27652 .43708 Metetra
.664 .741 .907 r
.27652 .43708 .27761 .43812 .28309 .43626 .28201 .43522 Metetra
.742 .249 0 r
.28201 .43522 .28309 .43626 .28693 .45723 .28687 .44216 Metetra
.623 .417 .583 r
.28687 .44216 .28693 .45723 .2941 .43253 .29302 .43149 Metetra
.664 .741 .907 r
.29302 .43149 .2941 .43253 .29962 .43066 .29854 .42962 Metetra
.664 .741 .907 r
.29854 .42962 .29962 .43066 .30515 .42879 .30408 .42774 Metetra
.664 .741 .907 r
.30408 .42774 .30515 .42879 .31069 .42691 .30962 .42586 Metetra
.664 .741 .907 r
.30962 .42586 .31069 .42691 .31625 .42503 .31518 .42398 Metetra
.664 .741 .907 r
.31518 .42398 .31625 .42503 .32181 .42314 .32075 .42209 Metetra
.664 .741 .907 r
.32075 .42209 .32181 .42314 .32739 .42125 .32633 .4202 Metetra
.664 .741 .907 r
.32633 .4202 .32739 .42125 .33298 .41936 .33192 .4183 Metetra
.664 .741 .907 r
.33192 .4183 .33298 .41936 .33858 .41746 .33752 .4164 Metetra
.664 .741 .907 r
.33752 .4164 .33858 .41746 .34419 .41556 .34314 .4145 Metetra
.664 .741 .907 r
.34314 .4145 .34419 .41556 .34982 .41365 .34876 .41259 Metetra
.664 .741 .907 r
.34876 .41259 .34982 .41365 .35546 .41174 .3544 .41068 Metetra
.664 .741 .907 r
.3544 .41068 .35546 .41174 .3611 .40983 .36005 .40876 Metetra
.664 .741 .907 r
.36005 .40876 .3611 .40983 .36677 .40791 .36572 .40684 Metetra
.664 .741 .907 r
.36572 .40684 .36677 .40791 .37244 .40599 .37139 .40492 Metetra
.664 .741 .907 r
.37139 .40492 .37244 .40599 .37812 .40406 .37708 .40299 Metetra
.664 .741 .907 r
.37708 .40299 .37812 .40406 .38382 .40213 .38278 .40105 Metetra
.664 .741 .907 r
.38278 .40105 .38382 .40213 .38953 .4002 .38849 .39912 Metetra
.664 .741 .907 r
.38849 .39912 .38953 .4002 .39525 .39826 .39421 .39718 Metetra
.664 .741 .907 r
.39421 .39718 .39525 .39826 .40058 .40673 .39995 .39523 Metetra
.57 .385 .591 r
.39995 .39523 .40058 .40673 .40673 .39437 .4057 .39328 Metetra
.956 .676 .463 r
.4057 .39328 .40673 .39437 .41151 .42039 .40621 .54019 Metetra
.353 .168 .485 r
.40621 .54019 .41151 .42039 .41826 .39046 .41723 .38937 Metetra
.664 .741 .907 r
.41723 .38937 .41826 .39046 .42404 .38851 .42302 .38741 Metetra
.664 .741 .907 r
.42302 .38741 .42404 .38851 .42984 .38654 .42882 .38544 Metetra
.664 .741 .907 r
.42882 .38544 .42984 .38654 .43565 .38457 .43463 .38347 Metetra
.664 .741 .907 r
.43463 .38347 .43565 .38457 .44147 .3826 .44045 .3815 Metetra
.664 .741 .907 r
.44045 .3815 .44147 .3826 .4473 .38063 .44628 .37952 Metetra
.664 .741 .907 r
.44628 .37952 .4473 .38063 .45315 .37865 .45213 .37754 Metetra
.664 .741 .907 r
.45213 .37754 .45315 .37865 .459 .37666 .45799 .37555 Metetra
.664 .741 .907 r
.45799 .37555 .459 .37666 .46487 .37467 .46386 .37356 Metetra
.664 .741 .907 r
.46386 .37356 .46487 .37467 .47076 .37268 .46975 .37156 Metetra
.664 .741 .907 r
.46975 .37156 .47076 .37268 .47665 .37068 .47565 .36956 Metetra
.664 .741 .907 r
.47565 .36956 .47665 .37068 .48256 .36868 .48156 .36756 Metetra
.664 .741 .907 r
.48156 .36756 .48256 .36868 .48848 .36667 .48749 .36555 Metetra
.664 .741 .907 r
.48749 .36555 .48848 .36667 .49442 .36466 .49342 .36354 Metetra
.664 .741 .907 r
.49342 .36354 .49442 .36466 .50037 .36265 .49937 .36152 Metetra
.664 .741 .907 r
.49937 .36152 .50037 .36265 .50633 .36063 .50534 .3595 Metetra
.664 .741 .907 r
.50534 .3595 .50633 .36063 .5123 .3586 .51131 .35747 Metetra
.664 .741 .907 r
.51131 .35747 .5123 .3586 .51829 .35657 .5173 .35544 Metetra
.664 .741 .907 r
.5173 .35544 .51829 .35657 .52429 .35454 .5233 .35341 Metetra
.664 .741 .907 r
.5233 .35341 .52429 .35454 .5303 .35251 .52932 .35137 Metetra
.664 .741 .907 r
.52932 .35137 .5303 .35251 .53633 .35046 .53535 .34932 Metetra
.664 .741 .907 r
.53535 .34932 .53633 .35046 .54236 .34842 .54139 .34727 Metetra
.664 .741 .907 r
.54139 .34727 .54236 .34842 .54842 .34637 .54744 .34522 Metetra
.664 .741 .907 r
.54744 .34522 .54842 .34637 .55448 .34431 .55351 .34316 Metetra
.664 .741 .907 r
.55351 .34316 .55448 .34431 .56056 .34225 .55959 .3411 Metetra
.664 .741 .907 r
.55959 .3411 .56056 .34225 .56665 .34019 .56569 .33903 Metetra
.664 .741 .907 r
.56569 .33903 .56665 .34019 .57276 .33812 .5718 .33696 Metetra
.664 .741 .907 r
.5718 .33696 .57276 .33812 .57888 .33605 .57792 .33489 Metetra
.664 .741 .907 r
.57792 .33489 .57888 .33605 .58501 .33397 .58405 .33281 Metetra
.664 .741 .907 r
.58405 .33281 .58501 .33397 .59116 .33189 .5902 .33072 Metetra
.664 .741 .907 r
.5902 .33072 .59116 .33189 .59732 .3298 .59637 .32863 Metetra
.664 .741 .907 r
.59637 .32863 .59732 .3298 .60349 .32771 .60254 .32654 Metetra
.664 .741 .907 r
.60254 .32654 .60349 .32771 .60968 .32561 .60873 .32444 Metetra
.664 .741 .907 r
.60873 .32444 .60968 .32561 .61588 .32351 .61494 .32234 Metetra
.664 .741 .907 r
.61494 .32234 .61588 .32351 .62209 .3214 .62115 .32023 Metetra
.664 .741 .907 r
.62115 .32023 .62209 .3214 .62832 .31929 .62738 .31811 Metetra
.664 .741 .907 r
.62738 .31811 .62832 .31929 .63456 .31718 .63363 .316 Metetra
.664 .741 .907 r
.63363 .316 .63456 .31718 .64082 .31506 .63989 .31387 Metetra
.664 .741 .907 r
.63989 .31387 .64082 .31506 .64709 .31293 .64616 .31175 Metetra
.966 .64 .317 r
.64616 .31175 .64709 .31293 .65338 .31081 .65538 .38157 Metetra
.413 .219 .505 r
.65538 .38157 .65338 .31081 .65967 .30867 .65875 .30748 Metetra
.664 .741 .907 r
.65875 .30748 .65967 .30867 .66599 .30653 .66507 .30534 Metetra
.664 .741 .907 r
.66507 .30534 .66599 .30653 .67231 .30439 .6714 .30319 Metetra
.664 .741 .907 r
.6714 .30319 .67231 .30439 .67865 .30224 .67774 .30104 Metetra
.664 .741 .907 r
.67774 .30104 .67865 .30224 .68501 .30009 .6841 .29888 Metetra
.664 .741 .907 r
.6841 .29888 .68501 .30009 .69138 .29793 .69047 .29672 Metetra
.664 .741 .907 r
.69047 .29672 .69138 .29793 .69776 .29577 .69686 .29456 Metetra
.664 .741 .907 r
.69686 .29456 .69776 .29577 .70416 .2936 .70326 .29239 Metetra
.664 .741 .907 r
.70326 .29239 .70416 .2936 .71057 .29143 .70967 .29021 Metetra
.664 .741 .907 r
.70967 .29021 .71057 .29143 .717 .28925 .7161 .28803 Metetra
.664 .741 .907 r
.7161 .28803 .717 .28925 .72344 .28707 .72255 .28585 Metetra
.664 .741 .907 r
.72255 .28585 .72344 .28707 .7299 .28488 .72901 .28366 Metetra
.664 .741 .907 r
.72901 .28366 .7299 .28488 .73637 .28269 .73548 .28146 Metetra
.664 .741 .907 r
.73548 .28146 .73637 .28269 .74286 .28049 .74197 .27926 Metetra
.664 .741 .907 r
.74197 .27926 .74286 .28049 .74936 .27829 .74848 .27706 Metetra
.664 .741 .907 r
.74848 .27706 .74936 .27829 .75587 .27608 .75499 .27485 Metetra
.664 .741 .907 r
.75499 .27485 .75587 .27608 .7624 .27387 .76153 .27263 Metetra
.664 .741 .907 r
.76153 .27263 .7624 .27387 .76895 .27165 .76808 .27041 Metetra
.664 .741 .907 r
.76808 .27041 .76895 .27165 .77551 .26943 .77464 .26818 Metetra
.664 .741 .907 r
.77464 .26818 .77551 .26943 .78208 .2672 .78122 .26595 Metetra
.664 .741 .907 r
.78122 .26595 .78208 .2672 .78867 .26497 .78781 .26372 Metetra
.664 .741 .907 r
.78781 .26372 .78867 .26497 .79528 .26273 .79442 .26148 Metetra
.664 .741 .907 r
.79442 .26148 .79528 .26273 .8019 .26049 .80104 .25923 Metetra
.664 .741 .907 r
.80104 .25923 .8019 .26049 .80853 .25824 .80768 .25698 Metetra
.664 .741 .907 r
.80768 .25698 .80853 .25824 .81518 .25598 .81433 .25473 Metetra
.664 .741 .907 r
.81433 .25473 .81518 .25598 .82185 .25373 .821 .25246 Metetra
.664 .741 .907 r
.821 .25246 .82185 .25373 .82853 .25146 .82769 .2502 Metetra
.664 .741 .907 r
.82769 .2502 .82853 .25146 .83523 .24919 .83439 .24793 Metetra
.664 .741 .907 r
.83439 .24793 .83523 .24919 .84194 .24692 .8411 .24565 Metetra
.664 .741 .907 r
.8411 .24565 .84194 .24692 .84867 .24464 .84784 .24337 Metetra
.664 .741 .907 r
.24274 .44714 .24384 .44817 .24926 .44633 .24816 .4453 Metetra
.664 .741 .907 r
.24816 .4453 .24926 .44633 .25469 .44449 .2536 .44346 Metetra
.664 .741 .907 r
.2536 .44346 .25469 .44449 .26013 .44264 .25904 .44161 Metetra
.664 .741 .907 r
.25904 .44161 .26013 .44264 .26558 .44079 .2645 .43976 Metetra
.664 .741 .907 r
.2645 .43976 .26558 .44079 .27105 .43894 .26996 .4379 Metetra
.664 .741 .907 r
.26996 .4379 .27105 .43894 .27652 .43708 .27544 .43605 Metetra
.664 .741 .907 r
.27544 .43605 .27652 .43708 .28201 .43522 .28093 .43418 Metetra
.664 .741 .907 r
.28093 .43418 .28201 .43522 .28687 .44216 .28643 .43232 Metetra
.574 .393 .599 r
.28643 .43232 .28687 .44216 .29302 .43149 .29194 .43045 Metetra
.664 .741 .907 r
.29194 .43045 .29302 .43149 .29854 .42962 .29747 .42857 Metetra
.664 .741 .907 r
.29747 .42857 .29854 .42962 .30408 .42774 .303 .42669 Metetra
.664 .741 .907 r
.303 .42669 .30408 .42774 .30962 .42586 .30855 .42481 Metetra
.664 .741 .907 r
.30855 .42481 .30962 .42586 .31518 .42398 .31411 .42292 Metetra
.664 .741 .907 r
.31411 .42292 .31518 .42398 .32075 .42209 .31968 .42103 Metetra
.664 .741 .907 r
.31968 .42103 .32075 .42209 .32633 .4202 .32526 .41914 Metetra
.664 .741 .907 r
.32526 .41914 .32633 .4202 .33192 .4183 .33085 .41724 Metetra
.664 .741 .907 r
.33085 .41724 .33192 .4183 .33752 .4164 .33646 .41534 Metetra
.664 .741 .907 r
.33646 .41534 .33752 .4164 .34314 .4145 .34208 .41343 Metetra
.664 .741 .907 r
.34208 .41343 .34314 .4145 .34876 .41259 .34771 .41152 Metetra
.664 .741 .907 r
.34771 .41152 .34876 .41259 .3544 .41068 .35335 .40961 Metetra
.664 .741 .907 r
.35335 .40961 .3544 .41068 .36005 .40876 .359 .40769 Metetra
.664 .741 .907 r
.359 .40769 .36005 .40876 .36572 .40684 .36467 .40577 Metetra
.664 .741 .907 r
.36467 .40577 .36572 .40684 .37139 .40492 .37034 .40384 Metetra
.664 .741 .907 r
.37034 .40384 .37139 .40492 .37708 .40299 .37603 .40191 Metetra
.664 .741 .907 r
.37603 .40191 .37708 .40299 .38278 .40105 .38174 .39997 Metetra
.664 .741 .907 r
.38174 .39997 .38278 .40105 .38849 .39912 .38745 .39804 Metetra
.664 .741 .907 r
.38745 .39804 .38849 .39912 .39421 .39718 .39318 .39609 Metetra
.664 .741 .907 r
.39318 .39609 .39421 .39718 .39995 .39523 .39891 .39415 Metetra
.956 .676 .467 r
.39891 .39415 .39995 .39523 .4057 .39328 .39867 .55243 Metetra
.584 .355 .534 r
.39867 .55243 .4057 .39328 .40621 .54019 .40235 .61698 Metetra
0 0 .305 r
.40235 .61698 .40621 .54019 .41723 .38937 .4162 .38828 Metetra
.664 .741 .907 r
.4162 .38828 .41723 .38937 .42302 .38741 .42199 .38631 Metetra
.664 .741 .907 r
.42199 .38631 .42302 .38741 .42882 .38544 .42779 .38435 Metetra
.664 .741 .907 r
.42779 .38435 .42882 .38544 .43463 .38347 .4336 .38237 Metetra
.664 .741 .907 r
.4336 .38237 .43463 .38347 .44045 .3815 .43943 .3804 Metetra
.664 .741 .907 r
.43943 .3804 .44045 .3815 .44628 .37952 .44527 .37842 Metetra
.664 .741 .907 r
.44527 .37842 .44628 .37952 .45213 .37754 .45112 .37643 Metetra
.664 .741 .907 r
.45112 .37643 .45213 .37754 .45799 .37555 .45698 .37444 Metetra
.664 .741 .907 r
.45698 .37444 .45799 .37555 .46386 .37356 .46285 .37245 Metetra
.664 .741 .907 r
.46285 .37245 .46386 .37356 .46975 .37156 .46874 .37045 Metetra
.664 .741 .907 r
.46874 .37045 .46975 .37156 .47565 .36956 .47464 .36845 Metetra
.664 .741 .907 r
.47464 .36845 .47565 .36956 .48156 .36756 .48056 .36644 Metetra
.664 .741 .907 r
.48056 .36644 .48156 .36756 .48749 .36555 .48648 .36443 Metetra
.664 .741 .907 r
.48648 .36443 .48749 .36555 .49342 .36354 .49242 .36241 Metetra
.664 .741 .907 r
.49242 .36241 .49342 .36354 .49937 .36152 .49838 .36039 Metetra
.664 .741 .907 r
.49838 .36039 .49937 .36152 .50534 .3595 .50434 .35837 Metetra
.664 .741 .907 r
.50434 .35837 .50534 .3595 .51131 .35747 .51032 .35634 Metetra
.664 .741 .907 r
.51032 .35634 .51131 .35747 .5173 .35544 .51631 .35431 Metetra
.664 .741 .907 r
.51631 .35431 .5173 .35544 .5233 .35341 .52232 .35227 Metetra
.664 .741 .907 r
.52232 .35227 .5233 .35341 .52932 .35137 .52834 .35023 Metetra
.664 .741 .907 r
.52834 .35023 .52932 .35137 .53535 .34932 .53437 .34818 Metetra
.664 .741 .907 r
.53437 .34818 .53535 .34932 .54139 .34727 .54041 .34613 Metetra
.664 .741 .907 r
.54041 .34613 .54139 .34727 .54744 .34522 .54647 .34407 Metetra
.664 .741 .907 r
.54647 .34407 .54744 .34522 .55351 .34316 .55254 .34201 Metetra
.664 .741 .907 r
.55254 .34201 .55351 .34316 .55959 .3411 .55862 .33995 Metetra
.664 .741 .907 r
.55862 .33995 .55959 .3411 .56569 .33903 .56472 .33788 Metetra
.664 .741 .907 r
.56472 .33788 .56569 .33903 .5718 .33696 .57083 .33581 Metetra
.664 .741 .907 r
.57083 .33581 .5718 .33696 .57792 .33489 .57696 .33373 Metetra
.664 .741 .907 r
.57696 .33373 .57792 .33489 .58405 .33281 .5831 .33165 Metetra
.664 .741 .907 r
.5831 .33165 .58405 .33281 .5902 .33072 .58925 .32956 Metetra
.664 .741 .907 r
.58925 .32956 .5902 .33072 .59637 .32863 .59541 .32747 Metetra
.664 .741 .907 r
.59541 .32747 .59637 .32863 .60254 .32654 .60159 .32537 Metetra
.664 .741 .907 r
.60159 .32537 .60254 .32654 .60873 .32444 .60778 .32327 Metetra
.664 .741 .907 r
.60778 .32327 .60873 .32444 .61494 .32234 .61399 .32116 Metetra
.664 .741 .907 r
.61399 .32116 .61494 .32234 .62115 .32023 .62021 .31905 Metetra
.664 .741 .907 r
.62021 .31905 .62115 .32023 .62738 .31811 .62645 .31693 Metetra
.664 .741 .907 r
.62645 .31693 .62738 .31811 .63363 .316 .63269 .31481 Metetra
.791 .35 0 r
.63269 .31481 .63363 .316 .63989 .31387 .63951 .32806 Metetra
.379 .163 .455 r
.63951 .32806 .63989 .31387 .64616 .31175 .64523 .31056 Metetra
.916 .529 .122 r
.64523 .31056 .64616 .31175 .65538 .38157 .65258 .33463 Metetra
.606 .382 .55 r
.65258 .33463 .65538 .38157 .65875 .30748 .65783 .30629 Metetra
.664 .741 .907 r
.65783 .30629 .65875 .30748 .66507 .30534 .66414 .30414 Metetra
.664 .741 .907 r
.66414 .30414 .66507 .30534 .6714 .30319 .67048 .30199 Metetra
.664 .741 .907 r
.67048 .30199 .6714 .30319 .67774 .30104 .67682 .29984 Metetra
.664 .741 .907 r
.67682 .29984 .67774 .30104 .6841 .29888 .68319 .29768 Metetra
.664 .741 .907 r
.68319 .29768 .6841 .29888 .69047 .29672 .68956 .29552 Metetra
.664 .741 .907 r
.68956 .29552 .69047 .29672 .69686 .29456 .69595 .29335 Metetra
.664 .741 .907 r
.69595 .29335 .69686 .29456 .70326 .29239 .70235 .29118 Metetra
.664 .741 .907 r
.70235 .29118 .70326 .29239 .70967 .29021 .70877 .289 Metetra
.664 .741 .907 r
.70877 .289 .70967 .29021 .7161 .28803 .71521 .28681 Metetra
.664 .741 .907 r
.71521 .28681 .7161 .28803 .72255 .28585 .72165 .28463 Metetra
.664 .741 .907 r
.72165 .28463 .72255 .28585 .72901 .28366 .72812 .28243 Metetra
.664 .741 .907 r
.72812 .28243 .72901 .28366 .73548 .28146 .73459 .28023 Metetra
.664 .741 .907 r
.73459 .28023 .73548 .28146 .74197 .27926 .74109 .27803 Metetra
.664 .741 .907 r
.74109 .27803 .74197 .27926 .74848 .27706 .74759 .27582 Metetra
.664 .741 .907 r
.74759 .27582 .74848 .27706 .75499 .27485 .75411 .27361 Metetra
.664 .741 .907 r
.75411 .27361 .75499 .27485 .76153 .27263 .76065 .27139 Metetra
.664 .741 .907 r
.76065 .27139 .76153 .27263 .76808 .27041 .7672 .26917 Metetra
.664 .741 .907 r
.7672 .26917 .76808 .27041 .77464 .26818 .77377 .26694 Metetra
.664 .741 .907 r
.77377 .26694 .77464 .26818 .78122 .26595 .78035 .26471 Metetra
.664 .741 .907 r
.78035 .26471 .78122 .26595 .78781 .26372 .78695 .26247 Metetra
.664 .741 .907 r
.78695 .26247 .78781 .26372 .79442 .26148 .79356 .26023 Metetra
.664 .741 .907 r
.79356 .26023 .79442 .26148 .80104 .25923 .80018 .25798 Metetra
.664 .741 .907 r
.80018 .25798 .80104 .25923 .80768 .25698 .80683 .25572 Metetra
.664 .741 .907 r
.80683 .25572 .80768 .25698 .81433 .25473 .81348 .25346 Metetra
.664 .741 .907 r
.81348 .25346 .81433 .25473 .821 .25246 .82016 .2512 Metetra
.664 .741 .907 r
.82016 .2512 .821 .25246 .82769 .2502 .82684 .24893 Metetra
.664 .741 .907 r
.82684 .24893 .82769 .2502 .83439 .24793 .83355 .24666 Metetra
.664 .741 .907 r
.83355 .24666 .83439 .24793 .8411 .24565 .84027 .24438 Metetra
.664 .741 .907 r
.84027 .24438 .8411 .24565 .84784 .24337 .847 .24209 Metetra
.664 .741 .907 r
.24165 .44612 .24274 .44714 .24816 .4453 .24707 .44427 Metetra
.664 .741 .907 r
.24707 .44427 .24816 .4453 .2536 .44346 .2525 .44243 Metetra
.664 .741 .907 r
.2525 .44243 .2536 .44346 .25904 .44161 .25795 .44058 Metetra
.664 .741 .907 r
.25795 .44058 .25904 .44161 .2645 .43976 .26341 .43873 Metetra
.664 .741 .907 r
.26341 .43873 .2645 .43976 .26996 .4379 .26887 .43687 Metetra
.664 .741 .907 r
.26887 .43687 .26996 .4379 .27544 .43605 .27435 .43501 Metetra
.664 .741 .907 r
.27435 .43501 .27544 .43605 .28093 .43418 .27984 .43314 Metetra
.664 .741 .907 r
.27984 .43314 .28093 .43418 .28643 .43232 .28535 .43127 Metetra
.664 .741 .907 r
.28535 .43127 .28643 .43232 .29194 .43045 .29086 .4294 Metetra
.664 .741 .907 r
.29086 .4294 .29194 .43045 .29747 .42857 .29639 .42752 Metetra
.664 .741 .907 r
.29639 .42752 .29747 .42857 .303 .42669 .30193 .42564 Metetra
.664 .741 .907 r
.30193 .42564 .303 .42669 .30855 .42481 .30747 .42376 Metetra
.664 .741 .907 r
.30747 .42376 .30855 .42481 .31411 .42292 .31304 .42187 Metetra
.664 .741 .907 r
.31304 .42187 .31411 .42292 .31968 .42103 .31861 .41998 Metetra
.664 .741 .907 r
.31861 .41998 .31968 .42103 .32526 .41914 .32419 .41808 Metetra
.664 .741 .907 r
.32419 .41808 .32526 .41914 .33085 .41724 .32979 .41618 Metetra
.664 .741 .907 r
.32979 .41618 .33085 .41724 .33646 .41534 .3354 .41428 Metetra
.664 .741 .907 r
.3354 .41428 .33646 .41534 .34208 .41343 .34102 .41237 Metetra
.664 .741 .907 r
.34102 .41237 .34208 .41343 .34771 .41152 .34665 .41046 Metetra
.664 .741 .907 r
.34665 .41046 .34771 .41152 .35335 .40961 .35229 .40854 Metetra
.664 .741 .907 r
.35229 .40854 .35335 .40961 .359 .40769 .35795 .40662 Metetra
.664 .741 .907 r
.35795 .40662 .359 .40769 .36467 .40577 .36362 .40469 Metetra
.664 .741 .907 r
.36362 .40469 .36467 .40577 .37034 .40384 .36929 .40276 Metetra
.664 .741 .907 r
.36929 .40276 .37034 .40384 .37603 .40191 .37499 .40083 Metetra
.664 .741 .907 r
.37499 .40083 .37603 .40191 .38174 .39997 .38069 .39889 Metetra
.664 .741 .907 r
.38069 .39889 .38174 .39997 .38745 .39804 .38641 .39695 Metetra
.664 .741 .907 r
.38641 .39695 .38745 .39804 .39318 .39609 .39214 .39501 Metetra
.664 .741 .907 r
.39214 .39501 .39318 .39609 .39891 .39415 .39788 .39306 Metetra
.956 .674 .461 r
.39788 .39306 .39891 .39415 .39867 .55243 .39867 .52243 Metetra
.651 .426 .564 r
.39867 .52243 .39867 .55243 .40235 .61698 .40579 .48945 Metetra
.629 .397 .548 r
.40579 .48945 .40235 .61698 .4162 .38828 .41517 .38718 Metetra
.664 .741 .907 r
.41517 .38718 .4162 .38828 .42199 .38631 .42096 .38522 Metetra
.664 .741 .907 r
.42096 .38522 .42199 .38631 .42779 .38435 .42676 .38325 Metetra
.664 .741 .907 r
.42676 .38325 .42779 .38435 .4336 .38237 .43258 .38127 Metetra
.664 .741 .907 r
.43258 .38127 .4336 .38237 .43943 .3804 .43841 .37929 Metetra
.664 .741 .907 r
.43841 .37929 .43943 .3804 .44527 .37842 .44425 .37731 Metetra
.664 .741 .907 r
.44425 .37731 .44527 .37842 .45112 .37643 .4501 .37532 Metetra
.664 .741 .907 r
.4501 .37532 .45112 .37643 .45698 .37444 .45596 .37333 Metetra
.664 .741 .907 r
.45596 .37333 .45698 .37444 .46285 .37245 .46184 .37133 Metetra
.664 .741 .907 r
.46184 .37133 .46285 .37245 .46874 .37045 .46773 .36933 Metetra
.664 .741 .907 r
.46773 .36933 .46874 .37045 .47464 .36845 .47364 .36733 Metetra
.664 .741 .907 r
.47364 .36733 .47464 .36845 .48056 .36644 .47955 .36532 Metetra
.664 .741 .907 r
.47955 .36532 .48056 .36644 .48648 .36443 .48548 .36331 Metetra
.664 .741 .907 r
.48548 .36331 .48648 .36443 .49242 .36241 .49143 .36129 Metetra
.664 .741 .907 r
.49143 .36129 .49242 .36241 .49838 .36039 .49738 .35926 Metetra
.664 .741 .907 r
.49738 .35926 .49838 .36039 .50434 .35837 .50335 .35724 Metetra
.664 .741 .907 r
.50335 .35724 .50434 .35837 .51032 .35634 .50933 .35521 Metetra
.664 .741 .907 r
.50933 .35521 .51032 .35634 .51631 .35431 .51532 .35317 Metetra
.664 .741 .907 r
.51532 .35317 .51631 .35431 .52232 .35227 .52133 .35113 Metetra
.664 .741 .907 r
.52133 .35113 .52232 .35227 .52834 .35023 .52735 .34909 Metetra
.664 .741 .907 r
.52735 .34909 .52834 .35023 .53437 .34818 .53339 .34704 Metetra
.664 .741 .907 r
.53339 .34704 .53437 .34818 .54041 .34613 .53943 .34498 Metetra
.664 .741 .907 r
.53943 .34498 .54041 .34613 .54647 .34407 .54549 .34293 Metetra
.664 .741 .907 r
.54549 .34293 .54647 .34407 .55254 .34201 .55157 .34086 Metetra
.664 .741 .907 r
.55157 .34086 .55254 .34201 .55862 .33995 .55765 .3388 Metetra
.664 .741 .907 r
.55765 .3388 .55862 .33995 .56472 .33788 .56375 .33672 Metetra
.664 .741 .907 r
.56375 .33672 .56472 .33788 .57083 .33581 .56987 .33465 Metetra
.664 .741 .907 r
.56987 .33465 .57083 .33581 .57696 .33373 .57599 .33257 Metetra
.664 .741 .907 r
.57599 .33257 .57696 .33373 .5831 .33165 .58214 .33048 Metetra
.664 .741 .907 r
.58214 .33048 .5831 .33165 .58925 .32956 .58829 .32839 Metetra
.664 .741 .907 r
.58829 .32839 .58925 .32956 .59541 .32747 .59446 .3263 Metetra
.664 .741 .907 r
.59446 .3263 .59541 .32747 .60159 .32537 .60064 .3242 Metetra
.664 .741 .907 r
.60064 .3242 .60159 .32537 .60778 .32327 .60684 .32209 Metetra
.664 .741 .907 r
.60684 .32209 .60778 .32327 .61399 .32116 .61304 .31998 Metetra
.664 .741 .907 r
.61304 .31998 .61399 .32116 .62021 .31905 .61927 .31787 Metetra
.664 .741 .907 r
.61927 .31787 .62021 .31905 .62645 .31693 .62551 .31575 Metetra
.664 .741 .907 r
.62551 .31575 .62645 .31693 .63269 .31481 .63176 .31363 Metetra
.664 .741 .907 r
.63176 .31363 .63269 .31481 .63951 .32806 .63802 .3115 Metetra
.269 .154 .533 r
.63802 .3115 .63951 .32806 .64523 .31056 .6456 .34357 Metetra
.402 .202 .49 r
.6456 .34357 .64523 .31056 .65258 .33463 .65059 .30723 Metetra
.556 .351 .558 r
.65059 .30723 .65258 .33463 .65783 .30629 .6569 .30509 Metetra
.664 .741 .907 r
.6569 .30509 .65783 .30629 .66414 .30414 .66322 .30294 Metetra
.664 .741 .907 r
.66322 .30294 .66414 .30414 .67048 .30199 .66956 .30079 Metetra
.664 .741 .907 r
.66956 .30079 .67048 .30199 .67682 .29984 .67591 .29864 Metetra
.664 .741 .907 r
.67591 .29864 .67682 .29984 .68319 .29768 .68227 .29647 Metetra
.664 .741 .907 r
.68227 .29647 .68319 .29768 .68956 .29552 .68865 .29431 Metetra
.664 .741 .907 r
.68865 .29431 .68956 .29552 .69595 .29335 .69504 .29214 Metetra
.664 .741 .907 r
.69504 .29214 .69595 .29335 .70235 .29118 .70145 .28996 Metetra
.664 .741 .907 r
.70145 .28996 .70235 .29118 .70877 .289 .70787 .28778 Metetra
.664 .741 .907 r
.70787 .28778 .70877 .289 .71521 .28681 .71431 .28559 Metetra
.664 .741 .907 r
.71431 .28559 .71521 .28681 .72165 .28463 .72076 .2834 Metetra
.664 .741 .907 r
.72076 .2834 .72165 .28463 .72812 .28243 .72722 .28121 Metetra
.664 .741 .907 r
.72722 .28121 .72812 .28243 .73459 .28023 .7337 .27901 Metetra
.664 .741 .907 r
.7337 .27901 .73459 .28023 .74109 .27803 .7402 .2768 Metetra
.664 .741 .907 r
.7402 .2768 .74109 .27803 .74759 .27582 .74671 .27459 Metetra
.664 .741 .907 r
.74671 .27459 .74759 .27582 .75411 .27361 .75323 .27237 Metetra
.664 .741 .907 r
.75323 .27237 .75411 .27361 .76065 .27139 .75977 .27015 Metetra
.664 .741 .907 r
.75977 .27015 .76065 .27139 .7672 .26917 .76633 .26793 Metetra
.664 .741 .907 r
.76633 .26793 .7672 .26917 .77377 .26694 .7729 .2657 Metetra
.664 .741 .907 r
.7729 .2657 .77377 .26694 .78035 .26471 .77948 .26346 Metetra
.664 .741 .907 r
.77948 .26346 .78035 .26471 .78695 .26247 .78608 .26122 Metetra
.664 .741 .907 r
.78608 .26122 .78695 .26247 .79356 .26023 .7927 .25897 Metetra
.664 .741 .907 r
.7927 .25897 .79356 .26023 .80018 .25798 .79933 .25672 Metetra
.664 .741 .907 r
.79933 .25672 .80018 .25798 .80683 .25572 .80597 .25446 Metetra
.664 .741 .907 r
.80597 .25446 .80683 .25572 .81348 .25346 .81263 .2522 Metetra
.664 .741 .907 r
.81263 .2522 .81348 .25346 .82016 .2512 .81931 .24993 Metetra
.664 .741 .907 r
.81931 .24993 .82016 .2512 .82684 .24893 .826 .24766 Metetra
.664 .741 .907 r
.826 .24766 .82684 .24893 .83355 .24666 .83271 .24538 Metetra
.664 .741 .907 r
.83271 .24538 .83355 .24666 .84027 .24438 .83943 .2431 Metetra
.664 .741 .907 r
.83943 .2431 .84027 .24438 .847 .24209 .84617 .24081 Metetra
.664 .741 .907 r
.24055 .44509 .24165 .44612 .24707 .44427 .24597 .44324 Metetra
.664 .741 .907 r
.24597 .44324 .24707 .44427 .2525 .44243 .25141 .4414 Metetra
.664 .741 .907 r
.25141 .4414 .2525 .44243 .25795 .44058 .25685 .43955 Metetra
.664 .741 .907 r
.25685 .43955 .25795 .44058 .26341 .43873 .26231 .43769 Metetra
.664 .741 .907 r
.26231 .43769 .26341 .43873 .26887 .43687 .26778 .43583 Metetra
.664 .741 .907 r
.26778 .43583 .26887 .43687 .27435 .43501 .27327 .43397 Metetra
.664 .741 .907 r
.27327 .43397 .27435 .43501 .27984 .43314 .27876 .4321 Metetra
.664 .741 .907 r
.27876 .4321 .27984 .43314 .28535 .43127 .28426 .43023 Metetra
.838 .378 0 r
.28426 .43023 .28535 .43127 .29086 .4294 .28901 .43906 Metetra
.32 .085 .393 r
.28901 .43906 .29086 .4294 .29639 .42752 .29531 .42648 Metetra
.664 .741 .907 r
.29531 .42648 .29639 .42752 .30193 .42564 .30085 .42459 Metetra
.664 .741 .907 r
.30085 .42459 .30193 .42564 .30747 .42376 .3064 .42271 Metetra
.664 .741 .907 r
.3064 .42271 .30747 .42376 .31304 .42187 .31196 .42082 Metetra
.664 .741 .907 r
.31196 .42082 .31304 .42187 .31861 .41998 .31754 .41892 Metetra
.664 .741 .907 r
.31754 .41892 .31861 .41998 .32419 .41808 .32312 .41702 Metetra
.664 .741 .907 r
.32312 .41702 .32419 .41808 .32979 .41618 .32872 .41512 Metetra
.664 .741 .907 r
.32872 .41512 .32979 .41618 .3354 .41428 .33433 .41321 Metetra
.664 .741 .907 r
.33433 .41321 .3354 .41428 .34102 .41237 .33995 .4113 Metetra
.664 .741 .907 r
.33995 .4113 .34102 .41237 .34665 .41046 .34559 .40939 Metetra
.664 .741 .907 r
.34559 .40939 .34665 .41046 .35229 .40854 .35123 .40747 Metetra
.664 .741 .907 r
.35123 .40747 .35229 .40854 .35795 .40662 .35689 .40554 Metetra
.664 .741 .907 r
.35689 .40554 .35795 .40662 .36362 .40469 .36256 .40362 Metetra
.664 .741 .907 r
.36256 .40362 .36362 .40469 .36929 .40276 .36824 .40169 Metetra
.664 .741 .907 r
.36824 .40169 .36929 .40276 .37499 .40083 .37394 .39975 Metetra
.664 .741 .907 r
.37394 .39975 .37499 .40083 .38069 .39889 .37964 .39781 Metetra
.664 .741 .907 r
.37964 .39781 .38069 .39889 .38641 .39695 .38536 .39587 Metetra
.664 .741 .907 r
.38536 .39587 .38641 .39695 .39214 .39501 .39109 .39392 Metetra
.664 .741 .907 r
.39109 .39392 .39214 .39501 .39788 .39306 .39684 .39197 Metetra
.957 .654 .418 r
.39684 .39197 .39788 .39306 .39867 .52243 .40038 .44809 Metetra
.569 .351 .544 r
.40038 .44809 .39867 .52243 .40579 .48945 .40675 .43251 Metetra
.628 .4 .553 r
.40675 .43251 .40579 .48945 .41517 .38718 .41414 .38609 Metetra
.664 .741 .907 r
.41414 .38609 .41517 .38718 .42096 .38522 .41993 .38412 Metetra
.664 .741 .907 r
.41993 .38412 .42096 .38522 .42676 .38325 .42574 .38215 Metetra
.664 .741 .907 r
.42574 .38215 .42676 .38325 .43258 .38127 .43155 .38017 Metetra
.664 .741 .907 r
.43155 .38017 .43258 .38127 .43841 .37929 .43738 .37819 Metetra
.664 .741 .907 r
.43738 .37819 .43841 .37929 .44425 .37731 .44323 .3762 Metetra
.664 .741 .907 r
.44323 .3762 .44425 .37731 .4501 .37532 .44908 .37421 Metetra
.664 .741 .907 r
.44908 .37421 .4501 .37532 .45596 .37333 .45495 .37222 Metetra
.664 .741 .907 r
.45495 .37222 .45596 .37333 .46184 .37133 .46083 .37022 Metetra
.664 .741 .907 r
.46083 .37022 .46184 .37133 .46773 .36933 .46672 .36822 Metetra
.664 .741 .907 r
.46672 .36822 .46773 .36933 .47364 .36733 .47263 .36621 Metetra
.664 .741 .907 r
.47263 .36621 .47364 .36733 .47955 .36532 .47855 .3642 Metetra
.664 .741 .907 r
.47855 .3642 .47955 .36532 .48548 .36331 .48448 .36218 Metetra
.664 .741 .907 r
.48448 .36218 .48548 .36331 .49143 .36129 .49042 .36016 Metetra
.664 .741 .907 r
.49042 .36016 .49143 .36129 .49738 .35926 .49638 .35814 Metetra
.664 .741 .907 r
.49638 .35814 .49738 .35926 .50335 .35724 .50235 .35611 Metetra
.506 .678 .943 r
.50235 .35611 .50335 .35724 .50933 .35521 .50833 .35597 Metetra
.50833 .35597 .50933 .35521 .51532 .35317 .51433 .35203 Metetra
.664 .741 .907 r
.51433 .35203 .51532 .35317 .52133 .35113 .52034 .34999 Metetra
.664 .741 .907 r
.52034 .34999 .52133 .35113 .52735 .34909 .52637 .34794 Metetra
.664 .741 .907 r
.52637 .34794 .52735 .34909 .53339 .34704 .5324 .34589 Metetra
.664 .741 .907 r
.5324 .34589 .53339 .34704 .53943 .34498 .53845 .34384 Metetra
.664 .741 .907 r
.53845 .34384 .53943 .34498 .54549 .34293 .54452 .34178 Metetra
.664 .741 .907 r
.54452 .34178 .54549 .34293 .55157 .34086 .55059 .33971 Metetra
.664 .741 .907 r
.55059 .33971 .55157 .34086 .55765 .3388 .55668 .33764 Metetra
.664 .741 .907 r
.55668 .33764 .55765 .3388 .56375 .33672 .56278 .33557 Metetra
.664 .741 .907 r
.56278 .33557 .56375 .33672 .56987 .33465 .5689 .33349 Metetra
.664 .741 .907 r
.5689 .33349 .56987 .33465 .57599 .33257 .57503 .3314 Metetra
.664 .741 .907 r
.57503 .3314 .57599 .33257 .58214 .33048 .58117 .32932 Metetra
.664 .741 .907 r
.58117 .32932 .58214 .33048 .58829 .32839 .58733 .32722 Metetra
.664 .741 .907 r
.58733 .32722 .58829 .32839 .59446 .3263 .5935 .32513 Metetra
.664 .741 .907 r
.5935 .32513 .59446 .3263 .60064 .3242 .59969 .32302 Metetra
.664 .741 .907 r
.59969 .32302 .60064 .3242 .60684 .32209 .60589 .32092 Metetra
.664 .741 .907 r
.60589 .32092 .60684 .32209 .61304 .31998 .6121 .31881 Metetra
.664 .741 .907 r
.6121 .31881 .61304 .31998 .61927 .31787 .61832 .31669 Metetra
.664 .741 .907 r
.61832 .31669 .61927 .31787 .62551 .31575 .62456 .31457 Metetra
.664 .741 .907 r
.62456 .31457 .62551 .31575 .63176 .31363 .63082 .31244 Metetra
.664 .741 .907 r
.63082 .31244 .63176 .31363 .63802 .3115 .63709 .31031 Metetra
.664 .741 .907 r
.63709 .31031 .63802 .3115 .6456 .34357 .64337 .30818 Metetra
.539 .334 .551 r
.64337 .30818 .6456 .34357 .65059 .30723 .64985 .31076 Metetra
.242 0 .254 r
.64985 .31076 .65059 .30723 .6569 .30509 .65597 .30389 Metetra
.664 .741 .907 r
.65597 .30389 .6569 .30509 .66322 .30294 .6623 .30174 Metetra
.664 .741 .907 r
.6623 .30174 .66322 .30294 .66956 .30079 .66864 .29959 Metetra
.664 .741 .907 r
.66864 .29959 .66956 .30079 .67591 .29864 .67499 .29743 Metetra
.664 .741 .907 r
.67499 .29743 .67591 .29864 .68227 .29647 .68136 .29527 Metetra
.664 .741 .907 r
.68136 .29527 .68227 .29647 .68865 .29431 .68774 .2931 Metetra
.664 .741 .907 r
.68774 .2931 .68865 .29431 .69504 .29214 .69413 .29092 Metetra
.664 .741 .907 r
.69413 .29092 .69504 .29214 .70145 .28996 .70054 .28875 Metetra
.664 .741 .907 r
.70054 .28875 .70145 .28996 .70787 .28778 .70697 .28656 Metetra
.664 .741 .907 r
.70697 .28656 .70787 .28778 .71431 .28559 .71341 .28437 Metetra
.664 .741 .907 r
.71341 .28437 .71431 .28559 .72076 .2834 .71986 .28218 Metetra
.664 .741 .907 r
.71986 .28218 .72076 .2834 .72722 .28121 .72633 .27998 Metetra
.664 .741 .907 r
.72633 .27998 .72722 .28121 .7337 .27901 .73281 .27778 Metetra
.664 .741 .907 r
.73281 .27778 .7337 .27901 .7402 .2768 .73931 .27557 Metetra
.664 .741 .907 r
.73931 .27557 .7402 .2768 .74671 .27459 .74582 .27336 Metetra
.664 .741 .907 r
.74582 .27336 .74671 .27459 .75323 .27237 .75235 .27114 Metetra
.664 .741 .907 r
.75235 .27114 .75323 .27237 .75977 .27015 .75889 .26891 Metetra
.664 .741 .907 r
.75889 .26891 .75977 .27015 .76633 .26793 .76545 .26668 Metetra
.664 .741 .907 r
.76545 .26668 .76633 .26793 .7729 .2657 .77203 .26445 Metetra
.664 .741 .907 r
.77203 .26445 .7729 .2657 .77948 .26346 .77861 .26221 Metetra
.664 .741 .907 r
.77861 .26221 .77948 .26346 .78608 .26122 .78522 .25997 Metetra
.664 .741 .907 r
.78522 .25997 .78608 .26122 .7927 .25897 .79183 .25772 Metetra
.664 .741 .907 r
.79183 .25772 .7927 .25897 .79933 .25672 .79847 .25546 Metetra
.664 .741 .907 r
.79847 .25546 .79933 .25672 .80597 .25446 .80512 .2532 Metetra
.664 .741 .907 r
.80512 .2532 .80597 .25446 .81263 .2522 .81178 .25094 Metetra
.664 .741 .907 r
.81178 .25094 .81263 .2522 .81931 .24993 .81846 .24867 Metetra
.664 .741 .907 r
.81846 .24867 .81931 .24993 .826 .24766 .82515 .24639 Metetra
.664 .741 .907 r
.82515 .24639 .826 .24766 .83271 .24538 .83186 .24411 Metetra
.664 .741 .907 r
.83186 .24411 .83271 .24538 .83943 .2431 .83859 .24183 Metetra
.664 .741 .907 r
.83859 .24183 .83943 .2431 .84617 .24081 .84533 .23953 Metetra
.664 .741 .907 r
.23945 .44406 .24055 .44509 .24597 .44324 .24487 .44221 Metetra
.664 .741 .907 r
.24487 .44221 .24597 .44324 .25141 .4414 .25031 .44036 Metetra
.664 .741 .907 r
.25031 .44036 .25141 .4414 .25685 .43955 .25576 .43851 Metetra
.664 .741 .907 r
.25576 .43851 .25685 .43955 .26231 .43769 .26122 .43665 Metetra
.664 .741 .907 r
.26122 .43665 .26231 .43769 .26778 .43583 .26669 .43479 Metetra
.664 .741 .907 r
.26669 .43479 .26778 .43583 .27327 .43397 .27218 .43293 Metetra
.664 .741 .907 r
.27218 .43293 .27327 .43397 .27876 .4321 .27767 .43106 Metetra
.664 .741 .907 r
.27767 .43106 .27876 .4321 .28426 .43023 .28318 .42918 Metetra
.948 .639 .418 r
.28318 .42918 .28426 .43023 .28901 .43906 .286 .46438 Metetra
.269 .077 .425 r
.286 .46438 .28901 .43906 .29531 .42648 .29423 .42543 Metetra
.664 .741 .907 r
.29423 .42543 .29531 .42648 .30085 .42459 .29977 .42354 Metetra
.664 .741 .907 r
.29977 .42354 .30085 .42459 .3064 .42271 .30532 .42165 Metetra
.664 .741 .907 r
.30532 .42165 .3064 .42271 .31196 .42082 .31089 .41976 Metetra
.664 .741 .907 r
.31089 .41976 .31196 .42082 .31754 .41892 .31647 .41786 Metetra
.664 .741 .907 r
.31647 .41786 .31754 .41892 .32312 .41702 .32205 .41596 Metetra
.664 .741 .907 r
.32205 .41596 .32312 .41702 .32872 .41512 .32766 .41406 Metetra
.664 .741 .907 r
.32766 .41406 .32872 .41512 .33433 .41321 .33327 .41215 Metetra
.664 .741 .907 r
.33327 .41215 .33433 .41321 .33995 .4113 .33889 .41023 Metetra
.664 .741 .907 r
.33889 .41023 .33995 .4113 .34559 .40939 .34453 .40832 Metetra
.664 .741 .907 r
.34453 .40832 .34559 .40939 .35123 .40747 .35018 .4064 Metetra
.664 .741 .907 r
.35018 .4064 .35123 .40747 .35689 .40554 .35584 .40447 Metetra
.664 .741 .907 r
.35584 .40447 .35689 .40554 .36256 .40362 .36151 .40254 Metetra
.664 .741 .907 r
.36151 .40254 .36256 .40362 .36824 .40169 .36719 .40061 Metetra
0 .076 .583 r
.36719 .40061 .36824 .40169 .37394 .39975 .37257 .40548 Metetra
.278 .017 .327 r
.37257 .40548 .37394 .39975 .37964 .39781 .3786 .39673 Metetra
.664 .741 .907 r
.3786 .39673 .37964 .39781 .38536 .39587 .38432 .39478 Metetra
.664 .741 .907 r
.38432 .39478 .38536 .39587 .39109 .39392 .39005 .39283 Metetra
.664 .741 .907 r
.39005 .39283 .39109 .39392 .39684 .39197 .3958 .39088 Metetra
.664 .741 .907 r
.3958 .39088 .39684 .39197 .40038 .44809 .40155 .38892 Metetra
.54 .329 .542 r
.40155 .38892 .40038 .44809 .40675 .43251 .40715 .3918 Metetra
.565 .352 .551 r
.40715 .3918 .40675 .43251 .41414 .38609 .41311 .38499 Metetra
.664 .741 .907 r
.41311 .38499 .41414 .38609 .41993 .38412 .4189 .38302 Metetra
.664 .741 .907 r
.4189 .38302 .41993 .38412 .42574 .38215 .42471 .38104 Metetra
.664 .741 .907 r
.42471 .38104 .42574 .38215 .43155 .38017 .43053 .37906 Metetra
.664 .741 .907 r
.43053 .37906 .43155 .38017 .43738 .37819 .43636 .37708 Metetra
.664 .741 .907 r
.43636 .37708 .43738 .37819 .44323 .3762 .44221 .37509 Metetra
.664 .741 .907 r
.44221 .37509 .44323 .3762 .44908 .37421 .44806 .3731 Metetra
.664 .741 .907 r
.44806 .3731 .44908 .37421 .45495 .37222 .45393 .3711 Metetra
.664 .741 .907 r
.45393 .3711 .45495 .37222 .46083 .37022 .45982 .3691 Metetra
.664 .741 .907 r
.45982 .3691 .46083 .37022 .46672 .36822 .46571 .3671 Metetra
.664 .741 .907 r
.46571 .3671 .46672 .36822 .47263 .36621 .47162 .36509 Metetra
.664 .741 .907 r
.47162 .36509 .47263 .36621 .47855 .3642 .47754 .36307 Metetra
.664 .741 .907 r
.47754 .36307 .47855 .3642 .48448 .36218 .48348 .36105 Metetra
.664 .741 .907 r
.48348 .36105 .48448 .36218 .49042 .36016 .48942 .35903 Metetra
.664 .741 .907 r
.48942 .35903 .49042 .36016 .49638 .35814 .49538 .357 Metetra
.664 .741 .907 r
.49538 .357 .49638 .35814 .50235 .35611 .50136 .35497 Metetra
.664 .741 .907 r
.50136 .35497 .50235 .35611 .50833 .35597 .50734 .35294 Metetra
.624 .532 .73 r
.50734 .35294 .50833 .35597 .51433 .35203 .51334 .3509 Metetra
.664 .741 .907 r
.51334 .3509 .51433 .35203 .52034 .34999 .51935 .34885 Metetra
.664 .741 .907 r
.51935 .34885 .52034 .34999 .52637 .34794 .52538 .3468 Metetra
.664 .741 .907 r
.52538 .3468 .52637 .34794 .5324 .34589 .53142 .34475 Metetra
.664 .741 .907 r
.53142 .34475 .5324 .34589 .53845 .34384 .53747 .34269 Metetra
.664 .741 .907 r
.53747 .34269 .53845 .34384 .54452 .34178 .54354 .34062 Metetra
.664 .741 .907 r
.54354 .34062 .54452 .34178 .55059 .33971 .54962 .33856 Metetra
.664 .741 .907 r
.54962 .33856 .55059 .33971 .55668 .33764 .55571 .33648 Metetra
.664 .741 .907 r
.55571 .33648 .55668 .33764 .56278 .33557 .56181 .33441 Metetra
.793 .344 0 r
.56181 .33441 .56278 .33557 .5689 .33349 .56812 .34623 Metetra
.366 .146 .442 r
.56812 .34623 .5689 .33349 .57503 .3314 .57407 .33024 Metetra
.664 .741 .907 r
.57407 .33024 .57503 .3314 .58117 .32932 .58021 .32815 Metetra
.664 .741 .907 r
.58021 .32815 .58117 .32932 .58733 .32722 .58637 .32605 Metetra
.664 .741 .907 r
.58637 .32605 .58733 .32722 .5935 .32513 .59255 .32395 Metetra
.664 .741 .907 r
.59255 .32395 .5935 .32513 .59969 .32302 .59873 .32185 Metetra
.664 .741 .907 r
.59873 .32185 .59969 .32302 .60589 .32092 .60493 .31974 Metetra
.664 .741 .907 r
.60493 .31974 .60589 .32092 .6121 .31881 .61115 .31763 Metetra
.664 .741 .907 r
.61115 .31763 .6121 .31881 .61832 .31669 .61738 .31551 Metetra
.664 .741 .907 r
.61738 .31551 .61832 .31669 .62456 .31457 .62362 .31338 Metetra
.664 .741 .907 r
.62362 .31338 .62456 .31457 .63082 .31244 .62988 .31126 Metetra
.664 .741 .907 r
.62988 .31126 .63082 .31244 .63709 .31031 .63615 .30912 Metetra
.664 .741 .907 r
.63615 .30912 .63709 .31031 .64337 .30818 .64243 .30699 Metetra
.664 .741 .907 r
.64243 .30699 .64337 .30818 .64985 .31076 .64873 .30484 Metetra
.592 .44 .644 r
.64873 .30484 .64985 .31076 .65597 .30389 .65504 .3027 Metetra
.664 .741 .907 r
.65504 .3027 .65597 .30389 .6623 .30174 .66137 .30054 Metetra
.664 .741 .907 r
.66137 .30054 .6623 .30174 .66864 .29959 .66771 .29839 Metetra
.664 .741 .907 r
.66771 .29839 .66864 .29959 .67499 .29743 .67407 .29622 Metetra
.664 .741 .907 r
.67407 .29622 .67499 .29743 .68136 .29527 .68044 .29406 Metetra
.664 .741 .907 r
.68044 .29406 .68136 .29527 .68774 .2931 .68682 .29189 Metetra
.664 .741 .907 r
.68682 .29189 .68774 .2931 .69413 .29092 .69322 .28971 Metetra
.664 .741 .907 r
.69322 .28971 .69413 .29092 .70054 .28875 .69964 .28753 Metetra
.664 .741 .907 r
.69964 .28753 .70054 .28875 .70697 .28656 .70606 .28534 Metetra
.664 .741 .907 r
.70606 .28534 .70697 .28656 .71341 .28437 .71251 .28315 Metetra
.664 .741 .907 r
.71251 .28315 .71341 .28437 .71986 .28218 .71896 .28095 Metetra
.664 .741 .907 r
.71896 .28095 .71986 .28218 .72633 .27998 .72543 .27875 Metetra
.664 .741 .907 r
.72543 .27875 .72633 .27998 .73281 .27778 .73192 .27655 Metetra
.664 .741 .907 r
.73192 .27655 .73281 .27778 .73931 .27557 .73842 .27433 Metetra
.664 .741 .907 r
.73842 .27433 .73931 .27557 .74582 .27336 .74494 .27212 Metetra
.664 .741 .907 r
.74494 .27212 .74582 .27336 .75235 .27114 .75147 .2699 Metetra
.664 .741 .907 r
.75147 .2699 .75235 .27114 .75889 .26891 .75802 .26767 Metetra
.664 .741 .907 r
.75802 .26767 .75889 .26891 .76545 .26668 .76458 .26544 Metetra
.664 .741 .907 r
.76458 .26544 .76545 .26668 .77203 .26445 .77115 .2632 Metetra
.664 .741 .907 r
.77115 .2632 .77203 .26445 .77861 .26221 .77774 .26096 Metetra
.664 .741 .907 r
.77774 .26096 .77861 .26221 .78522 .25997 .78435 .25871 Metetra
.664 .741 .907 r
.78435 .25871 .78522 .25997 .79183 .25772 .79097 .25646 Metetra
.664 .741 .907 r
.79097 .25646 .79183 .25772 .79847 .25546 .79761 .2542 Metetra
.664 .741 .907 r
.79761 .2542 .79847 .25546 .80512 .2532 .80426 .25194 Metetra
.664 .741 .907 r
.80426 .25194 .80512 .2532 .81178 .25094 .81093 .24967 Metetra
.664 .741 .907 r
.81093 .24967 .81178 .25094 .81846 .24867 .81761 .2474 Metetra
.664 .741 .907 r
.81761 .2474 .81846 .24867 .82515 .24639 .82431 .24512 Metetra
.664 .741 .907 r
.82431 .24512 .82515 .24639 .83186 .24411 .83102 .24284 Metetra
.664 .741 .907 r
.83102 .24284 .83186 .24411 .83859 .24183 .83775 .24055 Metetra
.664 .741 .907 r
.83775 .24055 .83859 .24183 .84533 .23953 .84449 .23825 Metetra
.664 .741 .907 r
.23834 .44303 .23945 .44406 .24487 .44221 .24377 .44118 Metetra
.664 .741 .907 r
.24377 .44118 .24487 .44221 .25031 .44036 .24921 .43933 Metetra
.664 .741 .907 r
.24921 .43933 .25031 .44036 .25576 .43851 .25466 .43748 Metetra
.664 .741 .907 r
.25466 .43748 .25576 .43851 .26122 .43665 .26013 .43562 Metetra
.664 .741 .907 r
.26013 .43562 .26122 .43665 .26669 .43479 .2656 .43375 Metetra
.664 .741 .907 r
.2656 .43375 .26669 .43479 .27218 .43293 .27109 .43188 Metetra
.664 .741 .907 r
.27109 .43188 .27218 .43293 .27767 .43106 .27659 .43001 Metetra
.664 .741 .907 r
.27659 .43001 .27767 .43106 .28318 .42918 .28209 .42814 Metetra
.335 .608 .949 r
.28209 .42814 .28318 .42918 .286 .46438 .28741 .42912 Metetra
.562 .352 .553 r
.28741 .42912 .286 .46438 .29423 .42543 .29315 .42438 Metetra
.664 .741 .907 r
.29315 .42438 .29423 .42543 .29977 .42354 .29869 .42249 Metetra
.664 .741 .907 r
.29869 .42249 .29977 .42354 .30532 .42165 .30425 .4206 Metetra
.664 .741 .907 r
.30425 .4206 .30532 .42165 .31089 .41976 .30981 .4187 Metetra
.664 .741 .907 r
.30981 .4187 .31089 .41976 .31647 .41786 .31539 .4168 Metetra
.664 .741 .907 r
.31539 .4168 .31647 .41786 .32205 .41596 .32098 .4149 Metetra
.664 .741 .907 r
.32098 .4149 .32205 .41596 .32766 .41406 .32659 .41299 Metetra
.664 .741 .907 r
.32659 .41299 .32766 .41406 .33327 .41215 .3322 .41108 Metetra
.664 .741 .907 r
.3322 .41108 .33327 .41215 .33889 .41023 .33783 .40917 Metetra
.664 .741 .907 r
.33783 .40917 .33889 .41023 .34453 .40832 .34347 .40725 Metetra
.664 .741 .907 r
.34347 .40725 .34453 .40832 .35018 .4064 .34912 .40532 Metetra
.664 .741 .907 r
.34912 .40532 .35018 .4064 .35584 .40447 .35478 .40339 Metetra
.664 .741 .907 r
.35478 .40339 .35584 .40447 .36151 .40254 .36045 .40146 Metetra
.954 .658 .437 r
.36045 .40146 .36151 .40254 .36719 .40061 .36307 .46185 Metetra
.51 .289 .514 r
.36307 .46185 .36719 .40061 .37257 .40548 .36956 .44562 Metetra
.349 .153 .468 r
.36956 .44562 .37257 .40548 .3786 .39673 .37755 .39564 Metetra
.664 .741 .907 r
.37755 .39564 .3786 .39673 .38432 .39478 .38327 .3937 Metetra
.664 .741 .907 r
.38327 .3937 .38432 .39478 .39005 .39283 .38901 .39174 Metetra
.664 .741 .907 r
.38901 .39174 .39005 .39283 .3958 .39088 .39476 .38979 Metetra
.664 .741 .907 r
.39476 .38979 .3958 .39088 .40155 .38892 .40051 .38783 Metetra
.664 .741 .907 r
.40051 .38783 .40155 .38892 .40715 .3918 .40629 .38586 Metetra
.591 .436 .641 r
.40629 .38586 .40715 .3918 .41311 .38499 .41207 .38389 Metetra
.664 .741 .907 r
.41207 .38389 .41311 .38499 .4189 .38302 .41787 .38192 Metetra
.664 .741 .907 r
.41787 .38192 .4189 .38302 .42471 .38104 .42368 .37994 Metetra
.664 .741 .907 r
.42368 .37994 .42471 .38104 .43053 .37906 .4295 .37796 Metetra
.664 .741 .907 r
.4295 .37796 .43053 .37906 .43636 .37708 .43534 .37597 Metetra
.664 .741 .907 r
.43534 .37597 .43636 .37708 .44221 .37509 .44118 .37398 Metetra
.664 .741 .907 r
.44118 .37398 .44221 .37509 .44806 .3731 .44704 .37199 Metetra
.664 .741 .907 r
.44704 .37199 .44806 .3731 .45393 .3711 .45292 .36999 Metetra
.664 .741 .907 r
.45292 .36999 .45393 .3711 .45982 .3691 .4588 .36798 Metetra
.664 .741 .907 r
.4588 .36798 .45982 .3691 .46571 .3671 .4647 .36598 Metetra
.664 .741 .907 r
.4647 .36598 .46571 .3671 .47162 .36509 .47061 .36396 Metetra
.664 .741 .907 r
.47061 .36396 .47162 .36509 .47754 .36307 .47653 .36195 Metetra
.664 .741 .907 r
.47653 .36195 .47754 .36307 .48348 .36105 .48247 .35993 Metetra
.664 .741 .907 r
.48247 .35993 .48348 .36105 .48942 .35903 .48842 .3579 Metetra
.664 .741 .907 r
.48842 .3579 .48942 .35903 .49538 .357 .49438 .35587 Metetra
.664 .741 .907 r
.49438 .35587 .49538 .357 .50136 .35497 .50036 .35384 Metetra
.664 .741 .907 r
.50036 .35384 .50136 .35497 .50734 .35294 .50635 .3518 Metetra
.664 .741 .907 r
.50635 .3518 .50734 .35294 .51334 .3509 .51235 .34975 Metetra
.664 .741 .907 r
.51235 .34975 .51334 .3509 .51935 .34885 .51836 .34771 Metetra
.664 .741 .907 r
.51836 .34771 .51935 .34885 .52538 .3468 .52439 .34566 Metetra
.664 .741 .907 r
.52439 .34566 .52538 .3468 .53142 .34475 .53043 .3436 Metetra
.664 .741 .907 r
.53043 .3436 .53142 .34475 .53747 .34269 .53649 .34154 Metetra
.664 .741 .907 r
.53649 .34154 .53747 .34269 .54354 .34062 .54256 .33947 Metetra
.664 .741 .907 r
.54256 .33947 .54354 .34062 .54962 .33856 .54864 .3374 Metetra
.664 .741 .907 r
.54864 .3374 .54962 .33856 .55571 .33648 .55473 .33533 Metetra
.664 .741 .907 r
.55473 .33533 .55571 .33648 .56181 .33441 .56084 .33325 Metetra
.968 .663 .388 r
.56084 .33325 .56181 .33441 .56812 .34623 .56841 .43979 Metetra
.382 .194 .497 r
.56841 .43979 .56812 .34623 .57407 .33024 .5731 .32907 Metetra
.664 .741 .907 r
.5731 .32907 .57407 .33024 .58021 .32815 .57925 .32698 Metetra
.664 .741 .907 r
.57925 .32698 .58021 .32815 .58637 .32605 .58541 .32488 Metetra
.664 .741 .907 r
.58541 .32488 .58637 .32605 .59255 .32395 .59159 .32278 Metetra
.664 .741 .907 r
.59159 .32278 .59255 .32395 .59873 .32185 .59778 .32067 Metetra
.664 .741 .907 r
.59778 .32067 .59873 .32185 .60493 .31974 .60398 .31856 Metetra
.664 .741 .907 r
.60398 .31856 .60493 .31974 .61115 .31763 .6102 .31645 Metetra
.664 .741 .907 r
.6102 .31645 .61115 .31763 .61738 .31551 .61643 .31432 Metetra
.664 .741 .907 r
.61643 .31432 .61738 .31551 .62362 .31338 .62268 .3122 Metetra
.664 .741 .907 r
.62268 .3122 .62362 .31338 .62988 .31126 .62894 .31007 Metetra
.664 .741 .907 r
.62894 .31007 .62988 .31126 .63615 .30912 .63521 .30793 Metetra
.664 .741 .907 r
.63521 .30793 .63615 .30912 .64243 .30699 .6415 .30579 Metetra
.664 .741 .907 r
.6415 .30579 .64243 .30699 .64873 .30484 .6478 .30365 Metetra
.664 .741 .907 r
.6478 .30365 .64873 .30484 .65504 .3027 .65412 .3015 Metetra
.664 .741 .907 r
.65412 .3015 .65504 .3027 .66137 .30054 .66045 .29934 Metetra
.664 .741 .907 r
.66045 .29934 .66137 .30054 .66771 .29839 .66679 .29718 Metetra
.664 .741 .907 r
.66679 .29718 .66771 .29839 .67407 .29622 .67315 .29502 Metetra
.664 .741 .907 r
.67315 .29502 .67407 .29622 .68044 .29406 .67952 .29285 Metetra
.664 .741 .907 r
.67952 .29285 .68044 .29406 .68682 .29189 .68591 .29067 Metetra
.664 .741 .907 r
.68591 .29067 .68682 .29189 .69322 .28971 .69231 .28849 Metetra
.664 .741 .907 r
.69231 .28849 .69322 .28971 .69964 .28753 .69873 .28631 Metetra
.664 .741 .907 r
.69873 .28631 .69964 .28753 .70606 .28534 .70516 .28412 Metetra
.664 .741 .907 r
.70516 .28412 .70606 .28534 .71251 .28315 .7116 .28193 Metetra
.664 .741 .907 r
.7116 .28193 .71251 .28315 .71896 .28095 .71806 .27973 Metetra
.664 .741 .907 r
.71806 .27973 .71896 .28095 .72543 .27875 .72454 .27752 Metetra
.664 .741 .907 r
.72454 .27752 .72543 .27875 .73192 .27655 .73103 .27531 Metetra
.664 .741 .907 r
.73103 .27531 .73192 .27655 .73842 .27433 .73753 .2731 Metetra
.664 .741 .907 r
.73753 .2731 .73842 .27433 .74494 .27212 .74405 .27088 Metetra
.664 .741 .907 r
.74405 .27088 .74494 .27212 .75147 .2699 .75059 .26866 Metetra
.664 .741 .907 r
.75059 .26866 .75147 .2699 .75802 .26767 .75713 .26643 Metetra
.664 .741 .907 r
.75713 .26643 .75802 .26767 .76458 .26544 .7637 .26419 Metetra
.664 .741 .907 r
.7637 .26419 .76458 .26544 .77115 .2632 .77028 .26195 Metetra
.664 .741 .907 r
.77028 .26195 .77115 .2632 .77774 .26096 .77687 .25971 Metetra
.952 .608 .222 r
.77687 .25971 .77774 .26096 .78435 .25871 .78921 .32568 Metetra
.419 .226 .51 r
.78921 .32568 .78435 .25871 .79097 .25646 .79011 .2552 Metetra
.664 .741 .907 r
.79011 .2552 .79097 .25646 .79761 .2542 .79675 .25294 Metetra
.664 .741 .907 r
.79675 .25294 .79761 .2542 .80426 .25194 .8034 .25068 Metetra
.664 .741 .907 r
.8034 .25068 .80426 .25194 .81093 .24967 .81007 .24841 Metetra
.664 .741 .907 r
.81007 .24841 .81093 .24967 .81761 .2474 .81676 .24613 Metetra
.664 .741 .907 r
.81676 .24613 .81761 .2474 .82431 .24512 .82346 .24385 Metetra
.664 .741 .907 r
.82346 .24385 .82431 .24512 .83102 .24284 .83018 .24156 Metetra
.664 .741 .907 r
.83018 .24156 .83102 .24284 .83775 .24055 .83691 .23927 Metetra
.664 .741 .907 r
.83691 .23927 .83775 .24055 .84449 .23825 .84366 .23697 Metetra
.664 .741 .907 r
.23724 .442 .23834 .44303 .24377 .44118 .24267 .44015 Metetra
.664 .741 .907 r
.24267 .44015 .24377 .44118 .24921 .43933 .24811 .4383 Metetra
.664 .741 .907 r
.24811 .4383 .24921 .43933 .25466 .43748 .25357 .43644 Metetra
.664 .741 .907 r
.25357 .43644 .25466 .43748 .26013 .43562 .25903 .43458 Metetra
.664 .741 .907 r
.25903 .43458 .26013 .43562 .2656 .43375 .26451 .43271 Metetra
.664 .741 .907 r
.26451 .43271 .2656 .43375 .27109 .43188 .27 .43084 Metetra
.664 .741 .907 r
.27 .43084 .27109 .43188 .27659 .43001 .2755 .42897 Metetra
.664 .741 .907 r
.2755 .42897 .27659 .43001 .28209 .42814 .28101 .42709 Metetra
.664 .741 .907 r
.28101 .42709 .28209 .42814 .28741 .42912 .28653 .42521 Metetra
.609 .485 .687 r
.28653 .42521 .28741 .42912 .29315 .42438 .29206 .42332 Metetra
.664 .741 .907 r
.29206 .42332 .29315 .42438 .29869 .42249 .29761 .42143 Metetra
.664 .741 .907 r
.29761 .42143 .29869 .42249 .30425 .4206 .30317 .41954 Metetra
.664 .741 .907 r
.30317 .41954 .30425 .4206 .30981 .4187 .30874 .41764 Metetra
.664 .741 .907 r
.30874 .41764 .30981 .4187 .31539 .4168 .31432 .41574 Metetra
.664 .741 .907 r
.31432 .41574 .31539 .4168 .32098 .4149 .31991 .41384 Metetra
.664 .741 .907 r
.31991 .41384 .32098 .4149 .32659 .41299 .32552 .41193 Metetra
.664 .741 .907 r
.32552 .41193 .32659 .41299 .3322 .41108 .33113 .41001 Metetra
.664 .741 .907 r
.33113 .41001 .3322 .41108 .33783 .40917 .33676 .4081 Metetra
.664 .741 .907 r
.33676 .4081 .33783 .40917 .34347 .40725 .3424 .40617 Metetra
.664 .741 .907 r
.3424 .40617 .34347 .40725 .34912 .40532 .34806 .40425 Metetra
.664 .741 .907 r
.34806 .40425 .34912 .40532 .35478 .40339 .35372 .40232 Metetra
.664 .741 .907 r
.35372 .40232 .35478 .40339 .36045 .40146 .3594 .40038 Metetra
.952 .679 .482 r
.3594 .40038 .36045 .40146 .36307 .46185 .35504 .60095 Metetra
.396 .2 .494 r
.35504 .60095 .36307 .46185 .36956 .44562 .36766 .46182 Metetra
0 0 .053 r
.36766 .46182 .36956 .44562 .37755 .39564 .3765 .39456 Metetra
.664 .741 .907 r
.3765 .39456 .37755 .39564 .38327 .3937 .38222 .39261 Metetra
.664 .741 .907 r
.38222 .39261 .38327 .3937 .38901 .39174 .38796 .39065 Metetra
.664 .741 .907 r
.38796 .39065 .38901 .39174 .39476 .38979 .39371 .38869 Metetra
.664 .741 .907 r
.39371 .38869 .39476 .38979 .40051 .38783 .39947 .38673 Metetra
.664 .741 .907 r
.39947 .38673 .40051 .38783 .40629 .38586 .40525 .38476 Metetra
.664 .741 .907 r
.40525 .38476 .40629 .38586 .41207 .38389 .41104 .38279 Metetra
.664 .741 .907 r
.41104 .38279 .41207 .38389 .41787 .38192 .41684 .38082 Metetra
.664 .741 .907 r
.41684 .38082 .41787 .38192 .42368 .37994 .42265 .37884 Metetra
.664 .741 .907 r
.42265 .37884 .42368 .37994 .4295 .37796 .42847 .37685 Metetra
.664 .741 .907 r
.42847 .37685 .4295 .37796 .43534 .37597 .43431 .37486 Metetra
.664 .741 .907 r
.43431 .37486 .43534 .37597 .44118 .37398 .44016 .37287 Metetra
.664 .741 .907 r
.44016 .37287 .44118 .37398 .44704 .37199 .44602 .37087 Metetra
.664 .741 .907 r
.44602 .37087 .44704 .37199 .45292 .36999 .4519 .36887 Metetra
.664 .741 .907 r
.4519 .36887 .45292 .36999 .4588 .36798 .45778 .36686 Metetra
.664 .741 .907 r
.45778 .36686 .4588 .36798 .4647 .36598 .46369 .36485 Metetra
.664 .741 .907 r
.46369 .36485 .4647 .36598 .47061 .36396 .4696 .36284 Metetra
.664 .741 .907 r
.4696 .36284 .47061 .36396 .47653 .36195 .47552 .36082 Metetra
.664 .741 .907 r
.47552 .36082 .47653 .36195 .48247 .35993 .48146 .3588 Metetra
.664 .741 .907 r
.48146 .3588 .48247 .35993 .48842 .3579 .48742 .35677 Metetra
.664 .741 .907 r
.48742 .35677 .48842 .3579 .49438 .35587 .49338 .35474 Metetra
.664 .741 .907 r
.49338 .35474 .49438 .35587 .50036 .35384 .49936 .3527 Metetra
.664 .741 .907 r
.49936 .3527 .50036 .35384 .50635 .3518 .50535 .35066 Metetra
.664 .741 .907 r
.50535 .35066 .50635 .3518 .51235 .34975 .51136 .34861 Metetra
.664 .741 .907 r
.51136 .34861 .51235 .34975 .51836 .34771 .51737 .34656 Metetra
.664 .741 .907 r
.51737 .34656 .51836 .34771 .52439 .34566 .5234 .34451 Metetra
.664 .741 .907 r
.5234 .34451 .52439 .34566 .53043 .3436 .52945 .34245 Metetra
.664 .741 .907 r
.52945 .34245 .53043 .3436 .53649 .34154 .53551 .34039 Metetra
.664 .741 .907 r
.53551 .34039 .53649 .34154 .54256 .33947 .54158 .33832 Metetra
.664 .741 .907 r
.54158 .33832 .54256 .33947 .54864 .3374 .54766 .33624 Metetra
.664 .741 .907 r
.54766 .33624 .54864 .3374 .55473 .33533 .55376 .33417 Metetra
.664 .741 .907 r
.55376 .33417 .55473 .33533 .56084 .33325 .55987 .33209 Metetra
.963 .635 .331 r
.55987 .33209 .56084 .33325 .56841 .43979 .56669 .38332 Metetra
.639 .406 .549 r
.56669 .38332 .56841 .43979 .5731 .32907 .57213 .32791 Metetra
.664 .741 .907 r
.57213 .32791 .5731 .32907 .57925 .32698 .57828 .32581 Metetra
.664 .741 .907 r
.57828 .32581 .57925 .32698 .58541 .32488 .58445 .32371 Metetra
.664 .741 .907 r
.58445 .32371 .58541 .32488 .59159 .32278 .59063 .32161 Metetra
.664 .741 .907 r
.59063 .32161 .59159 .32278 .59778 .32067 .59682 .3195 Metetra
.664 .741 .907 r
.59682 .3195 .59778 .32067 .60398 .31856 .60303 .31738 Metetra
.664 .741 .907 r
.60303 .31738 .60398 .31856 .6102 .31645 .60925 .31526 Metetra
.664 .741 .907 r
.60925 .31526 .6102 .31645 .61643 .31432 .61548 .31314 Metetra
.664 .741 .907 r
.61548 .31314 .61643 .31432 .62268 .3122 .62173 .31101 Metetra
.664 .741 .907 r
.62173 .31101 .62268 .3122 .62894 .31007 .62799 .30888 Metetra
.664 .741 .907 r
.62799 .30888 .62894 .31007 .63521 .30793 .63427 .30674 Metetra
.664 .741 .907 r
.63427 .30674 .63521 .30793 .6415 .30579 .64056 .30459 Metetra
.664 .741 .907 r
.64056 .30459 .6415 .30579 .6478 .30365 .64687 .30245 Metetra
.664 .741 .907 r
.64687 .30245 .6478 .30365 .65412 .3015 .65318 .30029 Metetra
.664 .741 .907 r
.65318 .30029 .65412 .3015 .66045 .29934 .65952 .29814 Metetra
.664 .741 .907 r
.65952 .29814 .66045 .29934 .66679 .29718 .66587 .29597 Metetra
.664 .741 .907 r
.66587 .29597 .66679 .29718 .67315 .29502 .67223 .29381 Metetra
.664 .741 .907 r
.67223 .29381 .67315 .29502 .67952 .29285 .6786 .29163 Metetra
.664 .741 .907 r
.6786 .29163 .67952 .29285 .68591 .29067 .68499 .28946 Metetra
.664 .741 .907 r
.68499 .28946 .68591 .29067 .69231 .28849 .6914 .28728 Metetra
.664 .741 .907 r
.6914 .28728 .69231 .28849 .69873 .28631 .69782 .28509 Metetra
.664 .741 .907 r
.69782 .28509 .69873 .28631 .70516 .28412 .70425 .2829 Metetra
.664 .741 .907 r
.70425 .2829 .70516 .28412 .7116 .28193 .7107 .2807 Metetra
.664 .741 .907 r
.7107 .2807 .7116 .28193 .71806 .27973 .71716 .2785 Metetra
.664 .741 .907 r
.71716 .2785 .71806 .27973 .72454 .27752 .72364 .27629 Metetra
.664 .741 .907 r
.72364 .27629 .72454 .27752 .73103 .27531 .73013 .27408 Metetra
.664 .741 .907 r
.73013 .27408 .73103 .27531 .73753 .2731 .73664 .27186 Metetra
.664 .741 .907 r
.73664 .27186 .73753 .2731 .74405 .27088 .74316 .26964 Metetra
.664 .741 .907 r
.74316 .26964 .74405 .27088 .75059 .26866 .7497 .26741 Metetra
.664 .741 .907 r
.7497 .26741 .75059 .26866 .75713 .26643 .75625 .26518 Metetra
.664 .741 .907 r
.75625 .26518 .75713 .26643 .7637 .26419 .76282 .26294 Metetra
.664 .741 .907 r
.76282 .26294 .7637 .26419 .77028 .26195 .7694 .2607 Metetra
.664 .741 .907 r
.7694 .2607 .77028 .26195 .77687 .25971 .776 .25845 Metetra
.741 .313 0 r
.776 .25845 .77687 .25971 .78921 .32568 .7841 .27395 Metetra
.584 .362 .546 r
.7841 .27395 .78921 .32568 .79011 .2552 .78924 .25394 Metetra
.664 .741 .907 r
.78924 .25394 .79011 .2552 .79675 .25294 .79588 .25168 Metetra
.664 .741 .907 r
.79588 .25168 .79675 .25294 .8034 .25068 .80254 .24941 Metetra
.664 .741 .907 r
.80254 .24941 .8034 .25068 .81007 .24841 .80922 .24714 Metetra
.664 .741 .907 r
.80922 .24714 .81007 .24841 .81676 .24613 .8159 .24486 Metetra
.664 .741 .907 r
.8159 .24486 .81676 .24613 .82346 .24385 .82261 .24257 Metetra
.664 .741 .907 r
.82261 .24257 .82346 .24385 .83018 .24156 .82933 .24028 Metetra
.664 .741 .907 r
.82933 .24028 .83018 .24156 .83691 .23927 .83607 .23799 Metetra
.664 .741 .907 r
.83607 .23799 .83691 .23927 .84366 .23697 .84282 .23569 Metetra
.664 .741 .907 r
.23614 .44097 .23724 .442 .24267 .44015 .24157 .43912 Metetra
.664 .741 .907 r
.24157 .43912 .24267 .44015 .24811 .4383 .24701 .43726 Metetra
.664 .741 .907 r
.24701 .43726 .24811 .4383 .25357 .43644 .25247 .4354 Metetra
.664 .741 .907 r
.25247 .4354 .25357 .43644 .25903 .43458 .25794 .43354 Metetra
.664 .741 .907 r
.25794 .43354 .25903 .43458 .26451 .43271 .26341 .43167 Metetra
.908 .5 .168 r
.26341 .43167 .26451 .43271 .27 .43084 .26781 .44374 Metetra
.361 .132 .425 r
.26781 .44374 .27 .43084 .2755 .42897 .27428 .42958 Metetra
.478 .876 .707 r
.27428 .42958 .2755 .42897 .28101 .42709 .27992 .42604 Metetra
.664 .741 .907 r
.27992 .42604 .28101 .42709 .28653 .42521 .28544 .42416 Metetra
.664 .741 .907 r
.28544 .42416 .28653 .42521 .29206 .42332 .29098 .42227 Metetra
.664 .741 .907 r
.29098 .42227 .29206 .42332 .29761 .42143 .29653 .42038 Metetra
.664 .741 .907 r
.29653 .42038 .29761 .42143 .30317 .41954 .30209 .41848 Metetra
.664 .741 .907 r
.30209 .41848 .30317 .41954 .30874 .41764 .30766 .41658 Metetra
.664 .741 .907 r
.30766 .41658 .30874 .41764 .31432 .41574 .31324 .41468 Metetra
.664 .741 .907 r
.31324 .41468 .31432 .41574 .31991 .41384 .31884 .41277 Metetra
.664 .741 .907 r
.31884 .41277 .31991 .41384 .32552 .41193 .32445 .41086 Metetra
.664 .741 .907 r
.32445 .41086 .32552 .41193 .33113 .41001 .33006 .40894 Metetra
.664 .741 .907 r
.33006 .40894 .33113 .41001 .33676 .4081 .3357 .40702 Metetra
.664 .741 .907 r
.3357 .40702 .33676 .4081 .3424 .40617 .34134 .4051 Metetra
.664 .741 .907 r
.34134 .4051 .3424 .40617 .34806 .40425 .34699 .40317 Metetra
.664 .741 .907 r
.34699 .40317 .34806 .40425 .35372 .40232 .35266 .40124 Metetra
.664 .741 .907 r
.35266 .40124 .35372 .40232 .3594 .40038 .35834 .3993 Metetra
.952 .679 .483 r
.35834 .3993 .3594 .40038 .35504 .60095 .35382 .60177 Metetra
.957 .703 .512 r
.35382 .60177 .35504 .60095 .36766 .46182 .36973 .39542 Metetra
.548 .334 .542 r
.36973 .39542 .36766 .46182 .3765 .39456 .37545 .39347 Metetra
.664 .741 .907 r
.37545 .39347 .3765 .39456 .38222 .39261 .38118 .39152 Metetra
.664 .741 .907 r
.38118 .39152 .38222 .39261 .38796 .39065 .38692 .38956 Metetra
.664 .741 .907 r
.38692 .38956 .38796 .39065 .39371 .38869 .39267 .3876 Metetra
.664 .741 .907 r
.39267 .3876 .39371 .38869 .39947 .38673 .39843 .38563 Metetra
.664 .741 .907 r
.39843 .38563 .39947 .38673 .40525 .38476 .40421 .38366 Metetra
.664 .741 .907 r
.40421 .38366 .40525 .38476 .41104 .38279 .41 .38169 Metetra
.664 .741 .907 r
.41 .38169 .41104 .38279 .41684 .38082 .4158 .37971 Metetra
.664 .741 .907 r
.4158 .37971 .41684 .38082 .42265 .37884 .42162 .37773 Metetra
.664 .741 .907 r
.42162 .37773 .42265 .37884 .42847 .37685 .42744 .37574 Metetra
.664 .741 .907 r
.42744 .37574 .42847 .37685 .43431 .37486 .43328 .37375 Metetra
.664 .741 .907 r
.43328 .37375 .43431 .37486 .44016 .37287 .43913 .37176 Metetra
.664 .741 .907 r
.43913 .37176 .44016 .37287 .44602 .37087 .445 .36976 Metetra
.664 .741 .907 r
.445 .36976 .44602 .37087 .4519 .36887 .45088 .36775 Metetra
.664 .741 .907 r
.45088 .36775 .4519 .36887 .45778 .36686 .45677 .36574 Metetra
.664 .741 .907 r
.45677 .36574 .45778 .36686 .46369 .36485 .46267 .36373 Metetra
.664 .741 .907 r
.46267 .36373 .46369 .36485 .4696 .36284 .46859 .36171 Metetra
.664 .741 .907 r
.46859 .36171 .4696 .36284 .47552 .36082 .47451 .35969 Metetra
.664 .741 .907 r
.47451 .35969 .47552 .36082 .48146 .3588 .48046 .35767 Metetra
.664 .741 .907 r
.48046 .35767 .48146 .3588 .48742 .35677 .48641 .35564 Metetra
.664 .741 .907 r
.48641 .35564 .48742 .35677 .49338 .35474 .49238 .3536 Metetra
.664 .741 .907 r
.49238 .3536 .49338 .35474 .49936 .3527 .49836 .35156 Metetra
.664 .741 .907 r
.49836 .35156 .49936 .3527 .50535 .35066 .50435 .34952 Metetra
.664 .741 .907 r
.50435 .34952 .50535 .35066 .51136 .34861 .51036 .34747 Metetra
.664 .741 .907 r
.51036 .34747 .51136 .34861 .51737 .34656 .51638 .34542 Metetra
.664 .741 .907 r
.51638 .34542 .51737 .34656 .5234 .34451 .52241 .34336 Metetra
.664 .741 .907 r
.52241 .34336 .5234 .34451 .52945 .34245 .52846 .3413 Metetra
.664 .741 .907 r
.52846 .3413 .52945 .34245 .53551 .34039 .53452 .33923 Metetra
.664 .741 .907 r
.53452 .33923 .53551 .34039 .54158 .33832 .54059 .33716 Metetra
.664 .741 .907 r
.54059 .33716 .54158 .33832 .54766 .33624 .54668 .33509 Metetra
.664 .741 .907 r
.54668 .33509 .54766 .33624 .55376 .33417 .55278 .33301 Metetra
.945 .583 .236 r
.55278 .33301 .55376 .33417 .55987 .33209 .55922 .36143 Metetra
.538 .303 .507 r
.55922 .36143 .55987 .33209 .56669 .38332 .56543 .36086 Metetra
.679 .448 .565 r
.56543 .36086 .56669 .38332 .57213 .32791 .57116 .32674 Metetra
.664 .741 .907 r
.57116 .32674 .57213 .32791 .57828 .32581 .57732 .32464 Metetra
.664 .741 .907 r
.57732 .32464 .57828 .32581 .58445 .32371 .58349 .32254 Metetra
.664 .741 .907 r
.58349 .32254 .58445 .32371 .59063 .32161 .58967 .32043 Metetra
.664 .741 .907 r
.58967 .32043 .59063 .32161 .59682 .3195 .59586 .31832 Metetra
.664 .741 .907 r
.59586 .31832 .59682 .3195 .60303 .31738 .60207 .3162 Metetra
.664 .741 .907 r
.60207 .3162 .60303 .31738 .60925 .31526 .6083 .31408 Metetra
.664 .741 .907 r
.6083 .31408 .60925 .31526 .61548 .31314 .61453 .31195 Metetra
.664 .741 .907 r
.61453 .31195 .61548 .31314 .62173 .31101 .62079 .30982 Metetra
.664 .741 .907 r
.62079 .30982 .62173 .31101 .62799 .30888 .62705 .30768 Metetra
.664 .741 .907 r
.62705 .30768 .62799 .30888 .63427 .30674 .63333 .30554 Metetra
.664 .741 .907 r
.63333 .30554 .63427 .30674 .64056 .30459 .63962 .3034 Metetra
.664 .741 .907 r
.63962 .3034 .64056 .30459 .64687 .30245 .64593 .30125 Metetra
.664 .741 .907 r
.64593 .30125 .64687 .30245 .65318 .30029 .65225 .29909 Metetra
.664 .741 .907 r
.65225 .29909 .65318 .30029 .65952 .29814 .65859 .29693 Metetra
.664 .741 .907 r
.65859 .29693 .65952 .29814 .66587 .29597 .66494 .29477 Metetra
.664 .741 .907 r
.66494 .29477 .66587 .29597 .67223 .29381 .6713 .2926 Metetra
.664 .741 .907 r
.6713 .2926 .67223 .29381 .6786 .29163 .67768 .29042 Metetra
.664 .741 .907 r
.67768 .29042 .6786 .29163 .68499 .28946 .68408 .28824 Metetra
.664 .741 .907 r
.68408 .28824 .68499 .28946 .6914 .28728 .69048 .28606 Metetra
.664 .741 .907 r
.69048 .28606 .6914 .28728 .69782 .28509 .69691 .28387 Metetra
.664 .741 .907 r
.69691 .28387 .69782 .28509 .70425 .2829 .70334 .28167 Metetra
.664 .741 .907 r
.70334 .28167 .70425 .2829 .7107 .2807 .70979 .27947 Metetra
.664 .741 .907 r
.70979 .27947 .7107 .2807 .71716 .2785 .71626 .27727 Metetra
.664 .741 .907 r
.71626 .27727 .71716 .2785 .72364 .27629 .72274 .27506 Metetra
.664 .741 .907 r
.72274 .27506 .72364 .27629 .73013 .27408 .72924 .27284 Metetra
.664 .741 .907 r
.72924 .27284 .73013 .27408 .73664 .27186 .73575 .27062 Metetra
.664 .741 .907 r
.73575 .27062 .73664 .27186 .74316 .26964 .74227 .2684 Metetra
.664 .741 .907 r
.74227 .2684 .74316 .26964 .7497 .26741 .74881 .26617 Metetra
.664 .741 .907 r
.74881 .26617 .7497 .26741 .75625 .26518 .75537 .26393 Metetra
.664 .741 .907 r
.75537 .26393 .75625 .26518 .76282 .26294 .76194 .26169 Metetra
.748 .319 0 r
.76194 .26169 .76282 .26294 .7694 .2607 .76992 .27705 Metetra
.392 .181 .469 r
.76992 .27705 .7694 .2607 .776 .25845 .77513 .2572 Metetra
.664 .741 .907 r
.77513 .2572 .776 .25845 .7841 .27395 .78174 .25494 Metetra
.56 .362 .569 r
.78174 .25494 .7841 .27395 .78924 .25394 .78837 .25268 Metetra
.664 .741 .907 r
.78837 .25268 .78924 .25394 .79588 .25168 .79502 .25041 Metetra
.664 .741 .907 r
.79502 .25041 .79588 .25168 .80254 .24941 .80168 .24814 Metetra
.664 .741 .907 r
.80168 .24814 .80254 .24941 .80922 .24714 .80836 .24587 Metetra
.664 .741 .907 r
.80836 .24587 .80922 .24714 .8159 .24486 .81505 .24358 Metetra
.664 .741 .907 r
.81505 .24358 .8159 .24486 .82261 .24257 .82176 .2413 Metetra
.664 .741 .907 r
.82176 .2413 .82261 .24257 .82933 .24028 .82848 .239 Metetra
.664 .741 .907 r
.82848 .239 .82933 .24028 .83607 .23799 .83522 .23671 Metetra
.664 .741 .907 r
.83522 .23671 .83607 .23799 .84282 .23569 .84198 .2344 Metetra
.664 .741 .907 r
.23503 .43994 .23614 .44097 .24157 .43912 .24046 .43808 Metetra
.664 .741 .907 r
.24046 .43808 .24157 .43912 .24701 .43726 .24591 .43622 Metetra
.664 .741 .907 r
.24591 .43622 .24701 .43726 .25247 .4354 .25137 .43436 Metetra
.664 .741 .907 r
.25137 .43436 .25247 .4354 .25794 .43354 .25684 .4325 Metetra
.664 .741 .907 r
.25684 .4325 .25794 .43354 .26341 .43167 .26232 .43062 Metetra
.946 .654 .453 r
.26232 .43062 .26341 .43167 .26781 .44374 .26387 .47863 Metetra
.276 .088 .435 r
.26387 .47863 .26781 .44374 .27428 .42958 .27332 .42687 Metetra
.628 .544 .741 r
.27332 .42687 .27428 .42958 .27992 .42604 .27883 .42499 Metetra
.664 .741 .907 r
.27883 .42499 .27992 .42604 .28544 .42416 .28436 .4231 Metetra
.664 .741 .907 r
.28436 .4231 .28544 .42416 .29098 .42227 .2899 .42121 Metetra
.664 .741 .907 r
.2899 .42121 .29098 .42227 .29653 .42038 .29545 .41932 Metetra
.664 .741 .907 r
.29545 .41932 .29653 .42038 .30209 .41848 .30101 .41742 Metetra
.664 .741 .907 r
.30101 .41742 .30209 .41848 .30766 .41658 .30658 .41552 Metetra
.664 .741 .907 r
.30658 .41552 .30766 .41658 .31324 .41468 .31217 .41362 Metetra
.664 .741 .907 r
.31217 .41362 .31324 .41468 .31884 .41277 .31776 .41171 Metetra
.664 .741 .907 r
.31776 .41171 .31884 .41277 .32445 .41086 .32337 .40979 Metetra
.664 .741 .907 r
.32337 .40979 .32445 .41086 .33006 .40894 .32899 .40787 Metetra
.664 .741 .907 r
.32899 .40787 .33006 .40894 .3357 .40702 .33463 .40595 Metetra
.664 .741 .907 r
.33463 .40595 .3357 .40702 .34134 .4051 .34027 .40403 Metetra
.664 .741 .907 r
.34027 .40403 .34134 .4051 .34699 .40317 .34593 .40209 Metetra
.664 .741 .907 r
.34593 .40209 .34699 .40317 .35266 .40124 .3516 .40016 Metetra
.664 .741 .907 r
.3516 .40016 .35266 .40124 .35834 .3993 .35728 .39822 Metetra
.953 .67 .463 r
.35728 .39822 .35834 .3993 .35382 .60177 .35783 .49844 Metetra
.633 .402 .549 r
.35783 .49844 .35382 .60177 .36973 .39542 .36796 .40923 Metetra
.348 .127 .43 r
.36796 .40923 .36973 .39542 .37545 .39347 .3744 .39238 Metetra
.664 .741 .907 r
.3744 .39238 .37545 .39347 .38118 .39152 .38013 .39043 Metetra
.664 .741 .907 r
.38013 .39043 .38118 .39152 .38692 .38956 .38587 .38847 Metetra
.664 .741 .907 r
.38587 .38847 .38692 .38956 .39267 .3876 .39162 .3865 Metetra
.664 .741 .907 r
.39162 .3865 .39267 .3876 .39843 .38563 .39739 .38454 Metetra
.664 .741 .907 r
.39739 .38454 .39843 .38563 .40421 .38366 .40317 .38256 Metetra
.664 .741 .907 r
.40317 .38256 .40421 .38366 .41 .38169 .40896 .38059 Metetra
.664 .741 .907 r
.40896 .38059 .41 .38169 .4158 .37971 .41477 .37861 Metetra
.664 .741 .907 r
.41477 .37861 .4158 .37971 .42162 .37773 .42058 .37662 Metetra
.664 .741 .907 r
.42058 .37662 .42162 .37773 .42744 .37574 .42641 .37463 Metetra
.664 .741 .907 r
.42641 .37463 .42744 .37574 .43328 .37375 .43225 .37264 Metetra
.664 .741 .907 r
.43225 .37264 .43328 .37375 .43913 .37176 .43811 .37064 Metetra
.664 .741 .907 r
.43811 .37064 .43913 .37176 .445 .36976 .44397 .36864 Metetra
.852 .411 0 r
.44397 .36864 .445 .36976 .45088 .36775 .44953 .38041 Metetra
.352 .13 .43 r
.44953 .38041 .45088 .36775 .45677 .36574 .45575 .36462 Metetra
.664 .741 .907 r
.45575 .36462 .45677 .36574 .46267 .36373 .46165 .36261 Metetra
.664 .741 .907 r
.46165 .36261 .46267 .36373 .46859 .36171 .46757 .36059 Metetra
.664 .741 .907 r
.46757 .36059 .46859 .36171 .47451 .35969 .4735 .35856 Metetra
.664 .741 .907 r
.4735 .35856 .47451 .35969 .48046 .35767 .47945 .35653 Metetra
.664 .741 .907 r
.47945 .35653 .48046 .35767 .48641 .35564 .4854 .3545 Metetra
.664 .741 .907 r
.4854 .3545 .48641 .35564 .49238 .3536 .49138 .35246 Metetra
.664 .741 .907 r
.49138 .35246 .49238 .3536 .49836 .35156 .49736 .35042 Metetra
.664 .741 .907 r
.49736 .35042 .49836 .35156 .50435 .34952 .50336 .34838 Metetra
.664 .741 .907 r
.50336 .34838 .50435 .34952 .51036 .34747 .50936 .34633 Metetra
.664 .741 .907 r
.50936 .34633 .51036 .34747 .51638 .34542 .51539 .34427 Metetra
.664 .741 .907 r
.51539 .34427 .51638 .34542 .52241 .34336 .52142 .34221 Metetra
.664 .741 .907 r
.52142 .34221 .52241 .34336 .52846 .3413 .52747 .34015 Metetra
.664 .741 .907 r
.52747 .34015 .52846 .3413 .53452 .33923 .53354 .33808 Metetra
.664 .741 .907 r
.53354 .33808 .53452 .33923 .54059 .33716 .53961 .33601 Metetra
.664 .741 .907 r
.53961 .33601 .54059 .33716 .54668 .33509 .5457 .33393 Metetra
.664 .741 .907 r
.5457 .33393 .54668 .33509 .55278 .33301 .5518 .33184 Metetra
.664 .741 .907 r
.5518 .33184 .55278 .33301 .55922 .36143 .55792 .32976 Metetra
.51 .313 .549 r
.55792 .32976 .55922 .36143 .56543 .36086 .5642 .33938 Metetra
.611 .397 .566 r
.5642 .33938 .56543 .36086 .57116 .32674 .57019 .32557 Metetra
.664 .741 .907 r
.57019 .32557 .57116 .32674 .57732 .32464 .57635 .32347 Metetra
.664 .741 .907 r
.57635 .32347 .57732 .32464 .58349 .32254 .58252 .32136 Metetra
.664 .741 .907 r
.58252 .32136 .58349 .32254 .58967 .32043 .58871 .31925 Metetra
.664 .741 .907 r
.58871 .31925 .58967 .32043 .59586 .31832 .59491 .31714 Metetra
.664 .741 .907 r
.59491 .31714 .59586 .31832 .60207 .3162 .60112 .31502 Metetra
.664 .741 .907 r
.60112 .31502 .60207 .3162 .6083 .31408 .60734 .31289 Metetra
.664 .741 .907 r
.60734 .31289 .6083 .31408 .61453 .31195 .61358 .31076 Metetra
.664 .741 .907 r
.61358 .31076 .61453 .31195 .62079 .30982 .61984 .30863 Metetra
.664 .741 .907 r
.61984 .30863 .62079 .30982 .62705 .30768 .62611 .30649 Metetra
.664 .741 .907 r
.62611 .30649 .62705 .30768 .63333 .30554 .63239 .30435 Metetra
.664 .741 .907 r
.63239 .30435 .63333 .30554 .63962 .3034 .63869 .3022 Metetra
.664 .741 .907 r
.63869 .3022 .63962 .3034 .64593 .30125 .645 .30005 Metetra
.664 .741 .907 r
.645 .30005 .64593 .30125 .65225 .29909 .65132 .29789 Metetra
.664 .741 .907 r
.65132 .29789 .65225 .29909 .65859 .29693 .65766 .29572 Metetra
.664 .741 .907 r
.65766 .29572 .65859 .29693 .66494 .29477 .66401 .29356 Metetra
.664 .741 .907 r
.66401 .29356 .66494 .29477 .6713 .2926 .67038 .29138 Metetra
.664 .741 .907 r
.67038 .29138 .6713 .2926 .67768 .29042 .67676 .28921 Metetra
.664 .741 .907 r
.67676 .28921 .67768 .29042 .68408 .28824 .68316 .28702 Metetra
.664 .741 .907 r
.68316 .28702 .68408 .28824 .69048 .28606 .68957 .28484 Metetra
.664 .741 .907 r
.68957 .28484 .69048 .28606 .69691 .28387 .69599 .28264 Metetra
.664 .741 .907 r
.69599 .28264 .69691 .28387 .70334 .28167 .70243 .28045 Metetra
.664 .741 .907 r
.70243 .28045 .70334 .28167 .70979 .27947 .70889 .27824 Metetra
.664 .741 .907 r
.70889 .27824 .70979 .27947 .71626 .27727 .71536 .27604 Metetra
.664 .741 .907 r
.71536 .27604 .71626 .27727 .72274 .27506 .72184 .27382 Metetra
.664 .741 .907 r
.72184 .27382 .72274 .27506 .72924 .27284 .72834 .27161 Metetra
.664 .741 .907 r
.72834 .27161 .72924 .27284 .73575 .27062 .73485 .26938 Metetra
.664 .741 .907 r
.73485 .26938 .73575 .27062 .74227 .2684 .74138 .26716 Metetra
.664 .741 .907 r
.74138 .26716 .74227 .2684 .74881 .26617 .74793 .26492 Metetra
.664 .741 .907 r
.74793 .26492 .74881 .26617 .75537 .26393 .75449 .26268 Metetra
.664 .741 .907 r
.75449 .26268 .75537 .26393 .76194 .26169 .76106 .26044 Metetra
.664 .741 .907 r
.76106 .26044 .76194 .26169 .76992 .27705 .76765 .25819 Metetra
.56 .362 .569 r
.76765 .25819 .76992 .27705 .77513 .2572 .77425 .25594 Metetra
.664 .741 .907 r
.77425 .25594 .77513 .2572 .78174 .25494 .78087 .25368 Metetra
.664 .741 .907 r
.78087 .25368 .78174 .25494 .78837 .25268 .7875 .25142 Metetra
.664 .741 .907 r
.7875 .25142 .78837 .25268 .79502 .25041 .79415 .24915 Metetra
.664 .741 .907 r
.79415 .24915 .79502 .25041 .80168 .24814 .80082 .24687 Metetra
.664 .741 .907 r
.80082 .24687 .80168 .24814 .80836 .24587 .8075 .24459 Metetra
.664 .741 .907 r
.8075 .24459 .80836 .24587 .81505 .24358 .8142 .24231 Metetra
.664 .741 .907 r
.8142 .24231 .81505 .24358 .82176 .2413 .82091 .24002 Metetra
.664 .741 .907 r
.82091 .24002 .82176 .2413 .82848 .239 .82763 .23772 Metetra
.664 .741 .907 r
.82763 .23772 .82848 .239 .83522 .23671 .83438 .23542 Metetra
.664 .741 .907 r
.83438 .23542 .83522 .23671 .84198 .2344 .84114 .23312 Metetra
.664 .741 .907 r
.23392 .4389 .23503 .43994 .24046 .43808 .23936 .43705 Metetra
.664 .741 .907 r
.23936 .43705 .24046 .43808 .24591 .43622 .24481 .43519 Metetra
.664 .741 .907 r
.24481 .43519 .24591 .43622 .25137 .43436 .25027 .43332 Metetra
.664 .741 .907 r
.25027 .43332 .25137 .43436 .25684 .4325 .25574 .43145 Metetra
.664 .741 .907 r
.25574 .43145 .25684 .4325 .26232 .43062 .26122 .42958 Metetra
.946 .65 .444 r
.26122 .42958 .26232 .43062 .26387 .47863 .26315 .47262 Metetra
.85 .621 .592 r
.26315 .47262 .26387 .47863 .27332 .42687 .27222 .42582 Metetra
.664 .741 .907 r
.27222 .42582 .27332 .42687 .27883 .42499 .27774 .42394 Metetra
.664 .741 .907 r
.27774 .42394 .27883 .42499 .28436 .4231 .28327 .42205 Metetra
.664 .741 .907 r
.28327 .42205 .28436 .4231 .2899 .42121 .28881 .42016 Metetra
.664 .741 .907 r
.28881 .42016 .2899 .42121 .29545 .41932 .29436 .41826 Metetra
.664 .741 .907 r
.29436 .41826 .29545 .41932 .30101 .41742 .29993 .41636 Metetra
.664 .741 .907 r
.29993 .41636 .30101 .41742 .30658 .41552 .3055 .41446 Metetra
.664 .741 .907 r
.3055 .41446 .30658 .41552 .31217 .41362 .31109 .41255 Metetra
.664 .741 .907 r
.31109 .41255 .31217 .41362 .31776 .41171 .31669 .41064 Metetra
.664 .741 .907 r
.31669 .41064 .31776 .41171 .32337 .40979 .3223 .40872 Metetra
.664 .741 .907 r
.3223 .40872 .32337 .40979 .32899 .40787 .32792 .4068 Metetra
.664 .741 .907 r
.32792 .4068 .32899 .40787 .33463 .40595 .33356 .40488 Metetra
.664 .741 .907 r
.33356 .40488 .33463 .40595 .34027 .40403 .33921 .40295 Metetra
.664 .741 .907 r
.33921 .40295 .34027 .40403 .34593 .40209 .34486 .40102 Metetra
.664 .741 .907 r
.34486 .40102 .34593 .40209 .3516 .40016 .35054 .39908 Metetra
.664 .741 .907 r
.35054 .39908 .3516 .40016 .35728 .39822 .35622 .39714 Metetra
.664 .741 .907 r
.35622 .39714 .35728 .39822 .35783 .49844 .36192 .39519 Metetra
.525 .313 .534 r
.36192 .39519 .35783 .49844 .36796 .40923 .36679 .41029 Metetra
.991 .874 .611 r
.36679 .41029 .36796 .40923 .3744 .39238 .37334 .39129 Metetra
.664 .741 .907 r
.37334 .39129 .3744 .39238 .38013 .39043 .37908 .38933 Metetra
.664 .741 .907 r
.37908 .38933 .38013 .39043 .38587 .38847 .38482 .38737 Metetra
.955 .635 .38 r
.38482 .38737 .38587 .38847 .39162 .3865 .38892 .42491 Metetra
.381 .179 .476 r
.38892 .42491 .39162 .3865 .39739 .38454 .39635 .38344 Metetra
.664 .741 .907 r
.39635 .38344 .39739 .38454 .40317 .38256 .40213 .38146 Metetra
.664 .741 .907 r
.40213 .38146 .40317 .38256 .40896 .38059 .40792 .37948 Metetra
.664 .741 .907 r
.40792 .37948 .40896 .38059 .41477 .37861 .41373 .3775 Metetra
.664 .741 .907 r
.41373 .3775 .41477 .37861 .42058 .37662 .41955 .37551 Metetra
.664 .741 .907 r
.41955 .37551 .42058 .37662 .42641 .37463 .42538 .37352 Metetra
.664 .741 .907 r
.42538 .37352 .42641 .37463 .43225 .37264 .43122 .37153 Metetra
.664 .741 .907 r
.43122 .37153 .43225 .37264 .43811 .37064 .43708 .36952 Metetra
.664 .741 .907 r
.43708 .36952 .43811 .37064 .44397 .36864 .44295 .36752 Metetra
.664 .741 .907 r
.44295 .36752 .44397 .36864 .44953 .38041 .44883 .36551 Metetra
.564 .37 .577 r
.44883 .36551 .44953 .38041 .45575 .36462 .45473 .3635 Metetra
.664 .741 .907 r
.45473 .3635 .45575 .36462 .46165 .36261 .46064 .36148 Metetra
.664 .741 .907 r
.46064 .36148 .46165 .36261 .46757 .36059 .46656 .35946 Metetra
.664 .741 .907 r
.46656 .35946 .46757 .36059 .4735 .35856 .47249 .35743 Metetra
.664 .741 .907 r
.47249 .35743 .4735 .35856 .47945 .35653 .47844 .3554 Metetra
.664 .741 .907 r
.47844 .3554 .47945 .35653 .4854 .3545 .4844 .35337 Metetra
.664 .741 .907 r
.4844 .35337 .4854 .3545 .49138 .35246 .49037 .35133 Metetra
.664 .741 .907 r
.49037 .35133 .49138 .35246 .49736 .35042 .49636 .34928 Metetra
.664 .741 .907 r
.49636 .34928 .49736 .35042 .50336 .34838 .50236 .34723 Metetra
.664 .741 .907 r
.50236 .34723 .50336 .34838 .50936 .34633 .50837 .34518 Metetra
.664 .741 .907 r
.50837 .34518 .50936 .34633 .51539 .34427 .51439 .34312 Metetra
.664 .741 .907 r
.51439 .34312 .51539 .34427 .52142 .34221 .52043 .34106 Metetra
.664 .741 .907 r
.52043 .34106 .52142 .34221 .52747 .34015 .52648 .33899 Metetra
.664 .741 .907 r
.52648 .33899 .52747 .34015 .53354 .33808 .53255 .33692 Metetra
.664 .741 .907 r
.53255 .33692 .53354 .33808 .53961 .33601 .53863 .33485 Metetra
.664 .741 .907 r
.53863 .33485 .53961 .33601 .5457 .33393 .54472 .33277 Metetra
.664 .741 .907 r
.54472 .33277 .5457 .33393 .5518 .33184 .55083 .33068 Metetra
.664 .741 .907 r
.55083 .33068 .5518 .33184 .55792 .32976 .55694 .32859 Metetra
.449 .648 .944 r
.55694 .32859 .55792 .32976 .5642 .33938 .56311 .32898 Metetra
.596 .408 .597 r
.56311 .32898 .5642 .33938 .57019 .32557 .56922 .3244 Metetra
.664 .741 .907 r
.56922 .3244 .57019 .32557 .57635 .32347 .57538 .32229 Metetra
.664 .741 .907 r
.57538 .32229 .57635 .32347 .58252 .32136 .58156 .32019 Metetra
.664 .741 .907 r
.58156 .32019 .58252 .32136 .58871 .31925 .58774 .31807 Metetra
.664 .741 .907 r
.58774 .31807 .58871 .31925 .59491 .31714 .59395 .31596 Metetra
.664 .741 .907 r
.59395 .31596 .59491 .31714 .60112 .31502 .60016 .31383 Metetra
.664 .741 .907 r
.60016 .31383 .60112 .31502 .60734 .31289 .60639 .31171 Metetra
.664 .741 .907 r
.60639 .31171 .60734 .31289 .61358 .31076 .61263 .30957 Metetra
.664 .741 .907 r
.61263 .30957 .61358 .31076 .61984 .30863 .61889 .30744 Metetra
.664 .741 .907 r
.61889 .30744 .61984 .30863 .62611 .30649 .62516 .3053 Metetra
.664 .741 .907 r
.62516 .3053 .62611 .30649 .63239 .30435 .63145 .30315 Metetra
.664 .741 .907 r
.63145 .30315 .63239 .30435 .63869 .3022 .63775 .301 Metetra
.664 .741 .907 r
.63775 .301 .63869 .3022 .645 .30005 .64406 .29884 Metetra
.664 .741 .907 r
.64406 .29884 .645 .30005 .65132 .29789 .65039 .29668 Metetra
.664 .741 .907 r
.65039 .29668 .65132 .29789 .65766 .29572 .65673 .29452 Metetra
.664 .741 .907 r
.65673 .29452 .65766 .29572 .66401 .29356 .66308 .29235 Metetra
.664 .741 .907 r
.66308 .29235 .66401 .29356 .67038 .29138 .66945 .29017 Metetra
.664 .741 .907 r
.66945 .29017 .67038 .29138 .67676 .28921 .67584 .28799 Metetra
.664 .741 .907 r
.67584 .28799 .67676 .28921 .68316 .28702 .68224 .2858 Metetra
.664 .741 .907 r
.68224 .2858 .68316 .28702 .68957 .28484 .68865 .28361 Metetra
.664 .741 .907 r
.68865 .28361 .68957 .28484 .69599 .28264 .69508 .28142 Metetra
.664 .741 .907 r
.69508 .28142 .69599 .28264 .70243 .28045 .70152 .27922 Metetra
.664 .741 .907 r
.70152 .27922 .70243 .28045 .70889 .27824 .70798 .27701 Metetra
.664 .741 .907 r
.70798 .27701 .70889 .27824 .71536 .27604 .71445 .2748 Metetra
.664 .741 .907 r
.71445 .2748 .71536 .27604 .72184 .27382 .72094 .27259 Metetra
.664 .741 .907 r
.72094 .27259 .72184 .27382 .72834 .27161 .72744 .27037 Metetra
.664 .741 .907 r
.72744 .27037 .72834 .27161 .73485 .26938 .73396 .26814 Metetra
.664 .741 .907 r
.73396 .26814 .73485 .26938 .74138 .26716 .74049 .26591 Metetra
.664 .741 .907 r
.74049 .26591 .74138 .26716 .74793 .26492 .74704 .26367 Metetra
.664 .741 .907 r
.74704 .26367 .74793 .26492 .75449 .26268 .7536 .26143 Metetra
.664 .741 .907 r
.7536 .26143 .75449 .26268 .76106 .26044 .76018 .25919 Metetra
.664 .741 .907 r
.76018 .25919 .76106 .26044 .76765 .25819 .76677 .25694 Metetra
.664 .741 .907 r
.76677 .25694 .76765 .25819 .77425 .25594 .77338 .25468 Metetra
.664 .741 .907 r
.77338 .25468 .77425 .25594 .78087 .25368 .78 .25242 Metetra
.664 .741 .907 r
.78 .25242 .78087 .25368 .7875 .25142 .78664 .25015 Metetra
.664 .741 .907 r
.78664 .25015 .7875 .25142 .79415 .24915 .79329 .24788 Metetra
.664 .741 .907 r
.79329 .24788 .79415 .24915 .80082 .24687 .79996 .2456 Metetra
.664 .741 .907 r
.79996 .2456 .80082 .24687 .8075 .24459 .80664 .24332 Metetra
.664 .741 .907 r
.80664 .24332 .8075 .24459 .8142 .24231 .81334 .24103 Metetra
.664 .741 .907 r
.81334 .24103 .8142 .24231 .82091 .24002 .82005 .23874 Metetra
.664 .741 .907 r
.82005 .23874 .82091 .24002 .82763 .23772 .82678 .23644 Metetra
.664 .741 .907 r
.82678 .23644 .82763 .23772 .83438 .23542 .83353 .23414 Metetra
.664 .741 .907 r
.83353 .23414 .83438 .23542 .84114 .23312 .84029 .23183 Metetra
.664 .741 .907 r
.23281 .43787 .23392 .4389 .23936 .43705 .23825 .43601 Metetra
.664 .741 .907 r
.23825 .43601 .23936 .43705 .24481 .43519 .2437 .43415 Metetra
.664 .741 .907 r
.2437 .43415 .24481 .43519 .25027 .43332 .24917 .43228 Metetra
.664 .741 .907 r
.24917 .43228 .25027 .43332 .25574 .43145 .25464 .43041 Metetra
.664 .741 .907 r
.25464 .43041 .25574 .43145 .26122 .42958 .26012 .42853 Metetra
.946 .623 .389 r
.26012 .42853 .26122 .42958 .26315 .47262 .26332 .45548 Metetra
.699 .475 .581 r
.26332 .45548 .26315 .47262 .27222 .42582 .27113 .42477 Metetra
.664 .741 .907 r
.27113 .42477 .27222 .42582 .27774 .42394 .27665 .42289 Metetra
.664 .741 .907 r
.27665 .42289 .27774 .42394 .28327 .42205 .28218 .421 Metetra
.664 .741 .907 r
.28218 .421 .28327 .42205 .28881 .42016 .28772 .4191 Metetra
.664 .741 .907 r
.28772 .4191 .28881 .42016 .29436 .41826 .29328 .4172 Metetra
.664 .741 .907 r
.29328 .4172 .29436 .41826 .29993 .41636 .29884 .4153 Metetra
.664 .741 .907 r
.29884 .4153 .29993 .41636 .3055 .41446 .30442 .41339 Metetra
.664 .741 .907 r
.30442 .41339 .3055 .41446 .31109 .41255 .31001 .41148 Metetra
.664 .741 .907 r
.31001 .41148 .31109 .41255 .31669 .41064 .31561 .40957 Metetra
.664 .741 .907 r
.31561 .40957 .31669 .41064 .3223 .40872 .32123 .40765 Metetra
.664 .741 .907 r
.32123 .40765 .3223 .40872 .32792 .4068 .32685 .40573 Metetra
.664 .741 .907 r
.32685 .40573 .32792 .4068 .33356 .40488 .33249 .4038 Metetra
.664 .741 .907 r
.33249 .4038 .33356 .40488 .33921 .40295 .33814 .40187 Metetra
.664 .741 .907 r
.33814 .40187 .33921 .40295 .34486 .40102 .3438 .39994 Metetra
.664 .741 .907 r
.3438 .39994 .34486 .40102 .35054 .39908 .34947 .398 Metetra
.664 .741 .907 r
.34947 .398 .35054 .39908 .35622 .39714 .35516 .39605 Metetra
.664 .741 .907 r
.35516 .39605 .35622 .39714 .36192 .39519 .36086 .39411 Metetra
.664 .741 .907 r
.36086 .39411 .36192 .39519 .36679 .41029 .36657 .39216 Metetra
.56 .361 .568 r
.36657 .39216 .36679 .41029 .37334 .39129 .37229 .3902 Metetra
.664 .741 .907 r
.37229 .3902 .37334 .39129 .37908 .38933 .37802 .38824 Metetra
.664 .741 .907 r
.37802 .38824 .37908 .38933 .38482 .38737 .38377 .38628 Metetra
.956 .672 .459 r
.38377 .38628 .38482 .38737 .38892 .42491 .38455 .50226 Metetra
.282 .107 .458 r
.38455 .50226 .38892 .42491 .39635 .38344 .3953 .38233 Metetra
.664 .741 .907 r
.3953 .38233 .39635 .38344 .40213 .38146 .40108 .38036 Metetra
.664 .741 .907 r
.40108 .38036 .40213 .38146 .40792 .37948 .40688 .37838 Metetra
.664 .741 .907 r
.40688 .37838 .40792 .37948 .41373 .3775 .41269 .37639 Metetra
.664 .741 .907 r
.41269 .37639 .41373 .3775 .41955 .37551 .41851 .3744 Metetra
.664 .741 .907 r
.41851 .3744 .41955 .37551 .42538 .37352 .42435 .37241 Metetra
.664 .741 .907 r
.42435 .37241 .42538 .37352 .43122 .37153 .43019 .37041 Metetra
.664 .741 .907 r
.43019 .37041 .43122 .37153 .43708 .36952 .43605 .36841 Metetra
.664 .741 .907 r
.43605 .36841 .43708 .36952 .44295 .36752 .44192 .3664 Metetra
.664 .741 .907 r
.44192 .3664 .44295 .36752 .44883 .36551 .44781 .36439 Metetra
.664 .741 .907 r
.44781 .36439 .44883 .36551 .45473 .3635 .45371 .36237 Metetra
.664 .741 .907 r
.45371 .36237 .45473 .3635 .46064 .36148 .45962 .36035 Metetra
.664 .741 .907 r
.45962 .36035 .46064 .36148 .46656 .35946 .46554 .35833 Metetra
.664 .741 .907 r
.46554 .35833 .46656 .35946 .47249 .35743 .47148 .3563 Metetra
.664 .741 .907 r
.47148 .3563 .47249 .35743 .47844 .3554 .47743 .35427 Metetra
.664 .741 .907 r
.47743 .35427 .47844 .3554 .4844 .35337 .48339 .35223 Metetra
.664 .741 .907 r
.48339 .35223 .4844 .35337 .49037 .35133 .48936 .35019 Metetra
.664 .741 .907 r
.48936 .35019 .49037 .35133 .49636 .34928 .49535 .34814 Metetra
.664 .741 .907 r
.49535 .34814 .49636 .34928 .50236 .34723 .50135 .34609 Metetra
.664 .741 .907 r
.50135 .34609 .50236 .34723 .50837 .34518 .50737 .34403 Metetra
.664 .741 .907 r
.50737 .34403 .50837 .34518 .51439 .34312 .5134 .34197 Metetra
.664 .741 .907 r
.5134 .34197 .51439 .34312 .52043 .34106 .51944 .33991 Metetra
.664 .741 .907 r
.51944 .33991 .52043 .34106 .52648 .33899 .52549 .33784 Metetra
.664 .741 .907 r
.52549 .33784 .52648 .33899 .53255 .33692 .53156 .33577 Metetra
.664 .741 .907 r
.53156 .33577 .53255 .33692 .53863 .33485 .53764 .33369 Metetra
.664 .741 .907 r
.53764 .33369 .53863 .33485 .54472 .33277 .54374 .3316 Metetra
.664 .741 .907 r
.54374 .3316 .54472 .33277 .55083 .33068 .54985 .32952 Metetra
.664 .741 .907 r
.54985 .32952 .55083 .33068 .55694 .32859 .55597 .32742 Metetra
.664 .741 .907 r
.55597 .32742 .55694 .32859 .56311 .32898 .5621 .32533 Metetra
.614 .503 .703 r
.5621 .32533 .56311 .32898 .56922 .3244 .56825 .32323 Metetra
.664 .741 .907 r
.56825 .32323 .56922 .3244 .57538 .32229 .57441 .32112 Metetra
.664 .741 .907 r
.57441 .32112 .57538 .32229 .58156 .32019 .58059 .31901 Metetra
.664 .741 .907 r
.58059 .31901 .58156 .32019 .58774 .31807 .58678 .31689 Metetra
.664 .741 .907 r
.58678 .31689 .58774 .31807 .59395 .31596 .59299 .31477 Metetra
.664 .741 .907 r
.59299 .31477 .59395 .31596 .60016 .31383 .5992 .31265 Metetra
.664 .741 .907 r
.5992 .31265 .60016 .31383 .60639 .31171 .60543 .31052 Metetra
.961 .626 .299 r
.60543 .31052 .60639 .31171 .61263 .30957 .61313 .36059 Metetra
.415 .215 .498 r
.61313 .36059 .61263 .30957 .61889 .30744 .61806 .31028 Metetra
.186 0 .177 r
.61806 .31028 .61889 .30744 .62516 .3053 .62421 .3041 Metetra
.664 .741 .907 r
.62421 .3041 .62516 .3053 .63145 .30315 .6305 .30195 Metetra
.664 .741 .907 r
.6305 .30195 .63145 .30315 .63775 .301 .6368 .2998 Metetra
.664 .741 .907 r
.6368 .2998 .63775 .301 .64406 .29884 .64312 .29764 Metetra
.664 .741 .907 r
.64312 .29764 .64406 .29884 .65039 .29668 .64945 .29547 Metetra
.664 .741 .907 r
.64945 .29547 .65039 .29668 .65673 .29452 .6558 .29331 Metetra
.664 .741 .907 r
.6558 .29331 .65673 .29452 .66308 .29235 .66215 .29113 Metetra
.664 .741 .907 r
.66215 .29113 .66308 .29235 .66945 .29017 .66853 .28895 Metetra
.664 .741 .907 r
.66853 .28895 .66945 .29017 .67584 .28799 .67492 .28677 Metetra
.664 .741 .907 r
.67492 .28677 .67584 .28799 .68224 .2858 .68132 .28458 Metetra
.664 .741 .907 r
.68132 .28458 .68224 .2858 .68865 .28361 .68774 .28239 Metetra
.664 .741 .907 r
.68774 .28239 .68865 .28361 .69508 .28142 .69417 .28019 Metetra
.664 .741 .907 r
.69417 .28019 .69508 .28142 .70152 .27922 .70061 .27799 Metetra
.664 .741 .907 r
.70061 .27799 .70152 .27922 .70798 .27701 .70707 .27578 Metetra
.664 .741 .907 r
.70707 .27578 .70798 .27701 .71445 .2748 .71355 .27357 Metetra
.664 .741 .907 r
.71355 .27357 .71445 .2748 .72094 .27259 .72004 .27135 Metetra
.664 .741 .907 r
.72004 .27135 .72094 .27259 .72744 .27037 .72654 .26913 Metetra
.664 .741 .907 r
.72654 .26913 .72744 .27037 .73396 .26814 .73306 .2669 Metetra
.664 .741 .907 r
.73306 .2669 .73396 .26814 .74049 .26591 .7396 .26466 Metetra
.664 .741 .907 r
.7396 .26466 .74049 .26591 .74704 .26367 .74615 .26243 Metetra
.664 .741 .907 r
.74615 .26243 .74704 .26367 .7536 .26143 .75271 .26018 Metetra
.664 .741 .907 r
.75271 .26018 .7536 .26143 .76018 .25919 .75929 .25793 Metetra
.664 .741 .907 r
.75929 .25793 .76018 .25919 .76677 .25694 .76589 .25568 Metetra
.664 .741 .907 r
.76589 .25568 .76677 .25694 .77338 .25468 .7725 .25342 Metetra
.664 .741 .907 r
.7725 .25342 .77338 .25468 .78 .25242 .77912 .25116 Metetra
.664 .741 .907 r
.77912 .25116 .78 .25242 .78664 .25015 .78577 .24889 Metetra
.664 .741 .907 r
.78577 .24889 .78664 .25015 .79329 .24788 .79242 .24661 Metetra
.664 .741 .907 r
.79242 .24661 .79329 .24788 .79996 .2456 .79909 .24433 Metetra
.664 .741 .907 r
.79909 .24433 .79996 .2456 .80664 .24332 .80578 .24205 Metetra
.664 .741 .907 r
.80578 .24205 .80664 .24332 .81334 .24103 .81248 .23975 Metetra
.664 .741 .907 r
.81248 .23975 .81334 .24103 .82005 .23874 .8192 .23746 Metetra
.664 .741 .907 r
.8192 .23746 .82005 .23874 .82678 .23644 .82593 .23516 Metetra
.664 .741 .907 r
.82593 .23516 .82678 .23644 .83353 .23414 .83268 .23285 Metetra
.664 .741 .907 r
.83268 .23285 .83353 .23414 .84029 .23183 .83945 .23054 Metetra
.664 .741 .907 r
.2317 .43683 .23281 .43787 .23825 .43601 .23715 .43497 Metetra
.664 .741 .907 r
.23715 .43497 .23825 .43601 .2437 .43415 .2426 .43311 Metetra
.664 .741 .907 r
.2426 .43311 .2437 .43415 .24917 .43228 .24806 .43124 Metetra
.664 .741 .907 r
.24806 .43124 .24917 .43228 .25464 .43041 .25354 .42936 Metetra
.664 .741 .907 r
.25354 .42936 .25464 .43041 .26012 .42853 .25902 .42749 Metetra
.664 .741 .907 r
.25902 .42749 .26012 .42853 .26332 .45548 .26452 .42561 Metetra
.553 .346 .553 r
.26452 .42561 .26332 .45548 .27113 .42477 .27003 .42372 Metetra
.664 .741 .907 r
.27003 .42372 .27113 .42477 .27665 .42289 .27555 .42183 Metetra
.664 .741 .907 r
.27555 .42183 .27665 .42289 .28218 .421 .28109 .41994 Metetra
.664 .741 .907 r
.28109 .41994 .28218 .421 .28772 .4191 .28663 .41804 Metetra
.664 .741 .907 r
.28663 .41804 .28772 .4191 .29328 .4172 .29219 .41614 Metetra
.664 .741 .907 r
.29219 .41614 .29328 .4172 .29884 .4153 .29776 .41424 Metetra
.664 .741 .907 r
.29776 .41424 .29884 .4153 .30442 .41339 .30334 .41233 Metetra
.664 .741 .907 r
.30334 .41233 .30442 .41339 .31001 .41148 .30893 .41042 Metetra
.664 .741 .907 r
.30893 .41042 .31001 .41148 .31561 .40957 .31453 .4085 Metetra
.664 .741 .907 r
.31453 .4085 .31561 .40957 .32123 .40765 .32015 .40658 Metetra
.664 .741 .907 r
.32015 .40658 .32123 .40765 .32685 .40573 .32578 .40465 Metetra
.664 .741 .907 r
.32578 .40465 .32685 .40573 .33249 .4038 .33142 .40273 Metetra
.664 .741 .907 r
.33142 .40273 .33249 .4038 .33814 .40187 .33707 .40079 Metetra
.664 .741 .907 r
.33707 .40079 .33814 .40187 .3438 .39994 .34273 .39886 Metetra
.664 .741 .907 r
.34273 .39886 .3438 .39994 .34947 .398 .34841 .39691 Metetra
.664 .741 .907 r
.34841 .39691 .34947 .398 .35516 .39605 .3541 .39497 Metetra
.664 .741 .907 r
.3541 .39497 .35516 .39605 .36086 .39411 .3598 .39302 Metetra
.664 .741 .907 r
.3598 .39302 .36086 .39411 .36657 .39216 .36551 .39107 Metetra
.664 .741 .907 r
.36551 .39107 .36657 .39216 .37229 .3902 .37123 .38911 Metetra
.664 .741 .907 r
.37123 .38911 .37229 .3902 .37802 .38824 .37697 .38714 Metetra
.955 .676 .47 r
.37697 .38714 .37802 .38824 .38377 .38628 .37567 .54418 Metetra
.556 .331 .528 r
.37567 .54418 .38377 .38628 .38455 .50226 .38073 .56539 Metetra
0 0 .3 r
.38073 .56539 .38455 .50226 .3953 .38233 .39425 .38123 Metetra
.664 .741 .907 r
.39425 .38123 .3953 .38233 .40108 .38036 .40004 .37925 Metetra
.664 .741 .907 r
.40004 .37925 .40108 .38036 .40688 .37838 .40584 .37727 Metetra
.664 .741 .907 r
.40584 .37727 .40688 .37838 .41269 .37639 .41165 .37528 Metetra
.664 .741 .907 r
.41165 .37528 .41269 .37639 .41851 .3744 .41747 .37329 Metetra
.664 .741 .907 r
.41747 .37329 .41851 .3744 .42435 .37241 .42331 .37129 Metetra
.664 .741 .907 r
.42331 .37129 .42435 .37241 .43019 .37041 .42916 .36929 Metetra
.664 .741 .907 r
.42916 .36929 .43019 .37041 .43605 .36841 .43502 .36729 Metetra
.664 .741 .907 r
.43502 .36729 .43605 .36841 .44192 .3664 .4409 .36528 Metetra
.664 .741 .907 r
.4409 .36528 .44192 .3664 .44781 .36439 .44678 .36327 Metetra
.664 .741 .907 r
.44678 .36327 .44781 .36439 .45371 .36237 .45268 .36125 Metetra
.664 .741 .907 r
.45268 .36125 .45371 .36237 .45962 .36035 .4586 .35922 Metetra
.664 .741 .907 r
.4586 .35922 .45962 .36035 .46554 .35833 .46452 .3572 Metetra
.664 .741 .907 r
.46452 .3572 .46554 .35833 .47148 .3563 .47046 .35517 Metetra
.664 .741 .907 r
.47046 .35517 .47148 .3563 .47743 .35427 .47641 .35313 Metetra
.664 .741 .907 r
.47641 .35313 .47743 .35427 .48339 .35223 .48238 .35109 Metetra
.664 .741 .907 r
.48238 .35109 .48339 .35223 .48936 .35019 .48836 .34905 Metetra
.664 .741 .907 r
.48836 .34905 .48936 .35019 .49535 .34814 .49435 .347 Metetra
.664 .741 .907 r
.49435 .347 .49535 .34814 .50135 .34609 .50035 .34494 Metetra
.664 .741 .907 r
.50035 .34494 .50135 .34609 .50737 .34403 .50637 .34288 Metetra
.664 .741 .907 r
.50637 .34288 .50737 .34403 .5134 .34197 .5124 .34082 Metetra
.664 .741 .907 r
.5124 .34082 .5134 .34197 .51944 .33991 .51844 .33875 Metetra
.664 .741 .907 r
.51844 .33875 .51944 .33991 .52549 .33784 .5245 .33668 Metetra
.664 .741 .907 r
.5245 .33668 .52549 .33784 .53156 .33577 .53057 .33461 Metetra
.664 .741 .907 r
.53057 .33461 .53156 .33577 .53764 .33369 .53666 .33253 Metetra
.664 .741 .907 r
.53666 .33253 .53764 .33369 .54374 .3316 .54275 .33044 Metetra
.664 .741 .907 r
.54275 .33044 .54374 .3316 .54985 .32952 .54886 .32835 Metetra
.664 .741 .907 r
.54886 .32835 .54985 .32952 .55597 .32742 .55499 .32625 Metetra
.664 .741 .907 r
.55499 .32625 .55597 .32742 .5621 .32533 .56113 .32416 Metetra
.664 .741 .907 r
.56113 .32416 .5621 .32533 .56825 .32323 .56728 .32205 Metetra
.664 .741 .907 r
.56728 .32205 .56825 .32323 .57441 .32112 .57344 .31994 Metetra
.664 .741 .907 r
.57344 .31994 .57441 .32112 .58059 .31901 .57962 .31783 Metetra
.664 .741 .907 r
.57962 .31783 .58059 .31901 .58678 .31689 .58582 .31571 Metetra
.664 .741 .907 r
.58582 .31571 .58678 .31689 .59299 .31477 .59202 .31359 Metetra
.664 .741 .907 r
.59202 .31359 .59299 .31477 .5992 .31265 .59824 .31146 Metetra
.664 .741 .907 r
.59824 .31146 .5992 .31265 .60543 .31052 .60448 .30933 Metetra
.961 .627 .301 r
.60448 .30933 .60543 .31052 .61313 .36059 .61218 .36026 Metetra
.983 .763 .527 r
.61218 .36026 .61313 .36059 .61806 .31028 .61755 .32399 Metetra
.322 .115 .436 r
.61755 .32399 .61806 .31028 .62421 .3041 .62327 .3029 Metetra
.664 .741 .907 r
.62327 .3029 .62421 .3041 .6305 .30195 .62956 .30075 Metetra
.664 .741 .907 r
.62956 .30075 .6305 .30195 .6368 .2998 .63586 .29859 Metetra
.664 .741 .907 r
.63586 .29859 .6368 .2998 .64312 .29764 .64218 .29643 Metetra
.664 .741 .907 r
.64218 .29643 .64312 .29764 .64945 .29547 .64851 .29427 Metetra
.664 .741 .907 r
.64851 .29427 .64945 .29547 .6558 .29331 .65486 .29209 Metetra
.664 .741 .907 r
.65486 .29209 .6558 .29331 .66215 .29113 .66122 .28992 Metetra
.664 .741 .907 r
.66122 .28992 .66215 .29113 .66853 .28895 .6676 .28774 Metetra
.664 .741 .907 r
.6676 .28774 .66853 .28895 .67492 .28677 .67399 .28555 Metetra
.664 .741 .907 r
.67399 .28555 .67492 .28677 .68132 .28458 .6804 .28336 Metetra
.664 .741 .907 r
.6804 .28336 .68132 .28458 .68774 .28239 .68682 .28116 Metetra
.664 .741 .907 r
.68682 .28116 .68774 .28239 .69417 .28019 .69325 .27896 Metetra
.664 .741 .907 r
.69325 .27896 .69417 .28019 .70061 .27799 .6997 .27676 Metetra
.664 .741 .907 r
.6997 .27676 .70061 .27799 .70707 .27578 .70616 .27455 Metetra
.664 .741 .907 r
.70616 .27455 .70707 .27578 .71355 .27357 .71264 .27233 Metetra
.664 .741 .907 r
.71264 .27233 .71355 .27357 .72004 .27135 .71914 .27011 Metetra
.664 .741 .907 r
.71914 .27011 .72004 .27135 .72654 .26913 .72564 .26788 Metetra
.664 .741 .907 r
.72564 .26788 .72654 .26913 .73306 .2669 .73217 .26565 Metetra
.664 .741 .907 r
.73217 .26565 .73306 .2669 .7396 .26466 .73871 .26342 Metetra
.664 .741 .907 r
.73871 .26342 .7396 .26466 .74615 .26243 .74526 .26117 Metetra
.664 .741 .907 r
.74526 .26117 .74615 .26243 .75271 .26018 .75183 .25893 Metetra
.664 .741 .907 r
.75183 .25893 .75271 .26018 .75929 .25793 .75841 .25668 Metetra
.664 .741 .907 r
.75841 .25668 .75929 .25793 .76589 .25568 .76501 .25442 Metetra
.664 .741 .907 r
.76501 .25442 .76589 .25568 .7725 .25342 .77162 .25216 Metetra
.664 .741 .907 r
.77162 .25216 .7725 .25342 .77912 .25116 .77825 .24989 Metetra
.664 .741 .907 r
.77825 .24989 .77912 .25116 .78577 .24889 .78489 .24762 Metetra
.664 .741 .907 r
.78489 .24762 .78577 .24889 .79242 .24661 .79155 .24534 Metetra
.664 .741 .907 r
.79155 .24534 .79242 .24661 .79909 .24433 .79823 .24306 Metetra
.664 .741 .907 r
.79823 .24306 .79909 .24433 .80578 .24205 .80492 .24077 Metetra
.664 .741 .907 r
.80492 .24077 .80578 .24205 .81248 .23975 .81162 .23847 Metetra
.664 .741 .907 r
.81162 .23847 .81248 .23975 .8192 .23746 .81835 .23618 Metetra
.664 .741 .907 r
.81835 .23618 .8192 .23746 .82593 .23516 .82508 .23387 Metetra
.664 .741 .907 r
.82508 .23387 .82593 .23516 .83268 .23285 .83184 .23156 Metetra
.664 .741 .907 r
.83184 .23156 .83268 .23285 .83945 .23054 .8386 .22925 Metetra
.664 .741 .907 r
.23059 .43579 .2317 .43683 .23715 .43497 .23604 .43393 Metetra
.664 .741 .907 r
.23604 .43393 .23715 .43497 .2426 .43311 .24149 .43206 Metetra
.664 .741 .907 r
.24149 .43206 .2426 .43311 .24806 .43124 .24696 .43019 Metetra
.664 .741 .907 r
.24696 .43019 .24806 .43124 .25354 .42936 .25243 .42832 Metetra
.664 .741 .907 r
.25243 .42832 .25354 .42936 .25902 .42749 .25792 .42644 Metetra
.664 .741 .907 r
.25792 .42644 .25902 .42749 .26452 .42561 .26342 .42456 Metetra
.664 .741 .907 r
.26342 .42456 .26452 .42561 .27003 .42372 .26894 .42267 Metetra
.664 .741 .907 r
.26894 .42267 .27003 .42372 .27555 .42183 .27446 .42078 Metetra
.664 .741 .907 r
.27446 .42078 .27555 .42183 .28109 .41994 .28 .41888 Metetra
.664 .741 .907 r
.28 .41888 .28109 .41994 .28663 .41804 .28554 .41698 Metetra
.664 .741 .907 r
.28554 .41698 .28663 .41804 .29219 .41614 .2911 .41508 Metetra
.664 .741 .907 r
.2911 .41508 .29219 .41614 .29776 .41424 .29667 .41317 Metetra
.664 .741 .907 r
.29667 .41317 .29776 .41424 .30334 .41233 .30225 .41126 Metetra
.664 .741 .907 r
.30225 .41126 .30334 .41233 .30893 .41042 .30785 .40935 Metetra
.664 .741 .907 r
.30785 .40935 .30893 .41042 .31453 .4085 .31345 .40743 Metetra
.664 .741 .907 r
.31345 .40743 .31453 .4085 .32015 .40658 .31907 .40551 Metetra
.664 .741 .907 r
.31907 .40551 .32015 .40658 .32578 .40465 .3247 .40358 Metetra
.664 .741 .907 r
.3247 .40358 .32578 .40465 .33142 .40273 .33034 .40165 Metetra
.664 .741 .907 r
.33034 .40165 .33142 .40273 .33707 .40079 .336 .39971 Metetra
.664 .741 .907 r
.336 .39971 .33707 .40079 .34273 .39886 .34166 .39777 Metetra
.664 .741 .907 r
.34166 .39777 .34273 .39886 .34841 .39691 .34734 .39583 Metetra
.664 .741 .907 r
.34734 .39583 .34841 .39691 .3541 .39497 .35303 .39388 Metetra
.664 .741 .907 r
.35303 .39388 .3541 .39497 .3598 .39302 .35873 .39193 Metetra
.664 .741 .907 r
.35873 .39193 .3598 .39302 .36551 .39107 .36445 .38997 Metetra
.664 .741 .907 r
.36445 .38997 .36551 .39107 .37123 .38911 .37017 .38801 Metetra
.664 .741 .907 r
.37017 .38801 .37123 .38911 .37697 .38714 .37591 .38605 Metetra
.954 .678 .475 r
.37591 .38605 .37697 .38714 .37567 .54418 .37303 .57751 Metetra
0 0 .237 r
.37303 .57751 .37567 .54418 .38073 .56539 .38369 .4693 Metetra
.638 .405 .549 r
.38369 .4693 .38073 .56539 .39425 .38123 .39321 .38013 Metetra
.664 .741 .907 r
.39321 .38013 .39425 .38123 .40004 .37925 .39899 .37815 Metetra
.664 .741 .907 r
.39899 .37815 .40004 .37925 .40584 .37727 .4048 .37616 Metetra
.664 .741 .907 r
.4048 .37616 .40584 .37727 .41165 .37528 .41061 .37417 Metetra
.664 .741 .907 r
.41061 .37417 .41165 .37528 .41747 .37329 .41644 .37218 Metetra
.664 .741 .907 r
.41644 .37218 .41747 .37329 .42331 .37129 .42227 .37018 Metetra
.664 .741 .907 r
.42227 .37018 .42331 .37129 .42916 .36929 .42813 .36818 Metetra
.664 .741 .907 r
.42813 .36818 .42916 .36929 .43502 .36729 .43399 .36617 Metetra
.664 .741 .907 r
.43399 .36617 .43502 .36729 .4409 .36528 .43987 .36416 Metetra
.664 .741 .907 r
.43987 .36416 .4409 .36528 .44678 .36327 .44576 .36214 Metetra
.664 .741 .907 r
.44576 .36214 .44678 .36327 .45268 .36125 .45166 .36012 Metetra
.664 .741 .907 r
.45166 .36012 .45268 .36125 .4586 .35922 .45758 .35809 Metetra
.664 .741 .907 r
.45758 .35809 .4586 .35922 .46452 .3572 .4635 .35607 Metetra
.664 .741 .907 r
.4635 .35607 .46452 .3572 .47046 .35517 .46944 .35403 Metetra
.664 .741 .907 r
.46944 .35403 .47046 .35517 .47641 .35313 .4754 .35199 Metetra
.664 .741 .907 r
.4754 .35199 .47641 .35313 .48238 .35109 .48137 .34995 Metetra
.664 .741 .907 r
.48137 .34995 .48238 .35109 .48836 .34905 .48735 .3479 Metetra
.664 .741 .907 r
.48735 .3479 .48836 .34905 .49435 .347 .49334 .34585 Metetra
.664 .741 .907 r
.49334 .34585 .49435 .347 .50035 .34494 .49935 .3438 Metetra
.664 .741 .907 r
.49935 .3438 .50035 .34494 .50637 .34288 .50537 .34173 Metetra
.664 .741 .907 r
.50537 .34173 .50637 .34288 .5124 .34082 .5114 .33967 Metetra
.664 .741 .907 r
.5114 .33967 .5124 .34082 .51844 .33875 .51745 .3376 Metetra
.664 .741 .907 r
.51745 .3376 .51844 .33875 .5245 .33668 .52351 .33553 Metetra
.664 .741 .907 r
.52351 .33553 .5245 .33668 .53057 .33461 .52958 .33345 Metetra
.664 .741 .907 r
.52958 .33345 .53057 .33461 .53666 .33253 .53567 .33136 Metetra
.664 .741 .907 r
.53567 .33136 .53666 .33253 .54275 .33044 .54177 .32927 Metetra
.664 .741 .907 r
.54177 .32927 .54275 .33044 .54886 .32835 .54788 .32718 Metetra
.664 .741 .907 r
.54788 .32718 .54886 .32835 .55499 .32625 .55401 .32508 Metetra
.664 .741 .907 r
.55401 .32508 .55499 .32625 .56113 .32416 .56015 .32298 Metetra
.664 .741 .907 r
.56015 .32298 .56113 .32416 .56728 .32205 .5663 .32088 Metetra
.664 .741 .907 r
.5663 .32088 .56728 .32205 .57344 .31994 .57247 .31876 Metetra
.664 .741 .907 r
.57247 .31876 .57344 .31994 .57962 .31783 .57865 .31665 Metetra
.664 .741 .907 r
.57865 .31665 .57962 .31783 .58582 .31571 .58485 .31453 Metetra
.664 .741 .907 r
.58485 .31453 .58582 .31571 .59202 .31359 .59106 .3124 Metetra
.664 .741 .907 r
.59106 .3124 .59202 .31359 .59824 .31146 .59728 .31027 Metetra
.905 .508 .098 r
.59728 .31027 .59824 .31146 .60448 .30933 .60409 .33068 Metetra
.385 .177 .47 r
.60409 .33068 .60448 .30933 .61218 .36026 .60977 .306 Metetra
.538 .327 .542 r
.60977 .306 .61218 .36026 .61755 .32399 .61619 .30893 Metetra
.597 .394 .577 r
.61619 .30893 .61755 .32399 .62327 .3029 .62232 .3017 Metetra
.664 .741 .907 r
.62232 .3017 .62327 .3029 .62956 .30075 .62861 .29955 Metetra
.664 .741 .907 r
.62861 .29955 .62956 .30075 .63586 .29859 .63492 .29739 Metetra
.664 .741 .907 r
.63492 .29739 .63586 .29859 .64218 .29643 .64124 .29522 Metetra
.664 .741 .907 r
.64124 .29522 .64218 .29643 .64851 .29427 .64758 .29305 Metetra
.664 .741 .907 r
.64758 .29305 .64851 .29427 .65486 .29209 .65393 .29088 Metetra
.664 .741 .907 r
.65393 .29088 .65486 .29209 .66122 .28992 .66029 .2887 Metetra
.664 .741 .907 r
.66029 .2887 .66122 .28992 .6676 .28774 .66667 .28652 Metetra
.664 .741 .907 r
.66667 .28652 .6676 .28774 .67399 .28555 .67307 .28433 Metetra
.664 .741 .907 r
.67307 .28433 .67399 .28555 .6804 .28336 .67947 .28214 Metetra
.664 .741 .907 r
.67947 .28214 .6804 .28336 .68682 .28116 .6859 .27994 Metetra
.664 .741 .907 r
.6859 .27994 .68682 .28116 .69325 .27896 .69233 .27773 Metetra
.664 .741 .907 r
.69233 .27773 .69325 .27896 .6997 .27676 .69879 .27552 Metetra
.664 .741 .907 r
.69879 .27552 .6997 .27676 .70616 .27455 .70525 .27331 Metetra
.664 .741 .907 r
.70525 .27331 .70616 .27455 .71264 .27233 .71173 .27109 Metetra
.664 .741 .907 r
.71173 .27109 .71264 .27233 .71914 .27011 .71823 .26887 Metetra
.664 .741 .907 r
.71823 .26887 .71914 .27011 .72564 .26788 .72474 .26664 Metetra
.664 .741 .907 r
.72474 .26664 .72564 .26788 .73217 .26565 .73127 .26441 Metetra
.664 .741 .907 r
.73127 .26441 .73217 .26565 .73871 .26342 .73781 .26217 Metetra
.664 .741 .907 r
.73781 .26217 .73871 .26342 .74526 .26117 .74437 .25992 Metetra
.664 .741 .907 r
.74437 .25992 .74526 .26117 .75183 .25893 .75094 .25767 Metetra
.664 .741 .907 r
.75094 .25767 .75183 .25893 .75841 .25668 .75752 .25542 Metetra
.664 .741 .907 r
.75752 .25542 .75841 .25668 .76501 .25442 .76413 .25316 Metetra
.664 .741 .907 r
.76413 .25316 .76501 .25442 .77162 .25216 .77074 .25089 Metetra
.664 .741 .907 r
.77074 .25089 .77162 .25216 .77825 .24989 .77737 .24862 Metetra
.664 .741 .907 r
.77737 .24862 .77825 .24989 .78489 .24762 .78402 .24635 Metetra
.664 .741 .907 r
.78402 .24635 .78489 .24762 .79155 .24534 .79068 .24407 Metetra
.664 .741 .907 r
.79068 .24407 .79155 .24534 .79823 .24306 .79736 .24178 Metetra
.664 .741 .907 r
.79736 .24178 .79823 .24306 .80492 .24077 .80406 .23949 Metetra
.664 .741 .907 r
.80406 .23949 .80492 .24077 .81162 .23847 .81077 .23719 Metetra
.664 .741 .907 r
.81077 .23719 .81162 .23847 .81835 .23618 .81749 .23489 Metetra
.664 .741 .907 r
.81749 .23489 .81835 .23618 .82508 .23387 .82423 .23258 Metetra
.664 .741 .907 r
.82423 .23258 .82508 .23387 .83184 .23156 .83099 .23027 Metetra
.664 .741 .907 r
.83099 .23027 .83184 .23156 .8386 .22925 .83776 .22795 Metetra
.664 .741 .907 r
.22948 .43476 .23059 .43579 .23604 .43393 .23493 .43289 Metetra
.664 .741 .907 r
.23493 .43289 .23604 .43393 .24149 .43206 .24038 .43102 Metetra
.664 .741 .907 r
.24038 .43102 .24149 .43206 .24696 .43019 .24585 .42915 Metetra
.664 .741 .907 r
.24585 .42915 .24696 .43019 .25243 .42832 .25133 .42727 Metetra
.664 .741 .907 r
.25133 .42727 .25243 .42832 .25792 .42644 .25682 .42539 Metetra
.664 .741 .907 r
.25682 .42539 .25792 .42644 .26342 .42456 .26232 .4235 Metetra
.664 .741 .907 r
.26232 .4235 .26342 .42456 .26894 .42267 .26784 .42161 Metetra
.947 .65 .441 r
.26784 .42161 .26894 .42267 .27446 .42078 .26984 .46516 Metetra
.37 .167 .469 r
.26984 .46516 .27446 .42078 .28 .41888 .2789 .41782 Metetra
.664 .741 .907 r
.2789 .41782 .28 .41888 .28554 .41698 .28445 .41592 Metetra
.664 .741 .907 r
.28445 .41592 .28554 .41698 .2911 .41508 .29001 .41402 Metetra
.664 .741 .907 r
.29001 .41402 .2911 .41508 .29667 .41317 .29558 .41211 Metetra
.664 .741 .907 r
.29558 .41211 .29667 .41317 .30225 .41126 .30117 .4102 Metetra
.664 .741 .907 r
.30117 .4102 .30225 .41126 .30785 .40935 .30676 .40828 Metetra
.664 .741 .907 r
.30676 .40828 .30785 .40935 .31345 .40743 .31237 .40636 Metetra
.664 .741 .907 r
.31237 .40636 .31345 .40743 .31907 .40551 .31799 .40443 Metetra
.664 .741 .907 r
.31799 .40443 .31907 .40551 .3247 .40358 .32363 .4025 Metetra
.664 .741 .907 r
.32363 .4025 .3247 .40358 .33034 .40165 .32927 .40057 Metetra
.664 .741 .907 r
.32927 .40057 .33034 .40165 .336 .39971 .33493 .39863 Metetra
.664 .741 .907 r
.33493 .39863 .336 .39971 .34166 .39777 .34059 .39669 Metetra
.664 .741 .907 r
.34059 .39669 .34166 .39777 .34734 .39583 .34627 .39474 Metetra
.664 .741 .907 r
.34627 .39474 .34734 .39583 .35303 .39388 .35197 .39279 Metetra
.664 .741 .907 r
.35197 .39279 .35303 .39388 .35873 .39193 .35767 .39084 Metetra
.664 .741 .907 r
.35767 .39084 .35873 .39193 .36445 .38997 .36339 .38888 Metetra
.664 .741 .907 r
.36339 .38888 .36445 .38997 .37017 .38801 .36912 .38692 Metetra
.664 .741 .907 r
.36912 .38692 .37017 .38801 .37591 .38605 .37486 .38495 Metetra
.955 .676 .469 r
.37486 .38495 .37591 .38605 .37303 .57751 .37382 .53383 Metetra
.731 .488 .559 r
.37382 .53383 .37303 .57751 .38369 .4693 .38434 .42811 Metetra
.657 .426 .558 r
.38434 .42811 .38369 .4693 .39321 .38013 .39216 .37902 Metetra
.664 .741 .907 r
.39216 .37902 .39321 .38013 .39899 .37815 .39795 .37704 Metetra
.664 .741 .907 r
.39795 .37704 .39899 .37815 .4048 .37616 .40375 .37505 Metetra
.664 .741 .907 r
.40375 .37505 .4048 .37616 .41061 .37417 .40957 .37306 Metetra
.664 .741 .907 r
.40957 .37306 .41061 .37417 .41644 .37218 .4154 .37106 Metetra
.664 .741 .907 r
.4154 .37106 .41644 .37218 .42227 .37018 .42124 .36906 Metetra
.664 .741 .907 r
.42124 .36906 .42227 .37018 .42813 .36818 .42709 .36706 Metetra
.664 .741 .907 r
.42709 .36706 .42813 .36818 .43399 .36617 .43296 .36505 Metetra
.664 .741 .907 r
.43296 .36505 .43399 .36617 .43987 .36416 .43884 .36303 Metetra
.664 .741 .907 r
.43884 .36303 .43987 .36416 .44576 .36214 .44473 .36101 Metetra
.664 .741 .907 r
.44473 .36101 .44576 .36214 .45166 .36012 .45063 .35899 Metetra
.664 .741 .907 r
.45063 .35899 .45166 .36012 .45758 .35809 .45655 .35696 Metetra
.664 .741 .907 r
.45655 .35696 .45758 .35809 .4635 .35607 .46248 .35493 Metetra
.664 .741 .907 r
.46248 .35493 .4635 .35607 .46944 .35403 .46843 .3529 Metetra
.664 .741 .907 r
.46843 .3529 .46944 .35403 .4754 .35199 .47438 .35085 Metetra
.099 .451 .883 r
.47438 .35085 .4754 .35199 .48137 .34995 .48029 .3535 Metetra
.207 0 .22 r
.48029 .3535 .48137 .34995 .48735 .3479 .48634 .34676 Metetra
.664 .741 .907 r
.48634 .34676 .48735 .3479 .49334 .34585 .49233 .34471 Metetra
.664 .741 .907 r
.49233 .34471 .49334 .34585 .49935 .3438 .49834 .34265 Metetra
.664 .741 .907 r
.49834 .34265 .49935 .3438 .50537 .34173 .50437 .34058 Metetra
.664 .741 .907 r
.50437 .34058 .50537 .34173 .5114 .33967 .5104 .33852 Metetra
.664 .741 .907 r
.5104 .33852 .5114 .33967 .51745 .3376 .51645 .33644 Metetra
.664 .741 .907 r
.51645 .33644 .51745 .3376 .52351 .33553 .52251 .33437 Metetra
.664 .741 .907 r
.52251 .33437 .52351 .33553 .52958 .33345 .52859 .33228 Metetra
.664 .741 .907 r
.52859 .33228 .52958 .33345 .53567 .33136 .53468 .3302 Metetra
.664 .741 .907 r
.53468 .3302 .53567 .33136 .54177 .32927 .54078 .32811 Metetra
.664 .741 .907 r
.54078 .32811 .54177 .32927 .54788 .32718 .5469 .32601 Metetra
.664 .741 .907 r
.5469 .32601 .54788 .32718 .55401 .32508 .55303 .32391 Metetra
.664 .741 .907 r
.55303 .32391 .55401 .32508 .56015 .32298 .55917 .32181 Metetra
.664 .741 .907 r
.55917 .32181 .56015 .32298 .5663 .32088 .56533 .3197 Metetra
.664 .741 .907 r
.56533 .3197 .5663 .32088 .57247 .31876 .5715 .31758 Metetra
.664 .741 .907 r
.5715 .31758 .57247 .31876 .57865 .31665 .57768 .31547 Metetra
.664 .741 .907 r
.57768 .31547 .57865 .31665 .58485 .31453 .58388 .31334 Metetra
.664 .741 .907 r
.58388 .31334 .58485 .31453 .59106 .3124 .59009 .31121 Metetra
.664 .741 .907 r
.59009 .31121 .59106 .3124 .59728 .31027 .59632 .30908 Metetra
.463 .653 .942 r
.59632 .30908 .59728 .31027 .60409 .33068 .60262 .30936 Metetra
.569 .364 .564 r
.60262 .30936 .60409 .33068 .60977 .306 .60882 .3048 Metetra
.664 .741 .907 r
.60882 .3048 .60977 .306 .61619 .30893 .61508 .30265 Metetra
.589 .433 .638 r
.61508 .30265 .61619 .30893 .62232 .3017 .62137 .3005 Metetra
.664 .741 .907 r
.62137 .3005 .62232 .3017 .62861 .29955 .62766 .29834 Metetra
.664 .741 .907 r
.62766 .29834 .62861 .29955 .63492 .29739 .63397 .29618 Metetra
.664 .741 .907 r
.63397 .29618 .63492 .29739 .64124 .29522 .6403 .29401 Metetra
.664 .741 .907 r
.6403 .29401 .64124 .29522 .64758 .29305 .64664 .29184 Metetra
.664 .741 .907 r
.64664 .29184 .64758 .29305 .65393 .29088 .65299 .28967 Metetra
.664 .741 .907 r
.65299 .28967 .65393 .29088 .66029 .2887 .65936 .28748 Metetra
.664 .741 .907 r
.65936 .28748 .66029 .2887 .66667 .28652 .66574 .2853 Metetra
.664 .741 .907 r
.66574 .2853 .66667 .28652 .67307 .28433 .67214 .28311 Metetra
.664 .741 .907 r
.67214 .28311 .67307 .28433 .67947 .28214 .67855 .28091 Metetra
.664 .741 .907 r
.67855 .28091 .67947 .28214 .6859 .27994 .68498 .27871 Metetra
.664 .741 .907 r
.68498 .27871 .6859 .27994 .69233 .27773 .69142 .2765 Metetra
.664 .741 .907 r
.69142 .2765 .69233 .27773 .69879 .27552 .69787 .27429 Metetra
.664 .741 .907 r
.69787 .27429 .69879 .27552 .70525 .27331 .70434 .27207 Metetra
.664 .741 .907 r
.70434 .27207 .70525 .27331 .71173 .27109 .71083 .26985 Metetra
.664 .741 .907 r
.71083 .26985 .71173 .27109 .71823 .26887 .71733 .26763 Metetra
.664 .741 .907 r
.71733 .26763 .71823 .26887 .72474 .26664 .72384 .26539 Metetra
.664 .741 .907 r
.72384 .26539 .72474 .26664 .73127 .26441 .73037 .26316 Metetra
.664 .741 .907 r
.73037 .26316 .73127 .26441 .73781 .26217 .73691 .26092 Metetra
.664 .741 .907 r
.73691 .26092 .73781 .26217 .74437 .25992 .74347 .25867 Metetra
.664 .741 .907 r
.74347 .25867 .74437 .25992 .75094 .25767 .75005 .25642 Metetra
.664 .741 .907 r
.75005 .25642 .75094 .25767 .75752 .25542 .75664 .25416 Metetra
.664 .741 .907 r
.75664 .25416 .75752 .25542 .76413 .25316 .76324 .2519 Metetra
.664 .741 .907 r
.76324 .2519 .76413 .25316 .77074 .25089 .76986 .24963 Metetra
.664 .741 .907 r
.76986 .24963 .77074 .25089 .77737 .24862 .7765 .24735 Metetra
.664 .741 .907 r
.7765 .24735 .77737 .24862 .78402 .24635 .78315 .24508 Metetra
.664 .741 .907 r
.78315 .24508 .78402 .24635 .79068 .24407 .78981 .24279 Metetra
.664 .741 .907 r
.78981 .24279 .79068 .24407 .79736 .24178 .7965 .2405 Metetra
.664 .741 .907 r
.7965 .2405 .79736 .24178 .80406 .23949 .80319 .23821 Metetra
.664 .741 .907 r
.80319 .23821 .80406 .23949 .81077 .23719 .80991 .23591 Metetra
.664 .741 .907 r
.80991 .23591 .81077 .23719 .81749 .23489 .81663 .2336 Metetra
.664 .741 .907 r
.81663 .2336 .81749 .23489 .82423 .23258 .82338 .23129 Metetra
.664 .741 .907 r
.82338 .23129 .82423 .23258 .83099 .23027 .83014 .22898 Metetra
.664 .741 .907 r
.83014 .22898 .83099 .23027 .83776 .22795 .83691 .22666 Metetra
.664 .741 .907 r
.22837 .43372 .22948 .43476 .23493 .43289 .23382 .43185 Metetra
.664 .741 .907 r
.23382 .43185 .23493 .43289 .24038 .43102 .23927 .42998 Metetra
.664 .741 .907 r
.23927 .42998 .24038 .43102 .24585 .42915 .24474 .4281 Metetra
.664 .741 .907 r
.24474 .4281 .24585 .42915 .25133 .42727 .25023 .42622 Metetra
.664 .741 .907 r
.25023 .42622 .25133 .42727 .25682 .42539 .25572 .42434 Metetra
.664 .741 .907 r
.25572 .42434 .25682 .42539 .26232 .4235 .26122 .42245 Metetra
.664 .741 .907 r
.26122 .42245 .26232 .4235 .26784 .42161 .26674 .42056 Metetra
.947 .647 .436 r
.26674 .42056 .26784 .42161 .26984 .46516 .26891 .46175 Metetra
.888 .663 .591 r
.26891 .46175 .26984 .46516 .2789 .41782 .27781 .41676 Metetra
.664 .741 .907 r
.27781 .41676 .2789 .41782 .28445 .41592 .28336 .41486 Metetra
.664 .741 .907 r
.28336 .41486 .28445 .41592 .29001 .41402 .28892 .41295 Metetra
.664 .741 .907 r
.28892 .41295 .29001 .41402 .29558 .41211 .2945 .41104 Metetra
.664 .741 .907 r
.2945 .41104 .29558 .41211 .30117 .4102 .30008 .40913 Metetra
.664 .741 .907 r
.30008 .40913 .30117 .4102 .30676 .40828 .30568 .40721 Metetra
.664 .741 .907 r
.30568 .40721 .30676 .40828 .31237 .40636 .31129 .40528 Metetra
.664 .741 .907 r
.31129 .40528 .31237 .40636 .31799 .40443 .31691 .40336 Metetra
.664 .741 .907 r
.31691 .40336 .31799 .40443 .32363 .4025 .32255 .40142 Metetra
.664 .741 .907 r
.32255 .40142 .32363 .4025 .32927 .40057 .32819 .39949 Metetra
.664 .741 .907 r
.32819 .39949 .32927 .40057 .33493 .39863 .33385 .39755 Metetra
.664 .741 .907 r
.33385 .39755 .33493 .39863 .34059 .39669 .33952 .3956 Metetra
.664 .741 .907 r
.33952 .3956 .34059 .39669 .34627 .39474 .3452 .39366 Metetra
.664 .741 .907 r
.3452 .39366 .34627 .39474 .35197 .39279 .3509 .3917 Metetra
.664 .741 .907 r
.3509 .3917 .35197 .39279 .35767 .39084 .35661 .38975 Metetra
.664 .741 .907 r
.35661 .38975 .35767 .39084 .36339 .38888 .36233 .38779 Metetra
.664 .741 .907 r
.36233 .38779 .36339 .38888 .36912 .38692 .36806 .38582 Metetra
.664 .741 .907 r
.36806 .38582 .36912 .38692 .37486 .38495 .3738 .38385 Metetra
.925 .536 .2 r
.3738 .38385 .37486 .38495 .37382 .53383 .37872 .40024 Metetra
.548 .33 .535 r
.37872 .40024 .37382 .53383 .38434 .42811 .3847 .39416 Metetra
.596 .378 .556 r
.3847 .39416 .38434 .42811 .39216 .37902 .39111 .37792 Metetra
.664 .741 .907 r
.39111 .37792 .39216 .37902 .39795 .37704 .3969 .37593 Metetra
.664 .741 .907 r
.3969 .37593 .39795 .37704 .40375 .37505 .40271 .37394 Metetra
.664 .741 .907 r
.40271 .37394 .40375 .37505 .40957 .37306 .40852 .37195 Metetra
.664 .741 .907 r
.40852 .37195 .40957 .37306 .4154 .37106 .41435 .36995 Metetra
.664 .741 .907 r
.41435 .36995 .4154 .37106 .42124 .36906 .4202 .36794 Metetra
.664 .741 .907 r
.4202 .36794 .42124 .36906 .42709 .36706 .42605 .36594 Metetra
.664 .741 .907 r
.42605 .36594 .42709 .36706 .43296 .36505 .43192 .36392 Metetra
.664 .741 .907 r
.43192 .36392 .43296 .36505 .43884 .36303 .43781 .36191 Metetra
.664 .741 .907 r
.43781 .36191 .43884 .36303 .44473 .36101 .4437 .35989 Metetra
.664 .741 .907 r
.4437 .35989 .44473 .36101 .45063 .35899 .44961 .35786 Metetra
.664 .741 .907 r
.44961 .35786 .45063 .35899 .45655 .35696 .45553 .35583 Metetra
.664 .741 .907 r
.45553 .35583 .45655 .35696 .46248 .35493 .46146 .3538 Metetra
.664 .741 .907 r
.46146 .3538 .46248 .35493 .46843 .3529 .46741 .35176 Metetra
.664 .741 .907 r
.46741 .35176 .46843 .3529 .47438 .35085 .47337 .34971 Metetra
.664 .741 .907 r
.47337 .34971 .47438 .35085 .48029 .3535 .47934 .34767 Metetra
.591 .439 .643 r
.47934 .34767 .48029 .3535 .48634 .34676 .48533 .34561 Metetra
.664 .741 .907 r
.48533 .34561 .48634 .34676 .49233 .34471 .49132 .34356 Metetra
.664 .741 .907 r
.49132 .34356 .49233 .34471 .49834 .34265 .49734 .3415 Metetra
.664 .741 .907 r
.49734 .3415 .49834 .34265 .50437 .34058 .50336 .33943 Metetra
.664 .741 .907 r
.50336 .33943 .50437 .34058 .5104 .33852 .5094 .33736 Metetra
.664 .741 .907 r
.5094 .33736 .5104 .33852 .51645 .33644 .51545 .33529 Metetra
.664 .741 .907 r
.51545 .33529 .51645 .33644 .52251 .33437 .52152 .33321 Metetra
.664 .741 .907 r
.52152 .33321 .52251 .33437 .52859 .33228 .5276 .33112 Metetra
.664 .741 .907 r
.5276 .33112 .52859 .33228 .53468 .3302 .53369 .32903 Metetra
.664 .741 .907 r
.53369 .32903 .53468 .3302 .54078 .32811 .53979 .32694 Metetra
.664 .741 .907 r
.53979 .32694 .54078 .32811 .5469 .32601 .54591 .32484 Metetra
.664 .741 .907 r
.54591 .32484 .5469 .32601 .55303 .32391 .55205 .32274 Metetra
.664 .741 .907 r
.55205 .32274 .55303 .32391 .55917 .32181 .55819 .32063 Metetra
.664 .741 .907 r
.55819 .32063 .55917 .32181 .56533 .3197 .56435 .31852 Metetra
.664 .741 .907 r
.56435 .31852 .56533 .3197 .5715 .31758 .57053 .3164 Metetra
.664 .741 .907 r
.57053 .3164 .5715 .31758 .57768 .31547 .57671 .31428 Metetra
.664 .741 .907 r
.57671 .31428 .57768 .31547 .58388 .31334 .58291 .31216 Metetra
.664 .741 .907 r
.58291 .31216 .58388 .31334 .59009 .31121 .58913 .31002 Metetra
.664 .741 .907 r
.58913 .31002 .59009 .31121 .59632 .30908 .59536 .30789 Metetra
.664 .741 .907 r
.59536 .30789 .59632 .30908 .60262 .30936 .6016 .30575 Metetra
.615 .506 .706 r
.6016 .30575 .60262 .30936 .60882 .3048 .60786 .3036 Metetra
0 .206 .72 r
.60786 .3036 .60882 .3048 .61508 .30265 .61434 .30877 Metetra
.31 .058 .36 r
.61434 .30877 .61508 .30265 .62137 .3005 .62041 .2993 Metetra
.664 .741 .907 r
.62041 .2993 .62137 .3005 .62766 .29834 .62671 .29714 Metetra
.664 .741 .907 r
.62671 .29714 .62766 .29834 .63397 .29618 .63303 .29497 Metetra
.664 .741 .907 r
.63303 .29497 .63397 .29618 .6403 .29401 .63936 .2928 Metetra
.664 .741 .907 r
.63936 .2928 .6403 .29401 .64664 .29184 .6457 .29063 Metetra
.664 .741 .907 r
.6457 .29063 .64664 .29184 .65299 .28967 .65205 .28845 Metetra
.664 .741 .907 r
.65205 .28845 .65299 .28967 .65936 .28748 .65843 .28627 Metetra
.664 .741 .907 r
.65843 .28627 .65936 .28748 .66574 .2853 .66481 .28408 Metetra
.664 .741 .907 r
.66481 .28408 .66574 .2853 .67214 .28311 .67121 .28188 Metetra
.664 .741 .907 r
.67121 .28188 .67214 .28311 .67855 .28091 .67762 .27968 Metetra
.664 .741 .907 r
.67762 .27968 .67855 .28091 .68498 .27871 .68405 .27748 Metetra
.664 .741 .907 r
.68405 .27748 .68498 .27871 .69142 .2765 .6905 .27527 Metetra
.664 .741 .907 r
.6905 .27527 .69142 .2765 .69787 .27429 .69696 .27306 Metetra
.664 .741 .907 r
.69696 .27306 .69787 .27429 .70434 .27207 .70343 .27084 Metetra
.664 .741 .907 r
.70343 .27084 .70434 .27207 .71083 .26985 .70992 .26861 Metetra
.664 .741 .907 r
.70992 .26861 .71083 .26985 .71733 .26763 .71642 .26638 Metetra
.664 .741 .907 r
.71642 .26638 .71733 .26763 .72384 .26539 .72294 .26415 Metetra
.664 .741 .907 r
.72294 .26415 .72384 .26539 .73037 .26316 .72947 .26191 Metetra
.664 .741 .907 r
.72947 .26191 .73037 .26316 .73691 .26092 .73602 .25966 Metetra
.664 .741 .907 r
.73602 .25966 .73691 .26092 .74347 .25867 .74258 .25741 Metetra
.664 .741 .907 r
.74258 .25741 .74347 .25867 .75005 .25642 .74916 .25516 Metetra
.664 .741 .907 r
.74916 .25516 .75005 .25642 .75664 .25416 .75575 .2529 Metetra
.664 .741 .907 r
.75575 .2529 .75664 .25416 .76324 .2519 .76236 .25063 Metetra
.664 .741 .907 r
.76236 .25063 .76324 .2519 .76986 .24963 .76898 .24836 Metetra
.664 .741 .907 r
.76898 .24836 .76986 .24963 .7765 .24735 .77562 .24608 Metetra
.664 .741 .907 r
.77562 .24608 .7765 .24735 .78315 .24508 .78227 .2438 Metetra
.664 .741 .907 r
.78227 .2438 .78315 .24508 .78981 .24279 .78894 .24152 Metetra
.664 .741 .907 r
.78894 .24152 .78981 .24279 .7965 .2405 .79563 .23922 Metetra
.664 .741 .907 r
.79563 .23922 .7965 .2405 .80319 .23821 .80233 .23693 Metetra
.664 .741 .907 r
.80233 .23693 .80319 .23821 .80991 .23591 .80904 .23462 Metetra
.664 .741 .907 r
.80904 .23462 .80991 .23591 .81663 .2336 .81578 .23232 Metetra
.664 .741 .907 r
.81578 .23232 .81663 .2336 .82338 .23129 .82252 .23 Metetra
.664 .741 .907 r
.82252 .23 .82338 .23129 .83014 .22898 .82929 .22768 Metetra
.664 .741 .907 r
.82929 .22768 .83014 .22898 .83691 .22666 .83606 .22536 Metetra
.664 .741 .907 r
.22725 .43267 .22837 .43372 .23382 .43185 .2327 .4308 Metetra
.664 .741 .907 r
.2327 .4308 .23382 .43185 .23927 .42998 .23816 .42893 Metetra
.664 .741 .907 r
.23816 .42893 .23927 .42998 .24474 .4281 .24364 .42705 Metetra
.664 .741 .907 r
.24364 .42705 .24474 .4281 .25023 .42622 .24912 .42517 Metetra
.907 .497 .165 r
.24912 .42517 .25023 .42622 .25572 .42434 .25347 .43705 Metetra
.327 .1 .409 r
.25347 .43705 .25572 .42434 .26122 .42245 .26012 .4214 Metetra
.664 .741 .907 r
.26012 .4214 .26122 .42245 .26674 .42056 .26564 .4195 Metetra
.947 .64 .421 r
.26564 .4195 .26674 .42056 .26891 .46175 .26823 .4551 Metetra
.827 .601 .596 r
.26823 .4551 .26891 .46175 .27781 .41676 .27671 .4157 Metetra
.664 .741 .907 r
.27671 .4157 .27781 .41676 .28336 .41486 .28226 .4138 Metetra
.664 .741 .907 r
.28226 .4138 .28336 .41486 .28892 .41295 .28783 .41189 Metetra
.664 .741 .907 r
.28783 .41189 .28892 .41295 .2945 .41104 .29341 .40997 Metetra
.664 .741 .907 r
.29341 .40997 .2945 .41104 .30008 .40913 .29899 .40806 Metetra
.664 .741 .907 r
.29899 .40806 .30008 .40913 .30568 .40721 .30459 .40614 Metetra
.664 .741 .907 r
.30459 .40614 .30568 .40721 .31129 .40528 .31021 .40421 Metetra
.664 .741 .907 r
.31021 .40421 .31129 .40528 .31691 .40336 .31583 .40228 Metetra
.664 .741 .907 r
.31583 .40228 .31691 .40336 .32255 .40142 .32147 .40035 Metetra
.664 .741 .907 r
.32147 .40035 .32255 .40142 .32819 .39949 .32712 .39841 Metetra
.664 .741 .907 r
.32712 .39841 .32819 .39949 .33385 .39755 .33278 .39647 Metetra
.952 .668 .463 r
.33278 .39647 .33385 .39755 .33952 .3956 .33323 .48457 Metetra
.383 .186 .484 r
.33323 .48457 .33952 .3956 .3452 .39366 .34413 .39257 Metetra
.664 .741 .907 r
.34413 .39257 .3452 .39366 .3509 .3917 .34983 .39061 Metetra
.664 .741 .907 r
.34983 .39061 .3509 .3917 .35661 .38975 .35554 .38865 Metetra
.664 .741 .907 r
.35554 .38865 .35661 .38975 .36233 .38779 .36126 .38669 Metetra
.664 .741 .907 r
.36126 .38669 .36233 .38779 .36806 .38582 .367 .38472 Metetra
.664 .741 .907 r
.367 .38472 .36806 .38582 .3738 .38385 .37274 .38275 Metetra
.664 .741 .907 r
.37274 .38275 .3738 .38385 .37872 .40024 .3785 .38078 Metetra
.545 .347 .563 r
.3785 .38078 .37872 .40024 .3847 .39416 .38418 .38096 Metetra
.583 .388 .583 r
.38418 .38096 .3847 .39416 .39111 .37792 .39005 .37681 Metetra
.664 .741 .907 r
.39005 .37681 .39111 .37792 .3969 .37593 .39585 .37482 Metetra
.664 .741 .907 r
.39585 .37482 .3969 .37593 .40271 .37394 .40166 .37283 Metetra
.664 .741 .907 r
.40166 .37283 .40271 .37394 .40852 .37195 .40748 .37083 Metetra
.664 .741 .907 r
.40748 .37083 .40852 .37195 .41435 .36995 .41331 .36883 Metetra
.664 .741 .907 r
.41331 .36883 .41435 .36995 .4202 .36794 .41916 .36682 Metetra
.664 .741 .907 r
.41916 .36682 .4202 .36794 .42605 .36594 .42502 .36481 Metetra
.664 .741 .907 r
.42502 .36481 .42605 .36594 .43192 .36392 .43089 .3628 Metetra
.664 .741 .907 r
.43089 .3628 .43192 .36392 .43781 .36191 .43677 .36078 Metetra
.664 .741 .907 r
.43677 .36078 .43781 .36191 .4437 .35989 .44267 .35876 Metetra
.664 .741 .907 r
.44267 .35876 .4437 .35989 .44961 .35786 .44858 .35673 Metetra
.664 .741 .907 r
.44858 .35673 .44961 .35786 .45553 .35583 .4545 .3547 Metetra
.664 .741 .907 r
.4545 .3547 .45553 .35583 .46146 .3538 .46044 .35266 Metetra
.664 .741 .907 r
.46044 .35266 .46146 .3538 .46741 .35176 .46639 .35062 Metetra
.664 .741 .907 r
.46639 .35062 .46741 .35176 .47337 .34971 .47235 .34857 Metetra
.664 .741 .907 r
.47235 .34857 .47337 .34971 .47934 .34767 .47833 .34652 Metetra
.664 .741 .907 r
.47833 .34652 .47934 .34767 .48533 .34561 .48431 .34447 Metetra
.664 .741 .907 r
.48431 .34447 .48533 .34561 .49132 .34356 .49031 .34241 Metetra
.664 .741 .907 r
.49031 .34241 .49132 .34356 .49734 .3415 .49633 .34034 Metetra
.664 .741 .907 r
.49633 .34034 .49734 .3415 .50336 .33943 .50236 .33828 Metetra
.664 .741 .907 r
.50236 .33828 .50336 .33943 .5094 .33736 .5084 .3362 Metetra
.952 .603 .282 r
.5084 .3362 .5094 .33736 .51545 .33529 .51434 .36766 Metetra
.386 .183 .478 r
.51434 .36766 .51545 .33529 .52152 .33321 .52052 .33204 Metetra
.664 .741 .907 r
.52052 .33204 .52152 .33321 .5276 .33112 .5266 .32996 Metetra
.664 .741 .907 r
.5266 .32996 .5276 .33112 .53369 .32903 .5327 .32787 Metetra
.664 .741 .907 r
.5327 .32787 .53369 .32903 .53979 .32694 .5388 .32577 Metetra
.664 .741 .907 r
.5388 .32577 .53979 .32694 .54591 .32484 .54493 .32367 Metetra
.664 .741 .907 r
.54493 .32367 .54591 .32484 .55205 .32274 .55106 .32156 Metetra
.664 .741 .907 r
.55106 .32156 .55205 .32274 .55819 .32063 .55721 .31945 Metetra
.664 .741 .907 r
.55721 .31945 .55819 .32063 .56435 .31852 .56337 .31734 Metetra
.664 .741 .907 r
.56337 .31734 .56435 .31852 .57053 .3164 .56955 .31522 Metetra
.664 .741 .907 r
.56955 .31522 .57053 .3164 .57671 .31428 .57574 .3131 Metetra
.664 .741 .907 r
.57574 .3131 .57671 .31428 .58291 .31216 .58194 .31097 Metetra
.664 .741 .907 r
.58194 .31097 .58291 .31216 .58913 .31002 .58816 .30883 Metetra
.664 .741 .907 r
.58816 .30883 .58913 .31002 .59536 .30789 .59439 .3067 Metetra
.664 .741 .907 r
.59439 .3067 .59536 .30789 .6016 .30575 .60064 .30455 Metetra
.664 .741 .907 r
.60064 .30455 .6016 .30575 .60786 .3036 .6069 .3024 Metetra
.664 .741 .907 r
.6069 .3024 .60786 .3036 .61434 .30877 .61317 .30025 Metetra
.577 .404 .61 r
.61317 .30025 .61434 .30877 .62041 .2993 .61946 .29809 Metetra
.664 .741 .907 r
.61946 .29809 .62041 .2993 .62671 .29714 .62576 .29593 Metetra
.664 .741 .907 r
.62576 .29593 .62671 .29714 .63303 .29497 .63208 .29376 Metetra
.664 .741 .907 r
.63208 .29376 .63303 .29497 .63936 .2928 .63841 .29159 Metetra
.664 .741 .907 r
.63841 .29159 .63936 .2928 .6457 .29063 .64476 .28941 Metetra
.664 .741 .907 r
.64476 .28941 .6457 .29063 .65205 .28845 .65112 .28723 Metetra
.664 .741 .907 r
.65112 .28723 .65205 .28845 .65843 .28627 .65749 .28505 Metetra
.664 .741 .907 r
.65749 .28505 .65843 .28627 .66481 .28408 .66388 .28285 Metetra
.664 .741 .907 r
.66388 .28285 .66481 .28408 .67121 .28188 .67028 .28066 Metetra
.664 .741 .907 r
.67028 .28066 .67121 .28188 .67762 .27968 .6767 .27845 Metetra
.664 .741 .907 r
.6767 .27845 .67762 .27968 .68405 .27748 .68313 .27625 Metetra
.664 .741 .907 r
.68313 .27625 .68405 .27748 .6905 .27527 .68958 .27404 Metetra
.664 .741 .907 r
.68958 .27404 .6905 .27527 .69696 .27306 .69604 .27182 Metetra
.664 .741 .907 r
.69604 .27182 .69696 .27306 .70343 .27084 .70251 .2696 Metetra
.664 .741 .907 r
.70251 .2696 .70343 .27084 .70992 .26861 .70901 .26737 Metetra
.664 .741 .907 r
.70901 .26737 .70992 .26861 .71642 .26638 .71551 .26514 Metetra
.664 .741 .907 r
.71551 .26514 .71642 .26638 .72294 .26415 .72203 .2629 Metetra
.664 .741 .907 r
.72203 .2629 .72294 .26415 .72947 .26191 .72857 .26066 Metetra
.664 .741 .907 r
.72857 .26066 .72947 .26191 .73602 .25966 .73512 .25841 Metetra
.664 .741 .907 r
.73512 .25841 .73602 .25966 .74258 .25741 .74168 .25616 Metetra
.664 .741 .907 r
.74168 .25616 .74258 .25741 .74916 .25516 .74826 .2539 Metetra
.664 .741 .907 r
.74826 .2539 .74916 .25516 .75575 .2529 .75486 .25163 Metetra
.664 .741 .907 r
.75486 .25163 .75575 .2529 .76236 .25063 .76147 .24937 Metetra
.664 .741 .907 r
.76147 .24937 .76236 .25063 .76898 .24836 .7681 .24709 Metetra
.664 .741 .907 r
.7681 .24709 .76898 .24836 .77562 .24608 .77474 .24481 Metetra
.664 .741 .907 r
.77474 .24481 .77562 .24608 .78227 .2438 .7814 .24253 Metetra
.664 .741 .907 r
.7814 .24253 .78227 .2438 .78894 .24152 .78807 .24024 Metetra
.664 .741 .907 r
.78807 .24024 .78894 .24152 .79563 .23922 .79476 .23794 Metetra
.664 .741 .907 r
.79476 .23794 .79563 .23922 .80233 .23693 .80146 .23564 Metetra
.664 .741 .907 r
.80146 .23564 .80233 .23693 .80904 .23462 .80818 .23334 Metetra
.664 .741 .907 r
.80818 .23334 .80904 .23462 .81578 .23232 .81492 .23103 Metetra
.664 .741 .907 r
.81492 .23103 .81578 .23232 .82252 .23 .82167 .22871 Metetra
.664 .741 .907 r
.82167 .22871 .82252 .23 .82929 .22768 .82843 .22639 Metetra
.664 .741 .907 r
.82843 .22639 .82929 .22768 .83606 .22536 .83522 .22406 Metetra
.664 .741 .907 r
.22614 .43163 .22725 .43267 .2327 .4308 .23159 .42976 Metetra
.664 .741 .907 r
.23159 .42976 .2327 .4308 .23816 .42893 .23705 .42788 Metetra
.664 .741 .907 r
.23705 .42788 .23816 .42893 .24364 .42705 .24253 .426 Metetra
.664 .741 .907 r
.24253 .426 .24364 .42705 .24912 .42517 .24801 .42412 Metetra
.664 .741 .907 r
.24801 .42412 .24912 .42517 .25347 .43705 .25351 .42223 Metetra
.562 .368 .575 r
.25351 .42223 .25347 .43705 .26012 .4214 .25902 .42034 Metetra
.664 .741 .907 r
.25902 .42034 .26012 .4214 .26564 .4195 .26454 .41844 Metetra
.664 .741 .907 r
.26454 .41844 .26564 .4195 .26823 .4551 .27007 .41655 Metetra
.55 .339 .547 r
.27007 .41655 .26823 .4551 .27671 .4157 .27561 .41464 Metetra
.664 .741 .907 r
.27561 .41464 .27671 .4157 .28226 .4138 .28117 .41273 Metetra
.664 .741 .907 r
.28117 .41273 .28226 .4138 .28783 .41189 .28674 .41082 Metetra
.664 .741 .907 r
.28674 .41082 .28783 .41189 .29341 .40997 .29231 .40891 Metetra
.664 .741 .907 r
.29231 .40891 .29341 .40997 .29899 .40806 .29791 .40699 Metetra
.664 .741 .907 r
.29791 .40699 .29899 .40806 .30459 .40614 .30351 .40506 Metetra
.664 .741 .907 r
.30351 .40506 .30459 .40614 .31021 .40421 .30912 .40313 Metetra
.664 .741 .907 r
.30912 .40313 .31021 .40421 .31583 .40228 .31475 .4012 Metetra
.664 .741 .907 r
.31475 .4012 .31583 .40228 .32147 .40035 .32039 .39927 Metetra
.664 .741 .907 r
.32039 .39927 .32147 .40035 .32712 .39841 .32604 .39732 Metetra
.952 .661 .449 r
.32604 .39732 .32712 .39841 .33278 .39647 .32772 .46176 Metetra
.716 .463 .543 r
.32772 .46176 .33278 .39647 .33323 .48457 .32417 .61998 Metetra
.228 .064 .44 r
.32417 .61998 .33323 .48457 .34413 .39257 .34306 .39148 Metetra
.664 .741 .907 r
.34306 .39148 .34413 .39257 .34983 .39061 .34876 .38952 Metetra
.664 .741 .907 r
.34876 .38952 .34983 .39061 .35554 .38865 .35447 .38756 Metetra
.664 .741 .907 r
.35447 .38756 .35554 .38865 .36126 .38669 .3602 .38559 Metetra
.664 .741 .907 r
.3602 .38559 .36126 .38669 .367 .38472 .36593 .38362 Metetra
.664 .741 .907 r
.36593 .38362 .367 .38472 .37274 .38275 .37168 .38165 Metetra
.664 .741 .907 r
.37168 .38165 .37274 .38275 .3785 .38078 .37744 .37967 Metetra
.664 .741 .907 r
.37744 .37967 .3785 .38078 .38418 .38096 .38322 .37769 Metetra
.618 .516 .716 r
.38322 .37769 .38418 .38096 .39005 .37681 .389 .3757 Metetra
.664 .741 .907 r
.389 .3757 .39005 .37681 .39585 .37482 .3948 .37371 Metetra
.664 .741 .907 r
.3948 .37371 .39585 .37482 .40166 .37283 .40061 .37172 Metetra
.664 .741 .907 r
.40061 .37172 .40166 .37283 .40748 .37083 .40643 .36972 Metetra
.664 .741 .907 r
.40643 .36972 .40748 .37083 .41331 .36883 .41227 .36771 Metetra
.664 .741 .907 r
.41227 .36771 .41331 .36883 .41916 .36682 .41812 .3657 Metetra
.664 .741 .907 r
.41812 .3657 .41916 .36682 .42502 .36481 .42398 .36369 Metetra
.664 .741 .907 r
.42398 .36369 .42502 .36481 .43089 .3628 .42985 .36167 Metetra
.664 .741 .907 r
.42985 .36167 .43089 .3628 .43677 .36078 .43574 .35965 Metetra
.664 .741 .907 r
.43574 .35965 .43677 .36078 .44267 .35876 .44164 .35763 Metetra
.664 .741 .907 r
.44164 .35763 .44267 .35876 .44858 .35673 .44755 .3556 Metetra
.664 .741 .907 r
.44755 .3556 .44858 .35673 .4545 .3547 .45348 .35356 Metetra
.664 .741 .907 r
.45348 .35356 .4545 .3547 .46044 .35266 .45942 .35152 Metetra
.664 .741 .907 r
.45942 .35152 .46044 .35266 .46639 .35062 .46537 .34948 Metetra
.664 .741 .907 r
.46537 .34948 .46639 .35062 .47235 .34857 .47133 .34743 Metetra
.664 .741 .907 r
.47133 .34743 .47235 .34857 .47833 .34652 .47731 .34538 Metetra
.664 .741 .907 r
.47731 .34538 .47833 .34652 .48431 .34447 .4833 .34332 Metetra
.664 .741 .907 r
.4833 .34332 .48431 .34447 .49031 .34241 .4893 .34126 Metetra
.664 .741 .907 r
.4893 .34126 .49031 .34241 .49633 .34034 .49532 .33919 Metetra
.664 .741 .907 r
.49532 .33919 .49633 .34034 .50236 .33828 .50135 .33712 Metetra
.544 .695 .938 r
.50135 .33712 .50236 .33828 .5084 .3362 .50739 .33658 Metetra
.95 .641 .412 r
.50739 .33658 .5084 .3362 .51434 .36766 .51317 .40988 Metetra
.236 .071 .443 r
.51317 .40988 .51434 .36766 .52052 .33204 .51952 .33088 Metetra
.664 .741 .907 r
.51952 .33088 .52052 .33204 .5266 .32996 .52561 .32879 Metetra
.664 .741 .907 r
.52561 .32879 .5266 .32996 .5327 .32787 .5317 .3267 Metetra
.664 .741 .907 r
.5317 .3267 .5327 .32787 .5388 .32577 .53781 .3246 Metetra
.664 .741 .907 r
.53781 .3246 .5388 .32577 .54493 .32367 .54394 .3225 Metetra
.664 .741 .907 r
.54394 .3225 .54493 .32367 .55106 .32156 .55008 .32039 Metetra
.664 .741 .907 r
.55008 .32039 .55106 .32156 .55721 .31945 .55623 .31828 Metetra
.664 .741 .907 r
.55623 .31828 .55721 .31945 .56337 .31734 .56239 .31616 Metetra
.664 .741 .907 r
.56239 .31616 .56337 .31734 .56955 .31522 .56857 .31404 Metetra
.664 .741 .907 r
.56857 .31404 .56955 .31522 .57574 .3131 .57477 .31191 Metetra
.664 .741 .907 r
.57477 .31191 .57574 .3131 .58194 .31097 .58097 .30978 Metetra
.664 .741 .907 r
.58097 .30978 .58194 .31097 .58816 .30883 .58719 .30764 Metetra
.664 .741 .907 r
.58719 .30764 .58816 .30883 .59439 .3067 .59343 .3055 Metetra
.664 .741 .907 r
.59343 .3055 .59439 .3067 .60064 .30455 .59968 .30336 Metetra
.664 .741 .907 r
.59968 .30336 .60064 .30455 .6069 .3024 .60594 .3012 Metetra
.664 .741 .907 r
.60594 .3012 .6069 .3024 .61317 .30025 .61222 .29905 Metetra
.664 .741 .907 r
.61222 .29905 .61317 .30025 .61946 .29809 .61851 .29689 Metetra
.664 .741 .907 r
.61851 .29689 .61946 .29809 .62576 .29593 .62481 .29472 Metetra
.664 .741 .907 r
.62481 .29472 .62576 .29593 .63208 .29376 .63113 .29255 Metetra
.664 .741 .907 r
.63113 .29255 .63208 .29376 .63841 .29159 .63747 .29038 Metetra
.664 .741 .907 r
.63747 .29038 .63841 .29159 .64476 .28941 .64381 .2882 Metetra
.664 .741 .907 r
.64381 .2882 .64476 .28941 .65112 .28723 .65018 .28601 Metetra
.664 .741 .907 r
.65018 .28601 .65112 .28723 .65749 .28505 .65655 .28382 Metetra
.664 .741 .907 r
.65655 .28382 .65749 .28505 .66388 .28285 .66294 .28163 Metetra
.664 .741 .907 r
.66294 .28163 .66388 .28285 .67028 .28066 .66935 .27943 Metetra
.664 .741 .907 r
.66935 .27943 .67028 .28066 .6767 .27845 .67577 .27722 Metetra
.664 .741 .907 r
.67577 .27722 .6767 .27845 .68313 .27625 .68221 .27501 Metetra
0 .281 .779 r
.68221 .27501 .68313 .27625 .68958 .27404 .68903 .27985 Metetra
.312 .058 .358 r
.68903 .27985 .68958 .27404 .69604 .27182 .69512 .27058 Metetra
.954 .609 .242 r
.69512 .27058 .69604 .27182 .70251 .2696 .70471 .32284 Metetra
.407 .211 .499 r
.70471 .32284 .70251 .2696 .70901 .26737 .70809 .26612 Metetra
.664 .741 .907 r
.70809 .26612 .70901 .26737 .71551 .26514 .7146 .26389 Metetra
.664 .741 .907 r
.7146 .26389 .71551 .26514 .72203 .2629 .72113 .26165 Metetra
.664 .741 .907 r
.72113 .26165 .72203 .2629 .72857 .26066 .72766 .2594 Metetra
.664 .741 .907 r
.72766 .2594 .72857 .26066 .73512 .25841 .73422 .25715 Metetra
.664 .741 .907 r
.73422 .25715 .73512 .25841 .74168 .25616 .74079 .2549 Metetra
.664 .741 .907 r
.74079 .2549 .74168 .25616 .74826 .2539 .74737 .25264 Metetra
.664 .741 .907 r
.74737 .25264 .74826 .2539 .75486 .25163 .75397 .25037 Metetra
.664 .741 .907 r
.75397 .25037 .75486 .25163 .76147 .24937 .76059 .2481 Metetra
.664 .741 .907 r
.76059 .2481 .76147 .24937 .7681 .24709 .76721 .24582 Metetra
.664 .741 .907 r
.76721 .24582 .7681 .24709 .77474 .24481 .77386 .24354 Metetra
.664 .741 .907 r
.77386 .24354 .77474 .24481 .7814 .24253 .78052 .24125 Metetra
.664 .741 .907 r
.78052 .24125 .7814 .24253 .78807 .24024 .7872 .23896 Metetra
.664 .741 .907 r
.7872 .23896 .78807 .24024 .79476 .23794 .79389 .23666 Metetra
.664 .741 .907 r
.79389 .23666 .79476 .23794 .80146 .23564 .80059 .23436 Metetra
.664 .741 .907 r
.80059 .23436 .80146 .23564 .80818 .23334 .80732 .23205 Metetra
.664 .741 .907 r
.80732 .23205 .80818 .23334 .81492 .23103 .81406 .22974 Metetra
.664 .741 .907 r
.81406 .22974 .81492 .23103 .82167 .22871 .82081 .22742 Metetra
.664 .741 .907 r
.82081 .22742 .82167 .22871 .82843 .22639 .82758 .22509 Metetra
.664 .741 .907 r
.82758 .22509 .82843 .22639 .83522 .22406 .83437 .22276 Metetra
.664 .741 .907 r
.22502 .43059 .22614 .43163 .23159 .42976 .23047 .42871 Metetra
.664 .741 .907 r
.23047 .42871 .23159 .42976 .23705 .42788 .23594 .42684 Metetra
.664 .741 .907 r
.23594 .42684 .23705 .42788 .24253 .426 .24141 .42495 Metetra
.664 .741 .907 r
.24141 .42495 .24253 .426 .24801 .42412 .2469 .42307 Metetra
0 .254 .736 r
.2469 .42307 .24801 .42412 .25351 .42223 .25196 .42645 Metetra
.197 0 .227 r
.25196 .42645 .25351 .42223 .25902 .42034 .25791 .41928 Metetra
.664 .741 .907 r
.25791 .41928 .25902 .42034 .26454 .41844 .26343 .41739 Metetra
.664 .741 .907 r
.26343 .41739 .26454 .41844 .27007 .41655 .26897 .41548 Metetra
.664 .741 .907 r
.26897 .41548 .27007 .41655 .27561 .41464 .27451 .41358 Metetra
.664 .741 .907 r
.27451 .41358 .27561 .41464 .28117 .41273 .28007 .41167 Metetra
.664 .741 .907 r
.28007 .41167 .28117 .41273 .28674 .41082 .28564 .40975 Metetra
.664 .741 .907 r
.28564 .40975 .28674 .41082 .29231 .40891 .29122 .40784 Metetra
.664 .741 .907 r
.29122 .40784 .29231 .40891 .29791 .40699 .29681 .40591 Metetra
.664 .741 .907 r
.29681 .40591 .29791 .40699 .30351 .40506 .30242 .40399 Metetra
.664 .741 .907 r
.30242 .40399 .30351 .40506 .30912 .40313 .30804 .40206 Metetra
.664 .741 .907 r
.30804 .40206 .30912 .40313 .31475 .4012 .31367 .40012 Metetra
.664 .741 .907 r
.31367 .40012 .31475 .4012 .32039 .39927 .31931 .39818 Metetra
.664 .741 .907 r
.31931 .39818 .32039 .39927 .32604 .39732 .32496 .39624 Metetra
.951 .673 .476 r
.32496 .39624 .32604 .39732 .32772 .46176 .32335 .51471 Metetra
.622 .381 .53 r
.32335 .51471 .32772 .46176 .32417 .61998 .32649 .5596 Metetra
.75 .503 .558 r
.32649 .5596 .32417 .61998 .34306 .39148 .34199 .39039 Metetra
.664 .741 .907 r
.34199 .39039 .34306 .39148 .34876 .38952 .34769 .38843 Metetra
.664 .741 .907 r
.34769 .38843 .34876 .38952 .35447 .38756 .35341 .38646 Metetra
.664 .741 .907 r
.35341 .38646 .35447 .38756 .3602 .38559 .35913 .3845 Metetra
.664 .741 .907 r
.35913 .3845 .3602 .38559 .36593 .38362 .36487 .38252 Metetra
.664 .741 .907 r
.36487 .38252 .36593 .38362 .37168 .38165 .37062 .38055 Metetra
.664 .741 .907 r
.37062 .38055 .37168 .38165 .37744 .37967 .37638 .37857 Metetra
.664 .741 .907 r
.37638 .37857 .37744 .37967 .38322 .37769 .38216 .37658 Metetra
.664 .741 .907 r
.38216 .37658 .38322 .37769 .389 .3757 .38795 .37459 Metetra
.664 .741 .907 r
.38795 .37459 .389 .3757 .3948 .37371 .39375 .3726 Metetra
.664 .741 .907 r
.39375 .3726 .3948 .37371 .40061 .37172 .39956 .3706 Metetra
.664 .741 .907 r
.39956 .3706 .40061 .37172 .40643 .36972 .40539 .3686 Metetra
.664 .741 .907 r
.40539 .3686 .40643 .36972 .41227 .36771 .41122 .36659 Metetra
.664 .741 .907 r
.41122 .36659 .41227 .36771 .41812 .3657 .41708 .36458 Metetra
.664 .741 .907 r
.41708 .36458 .41812 .3657 .42398 .36369 .42294 .36257 Metetra
.664 .741 .907 r
.42294 .36257 .42398 .36369 .42985 .36167 .42882 .36055 Metetra
.664 .741 .907 r
.42882 .36055 .42985 .36167 .43574 .35965 .4347 .35852 Metetra
.664 .741 .907 r
.4347 .35852 .43574 .35965 .44164 .35763 .44061 .35649 Metetra
.664 .741 .907 r
.44061 .35649 .44164 .35763 .44755 .3556 .44652 .35446 Metetra
.664 .741 .907 r
.44652 .35446 .44755 .3556 .45348 .35356 .45245 .35242 Metetra
.664 .741 .907 r
.45245 .35242 .45348 .35356 .45942 .35152 .45839 .35038 Metetra
.664 .741 .907 r
.45839 .35038 .45942 .35152 .46537 .34948 .46434 .34834 Metetra
.664 .741 .907 r
.46434 .34834 .46537 .34948 .47133 .34743 .47031 .34629 Metetra
.664 .741 .907 r
.47031 .34629 .47133 .34743 .47731 .34538 .47629 .34423 Metetra
.664 .741 .907 r
.47629 .34423 .47731 .34538 .4833 .34332 .48228 .34217 Metetra
.664 .741 .907 r
.48228 .34217 .4833 .34332 .4893 .34126 .48829 .34011 Metetra
.664 .741 .907 r
.48829 .34011 .4893 .34126 .49532 .33919 .49431 .33804 Metetra
.664 .741 .907 r
.49431 .33804 .49532 .33919 .50135 .33712 .50034 .33596 Metetra
.938 .565 .216 r
.50034 .33596 .50135 .33712 .50739 .33658 .50624 .35928 Metetra
.589 .34 .506 r
.50624 .35928 .50739 .33658 .51317 .40988 .51229 .37108 Metetra
.646 .414 .554 r
.51229 .37108 .51317 .40988 .51952 .33088 .51852 .32972 Metetra
.664 .741 .907 r
.51852 .32972 .51952 .33088 .52561 .32879 .52461 .32762 Metetra
.664 .741 .907 r
.52461 .32762 .52561 .32879 .5317 .3267 .53071 .32553 Metetra
.664 .741 .907 r
.53071 .32553 .5317 .3267 .53781 .3246 .53682 .32343 Metetra
.664 .741 .907 r
.53682 .32343 .53781 .3246 .54394 .3225 .54295 .32132 Metetra
.664 .741 .907 r
.54295 .32132 .54394 .3225 .55008 .32039 .54909 .31921 Metetra
.664 .741 .907 r
.54909 .31921 .55008 .32039 .55623 .31828 .55525 .3171 Metetra
.664 .741 .907 r
.55525 .3171 .55623 .31828 .56239 .31616 .56141 .31498 Metetra
.664 .741 .907 r
.56141 .31498 .56239 .31616 .56857 .31404 .5676 .31285 Metetra
.664 .741 .907 r
.5676 .31285 .56857 .31404 .57477 .31191 .57379 .31072 Metetra
.664 .741 .907 r
.57379 .31072 .57477 .31191 .58097 .30978 .58 .30859 Metetra
.664 .741 .907 r
.58 .30859 .58097 .30978 .58719 .30764 .58622 .30645 Metetra
.664 .741 .907 r
.58622 .30645 .58719 .30764 .59343 .3055 .59246 .3043 Metetra
.664 .741 .907 r
.59246 .3043 .59343 .3055 .59968 .30336 .59871 .30216 Metetra
.664 .741 .907 r
.59871 .30216 .59968 .30336 .60594 .3012 .60498 .3 Metetra
.664 .741 .907 r
.60498 .3 .60594 .3012 .61222 .29905 .61126 .29784 Metetra
.664 .741 .907 r
.61126 .29784 .61222 .29905 .61851 .29689 .61755 .29568 Metetra
.664 .741 .907 r
.61755 .29568 .61851 .29689 .62481 .29472 .62386 .29351 Metetra
.664 .741 .907 r
.62386 .29351 .62481 .29472 .63113 .29255 .63018 .29134 Metetra
.664 .741 .907 r
.63018 .29134 .63113 .29255 .63747 .29038 .63652 .28916 Metetra
.664 .741 .907 r
.63652 .28916 .63747 .29038 .64381 .2882 .64287 .28698 Metetra
.664 .741 .907 r
.64287 .28698 .64381 .2882 .65018 .28601 .64924 .28479 Metetra
.664 .741 .907 r
.64924 .28479 .65018 .28601 .65655 .28382 .65562 .2826 Metetra
.664 .741 .907 r
.65562 .2826 .65655 .28382 .66294 .28163 .66201 .2804 Metetra
.664 .741 .907 r
.66201 .2804 .66294 .28163 .66935 .27943 .66842 .2782 Metetra
.664 .741 .907 r
.66842 .2782 .66935 .27943 .67577 .27722 .67484 .27599 Metetra
.664 .741 .907 r
.67484 .27599 .67577 .27722 .68221 .27501 .68128 .27378 Metetra
.944 .585 .204 r
.68128 .27378 .68221 .27501 .68903 .27985 .68991 .31299 Metetra
.367 .174 .482 r
.68991 .31299 .68903 .27985 .69512 .27058 .6942 .26934 Metetra
.664 .741 .907 r
.6942 .26934 .69512 .27058 .70471 .32284 .70068 .26711 Metetra
.547 .333 .542 r
.70068 .26711 .70471 .32284 .70809 .26612 .70718 .26488 Metetra
.664 .741 .907 r
.70718 .26488 .70809 .26612 .7146 .26389 .71369 .26264 Metetra
.664 .741 .907 r
.71369 .26264 .7146 .26389 .72113 .26165 .72022 .2604 Metetra
.664 .741 .907 r
.72022 .2604 .72113 .26165 .72766 .2594 .72676 .25815 Metetra
.664 .741 .907 r
.72676 .25815 .72766 .2594 .73422 .25715 .73332 .2559 Metetra
.664 .741 .907 r
.73332 .2559 .73422 .25715 .74079 .2549 .73989 .25364 Metetra
.664 .741 .907 r
.73989 .25364 .74079 .2549 .74737 .25264 .74648 .25137 Metetra
.664 .741 .907 r
.74648 .25137 .74737 .25264 .75397 .25037 .75308 .2491 Metetra
.664 .741 .907 r
.75308 .2491 .75397 .25037 .76059 .2481 .7597 .24683 Metetra
.664 .741 .907 r
.7597 .24683 .76059 .2481 .76721 .24582 .76633 .24455 Metetra
.664 .741 .907 r
.76633 .24455 .76721 .24582 .77386 .24354 .77298 .24226 Metetra
.664 .741 .907 r
.77298 .24226 .77386 .24354 .78052 .24125 .77964 .23997 Metetra
.664 .741 .907 r
.77964 .23997 .78052 .24125 .7872 .23896 .78632 .23768 Metetra
.664 .741 .907 r
.78632 .23768 .7872 .23896 .79389 .23666 .79302 .23538 Metetra
.664 .741 .907 r
.79302 .23538 .79389 .23666 .80059 .23436 .79973 .23307 Metetra
.664 .741 .907 r
.79973 .23307 .80059 .23436 .80732 .23205 .80645 .23076 Metetra
.664 .741 .907 r
.80645 .23076 .80732 .23205 .81406 .22974 .81319 .22844 Metetra
.664 .741 .907 r
.81319 .22844 .81406 .22974 .82081 .22742 .81995 .22612 Metetra
.664 .741 .907 r
.81995 .22612 .82081 .22742 .82758 .22509 .82672 .22379 Metetra
.664 .741 .907 r
.82672 .22379 .82758 .22509 .83437 .22276 .83351 .22146 Metetra
.664 .741 .907 r
.2239 .42954 .22502 .43059 .23047 .42871 .22936 .42767 Metetra
.664 .741 .907 r
.22936 .42767 .23047 .42871 .23594 .42684 .23482 .42579 Metetra
.664 .741 .907 r
.23482 .42579 .23594 .42684 .24141 .42495 .2403 .4239 Metetra
.664 .741 .907 r
.2403 .4239 .24141 .42495 .2469 .42307 .24579 .42201 Metetra
.749 .257 0 r
.24579 .42201 .2469 .42307 .25196 .42645 .25055 .42892 Metetra
.25055 .42892 .25196 .42645 .25791 .41928 .25681 .41823 Metetra
.664 .741 .907 r
.25681 .41823 .25791 .41928 .26343 .41739 .26233 .41633 Metetra
.664 .741 .907 r
.26233 .41633 .26343 .41739 .26897 .41548 .26787 .41442 Metetra
.664 .741 .907 r
.26787 .41442 .26897 .41548 .27451 .41358 .27341 .41251 Metetra
.664 .741 .907 r
.27341 .41251 .27451 .41358 .28007 .41167 .27897 .4106 Metetra
.664 .741 .907 r
.27897 .4106 .28007 .41167 .28564 .40975 .28454 .40868 Metetra
.664 .741 .907 r
.28454 .40868 .28564 .40975 .29122 .40784 .29013 .40676 Metetra
.664 .741 .907 r
.29013 .40676 .29122 .40784 .29681 .40591 .29572 .40484 Metetra
.664 .741 .907 r
.29572 .40484 .29681 .40591 .30242 .40399 .30133 .40291 Metetra
.664 .741 .907 r
.30133 .40291 .30242 .40399 .30804 .40206 .30695 .40098 Metetra
.664 .741 .907 r
.30695 .40098 .30804 .40206 .31367 .40012 .31258 .39904 Metetra
.664 .741 .907 r
.31258 .39904 .31367 .40012 .31931 .39818 .31822 .3971 Metetra
.664 .741 .907 r
.31822 .3971 .31931 .39818 .32496 .39624 .32388 .39516 Metetra
.951 .67 .469 r
.32388 .39516 .32496 .39624 .32335 .51471 .3235 .4928 Metetra
.595 .385 .566 r
.3235 .4928 .32335 .51471 .32649 .5596 .32982 .48277 Metetra
.661 .425 .553 r
.32982 .48277 .32649 .5596 .34199 .39039 .34092 .38929 Metetra
.664 .741 .907 r
.34092 .38929 .34199 .39039 .34769 .38843 .34662 .38733 Metetra
.664 .741 .907 r
.34662 .38733 .34769 .38843 .35341 .38646 .35234 .38537 Metetra
.664 .741 .907 r
.35234 .38537 .35341 .38646 .35913 .3845 .35806 .3834 Metetra
.664 .741 .907 r
.35806 .3834 .35913 .3845 .36487 .38252 .3638 .38142 Metetra
.664 .741 .907 r
.3638 .38142 .36487 .38252 .37062 .38055 .36956 .37944 Metetra
.664 .741 .907 r
.36956 .37944 .37062 .38055 .37638 .37857 .37532 .37746 Metetra
.664 .741 .907 r
.37532 .37746 .37638 .37857 .38216 .37658 .3811 .37547 Metetra
.664 .741 .907 r
.3811 .37547 .38216 .37658 .38795 .37459 .38689 .37348 Metetra
.664 .741 .907 r
.38689 .37348 .38795 .37459 .39375 .3726 .39269 .37149 Metetra
.664 .741 .907 r
.39269 .37149 .39375 .3726 .39956 .3706 .39851 .36949 Metetra
.664 .741 .907 r
.39851 .36949 .39956 .3706 .40539 .3686 .40434 .36748 Metetra
.664 .741 .907 r
.40434 .36748 .40539 .3686 .41122 .36659 .41018 .36547 Metetra
.664 .741 .907 r
.41018 .36547 .41122 .36659 .41708 .36458 .41603 .36346 Metetra
.664 .741 .907 r
.41603 .36346 .41708 .36458 .42294 .36257 .4219 .36144 Metetra
.664 .741 .907 r
.4219 .36144 .42294 .36257 .42882 .36055 .42778 .35942 Metetra
.664 .741 .907 r
.42778 .35942 .42882 .36055 .4347 .35852 .43367 .35739 Metetra
.664 .741 .907 r
.43367 .35739 .4347 .35852 .44061 .35649 .43957 .35536 Metetra
.664 .741 .907 r
.43957 .35536 .44061 .35649 .44652 .35446 .44549 .35333 Metetra
.664 .741 .907 r
.44549 .35333 .44652 .35446 .45245 .35242 .45142 .35129 Metetra
.664 .741 .907 r
.45142 .35129 .45245 .35242 .45839 .35038 .45736 .34924 Metetra
.664 .741 .907 r
.45736 .34924 .45839 .35038 .46434 .34834 .46332 .34719 Metetra
.664 .741 .907 r
.46332 .34719 .46434 .34834 .47031 .34629 .46929 .34514 Metetra
.664 .741 .907 r
.46929 .34514 .47031 .34629 .47629 .34423 .47527 .34308 Metetra
.664 .741 .907 r
.47527 .34308 .47629 .34423 .48228 .34217 .48127 .34102 Metetra
.664 .741 .907 r
.48127 .34102 .48228 .34217 .48829 .34011 .48728 .33895 Metetra
.664 .741 .907 r
.48728 .33895 .48829 .34011 .49431 .33804 .4933 .33688 Metetra
.664 .741 .907 r
.4933 .33688 .49431 .33804 .50034 .33596 .49934 .33481 Metetra
.827 .382 0 r
.49934 .33481 .50034 .33596 .50624 .35928 .5053 .34682 Metetra
.647 .438 .586 r
.5053 .34682 .50624 .35928 .51229 .37108 .51143 .33388 Metetra
.559 .347 .549 r
.51143 .33388 .51229 .37108 .51852 .32972 .51752 .32855 Metetra
.664 .741 .907 r
.51752 .32855 .51852 .32972 .52461 .32762 .52361 .32646 Metetra
.664 .741 .907 r
.52361 .32646 .52461 .32762 .53071 .32553 .52971 .32436 Metetra
.664 .741 .907 r
.52971 .32436 .53071 .32553 .53682 .32343 .53583 .32225 Metetra
.664 .741 .907 r
.53583 .32225 .53682 .32343 .54295 .32132 .54196 .32014 Metetra
.664 .741 .907 r
.54196 .32014 .54295 .32132 .54909 .31921 .5481 .31803 Metetra
.664 .741 .907 r
.5481 .31803 .54909 .31921 .55525 .3171 .55426 .31591 Metetra
.664 .741 .907 r
.55426 .31591 .55525 .3171 .56141 .31498 .56043 .31379 Metetra
.664 .741 .907 r
.56043 .31379 .56141 .31498 .5676 .31285 .56662 .31166 Metetra
.664 .741 .907 r
.56662 .31166 .5676 .31285 .57379 .31072 .57282 .30953 Metetra
.664 .741 .907 r
.57282 .30953 .57379 .31072 .58 .30859 .57903 .30739 Metetra
.664 .741 .907 r
.57903 .30739 .58 .30859 .58622 .30645 .58525 .30525 Metetra
.664 .741 .907 r
.58525 .30525 .58622 .30645 .59246 .3043 .59149 .30311 Metetra
.664 .741 .907 r
.59149 .30311 .59246 .3043 .59871 .30216 .59775 .30096 Metetra
.664 .741 .907 r
.59775 .30096 .59871 .30216 .60498 .3 .60402 .2988 Metetra
.664 .741 .907 r
.60402 .2988 .60498 .3 .61126 .29784 .6103 .29664 Metetra
.664 .741 .907 r
.6103 .29664 .61126 .29784 .61755 .29568 .6166 .29447 Metetra
.664 .741 .907 r
.6166 .29447 .61755 .29568 .62386 .29351 .62291 .2923 Metetra
.664 .741 .907 r
.62291 .2923 .62386 .29351 .63018 .29134 .62923 .29013 Metetra
.664 .741 .907 r
.62923 .29013 .63018 .29134 .63652 .28916 .63557 .28795 Metetra
.664 .741 .907 r
.63557 .28795 .63652 .28916 .64287 .28698 .64193 .28576 Metetra
.664 .741 .907 r
.64193 .28576 .64287 .28698 .64924 .28479 .64829 .28357 Metetra
.664 .741 .907 r
.64829 .28357 .64924 .28479 .65562 .2826 .65468 .28137 Metetra
.664 .741 .907 r
.65468 .28137 .65562 .2826 .66201 .2804 .66107 .27917 Metetra
.664 .741 .907 r
.66107 .27917 .66201 .2804 .66842 .2782 .66749 .27697 Metetra
.664 .741 .907 r
.66749 .27697 .66842 .2782 .67484 .27599 .67391 .27476 Metetra
.664 .741 .907 r
.67391 .27476 .67484 .27599 .68128 .27378 .68035 .27254 Metetra
.897 .504 .071 r
.68035 .27254 .68128 .27378 .68991 .31299 .68817 .29629 Metetra
.69 .458 .567 r
.68817 .29629 .68991 .31299 .6942 .26934 .69328 .2681 Metetra
.664 .741 .907 r
.69328 .2681 .6942 .26934 .70068 .26711 .69977 .26587 Metetra
.664 .741 .907 r
.69977 .26587 .70068 .26711 .70718 .26488 .70627 .26363 Metetra
.664 .741 .907 r
.70627 .26363 .70718 .26488 .71369 .26264 .71278 .26139 Metetra
.664 .741 .907 r
.71278 .26139 .71369 .26264 .72022 .2604 .71931 .25914 Metetra
.664 .741 .907 r
.71931 .25914 .72022 .2604 .72676 .25815 .72586 .25689 Metetra
.664 .741 .907 r
.72586 .25689 .72676 .25815 .73332 .2559 .73242 .25464 Metetra
.664 .741 .907 r
.73242 .25464 .73332 .2559 .73989 .25364 .73899 .25237 Metetra
.664 .741 .907 r
.73899 .25237 .73989 .25364 .74648 .25137 .74558 .25011 Metetra
.664 .741 .907 r
.74558 .25011 .74648 .25137 .75308 .2491 .75219 .24784 Metetra
.664 .741 .907 r
.75219 .24784 .75308 .2491 .7597 .24683 .75881 .24556 Metetra
.664 .741 .907 r
.75881 .24556 .7597 .24683 .76633 .24455 .76544 .24328 Metetra
.664 .741 .907 r
.76544 .24328 .76633 .24455 .77298 .24226 .7721 .24099 Metetra
.664 .741 .907 r
.7721 .24099 .77298 .24226 .77964 .23997 .77876 .23869 Metetra
.664 .741 .907 r
.77876 .23869 .77964 .23997 .78632 .23768 .78545 .2364 Metetra
.664 .741 .907 r
.78545 .2364 .78632 .23768 .79302 .23538 .79214 .23409 Metetra
.664 .741 .907 r
.79214 .23409 .79302 .23538 .79973 .23307 .79886 .23178 Metetra
.664 .741 .907 r
.79886 .23178 .79973 .23307 .80645 .23076 .80559 .22947 Metetra
.664 .741 .907 r
.80559 .22947 .80645 .23076 .81319 .22844 .81233 .22715 Metetra
.664 .741 .907 r
.81233 .22715 .81319 .22844 .81995 .22612 .81909 .22482 Metetra
.664 .741 .907 r
.81909 .22482 .81995 .22612 .82672 .22379 .82587 .22249 Metetra
.664 .741 .907 r
.82587 .22249 .82672 .22379 .83351 .22146 .83266 .22016 Metetra
.664 .741 .907 r
.22278 .4285 .2239 .42954 .22936 .42767 .22824 .42662 Metetra
.664 .741 .907 r
.22824 .42662 .22936 .42767 .23482 .42579 .23371 .42474 Metetra
.664 .741 .907 r
.23371 .42474 .23482 .42579 .2403 .4239 .23919 .42285 Metetra
.945 .641 .429 r
.23919 .42285 .2403 .4239 .24579 .42201 .24147 .45816 Metetra
.361 .155 .46 r
.24147 .45816 .24579 .42201 .25055 .42892 .25018 .41906 Metetra
.571 .39 .597 r
.25018 .41906 .25055 .42892 .25681 .41823 .2557 .41717 Metetra
.664 .741 .907 r
.2557 .41717 .25681 .41823 .26233 .41633 .26122 .41526 Metetra
.664 .741 .907 r
.26122 .41526 .26233 .41633 .26787 .41442 .26676 .41336 Metetra
.664 .741 .907 r
.26676 .41336 .26787 .41442 .27341 .41251 .27231 .41145 Metetra
.664 .741 .907 r
.27231 .41145 .27341 .41251 .27897 .4106 .27787 .40953 Metetra
.664 .741 .907 r
.27787 .40953 .27897 .4106 .28454 .40868 .28345 .40761 Metetra
.664 .741 .907 r
.28345 .40761 .28454 .40868 .29013 .40676 .28903 .40569 Metetra
.664 .741 .907 r
.28903 .40569 .29013 .40676 .29572 .40484 .29463 .40376 Metetra
.664 .741 .907 r
.29463 .40376 .29572 .40484 .30133 .40291 .30024 .40183 Metetra
.664 .741 .907 r
.30024 .40183 .30133 .40291 .30695 .40098 .30586 .3999 Metetra
.664 .741 .907 r
.30586 .3999 .30695 .40098 .31258 .39904 .31149 .39796 Metetra
.664 .741 .907 r
.31149 .39796 .31258 .39904 .31822 .3971 .31714 .39602 Metetra
.664 .741 .907 r
.31714 .39602 .31822 .3971 .32388 .39516 .3228 .39407 Metetra
0 .209 .703 r
.3228 .39407 .32388 .39516 .3235 .4928 .32811 .39798 Metetra
.446 .247 .516 r
.32811 .39798 .3235 .4928 .32982 .48277 .32991 .46146 Metetra
.77 .529 .569 r
.32991 .46146 .32982 .48277 .34092 .38929 .33984 .3882 Metetra
.664 .741 .907 r
.33984 .3882 .34092 .38929 .34662 .38733 .34555 .38624 Metetra
.664 .741 .907 r
.34555 .38624 .34662 .38733 .35234 .38537 .35127 .38427 Metetra
.664 .741 .907 r
.35127 .38427 .35234 .38537 .35806 .3834 .357 .3823 Metetra
.664 .741 .907 r
.357 .3823 .35806 .3834 .3638 .38142 .36274 .38032 Metetra
.664 .741 .907 r
.36274 .38032 .3638 .38142 .36956 .37944 .36849 .37834 Metetra
.664 .741 .907 r
.36849 .37834 .36956 .37944 .37532 .37746 .37426 .37635 Metetra
.664 .741 .907 r
.37426 .37635 .37532 .37746 .3811 .37547 .38004 .37436 Metetra
.664 .741 .907 r
.38004 .37436 .3811 .37547 .38689 .37348 .38583 .37237 Metetra
.664 .741 .907 r
.38583 .37237 .38689 .37348 .39269 .37149 .39164 .37037 Metetra
.664 .741 .907 r
.39164 .37037 .39269 .37149 .39851 .36949 .39746 .36837 Metetra
.664 .741 .907 r
.39746 .36837 .39851 .36949 .40434 .36748 .40329 .36636 Metetra
.664 .741 .907 r
.40329 .36636 .40434 .36748 .41018 .36547 .40913 .36435 Metetra
.664 .741 .907 r
.40913 .36435 .41018 .36547 .41603 .36346 .41499 .36233 Metetra
.664 .741 .907 r
.41499 .36233 .41603 .36346 .4219 .36144 .42085 .36031 Metetra
.664 .741 .907 r
.42085 .36031 .4219 .36144 .42778 .35942 .42674 .35829 Metetra
.664 .741 .907 r
.42674 .35829 .42778 .35942 .43367 .35739 .43263 .35626 Metetra
.664 .741 .907 r
.43263 .35626 .43367 .35739 .43957 .35536 .43854 .35423 Metetra
.664 .741 .907 r
.43854 .35423 .43957 .35536 .44549 .35333 .44446 .35219 Metetra
.664 .741 .907 r
.44446 .35219 .44549 .35333 .45142 .35129 .45039 .35015 Metetra
.664 .741 .907 r
.45039 .35015 .45142 .35129 .45736 .34924 .45634 .3481 Metetra
.664 .741 .907 r
.45634 .3481 .45736 .34924 .46332 .34719 .4623 .34605 Metetra
.664 .741 .907 r
.4623 .34605 .46332 .34719 .46929 .34514 .46827 .34399 Metetra
.664 .741 .907 r
.46827 .34399 .46929 .34514 .47527 .34308 .47425 .34193 Metetra
.664 .741 .907 r
.47425 .34193 .47527 .34308 .48127 .34102 .48025 .33987 Metetra
.664 .741 .907 r
.48025 .33987 .48127 .34102 .48728 .33895 .48626 .3378 Metetra
.664 .741 .907 r
.48626 .3378 .48728 .33895 .4933 .33688 .49229 .33572 Metetra
.664 .741 .907 r
.49229 .33572 .4933 .33688 .49934 .33481 .49833 .33365 Metetra
.664 .741 .907 r
.49833 .33365 .49934 .33481 .5053 .34682 .50438 .33156 Metetra
.561 .367 .575 r
.50438 .33156 .5053 .34682 .51143 .33388 .51044 .32947 Metetra
.604 .474 .677 r
.51044 .32947 .51143 .33388 .51752 .32855 .51652 .32738 Metetra
.664 .741 .907 r
.51652 .32738 .51752 .32855 .52361 .32646 .52261 .32529 Metetra
.664 .741 .907 r
.52261 .32529 .52361 .32646 .52971 .32436 .52872 .32318 Metetra
.664 .741 .907 r
.52872 .32318 .52971 .32436 .53583 .32225 .53484 .32108 Metetra
.664 .741 .907 r
.53484 .32108 .53583 .32225 .54196 .32014 .54097 .31897 Metetra
.664 .741 .907 r
.54097 .31897 .54196 .32014 .5481 .31803 .54712 .31685 Metetra
.664 .741 .907 r
.54712 .31685 .5481 .31803 .55426 .31591 .55328 .31473 Metetra
.664 .741 .907 r
.55328 .31473 .55426 .31591 .56043 .31379 .55945 .31261 Metetra
.664 .741 .907 r
.55945 .31261 .56043 .31379 .56662 .31166 .56564 .31048 Metetra
.664 .741 .907 r
.56564 .31048 .56662 .31166 .57282 .30953 .57184 .30834 Metetra
.664 .741 .907 r
.57184 .30834 .57282 .30953 .57903 .30739 .57805 .3062 Metetra
.664 .741 .907 r
.57805 .3062 .57903 .30739 .58525 .30525 .58428 .30406 Metetra
.664 .741 .907 r
.58428 .30406 .58525 .30525 .59149 .30311 .59053 .30191 Metetra
.664 .741 .907 r
.59053 .30191 .59149 .30311 .59775 .30096 .59678 .29975 Metetra
.664 .741 .907 r
.59678 .29975 .59775 .30096 .60402 .2988 .60305 .29759 Metetra
.664 .741 .907 r
.60305 .29759 .60402 .2988 .6103 .29664 .60934 .29543 Metetra
.664 .741 .907 r
.60934 .29543 .6103 .29664 .6166 .29447 .61564 .29326 Metetra
.664 .741 .907 r
.61564 .29326 .6166 .29447 .62291 .2923 .62195 .29109 Metetra
.664 .741 .907 r
.62195 .29109 .62291 .2923 .62923 .29013 .62828 .28891 Metetra
.664 .741 .907 r
.62828 .28891 .62923 .29013 .63557 .28795 .63462 .28673 Metetra
.664 .741 .907 r
.63462 .28673 .63557 .28795 .64193 .28576 .64098 .28454 Metetra
.664 .741 .907 r
.64098 .28454 .64193 .28576 .64829 .28357 .64735 .28235 Metetra
.664 .741 .907 r
.64735 .28235 .64829 .28357 .65468 .28137 .65374 .28015 Metetra
.664 .741 .907 r
.65374 .28015 .65468 .28137 .66107 .27917 .66014 .27794 Metetra
.664 .741 .907 r
.66014 .27794 .66107 .27917 .66749 .27697 .66655 .27574 Metetra
.664 .741 .907 r
.66655 .27574 .66749 .27697 .67391 .27476 .67298 .27352 Metetra
.664 .741 .907 r
.67298 .27352 .67391 .27476 .68035 .27254 .67943 .27131 Metetra
.664 .741 .907 r
.67943 .27131 .68035 .27254 .68817 .29629 .68588 .26908 Metetra
.553 .347 .555 r
.68588 .26908 .68817 .29629 .69328 .2681 .69236 .26685 Metetra
.664 .741 .907 r
.69236 .26685 .69328 .2681 .69977 .26587 .69885 .26462 Metetra
.664 .741 .907 r
.69885 .26462 .69977 .26587 .70627 .26363 .70535 .26238 Metetra
.664 .741 .907 r
.70535 .26238 .70627 .26363 .71278 .26139 .71187 .26014 Metetra
.664 .741 .907 r
.71187 .26014 .71278 .26139 .71931 .25914 .7184 .25789 Metetra
.664 .741 .907 r
.7184 .25789 .71931 .25914 .72586 .25689 .72495 .25563 Metetra
.664 .741 .907 r
.72495 .25563 .72586 .25689 .73242 .25464 .73151 .25338 Metetra
.664 .741 .907 r
.73151 .25338 .73242 .25464 .73899 .25237 .73809 .25111 Metetra
.664 .741 .907 r
.73809 .25111 .73899 .25237 .74558 .25011 .74468 .24884 Metetra
.664 .741 .907 r
.74468 .24884 .74558 .25011 .75219 .24784 .75129 .24657 Metetra
.664 .741 .907 r
.75129 .24657 .75219 .24784 .75881 .24556 .75792 .24429 Metetra
.664 .741 .907 r
.75792 .24429 .75881 .24556 .76544 .24328 .76456 .242 Metetra
.664 .741 .907 r
.76456 .242 .76544 .24328 .7721 .24099 .77121 .23971 Metetra
.664 .741 .907 r
.77121 .23971 .7721 .24099 .77876 .23869 .77788 .23741 Metetra
.664 .741 .907 r
.77788 .23741 .77876 .23869 .78545 .2364 .78457 .23511 Metetra
.664 .741 .907 r
.78457 .23511 .78545 .2364 .79214 .23409 .79127 .2328 Metetra
.664 .741 .907 r
.79127 .2328 .79214 .23409 .79886 .23178 .79799 .23049 Metetra
.664 .741 .907 r
.79799 .23049 .79886 .23178 .80559 .22947 .80472 .22817 Metetra
.664 .741 .907 r
.80472 .22817 .80559 .22947 .81233 .22715 .81147 .22585 Metetra
.664 .741 .907 r
.81147 .22585 .81233 .22715 .81909 .22482 .81823 .22352 Metetra
.664 .741 .907 r
.81823 .22352 .81909 .22482 .82587 .22249 .82501 .22119 Metetra
.664 .741 .907 r
.82501 .22119 .82587 .22249 .83266 .22016 .83181 .21885 Metetra
.664 .741 .907 r
.22166 .42745 .22278 .4285 .22824 .42662 .22712 .42557 Metetra
.664 .741 .907 r
.22712 .42557 .22824 .42662 .23371 .42474 .23259 .42368 Metetra
.664 .741 .907 r
.23259 .42368 .23371 .42474 .23919 .42285 .23807 .4218 Metetra
.945 .648 .444 r
.23807 .4218 .23919 .42285 .24147 .45816 .23984 .46285 Metetra
.998 .833 .499 r
.23984 .46285 .24147 .45816 .25018 .41906 .24907 .41801 Metetra
.664 .741 .907 r
.24907 .41801 .25018 .41906 .2557 .41717 .25459 .41611 Metetra
.664 .741 .907 r
.25459 .41611 .2557 .41717 .26122 .41526 .26012 .4142 Metetra
.664 .741 .907 r
.26012 .4142 .26122 .41526 .26676 .41336 .26566 .41229 Metetra
.664 .741 .907 r
.26566 .41229 .26676 .41336 .27231 .41145 .27121 .41038 Metetra
.664 .741 .907 r
.27121 .41038 .27231 .41145 .27787 .40953 .27677 .40846 Metetra
.664 .741 .907 r
.27677 .40846 .27787 .40953 .28345 .40761 .28235 .40654 Metetra
.664 .741 .907 r
.28235 .40654 .28345 .40761 .28903 .40569 .28794 .40462 Metetra
.664 .741 .907 r
.28794 .40462 .28903 .40569 .29463 .40376 .29354 .40269 Metetra
.664 .741 .907 r
.29354 .40269 .29463 .40376 .30024 .40183 .29915 .40075 Metetra
.664 .741 .907 r
.29915 .40075 .30024 .40183 .30586 .3999 .30477 .39882 Metetra
.664 .741 .907 r
.30477 .39882 .30586 .3999 .31149 .39796 .31041 .39688 Metetra
.664 .741 .907 r
.31041 .39688 .31149 .39796 .31714 .39602 .31605 .39493 Metetra
.664 .741 .907 r
.31605 .39493 .31714 .39602 .3228 .39407 .32171 .39298 Metetra
.664 .741 .907 r
.32171 .39298 .3228 .39407 .32811 .39798 .32738 .39103 Metetra
.583 .418 .624 r
.32738 .39103 .32811 .39798 .32991 .46146 .33307 .38907 Metetra
.545 .329 .538 r
.33307 .38907 .32991 .46146 .33984 .3882 .33876 .38711 Metetra
.664 .741 .907 r
.33876 .38711 .33984 .3882 .34555 .38624 .34447 .38514 Metetra
.911 .506 .156 r
.34447 .38514 .34555 .38624 .35127 .38427 .34932 .39913 Metetra
.593 .336 .496 r
.34932 .39913 .35127 .38427 .357 .3823 .35454 .40755 Metetra
.363 .154 .456 r
.35454 .40755 .357 .3823 .36274 .38032 .36167 .37921 Metetra
.664 .741 .907 r
.36167 .37921 .36274 .38032 .36849 .37834 .36743 .37723 Metetra
.664 .741 .907 r
.36743 .37723 .36849 .37834 .37426 .37635 .3732 .37524 Metetra
.664 .741 .907 r
.3732 .37524 .37426 .37635 .38004 .37436 .37898 .37325 Metetra
.664 .741 .907 r
.37898 .37325 .38004 .37436 .38583 .37237 .38478 .37125 Metetra
.664 .741 .907 r
.38478 .37125 .38583 .37237 .39164 .37037 .39058 .36925 Metetra
.664 .741 .907 r
.39058 .36925 .39164 .37037 .39746 .36837 .3964 .36725 Metetra
.664 .741 .907 r
.3964 .36725 .39746 .36837 .40329 .36636 .40224 .36524 Metetra
.664 .741 .907 r
.40224 .36524 .40329 .36636 .40913 .36435 .40808 .36323 Metetra
.664 .741 .907 r
.40808 .36323 .40913 .36435 .41499 .36233 .41394 .36121 Metetra
.664 .741 .907 r
.41394 .36121 .41499 .36233 .42085 .36031 .41981 .35918 Metetra
.664 .741 .907 r
.41981 .35918 .42085 .36031 .42674 .35829 .4257 .35716 Metetra
.664 .741 .907 r
.4257 .35716 .42674 .35829 .43263 .35626 .43159 .35513 Metetra
.664 .741 .907 r
.43159 .35513 .43263 .35626 .43854 .35423 .4375 .35309 Metetra
.664 .741 .907 r
.4375 .35309 .43854 .35423 .44446 .35219 .44342 .35105 Metetra
.664 .741 .907 r
.44342 .35105 .44446 .35219 .45039 .35015 .44936 .34901 Metetra
.664 .741 .907 r
.44936 .34901 .45039 .35015 .45634 .3481 .45531 .34696 Metetra
.664 .741 .907 r
.45531 .34696 .45634 .3481 .4623 .34605 .46127 .3449 Metetra
.664 .741 .907 r
.46127 .3449 .4623 .34605 .46827 .34399 .46724 .34284 Metetra
.664 .741 .907 r
.46724 .34284 .46827 .34399 .47425 .34193 .47323 .34078 Metetra
.664 .741 .907 r
.47323 .34078 .47425 .34193 .48025 .33987 .47923 .33871 Metetra
.664 .741 .907 r
.47923 .33871 .48025 .33987 .48626 .3378 .48525 .33664 Metetra
.664 .741 .907 r
.48525 .33664 .48626 .3378 .49229 .33572 .49127 .33457 Metetra
.664 .741 .907 r
.49127 .33457 .49229 .33572 .49833 .33365 .49731 .33248 Metetra
.664 .741 .907 r
.49731 .33248 .49833 .33365 .50438 .33156 .50337 .3304 Metetra
.664 .741 .907 r
.50337 .3304 .50438 .33156 .51044 .32947 .50944 .32831 Metetra
.664 .741 .907 r
.50944 .32831 .51044 .32947 .51652 .32738 .51552 .32621 Metetra
.664 .741 .907 r
.51552 .32621 .51652 .32738 .52261 .32529 .52161 .32411 Metetra
.664 .741 .907 r
.52161 .32411 .52261 .32529 .52872 .32318 .52772 .32201 Metetra
.664 .741 .907 r
.52772 .32201 .52872 .32318 .53484 .32108 .53384 .3199 Metetra
.664 .741 .907 r
.53384 .3199 .53484 .32108 .54097 .31897 .53998 .31779 Metetra
.664 .741 .907 r
.53998 .31779 .54097 .31897 .54712 .31685 .54613 .31567 Metetra
.953 .603 .271 r
.54613 .31567 .54712 .31685 .55328 .31473 .55261 .35004 Metetra
.389 .187 .481 r
.55261 .35004 .55328 .31473 .55945 .31261 .55846 .31142 Metetra
.664 .741 .907 r
.55846 .31142 .55945 .31261 .56564 .31048 .56465 .30929 Metetra
.664 .741 .907 r
.56465 .30929 .56564 .31048 .57184 .30834 .57086 .30715 Metetra
.664 .741 .907 r
.57086 .30715 .57184 .30834 .57805 .3062 .57708 .30501 Metetra
.664 .741 .907 r
.57708 .30501 .57805 .3062 .58428 .30406 .58331 .30286 Metetra
.664 .741 .907 r
.58331 .30286 .58428 .30406 .59053 .30191 .58955 .30071 Metetra
.664 .741 .907 r
.58955 .30071 .59053 .30191 .59678 .29975 .59582 .29855 Metetra
.664 .741 .907 r
.59582 .29855 .59678 .29975 .60305 .29759 .60209 .29639 Metetra
.664 .741 .907 r
.60209 .29639 .60305 .29759 .60934 .29543 .60838 .29422 Metetra
.664 .741 .907 r
.60838 .29422 .60934 .29543 .61564 .29326 .61468 .29205 Metetra
.664 .741 .907 r
.61468 .29205 .61564 .29326 .62195 .29109 .621 .28987 Metetra
.664 .741 .907 r
.621 .28987 .62195 .29109 .62828 .28891 .62733 .28769 Metetra
.664 .741 .907 r
.62733 .28769 .62828 .28891 .63462 .28673 .63367 .28551 Metetra
.664 .741 .907 r
.63367 .28551 .63462 .28673 .64098 .28454 .64003 .28332 Metetra
.664 .741 .907 r
.64003 .28332 .64098 .28454 .64735 .28235 .64641 .28112 Metetra
.664 .741 .907 r
.64641 .28112 .64735 .28235 .65374 .28015 .6528 .27892 Metetra
.664 .741 .907 r
.6528 .27892 .65374 .28015 .66014 .27794 .6592 .27671 Metetra
.664 .741 .907 r
.6592 .27671 .66014 .27794 .66655 .27574 .66562 .2745 Metetra
.664 .741 .907 r
.66562 .2745 .66655 .27574 .67298 .27352 .67205 .27229 Metetra
.664 .741 .907 r
.67205 .27229 .67298 .27352 .67943 .27131 .6785 .27007 Metetra
.664 .741 .907 r
.6785 .27007 .67943 .27131 .68588 .26908 .68496 .26784 Metetra
.664 .741 .907 r
.68496 .26784 .68588 .26908 .69236 .26685 .69144 .26561 Metetra
.664 .741 .907 r
.69144 .26561 .69236 .26685 .69885 .26462 .69793 .26337 Metetra
.664 .741 .907 r
.69793 .26337 .69885 .26462 .70535 .26238 .70443 .26113 Metetra
.664 .741 .907 r
.70443 .26113 .70535 .26238 .71187 .26014 .71095 .25888 Metetra
.664 .741 .907 r
.71095 .25888 .71187 .26014 .7184 .25789 .71749 .25663 Metetra
.664 .741 .907 r
.71749 .25663 .7184 .25789 .72495 .25563 .72404 .25437 Metetra
.664 .741 .907 r
.72404 .25437 .72495 .25563 .73151 .25338 .73061 .25211 Metetra
.664 .741 .907 r
.73061 .25211 .73151 .25338 .73809 .25111 .73719 .24985 Metetra
.664 .741 .907 r
.73719 .24985 .73809 .25111 .74468 .24884 .74379 .24757 Metetra
.664 .741 .907 r
.74379 .24757 .74468 .24884 .75129 .24657 .7504 .24529 Metetra
.664 .741 .907 r
.7504 .24529 .75129 .24657 .75792 .24429 .75703 .24301 Metetra
.664 .741 .907 r
.75703 .24301 .75792 .24429 .76456 .242 .76367 .24072 Metetra
.38 .597 .932 r
.76367 .24072 .76456 .242 .77121 .23971 .77061 .24192 Metetra
.141 0 .106 r
.77061 .24192 .77121 .23971 .77788 .23741 .777 .23613 Metetra
.664 .741 .907 r
.777 .23613 .77788 .23741 .78457 .23511 .78369 .23383 Metetra
.664 .741 .907 r
.78369 .23383 .78457 .23511 .79127 .2328 .7904 .23152 Metetra
.664 .741 .907 r
.7904 .23152 .79127 .2328 .79799 .23049 .79712 .2292 Metetra
.664 .741 .907 r
.79712 .2292 .79799 .23049 .80472 .22817 .80385 .22688 Metetra
.664 .741 .907 r
.80385 .22688 .80472 .22817 .81147 .22585 .8106 .22455 Metetra
.664 .741 .907 r
.8106 .22455 .81147 .22585 .81823 .22352 .81737 .22222 Metetra
.664 .741 .907 r
.81737 .22222 .81823 .22352 .82501 .22119 .82415 .21989 Metetra
.664 .741 .907 r
.82415 .21989 .82501 .22119 .83181 .21885 .83095 .21754 Metetra
.664 .741 .907 r
.22054 .4264 .22166 .42745 .22712 .42557 .226 .42452 Metetra
.664 .741 .907 r
.226 .42452 .22712 .42557 .23259 .42368 .23147 .42263 Metetra
.664 .741 .907 r
.23147 .42263 .23259 .42368 .23807 .4218 .23696 .42074 Metetra
.664 .741 .907 r
.23696 .42074 .23807 .4218 .23984 .46285 .24245 .41885 Metetra
.547 .335 .544 r
.24245 .41885 .23984 .46285 .24907 .41801 .24796 .41695 Metetra
.664 .741 .907 r
.24796 .41695 .24907 .41801 .25459 .41611 .25348 .41504 Metetra
.664 .741 .907 r
.25348 .41504 .25459 .41611 .26012 .4142 .25901 .41314 Metetra
.664 .741 .907 r
.25901 .41314 .26012 .4142 .26566 .41229 .26455 .41123 Metetra
.664 .741 .907 r
.26455 .41123 .26566 .41229 .27121 .41038 .27011 .40931 Metetra
.664 .741 .907 r
.27011 .40931 .27121 .41038 .27677 .40846 .27567 .40739 Metetra
.664 .741 .907 r
.27567 .40739 .27677 .40846 .28235 .40654 .28125 .40547 Metetra
.664 .741 .907 r
.28125 .40547 .28235 .40654 .28794 .40462 .28684 .40354 Metetra
.664 .741 .907 r
.28684 .40354 .28794 .40462 .29354 .40269 .29244 .40161 Metetra
.664 .741 .907 r
.29244 .40161 .29354 .40269 .29915 .40075 .29805 .39967 Metetra
.664 .741 .907 r
.29805 .39967 .29915 .40075 .30477 .39882 .30368 .39773 Metetra
.664 .741 .907 r
.30368 .39773 .30477 .39882 .31041 .39688 .30932 .39579 Metetra
.664 .741 .907 r
.30932 .39579 .31041 .39688 .31605 .39493 .31497 .39384 Metetra
.664 .741 .907 r
.31497 .39384 .31605 .39493 .32171 .39298 .32063 .39189 Metetra
.664 .741 .907 r
.32063 .39189 .32171 .39298 .32738 .39103 .3263 .38993 Metetra
.664 .741 .907 r
.3263 .38993 .32738 .39103 .33307 .38907 .33199 .38797 Metetra
.664 .741 .907 r
.33199 .38797 .33307 .38907 .33876 .38711 .33769 .38601 Metetra
.664 .741 .907 r
.33769 .38601 .33876 .38711 .34447 .38514 .3434 .38404 Metetra
.952 .678 .48 r
.3434 .38404 .34447 .38514 .34932 .39913 .33941 .55905 Metetra
.466 .255 .508 r
.33941 .55905 .34932 .39913 .35454 .40755 .35003 .47094 Metetra
.29 .109 .453 r
.35003 .47094 .35454 .40755 .36167 .37921 .3606 .37811 Metetra
.664 .741 .907 r
.3606 .37811 .36167 .37921 .36743 .37723 .36636 .37612 Metetra
.664 .741 .907 r
.36636 .37612 .36743 .37723 .3732 .37524 .37213 .37413 Metetra
.664 .741 .907 r
.37213 .37413 .3732 .37524 .37898 .37325 .37792 .37214 Metetra
.664 .741 .907 r
.37792 .37214 .37898 .37325 .38478 .37125 .38372 .37014 Metetra
.664 .741 .907 r
.38372 .37014 .38478 .37125 .39058 .36925 .38953 .36814 Metetra
.664 .741 .907 r
.38953 .36814 .39058 .36925 .3964 .36725 .39535 .36613 Metetra
.664 .741 .907 r
.39535 .36613 .3964 .36725 .40224 .36524 .40118 .36412 Metetra
.664 .741 .907 r
.40118 .36412 .40224 .36524 .40808 .36323 .40703 .3621 Metetra
.664 .741 .907 r
.40703 .3621 .40808 .36323 .41394 .36121 .41289 .36008 Metetra
.664 .741 .907 r
.41289 .36008 .41394 .36121 .41981 .35918 .41877 .35805 Metetra
.664 .741 .907 r
.41877 .35805 .41981 .35918 .4257 .35716 .42465 .35603 Metetra
.664 .741 .907 r
.42465 .35603 .4257 .35716 .43159 .35513 .43055 .35399 Metetra
.664 .741 .907 r
.43055 .35399 .43159 .35513 .4375 .35309 .43646 .35195 Metetra
.664 .741 .907 r
.43646 .35195 .4375 .35309 .44342 .35105 .44239 .34991 Metetra
.664 .741 .907 r
.44239 .34991 .44342 .35105 .44936 .34901 .44833 .34786 Metetra
.664 .741 .907 r
.44833 .34786 .44936 .34901 .45531 .34696 .45428 .34581 Metetra
.664 .741 .907 r
.45428 .34581 .45531 .34696 .46127 .3449 .46024 .34375 Metetra
.664 .741 .907 r
.46024 .34375 .46127 .3449 .46724 .34284 .46622 .34169 Metetra
.664 .741 .907 r
.46622 .34169 .46724 .34284 .47323 .34078 .47221 .33963 Metetra
.664 .741 .907 r
.47221 .33963 .47323 .34078 .47923 .33871 .47821 .33756 Metetra
.664 .741 .907 r
.47821 .33756 .47923 .33871 .48525 .33664 .48423 .33548 Metetra
.664 .741 .907 r
.48423 .33548 .48525 .33664 .49127 .33457 .49026 .33341 Metetra
.664 .741 .907 r
.49026 .33341 .49127 .33457 .49731 .33248 .4963 .33132 Metetra
.664 .741 .907 r
.4963 .33132 .49731 .33248 .50337 .3304 .50236 .32923 Metetra
.664 .741 .907 r
.50236 .32923 .50337 .3304 .50944 .32831 .50843 .32714 Metetra
.664 .741 .907 r
.50843 .32714 .50944 .32831 .51552 .32621 .51451 .32504 Metetra
.664 .741 .907 r
.51451 .32504 .51552 .32621 .52161 .32411 .52061 .32294 Metetra
.664 .741 .907 r
.52061 .32294 .52161 .32411 .52772 .32201 .52672 .32083 Metetra
.664 .741 .907 r
.52672 .32083 .52772 .32201 .53384 .3199 .53284 .31872 Metetra
.664 .741 .907 r
.53284 .31872 .53384 .3199 .53998 .31779 .53898 .31661 Metetra
.664 .741 .907 r
.53898 .31661 .53998 .31779 .54613 .31567 .54513 .31449 Metetra
.968 .666 .393 r
.54513 .31449 .54613 .31567 .55261 .35004 .55232 .43298 Metetra
.32 .142 .477 r
.55232 .43298 .55261 .35004 .55846 .31142 .55748 .31023 Metetra
.664 .741 .907 r
.55748 .31023 .55846 .31142 .56465 .30929 .56367 .30809 Metetra
.664 .741 .907 r
.56367 .30809 .56465 .30929 .57086 .30715 .56988 .30595 Metetra
.664 .741 .907 r
.56988 .30595 .57086 .30715 .57708 .30501 .5761 .30381 Metetra
.664 .741 .907 r
.5761 .30381 .57708 .30501 .58331 .30286 .58233 .30166 Metetra
.664 .741 .907 r
.58233 .30166 .58331 .30286 .58955 .30071 .58858 .2995 Metetra
.664 .741 .907 r
.58858 .2995 .58955 .30071 .59582 .29855 .59485 .29735 Metetra
.664 .741 .907 r
.59485 .29735 .59582 .29855 .60209 .29639 .60112 .29518 Metetra
.664 .741 .907 r
.60112 .29518 .60209 .29639 .60838 .29422 .60741 .29301 Metetra
.664 .741 .907 r
.60741 .29301 .60838 .29422 .61468 .29205 .61372 .29084 Metetra
.664 .741 .907 r
.61372 .29084 .61468 .29205 .621 .28987 .62004 .28866 Metetra
.664 .741 .907 r
.62004 .28866 .621 .28987 .62733 .28769 .62637 .28648 Metetra
.664 .741 .907 r
.62637 .28648 .62733 .28769 .63367 .28551 .63272 .28429 Metetra
.664 .741 .907 r
.63272 .28429 .63367 .28551 .64003 .28332 .63908 .28209 Metetra
.664 .741 .907 r
.63908 .28209 .64003 .28332 .64641 .28112 .64546 .27989 Metetra
.664 .741 .907 r
.64546 .27989 .64641 .28112 .6528 .27892 .65185 .27769 Metetra
.664 .741 .907 r
.65185 .27769 .6528 .27892 .6592 .27671 .65826 .27548 Metetra
.664 .741 .907 r
.65826 .27548 .6592 .27671 .66562 .2745 .66468 .27327 Metetra
.664 .741 .907 r
.66468 .27327 .66562 .2745 .67205 .27229 .67112 .27105 Metetra
.664 .741 .907 r
.67112 .27105 .67205 .27229 .6785 .27007 .67757 .26882 Metetra
.664 .741 .907 r
.67757 .26882 .6785 .27007 .68496 .26784 .68403 .2666 Metetra
.664 .741 .907 r
.68403 .2666 .68496 .26784 .69144 .26561 .69051 .26436 Metetra
.664 .741 .907 r
.69051 .26436 .69144 .26561 .69793 .26337 .69701 .26212 Metetra
.664 .741 .907 r
.69701 .26212 .69793 .26337 .70443 .26113 .70352 .25988 Metetra
.664 .741 .907 r
.70352 .25988 .70443 .26113 .71095 .25888 .71004 .25763 Metetra
.664 .741 .907 r
.71004 .25763 .71095 .25888 .71749 .25663 .71658 .25537 Metetra
.664 .741 .907 r
.71658 .25537 .71749 .25663 .72404 .25437 .72313 .25311 Metetra
.664 .741 .907 r
.72313 .25311 .72404 .25437 .73061 .25211 .7297 .25085 Metetra
.664 .741 .907 r
.7297 .25085 .73061 .25211 .73719 .24985 .73629 .24858 Metetra
.664 .741 .907 r
.73629 .24858 .73719 .24985 .74379 .24757 .74289 .2463 Metetra
.664 .741 .907 r
.74289 .2463 .74379 .24757 .7504 .24529 .7495 .24402 Metetra
.664 .741 .907 r
.7495 .24402 .7504 .24529 .75703 .24301 .75613 .24174 Metetra
.664 .741 .907 r
.75613 .24174 .75703 .24301 .76367 .24072 .76278 .23944 Metetra
.952 .608 .222 r
.76278 .23944 .76367 .24072 .77061 .24192 .77492 .30574 Metetra
.404 .212 .503 r
.77492 .30574 .77061 .24192 .777 .23613 .77612 .23485 Metetra
.664 .741 .907 r
.77612 .23485 .777 .23613 .78369 .23383 .78281 .23254 Metetra
.664 .741 .907 r
.78281 .23254 .78369 .23383 .7904 .23152 .78952 .23023 Metetra
.664 .741 .907 r
.78952 .23023 .7904 .23152 .79712 .2292 .79624 .22791 Metetra
.664 .741 .907 r
.79624 .22791 .79712 .2292 .80385 .22688 .80298 .22558 Metetra
.664 .741 .907 r
.80298 .22558 .80385 .22688 .8106 .22455 .80974 .22325 Metetra
.664 .741 .907 r
.80974 .22325 .8106 .22455 .81737 .22222 .81651 .22092 Metetra
.664 .741 .907 r
.81651 .22092 .81737 .22222 .82415 .21989 .8233 .21858 Metetra
.664 .741 .907 r
.8233 .21858 .82415 .21989 .83095 .21754 .8301 .21623 Metetra
.664 .741 .907 r
.21941 .42535 .22054 .4264 .226 .42452 .22488 .42347 Metetra
.664 .741 .907 r
.22488 .42347 .226 .42452 .23147 .42263 .23035 .42158 Metetra
.664 .741 .907 r
.23035 .42158 .23147 .42263 .23696 .42074 .23584 .41968 Metetra
.664 .741 .907 r
.23584 .41968 .23696 .42074 .24245 .41885 .24134 .41779 Metetra
.664 .741 .907 r
.24134 .41779 .24245 .41885 .24796 .41695 .24684 .41589 Metetra
.664 .741 .907 r
.24684 .41589 .24796 .41695 .25348 .41504 .25237 .41398 Metetra
.664 .741 .907 r
.25237 .41398 .25348 .41504 .25901 .41314 .2579 .41207 Metetra
.664 .741 .907 r
.2579 .41207 .25901 .41314 .26455 .41123 .26344 .41016 Metetra
.664 .741 .907 r
.26344 .41016 .26455 .41123 .27011 .40931 .269 .40824 Metetra
.664 .741 .907 r
.269 .40824 .27011 .40931 .27567 .40739 .27457 .40632 Metetra
.664 .741 .907 r
.27457 .40632 .27567 .40739 .28125 .40547 .28015 .40439 Metetra
.664 .741 .907 r
.28015 .40439 .28125 .40547 .28684 .40354 .28574 .40246 Metetra
.664 .741 .907 r
.28574 .40246 .28684 .40354 .29244 .40161 .29134 .40053 Metetra
.664 .741 .907 r
.29134 .40053 .29244 .40161 .29805 .39967 .29696 .39859 Metetra
.664 .741 .907 r
.29696 .39859 .29805 .39967 .30368 .39773 .30259 .39665 Metetra
.664 .741 .907 r
.30259 .39665 .30368 .39773 .30932 .39579 .30823 .39471 Metetra
.664 .741 .907 r
.30823 .39471 .30932 .39579 .31497 .39384 .31388 .39276 Metetra
.664 .741 .907 r
.31388 .39276 .31497 .39384 .32063 .39189 .31954 .3908 Metetra
.664 .741 .907 r
.31954 .3908 .32063 .39189 .3263 .38993 .32522 .38884 Metetra
.664 .741 .907 r
.32522 .38884 .3263 .38993 .33199 .38797 .33091 .38688 Metetra
.664 .741 .907 r
.33091 .38688 .33199 .38797 .33769 .38601 .33661 .38491 Metetra
.664 .741 .907 r
.33661 .38491 .33769 .38601 .3434 .38404 .34232 .38294 Metetra
.952 .679 .482 r
.34232 .38294 .3434 .38404 .33941 .55905 .33682 .5843 Metetra
.94 .763 .294 r
.33682 .5843 .33941 .55905 .35003 .47094 .35228 .4071 Metetra
.594 .37 .546 r
.35228 .4071 .35003 .47094 .3606 .37811 .35953 .377 Metetra
.664 .741 .907 r
.35953 .377 .3606 .37811 .36636 .37612 .36529 .37501 Metetra
.664 .741 .907 r
.36529 .37501 .36636 .37612 .37213 .37413 .37107 .37302 Metetra
.664 .741 .907 r
.37107 .37302 .37213 .37413 .37792 .37214 .37686 .37102 Metetra
.664 .741 .907 r
.37686 .37102 .37792 .37214 .38372 .37014 .38266 .36902 Metetra
.664 .741 .907 r
.38266 .36902 .38372 .37014 .38953 .36814 .38847 .36702 Metetra
.664 .741 .907 r
.38847 .36702 .38953 .36814 .39535 .36613 .39429 .36501 Metetra
.664 .741 .907 r
.39429 .36501 .39535 .36613 .40118 .36412 .40013 .36299 Metetra
.664 .741 .907 r
.40013 .36299 .40118 .36412 .40703 .3621 .40598 .36097 Metetra
.664 .741 .907 r
.40598 .36097 .40703 .3621 .41289 .36008 .41184 .35895 Metetra
.664 .741 .907 r
.41184 .35895 .41289 .36008 .41877 .35805 .41772 .35692 Metetra
.664 .741 .907 r
.41772 .35692 .41877 .35805 .42465 .35603 .42361 .35489 Metetra
.664 .741 .907 r
.42361 .35489 .42465 .35603 .43055 .35399 .42951 .35286 Metetra
.664 .741 .907 r
.42951 .35286 .43055 .35399 .43646 .35195 .43542 .35081 Metetra
.664 .741 .907 r
.43542 .35081 .43646 .35195 .44239 .34991 .44135 .34877 Metetra
.664 .741 .907 r
.44135 .34877 .44239 .34991 .44833 .34786 .44729 .34672 Metetra
.664 .741 .907 r
.44729 .34672 .44833 .34786 .45428 .34581 .45325 .34466 Metetra
.664 .741 .907 r
.45325 .34466 .45428 .34581 .46024 .34375 .45921 .34261 Metetra
.664 .741 .907 r
.45921 .34261 .46024 .34375 .46622 .34169 .46519 .34054 Metetra
.664 .741 .907 r
.46519 .34054 .46622 .34169 .47221 .33963 .47118 .33847 Metetra
.664 .741 .907 r
.47118 .33847 .47221 .33963 .47821 .33756 .47719 .3364 Metetra
.664 .741 .907 r
.47719 .3364 .47821 .33756 .48423 .33548 .48321 .33433 Metetra
.664 .741 .907 r
.48321 .33433 .48423 .33548 .49026 .33341 .48924 .33224 Metetra
.664 .741 .907 r
.48924 .33224 .49026 .33341 .4963 .33132 .49529 .33016 Metetra
.664 .741 .907 r
.49529 .33016 .4963 .33132 .50236 .32923 .50135 .32807 Metetra
.664 .741 .907 r
.50135 .32807 .50236 .32923 .50843 .32714 .50742 .32597 Metetra
.664 .741 .907 r
.50742 .32597 .50843 .32714 .51451 .32504 .51351 .32387 Metetra
.664 .741 .907 r
.51351 .32387 .51451 .32504 .52061 .32294 .51961 .32177 Metetra
.664 .741 .907 r
.51961 .32177 .52061 .32294 .52672 .32083 .52572 .31966 Metetra
.664 .741 .907 r
.52572 .31966 .52672 .32083 .53284 .31872 .53185 .31754 Metetra
.664 .741 .907 r
.53185 .31754 .53284 .31872 .53898 .31661 .53799 .31542 Metetra
.894 .485 .075 r
.53799 .31542 .53898 .31661 .54513 .31449 .54426 .33265 Metetra
.677 .407 .505 r
.54426 .33265 .54513 .31449 .55232 .43298 .55074 .36367 Metetra
.621 .389 .544 r
.55074 .36367 .55232 .43298 .55748 .31023 .55649 .30904 Metetra
.664 .741 .907 r
.55649 .30904 .55748 .31023 .56367 .30809 .56269 .3069 Metetra
.664 .741 .907 r
.56269 .3069 .56367 .30809 .56988 .30595 .5689 .30476 Metetra
.664 .741 .907 r
.5689 .30476 .56988 .30595 .5761 .30381 .57512 .30261 Metetra
.664 .741 .907 r
.57512 .30261 .5761 .30381 .58233 .30166 .58136 .30046 Metetra
.664 .741 .907 r
.58136 .30046 .58233 .30166 .58858 .2995 .58761 .2983 Metetra
.664 .741 .907 r
.58761 .2983 .58858 .2995 .59485 .29735 .59388 .29614 Metetra
.664 .741 .907 r
.59388 .29614 .59485 .29735 .60112 .29518 .60016 .29397 Metetra
.664 .741 .907 r
.60016 .29397 .60112 .29518 .60741 .29301 .60645 .2918 Metetra
.664 .741 .907 r
.60645 .2918 .60741 .29301 .61372 .29084 .61276 .28962 Metetra
.664 .741 .907 r
.61276 .28962 .61372 .29084 .62004 .28866 .61908 .28744 Metetra
.664 .741 .907 r
.61908 .28744 .62004 .28866 .62637 .28648 .62542 .28525 Metetra
.664 .741 .907 r
.62542 .28525 .62637 .28648 .63272 .28429 .63177 .28306 Metetra
.664 .741 .907 r
.63177 .28306 .63272 .28429 .63908 .28209 .63814 .28087 Metetra
.664 .741 .907 r
.63814 .28087 .63908 .28209 .64546 .27989 .64452 .27867 Metetra
.664 .741 .907 r
.64452 .27867 .64546 .27989 .65185 .27769 .65091 .27646 Metetra
.664 .741 .907 r
.65091 .27646 .65185 .27769 .65826 .27548 .65732 .27425 Metetra
.664 .741 .907 r
.65732 .27425 .65826 .27548 .66468 .27327 .66374 .27203 Metetra
.664 .741 .907 r
.66374 .27203 .66468 .27327 .67112 .27105 .67018 .26981 Metetra
.664 .741 .907 r
.67018 .26981 .67112 .27105 .67757 .26882 .67663 .26758 Metetra
.664 .741 .907 r
.67663 .26758 .67757 .26882 .68403 .2666 .6831 .26535 Metetra
.664 .741 .907 r
.6831 .26535 .68403 .2666 .69051 .26436 .68959 .26311 Metetra
.664 .741 .907 r
.68959 .26311 .69051 .26436 .69701 .26212 .69608 .26087 Metetra
.664 .741 .907 r
.69608 .26087 .69701 .26212 .70352 .25988 .7026 .25862 Metetra
.664 .741 .907 r
.7026 .25862 .70352 .25988 .71004 .25763 .70912 .25637 Metetra
.664 .741 .907 r
.70912 .25637 .71004 .25763 .71658 .25537 .71567 .25411 Metetra
.664 .741 .907 r
.71567 .25411 .71658 .25537 .72313 .25311 .72222 .25185 Metetra
.664 .741 .907 r
.72222 .25185 .72313 .25311 .7297 .25085 .7288 .24958 Metetra
.664 .741 .907 r
.7288 .24958 .7297 .25085 .73629 .24858 .73538 .24731 Metetra
.664 .741 .907 r
.73538 .24731 .73629 .24858 .74289 .2463 .74199 .24503 Metetra
.664 .741 .907 r
.74199 .24503 .74289 .2463 .7495 .24402 .74861 .24275 Metetra
0 0 .41 r
.74861 .24275 .7495 .24402 .75613 .24174 .75622 .25352 Metetra
.37 .148 .442 r
.75622 .25352 .75613 .24174 .76278 .23944 .76189 .23816 Metetra
.268 .529 .914 r
.76189 .23816 .76278 .23944 .77492 .30574 .76891 .24038 Metetra
.552 .335 .539 r
.76891 .24038 .77492 .30574 .77612 .23485 .77523 .23356 Metetra
.664 .741 .907 r
.77523 .23356 .77612 .23485 .78281 .23254 .78193 .23125 Metetra
.664 .741 .907 r
.78193 .23125 .78281 .23254 .78952 .23023 .78864 .22893 Metetra
.664 .741 .907 r
.78864 .22893 .78952 .23023 .79624 .22791 .79537 .22661 Metetra
.664 .741 .907 r
.79537 .22661 .79624 .22791 .80298 .22558 .80211 .22428 Metetra
.664 .741 .907 r
.80211 .22428 .80298 .22558 .80974 .22325 .80887 .22195 Metetra
.664 .741 .907 r
.80887 .22195 .80974 .22325 .81651 .22092 .81564 .21962 Metetra
.664 .741 .907 r
.81564 .21962 .81651 .22092 .8233 .21858 .82243 .21727 Metetra
.664 .741 .907 r
.82243 .21727 .8233 .21858 .8301 .21623 .82924 .21492 Metetra
.664 .741 .907 r
.21829 .4243 .21941 .42535 .22488 .42347 .22375 .42241 Metetra
.664 .741 .907 r
.22375 .42241 .22488 .42347 .23035 .42158 .22923 .42052 Metetra
.664 .741 .907 r
.22923 .42052 .23035 .42158 .23584 .41968 .23472 .41863 Metetra
.664 .741 .907 r
.23472 .41863 .23584 .41968 .24134 .41779 .24022 .41673 Metetra
.664 .741 .907 r
.24022 .41673 .24134 .41779 .24684 .41589 .24573 .41482 Metetra
.945 .616 .376 r
.24573 .41482 .24684 .41589 .25237 .41398 .24898 .43978 Metetra
.351 .141 .447 r
.24898 .43978 .25237 .41398 .2579 .41207 .25679 .411 Metetra
.664 .741 .907 r
.25679 .411 .2579 .41207 .26344 .41016 .26233 .40909 Metetra
.664 .741 .907 r
.26233 .40909 .26344 .41016 .269 .40824 .26789 .40717 Metetra
.664 .741 .907 r
.26789 .40717 .269 .40824 .27457 .40632 .27346 .40525 Metetra
.664 .741 .907 r
.27346 .40525 .27457 .40632 .28015 .40439 .27905 .40332 Metetra
.664 .741 .907 r
.27905 .40332 .28015 .40439 .28574 .40246 .28464 .40139 Metetra
.664 .741 .907 r
.28464 .40139 .28574 .40246 .29134 .40053 .29025 .39945 Metetra
.664 .741 .907 r
.29025 .39945 .29134 .40053 .29696 .39859 .29586 .39751 Metetra
.664 .741 .907 r
.29586 .39751 .29696 .39859 .30259 .39665 .30149 .39557 Metetra
.664 .741 .907 r
.30149 .39557 .30259 .39665 .30823 .39471 .30714 .39362 Metetra
.664 .741 .907 r
.30714 .39362 .30823 .39471 .31388 .39276 .31279 .39167 Metetra
.664 .741 .907 r
.31279 .39167 .31388 .39276 .31954 .3908 .31846 .38971 Metetra
.664 .741 .907 r
.31846 .38971 .31954 .3908 .32522 .38884 .32413 .38775 Metetra
.664 .741 .907 r
.32413 .38775 .32522 .38884 .33091 .38688 .32982 .38578 Metetra
.664 .741 .907 r
.32982 .38578 .33091 .38688 .33661 .38491 .33553 .38381 Metetra
.664 .741 .907 r
.33553 .38381 .33661 .38491 .34232 .38294 .34124 .38184 Metetra
.953 .673 .47 r
.34124 .38184 .34232 .38294 .33682 .5843 .34016 .50245 Metetra
.682 .442 .552 r
.34016 .50245 .33682 .5843 .35228 .4071 .35271 .37788 Metetra
.551 .343 .552 r
.35271 .37788 .35228 .4071 .35953 .377 .35846 .37589 Metetra
.664 .741 .907 r
.35846 .37589 .35953 .377 .36529 .37501 .36423 .3739 Metetra
.664 .741 .907 r
.36423 .3739 .36529 .37501 .37107 .37302 .37 .37191 Metetra
.664 .741 .907 r
.37 .37191 .37107 .37302 .37686 .37102 .37579 .36991 Metetra
.664 .741 .907 r
.37579 .36991 .37686 .37102 .38266 .36902 .38159 .3679 Metetra
.664 .741 .907 r
.38159 .3679 .38266 .36902 .38847 .36702 .38741 .3659 Metetra
.664 .741 .907 r
.38741 .3659 .38847 .36702 .39429 .36501 .39324 .36388 Metetra
.664 .741 .907 r
.39324 .36388 .39429 .36501 .40013 .36299 .39908 .36187 Metetra
.664 .741 .907 r
.39908 .36187 .40013 .36299 .40598 .36097 .40493 .35985 Metetra
.664 .741 .907 r
.40493 .35985 .40598 .36097 .41184 .35895 .41079 .35782 Metetra
.664 .741 .907 r
.41079 .35782 .41184 .35895 .41772 .35692 .41667 .35579 Metetra
.664 .741 .907 r
.41667 .35579 .41772 .35692 .42361 .35489 .42256 .35376 Metetra
.664 .741 .907 r
.42256 .35376 .42361 .35489 .42951 .35286 .42847 .35172 Metetra
.664 .741 .907 r
.42847 .35172 .42951 .35286 .43542 .35081 .43438 .34967 Metetra
.664 .741 .907 r
.43438 .34967 .43542 .35081 .44135 .34877 .44031 .34763 Metetra
.664 .741 .907 r
.44031 .34763 .44135 .34877 .44729 .34672 .44626 .34557 Metetra
.664 .741 .907 r
.44626 .34557 .44729 .34672 .45325 .34466 .45221 .34352 Metetra
.664 .741 .907 r
.45221 .34352 .45325 .34466 .45921 .34261 .45818 .34146 Metetra
.664 .741 .907 r
.45818 .34146 .45921 .34261 .46519 .34054 .46416 .33939 Metetra
.664 .741 .907 r
.46416 .33939 .46519 .34054 .47118 .33847 .47016 .33732 Metetra
.664 .741 .907 r
.47016 .33732 .47118 .33847 .47719 .3364 .47617 .33524 Metetra
.664 .741 .907 r
.47617 .33524 .47719 .3364 .48321 .33433 .48219 .33316 Metetra
.664 .741 .907 r
.48219 .33316 .48321 .33433 .48924 .33224 .48823 .33108 Metetra
.664 .741 .907 r
.48823 .33108 .48924 .33224 .49529 .33016 .49427 .32899 Metetra
.664 .741 .907 r
.49427 .32899 .49529 .33016 .50135 .32807 .50034 .3269 Metetra
.664 .741 .907 r
.50034 .3269 .50135 .32807 .50742 .32597 .50641 .3248 Metetra
.664 .741 .907 r
.50641 .3248 .50742 .32597 .51351 .32387 .5125 .3227 Metetra
.664 .741 .907 r
.5125 .3227 .51351 .32387 .51961 .32177 .5186 .32059 Metetra
.664 .741 .907 r
.5186 .32059 .51961 .32177 .52572 .31966 .52472 .31848 Metetra
.664 .741 .907 r
.52472 .31848 .52572 .31966 .53185 .31754 .53085 .31636 Metetra
.664 .741 .907 r
.53085 .31636 .53185 .31754 .53799 .31542 .53699 .31424 Metetra
.664 .741 .907 r
.53699 .31424 .53799 .31542 .54426 .33265 .54315 .31211 Metetra
.524 .33 .56 r
.54315 .31211 .54426 .33265 .55074 .36367 .54936 .3156 Metetra
.56 .344 .544 r
.54936 .3156 .55074 .36367 .55649 .30904 .5555 .30785 Metetra
.664 .741 .907 r
.5555 .30785 .55649 .30904 .56269 .3069 .5617 .30571 Metetra
.664 .741 .907 r
.5617 .30571 .56269 .3069 .5689 .30476 .56792 .30356 Metetra
.664 .741 .907 r
.56792 .30356 .5689 .30476 .57512 .30261 .57414 .30141 Metetra
.664 .741 .907 r
.57414 .30141 .57512 .30261 .58136 .30046 .58038 .29926 Metetra
.664 .741 .907 r
.58038 .29926 .58136 .30046 .58761 .2983 .58664 .2971 Metetra
.664 .741 .907 r
.58664 .2971 .58761 .2983 .59388 .29614 .59291 .29493 Metetra
.664 .741 .907 r
.59291 .29493 .59388 .29614 .60016 .29397 .59919 .29276 Metetra
.664 .741 .907 r
.59919 .29276 .60016 .29397 .60645 .2918 .60549 .29059 Metetra
.664 .741 .907 r
.60549 .29059 .60645 .2918 .61276 .28962 .6118 .28841 Metetra
.664 .741 .907 r
.6118 .28841 .61276 .28962 .61908 .28744 .61812 .28622 Metetra
.664 .741 .907 r
.61812 .28622 .61908 .28744 .62542 .28525 .62446 .28403 Metetra
.664 .741 .907 r
.62446 .28403 .62542 .28525 .63177 .28306 .63082 .28184 Metetra
.664 .741 .907 r
.63082 .28184 .63177 .28306 .63814 .28087 .63718 .27964 Metetra
.664 .741 .907 r
.63718 .27964 .63814 .28087 .64452 .27867 .64357 .27744 Metetra
.664 .741 .907 r
.64357 .27744 .64452 .27867 .65091 .27646 .64997 .27523 Metetra
.664 .741 .907 r
.64997 .27523 .65091 .27646 .65732 .27425 .65638 .27301 Metetra
.664 .741 .907 r
.65638 .27301 .65732 .27425 .66374 .27203 .6628 .27079 Metetra
.664 .741 .907 r
.6628 .27079 .66374 .27203 .67018 .26981 .66925 .26857 Metetra
.664 .741 .907 r
.66925 .26857 .67018 .26981 .67663 .26758 .6757 .26634 Metetra
.664 .741 .907 r
.6757 .26634 .67663 .26758 .6831 .26535 .68217 .2641 Metetra
.664 .741 .907 r
.68217 .2641 .6831 .26535 .68959 .26311 .68866 .26186 Metetra
.664 .741 .907 r
.68866 .26186 .68959 .26311 .69608 .26087 .69516 .25962 Metetra
.664 .741 .907 r
.69516 .25962 .69608 .26087 .7026 .25862 .70168 .25737 Metetra
.664 .741 .907 r
.70168 .25737 .7026 .25862 .70912 .25637 .70821 .25511 Metetra
.664 .741 .907 r
.70821 .25511 .70912 .25637 .71567 .25411 .71475 .25285 Metetra
.664 .741 .907 r
.71475 .25285 .71567 .25411 .72222 .25185 .72131 .25059 Metetra
.664 .741 .907 r
.72131 .25059 .72222 .25185 .7288 .24958 .72789 .24832 Metetra
.664 .741 .907 r
.72789 .24832 .7288 .24958 .73538 .24731 .73448 .24604 Metetra
.664 .741 .907 r
.73448 .24604 .73538 .24731 .74199 .24503 .74109 .24376 Metetra
.664 .741 .907 r
.74109 .24376 .74199 .24503 .74861 .24275 .74771 .24147 Metetra
0 0 .43 r
.74771 .24147 .74861 .24275 .75622 .25352 .7553 .25191 Metetra
.922 .758 .661 r
.7553 .25191 .75622 .25352 .76189 .23816 .761 .23688 Metetra
.178 .471 .891 r
.761 .23688 .76189 .23816 .76891 .24038 .76809 .23987 Metetra
.906 .929 .818 r
.76809 .23987 .76891 .24038 .77523 .23356 .77435 .23227 Metetra
.664 .741 .907 r
.77435 .23227 .77523 .23356 .78193 .23125 .78105 .22996 Metetra
.664 .741 .907 r
.78105 .22996 .78193 .23125 .78864 .22893 .78776 .22764 Metetra
.664 .741 .907 r
.78776 .22764 .78864 .22893 .79537 .22661 .79449 .22531 Metetra
.664 .741 .907 r
.79449 .22531 .79537 .22661 .80211 .22428 .80124 .22298 Metetra
.664 .741 .907 r
.80124 .22298 .80211 .22428 .80887 .22195 .808 .22065 Metetra
.664 .741 .907 r
.808 .22065 .80887 .22195 .81564 .21962 .81478 .21831 Metetra
.664 .741 .907 r
.81478 .21831 .81564 .21962 .82243 .21727 .82157 .21596 Metetra
.664 .741 .907 r
.82157 .21596 .82243 .21727 .82924 .21492 .82838 .21361 Metetra
.664 .741 .907 r
.21716 .42325 .21829 .4243 .22375 .42241 .22263 .42136 Metetra
.664 .741 .907 r
.22263 .42136 .22375 .42241 .22923 .42052 .22811 .41947 Metetra
.664 .741 .907 r
.22811 .41947 .22923 .42052 .23472 .41863 .2336 .41757 Metetra
.664 .741 .907 r
.2336 .41757 .23472 .41863 .24022 .41673 .2391 .41567 Metetra
.664 .741 .907 r
.2391 .41567 .24022 .41673 .24573 .41482 .24461 .41376 Metetra
.945 .664 .476 r
.24461 .41376 .24573 .41482 .24898 .43978 .24412 .48268 Metetra
.206 .03 .409 r
.24412 .48268 .24898 .43978 .25679 .411 .25568 .40994 Metetra
.664 .741 .907 r
.25568 .40994 .25679 .411 .26233 .40909 .26122 .40802 Metetra
.664 .741 .907 r
.26122 .40802 .26233 .40909 .26789 .40717 .26679 .4061 Metetra
.664 .741 .907 r
.26679 .4061 .26789 .40717 .27346 .40525 .27236 .40417 Metetra
.664 .741 .907 r
.27236 .40417 .27346 .40525 .27905 .40332 .27794 .40224 Metetra
.664 .741 .907 r
.27794 .40224 .27905 .40332 .28464 .40139 .28354 .40031 Metetra
.664 .741 .907 r
.28354 .40031 .28464 .40139 .29025 .39945 .28915 .39837 Metetra
.664 .741 .907 r
.28915 .39837 .29025 .39945 .29586 .39751 .29477 .39643 Metetra
.664 .741 .907 r
.29477 .39643 .29586 .39751 .30149 .39557 .3004 .39448 Metetra
.664 .741 .907 r
.3004 .39448 .30149 .39557 .30714 .39362 .30604 .39253 Metetra
.664 .741 .907 r
.30604 .39253 .30714 .39362 .31279 .39167 .3117 .39057 Metetra
.664 .741 .907 r
.3117 .39057 .31279 .39167 .31846 .38971 .31737 .38862 Metetra
.664 .741 .907 r
.31737 .38862 .31846 .38971 .32413 .38775 .32305 .38665 Metetra
.664 .741 .907 r
.32305 .38665 .32413 .38775 .32982 .38578 .32874 .38468 Metetra
.664 .741 .907 r
.32874 .38468 .32982 .38578 .33553 .38381 .33445 .38271 Metetra
.664 .741 .907 r
.33445 .38271 .33553 .38381 .34124 .38184 .34016 .38074 Metetra
.937 .567 .26 r
.34016 .38074 .34124 .38184 .34016 .50245 .34473 .39951 Metetra
.547 .328 .535 r
.34473 .39951 .34016 .50245 .35271 .37788 .35069 .39428 Metetra
.346 .128 .433 r
.35069 .39428 .35271 .37788 .35846 .37589 .35739 .37478 Metetra
.664 .741 .907 r
.35739 .37478 .35846 .37589 .36423 .3739 .36316 .37279 Metetra
.664 .741 .907 r
.36316 .37279 .36423 .3739 .37 .37191 .36893 .37079 Metetra
.664 .741 .907 r
.36893 .37079 .37 .37191 .37579 .36991 .37473 .36879 Metetra
.664 .741 .907 r
.37473 .36879 .37579 .36991 .38159 .3679 .38053 .36679 Metetra
.664 .741 .907 r
.38053 .36679 .38159 .3679 .38741 .3659 .38635 .36477 Metetra
.664 .741 .907 r
.38635 .36477 .38741 .3659 .39324 .36388 .39218 .36276 Metetra
.664 .741 .907 r
.39218 .36276 .39324 .36388 .39908 .36187 .39802 .36074 Metetra
.664 .741 .907 r
.39802 .36074 .39908 .36187 .40493 .35985 .40388 .35872 Metetra
.664 .741 .907 r
.40388 .35872 .40493 .35985 .41079 .35782 .40974 .35669 Metetra
.664 .741 .907 r
.40974 .35669 .41079 .35782 .41667 .35579 .41562 .35466 Metetra
.664 .741 .907 r
.41562 .35466 .41667 .35579 .42256 .35376 .42152 .35262 Metetra
.664 .741 .907 r
.42152 .35262 .42256 .35376 .42847 .35172 .42742 .35058 Metetra
0 .086 .601 r
.42742 .35058 .42847 .35172 .43438 .34967 .43313 .35581 Metetra
.281 .023 .333 r
.43313 .35581 .43438 .34967 .44031 .34763 .43928 .34648 Metetra
.664 .741 .907 r
.43928 .34648 .44031 .34763 .44626 .34557 .44522 .34443 Metetra
.664 .741 .907 r
.44522 .34443 .44626 .34557 .45221 .34352 .45118 .34237 Metetra
.664 .741 .907 r
.45118 .34237 .45221 .34352 .45818 .34146 .45715 .3403 Metetra
.664 .741 .907 r
.45715 .3403 .45818 .34146 .46416 .33939 .46314 .33824 Metetra
.664 .741 .907 r
.46314 .33824 .46416 .33939 .47016 .33732 .46913 .33616 Metetra
.664 .741 .907 r
.46913 .33616 .47016 .33732 .47617 .33524 .47514 .33409 Metetra
.664 .741 .907 r
.47514 .33409 .47617 .33524 .48219 .33316 .48117 .332 Metetra
.664 .741 .907 r
.48117 .332 .48219 .33316 .48823 .33108 .48721 .32992 Metetra
.664 .741 .907 r
.48721 .32992 .48823 .33108 .49427 .32899 .49326 .32782 Metetra
.664 .741 .907 r
.49326 .32782 .49427 .32899 .50034 .3269 .49932 .32573 Metetra
.664 .741 .907 r
.49932 .32573 .50034 .3269 .50641 .3248 .5054 .32363 Metetra
.664 .741 .907 r
.5054 .32363 .50641 .3248 .5125 .3227 .51149 .32152 Metetra
.664 .741 .907 r
.51149 .32152 .5125 .3227 .5186 .32059 .5176 .31941 Metetra
.664 .741 .907 r
.5176 .31941 .5186 .32059 .52472 .31848 .52372 .3173 Metetra
.664 .741 .907 r
.52372 .3173 .52472 .31848 .53085 .31636 .52985 .31518 Metetra
.664 .741 .907 r
.52985 .31518 .53085 .31636 .53699 .31424 .53599 .31305 Metetra
.664 .741 .907 r
.53599 .31305 .53699 .31424 .54315 .31211 .54215 .31093 Metetra
.674 .206 0 r
.54215 .31093 .54315 .31211 .54936 .3156 .54841 .3201 Metetra
0 0 .183 r
.54841 .3201 .54936 .3156 .5555 .30785 .55452 .30665 Metetra
.664 .741 .907 r
.55452 .30665 .5555 .30785 .5617 .30571 .56072 .30451 Metetra
.664 .741 .907 r
.56072 .30451 .5617 .30571 .56792 .30356 .56693 .30236 Metetra
.664 .741 .907 r
.56693 .30236 .56792 .30356 .57414 .30141 .57316 .30021 Metetra
.664 .741 .907 r
.57316 .30021 .57414 .30141 .58038 .29926 .5794 .29805 Metetra
.664 .741 .907 r
.5794 .29805 .58038 .29926 .58664 .2971 .58566 .29589 Metetra
.664 .741 .907 r
.58566 .29589 .58664 .2971 .59291 .29493 .59193 .29372 Metetra
.664 .741 .907 r
.59193 .29372 .59291 .29493 .59919 .29276 .59822 .29155 Metetra
.664 .741 .907 r
.59822 .29155 .59919 .29276 .60549 .29059 .60452 .28937 Metetra
.664 .741 .907 r
.60452 .28937 .60549 .29059 .6118 .28841 .61083 .28719 Metetra
.664 .741 .907 r
.61083 .28719 .6118 .28841 .61812 .28622 .61716 .285 Metetra
.664 .741 .907 r
.61716 .285 .61812 .28622 .62446 .28403 .6235 .28281 Metetra
.664 .741 .907 r
.6235 .28281 .62446 .28403 .63082 .28184 .62986 .28061 Metetra
.664 .741 .907 r
.62986 .28061 .63082 .28184 .63718 .27964 .63623 .27841 Metetra
.664 .741 .907 r
.63623 .27841 .63718 .27964 .64357 .27744 .64262 .2762 Metetra
.664 .741 .907 r
.64262 .2762 .64357 .27744 .64997 .27523 .64902 .27399 Metetra
.664 .741 .907 r
.64902 .27399 .64997 .27523 .65638 .27301 .65543 .27177 Metetra
.664 .741 .907 r
.65543 .27177 .65638 .27301 .6628 .27079 .66186 .26955 Metetra
.664 .741 .907 r
.66186 .26955 .6628 .27079 .66925 .26857 .66831 .26732 Metetra
.664 .741 .907 r
.66831 .26732 .66925 .26857 .6757 .26634 .67477 .26509 Metetra
.664 .741 .907 r
.67477 .26509 .6757 .26634 .68217 .2641 .68124 .26285 Metetra
.664 .741 .907 r
.68124 .26285 .68217 .2641 .68866 .26186 .68773 .26061 Metetra
.664 .741 .907 r
.68773 .26061 .68866 .26186 .69516 .25962 .69424 .25836 Metetra
.664 .741 .907 r
.69424 .25836 .69516 .25962 .70168 .25737 .70075 .25611 Metetra
.664 .741 .907 r
.70075 .25611 .70168 .25737 .70821 .25511 .70729 .25385 Metetra
.664 .741 .907 r
.70729 .25385 .70821 .25511 .71475 .25285 .71384 .25159 Metetra
.664 .741 .907 r
.71384 .25159 .71475 .25285 .72131 .25059 .7204 .24932 Metetra
.664 .741 .907 r
.7204 .24932 .72131 .25059 .72789 .24832 .72698 .24705 Metetra
.664 .741 .907 r
.72698 .24705 .72789 .24832 .73448 .24604 .73357 .24477 Metetra
.664 .741 .907 r
.73357 .24477 .73448 .24604 .74109 .24376 .74018 .24248 Metetra
.664 .741 .907 r
.74018 .24248 .74109 .24376 .74771 .24147 .74681 .24019 Metetra
.664 .741 .907 r
.74681 .24019 .74771 .24147 .7553 .25191 .75345 .2379 Metetra
.563 .371 .579 r
.75345 .2379 .7553 .25191 .761 .23688 .76011 .2356 Metetra
.701 .269 0 r
.76011 .2356 .761 .23688 .76809 .23987 .76807 .24968 Metetra
.278 .071 .409 r
.76807 .24968 .76809 .23987 .77435 .23227 .77346 .23098 Metetra
.664 .741 .907 r
.77346 .23098 .77435 .23227 .78105 .22996 .78017 .22866 Metetra
.664 .741 .907 r
.78017 .22866 .78105 .22996 .78776 .22764 .78688 .22634 Metetra
.664 .741 .907 r
.78688 .22634 .78776 .22764 .79449 .22531 .79362 .22402 Metetra
.664 .741 .907 r
.79362 .22402 .79449 .22531 .80124 .22298 .80037 .22168 Metetra
.664 .741 .907 r
.80037 .22168 .80124 .22298 .808 .22065 .80713 .21934 Metetra
.664 .741 .907 r
.80713 .21934 .808 .22065 .81478 .21831 .81391 .217 Metetra
.664 .741 .907 r
.81391 .217 .81478 .21831 .82157 .21596 .82071 .21465 Metetra
.664 .741 .907 r
.82071 .21465 .82157 .21596 .82838 .21361 .82752 .2123 Metetra
.664 .741 .907 r
.21603 .42219 .21716 .42325 .22263 .42136 .2215 .4203 Metetra
.664 .741 .907 r
.2215 .4203 .22263 .42136 .22811 .41947 .22698 .41841 Metetra
.664 .741 .907 r
.22698 .41841 .22811 .41947 .2336 .41757 .23248 .41651 Metetra
.664 .741 .907 r
.23248 .41651 .2336 .41757 .2391 .41567 .23798 .4146 Metetra
.664 .741 .907 r
.23798 .4146 .2391 .41567 .24461 .41376 .2435 .4127 Metetra
.172 .518 .917 r
.2435 .4127 .24461 .41376 .24412 .48268 .24871 .41445 Metetra
.551 .334 .539 r
.24871 .41445 .24412 .48268 .25568 .40994 .25456 .40887 Metetra
.664 .741 .907 r
.25456 .40887 .25568 .40994 .26122 .40802 .26011 .40695 Metetra
.664 .741 .907 r
.26011 .40695 .26122 .40802 .26679 .4061 .26568 .40502 Metetra
.664 .741 .907 r
.26568 .40502 .26679 .4061 .27236 .40417 .27125 .4031 Metetra
.664 .741 .907 r
.27125 .4031 .27236 .40417 .27794 .40224 .27684 .40116 Metetra
.664 .741 .907 r
.27684 .40116 .27794 .40224 .28354 .40031 .28244 .39923 Metetra
.664 .741 .907 r
.28244 .39923 .28354 .40031 .28915 .39837 .28805 .39729 Metetra
.664 .741 .907 r
.28805 .39729 .28915 .39837 .29477 .39643 .29367 .39534 Metetra
.664 .741 .907 r
.29367 .39534 .29477 .39643 .3004 .39448 .2993 .39339 Metetra
.664 .741 .907 r
.2993 .39339 .3004 .39448 .30604 .39253 .30495 .39144 Metetra
.664 .741 .907 r
.30495 .39144 .30604 .39253 .3117 .39057 .31061 .38948 Metetra
.664 .741 .907 r
.31061 .38948 .3117 .39057 .31737 .38862 .31628 .38752 Metetra
.664 .741 .907 r
.31628 .38752 .31737 .38862 .32305 .38665 .32196 .38556 Metetra
.664 .741 .907 r
.32196 .38556 .32305 .38665 .32874 .38468 .32766 .38359 Metetra
.664 .741 .907 r
.32766 .38359 .32874 .38468 .33445 .38271 .33336 .38161 Metetra
.664 .741 .907 r
.33336 .38161 .33445 .38271 .34016 .38074 .33908 .37963 Metetra
.664 .741 .907 r
.33908 .37963 .34016 .38074 .34473 .39951 .34481 .37765 Metetra
.554 .351 .559 r
.34481 .37765 .34473 .39951 .35069 .39428 .35056 .37566 Metetra
.557 .356 .565 r
.35056 .37566 .35069 .39428 .35739 .37478 .35631 .37367 Metetra
.664 .741 .907 r
.35631 .37367 .35739 .37478 .36316 .37279 .36208 .37168 Metetra
.664 .741 .907 r
.36208 .37168 .36316 .37279 .36893 .37079 .36787 .36968 Metetra
.664 .741 .907 r
.36787 .36968 .36893 .37079 .37473 .36879 .37366 .36767 Metetra
.664 .741 .907 r
.37366 .36767 .37473 .36879 .38053 .36679 .37947 .36566 Metetra
.664 .741 .907 r
.37947 .36566 .38053 .36679 .38635 .36477 .38529 .36365 Metetra
.664 .741 .907 r
.38529 .36365 .38635 .36477 .39218 .36276 .39112 .36163 Metetra
.664 .741 .907 r
.39112 .36163 .39218 .36276 .39802 .36074 .39696 .35961 Metetra
.664 .741 .907 r
.39696 .35961 .39802 .36074 .40388 .35872 .40282 .35759 Metetra
.664 .741 .907 r
.40282 .35759 .40388 .35872 .40974 .35669 .40869 .35556 Metetra
.664 .741 .907 r
.40869 .35556 .40974 .35669 .41562 .35466 .41457 .35352 Metetra
.664 .741 .907 r
.41457 .35352 .41562 .35466 .42152 .35262 .42047 .35148 Metetra
.664 .741 .907 r
.42047 .35148 .42152 .35262 .42742 .35058 .42638 .34944 Metetra
.664 .741 .907 r
.42638 .34944 .42742 .35058 .43313 .35581 .4323 .34739 Metetra
.576 .402 .609 r
.4323 .34739 .43313 .35581 .43928 .34648 .43823 .34534 Metetra
.575 .089 0 r
.43823 .34534 .43928 .34648 .44522 .34443 .44396 .35211 Metetra
.306 .061 .369 r
.44396 .35211 .44522 .34443 .45118 .34237 .45014 .34122 Metetra
.664 .741 .907 r
.45014 .34122 .45118 .34237 .45715 .3403 .45612 .33915 Metetra
.664 .741 .907 r
.45612 .33915 .45715 .3403 .46314 .33824 .46211 .33708 Metetra
.664 .741 .907 r
.46211 .33708 .46314 .33824 .46913 .33616 .46811 .335 Metetra
.664 .741 .907 r
.46811 .335 .46913 .33616 .47514 .33409 .47412 .33292 Metetra
.664 .741 .907 r
.47412 .33292 .47514 .33409 .48117 .332 .48015 .33084 Metetra
.664 .741 .907 r
.48015 .33084 .48117 .332 .48721 .32992 .48619 .32875 Metetra
.664 .741 .907 r
.48619 .32875 .48721 .32992 .49326 .32782 .49224 .32666 Metetra
.664 .741 .907 r
.49224 .32666 .49326 .32782 .49932 .32573 .49831 .32456 Metetra
.664 .741 .907 r
.49831 .32456 .49932 .32573 .5054 .32363 .50439 .32245 Metetra
.664 .741 .907 r
.50439 .32245 .5054 .32363 .51149 .32152 .51048 .32035 Metetra
.664 .741 .907 r
.51048 .32035 .51149 .32152 .5176 .31941 .51659 .31823 Metetra
.664 .741 .907 r
.51659 .31823 .5176 .31941 .52372 .3173 .52271 .31612 Metetra
.664 .741 .907 r
.52271 .31612 .52372 .3173 .52985 .31518 .52885 .31399 Metetra
.664 .741 .907 r
.52885 .31399 .52985 .31518 .53599 .31305 .535 .31187 Metetra
.664 .741 .907 r
.535 .31187 .53599 .31305 .54215 .31093 .54116 .30974 Metetra
.664 .741 .907 r
.54116 .30974 .54215 .31093 .54841 .3201 .54733 .3076 Metetra
.565 .376 .584 r
.54733 .3076 .54841 .3201 .55452 .30665 .55353 .30546 Metetra
.664 .741 .907 r
.55353 .30546 .55452 .30665 .56072 .30451 .55973 .30331 Metetra
.664 .741 .907 r
.55973 .30331 .56072 .30451 .56693 .30236 .56595 .30116 Metetra
.664 .741 .907 r
.56595 .30116 .56693 .30236 .57316 .30021 .57218 .29901 Metetra
.664 .741 .907 r
.57218 .29901 .57316 .30021 .5794 .29805 .57843 .29685 Metetra
.664 .741 .907 r
.57843 .29685 .5794 .29805 .58566 .29589 .58469 .29468 Metetra
.664 .741 .907 r
.58469 .29468 .58566 .29589 .59193 .29372 .59096 .29251 Metetra
.664 .741 .907 r
.59096 .29251 .59193 .29372 .59822 .29155 .59725 .29034 Metetra
.664 .741 .907 r
.59725 .29034 .59822 .29155 .60452 .28937 .60355 .28815 Metetra
.664 .741 .907 r
.60355 .28815 .60452 .28937 .61083 .28719 .60987 .28597 Metetra
.664 .741 .907 r
.60987 .28597 .61083 .28719 .61716 .285 .6162 .28378 Metetra
.664 .741 .907 r
.6162 .28378 .61716 .285 .6235 .28281 .62254 .28159 Metetra
.664 .741 .907 r
.62254 .28159 .6235 .28281 .62986 .28061 .6289 .27939 Metetra
.664 .741 .907 r
.6289 .27939 .62986 .28061 .63623 .27841 .63528 .27718 Metetra
.664 .741 .907 r
.63528 .27718 .63623 .27841 .64262 .2762 .64167 .27497 Metetra
.664 .741 .907 r
.64167 .27497 .64262 .2762 .64902 .27399 .64807 .27276 Metetra
.664 .741 .907 r
.64807 .27276 .64902 .27399 .65543 .27177 .65449 .27054 Metetra
.664 .741 .907 r
.65449 .27054 .65543 .27177 .66186 .26955 .66092 .26831 Metetra
.664 .741 .907 r
.66092 .26831 .66186 .26955 .66831 .26732 .66737 .26608 Metetra
.664 .741 .907 r
.66737 .26608 .66831 .26732 .67477 .26509 .67383 .26384 Metetra
.664 .741 .907 r
.67383 .26384 .67477 .26509 .68124 .26285 .68031 .2616 Metetra
.664 .741 .907 r
.68031 .2616 .68124 .26285 .68773 .26061 .6868 .25936 Metetra
.664 .741 .907 r
.6868 .25936 .68773 .26061 .69424 .25836 .69331 .25711 Metetra
.664 .741 .907 r
.69331 .25711 .69424 .25836 .70075 .25611 .69983 .25485 Metetra
.664 .741 .907 r
.69983 .25485 .70075 .25611 .70729 .25385 .70637 .25259 Metetra
.664 .741 .907 r
.70637 .25259 .70729 .25385 .71384 .25159 .71292 .25032 Metetra
.664 .741 .907 r
.71292 .25032 .71384 .25159 .7204 .24932 .71949 .24805 Metetra
.664 .741 .907 r
.71949 .24805 .7204 .24932 .72698 .24705 .72607 .24578 Metetra
.664 .741 .907 r
.72607 .24578 .72698 .24705 .73357 .24477 .73267 .24349 Metetra
.664 .741 .907 r
.73267 .24349 .73357 .24477 .74018 .24248 .73928 .24121 Metetra
.664 .741 .907 r
.73928 .24121 .74018 .24248 .74681 .24019 .74591 .23891 Metetra
.664 .741 .907 r
.74591 .23891 .74681 .24019 .75345 .2379 .75255 .23662 Metetra
.664 .741 .907 r
.75255 .23662 .75345 .2379 .76011 .2356 .75921 .23431 Metetra
.896 .512 .064 r
.75921 .23431 .76011 .2356 .76807 .24968 .76841 .26405 Metetra
.197 .03 .416 r
.76841 .26405 .76807 .24968 .77346 .23098 .77258 .22969 Metetra
.664 .741 .907 r
.77258 .22969 .77346 .23098 .78017 .22866 .77928 .22737 Metetra
.664 .741 .907 r
.77928 .22737 .78017 .22866 .78688 .22634 .786 .22505 Metetra
.664 .741 .907 r
.786 .22505 .78688 .22634 .79362 .22402 .79274 .22272 Metetra
.664 .741 .907 r
.79274 .22272 .79362 .22402 .80037 .22168 .79949 .22038 Metetra
.664 .741 .907 r
.79949 .22038 .80037 .22168 .80713 .21934 .80626 .21804 Metetra
.664 .741 .907 r
.80626 .21804 .80713 .21934 .81391 .217 .81305 .21569 Metetra
.664 .741 .907 r
.81305 .21569 .81391 .217 .82071 .21465 .81985 .21334 Metetra
.664 .741 .907 r
.81985 .21334 .82071 .21465 .82752 .2123 .82666 .21098 Metetra
.664 .741 .907 r
.2149 .42114 .21603 .42219 .2215 .4203 .22038 .41925 Metetra
.664 .741 .907 r
.22038 .41925 .2215 .4203 .22698 .41841 .22586 .41735 Metetra
.664 .741 .907 r
.22586 .41735 .22698 .41841 .23248 .41651 .23135 .41545 Metetra
.664 .741 .907 r
.23135 .41545 .23248 .41651 .23798 .4146 .23686 .41354 Metetra
.664 .741 .907 r
.23686 .41354 .23798 .4146 .2435 .4127 .24238 .41163 Metetra
.664 .741 .907 r
.24238 .41163 .2435 .4127 .24871 .41445 .24791 .40972 Metetra
.598 .459 .663 r
.24791 .40972 .24871 .41445 .25456 .40887 .25345 .4078 Metetra
.664 .741 .907 r
.25345 .4078 .25456 .40887 .26011 .40695 .259 .40588 Metetra
.664 .741 .907 r
.259 .40588 .26011 .40695 .26568 .40502 .26457 .40395 Metetra
.664 .741 .907 r
.26457 .40395 .26568 .40502 .27125 .4031 .27014 .40202 Metetra
.664 .741 .907 r
.27014 .40202 .27125 .4031 .27684 .40116 .27573 .40008 Metetra
.664 .741 .907 r
.27573 .40008 .27684 .40116 .28244 .39923 .28133 .39815 Metetra
.664 .741 .907 r
.28133 .39815 .28244 .39923 .28805 .39729 .28694 .3962 Metetra
.664 .741 .907 r
.28694 .3962 .28805 .39729 .29367 .39534 .29257 .39426 Metetra
.664 .741 .907 r
.29257 .39426 .29367 .39534 .2993 .39339 .2982 .3923 Metetra
.664 .741 .907 r
.2982 .3923 .2993 .39339 .30495 .39144 .30385 .39035 Metetra
.664 .741 .907 r
.30385 .39035 .30495 .39144 .31061 .38948 .30951 .38839 Metetra
.664 .741 .907 r
.30951 .38839 .31061 .38948 .31628 .38752 .31519 .38643 Metetra
.664 .741 .907 r
.31519 .38643 .31628 .38752 .32196 .38556 .32087 .38446 Metetra
.664 .741 .907 r
.32087 .38446 .32196 .38556 .32766 .38359 .32657 .38249 Metetra
.664 .741 .907 r
.32657 .38249 .32766 .38359 .33336 .38161 .33228 .38051 Metetra
.664 .741 .907 r
.33228 .38051 .33336 .38161 .33908 .37963 .338 .37853 Metetra
.664 .741 .907 r
.338 .37853 .33908 .37963 .34481 .37765 .34373 .37654 Metetra
.664 .741 .907 r
.34373 .37654 .34481 .37765 .35056 .37566 .34948 .37455 Metetra
.664 .741 .907 r
.34948 .37455 .35056 .37566 .35631 .37367 .35524 .37256 Metetra
.664 .741 .907 r
.35524 .37256 .35631 .37367 .36208 .37168 .36101 .37056 Metetra
.664 .741 .907 r
.36101 .37056 .36208 .37168 .36787 .36968 .36679 .36856 Metetra
.664 .741 .907 r
.36679 .36856 .36787 .36968 .37366 .36767 .37259 .36655 Metetra
.664 .741 .907 r
.37259 .36655 .37366 .36767 .37947 .36566 .3784 .36454 Metetra
.664 .741 .907 r
.3784 .36454 .37947 .36566 .38529 .36365 .38422 .36253 Metetra
.664 .741 .907 r
.38422 .36253 .38529 .36365 .39112 .36163 .39006 .36051 Metetra
.664 .741 .907 r
.39006 .36051 .39112 .36163 .39696 .35961 .3959 .35848 Metetra
.664 .741 .907 r
.3959 .35848 .39696 .35961 .40282 .35759 .40176 .35645 Metetra
.664 .741 .907 r
.40176 .35645 .40282 .35759 .40869 .35556 .40764 .35442 Metetra
.664 .741 .907 r
.40764 .35442 .40869 .35556 .41457 .35352 .41352 .35238 Metetra
.664 .741 .907 r
.41352 .35238 .41457 .35352 .42047 .35148 .41942 .35034 Metetra
.664 .741 .907 r
.41942 .35034 .42047 .35148 .42638 .34944 .42533 .3483 Metetra
.664 .741 .907 r
.42533 .3483 .42638 .34944 .4323 .34739 .43126 .34625 Metetra
.823 .371 0 r
.43126 .34625 .4323 .34739 .43823 .34534 .43684 .35705 Metetra
.907 .624 .495 r
.43684 .35705 .43823 .34534 .44396 .35211 .43721 .57179 Metetra
.394 .199 .495 r
.43721 .57179 .44396 .35211 .45014 .34122 .44884 .35115 Metetra
.327 .094 .4 r
.44884 .35115 .45014 .34122 .45612 .33915 .45508 .338 Metetra
.664 .741 .907 r
.45508 .338 .45612 .33915 .46211 .33708 .46107 .33592 Metetra
.664 .741 .907 r
.46107 .33592 .46211 .33708 .46811 .335 .46708 .33384 Metetra
.664 .741 .907 r
.46708 .33384 .46811 .335 .47412 .33292 .47309 .33176 Metetra
.664 .741 .907 r
.47309 .33176 .47412 .33292 .48015 .33084 .47912 .32967 Metetra
.664 .741 .907 r
.47912 .32967 .48015 .33084 .48619 .32875 .48517 .32758 Metetra
.664 .741 .907 r
.48517 .32758 .48619 .32875 .49224 .32666 .49122 .32549 Metetra
.664 .741 .907 r
.49122 .32549 .49224 .32666 .49831 .32456 .49729 .32339 Metetra
.664 .741 .907 r
.49729 .32339 .49831 .32456 .50439 .32245 .50338 .32128 Metetra
.664 .741 .907 r
.50338 .32128 .50439 .32245 .51048 .32035 .50947 .31917 Metetra
.664 .741 .907 r
.50947 .31917 .51048 .32035 .51659 .31823 .51558 .31705 Metetra
.664 .741 .907 r
.51558 .31705 .51659 .31823 .52271 .31612 .52171 .31493 Metetra
.664 .741 .907 r
.52171 .31493 .52271 .31612 .52885 .31399 .52784 .31281 Metetra
.664 .741 .907 r
.52784 .31281 .52885 .31399 .535 .31187 .534 .31068 Metetra
.664 .741 .907 r
.534 .31068 .535 .31187 .54116 .30974 .54016 .30855 Metetra
.664 .741 .907 r
.54016 .30855 .54116 .30974 .54733 .3076 .54634 .30641 Metetra
.664 .741 .907 r
.54634 .30641 .54733 .3076 .55353 .30546 .55253 .30426 Metetra
.664 .741 .907 r
.55253 .30426 .55353 .30546 .55973 .30331 .55874 .30211 Metetra
.664 .741 .907 r
.55874 .30211 .55973 .30331 .56595 .30116 .56496 .29996 Metetra
.664 .741 .907 r
.56496 .29996 .56595 .30116 .57218 .29901 .5712 .2978 Metetra
.664 .741 .907 r
.5712 .2978 .57218 .29901 .57843 .29685 .57744 .29564 Metetra
.664 .741 .907 r
.57744 .29564 .57843 .29685 .58469 .29468 .58371 .29347 Metetra
.664 .741 .907 r
.58371 .29347 .58469 .29468 .59096 .29251 .58998 .2913 Metetra
.664 .741 .907 r
.58998 .2913 .59096 .29251 .59725 .29034 .59628 .28912 Metetra
.664 .741 .907 r
.59628 .28912 .59725 .29034 .60355 .28815 .60258 .28694 Metetra
.664 .741 .907 r
.60258 .28694 .60355 .28815 .60987 .28597 .6089 .28475 Metetra
.664 .741 .907 r
.6089 .28475 .60987 .28597 .6162 .28378 .61524 .28256 Metetra
.664 .741 .907 r
.61524 .28256 .6162 .28378 .62254 .28159 .62158 .28036 Metetra
.664 .741 .907 r
.62158 .28036 .62254 .28159 .6289 .27939 .62795 .27816 Metetra
.664 .741 .907 r
.62795 .27816 .6289 .27939 .63528 .27718 .63432 .27595 Metetra
.664 .741 .907 r
.63432 .27595 .63528 .27718 .64167 .27497 .64072 .27374 Metetra
.664 .741 .907 r
.64072 .27374 .64167 .27497 .64807 .27276 .64712 .27152 Metetra
.664 .741 .907 r
.64712 .27152 .64807 .27276 .65449 .27054 .65354 .26929 Metetra
.664 .741 .907 r
.65354 .26929 .65449 .27054 .66092 .26831 .65998 .26707 Metetra
.664 .741 .907 r
.65998 .26707 .66092 .26831 .66737 .26608 .66643 .26483 Metetra
.664 .741 .907 r
.66643 .26483 .66737 .26608 .67383 .26384 .6729 .2626 Metetra
.664 .741 .907 r
.6729 .2626 .67383 .26384 .68031 .2616 .67938 .26035 Metetra
.664 .741 .907 r
.67938 .26035 .68031 .2616 .6868 .25936 .68587 .2581 Metetra
.664 .741 .907 r
.68587 .2581 .6868 .25936 .69331 .25711 .69238 .25585 Metetra
.664 .741 .907 r
.69238 .25585 .69331 .25711 .69983 .25485 .69891 .25359 Metetra
.664 .741 .907 r
.69891 .25359 .69983 .25485 .70637 .25259 .70545 .25133 Metetra
.664 .741 .907 r
.70545 .25133 .70637 .25259 .71292 .25032 .712 .24906 Metetra
.664 .741 .907 r
.712 .24906 .71292 .25032 .71949 .24805 .71857 .24678 Metetra
.664 .741 .907 r
.71857 .24678 .71949 .24805 .72607 .24578 .72516 .2445 Metetra
.664 .741 .907 r
.72516 .2445 .72607 .24578 .73267 .24349 .73176 .24222 Metetra
.664 .741 .907 r
.73176 .24222 .73267 .24349 .73928 .24121 .73838 .23993 Metetra
.506 .668 .936 r
.73838 .23993 .73928 .24121 .74591 .23891 .74516 .23979 Metetra
.74516 .23979 .74591 .23891 .75255 .23662 .75165 .23533 Metetra
.664 .741 .907 r
.75165 .23533 .75255 .23662 .75921 .23431 .75832 .23303 Metetra
.948 .601 .208 r
.75832 .23303 .75921 .23431 .76841 .26405 .76986 .29265 Metetra
.221 .068 .45 r
.76986 .29265 .76841 .26405 .77258 .22969 .77169 .2284 Metetra
.664 .741 .907 r
.77169 .2284 .77258 .22969 .77928 .22737 .7784 .22607 Metetra
.664 .741 .907 r
.7784 .22607 .77928 .22737 .786 .22505 .78512 .22375 Metetra
.664 .741 .907 r
.78512 .22375 .786 .22505 .79274 .22272 .79186 .22141 Metetra
.664 .741 .907 r
.79186 .22141 .79274 .22272 .79949 .22038 .79862 .21907 Metetra
.664 .741 .907 r
.79862 .21907 .79949 .22038 .80626 .21804 .80539 .21673 Metetra
.664 .741 .907 r
.80539 .21673 .80626 .21804 .81305 .21569 .81218 .21438 Metetra
.664 .741 .907 r
.81218 .21438 .81305 .21569 .81985 .21334 .81898 .21202 Metetra
.664 .741 .907 r
.81898 .21202 .81985 .21334 .82666 .21098 .8258 .20966 Metetra
.664 .741 .907 r
.21377 .42008 .2149 .42114 .22038 .41925 .21925 .41819 Metetra
.664 .741 .907 r
.21925 .41819 .22038 .41925 .22586 .41735 .22473 .41629 Metetra
.664 .741 .907 r
.22473 .41629 .22586 .41735 .23135 .41545 .23023 .41438 Metetra
.664 .741 .907 r
.23023 .41438 .23135 .41545 .23686 .41354 .23574 .41248 Metetra
.664 .741 .907 r
.23574 .41248 .23686 .41354 .24238 .41163 .24126 .41056 Metetra
.664 .741 .907 r
.24126 .41056 .24238 .41163 .24791 .40972 .24679 .40865 Metetra
.664 .741 .907 r
.24679 .40865 .24791 .40972 .25345 .4078 .25233 .40673 Metetra
.664 .741 .907 r
.25233 .40673 .25345 .4078 .259 .40588 .25789 .4048 Metetra
.664 .741 .907 r
.25789 .4048 .259 .40588 .26457 .40395 .26345 .40287 Metetra
.664 .741 .907 r
.26345 .40287 .26457 .40395 .27014 .40202 .26903 .40094 Metetra
.664 .741 .907 r
.26903 .40094 .27014 .40202 .27573 .40008 .27462 .399 Metetra
.664 .741 .907 r
.27462 .399 .27573 .40008 .28133 .39815 .28023 .39706 Metetra
.664 .741 .907 r
.28023 .39706 .28133 .39815 .28694 .3962 .28584 .39512 Metetra
.664 .741 .907 r
.28584 .39512 .28694 .3962 .29257 .39426 .29147 .39317 Metetra
.664 .741 .907 r
.29147 .39317 .29257 .39426 .2982 .3923 .29711 .39121 Metetra
.664 .741 .907 r
.29711 .39121 .2982 .3923 .30385 .39035 .30276 .38926 Metetra
.664 .741 .907 r
.30276 .38926 .30385 .39035 .30951 .38839 .30842 .38729 Metetra
.664 .741 .907 r
.30842 .38729 .30951 .38839 .31519 .38643 .31409 .38533 Metetra
.664 .741 .907 r
.31409 .38533 .31519 .38643 .32087 .38446 .31978 .38336 Metetra
.664 .741 .907 r
.31978 .38336 .32087 .38446 .32657 .38249 .32548 .38138 Metetra
.664 .741 .907 r
.32548 .38138 .32657 .38249 .33228 .38051 .33119 .3794 Metetra
.664 .741 .907 r
.33119 .3794 .33228 .38051 .338 .37853 .33692 .37742 Metetra
.664 .741 .907 r
.33692 .37742 .338 .37853 .34373 .37654 .34265 .37543 Metetra
.664 .741 .907 r
.34265 .37543 .34373 .37654 .34948 .37455 .3484 .37344 Metetra
.664 .741 .907 r
.3484 .37344 .34948 .37455 .35524 .37256 .35416 .37145 Metetra
.664 .741 .907 r
.35416 .37145 .35524 .37256 .36101 .37056 .35994 .36945 Metetra
.664 .741 .907 r
.35994 .36945 .36101 .37056 .36679 .36856 .36572 .36744 Metetra
.664 .741 .907 r
.36572 .36744 .36679 .36856 .37259 .36655 .37152 .36543 Metetra
.664 .741 .907 r
.37152 .36543 .37259 .36655 .3784 .36454 .37733 .36342 Metetra
.664 .741 .907 r
.37733 .36342 .3784 .36454 .38422 .36253 .38316 .3614 Metetra
.664 .741 .907 r
.38316 .3614 .38422 .36253 .39006 .36051 .38899 .35938 Metetra
.664 .741 .907 r
.38899 .35938 .39006 .36051 .3959 .35848 .39484 .35735 Metetra
.664 .741 .907 r
.39484 .35735 .3959 .35848 .40176 .35645 .40071 .35532 Metetra
.664 .741 .907 r
.40071 .35532 .40176 .35645 .40764 .35442 .40658 .35329 Metetra
.664 .741 .907 r
.40658 .35329 .40764 .35442 .41352 .35238 .41247 .35125 Metetra
.664 .741 .907 r
.41247 .35125 .41352 .35238 .41942 .35034 .41837 .3492 Metetra
.664 .741 .907 r
.41837 .3492 .41942 .35034 .42533 .3483 .42428 .34715 Metetra
.664 .741 .907 r
.42428 .34715 .42533 .3483 .43126 .34625 .43021 .3451 Metetra
.961 .655 .402 r
.43021 .3451 .43126 .34625 .43684 .35705 .43433 .40791 Metetra
.748 .484 .532 r
.43433 .40791 .43684 .35705 .43721 .57179 .43609 .5707 Metetra
.96 .696 .489 r
.43609 .5707 .43721 .57179 .44884 .35115 .44807 .33891 Metetra
.565 .376 .584 r
.44807 .33891 .44884 .35115 .45508 .338 .45405 .33684 Metetra
.664 .741 .907 r
.45405 .33684 .45508 .338 .46107 .33592 .46004 .33476 Metetra
.664 .741 .907 r
.46004 .33476 .46107 .33592 .46708 .33384 .46605 .33268 Metetra
.664 .741 .907 r
.46605 .33268 .46708 .33384 .47309 .33176 .47207 .3306 Metetra
.664 .741 .907 r
.47207 .3306 .47309 .33176 .47912 .32967 .4781 .32851 Metetra
.664 .741 .907 r
.4781 .32851 .47912 .32967 .48517 .32758 .48414 .32641 Metetra
.664 .741 .907 r
.48414 .32641 .48517 .32758 .49122 .32549 .4902 .32432 Metetra
.664 .741 .907 r
.4902 .32432 .49122 .32549 .49729 .32339 .49627 .32221 Metetra
.664 .741 .907 r
.49627 .32221 .49729 .32339 .50338 .32128 .50236 .3201 Metetra
.664 .741 .907 r
.50236 .3201 .50338 .32128 .50947 .31917 .50846 .31799 Metetra
.664 .741 .907 r
.50846 .31799 .50947 .31917 .51558 .31705 .51457 .31587 Metetra
.664 .741 .907 r
.51457 .31587 .51558 .31705 .52171 .31493 .5207 .31375 Metetra
.664 .741 .907 r
.5207 .31375 .52171 .31493 .52784 .31281 .52684 .31162 Metetra
.664 .741 .907 r
.52684 .31162 .52784 .31281 .534 .31068 .533 .30949 Metetra
.664 .741 .907 r
.533 .30949 .534 .31068 .54016 .30855 .53916 .30735 Metetra
.664 .741 .907 r
.53916 .30735 .54016 .30855 .54634 .30641 .54534 .30521 Metetra
.664 .741 .907 r
.54534 .30521 .54634 .30641 .55253 .30426 .55154 .30306 Metetra
.664 .741 .907 r
.55154 .30306 .55253 .30426 .55874 .30211 .55775 .30091 Metetra
.664 .741 .907 r
.55775 .30091 .55874 .30211 .56496 .29996 .56397 .29876 Metetra
.664 .741 .907 r
.56397 .29876 .56496 .29996 .5712 .2978 .57021 .2966 Metetra
.664 .741 .907 r
.57021 .2966 .5712 .2978 .57744 .29564 .57646 .29443 Metetra
.664 .741 .907 r
.57646 .29443 .57744 .29564 .58371 .29347 .58273 .29226 Metetra
.664 .741 .907 r
.58273 .29226 .58371 .29347 .58998 .2913 .58901 .29008 Metetra
.664 .741 .907 r
.58901 .29008 .58998 .2913 .59628 .28912 .5953 .2879 Metetra
.664 .741 .907 r
.5953 .2879 .59628 .28912 .60258 .28694 .60161 .28572 Metetra
.664 .741 .907 r
.60161 .28572 .60258 .28694 .6089 .28475 .60793 .28353 Metetra
.664 .741 .907 r
.60793 .28353 .6089 .28475 .61524 .28256 .61427 .28133 Metetra
.664 .741 .907 r
.61427 .28133 .61524 .28256 .62158 .28036 .62062 .27913 Metetra
.664 .741 .907 r
.62062 .27913 .62158 .28036 .62795 .27816 .62699 .27693 Metetra
.664 .741 .907 r
.62699 .27693 .62795 .27816 .63432 .27595 .63337 .27471 Metetra
.664 .741 .907 r
.63337 .27471 .63432 .27595 .64072 .27374 .63976 .2725 Metetra
.664 .741 .907 r
.63976 .2725 .64072 .27374 .64712 .27152 .64617 .27028 Metetra
.664 .741 .907 r
.64617 .27028 .64712 .27152 .65354 .26929 .6526 .26805 Metetra
.664 .741 .907 r
.6526 .26805 .65354 .26929 .65998 .26707 .65904 .26582 Metetra
.664 .741 .907 r
.65904 .26582 .65998 .26707 .66643 .26483 .66549 .26359 Metetra
.664 .741 .907 r
.66549 .26359 .66643 .26483 .6729 .2626 .67196 .26135 Metetra
.664 .741 .907 r
.67196 .26135 .6729 .2626 .67938 .26035 .67844 .2591 Metetra
.664 .741 .907 r
.67844 .2591 .67938 .26035 .68587 .2581 .68494 .25685 Metetra
.664 .741 .907 r
.68494 .25685 .68587 .2581 .69238 .25585 .69145 .25459 Metetra
.664 .741 .907 r
.69145 .25459 .69238 .25585 .69891 .25359 .69798 .25233 Metetra
.664 .741 .907 r
.69798 .25233 .69891 .25359 .70545 .25133 .70453 .25006 Metetra
.664 .741 .907 r
.70453 .25006 .70545 .25133 .712 .24906 .71108 .24779 Metetra
.664 .741 .907 r
.71108 .24779 .712 .24906 .71857 .24678 .71766 .24551 Metetra
.664 .741 .907 r
.71766 .24551 .71857 .24678 .72516 .2445 .72425 .24323 Metetra
.664 .741 .907 r
.72425 .24323 .72516 .2445 .73176 .24222 .73085 .24094 Metetra
.664 .741 .907 r
.73085 .24094 .73176 .24222 .73838 .23993 .73747 .23865 Metetra
.191 .482 .896 r
.73747 .23865 .73838 .23993 .74516 .23979 .74447 .24146 Metetra
.74447 .24146 .74516 .23979 .75165 .23533 .75075 .23405 Metetra
.664 .741 .907 r
.75075 .23405 .75165 .23533 .75832 .23303 .75742 .23174 Metetra
.664 .741 .907 r
.75742 .23174 .75832 .23303 .76986 .29265 .7641 .22942 Metetra
.544 .329 .538 r
.7641 .22942 .76986 .29265 .77169 .2284 .7708 .2271 Metetra
.664 .741 .907 r
.7708 .2271 .77169 .2284 .7784 .22607 .77751 .22478 Metetra
.664 .741 .907 r
.77751 .22478 .7784 .22607 .78512 .22375 .78424 .22245 Metetra
.664 .741 .907 r
.78424 .22245 .78512 .22375 .79186 .22141 .79098 .22011 Metetra
.664 .741 .907 r
.79098 .22011 .79186 .22141 .79862 .21907 .79774 .21777 Metetra
.664 .741 .907 r
.79774 .21777 .79862 .21907 .80539 .21673 .80452 .21542 Metetra
.664 .741 .907 r
.80452 .21542 .80539 .21673 .81218 .21438 .81131 .21307 Metetra
.664 .741 .907 r
.81131 .21307 .81218 .21438 .81898 .21202 .81812 .21071 Metetra
.664 .741 .907 r
.81812 .21071 .81898 .21202 .8258 .20966 .82494 .20834 Metetra
.664 .741 .907 r
.21264 .41903 .21377 .42008 .21925 .41819 .21812 .41713 Metetra
.664 .741 .907 r
.21812 .41713 .21925 .41819 .22473 .41629 .2236 .41523 Metetra
.664 .741 .907 r
.2236 .41523 .22473 .41629 .23023 .41438 .2291 .41332 Metetra
.664 .741 .907 r
.2291 .41332 .23023 .41438 .23574 .41248 .23461 .41141 Metetra
.664 .741 .907 r
.23461 .41141 .23574 .41248 .24126 .41056 .24013 .40949 Metetra
.664 .741 .907 r
.24013 .40949 .24126 .41056 .24679 .40865 .24567 .40758 Metetra
.664 .741 .907 r
.24567 .40758 .24679 .40865 .25233 .40673 .25121 .40565 Metetra
.664 .741 .907 r
.25121 .40565 .25233 .40673 .25789 .4048 .25677 .40373 Metetra
.664 .741 .907 r
.25677 .40373 .25789 .4048 .26345 .40287 .26234 .4018 Metetra
.664 .741 .907 r
.26234 .4018 .26345 .40287 .26903 .40094 .26792 .39986 Metetra
.664 .741 .907 r
.26792 .39986 .26903 .40094 .27462 .399 .27351 .39792 Metetra
.664 .741 .907 r
.27351 .39792 .27462 .399 .28023 .39706 .27912 .39598 Metetra
.664 .741 .907 r
.27912 .39598 .28023 .39706 .28584 .39512 .28474 .39403 Metetra
0 .08 .58 r
.28474 .39403 .28584 .39512 .29147 .39317 .28989 .39859 Metetra
.589 .288 .427 r
.28989 .39859 .29147 .39317 .29711 .39121 .29514 .40228 Metetra
.315 .084 .394 r
.29514 .40228 .29711 .39121 .30276 .38926 .30166 .38816 Metetra
.664 .741 .907 r
.30166 .38816 .30276 .38926 .30842 .38729 .30732 .3862 Metetra
.664 .741 .907 r
.30732 .3862 .30842 .38729 .31409 .38533 .313 .38423 Metetra
.664 .741 .907 r
.313 .38423 .31409 .38533 .31978 .38336 .31869 .38226 Metetra
.664 .741 .907 r
.31869 .38226 .31978 .38336 .32548 .38138 .32439 .38028 Metetra
.664 .741 .907 r
.32439 .38028 .32548 .38138 .33119 .3794 .33011 .3783 Metetra
.664 .741 .907 r
.33011 .3783 .33119 .3794 .33692 .37742 .33583 .37631 Metetra
.664 .741 .907 r
.33583 .37631 .33692 .37742 .34265 .37543 .34157 .37432 Metetra
.664 .741 .907 r
.34157 .37432 .34265 .37543 .3484 .37344 .34732 .37233 Metetra
.664 .741 .907 r
.34732 .37233 .3484 .37344 .35416 .37145 .35309 .37033 Metetra
.664 .741 .907 r
.35309 .37033 .35416 .37145 .35994 .36945 .35886 .36833 Metetra
.664 .741 .907 r
.35886 .36833 .35994 .36945 .36572 .36744 .36465 .36632 Metetra
.664 .741 .907 r
.36465 .36632 .36572 .36744 .37152 .36543 .37045 .36431 Metetra
.664 .741 .907 r
.37045 .36431 .37152 .36543 .37733 .36342 .37627 .36229 Metetra
.664 .741 .907 r
.37627 .36229 .37733 .36342 .38316 .3614 .38209 .36027 Metetra
.664 .741 .907 r
.38209 .36027 .38316 .3614 .38899 .35938 .38793 .35825 Metetra
.664 .741 .907 r
.38793 .35825 .38899 .35938 .39484 .35735 .39378 .35622 Metetra
.664 .741 .907 r
.39378 .35622 .39484 .35735 .40071 .35532 .39965 .35419 Metetra
.664 .741 .907 r
.39965 .35419 .40071 .35532 .40658 .35329 .40552 .35215 Metetra
.664 .741 .907 r
.40552 .35215 .40658 .35329 .41247 .35125 .41142 .35011 Metetra
.664 .741 .907 r
.41142 .35011 .41247 .35125 .41837 .3492 .41732 .34806 Metetra
.664 .741 .907 r
.41732 .34806 .41837 .3492 .42428 .34715 .42323 .34601 Metetra
.664 .741 .907 r
.42323 .34601 .42428 .34715 .43021 .3451 .42916 .34395 Metetra
.961 .653 .398 r
.42916 .34395 .43021 .3451 .43433 .40791 .43337 .40306 Metetra
.971 .678 .279 r
.43337 .40306 .43433 .40791 .43609 .5707 .43781 .4626 Metetra
.655 .415 .544 r
.43781 .4626 .43609 .5707 .44807 .33891 .44703 .33776 Metetra
.664 .741 .907 r
.44703 .33776 .44807 .33891 .45405 .33684 .45301 .33568 Metetra
.664 .741 .907 r
.45301 .33568 .45405 .33684 .46004 .33476 .45901 .3336 Metetra
.664 .741 .907 r
.45901 .3336 .46004 .33476 .46605 .33268 .46502 .33152 Metetra
.664 .741 .907 r
.46502 .33152 .46605 .33268 .47207 .3306 .47104 .32943 Metetra
.664 .741 .907 r
.47104 .32943 .47207 .3306 .4781 .32851 .47707 .32734 Metetra
.664 .741 .907 r
.47707 .32734 .4781 .32851 .48414 .32641 .48312 .32524 Metetra
.664 .741 .907 r
.48312 .32524 .48414 .32641 .4902 .32432 .48918 .32314 Metetra
.664 .741 .907 r
.48918 .32314 .4902 .32432 .49627 .32221 .49526 .32104 Metetra
.664 .741 .907 r
.49526 .32104 .49627 .32221 .50236 .3201 .50135 .31892 Metetra
.664 .741 .907 r
.50135 .31892 .50236 .3201 .50846 .31799 .50745 .31681 Metetra
.664 .741 .907 r
.50745 .31681 .50846 .31799 .51457 .31587 .51356 .31469 Metetra
.664 .741 .907 r
.51356 .31469 .51457 .31587 .5207 .31375 .51969 .31256 Metetra
.664 .741 .907 r
.51969 .31256 .5207 .31375 .52684 .31162 .52584 .31043 Metetra
.664 .741 .907 r
.52584 .31043 .52684 .31162 .533 .30949 .53199 .3083 Metetra
.664 .741 .907 r
.53199 .3083 .533 .30949 .53916 .30735 .53816 .30616 Metetra
.664 .741 .907 r
.53816 .30616 .53916 .30735 .54534 .30521 .54435 .30401 Metetra
.664 .741 .907 r
.54435 .30401 .54534 .30521 .55154 .30306 .55055 .30187 Metetra
.664 .741 .907 r
.55055 .30187 .55154 .30306 .55775 .30091 .55676 .29971 Metetra
.664 .741 .907 r
.55676 .29971 .55775 .30091 .56397 .29876 .56299 .29755 Metetra
.664 .741 .907 r
.56299 .29755 .56397 .29876 .57021 .2966 .56923 .29539 Metetra
.664 .741 .907 r
.56923 .29539 .57021 .2966 .57646 .29443 .57548 .29322 Metetra
.664 .741 .907 r
.57548 .29322 .57646 .29443 .58273 .29226 .58175 .29105 Metetra
.664 .741 .907 r
.58175 .29105 .58273 .29226 .58901 .29008 .58803 .28887 Metetra
.664 .741 .907 r
.58803 .28887 .58901 .29008 .5953 .2879 .59433 .28668 Metetra
.664 .741 .907 r
.59433 .28668 .5953 .2879 .60161 .28572 .60064 .2845 Metetra
.664 .741 .907 r
.60064 .2845 .60161 .28572 .60793 .28353 .60697 .2823 Metetra
.664 .741 .907 r
.60697 .2823 .60793 .28353 .61427 .28133 .61331 .2801 Metetra
.664 .741 .907 r
.61331 .2801 .61427 .28133 .62062 .27913 .61966 .2779 Metetra
.664 .741 .907 r
.61966 .2779 .62062 .27913 .62699 .27693 .62603 .27569 Metetra
.664 .741 .907 r
.62603 .27569 .62699 .27693 .63337 .27471 .63241 .27348 Metetra
.664 .741 .907 r
.63241 .27348 .63337 .27471 .63976 .2725 .63881 .27126 Metetra
.664 .741 .907 r
.63881 .27126 .63976 .2725 .64617 .27028 .64522 .26904 Metetra
.664 .741 .907 r
.64522 .26904 .64617 .27028 .6526 .26805 .65165 .26681 Metetra
.664 .741 .907 r
.65165 .26681 .6526 .26805 .65904 .26582 .65809 .26458 Metetra
.664 .741 .907 r
.65809 .26458 .65904 .26582 .66549 .26359 .66455 .26234 Metetra
.664 .741 .907 r
.66455 .26234 .66549 .26359 .67196 .26135 .67102 .26009 Metetra
.664 .741 .907 r
.67102 .26009 .67196 .26135 .67844 .2591 .67751 .25784 Metetra
.664 .741 .907 r
.67751 .25784 .67844 .2591 .68494 .25685 .68401 .25559 Metetra
.664 .741 .907 r
.68401 .25559 .68494 .25685 .69145 .25459 .69052 .25333 Metetra
.664 .741 .907 r
.69052 .25333 .69145 .25459 .69798 .25233 .69706 .25107 Metetra
.664 .741 .907 r
.69706 .25107 .69798 .25233 .70453 .25006 .7036 .2488 Metetra
.664 .741 .907 r
.7036 .2488 .70453 .25006 .71108 .24779 .71016 .24652 Metetra
.664 .741 .907 r
.71016 .24652 .71108 .24779 .71766 .24551 .71674 .24424 Metetra
.664 .741 .907 r
.71674 .24424 .71766 .24551 .72425 .24323 .72333 .24195 Metetra
.664 .741 .907 r
.72333 .24195 .72425 .24323 .73085 .24094 .72994 .23966 Metetra
.664 .741 .907 r
.72994 .23966 .73085 .24094 .73747 .23865 .73656 .23737 Metetra
.664 .741 .907 r
.73656 .23737 .73747 .23865 .74447 .24146 .7432 .23507 Metetra
.548 .405 .639 r
.7432 .23507 .74447 .24146 .75075 .23405 .75003 .23514 Metetra
.75003 .23514 .75075 .23405 .75742 .23174 .75652 .23045 Metetra
.664 .741 .907 r
.75652 .23045 .75742 .23174 .7641 .22942 .76321 .22813 Metetra
.664 .741 .907 r
.76321 .22813 .7641 .22942 .7708 .2271 .76991 .22581 Metetra
.664 .741 .907 r
.76991 .22581 .7708 .2271 .77751 .22478 .77662 .22348 Metetra
.664 .741 .907 r
.77662 .22348 .77751 .22478 .78424 .22245 .78335 .22114 Metetra
.664 .741 .907 r
.78335 .22114 .78424 .22245 .79098 .22011 .7901 .2188 Metetra
.664 .741 .907 r
.7901 .2188 .79098 .22011 .79774 .21777 .79686 .21646 Metetra
.664 .741 .907 r
.79686 .21646 .79774 .21777 .80452 .21542 .80364 .21411 Metetra
.664 .741 .907 r
.80364 .21411 .80452 .21542 .81131 .21307 .81044 .21175 Metetra
.664 .741 .907 r
.81044 .21175 .81131 .21307 .81812 .21071 .81725 .20939 Metetra
.664 .741 .907 r
.81725 .20939 .81812 .21071 .82494 .20834 .82408 .20702 Metetra
.664 .741 .907 r
.21151 .41797 .21264 .41903 .21812 .41713 .21699 .41607 Metetra
.664 .741 .907 r
.21699 .41607 .21812 .41713 .2236 .41523 .22247 .41416 Metetra
.664 .741 .907 r
.22247 .41416 .2236 .41523 .2291 .41332 .22798 .41225 Metetra
.664 .741 .907 r
.22798 .41225 .2291 .41332 .23461 .41141 .23349 .41034 Metetra
.664 .741 .907 r
.23349 .41034 .23461 .41141 .24013 .40949 .23901 .40842 Metetra
.664 .741 .907 r
.23901 .40842 .24013 .40949 .24567 .40758 .24455 .4065 Metetra
.664 .741 .907 r
.24455 .4065 .24567 .40758 .25121 .40565 .2501 .40458 Metetra
.664 .741 .907 r
.2501 .40458 .25121 .40565 .25677 .40373 .25565 .40265 Metetra
.664 .741 .907 r
.25565 .40265 .25677 .40373 .26234 .4018 .26123 .40072 Metetra
.664 .741 .907 r
.26123 .40072 .26234 .4018 .26792 .39986 .26681 .39878 Metetra
.664 .741 .907 r
.26681 .39878 .26792 .39986 .27351 .39792 .2724 .39684 Metetra
.664 .741 .907 r
.2724 .39684 .27351 .39792 .27912 .39598 .27801 .39489 Metetra
.664 .741 .907 r
.27801 .39489 .27912 .39598 .28474 .39403 .28363 .39294 Metetra
.948 .619 .369 r
.28363 .39294 .28474 .39403 .28989 .39859 .28713 .41999 Metetra
.278 .076 .417 r
.28713 .41999 .28989 .39859 .29514 .40228 .2949 .38903 Metetra
.562 .37 .579 r
.2949 .38903 .29514 .40228 .30166 .38816 .30056 .38707 Metetra
.664 .741 .907 r
.30056 .38707 .30166 .38816 .30732 .3862 .30623 .3851 Metetra
.664 .741 .907 r
.30623 .3851 .30732 .3862 .313 .38423 .31191 .38313 Metetra
.664 .741 .907 r
.31191 .38313 .313 .38423 .31869 .38226 .3176 .38115 Metetra
.664 .741 .907 r
.3176 .38115 .31869 .38226 .32439 .38028 .3233 .37918 Metetra
.664 .741 .907 r
.3233 .37918 .32439 .38028 .33011 .3783 .32902 .37719 Metetra
.664 .741 .907 r
.32902 .37719 .33011 .3783 .33583 .37631 .33475 .3752 Metetra
.664 .741 .907 r
.33475 .3752 .33583 .37631 .34157 .37432 .34049 .37321 Metetra
.664 .741 .907 r
.34049 .37321 .34157 .37432 .34732 .37233 .34624 .37122 Metetra
.664 .741 .907 r
.34624 .37122 .34732 .37233 .35309 .37033 .35201 .36921 Metetra
.664 .741 .907 r
.35201 .36921 .35309 .37033 .35886 .36833 .35778 .36721 Metetra
.664 .741 .907 r
.35778 .36721 .35886 .36833 .36465 .36632 .36358 .3652 Metetra
.664 .741 .907 r
.36358 .3652 .36465 .36632 .37045 .36431 .36938 .36319 Metetra
.664 .741 .907 r
.36938 .36319 .37045 .36431 .37627 .36229 .3752 .36117 Metetra
.664 .741 .907 r
.3752 .36117 .37627 .36229 .38209 .36027 .38102 .35914 Metetra
.664 .741 .907 r
.38102 .35914 .38209 .36027 .38793 .35825 .38687 .35712 Metetra
.664 .741 .907 r
.38687 .35712 .38793 .35825 .39378 .35622 .39272 .35509 Metetra
.664 .741 .907 r
.39272 .35509 .39378 .35622 .39965 .35419 .39859 .35305 Metetra
.664 .741 .907 r
.39859 .35305 .39965 .35419 .40552 .35215 .40447 .35101 Metetra
.664 .741 .907 r
.40447 .35101 .40552 .35215 .41142 .35011 .41036 .34897 Metetra
.664 .741 .907 r
.41036 .34897 .41142 .35011 .41732 .34806 .41627 .34692 Metetra
.664 .741 .907 r
.41627 .34692 .41732 .34806 .42323 .34601 .42218 .34486 Metetra
.664 .741 .907 r
.42218 .34486 .42323 .34601 .42916 .34395 .42812 .3428 Metetra
.664 .741 .907 r
.42812 .3428 .42916 .34395 .43337 .40306 .43406 .34074 Metetra
.429 .238 .518 r
.43406 .34074 .43337 .40306 .43781 .4626 .43864 .38993 Metetra
.617 .386 .544 r
.43864 .38993 .43781 .4626 .44703 .33776 .44599 .3366 Metetra
.664 .741 .907 r
.44599 .3366 .44703 .33776 .45301 .33568 .45197 .33452 Metetra
.664 .741 .907 r
.45197 .33452 .45301 .33568 .45901 .3336 .45797 .33244 Metetra
.664 .741 .907 r
.45797 .33244 .45901 .3336 .46502 .33152 .46398 .33036 Metetra
.664 .741 .907 r
.46398 .33036 .46502 .33152 .47104 .32943 .47001 .32827 Metetra
.664 .741 .907 r
.47001 .32827 .47104 .32943 .47707 .32734 .47604 .32617 Metetra
.664 .741 .907 r
.47604 .32617 .47707 .32734 .48312 .32524 .48209 .32407 Metetra
.664 .741 .907 r
.48209 .32407 .48312 .32524 .48918 .32314 .48816 .32197 Metetra
.664 .741 .907 r
.48816 .32197 .48918 .32314 .49526 .32104 .49424 .31986 Metetra
.664 .741 .907 r
.49424 .31986 .49526 .32104 .50135 .31892 .50033 .31775 Metetra
.664 .741 .907 r
.50033 .31775 .50135 .31892 .50745 .31681 .50643 .31563 Metetra
.664 .741 .907 r
.50643 .31563 .50745 .31681 .51356 .31469 .51255 .3135 Metetra
.664 .741 .907 r
.51255 .3135 .51356 .31469 .51969 .31256 .51868 .31138 Metetra
.664 .741 .907 r
.51868 .31138 .51969 .31256 .52584 .31043 .52483 .30924 Metetra
.664 .741 .907 r
.52483 .30924 .52584 .31043 .53199 .3083 .53099 .30711 Metetra
.664 .741 .907 r
.53099 .30711 .53199 .3083 .53816 .30616 .53716 .30496 Metetra
.664 .741 .907 r
.53716 .30496 .53816 .30616 .54435 .30401 .54335 .30282 Metetra
.664 .741 .907 r
.54335 .30282 .54435 .30401 .55055 .30187 .54955 .30066 Metetra
.664 .741 .907 r
.54955 .30066 .55055 .30187 .55676 .29971 .55577 .29851 Metetra
.664 .741 .907 r
.55577 .29851 .55676 .29971 .56299 .29755 .562 .29635 Metetra
.664 .741 .907 r
.562 .29635 .56299 .29755 .56923 .29539 .56824 .29418 Metetra
.664 .741 .907 r
.56824 .29418 .56923 .29539 .57548 .29322 .5745 .29201 Metetra
.664 .741 .907 r
.5745 .29201 .57548 .29322 .58175 .29105 .58077 .28983 Metetra
.664 .741 .907 r
.58077 .28983 .58175 .29105 .58803 .28887 .58705 .28765 Metetra
.664 .741 .907 r
.58705 .28765 .58803 .28887 .59433 .28668 .59335 .28546 Metetra
.664 .741 .907 r
.59335 .28546 .59433 .28668 .60064 .2845 .59967 .28327 Metetra
.664 .741 .907 r
.59967 .28327 .60064 .2845 .60697 .2823 .606 .28108 Metetra
.664 .741 .907 r
.606 .28108 .60697 .2823 .61331 .2801 .61234 .27888 Metetra
.664 .741 .907 r
.61234 .27888 .61331 .2801 .61966 .2779 .6187 .27667 Metetra
.664 .741 .907 r
.6187 .27667 .61966 .2779 .62603 .27569 .62507 .27446 Metetra
.664 .741 .907 r
.62507 .27446 .62603 .27569 .63241 .27348 .63145 .27224 Metetra
.664 .741 .907 r
.63145 .27224 .63241 .27348 .63881 .27126 .63786 .27002 Metetra
.664 .741 .907 r
.63786 .27002 .63881 .27126 .64522 .26904 .64427 .2678 Metetra
.664 .741 .907 r
.64427 .2678 .64522 .26904 .65165 .26681 .6507 .26556 Metetra
.664 .741 .907 r
.6507 .26556 .65165 .26681 .65809 .26458 .65715 .26333 Metetra
.664 .741 .907 r
.65715 .26333 .65809 .26458 .66455 .26234 .66361 .26109 Metetra
.664 .741 .907 r
.66361 .26109 .66455 .26234 .67102 .26009 .67008 .25884 Metetra
.664 .741 .907 r
.67008 .25884 .67102 .26009 .67751 .25784 .67657 .25659 Metetra
.664 .741 .907 r
.67657 .25659 .67751 .25784 .68401 .25559 .68307 .25433 Metetra
.664 .741 .907 r
.68307 .25433 .68401 .25559 .69052 .25333 .68959 .25207 Metetra
.664 .741 .907 r
.68959 .25207 .69052 .25333 .69706 .25107 .69613 .2498 Metetra
.664 .741 .907 r
.69613 .2498 .69706 .25107 .7036 .2488 .70268 .24753 Metetra
.664 .741 .907 r
.70268 .24753 .7036 .2488 .71016 .24652 .70924 .24525 Metetra
.664 .741 .907 r
.70924 .24525 .71016 .24652 .71674 .24424 .71582 .24297 Metetra
.664 .741 .907 r
.71582 .24297 .71674 .24424 .72333 .24195 .72242 .24068 Metetra
.664 .741 .907 r
.72242 .24068 .72333 .24195 .72994 .23966 .72903 .23838 Metetra
.664 .741 .907 r
.72903 .23838 .72994 .23966 .73656 .23737 .73565 .23608 Metetra
.664 .741 .907 r
.73565 .23608 .73656 .23737 .7432 .23507 .7423 .23378 Metetra
.664 .741 .907 r
.7423 .23378 .7432 .23507 .75003 .23514 .74895 .23147 Metetra
.615 .508 .709 r
.74895 .23147 .75003 .23514 .75652 .23045 .75562 .22915 Metetra
.664 .741 .907 r
.75562 .22915 .75652 .23045 .76321 .22813 .76231 .22683 Metetra
.664 .741 .907 r
.76231 .22683 .76321 .22813 .76991 .22581 .76902 .22451 Metetra
.664 .741 .907 r
.76902 .22451 .76991 .22581 .77662 .22348 .77573 .22218 Metetra
.664 .741 .907 r
.77573 .22218 .77662 .22348 .78335 .22114 .78247 .21984 Metetra
.664 .741 .907 r
.78247 .21984 .78335 .22114 .7901 .2188 .78922 .2175 Metetra
.664 .741 .907 r
.78922 .2175 .7901 .2188 .79686 .21646 .79599 .21515 Metetra
.664 .741 .907 r
.79599 .21515 .79686 .21646 .80364 .21411 .80277 .2128 Metetra
.664 .741 .907 r
.80277 .2128 .80364 .21411 .81044 .21175 .80957 .21044 Metetra
.664 .741 .907 r
.80957 .21044 .81044 .21175 .81725 .20939 .81638 .20807 Metetra
.664 .741 .907 r
.81638 .20807 .81725 .20939 .82408 .20702 .82321 .2057 Metetra
.664 .741 .907 r
.21037 .41691 .21151 .41797 .21699 .41607 .21585 .41501 Metetra
.664 .741 .907 r
.21585 .41501 .21699 .41607 .22247 .41416 .22134 .4131 Metetra
.664 .741 .907 r
.22134 .4131 .22247 .41416 .22798 .41225 .22685 .41119 Metetra
.664 .741 .907 r
.22685 .41119 .22798 .41225 .23349 .41034 .23236 .40927 Metetra
.664 .741 .907 r
.23236 .40927 .23349 .41034 .23901 .40842 .23789 .40735 Metetra
.664 .741 .907 r
.23789 .40735 .23901 .40842 .24455 .4065 .24343 .40543 Metetra
.664 .741 .907 r
.24343 .40543 .24455 .4065 .2501 .40458 .24897 .4035 Metetra
.664 .741 .907 r
.24897 .4035 .2501 .40458 .25565 .40265 .25454 .40157 Metetra
.664 .741 .907 r
.25454 .40157 .25565 .40265 .26123 .40072 .26011 .39964 Metetra
.664 .741 .907 r
.26011 .39964 .26123 .40072 .26681 .39878 .26569 .3977 Metetra
.664 .741 .907 r
.26569 .3977 .26681 .39878 .2724 .39684 .27129 .39575 Metetra
.664 .741 .907 r
.27129 .39575 .2724 .39684 .27801 .39489 .2769 .3938 Metetra
.664 .741 .907 r
.2769 .3938 .27801 .39489 .28363 .39294 .28252 .39185 Metetra
.026 .421 .863 r
.28252 .39185 .28363 .39294 .28713 .41999 .28783 .39436 Metetra
.571 .361 .557 r
.28783 .39436 .28713 .41999 .2949 .38903 .2938 .38794 Metetra
.664 .741 .907 r
.2938 .38794 .2949 .38903 .30056 .38707 .29946 .38597 Metetra
.664 .741 .907 r
.29946 .38597 .30056 .38707 .30623 .3851 .30513 .384 Metetra
.664 .741 .907 r
.30513 .384 .30623 .3851 .31191 .38313 .31081 .38203 Metetra
.664 .741 .907 r
.31081 .38203 .31191 .38313 .3176 .38115 .3165 .38005 Metetra
.664 .741 .907 r
.3165 .38005 .3176 .38115 .3233 .37918 .32221 .37807 Metetra
.664 .741 .907 r
.32221 .37807 .3233 .37918 .32902 .37719 .32793 .37608 Metetra
.664 .741 .907 r
.32793 .37608 .32902 .37719 .33475 .3752 .33366 .37409 Metetra
.664 .741 .907 r
.33366 .37409 .33475 .3752 .34049 .37321 .3394 .3721 Metetra
.664 .741 .907 r
.3394 .3721 .34049 .37321 .34624 .37122 .34516 .3701 Metetra
.664 .741 .907 r
.34516 .3701 .34624 .37122 .35201 .36921 .35093 .3681 Metetra
.664 .741 .907 r
.35093 .3681 .35201 .36921 .35778 .36721 .35671 .36609 Metetra
.664 .741 .907 r
.35671 .36609 .35778 .36721 .36358 .3652 .3625 .36408 Metetra
.664 .741 .907 r
.3625 .36408 .36358 .3652 .36938 .36319 .36831 .36206 Metetra
.664 .741 .907 r
.36831 .36206 .36938 .36319 .3752 .36117 .37412 .36004 Metetra
.664 .741 .907 r
.37412 .36004 .3752 .36117 .38102 .35914 .37996 .35801 Metetra
.664 .741 .907 r
.37996 .35801 .38102 .35914 .38687 .35712 .3858 .35599 Metetra
.664 .741 .907 r
.3858 .35599 .38687 .35712 .39272 .35509 .39166 .35395 Metetra
.664 .741 .907 r
.39166 .35395 .39272 .35509 .39859 .35305 .39753 .35191 Metetra
.664 .741 .907 r
.39753 .35191 .39859 .35305 .40447 .35101 .40341 .34987 Metetra
.664 .741 .907 r
.40341 .34987 .40447 .35101 .41036 .34897 .4093 .34782 Metetra
.664 .741 .907 r
.4093 .34782 .41036 .34897 .41627 .34692 .41521 .34577 Metetra
.664 .741 .907 r
.41521 .34577 .41627 .34692 .42218 .34486 .42113 .34371 Metetra
.664 .741 .907 r
.42113 .34371 .42218 .34486 .42812 .3428 .42707 .34165 Metetra
.664 .741 .907 r
.42707 .34165 .42812 .3428 .43406 .34074 .43301 .33959 Metetra
.664 .741 .907 r
.43301 .33959 .43406 .34074 .43864 .38993 .43897 .33752 Metetra
.544 .33 .539 r
.43897 .33752 .43864 .38993 .44599 .3366 .44495 .33544 Metetra
.664 .741 .907 r
.44495 .33544 .44599 .3366 .45197 .33452 .45094 .33336 Metetra
.664 .741 .907 r
.45094 .33336 .45197 .33452 .45797 .33244 .45694 .33128 Metetra
.664 .741 .907 r
.45694 .33128 .45797 .33244 .46398 .33036 .46295 .32919 Metetra
.664 .741 .907 r
.46295 .32919 .46398 .33036 .47001 .32827 .46898 .3271 Metetra
.664 .741 .907 r
.46898 .3271 .47001 .32827 .47604 .32617 .47502 .325 Metetra
.664 .741 .907 r
.47502 .325 .47604 .32617 .48209 .32407 .48107 .3229 Metetra
.664 .741 .907 r
.48107 .3229 .48209 .32407 .48816 .32197 .48714 .32079 Metetra
.664 .741 .907 r
.48714 .32079 .48816 .32197 .49424 .31986 .49322 .31868 Metetra
.664 .741 .907 r
.49322 .31868 .49424 .31986 .50033 .31775 .49931 .31656 Metetra
.664 .741 .907 r
.49931 .31656 .50033 .31775 .50643 .31563 .50542 .31444 Metetra
.664 .741 .907 r
.50542 .31444 .50643 .31563 .51255 .3135 .51154 .31232 Metetra
.664 .741 .907 r
.51154 .31232 .51255 .3135 .51868 .31138 .51767 .31019 Metetra
.664 .741 .907 r
.51767 .31019 .51868 .31138 .52483 .30924 .52382 .30805 Metetra
.664 .741 .907 r
.52382 .30805 .52483 .30924 .53099 .30711 .52998 .30591 Metetra
.664 .741 .907 r
.52998 .30591 .53099 .30711 .53716 .30496 .53616 .30377 Metetra
.966 .648 .356 r
.53616 .30377 .53716 .30496 .54335 .30282 .54273 .36994 Metetra
.392 .195 .489 r
.54273 .36994 .54335 .30282 .54955 .30066 .54855 .29946 Metetra
.664 .741 .907 r
.54855 .29946 .54955 .30066 .55577 .29851 .55477 .2973 Metetra
.664 .741 .907 r
.55477 .2973 .55577 .29851 .562 .29635 .561 .29514 Metetra
.664 .741 .907 r
.561 .29514 .562 .29635 .56824 .29418 .56725 .29297 Metetra
.664 .741 .907 r
.56725 .29297 .56824 .29418 .5745 .29201 .57351 .29079 Metetra
.664 .741 .907 r
.57351 .29079 .5745 .29201 .58077 .28983 .57979 .28862 Metetra
.664 .741 .907 r
.57979 .28862 .58077 .28983 .58705 .28765 .58607 .28643 Metetra
.664 .741 .907 r
.58607 .28643 .58705 .28765 .59335 .28546 .59238 .28424 Metetra
.664 .741 .907 r
.59238 .28424 .59335 .28546 .59967 .28327 .59869 .28205 Metetra
.664 .741 .907 r
.59869 .28205 .59967 .28327 .606 .28108 .60502 .27985 Metetra
.664 .741 .907 r
.60502 .27985 .606 .28108 .61234 .27888 .61137 .27765 Metetra
.664 .741 .907 r
.61137 .27765 .61234 .27888 .6187 .27667 .61773 .27544 Metetra
.664 .741 .907 r
.61773 .27544 .6187 .27667 .62507 .27446 .62411 .27322 Metetra
.664 .741 .907 r
.62411 .27322 .62507 .27446 .63145 .27224 .6305 .271 Metetra
.664 .741 .907 r
.6305 .271 .63145 .27224 .63786 .27002 .6369 .26878 Metetra
.664 .741 .907 r
.6369 .26878 .63786 .27002 .64427 .2678 .64332 .26655 Metetra
.664 .741 .907 r
.64332 .26655 .64427 .2678 .6507 .26556 .64975 .26432 Metetra
.664 .741 .907 r
.64975 .26432 .6507 .26556 .65715 .26333 .6562 .26208 Metetra
.664 .741 .907 r
.6562 .26208 .65715 .26333 .66361 .26109 .66266 .25983 Metetra
.664 .741 .907 r
.66266 .25983 .66361 .26109 .67008 .25884 .66914 .25758 Metetra
.664 .741 .907 r
.66914 .25758 .67008 .25884 .67657 .25659 .67563 .25533 Metetra
.664 .741 .907 r
.67563 .25533 .67657 .25659 .68307 .25433 .68214 .25307 Metetra
.664 .741 .907 r
.68214 .25307 .68307 .25433 .68959 .25207 .68866 .2508 Metetra
.664 .741 .907 r
.68866 .2508 .68959 .25207 .69613 .2498 .6952 .24853 Metetra
.664 .741 .907 r
.6952 .24853 .69613 .2498 .70268 .24753 .70175 .24626 Metetra
.664 .741 .907 r
.70175 .24626 .70268 .24753 .70924 .24525 .70832 .24398 Metetra
.664 .741 .907 r
.70832 .24398 .70924 .24525 .71582 .24297 .7149 .24169 Metetra
.664 .741 .907 r
.7149 .24169 .71582 .24297 .72242 .24068 .7215 .2394 Metetra
.664 .741 .907 r
.7215 .2394 .72242 .24068 .72903 .23838 .72812 .2371 Metetra
.664 .741 .907 r
.72812 .2371 .72903 .23838 .73565 .23608 .73474 .2348 Metetra
.664 .741 .907 r
.73474 .2348 .73565 .23608 .7423 .23378 .74139 .23249 Metetra
.664 .741 .907 r
.74139 .23249 .7423 .23378 .74895 .23147 .74805 .23018 Metetra
.664 .741 .907 r
.74805 .23018 .74895 .23147 .75562 .22915 .75472 .22786 Metetra
.664 .741 .907 r
.75472 .22786 .75562 .22915 .76231 .22683 .76142 .22554 Metetra
.664 .741 .907 r
.76142 .22554 .76231 .22683 .76902 .22451 .76812 .22321 Metetra
.664 .741 .907 r
.76812 .22321 .76902 .22451 .77573 .22218 .77484 .22087 Metetra
.664 .741 .907 r
.77484 .22087 .77573 .22218 .78247 .21984 .78158 .21853 Metetra
.664 .741 .907 r
.78158 .21853 .78247 .21984 .78922 .2175 .78834 .21619 Metetra
.664 .741 .907 r
.78834 .21619 .78922 .2175 .79599 .21515 .79511 .21384 Metetra
.664 .741 .907 r
.79511 .21384 .79599 .21515 .80277 .2128 .80189 .21148 Metetra
.664 .741 .907 r
.80189 .21148 .80277 .2128 .80957 .21044 .80869 .20912 Metetra
.664 .741 .907 r
.80869 .20912 .80957 .21044 .81638 .20807 .81551 .20675 Metetra
.664 .741 .907 r
.81551 .20675 .81638 .20807 .82321 .2057 .82235 .20438 Metetra
.664 .741 .907 r
.20924 .41585 .21037 .41691 .21585 .41501 .21472 .41394 Metetra
.664 .741 .907 r
.21472 .41394 .21585 .41501 .22134 .4131 .22021 .41203 Metetra
.664 .741 .907 r
.22021 .41203 .22134 .4131 .22685 .41119 .22572 .41012 Metetra
.664 .741 .907 r
.22572 .41012 .22685 .41119 .23236 .40927 .23123 .4082 Metetra
.664 .741 .907 r
.23123 .4082 .23236 .40927 .23789 .40735 .23676 .40628 Metetra
.664 .741 .907 r
.23676 .40628 .23789 .40735 .24343 .40543 .2423 .40436 Metetra
.664 .741 .907 r
.2423 .40436 .24343 .40543 .24897 .4035 .24785 .40243 Metetra
.664 .741 .907 r
.24785 .40243 .24897 .4035 .25454 .40157 .25342 .40049 Metetra
.664 .741 .907 r
.25342 .40049 .25454 .40157 .26011 .39964 .25899 .39855 Metetra
.664 .741 .907 r
.25899 .39855 .26011 .39964 .26569 .3977 .26458 .39661 Metetra
.664 .741 .907 r
.26458 .39661 .26569 .3977 .27129 .39575 .27018 .39467 Metetra
.664 .741 .907 r
.27018 .39467 .27129 .39575 .2769 .3938 .27579 .39272 Metetra
.664 .741 .907 r
.27579 .39272 .2769 .3938 .28252 .39185 .28141 .39076 Metetra
.664 .741 .907 r
.28141 .39076 .28252 .39185 .28783 .39436 .28705 .3888 Metetra
.59 .44 .646 r
.28705 .3888 .28783 .39436 .2938 .38794 .2927 .38684 Metetra
.664 .741 .907 r
.2927 .38684 .2938 .38794 .29946 .38597 .29836 .38487 Metetra
.664 .741 .907 r
.29836 .38487 .29946 .38597 .30513 .384 .30403 .3829 Metetra
.664 .741 .907 r
.30403 .3829 .30513 .384 .31081 .38203 .30971 .38093 Metetra
.664 .741 .907 r
.30971 .38093 .31081 .38203 .3165 .38005 .31541 .37895 Metetra
.664 .741 .907 r
.31541 .37895 .3165 .38005 .32221 .37807 .32112 .37696 Metetra
.664 .741 .907 r
.32112 .37696 .32221 .37807 .32793 .37608 .32684 .37497 Metetra
.664 .741 .907 r
.32684 .37497 .32793 .37608 .33366 .37409 .33257 .37298 Metetra
.664 .741 .907 r
.33257 .37298 .33366 .37409 .3394 .3721 .33832 .37098 Metetra
.664 .741 .907 r
.33832 .37098 .3394 .3721 .34516 .3701 .34407 .36898 Metetra
.664 .741 .907 r
.34407 .36898 .34516 .3701 .35093 .3681 .34984 .36698 Metetra
.664 .741 .907 r
.34984 .36698 .35093 .3681 .35671 .36609 .35563 .36497 Metetra
.664 .741 .907 r
.35563 .36497 .35671 .36609 .3625 .36408 .36142 .36295 Metetra
.664 .741 .907 r
.36142 .36295 .3625 .36408 .36831 .36206 .36723 .36093 Metetra
.664 .741 .907 r
.36723 .36093 .36831 .36206 .37412 .36004 .37305 .35891 Metetra
.664 .741 .907 r
.37305 .35891 .37412 .36004 .37996 .35801 .37889 .35688 Metetra
.664 .741 .907 r
.37889 .35688 .37996 .35801 .3858 .35599 .38473 .35485 Metetra
.664 .741 .907 r
.38473 .35485 .3858 .35599 .39166 .35395 .39059 .35281 Metetra
.664 .741 .907 r
.39059 .35281 .39166 .35395 .39753 .35191 .39646 .35077 Metetra
.664 .741 .907 r
.39646 .35077 .39753 .35191 .40341 .34987 .40235 .34873 Metetra
.664 .741 .907 r
.40235 .34873 .40341 .34987 .4093 .34782 .40825 .34668 Metetra
.664 .741 .907 r
.40825 .34668 .4093 .34782 .41521 .34577 .41416 .34462 Metetra
.664 .741 .907 r
.41416 .34462 .41521 .34577 .42113 .34371 .42008 .34257 Metetra
.664 .741 .907 r
.42008 .34257 .42113 .34371 .42707 .34165 .42602 .3405 Metetra
.664 .741 .907 r
.42602 .3405 .42707 .34165 .43301 .33959 .43197 .33843 Metetra
.664 .741 .907 r
.43197 .33843 .43301 .33959 .43897 .33752 .43793 .33636 Metetra
.664 .741 .907 r
.43793 .33636 .43897 .33752 .44495 .33544 .44391 .33428 Metetra
.664 .741 .907 r
.44391 .33428 .44495 .33544 .45094 .33336 .44989 .3322 Metetra
.664 .741 .907 r
.44989 .3322 .45094 .33336 .45694 .33128 .4559 .33012 Metetra
.664 .741 .907 r
.4559 .33012 .45694 .33128 .46295 .32919 .46191 .32803 Metetra
.664 .741 .907 r
.46191 .32803 .46295 .32919 .46898 .3271 .46794 .32593 Metetra
.664 .741 .907 r
.46794 .32593 .46898 .3271 .47502 .325 .47399 .32383 Metetra
.664 .741 .907 r
.47399 .32383 .47502 .325 .48107 .3229 .48004 .32172 Metetra
.664 .741 .907 r
.48004 .32172 .48107 .3229 .48714 .32079 .48611 .31962 Metetra
.664 .741 .907 r
.48611 .31962 .48714 .32079 .49322 .31868 .49219 .3175 Metetra
.664 .741 .907 r
.49219 .3175 .49322 .31868 .49931 .31656 .49829 .31538 Metetra
.664 .741 .907 r
.49829 .31538 .49931 .31656 .50542 .31444 .5044 .31326 Metetra
.664 .741 .907 r
.5044 .31326 .50542 .31444 .51154 .31232 .51052 .31113 Metetra
.664 .741 .907 r
.51052 .31113 .51154 .31232 .51767 .31019 .51666 .309 Metetra
.664 .741 .907 r
.51666 .309 .51767 .31019 .52382 .30805 .52281 .30686 Metetra
.664 .741 .907 r
.52281 .30686 .52382 .30805 .52998 .30591 .52898 .30472 Metetra
.966 .651 .365 r
.52898 .30472 .52998 .30591 .53616 .30377 .5354 .37582 Metetra
.678 .421 .527 r
.5354 .37582 .53616 .30377 .54273 .36994 .5424 .5004 Metetra
.297 .126 .472 r
.5424 .5004 .54273 .36994 .54855 .29946 .54756 .29826 Metetra
.664 .741 .907 r
.54756 .29826 .54855 .29946 .55477 .2973 .55378 .2961 Metetra
.664 .741 .907 r
.55378 .2961 .55477 .2973 .561 .29514 .56001 .29393 Metetra
.664 .741 .907 r
.56001 .29393 .561 .29514 .56725 .29297 .56626 .29176 Metetra
.664 .741 .907 r
.56626 .29176 .56725 .29297 .57351 .29079 .57252 .28958 Metetra
.664 .741 .907 r
.57252 .28958 .57351 .29079 .57979 .28862 .5788 .2874 Metetra
.664 .741 .907 r
.5788 .2874 .57979 .28862 .58607 .28643 .58509 .28521 Metetra
.664 .741 .907 r
.58509 .28521 .58607 .28643 .59238 .28424 .5914 .28302 Metetra
.664 .741 .907 r
.5914 .28302 .59238 .28424 .59869 .28205 .59772 .28082 Metetra
.664 .741 .907 r
.59772 .28082 .59869 .28205 .60502 .27985 .60405 .27862 Metetra
.664 .741 .907 r
.60405 .27862 .60502 .27985 .61137 .27765 .6104 .27642 Metetra
.664 .741 .907 r
.6104 .27642 .61137 .27765 .61773 .27544 .61676 .2742 Metetra
.664 .741 .907 r
.61676 .2742 .61773 .27544 .62411 .27322 .62314 .27199 Metetra
.664 .741 .907 r
.62314 .27199 .62411 .27322 .6305 .271 .62953 .26976 Metetra
.664 .741 .907 r
.62953 .26976 .6305 .271 .6369 .26878 .63594 .26754 Metetra
.664 .741 .907 r
.63594 .26754 .6369 .26878 .64332 .26655 .64236 .26531 Metetra
.664 .741 .907 r
.64236 .26531 .64332 .26655 .64975 .26432 .6488 .26307 Metetra
.664 .741 .907 r
.6488 .26307 .64975 .26432 .6562 .26208 .65525 .26083 Metetra
.664 .741 .907 r
.65525 .26083 .6562 .26208 .66266 .25983 .66172 .25858 Metetra
.664 .741 .907 r
.66172 .25858 .66266 .25983 .66914 .25758 .6682 .25633 Metetra
.664 .741 .907 r
.6682 .25633 .66914 .25758 .67563 .25533 .67469 .25407 Metetra
.664 .741 .907 r
.67469 .25407 .67563 .25533 .68214 .25307 .6812 .25181 Metetra
.664 .741 .907 r
.6812 .25181 .68214 .25307 .68866 .2508 .68773 .24954 Metetra
.664 .741 .907 r
.68773 .24954 .68866 .2508 .6952 .24853 .69427 .24726 Metetra
.664 .741 .907 r
.69427 .24726 .6952 .24853 .70175 .24626 .70083 .24499 Metetra
.664 .741 .907 r
.70083 .24499 .70175 .24626 .70832 .24398 .7074 .2427 Metetra
.664 .741 .907 r
.7074 .2427 .70832 .24398 .7149 .24169 .71398 .24041 Metetra
.664 .741 .907 r
.71398 .24041 .7149 .24169 .7215 .2394 .72058 .23812 Metetra
.664 .741 .907 r
.72058 .23812 .7215 .2394 .72812 .2371 .7272 .23582 Metetra
.664 .741 .907 r
.7272 .23582 .72812 .2371 .73474 .2348 .73383 .23351 Metetra
.664 .741 .907 r
.73383 .23351 .73474 .2348 .74139 .23249 .74048 .2312 Metetra
.664 .741 .907 r
.74048 .2312 .74139 .23249 .74805 .23018 .74714 .22889 Metetra
.664 .741 .907 r
.74714 .22889 .74805 .23018 .75472 .22786 .75382 .22657 Metetra
.664 .741 .907 r
.75382 .22657 .75472 .22786 .76142 .22554 .76052 .22424 Metetra
.664 .741 .907 r
.76052 .22424 .76142 .22554 .76812 .22321 .76723 .22191 Metetra
.664 .741 .907 r
.76723 .22191 .76812 .22321 .77484 .22087 .77395 .21957 Metetra
.664 .741 .907 r
.77395 .21957 .77484 .22087 .78158 .21853 .7807 .21723 Metetra
.664 .741 .907 r
.7807 .21723 .78158 .21853 .78834 .21619 .78745 .21488 Metetra
.664 .741 .907 r
.78745 .21488 .78834 .21619 .79511 .21384 .79423 .21252 Metetra
.664 .741 .907 r
.79423 .21252 .79511 .21384 .80189 .21148 .80102 .21016 Metetra
.664 .741 .907 r
.80102 .21016 .80189 .21148 .80869 .20912 .80782 .2078 Metetra
.664 .741 .907 r
.80782 .2078 .80869 .20912 .81551 .20675 .81464 .20543 Metetra
.664 .741 .907 r
.81464 .20543 .81551 .20675 .82235 .20438 .82148 .20305 Metetra
.664 .741 .907 r
.2081 .41479 .20924 .41585 .21472 .41394 .21358 .41288 Metetra
.664 .741 .907 r
.21358 .41288 .21472 .41394 .22021 .41203 .21908 .41097 Metetra
.664 .741 .907 r
.21908 .41097 .22021 .41203 .22572 .41012 .22459 .40905 Metetra
.664 .741 .907 r
.22459 .40905 .22572 .41012 .23123 .4082 .2301 .40713 Metetra
.664 .741 .907 r
.2301 .40713 .23123 .4082 .23676 .40628 .23563 .40521 Metetra
.664 .741 .907 r
.23563 .40521 .23676 .40628 .2423 .40436 .24118 .40328 Metetra
.664 .741 .907 r
.24118 .40328 .2423 .40436 .24785 .40243 .24673 .40135 Metetra
.664 .741 .907 r
.24673 .40135 .24785 .40243 .25342 .40049 .2523 .39941 Metetra
.664 .741 .907 r
.2523 .39941 .25342 .40049 .25899 .39855 .25787 .39747 Metetra
.664 .741 .907 r
.25787 .39747 .25899 .39855 .26458 .39661 .26346 .39553 Metetra
.664 .741 .907 r
.26346 .39553 .26458 .39661 .27018 .39467 .26906 .39358 Metetra
.664 .741 .907 r
.26906 .39358 .27018 .39467 .27579 .39272 .27468 .39163 Metetra
.664 .741 .907 r
.27468 .39163 .27579 .39272 .28141 .39076 .2803 .38967 Metetra
.664 .741 .907 r
.2803 .38967 .28141 .39076 .28705 .3888 .28594 .38771 Metetra
.664 .741 .907 r
.28594 .38771 .28705 .3888 .2927 .38684 .29159 .38574 Metetra
.664 .741 .907 r
.29159 .38574 .2927 .38684 .29836 .38487 .29725 .38377 Metetra
.664 .741 .907 r
.29725 .38377 .29836 .38487 .30403 .3829 .30293 .3818 Metetra
.664 .741 .907 r
.30293 .3818 .30403 .3829 .30971 .38093 .30861 .37982 Metetra
.664 .741 .907 r
.30861 .37982 .30971 .38093 .31541 .37895 .31431 .37784 Metetra
.664 .741 .907 r
.31431 .37784 .31541 .37895 .32112 .37696 .32002 .37585 Metetra
.664 .741 .907 r
.32002 .37585 .32112 .37696 .32684 .37497 .32574 .37386 Metetra
.664 .741 .907 r
.32574 .37386 .32684 .37497 .33257 .37298 .33148 .37187 Metetra
.664 .741 .907 r
.33148 .37187 .33257 .37298 .33832 .37098 .33723 .36987 Metetra
.664 .741 .907 r
.33723 .36987 .33832 .37098 .34407 .36898 .34299 .36786 Metetra
.664 .741 .907 r
.34299 .36786 .34407 .36898 .34984 .36698 .34876 .36586 Metetra
.664 .741 .907 r
.34876 .36586 .34984 .36698 .35563 .36497 .35455 .36384 Metetra
.664 .741 .907 r
.35455 .36384 .35563 .36497 .36142 .36295 .36034 .36183 Metetra
.664 .741 .907 r
.36034 .36183 .36142 .36295 .36723 .36093 .36616 .35981 Metetra
.664 .741 .907 r
.36616 .35981 .36723 .36093 .37305 .35891 .37198 .35778 Metetra
.664 .741 .907 r
.37198 .35778 .37305 .35891 .37889 .35688 .37781 .35575 Metetra
.664 .741 .907 r
.37781 .35575 .37889 .35688 .38473 .35485 .38366 .35372 Metetra
.664 .741 .907 r
.38366 .35372 .38473 .35485 .39059 .35281 .38952 .35168 Metetra
.664 .741 .907 r
.38952 .35168 .39059 .35281 .39646 .35077 .3954 .34963 Metetra
.664 .741 .907 r
.3954 .34963 .39646 .35077 .40235 .34873 .40129 .34759 Metetra
.664 .741 .907 r
.40129 .34759 .40235 .34873 .40825 .34668 .40719 .34553 Metetra
.664 .741 .907 r
.40719 .34553 .40825 .34668 .41416 .34462 .4131 .34348 Metetra
.664 .741 .907 r
.4131 .34348 .41416 .34462 .42008 .34257 .41903 .34142 Metetra
.664 .741 .907 r
.41903 .34142 .42008 .34257 .42602 .3405 .42497 .33935 Metetra
.664 .741 .907 r
.42497 .33935 .42602 .3405 .43197 .33843 .43092 .33728 Metetra
.664 .741 .907 r
.43092 .33728 .43197 .33843 .43793 .33636 .43688 .3352 Metetra
.664 .741 .907 r
.43688 .3352 .43793 .33636 .44391 .33428 .44286 .33312 Metetra
.664 .741 .907 r
.44286 .33312 .44391 .33428 .44989 .3322 .44885 .33104 Metetra
.664 .741 .907 r
.44885 .33104 .44989 .3322 .4559 .33012 .45486 .32895 Metetra
.664 .741 .907 r
.45486 .32895 .4559 .33012 .46191 .32803 .46088 .32686 Metetra
.664 .741 .907 r
.46088 .32686 .46191 .32803 .46794 .32593 .46691 .32476 Metetra
.664 .741 .907 r
.46691 .32476 .46794 .32593 .47399 .32383 .47295 .32266 Metetra
.664 .741 .907 r
.47295 .32266 .47399 .32383 .48004 .32172 .47901 .32055 Metetra
.664 .741 .907 r
.47901 .32055 .48004 .32172 .48611 .31962 .48508 .31844 Metetra
.664 .741 .907 r
.48508 .31844 .48611 .31962 .49219 .3175 .49117 .31632 Metetra
.664 .741 .907 r
.49117 .31632 .49219 .3175 .49829 .31538 .49727 .3142 Metetra
.664 .741 .907 r
.49727 .3142 .49829 .31538 .5044 .31326 .50338 .31207 Metetra
.664 .741 .907 r
.50338 .31207 .5044 .31326 .51052 .31113 .50951 .30994 Metetra
.664 .741 .907 r
.50951 .30994 .51052 .31113 .51666 .309 .51565 .3078 Metetra
.664 .741 .907 r
.51565 .3078 .51666 .309 .52281 .30686 .5218 .30566 Metetra
.664 .741 .907 r
.5218 .30566 .52281 .30686 .52898 .30472 .52797 .30352 Metetra
.969 .672 .408 r
.52797 .30352 .52898 .30472 .5354 .37582 .53464 .46617 Metetra
.435 .229 .5 r
.53464 .46617 .5354 .37582 .5424 .5004 .54083 .39616 Metetra
.636 .397 .54 r
.54083 .39616 .5424 .5004 .54756 .29826 .54656 .29705 Metetra
.664 .741 .907 r
.54656 .29705 .54756 .29826 .55378 .2961 .55278 .29489 Metetra
.664 .741 .907 r
.55278 .29489 .55378 .2961 .56001 .29393 .55902 .29272 Metetra
.664 .741 .907 r
.55902 .29272 .56001 .29393 .56626 .29176 .56527 .29054 Metetra
.664 .741 .907 r
.56527 .29054 .56626 .29176 .57252 .28958 .57154 .28836 Metetra
.664 .741 .907 r
.57154 .28836 .57252 .28958 .5788 .2874 .57782 .28618 Metetra
.664 .741 .907 r
.57782 .28618 .5788 .2874 .58509 .28521 .58411 .28399 Metetra
.664 .741 .907 r
.58411 .28399 .58509 .28521 .5914 .28302 .59042 .2818 Metetra
.664 .741 .907 r
.59042 .2818 .5914 .28302 .59772 .28082 .59674 .2796 Metetra
.664 .741 .907 r
.59674 .2796 .59772 .28082 .60405 .27862 .60308 .27739 Metetra
.664 .741 .907 r
.60308 .27739 .60405 .27862 .6104 .27642 .60943 .27518 Metetra
.664 .741 .907 r
.60943 .27518 .6104 .27642 .61676 .2742 .6158 .27297 Metetra
.664 .741 .907 r
.6158 .27297 .61676 .2742 .62314 .27199 .62218 .27075 Metetra
.664 .741 .907 r
.62218 .27075 .62314 .27199 .62953 .26976 .62857 .26852 Metetra
.664 .741 .907 r
.62857 .26852 .62953 .26976 .63594 .26754 .63498 .26629 Metetra
.664 .741 .907 r
.63498 .26629 .63594 .26754 .64236 .26531 .64141 .26406 Metetra
.664 .741 .907 r
.64141 .26406 .64236 .26531 .6488 .26307 .64785 .26182 Metetra
.664 .741 .907 r
.64785 .26182 .6488 .26307 .65525 .26083 .6543 .25957 Metetra
.664 .741 .907 r
.6543 .25957 .65525 .26083 .66172 .25858 .66077 .25732 Metetra
.664 .741 .907 r
.66077 .25732 .66172 .25858 .6682 .25633 .66725 .25507 Metetra
.664 .741 .907 r
.66725 .25507 .6682 .25633 .67469 .25407 .67375 .25281 Metetra
.664 .741 .907 r
.67375 .25281 .67469 .25407 .6812 .25181 .68027 .25054 Metetra
.664 .741 .907 r
.68027 .25054 .6812 .25181 .68773 .24954 .6868 .24827 Metetra
.664 .741 .907 r
.6868 .24827 .68773 .24954 .69427 .24726 .69334 .24599 Metetra
.664 .741 .907 r
.69334 .24599 .69427 .24726 .70083 .24499 .6999 .24371 Metetra
.664 .741 .907 r
.6999 .24371 .70083 .24499 .7074 .2427 .70647 .24143 Metetra
.664 .741 .907 r
.70647 .24143 .7074 .2427 .71398 .24041 .71306 .23913 Metetra
.664 .741 .907 r
.71306 .23913 .71398 .24041 .72058 .23812 .71967 .23684 Metetra
.664 .741 .907 r
.71967 .23684 .72058 .23812 .7272 .23582 .72629 .23453 Metetra
.664 .741 .907 r
.72629 .23453 .7272 .23582 .73383 .23351 .73292 .23223 Metetra
.664 .741 .907 r
.73292 .23223 .73383 .23351 .74048 .2312 .73957 .22991 Metetra
.664 .741 .907 r
.73957 .22991 .74048 .2312 .74714 .22889 .74624 .22759 Metetra
.664 .741 .907 r
.74624 .22759 .74714 .22889 .75382 .22657 .75292 .22527 Metetra
.664 .741 .907 r
.75292 .22527 .75382 .22657 .76052 .22424 .75962 .22294 Metetra
.664 .741 .907 r
.75962 .22294 .76052 .22424 .76723 .22191 .76633 .2206 Metetra
.664 .741 .907 r
.76633 .2206 .76723 .22191 .77395 .21957 .77306 .21826 Metetra
.664 .741 .907 r
.77306 .21826 .77395 .21957 .7807 .21723 .77981 .21592 Metetra
.664 .741 .907 r
.77981 .21592 .7807 .21723 .78745 .21488 .78657 .21356 Metetra
.664 .741 .907 r
.78657 .21356 .78745 .21488 .79423 .21252 .79334 .21121 Metetra
.664 .741 .907 r
.79334 .21121 .79423 .21252 .80102 .21016 .80014 .20884 Metetra
.664 .741 .907 r
.80014 .20884 .80102 .21016 .80782 .2078 .80695 .20648 Metetra
.664 .741 .907 r
.80695 .20648 .80782 .2078 .81464 .20543 .81377 .2041 Metetra
.664 .741 .907 r
.81377 .2041 .81464 .20543 .82148 .20305 .82061 .20172 Metetra
.664 .741 .907 r
.20696 .41372 .2081 .41479 .21358 .41288 .21245 .41181 Metetra
.664 .741 .907 r
.21245 .41181 .21358 .41288 .21908 .41097 .21794 .4099 Metetra
.664 .741 .907 r
.21794 .4099 .21908 .41097 .22459 .40905 .22345 .40798 Metetra
.664 .741 .907 r
.22345 .40798 .22459 .40905 .2301 .40713 .22897 .40606 Metetra
.664 .741 .907 r
.22897 .40606 .2301 .40713 .23563 .40521 .23451 .40413 Metetra
.664 .741 .907 r
.23451 .40413 .23563 .40521 .24118 .40328 .24005 .4022 Metetra
.664 .741 .907 r
.24005 .4022 .24118 .40328 .24673 .40135 .24561 .40027 Metetra
.664 .741 .907 r
.24561 .40027 .24673 .40135 .2523 .39941 .25117 .39833 Metetra
.664 .741 .907 r
.25117 .39833 .2523 .39941 .25787 .39747 .25675 .39639 Metetra
.664 .741 .907 r
.25675 .39639 .25787 .39747 .26346 .39553 .26235 .39444 Metetra
.664 .741 .907 r
.26235 .39444 .26346 .39553 .26906 .39358 .26795 .39249 Metetra
.664 .741 .907 r
.26795 .39249 .26906 .39358 .27468 .39163 .27356 .39054 Metetra
.664 .741 .907 r
.27356 .39054 .27468 .39163 .2803 .38967 .27919 .38858 Metetra
.664 .741 .907 r
.27919 .38858 .2803 .38967 .28594 .38771 .28483 .38661 Metetra
.664 .741 .907 r
.28483 .38661 .28594 .38771 .29159 .38574 .29048 .38465 Metetra
.664 .741 .907 r
.29048 .38465 .29159 .38574 .29725 .38377 .29615 .38267 Metetra
.664 .741 .907 r
.29615 .38267 .29725 .38377 .30293 .3818 .30182 .3807 Metetra
.664 .741 .907 r
.30182 .3807 .30293 .3818 .30861 .37982 .30751 .37872 Metetra
.664 .741 .907 r
.30751 .37872 .30861 .37982 .31431 .37784 .31321 .37673 Metetra
.664 .741 .907 r
.31321 .37673 .31431 .37784 .32002 .37585 .31893 .37474 Metetra
.664 .741 .907 r
.31893 .37474 .32002 .37585 .32574 .37386 .32465 .37275 Metetra
.664 .741 .907 r
.32465 .37275 .32574 .37386 .33148 .37187 .33039 .37075 Metetra
.664 .741 .907 r
.33039 .37075 .33148 .37187 .33723 .36987 .33614 .36875 Metetra
.664 .741 .907 r
.33614 .36875 .33723 .36987 .34299 .36786 .3419 .36675 Metetra
.664 .741 .907 r
.3419 .36675 .34299 .36786 .34876 .36586 .34768 .36473 Metetra
.664 .741 .907 r
.34768 .36473 .34876 .36586 .35455 .36384 .35346 .36272 Metetra
.664 .741 .907 r
.35346 .36272 .35455 .36384 .36034 .36183 .35926 .3607 Metetra
.664 .741 .907 r
.35926 .3607 .36034 .36183 .36616 .35981 .36508 .35868 Metetra
.664 .741 .907 r
.36508 .35868 .36616 .35981 .37198 .35778 .3709 .35665 Metetra
.664 .741 .907 r
.3709 .35665 .37198 .35778 .37781 .35575 .37674 .35462 Metetra
.664 .741 .907 r
.37674 .35462 .37781 .35575 .38366 .35372 .38259 .35258 Metetra
.664 .741 .907 r
.38259 .35258 .38366 .35372 .38952 .35168 .38846 .35054 Metetra
.664 .741 .907 r
.38846 .35054 .38952 .35168 .3954 .34963 .39433 .34849 Metetra
.664 .741 .907 r
.39433 .34849 .3954 .34963 .40129 .34759 .40022 .34644 Metetra
.664 .741 .907 r
.40022 .34644 .40129 .34759 .40719 .34553 .40613 .34439 Metetra
.664 .741 .907 r
.40613 .34439 .40719 .34553 .4131 .34348 .41204 .34233 Metetra
.664 .741 .907 r
.41204 .34233 .4131 .34348 .41903 .34142 .41797 .34026 Metetra
.664 .741 .907 r
.41797 .34026 .41903 .34142 .42497 .33935 .42391 .33819 Metetra
.664 .741 .907 r
.42391 .33819 .42497 .33935 .43092 .33728 .42987 .33612 Metetra
.664 .741 .907 r
.42987 .33612 .43092 .33728 .43688 .3352 .43583 .33404 Metetra
.664 .741 .907 r
.43583 .33404 .43688 .3352 .44286 .33312 .44182 .33196 Metetra
.664 .741 .907 r
.44182 .33196 .44286 .33312 .44885 .33104 .44781 .32988 Metetra
.664 .741 .907 r
.44781 .32988 .44885 .33104 .45486 .32895 .45382 .32778 Metetra
.664 .741 .907 r
.45382 .32778 .45486 .32895 .46088 .32686 .45984 .32569 Metetra
.664 .741 .907 r
.45984 .32569 .46088 .32686 .46691 .32476 .46587 .32359 Metetra
.664 .741 .907 r
.46587 .32359 .46691 .32476 .47295 .32266 .47192 .32148 Metetra
.664 .741 .907 r
.47192 .32148 .47295 .32266 .47901 .32055 .47798 .31937 Metetra
.664 .741 .907 r
.47798 .31937 .47901 .32055 .48508 .31844 .48406 .31726 Metetra
.664 .741 .907 r
.48406 .31726 .48508 .31844 .49117 .31632 .49015 .31514 Metetra
.664 .741 .907 r
.49015 .31514 .49117 .31632 .49727 .3142 .49625 .31301 Metetra
.664 .741 .907 r
.49625 .31301 .49727 .3142 .50338 .31207 .50236 .31088 Metetra
.664 .741 .907 r
.50236 .31088 .50338 .31207 .50951 .30994 .50849 .30875 Metetra
.664 .741 .907 r
.50849 .30875 .50951 .30994 .51565 .3078 .51464 .30661 Metetra
.664 .741 .907 r
.51464 .30661 .51565 .3078 .5218 .30566 .52079 .30447 Metetra
.664 .741 .907 r
.52079 .30447 .5218 .30566 .52797 .30352 .52696 .30232 Metetra
.968 .669 .402 r
.52696 .30232 .52797 .30352 .53464 .46617 .53351 .4387 Metetra
.826 .56 .537 r
.53351 .4387 .53464 .46617 .54083 .39616 .53935 .29801 Metetra
.541 .323 .532 r
.53935 .29801 .54083 .39616 .54656 .29705 .54556 .29585 Metetra
.664 .741 .907 r
.54556 .29585 .54656 .29705 .55278 .29489 .55178 .29368 Metetra
.664 .741 .907 r
.55178 .29368 .55278 .29489 .55902 .29272 .55802 .29151 Metetra
.664 .741 .907 r
.55802 .29151 .55902 .29272 .56527 .29054 .56428 .28933 Metetra
.664 .741 .907 r
.56428 .28933 .56527 .29054 .57154 .28836 .57055 .28715 Metetra
.664 .741 .907 r
.57055 .28715 .57154 .28836 .57782 .28618 .57683 .28496 Metetra
.664 .741 .907 r
.57683 .28496 .57782 .28618 .58411 .28399 .58313 .28277 Metetra
.664 .741 .907 r
.58313 .28277 .58411 .28399 .59042 .2818 .58944 .28057 Metetra
.664 .741 .907 r
.58944 .28057 .59042 .2818 .59674 .2796 .59576 .27837 Metetra
.664 .741 .907 r
.59576 .27837 .59674 .2796 .60308 .27739 .6021 .27616 Metetra
.664 .741 .907 r
.6021 .27616 .60308 .27739 .60943 .27518 .60846 .27395 Metetra
.664 .741 .907 r
.60846 .27395 .60943 .27518 .6158 .27297 .61483 .27173 Metetra
.664 .741 .907 r
.61483 .27173 .6158 .27297 .62218 .27075 .62121 .26951 Metetra
.664 .741 .907 r
.62121 .26951 .62218 .27075 .62857 .26852 .62761 .26728 Metetra
.664 .741 .907 r
.62761 .26728 .62857 .26852 .63498 .26629 .63402 .26505 Metetra
.664 .741 .907 r
.63402 .26505 .63498 .26629 .64141 .26406 .64045 .26281 Metetra
.664 .741 .907 r
.64045 .26281 .64141 .26406 .64785 .26182 .64689 .26057 Metetra
.664 .741 .907 r
.64689 .26057 .64785 .26182 .6543 .25957 .65335 .25832 Metetra
.664 .741 .907 r
.65335 .25832 .6543 .25957 .66077 .25732 .65982 .25607 Metetra
.664 .741 .907 r
.65982 .25607 .66077 .25732 .66725 .25507 .66631 .25381 Metetra
.664 .741 .907 r
.66631 .25381 .66725 .25507 .67375 .25281 .67281 .25154 Metetra
.664 .741 .907 r
.67281 .25154 .67375 .25281 .68027 .25054 .67933 .24928 Metetra
.664 .741 .907 r
.67933 .24928 .68027 .25054 .6868 .24827 .68586 .247 Metetra
.664 .741 .907 r
.68586 .247 .6868 .24827 .69334 .24599 .69241 .24472 Metetra
.664 .741 .907 r
.69241 .24472 .69334 .24599 .6999 .24371 .69897 .24244 Metetra
.664 .741 .907 r
.69897 .24244 .6999 .24371 .70647 .24143 .70555 .24015 Metetra
.664 .741 .907 r
.70555 .24015 .70647 .24143 .71306 .23913 .71214 .23785 Metetra
.664 .741 .907 r
.71214 .23785 .71306 .23913 .71967 .23684 .71875 .23555 Metetra
.664 .741 .907 r
.71875 .23555 .71967 .23684 .72629 .23453 .72537 .23325 Metetra
.664 .741 .907 r
.72537 .23325 .72629 .23453 .73292 .23223 .73201 .23094 Metetra
.664 .741 .907 r
.73201 .23094 .73292 .23223 .73957 .22991 .73866 .22862 Metetra
.664 .741 .907 r
.73866 .22862 .73957 .22991 .74624 .22759 .74533 .2263 Metetra
.664 .741 .907 r
.74533 .2263 .74624 .22759 .75292 .22527 .75202 .22397 Metetra
.664 .741 .907 r
.75202 .22397 .75292 .22527 .75962 .22294 .75872 .22164 Metetra
.664 .741 .907 r
.75872 .22164 .75962 .22294 .76633 .2206 .76544 .2193 Metetra
.664 .741 .907 r
.76544 .2193 .76633 .2206 .77306 .21826 .77217 .21695 Metetra
.664 .741 .907 r
.77217 .21695 .77306 .21826 .77981 .21592 .77892 .21461 Metetra
.664 .741 .907 r
.77892 .21461 .77981 .21592 .78657 .21356 .78568 .21225 Metetra
.664 .741 .907 r
.78568 .21225 .78657 .21356 .79334 .21121 .79246 .20989 Metetra
.664 .741 .907 r
.79246 .20989 .79334 .21121 .80014 .20884 .79926 .20752 Metetra
.664 .741 .907 r
.79926 .20752 .80014 .20884 .80695 .20648 .80607 .20515 Metetra
.664 .741 .907 r
.80607 .20515 .80695 .20648 .81377 .2041 .8129 .20278 Metetra
.664 .741 .907 r
.8129 .20278 .81377 .2041 .82061 .20172 .81974 .20039 Metetra
.664 .741 .907 r
.20582 .41266 .20696 .41372 .21245 .41181 .21131 .41075 Metetra
.664 .741 .907 r
.21131 .41075 .21245 .41181 .21794 .4099 .21681 .40883 Metetra
.664 .741 .907 r
.21681 .40883 .21794 .4099 .22345 .40798 .22232 .40691 Metetra
.664 .741 .907 r
.22232 .40691 .22345 .40798 .22897 .40606 .22784 .40499 Metetra
.664 .741 .907 r
.22784 .40499 .22897 .40606 .23451 .40413 .23338 .40306 Metetra
.664 .741 .907 r
.23338 .40306 .23451 .40413 .24005 .4022 .23892 .40113 Metetra
.664 .741 .907 r
.23892 .40113 .24005 .4022 .24561 .40027 .24448 .39919 Metetra
.664 .741 .907 r
.24448 .39919 .24561 .40027 .25117 .39833 .25005 .39725 Metetra
.664 .741 .907 r
.25005 .39725 .25117 .39833 .25675 .39639 .25563 .3953 Metetra
.664 .741 .907 r
.25563 .3953 .25675 .39639 .26235 .39444 .26123 .39335 Metetra
.664 .741 .907 r
.26123 .39335 .26235 .39444 .26795 .39249 .26683 .3914 Metetra
.664 .741 .907 r
.26683 .3914 .26795 .39249 .27356 .39054 .27245 .38944 Metetra
.664 .741 .907 r
.27245 .38944 .27356 .39054 .27919 .38858 .27808 .38748 Metetra
.664 .741 .907 r
.27808 .38748 .27919 .38858 .28483 .38661 .28372 .38552 Metetra
.664 .741 .907 r
.28372 .38552 .28483 .38661 .29048 .38465 .28938 .38355 Metetra
.664 .741 .907 r
.28938 .38355 .29048 .38465 .29615 .38267 .29504 .38157 Metetra
.664 .741 .907 r
.29504 .38157 .29615 .38267 .30182 .3807 .30072 .37959 Metetra
.664 .741 .907 r
.30072 .37959 .30182 .3807 .30751 .37872 .30641 .37761 Metetra
.664 .741 .907 r
.30641 .37761 .30751 .37872 .31321 .37673 .31211 .37562 Metetra
.664 .741 .907 r
.31211 .37562 .31321 .37673 .31893 .37474 .31783 .37363 Metetra
.664 .741 .907 r
.31783 .37363 .31893 .37474 .32465 .37275 .32356 .37164 Metetra
.863 .421 .024 r
.32356 .37164 .32465 .37275 .33039 .37075 .32852 .38233 Metetra
.319 .089 .399 r
.32852 .38233 .33039 .37075 .33614 .36875 .33505 .36763 Metetra
.664 .741 .907 r
.33505 .36763 .33614 .36875 .3419 .36675 .34081 .36562 Metetra
.664 .741 .907 r
.34081 .36562 .3419 .36675 .34768 .36473 .34659 .36361 Metetra
.664 .741 .907 r
.34659 .36361 .34768 .36473 .35346 .36272 .35238 .36159 Metetra
.664 .741 .907 r
.35238 .36159 .35346 .36272 .35926 .3607 .35818 .35957 Metetra
.664 .741 .907 r
.35818 .35957 .35926 .3607 .36508 .35868 .364 .35755 Metetra
.664 .741 .907 r
.364 .35755 .36508 .35868 .3709 .35665 .36983 .35552 Metetra
.664 .741 .907 r
.36983 .35552 .3709 .35665 .37674 .35462 .37567 .35348 Metetra
.664 .741 .907 r
.37567 .35348 .37674 .35462 .38259 .35258 .38152 .35144 Metetra
.664 .741 .907 r
.38152 .35144 .38259 .35258 .38846 .35054 .38739 .3494 Metetra
.664 .741 .907 r
.38739 .3494 .38846 .35054 .39433 .34849 .39327 .34735 Metetra
.664 .741 .907 r
.39327 .34735 .39433 .34849 .40022 .34644 .39916 .3453 Metetra
.664 .741 .907 r
.39916 .3453 .40022 .34644 .40613 .34439 .40506 .34324 Metetra
.664 .741 .907 r
.40506 .34324 .40613 .34439 .41204 .34233 .41098 .34118 Metetra
.664 .741 .907 r
.41098 .34118 .41204 .34233 .41797 .34026 .41691 .33911 Metetra
.664 .741 .907 r
.41691 .33911 .41797 .34026 .42391 .33819 .42286 .33704 Metetra
.664 .741 .907 r
.42286 .33704 .42391 .33819 .42987 .33612 .42882 .33496 Metetra
.664 .741 .907 r
.42882 .33496 .42987 .33612 .43583 .33404 .43479 .33288 Metetra
.664 .741 .907 r
.43479 .33288 .43583 .33404 .44182 .33196 .44077 .3308 Metetra
.664 .741 .907 r
.44077 .3308 .44182 .33196 .44781 .32988 .44677 .32871 Metetra
.664 .741 .907 r
.44677 .32871 .44781 .32988 .45382 .32778 .45278 .32662 Metetra
.664 .741 .907 r
.45278 .32662 .45382 .32778 .45984 .32569 .4588 .32452 Metetra
.664 .741 .907 r
.4588 .32452 .45984 .32569 .46587 .32359 .46484 .32241 Metetra
.664 .741 .907 r
.46484 .32241 .46587 .32359 .47192 .32148 .47089 .3203 Metetra
.664 .741 .907 r
.47089 .3203 .47192 .32148 .47798 .31937 .47695 .31819 Metetra
.664 .741 .907 r
.47695 .31819 .47798 .31937 .48406 .31726 .48303 .31607 Metetra
.664 .741 .907 r
.48303 .31607 .48406 .31726 .49015 .31514 .48912 .31395 Metetra
.664 .741 .907 r
.48912 .31395 .49015 .31514 .49625 .31301 .49522 .31183 Metetra
.664 .741 .907 r
.49522 .31183 .49625 .31301 .50236 .31088 .50134 .30969 Metetra
.664 .741 .907 r
.50134 .30969 .50236 .31088 .50849 .30875 .50747 .30756 Metetra
.664 .741 .907 r
.50747 .30756 .50849 .30875 .51464 .30661 .51362 .30542 Metetra
.664 .741 .907 r
.51362 .30542 .51464 .30661 .52079 .30447 .51978 .30327 Metetra
.664 .741 .907 r
.51978 .30327 .52079 .30447 .52696 .30232 .52595 .30112 Metetra
.664 .741 .907 r
.52595 .30112 .52696 .30232 .53351 .4387 .53214 .29896 Metetra
.515 .301 .527 r
.53214 .29896 .53351 .4387 .53935 .29801 .53846 .32413 Metetra
.375 .167 .466 r
.53846 .32413 .53935 .29801 .54556 .29585 .54456 .29464 Metetra
.664 .741 .907 r
.54456 .29464 .54556 .29585 .55178 .29368 .55078 .29247 Metetra
.664 .741 .907 r
.55078 .29247 .55178 .29368 .55802 .29151 .55703 .29029 Metetra
.664 .741 .907 r
.55703 .29029 .55802 .29151 .56428 .28933 .56329 .28811 Metetra
.664 .741 .907 r
.56329 .28811 .56428 .28933 .57055 .28715 .56956 .28593 Metetra
.664 .741 .907 r
.56956 .28593 .57055 .28715 .57683 .28496 .57584 .28374 Metetra
.664 .741 .907 r
.57584 .28374 .57683 .28496 .58313 .28277 .58214 .28154 Metetra
.664 .741 .907 r
.58214 .28154 .58313 .28277 .58944 .28057 .58846 .27934 Metetra
.664 .741 .907 r
.58846 .27934 .58944 .28057 .59576 .27837 .59479 .27714 Metetra
.664 .741 .907 r
.59479 .27714 .59576 .27837 .6021 .27616 .60113 .27493 Metetra
.664 .741 .907 r
.60113 .27493 .6021 .27616 .60846 .27395 .60749 .27271 Metetra
.664 .741 .907 r
.60749 .27271 .60846 .27395 .61483 .27173 .61386 .27049 Metetra
.664 .741 .907 r
.61386 .27049 .61483 .27173 .62121 .26951 .62024 .26827 Metetra
.664 .741 .907 r
.62024 .26827 .62121 .26951 .62761 .26728 .62665 .26604 Metetra
.664 .741 .907 r
.62665 .26604 .62761 .26728 .63402 .26505 .63306 .2638 Metetra
.664 .741 .907 r
.63306 .2638 .63402 .26505 .64045 .26281 .63949 .26156 Metetra
.664 .741 .907 r
.63949 .26156 .64045 .26281 .64689 .26057 .64594 .25931 Metetra
.664 .741 .907 r
.64594 .25931 .64689 .26057 .65335 .25832 .6524 .25706 Metetra
.664 .741 .907 r
.6524 .25706 .65335 .25832 .65982 .25607 .65887 .25481 Metetra
.664 .741 .907 r
.65887 .25481 .65982 .25607 .66631 .25381 .66536 .25255 Metetra
.664 .741 .907 r
.66536 .25255 .66631 .25381 .67281 .25154 .67187 .25028 Metetra
.664 .741 .907 r
.67187 .25028 .67281 .25154 .67933 .24928 .67839 .24801 Metetra
.664 .741 .907 r
.67839 .24801 .67933 .24928 .68586 .247 .68492 .24573 Metetra
.664 .741 .907 r
.68492 .24573 .68586 .247 .69241 .24472 .69147 .24345 Metetra
.664 .741 .907 r
.69147 .24345 .69241 .24472 .69897 .24244 .69804 .24116 Metetra
.664 .741 .907 r
.69804 .24116 .69897 .24244 .70555 .24015 .70462 .23887 Metetra
.664 .741 .907 r
.70462 .23887 .70555 .24015 .71214 .23785 .71121 .23657 Metetra
.664 .741 .907 r
.71121 .23657 .71214 .23785 .71875 .23555 .71783 .23427 Metetra
.664 .741 .907 r
.71783 .23427 .71875 .23555 .72537 .23325 .72445 .23196 Metetra
.664 .741 .907 r
.72445 .23196 .72537 .23325 .73201 .23094 .73109 .22964 Metetra
.664 .741 .907 r
.73109 .22964 .73201 .23094 .73866 .22862 .73775 .22732 Metetra
.664 .741 .907 r
.73775 .22732 .73866 .22862 .74533 .2263 .74443 .225 Metetra
.664 .741 .907 r
.74443 .225 .74533 .2263 .75202 .22397 .75111 .22267 Metetra
.664 .741 .907 r
.75111 .22267 .75202 .22397 .75872 .22164 .75782 .22033 Metetra
.664 .741 .907 r
.75782 .22033 .75872 .22164 .76544 .2193 .76454 .21799 Metetra
.664 .741 .907 r
.76454 .21799 .76544 .2193 .77217 .21695 .77127 .21565 Metetra
.664 .741 .907 r
.77127 .21565 .77217 .21695 .77892 .21461 .77803 .21329 Metetra
.664 .741 .907 r
.77803 .21329 .77892 .21461 .78568 .21225 .78479 .21093 Metetra
.664 .741 .907 r
.78479 .21093 .78568 .21225 .79246 .20989 .79158 .20857 Metetra
.664 .741 .907 r
.79158 .20857 .79246 .20989 .79926 .20752 .79838 .2062 Metetra
.664 .741 .907 r
.79838 .2062 .79926 .20752 .80607 .20515 .80519 .20383 Metetra
.664 .741 .907 r
.80519 .20383 .80607 .20515 .8129 .20278 .81202 .20145 Metetra
.664 .741 .907 r
.81202 .20145 .8129 .20278 .81974 .20039 .81887 .19906 Metetra
.664 .741 .907 r
.20468 .41159 .20582 .41266 .21131 .41075 .21017 .40968 Metetra
.664 .741 .907 r
.21017 .40968 .21131 .41075 .21681 .40883 .21567 .40776 Metetra
.664 .741 .907 r
.21567 .40776 .21681 .40883 .22232 .40691 .22118 .40584 Metetra
.664 .741 .907 r
.22118 .40584 .22232 .40691 .22784 .40499 .22671 .40391 Metetra
.664 .741 .907 r
.22671 .40391 .22784 .40499 .23338 .40306 .23225 .40198 Metetra
.664 .741 .907 r
.23225 .40198 .23338 .40306 .23892 .40113 .23779 .40005 Metetra
.664 .741 .907 r
.23779 .40005 .23892 .40113 .24448 .39919 .24335 .39811 Metetra
.664 .741 .907 r
.24335 .39811 .24448 .39919 .25005 .39725 .24893 .39616 Metetra
.664 .741 .907 r
.24893 .39616 .25005 .39725 .25563 .3953 .25451 .39422 Metetra
.664 .741 .907 r
.25451 .39422 .25563 .3953 .26123 .39335 .26011 .39227 Metetra
.664 .741 .907 r
.26011 .39227 .26123 .39335 .26683 .3914 .26571 .39031 Metetra
.664 .741 .907 r
.26571 .39031 .26683 .3914 .27245 .38944 .27133 .38835 Metetra
.664 .741 .907 r
.27133 .38835 .27245 .38944 .27808 .38748 .27697 .38639 Metetra
.664 .741 .907 r
.27697 .38639 .27808 .38748 .28372 .38552 .28261 .38442 Metetra
.664 .741 .907 r
.28261 .38442 .28372 .38552 .28938 .38355 .28827 .38245 Metetra
.664 .741 .907 r
.28827 .38245 .28938 .38355 .29504 .38157 .29393 .38047 Metetra
.664 .741 .907 r
.29393 .38047 .29504 .38157 .30072 .37959 .29961 .37849 Metetra
.664 .741 .907 r
.29961 .37849 .30072 .37959 .30641 .37761 .30531 .3765 Metetra
.664 .741 .907 r
.30531 .3765 .30641 .37761 .31211 .37562 .31101 .37451 Metetra
.664 .741 .907 r
.31101 .37451 .31211 .37562 .31783 .37363 .31673 .37252 Metetra
.664 .741 .907 r
.31673 .37252 .31783 .37363 .32356 .37164 .32246 .37052 Metetra
.664 .741 .907 r
.32246 .37052 .32356 .37164 .32852 .38233 .3282 .36852 Metetra
.56 .367 .576 r
.3282 .36852 .32852 .38233 .33505 .36763 .33396 .36651 Metetra
.664 .741 .907 r
.33396 .36651 .33505 .36763 .34081 .36562 .33972 .3645 Metetra
.664 .741 .907 r
.33972 .3645 .34081 .36562 .34659 .36361 .3455 .36249 Metetra
.664 .741 .907 r
.3455 .36249 .34659 .36361 .35238 .36159 .3513 .36047 Metetra
.664 .741 .907 r
.3513 .36047 .35238 .36159 .35818 .35957 .3571 .35844 Metetra
.664 .741 .907 r
.3571 .35844 .35818 .35957 .364 .35755 .36292 .35641 Metetra
.664 .741 .907 r
.36292 .35641 .364 .35755 .36983 .35552 .36875 .35438 Metetra
.664 .741 .907 r
.36875 .35438 .36983 .35552 .37567 .35348 .37459 .35234 Metetra
.664 .741 .907 r
.37459 .35234 .37567 .35348 .38152 .35144 .38045 .3503 Metetra
.664 .741 .907 r
.38045 .3503 .38152 .35144 .38739 .3494 .38632 .34826 Metetra
.664 .741 .907 r
.38632 .34826 .38739 .3494 .39327 .34735 .3922 .3462 Metetra
.664 .741 .907 r
.3922 .3462 .39327 .34735 .39916 .3453 .39809 .34415 Metetra
.664 .741 .907 r
.39809 .34415 .39916 .3453 .40506 .34324 .404 .34209 Metetra
.664 .741 .907 r
.404 .34209 .40506 .34324 .41098 .34118 .40992 .34002 Metetra
.664 .741 .907 r
.40992 .34002 .41098 .34118 .41691 .33911 .41586 .33796 Metetra
.664 .741 .907 r
.41586 .33796 .41691 .33911 .42286 .33704 .4218 .33588 Metetra
.664 .741 .907 r
.4218 .33588 .42286 .33704 .42882 .33496 .42776 .3338 Metetra
.959 .635 .36 r
.42776 .3338 .42882 .33496 .43479 .33288 .43246 .37587 Metetra
.375 .172 .473 r
.43246 .37587 .43479 .33288 .44077 .3308 .43972 .32963 Metetra
.664 .741 .907 r
.43972 .32963 .44077 .3308 .44677 .32871 .44572 .32754 Metetra
.664 .741 .907 r
.44572 .32754 .44677 .32871 .45278 .32662 .45173 .32545 Metetra
.664 .741 .907 r
.45173 .32545 .45278 .32662 .4588 .32452 .45776 .32334 Metetra
.664 .741 .907 r
.45776 .32334 .4588 .32452 .46484 .32241 .4638 .32124 Metetra
.664 .741 .907 r
.4638 .32124 .46484 .32241 .47089 .3203 .46985 .31913 Metetra
.664 .741 .907 r
.46985 .31913 .47089 .3203 .47695 .31819 .47592 .31701 Metetra
.664 .741 .907 r
.47592 .31701 .47695 .31819 .48303 .31607 .482 .31489 Metetra
.664 .741 .907 r
.482 .31489 .48303 .31607 .48912 .31395 .48809 .31277 Metetra
.664 .741 .907 r
.48809 .31277 .48912 .31395 .49522 .31183 .4942 .31064 Metetra
.664 .741 .907 r
.4942 .31064 .49522 .31183 .50134 .30969 .50032 .3085 Metetra
.664 .741 .907 r
.50032 .3085 .50134 .30969 .50747 .30756 .50645 .30636 Metetra
.664 .741 .907 r
.50645 .30636 .50747 .30756 .51362 .30542 .5126 .30422 Metetra
.664 .741 .907 r
.5126 .30422 .51362 .30542 .51978 .30327 .51877 .30207 Metetra
.664 .741 .907 r
.51877 .30207 .51978 .30327 .52595 .30112 .52494 .29992 Metetra
.664 .741 .907 r
.52494 .29992 .52595 .30112 .53214 .29896 .53113 .29776 Metetra
.664 .741 .907 r
.53113 .29776 .53214 .29896 .53846 .32413 .53734 .2956 Metetra
.549 .341 .55 r
.53734 .2956 .53846 .32413 .54456 .29464 .54355 .29343 Metetra
.664 .741 .907 r
.54355 .29343 .54456 .29464 .55078 .29247 .54978 .29125 Metetra
.664 .741 .907 r
.54978 .29125 .55078 .29247 .55703 .29029 .55603 .28908 Metetra
.664 .741 .907 r
.55603 .28908 .55703 .29029 .56329 .28811 .56229 .28689 Metetra
.664 .741 .907 r
.56229 .28689 .56329 .28811 .56956 .28593 .56857 .28471 Metetra
.664 .741 .907 r
.56857 .28471 .56956 .28593 .57584 .28374 .57485 .28251 Metetra
.664 .741 .907 r
.57485 .28251 .57584 .28374 .58214 .28154 .58116 .28032 Metetra
.664 .741 .907 r
.58116 .28032 .58214 .28154 .58846 .27934 .58747 .27811 Metetra
.664 .741 .907 r
.58747 .27811 .58846 .27934 .59479 .27714 .59381 .2759 Metetra
.664 .741 .907 r
.59381 .2759 .59479 .27714 .60113 .27493 .60015 .27369 Metetra
.664 .741 .907 r
.60015 .27369 .60113 .27493 .60749 .27271 .60651 .27147 Metetra
.664 .741 .907 r
.60651 .27147 .60749 .27271 .61386 .27049 .61289 .26925 Metetra
.664 .741 .907 r
.61289 .26925 .61386 .27049 .62024 .26827 .61928 .26702 Metetra
.664 .741 .907 r
.61928 .26702 .62024 .26827 .62665 .26604 .62568 .26479 Metetra
.664 .741 .907 r
.62568 .26479 .62665 .26604 .63306 .2638 .6321 .26255 Metetra
.664 .741 .907 r
.6321 .26255 .63306 .2638 .63949 .26156 .63853 .26031 Metetra
.664 .741 .907 r
.63853 .26031 .63949 .26156 .64594 .25931 .64498 .25806 Metetra
.664 .741 .907 r
.64498 .25806 .64594 .25931 .6524 .25706 .65144 .25581 Metetra
.664 .741 .907 r
.65144 .25581 .6524 .25706 .65887 .25481 .65792 .25355 Metetra
.664 .741 .907 r
.65792 .25355 .65887 .25481 .66536 .25255 .66442 .25128 Metetra
.664 .741 .907 r
.66442 .25128 .66536 .25255 .67187 .25028 .67092 .24901 Metetra
.664 .741 .907 r
.67092 .24901 .67187 .25028 .67839 .24801 .67745 .24674 Metetra
.664 .741 .907 r
.67745 .24674 .67839 .24801 .68492 .24573 .68399 .24446 Metetra
.664 .741 .907 r
.68399 .24446 .68492 .24573 .69147 .24345 .69054 .24217 Metetra
.664 .741 .907 r
.69054 .24217 .69147 .24345 .69804 .24116 .69711 .23988 Metetra
.664 .741 .907 r
.69711 .23988 .69804 .24116 .70462 .23887 .70369 .23759 Metetra
.664 .741 .907 r
.70369 .23759 .70462 .23887 .71121 .23657 .71029 .23529 Metetra
.664 .741 .907 r
.71029 .23529 .71121 .23657 .71783 .23427 .7169 .23298 Metetra
.664 .741 .907 r
.7169 .23298 .71783 .23427 .72445 .23196 .72353 .23067 Metetra
.664 .741 .907 r
.72353 .23067 .72445 .23196 .73109 .22964 .73018 .22835 Metetra
.664 .741 .907 r
.73018 .22835 .73109 .22964 .73775 .22732 .73684 .22603 Metetra
.664 .741 .907 r
.73684 .22603 .73775 .22732 .74443 .225 .74352 .2237 Metetra
.664 .741 .907 r
.74352 .2237 .74443 .225 .75111 .22267 .75021 .22137 Metetra
.664 .741 .907 r
.75021 .22137 .75111 .22267 .75782 .22033 .75692 .21903 Metetra
.664 .741 .907 r
.75692 .21903 .75782 .22033 .76454 .21799 .76364 .21668 Metetra
.664 .741 .907 r
.76364 .21668 .76454 .21799 .77127 .21565 .77038 .21433 Metetra
.664 .741 .907 r
.77038 .21433 .77127 .21565 .77803 .21329 .77713 .21198 Metetra
.664 .741 .907 r
.77713 .21198 .77803 .21329 .78479 .21093 .7839 .20962 Metetra
.664 .741 .907 r
.7839 .20962 .78479 .21093 .79158 .20857 .79069 .20725 Metetra
.664 .741 .907 r
.79069 .20725 .79158 .20857 .79838 .2062 .79749 .20488 Metetra
.664 .741 .907 r
.79749 .20488 .79838 .2062 .80519 .20383 .80431 .2025 Metetra
.664 .741 .907 r
.80431 .2025 .80519 .20383 .81202 .20145 .81115 .20012 Metetra
.664 .741 .907 r
.81115 .20012 .81202 .20145 .81887 .19906 .818 .19773 Metetra
.664 .741 .907 r
.20354 .41052 .20468 .41159 .21017 .40968 .20903 .40861 Metetra
.664 .741 .907 r
.20903 .40861 .21017 .40968 .21567 .40776 .21453 .40669 Metetra
.664 .741 .907 r
.21453 .40669 .21567 .40776 .22118 .40584 .22005 .40476 Metetra
.664 .741 .907 r
.22005 .40476 .22118 .40584 .22671 .40391 .22557 .40283 Metetra
.664 .741 .907 r
.22557 .40283 .22671 .40391 .23225 .40198 .23111 .4009 Metetra
.664 .741 .907 r
.23111 .4009 .23225 .40198 .23779 .40005 .23666 .39896 Metetra
.664 .741 .907 r
.23666 .39896 .23779 .40005 .24335 .39811 .24223 .39702 Metetra
.664 .741 .907 r
.24223 .39702 .24335 .39811 .24893 .39616 .2478 .39508 Metetra
.664 .741 .907 r
.2478 .39508 .24893 .39616 .25451 .39422 .25339 .39313 Metetra
.664 .741 .907 r
.25339 .39313 .25451 .39422 .26011 .39227 .25898 .39118 Metetra
.664 .741 .907 r
.25898 .39118 .26011 .39227 .26571 .39031 .26459 .38922 Metetra
.664 .741 .907 r
.26459 .38922 .26571 .39031 .27133 .38835 .27022 .38726 Metetra
.664 .741 .907 r
.27022 .38726 .27133 .38835 .27697 .38639 .27585 .38529 Metetra
.664 .741 .907 r
.27585 .38529 .27697 .38639 .28261 .38442 .2815 .38332 Metetra
.664 .741 .907 r
.2815 .38332 .28261 .38442 .28827 .38245 .28715 .38134 Metetra
.664 .741 .907 r
.28715 .38134 .28827 .38245 .29393 .38047 .29283 .37937 Metetra
.664 .741 .907 r
.29283 .37937 .29393 .38047 .29961 .37849 .29851 .37738 Metetra
.664 .741 .907 r
.29851 .37738 .29961 .37849 .30531 .3765 .3042 .37539 Metetra
.664 .741 .907 r
.3042 .37539 .30531 .3765 .31101 .37451 .30991 .3734 Metetra
.664 .741 .907 r
.30991 .3734 .31101 .37451 .31673 .37252 .31563 .37141 Metetra
.664 .741 .907 r
.31563 .37141 .31673 .37252 .32246 .37052 .32136 .36941 Metetra
.664 .741 .907 r
.32136 .36941 .32246 .37052 .3282 .36852 .32711 .3674 Metetra
.664 .741 .907 r
.32711 .3674 .3282 .36852 .33396 .36651 .33286 .36539 Metetra
.664 .741 .907 r
.33286 .36539 .33396 .36651 .33972 .3645 .33863 .36338 Metetra
.664 .741 .907 r
.33863 .36338 .33972 .3645 .3455 .36249 .34442 .36136 Metetra
.664 .741 .907 r
.34442 .36136 .3455 .36249 .3513 .36047 .35021 .35934 Metetra
.664 .741 .907 r
.35021 .35934 .3513 .36047 .3571 .35844 .35602 .35731 Metetra
.664 .741 .907 r
.35602 .35731 .3571 .35844 .36292 .35641 .36184 .35528 Metetra
.664 .741 .907 r
.36184 .35528 .36292 .35641 .36875 .35438 .36767 .35325 Metetra
.664 .741 .907 r
.36767 .35325 .36875 .35438 .37459 .35234 .37352 .35121 Metetra
.664 .741 .907 r
.37352 .35121 .37459 .35234 .38045 .3503 .37937 .34916 Metetra
.664 .741 .907 r
.37937 .34916 .38045 .3503 .38632 .34826 .38525 .34711 Metetra
.664 .741 .907 r
.38525 .34711 .38632 .34826 .3922 .3462 .39113 .34506 Metetra
.664 .741 .907 r
.39113 .34506 .3922 .3462 .39809 .34415 .39703 .343 Metetra
.664 .741 .907 r
.39703 .343 .39809 .34415 .404 .34209 .40294 .34094 Metetra
.664 .741 .907 r
.40294 .34094 .404 .34209 .40992 .34002 .40886 .33887 Metetra
.664 .741 .907 r
.40886 .33887 .40992 .34002 .41586 .33796 .4148 .3368 Metetra
.664 .741 .907 r
.4148 .3368 .41586 .33796 .4218 .33588 .42075 .33472 Metetra
.699 .219 0 r
.42075 .33472 .4218 .33588 .42776 .3338 .42639 .3429 Metetra
.919 .636 .488 r
.42639 .3429 .42776 .3338 .43246 .37587 .42595 .56089 Metetra
.346 .159 .479 r
.42595 .56089 .43246 .37587 .43972 .32963 .4385 .33473 Metetra
.247 0 .29 r
.4385 .33473 .43972 .32963 .44572 .32754 .44467 .32637 Metetra
.664 .741 .907 r
.44467 .32637 .44572 .32754 .45173 .32545 .45069 .32427 Metetra
.664 .741 .907 r
.45069 .32427 .45173 .32545 .45776 .32334 .45672 .32217 Metetra
.664 .741 .907 r
.45672 .32217 .45776 .32334 .4638 .32124 .46276 .32006 Metetra
.664 .741 .907 r
.46276 .32006 .4638 .32124 .46985 .31913 .46882 .31795 Metetra
.664 .741 .907 r
.46882 .31795 .46985 .31913 .47592 .31701 .47488 .31583 Metetra
.664 .741 .907 r
.47488 .31583 .47592 .31701 .482 .31489 .48097 .31371 Metetra
.664 .741 .907 r
.48097 .31371 .482 .31489 .48809 .31277 .48706 .31158 Metetra
.664 .741 .907 r
.48706 .31158 .48809 .31277 .4942 .31064 .49317 .30945 Metetra
.664 .741 .907 r
.49317 .30945 .4942 .31064 .50032 .3085 .4993 .30731 Metetra
.664 .741 .907 r
.4993 .30731 .50032 .3085 .50645 .30636 .50543 .30517 Metetra
.664 .741 .907 r
.50543 .30517 .50645 .30636 .5126 .30422 .51159 .30302 Metetra
.664 .741 .907 r
.51159 .30302 .5126 .30422 .51877 .30207 .51775 .30087 Metetra
.664 .741 .907 r
.51775 .30087 .51877 .30207 .52494 .29992 .52393 .29871 Metetra
.664 .741 .907 r
.52393 .29871 .52494 .29992 .53113 .29776 .53012 .29655 Metetra
.664 .741 .907 r
.53012 .29655 .53113 .29776 .53734 .2956 .53633 .29439 Metetra
.664 .741 .907 r
.53633 .29439 .53734 .2956 .54355 .29343 .54255 .29222 Metetra
.664 .741 .907 r
.54255 .29222 .54355 .29343 .54978 .29125 .54878 .29004 Metetra
.664 .741 .907 r
.54878 .29004 .54978 .29125 .55603 .28908 .55503 .28786 Metetra
.664 .741 .907 r
.55503 .28786 .55603 .28908 .56229 .28689 .5613 .28567 Metetra
.664 .741 .907 r
.5613 .28567 .56229 .28689 .56857 .28471 .56757 .28348 Metetra
.664 .741 .907 r
.56757 .28348 .56857 .28471 .57485 .28251 .57386 .28129 Metetra
.664 .741 .907 r
.57386 .28129 .57485 .28251 .58116 .28032 .58017 .27909 Metetra
.664 .741 .907 r
.58017 .27909 .58116 .28032 .58747 .27811 .58649 .27688 Metetra
.664 .741 .907 r
.58649 .27688 .58747 .27811 .59381 .2759 .59282 .27467 Metetra
.664 .741 .907 r
.59282 .27467 .59381 .2759 .60015 .27369 .59917 .27246 Metetra
.664 .741 .907 r
.59917 .27246 .60015 .27369 .60651 .27147 .60554 .27023 Metetra
.664 .741 .907 r
.60554 .27023 .60651 .27147 .61289 .26925 .61191 .26801 Metetra
.664 .741 .907 r
.61191 .26801 .61289 .26925 .61928 .26702 .61831 .26578 Metetra
.664 .741 .907 r
.61831 .26578 .61928 .26702 .62568 .26479 .62471 .26354 Metetra
.664 .741 .907 r
.62471 .26354 .62568 .26479 .6321 .26255 .63114 .2613 Metetra
.664 .741 .907 r
.63114 .2613 .6321 .26255 .63853 .26031 .63757 .25905 Metetra
.664 .741 .907 r
.63757 .25905 .63853 .26031 .64498 .25806 .64402 .2568 Metetra
.664 .741 .907 r
.64402 .2568 .64498 .25806 .65144 .25581 .65049 .25455 Metetra
.664 .741 .907 r
.65049 .25455 .65144 .25581 .65792 .25355 .65697 .25228 Metetra
.664 .741 .907 r
.65697 .25228 .65792 .25355 .66442 .25128 .66347 .25002 Metetra
.664 .741 .907 r
.66347 .25002 .66442 .25128 .67092 .24901 .66998 .24775 Metetra
.664 .741 .907 r
.66998 .24775 .67092 .24901 .67745 .24674 .6765 .24547 Metetra
.664 .741 .907 r
.6765 .24547 .67745 .24674 .68399 .24446 .68305 .24319 Metetra
.664 .741 .907 r
.68305 .24319 .68399 .24446 .69054 .24217 .6896 .2409 Metetra
.664 .741 .907 r
.6896 .2409 .69054 .24217 .69711 .23988 .69617 .2386 Metetra
.664 .741 .907 r
.69617 .2386 .69711 .23988 .70369 .23759 .70276 .23631 Metetra
.664 .741 .907 r
.70276 .23631 .70369 .23759 .71029 .23529 .70936 .234 Metetra
.664 .741 .907 r
.70936 .234 .71029 .23529 .7169 .23298 .71598 .23169 Metetra
.664 .741 .907 r
.71598 .23169 .7169 .23298 .72353 .23067 .72261 .22938 Metetra
.664 .741 .907 r
.72261 .22938 .72353 .23067 .73018 .22835 .72926 .22706 Metetra
.736 .305 0 r
.72926 .22706 .73018 .22835 .73684 .22603 .73711 .24181 Metetra
.374 .16 .454 r
.73711 .24181 .73684 .22603 .74352 .2237 .74261 .2224 Metetra
.106 .423 .868 r
.74261 .2224 .74352 .2237 .75021 .22137 .74973 .22594 Metetra
.893 .547 .386 r
.74973 .22594 .75021 .22137 .75692 .21903 .76063 .27843 Metetra
.404 .208 .498 r
.76063 .27843 .75692 .21903 .76364 .21668 .76274 .21537 Metetra
.664 .741 .907 r
.76274 .21537 .76364 .21668 .77038 .21433 .76948 .21302 Metetra
.664 .741 .907 r
.76948 .21302 .77038 .21433 .77713 .21198 .77624 .21066 Metetra
.664 .741 .907 r
.77624 .21066 .77713 .21198 .7839 .20962 .78301 .2083 Metetra
.664 .741 .907 r
.78301 .2083 .7839 .20962 .79069 .20725 .78981 .20593 Metetra
.664 .741 .907 r
.78981 .20593 .79069 .20725 .79749 .20488 .79661 .20355 Metetra
.664 .741 .907 r
.79661 .20355 .79749 .20488 .80431 .2025 .80343 .20117 Metetra
.664 .741 .907 r
.80343 .20117 .80431 .2025 .81115 .20012 .81027 .19879 Metetra
.664 .741 .907 r
.81027 .19879 .81115 .20012 .818 .19773 .81713 .19639 Metetra
.664 .741 .907 r
.20239 .40946 .20354 .41052 .20903 .40861 .20789 .40754 Metetra
.664 .741 .907 r
.20789 .40754 .20903 .40861 .21453 .40669 .21339 .40561 Metetra
.664 .741 .907 r
.21339 .40561 .21453 .40669 .22005 .40476 .21891 .40369 Metetra
.664 .741 .907 r
.21891 .40369 .22005 .40476 .22557 .40283 .22444 .40176 Metetra
.664 .741 .907 r
.22444 .40176 .22557 .40283 .23111 .4009 .22998 .39982 Metetra
.664 .741 .907 r
.22998 .39982 .23111 .4009 .23666 .39896 .23553 .39788 Metetra
.664 .741 .907 r
.23553 .39788 .23666 .39896 .24223 .39702 .2411 .39594 Metetra
.664 .741 .907 r
.2411 .39594 .24223 .39702 .2478 .39508 .24667 .39399 Metetra
.664 .741 .907 r
.24667 .39399 .2478 .39508 .25339 .39313 .25226 .39204 Metetra
.664 .741 .907 r
.25226 .39204 .25339 .39313 .25898 .39118 .25786 .39008 Metetra
.664 .741 .907 r
.25786 .39008 .25898 .39118 .26459 .38922 .26347 .38812 Metetra
.664 .741 .907 r
.26347 .38812 .26459 .38922 .27022 .38726 .2691 .38616 Metetra
.664 .741 .907 r
.2691 .38616 .27022 .38726 .27585 .38529 .27473 .38419 Metetra
.664 .741 .907 r
.27473 .38419 .27585 .38529 .2815 .38332 .28038 .38222 Metetra
.664 .741 .907 r
.28038 .38222 .2815 .38332 .28715 .38134 .28604 .38024 Metetra
.664 .741 .907 r
.28604 .38024 .28715 .38134 .29283 .37937 .29172 .37826 Metetra
.664 .741 .907 r
.29172 .37826 .29283 .37937 .29851 .37738 .2974 .37627 Metetra
.664 .741 .907 r
.2974 .37627 .29851 .37738 .3042 .37539 .3031 .37428 Metetra
.664 .741 .907 r
.3031 .37428 .3042 .37539 .30991 .3734 .30881 .37229 Metetra
.664 .741 .907 r
.30881 .37229 .30991 .3734 .31563 .37141 .31453 .37029 Metetra
.664 .741 .907 r
.31453 .37029 .31563 .37141 .32136 .36941 .32026 .36829 Metetra
.664 .741 .907 r
.32026 .36829 .32136 .36941 .32711 .3674 .32601 .36628 Metetra
.664 .741 .907 r
.32601 .36628 .32711 .3674 .33286 .36539 .33177 .36427 Metetra
.664 .741 .907 r
.33177 .36427 .33286 .36539 .33863 .36338 .33754 .36225 Metetra
.664 .741 .907 r
.33754 .36225 .33863 .36338 .34442 .36136 .34333 .36023 Metetra
.664 .741 .907 r
.34333 .36023 .34442 .36136 .35021 .35934 .34912 .35821 Metetra
.664 .741 .907 r
.34912 .35821 .35021 .35934 .35602 .35731 .35493 .35618 Metetra
.664 .741 .907 r
.35493 .35618 .35602 .35731 .36184 .35528 .36076 .35415 Metetra
.664 .741 .907 r
.36076 .35415 .36184 .35528 .36767 .35325 .36659 .35211 Metetra
.664 .741 .907 r
.36659 .35211 .36767 .35325 .37352 .35121 .37244 .35007 Metetra
.664 .741 .907 r
.37244 .35007 .37352 .35121 .37937 .34916 .3783 .34802 Metetra
.664 .741 .907 r
.3783 .34802 .37937 .34916 .38525 .34711 .38417 .34597 Metetra
.664 .741 .907 r
.38417 .34597 .38525 .34711 .39113 .34506 .39006 .34391 Metetra
.664 .741 .907 r
.39006 .34391 .39113 .34506 .39703 .343 .39596 .34185 Metetra
.664 .741 .907 r
.39596 .34185 .39703 .343 .40294 .34094 .40187 .33979 Metetra
.664 .741 .907 r
.40187 .33979 .40294 .34094 .40886 .33887 .4078 .33772 Metetra
.664 .741 .907 r
.4078 .33772 .40886 .33887 .4148 .3368 .41374 .33564 Metetra
.664 .741 .907 r
.41374 .33564 .4148 .3368 .42075 .33472 .41969 .33356 Metetra
.961 .653 .399 r
.41969 .33356 .42075 .33472 .42639 .3429 .4237 .39347 Metetra
.737 .474 .53 r
.4237 .39347 .42639 .3429 .42595 .56089 .42537 .54113 Metetra
.891 .624 .528 r
.42537 .54113 .42595 .56089 .4385 .33473 .43762 .3273 Metetra
.579 .411 .619 r
.43762 .3273 .4385 .33473 .44467 .32637 .44363 .3252 Metetra
.664 .741 .907 r
.44363 .3252 .44467 .32637 .45069 .32427 .44964 .3231 Metetra
.664 .741 .907 r
.44964 .3231 .45069 .32427 .45672 .32217 .45567 .32099 Metetra
.664 .741 .907 r
.45567 .32099 .45672 .32217 .46276 .32006 .46172 .31888 Metetra
.664 .741 .907 r
.46172 .31888 .46276 .32006 .46882 .31795 .46778 .31677 Metetra
.664 .741 .907 r
.46778 .31677 .46882 .31795 .47488 .31583 .47385 .31465 Metetra
.664 .741 .907 r
.47385 .31465 .47488 .31583 .48097 .31371 .47993 .31252 Metetra
.664 .741 .907 r
.47993 .31252 .48097 .31371 .48706 .31158 .48603 .31039 Metetra
.664 .741 .907 r
.48603 .31039 .48706 .31158 .49317 .30945 .49215 .30826 Metetra
.664 .741 .907 r
.49215 .30826 .49317 .30945 .4993 .30731 .49827 .30612 Metetra
.664 .741 .907 r
.49827 .30612 .4993 .30731 .50543 .30517 .50441 .30397 Metetra
.664 .741 .907 r
.50441 .30397 .50543 .30517 .51159 .30302 .51057 .30182 Metetra
.664 .741 .907 r
.51057 .30182 .51159 .30302 .51775 .30087 .51673 .29967 Metetra
.664 .741 .907 r
.51673 .29967 .51775 .30087 .52393 .29871 .52292 .29751 Metetra
.664 .741 .907 r
.52292 .29751 .52393 .29871 .53012 .29655 .52911 .29535 Metetra
.664 .741 .907 r
.52911 .29535 .53012 .29655 .53633 .29439 .53532 .29318 Metetra
.664 .741 .907 r
.53532 .29318 .53633 .29439 .54255 .29222 .54154 .291 Metetra
.664 .741 .907 r
.54154 .291 .54255 .29222 .54878 .29004 .54778 .28882 Metetra
.664 .741 .907 r
.54778 .28882 .54878 .29004 .55503 .28786 .55403 .28664 Metetra
.664 .741 .907 r
.55403 .28664 .55503 .28786 .5613 .28567 .5603 .28445 Metetra
.664 .741 .907 r
.5603 .28445 .5613 .28567 .56757 .28348 .56658 .28226 Metetra
.664 .741 .907 r
.56658 .28226 .56757 .28348 .57386 .28129 .57287 .28006 Metetra
.664 .741 .907 r
.57287 .28006 .57386 .28129 .58017 .27909 .57918 .27786 Metetra
.664 .741 .907 r
.57918 .27786 .58017 .27909 .58649 .27688 .5855 .27565 Metetra
.664 .741 .907 r
.5855 .27565 .58649 .27688 .59282 .27467 .59184 .27344 Metetra
.664 .741 .907 r
.59184 .27344 .59282 .27467 .59917 .27246 .59819 .27122 Metetra
.664 .741 .907 r
.59819 .27122 .59917 .27246 .60554 .27023 .60456 .26899 Metetra
.664 .741 .907 r
.60456 .26899 .60554 .27023 .61191 .26801 .61094 .26677 Metetra
.664 .741 .907 r
.61094 .26677 .61191 .26801 .61831 .26578 .61734 .26453 Metetra
.664 .741 .907 r
.61734 .26453 .61831 .26578 .62471 .26354 .62375 .26229 Metetra
.664 .741 .907 r
.62375 .26229 .62471 .26354 .63114 .2613 .63017 .26005 Metetra
.664 .741 .907 r
.63017 .26005 .63114 .2613 .63757 .25905 .63661 .2578 Metetra
.664 .741 .907 r
.63661 .2578 .63757 .25905 .64402 .2568 .64307 .25555 Metetra
.664 .741 .907 r
.64307 .25555 .64402 .2568 .65049 .25455 .64953 .25329 Metetra
.664 .741 .907 r
.64953 .25329 .65049 .25455 .65697 .25228 .65602 .25102 Metetra
.664 .741 .907 r
.65602 .25102 .65697 .25228 .66347 .25002 .66252 .24875 Metetra
.664 .741 .907 r
.66252 .24875 .66347 .25002 .66998 .24775 .66903 .24648 Metetra
.664 .741 .907 r
.66903 .24648 .66998 .24775 .6765 .24547 .67556 .2442 Metetra
.664 .741 .907 r
.67556 .2442 .6765 .24547 .68305 .24319 .68211 .24191 Metetra
.664 .741 .907 r
.68211 .24191 .68305 .24319 .6896 .2409 .68867 .23962 Metetra
.664 .741 .907 r
.68867 .23962 .6896 .2409 .69617 .2386 .69524 .23732 Metetra
.664 .741 .907 r
.69524 .23732 .69617 .2386 .70276 .23631 .70183 .23502 Metetra
.664 .741 .907 r
.70183 .23502 .70276 .23631 .70936 .234 .70844 .23271 Metetra
.664 .741 .907 r
.70844 .23271 .70936 .234 .71598 .23169 .71506 .2304 Metetra
.664 .741 .907 r
.71506 .2304 .71598 .23169 .72261 .22938 .72169 .22808 Metetra
.664 .741 .907 r
.72169 .22808 .72261 .22938 .72926 .22706 .72834 .22576 Metetra
.664 .741 .907 r
.72834 .22576 .72926 .22706 .73711 .24181 .73501 .22343 Metetra
.555 .355 .565 r
.73501 .22343 .73711 .24181 .74261 .2224 .7417 .2211 Metetra
.664 .741 .907 r
.7417 .2211 .74261 .2224 .74973 .22594 .74839 .21876 Metetra
.21 .167 .588 r
.74839 .21876 .74973 .22594 .76063 .27843 .75654 .23532 Metetra
.589 .364 .542 r
.75654 .23532 .76063 .27843 .76274 .21537 .76184 .21406 Metetra
.664 .741 .907 r
.76184 .21406 .76274 .21537 .76948 .21302 .76858 .21171 Metetra
.664 .741 .907 r
.76858 .21171 .76948 .21302 .77624 .21066 .77535 .20934 Metetra
.664 .741 .907 r
.77535 .20934 .77624 .21066 .78301 .2083 .78212 .20698 Metetra
.664 .741 .907 r
.78212 .20698 .78301 .2083 .78981 .20593 .78892 .2046 Metetra
.664 .741 .907 r
.78892 .2046 .78981 .20593 .79661 .20355 .79573 .20223 Metetra
.664 .741 .907 r
.79573 .20223 .79661 .20355 .80343 .20117 .80255 .19984 Metetra
.664 .741 .907 r
.80255 .19984 .80343 .20117 .81027 .19879 .8094 .19745 Metetra
.664 .741 .907 r
.8094 .19745 .81027 .19879 .81713 .19639 .81625 .19506 Metetra
.664 .741 .907 r
.20125 .40839 .20239 .40946 .20789 .40754 .20674 .40647 Metetra
.664 .741 .907 r
.20674 .40647 .20789 .40754 .21339 .40561 .21225 .40454 Metetra
.664 .741 .907 r
.21225 .40454 .21339 .40561 .21891 .40369 .21777 .40261 Metetra
.664 .741 .907 r
.21777 .40261 .21891 .40369 .22444 .40176 .2233 .40068 Metetra
.664 .741 .907 r
.2233 .40068 .22444 .40176 .22998 .39982 .22884 .39874 Metetra
.664 .741 .907 r
.22884 .39874 .22998 .39982 .23553 .39788 .2344 .3968 Metetra
.664 .741 .907 r
.2344 .3968 .23553 .39788 .2411 .39594 .23997 .39485 Metetra
.664 .741 .907 r
.23997 .39485 .2411 .39594 .24667 .39399 .24554 .3929 Metetra
.664 .741 .907 r
.24554 .3929 .24667 .39399 .25226 .39204 .25113 .39095 Metetra
.664 .741 .907 r
.25113 .39095 .25226 .39204 .25786 .39008 .25674 .38899 Metetra
.664 .741 .907 r
.25674 .38899 .25786 .39008 .26347 .38812 .26235 .38703 Metetra
.664 .741 .907 r
.26235 .38703 .26347 .38812 .2691 .38616 .26798 .38506 Metetra
.664 .741 .907 r
.26798 .38506 .2691 .38616 .27473 .38419 .27362 .38309 Metetra
.81 .341 0 r
.27362 .38309 .27473 .38419 .28038 .38222 .27847 .39157 Metetra
.46 .198 .428 r
.27847 .39157 .28038 .38222 .28604 .38024 .28432 .3873 Metetra
.266 .012 .329 r
.28432 .3873 .28604 .38024 .29172 .37826 .2906 .37715 Metetra
.664 .741 .907 r
.2906 .37715 .29172 .37826 .2974 .37627 .29629 .37516 Metetra
.664 .741 .907 r
.29629 .37516 .2974 .37627 .3031 .37428 .30199 .37317 Metetra
.664 .741 .907 r
.30199 .37317 .3031 .37428 .30881 .37229 .3077 .37118 Metetra
.664 .741 .907 r
.3077 .37118 .30881 .37229 .31453 .37029 .31343 .36917 Metetra
.664 .741 .907 r
.31343 .36917 .31453 .37029 .32026 .36829 .31916 .36717 Metetra
.664 .741 .907 r
.31916 .36717 .32026 .36829 .32601 .36628 .32491 .36516 Metetra
.664 .741 .907 r
.32491 .36516 .32601 .36628 .33177 .36427 .33067 .36315 Metetra
.664 .741 .907 r
.33067 .36315 .33177 .36427 .33754 .36225 .33645 .36113 Metetra
.664 .741 .907 r
.33645 .36113 .33754 .36225 .34333 .36023 .34224 .3591 Metetra
.664 .741 .907 r
.34224 .3591 .34333 .36023 .34912 .35821 .34803 .35708 Metetra
.664 .741 .907 r
.34803 .35708 .34912 .35821 .35493 .35618 .35385 .35505 Metetra
.664 .741 .907 r
.35385 .35505 .35493 .35618 .36076 .35415 .35967 .35301 Metetra
.664 .741 .907 r
.35967 .35301 .36076 .35415 .36659 .35211 .36551 .35097 Metetra
.664 .741 .907 r
.36551 .35097 .36659 .35211 .37244 .35007 .37136 .34892 Metetra
.664 .741 .907 r
.37136 .34892 .37244 .35007 .3783 .34802 .37722 .34688 Metetra
.664 .741 .907 r
.37722 .34688 .3783 .34802 .38417 .34597 .3831 .34482 Metetra
.664 .741 .907 r
.3831 .34482 .38417 .34597 .39006 .34391 .38899 .34276 Metetra
.664 .741 .907 r
.38899 .34276 .39006 .34391 .39596 .34185 .39489 .3407 Metetra
.664 .741 .907 r
.39489 .3407 .39596 .34185 .40187 .33979 .4008 .33863 Metetra
.664 .741 .907 r
.4008 .33863 .40187 .33979 .4078 .33772 .40673 .33656 Metetra
.664 .741 .907 r
.40673 .33656 .4078 .33772 .41374 .33564 .41267 .33448 Metetra
.664 .741 .907 r
.41267 .33448 .41374 .33564 .41969 .33356 .41863 .3324 Metetra
.961 .655 .403 r
.41863 .3324 .41969 .33356 .4237 .39347 .42252 .39563 Metetra
.879 .552 .426 r
.42252 .39563 .4237 .39347 .42537 .54113 .42761 .42717 Metetra
.631 .395 .541 r
.42761 .42717 .42537 .54113 .43762 .3273 .43657 .32613 Metetra
.664 .741 .907 r
.43657 .32613 .43762 .3273 .44363 .3252 .44258 .32403 Metetra
.664 .741 .907 r
.44258 .32403 .44363 .3252 .44964 .3231 .4486 .32193 Metetra
.664 .741 .907 r
.4486 .32193 .44964 .3231 .45567 .32099 .45463 .31982 Metetra
.664 .741 .907 r
.45463 .31982 .45567 .32099 .46172 .31888 .46068 .3177 Metetra
.664 .741 .907 r
.46068 .3177 .46172 .31888 .46778 .31677 .46674 .31558 Metetra
.664 .741 .907 r
.46674 .31558 .46778 .31677 .47385 .31465 .47281 .31346 Metetra
.664 .741 .907 r
.47281 .31346 .47385 .31465 .47993 .31252 .4789 .31133 Metetra
.664 .741 .907 r
.4789 .31133 .47993 .31252 .48603 .31039 .485 .3092 Metetra
.664 .741 .907 r
.485 .3092 .48603 .31039 .49215 .30826 .49112 .30706 Metetra
.664 .741 .907 r
.49112 .30706 .49215 .30826 .49827 .30612 .49725 .30492 Metetra
.664 .741 .907 r
.49725 .30492 .49827 .30612 .50441 .30397 .50339 .30277 Metetra
.664 .741 .907 r
.50339 .30277 .50441 .30397 .51057 .30182 .50955 .30062 Metetra
.664 .741 .907 r
.50955 .30062 .51057 .30182 .51673 .29967 .51572 .29846 Metetra
.664 .741 .907 r
.51572 .29846 .51673 .29967 .52292 .29751 .5219 .2963 Metetra
.664 .741 .907 r
.5219 .2963 .52292 .29751 .52911 .29535 .5281 .29414 Metetra
.664 .741 .907 r
.5281 .29414 .52911 .29535 .53532 .29318 .53431 .29197 Metetra
.664 .741 .907 r
.53431 .29197 .53532 .29318 .54154 .291 .54054 .28979 Metetra
.664 .741 .907 r
.54054 .28979 .54154 .291 .54778 .28882 .54678 .28761 Metetra
.664 .741 .907 r
.54678 .28761 .54778 .28882 .55403 .28664 .55303 .28542 Metetra
.664 .741 .907 r
.55303 .28542 .55403 .28664 .5603 .28445 .5593 .28323 Metetra
.664 .741 .907 r
.5593 .28323 .5603 .28445 .56658 .28226 .56558 .28103 Metetra
.664 .741 .907 r
.56558 .28103 .56658 .28226 .57287 .28006 .57188 .27883 Metetra
.664 .741 .907 r
.57188 .27883 .57287 .28006 .57918 .27786 .57819 .27663 Metetra
.664 .741 .907 r
.57819 .27663 .57918 .27786 .5855 .27565 .58452 .27442 Metetra
.664 .741 .907 r
.58452 .27442 .5855 .27565 .59184 .27344 .59086 .2722 Metetra
.664 .741 .907 r
.59086 .2722 .59184 .27344 .59819 .27122 .59721 .26998 Metetra
.664 .741 .907 r
.59721 .26998 .59819 .27122 .60456 .26899 .60358 .26775 Metetra
.664 .741 .907 r
.60358 .26775 .60456 .26899 .61094 .26677 .60997 .26552 Metetra
.664 .741 .907 r
.60997 .26552 .61094 .26677 .61734 .26453 .61636 .26328 Metetra
.664 .741 .907 r
.61636 .26328 .61734 .26453 .62375 .26229 .62278 .26104 Metetra
.664 .741 .907 r
.62278 .26104 .62375 .26229 .63017 .26005 .62921 .25879 Metetra
.664 .741 .907 r
.62921 .25879 .63017 .26005 .63661 .2578 .63565 .25654 Metetra
.664 .741 .907 r
.63565 .25654 .63661 .2578 .64307 .25555 .64211 .25429 Metetra
.664 .741 .907 r
.64211 .25429 .64307 .25555 .64953 .25329 .64858 .25202 Metetra
.664 .741 .907 r
.64858 .25202 .64953 .25329 .65602 .25102 .65506 .24976 Metetra
.664 .741 .907 r
.65506 .24976 .65602 .25102 .66252 .24875 .66157 .24748 Metetra
.664 .741 .907 r
.66157 .24748 .66252 .24875 .66903 .24648 .66808 .2452 Metetra
.664 .741 .907 r
.66808 .2452 .66903 .24648 .67556 .2442 .67462 .24292 Metetra
.664 .741 .907 r
.67462 .24292 .67556 .2442 .68211 .24191 .68116 .24063 Metetra
.664 .741 .907 r
.68116 .24063 .68211 .24191 .68867 .23962 .68773 .23834 Metetra
.664 .741 .907 r
.68773 .23834 .68867 .23962 .69524 .23732 .69431 .23604 Metetra
.664 .741 .907 r
.69431 .23604 .69524 .23732 .70183 .23502 .7009 .23373 Metetra
.664 .741 .907 r
.7009 .23373 .70183 .23502 .70844 .23271 .70751 .23142 Metetra
.664 .741 .907 r
.70751 .23142 .70844 .23271 .71506 .2304 .71413 .22911 Metetra
.664 .741 .907 r
.71413 .22911 .71506 .2304 .72169 .22808 .72077 .22679 Metetra
.664 .741 .907 r
.72077 .22679 .72169 .22808 .72834 .22576 .72743 .22446 Metetra
.664 .741 .907 r
.72743 .22446 .72834 .22576 .73501 .22343 .7341 .22213 Metetra
.664 .741 .907 r
.7341 .22213 .73501 .22343 .7417 .2211 .74078 .21979 Metetra
.664 .741 .907 r
.74078 .21979 .7417 .2211 .74839 .21876 .74748 .21745 Metetra
.664 .741 .907 r
.74748 .21745 .74839 .21876 .75654 .23532 .7542 .2151 Metetra
.553 .351 .561 r
.7542 .2151 .75654 .23532 .76184 .21406 .76094 .21275 Metetra
.664 .741 .907 r
.76094 .21275 .76184 .21406 .76858 .21171 .76768 .21039 Metetra
.664 .741 .907 r
.76768 .21039 .76858 .21171 .77535 .20934 .77445 .20802 Metetra
.664 .741 .907 r
.77445 .20802 .77535 .20934 .78212 .20698 .78123 .20565 Metetra
.664 .741 .907 r
.78123 .20565 .78212 .20698 .78892 .2046 .78803 .20328 Metetra
.664 .741 .907 r
.78803 .20328 .78892 .2046 .79573 .20223 .79484 .2009 Metetra
.664 .741 .907 r
.79484 .2009 .79573 .20223 .80255 .19984 .80167 .19851 Metetra
.664 .741 .907 r
.80167 .19851 .80255 .19984 .8094 .19745 .80852 .19612 Metetra
.664 .741 .907 r
.80852 .19612 .8094 .19745 .81625 .19506 .81538 .19372 Metetra
.664 .741 .907 r
.2001 .40732 .20125 .40839 .20674 .40647 .2056 .40539 Metetra
.664 .741 .907 r
.2056 .40539 .20674 .40647 .21225 .40454 .21111 .40347 Metetra
.664 .741 .907 r
.21111 .40347 .21225 .40454 .21777 .40261 .21663 .40153 Metetra
.664 .741 .907 r
.21663 .40153 .21777 .40261 .2233 .40068 .22216 .3996 Metetra
.664 .741 .907 r
.22216 .3996 .2233 .40068 .22884 .39874 .22771 .39766 Metetra
.664 .741 .907 r
.22771 .39766 .22884 .39874 .2344 .3968 .23326 .39571 Metetra
.664 .741 .907 r
.23326 .39571 .2344 .3968 .23997 .39485 .23883 .39377 Metetra
.664 .741 .907 r
.23883 .39377 .23997 .39485 .24554 .3929 .24441 .39181 Metetra
.664 .741 .907 r
.24441 .39181 .24554 .3929 .25113 .39095 .25001 .38986 Metetra
.664 .741 .907 r
.25001 .38986 .25113 .39095 .25674 .38899 .25561 .3879 Metetra
.664 .741 .907 r
.25561 .3879 .25674 .38899 .26235 .38703 .26123 .38593 Metetra
.664 .741 .907 r
.26123 .38593 .26235 .38703 .26798 .38506 .26686 .38396 Metetra
.664 .741 .907 r
.26686 .38396 .26798 .38506 .27362 .38309 .2725 .38199 Metetra
.817 .351 0 r
.2725 .38199 .27362 .38309 .27847 .39157 .27733 .39063 Metetra
.897 .764 .706 r
.27733 .39063 .27847 .39157 .28432 .3873 .28381 .37803 Metetra
.57 .391 .599 r
.28381 .37803 .28432 .3873 .2906 .37715 .28949 .37604 Metetra
.664 .741 .907 r
.28949 .37604 .2906 .37715 .29629 .37516 .29518 .37405 Metetra
.664 .741 .907 r
.29518 .37405 .29629 .37516 .30199 .37317 .30088 .37206 Metetra
.664 .741 .907 r
.30088 .37206 .30199 .37317 .3077 .37118 .3066 .37006 Metetra
.664 .741 .907 r
.3066 .37006 .3077 .37118 .31343 .36917 .31232 .36806 Metetra
.664 .741 .907 r
.31232 .36806 .31343 .36917 .31916 .36717 .31806 .36605 Metetra
.664 .741 .907 r
.31806 .36605 .31916 .36717 .32491 .36516 .32381 .36404 Metetra
.664 .741 .907 r
.32381 .36404 .32491 .36516 .33067 .36315 .32958 .36202 Metetra
.664 .741 .907 r
.32958 .36202 .33067 .36315 .33645 .36113 .33535 .36 Metetra
.664 .741 .907 r
.33535 .36 .33645 .36113 .34224 .3591 .34114 .35797 Metetra
.664 .741 .907 r
.34114 .35797 .34224 .3591 .34803 .35708 .34695 .35595 Metetra
.664 .741 .907 r
.34695 .35595 .34803 .35708 .35385 .35505 .35276 .35391 Metetra
.664 .741 .907 r
.35276 .35391 .35385 .35505 .35967 .35301 .35859 .35187 Metetra
.664 .741 .907 r
.35859 .35187 .35967 .35301 .36551 .35097 .36443 .34983 Metetra
.664 .741 .907 r
.36443 .34983 .36551 .35097 .37136 .34892 .37028 .34778 Metetra
.664 .741 .907 r
.37028 .34778 .37136 .34892 .37722 .34688 .37614 .34573 Metetra
.664 .741 .907 r
.37614 .34573 .37722 .34688 .3831 .34482 .38202 .34367 Metetra
.664 .741 .907 r
.38202 .34367 .3831 .34482 .38899 .34276 .38791 .34161 Metetra
.664 .741 .907 r
.38791 .34161 .38899 .34276 .39489 .3407 .39382 .33955 Metetra
.664 .741 .907 r
.39382 .33955 .39489 .3407 .4008 .33863 .39974 .33748 Metetra
.664 .741 .907 r
.39974 .33748 .4008 .33863 .40673 .33656 .40567 .3354 Metetra
.664 .741 .907 r
.40567 .3354 .40673 .33656 .41267 .33448 .41161 .33332 Metetra
.664 .741 .907 r
.41161 .33332 .41267 .33448 .41863 .3324 .41757 .33124 Metetra
.664 .741 .907 r
.41757 .33124 .41863 .3324 .42252 .39563 .42354 .32915 Metetra
.512 .301 .53 r
.42354 .32915 .42252 .39563 .42761 .42717 .42906 .34219 Metetra
.561 .339 .535 r
.42906 .34219 .42761 .42717 .43657 .32613 .43552 .32496 Metetra
.664 .741 .907 r
.43552 .32496 .43657 .32613 .44258 .32403 .44153 .32286 Metetra
.664 .741 .907 r
.44153 .32286 .44258 .32403 .4486 .32193 .44755 .32075 Metetra
.664 .741 .907 r
.44755 .32075 .4486 .32193 .45463 .31982 .45359 .31864 Metetra
.664 .741 .907 r
.45359 .31864 .45463 .31982 .46068 .3177 .45964 .31652 Metetra
.664 .741 .907 r
.45964 .31652 .46068 .3177 .46674 .31558 .4657 .3144 Metetra
.664 .741 .907 r
.4657 .3144 .46674 .31558 .47281 .31346 .47178 .31228 Metetra
.664 .741 .907 r
.47178 .31228 .47281 .31346 .4789 .31133 .47787 .31014 Metetra
.664 .741 .907 r
.47787 .31014 .4789 .31133 .485 .3092 .48397 .30801 Metetra
.664 .741 .907 r
.48397 .30801 .485 .3092 .49112 .30706 .49009 .30587 Metetra
.664 .741 .907 r
.49009 .30587 .49112 .30706 .49725 .30492 .49622 .30372 Metetra
.664 .741 .907 r
.49622 .30372 .49725 .30492 .50339 .30277 .50236 .30157 Metetra
.664 .741 .907 r
.50236 .30157 .50339 .30277 .50955 .30062 .50852 .29942 Metetra
.664 .741 .907 r
.50852 .29942 .50955 .30062 .51572 .29846 .5147 .29726 Metetra
.664 .741 .907 r
.5147 .29726 .51572 .29846 .5219 .2963 .52088 .2951 Metetra
.664 .741 .907 r
.52088 .2951 .5219 .2963 .5281 .29414 .52709 .29293 Metetra
.664 .741 .907 r
.52709 .29293 .5281 .29414 .53431 .29197 .5333 .29075 Metetra
.664 .741 .907 r
.5333 .29075 .53431 .29197 .54054 .28979 .53953 .28857 Metetra
.664 .741 .907 r
.53953 .28857 .54054 .28979 .54678 .28761 .54577 .28639 Metetra
.664 .741 .907 r
.54577 .28639 .54678 .28761 .55303 .28542 .55203 .2842 Metetra
.664 .741 .907 r
.55203 .2842 .55303 .28542 .5593 .28323 .5583 .28201 Metetra
.664 .741 .907 r
.5583 .28201 .5593 .28323 .56558 .28103 .56459 .27981 Metetra
.664 .741 .907 r
.56459 .27981 .56558 .28103 .57188 .27883 .57089 .2776 Metetra
.664 .741 .907 r
.57089 .2776 .57188 .27883 .57819 .27663 .5772 .27539 Metetra
.664 .741 .907 r
.5772 .27539 .57819 .27663 .58452 .27442 .58353 .27318 Metetra
.664 .741 .907 r
.58353 .27318 .58452 .27442 .59086 .2722 .58987 .27096 Metetra
.664 .741 .907 r
.58987 .27096 .59086 .2722 .59721 .26998 .59623 .26874 Metetra
.664 .741 .907 r
.59623 .26874 .59721 .26998 .60358 .26775 .6026 .26651 Metetra
.664 .741 .907 r
.6026 .26651 .60358 .26775 .60997 .26552 .60899 .26427 Metetra
.664 .741 .907 r
.60899 .26427 .60997 .26552 .61636 .26328 .61539 .26203 Metetra
.664 .741 .907 r
.61539 .26203 .61636 .26328 .62278 .26104 .62181 .25979 Metetra
.664 .741 .907 r
.62181 .25979 .62278 .26104 .62921 .25879 .62824 .25754 Metetra
.664 .741 .907 r
.62824 .25754 .62921 .25879 .63565 .25654 .63468 .25528 Metetra
.664 .741 .907 r
.63468 .25528 .63565 .25654 .64211 .25429 .64114 .25302 Metetra
.664 .741 .907 r
.64114 .25302 .64211 .25429 .64858 .25202 .64762 .25076 Metetra
.664 .741 .907 r
.64762 .25076 .64858 .25202 .65506 .24976 .65411 .24849 Metetra
.664 .741 .907 r
.65411 .24849 .65506 .24976 .66157 .24748 .66062 .24621 Metetra
.664 .741 .907 r
.66062 .24621 .66157 .24748 .66808 .2452 .66714 .24393 Metetra
.664 .741 .907 r
.66714 .24393 .66808 .2452 .67462 .24292 .67367 .24165 Metetra
.664 .741 .907 r
.67367 .24165 .67462 .24292 .68116 .24063 .68022 .23935 Metetra
.664 .741 .907 r
.68022 .23935 .68116 .24063 .68773 .23834 .68679 .23706 Metetra
.664 .741 .907 r
.68679 .23706 .68773 .23834 .69431 .23604 .69337 .23475 Metetra
.664 .741 .907 r
.69337 .23475 .69431 .23604 .7009 .23373 .69997 .23245 Metetra
.664 .741 .907 r
.69997 .23245 .7009 .23373 .70751 .23142 .70658 .23013 Metetra
.664 .741 .907 r
.70658 .23013 .70751 .23142 .71413 .22911 .7132 .22782 Metetra
.664 .741 .907 r
.7132 .22782 .71413 .22911 .72077 .22679 .71985 .22549 Metetra
.664 .741 .907 r
.71985 .22549 .72077 .22679 .72743 .22446 .72651 .22316 Metetra
.664 .741 .907 r
.72651 .22316 .72743 .22446 .7341 .22213 .73318 .22083 Metetra
.664 .741 .907 r
.73318 .22083 .7341 .22213 .74078 .21979 .73987 .21849 Metetra
.664 .741 .907 r
.73987 .21849 .74078 .21979 .74748 .21745 .74657 .21614 Metetra
.709 .277 0 r
.74657 .21614 .74748 .21745 .7542 .2151 .75455 .23049 Metetra
.373 .158 .453 r
.75455 .23049 .7542 .2151 .76094 .21275 .76003 .21143 Metetra
.664 .741 .907 r
.76003 .21143 .76094 .21275 .76768 .21039 .76678 .20907 Metetra
.664 .741 .907 r
.76678 .20907 .76768 .21039 .77445 .20802 .77355 .2067 Metetra
.664 .741 .907 r
.77355 .2067 .77445 .20802 .78123 .20565 .78034 .20433 Metetra
.664 .741 .907 r
.78034 .20433 .78123 .20565 .78803 .20328 .78714 .20195 Metetra
.664 .741 .907 r
.78714 .20195 .78803 .20328 .79484 .2009 .79396 .19957 Metetra
.664 .741 .907 r
.79396 .19957 .79484 .2009 .80167 .19851 .80079 .19718 Metetra
.664 .741 .907 r
.80079 .19718 .80167 .19851 .80852 .19612 .80764 .19478 Metetra
.664 .741 .907 r
.80764 .19478 .80852 .19612 .81538 .19372 .8145 .19238 Metetra
.664 .741 .907 r
.19895 .40624 .2001 .40732 .2056 .40539 .20445 .40432 Metetra
.664 .741 .907 r
.20445 .40432 .2056 .40539 .21111 .40347 .20997 .40239 Metetra
.664 .741 .907 r
.20997 .40239 .21111 .40347 .21663 .40153 .21549 .40045 Metetra
.664 .741 .907 r
.21549 .40045 .21663 .40153 .22216 .3996 .22102 .39852 Metetra
.664 .741 .907 r
.22102 .39852 .22216 .3996 .22771 .39766 .22657 .39657 Metetra
.664 .741 .907 r
.22657 .39657 .22771 .39766 .23326 .39571 .23213 .39463 Metetra
.831 .368 0 r
.23213 .39463 .23326 .39571 .23883 .39377 .23676 .40317 Metetra
.287 .046 .363 r
.23676 .40317 .23883 .39377 .24441 .39181 .24328 .39072 Metetra
.664 .741 .907 r
.24328 .39072 .24441 .39181 .25001 .38986 .24888 .38876 Metetra
.664 .741 .907 r
.24888 .38876 .25001 .38986 .25561 .3879 .25448 .3868 Metetra
.664 .741 .907 r
.25448 .3868 .25561 .3879 .26123 .38593 .2601 .38483 Metetra
.664 .741 .907 r
.2601 .38483 .26123 .38593 .26686 .38396 .26573 .38286 Metetra
.664 .741 .907 r
.26573 .38286 .26686 .38396 .2725 .38199 .27138 .38089 Metetra
.911 .505 .166 r
.27138 .38089 .2725 .38199 .27733 .39063 .27587 .39396 Metetra
.755 .819 .349 r
.27587 .39396 .27733 .39063 .28381 .37803 .2827 .37692 Metetra
.664 .741 .907 r
.2827 .37692 .28381 .37803 .28949 .37604 .28838 .37493 Metetra
.664 .741 .907 r
.28838 .37493 .28949 .37604 .29518 .37405 .29407 .37294 Metetra
.664 .741 .907 r
.29407 .37294 .29518 .37405 .30088 .37206 .29977 .37094 Metetra
.664 .741 .907 r
.29977 .37094 .30088 .37206 .3066 .37006 .30549 .36894 Metetra
.664 .741 .907 r
.30549 .36894 .3066 .37006 .31232 .36806 .31122 .36694 Metetra
.664 .741 .907 r
.31122 .36694 .31232 .36806 .31806 .36605 .31696 .36493 Metetra
.664 .741 .907 r
.31696 .36493 .31806 .36605 .32381 .36404 .32271 .36291 Metetra
0 .149 .651 r
.32271 .36291 .32381 .36404 .32958 .36202 .32809 .36727 Metetra
.763 .458 .47 r
.32809 .36727 .32958 .36202 .33535 .36 .33251 .388 Metetra
.354 .145 .451 r
.33251 .388 .33535 .36 .34114 .35797 .34005 .35684 Metetra
.664 .741 .907 r
.34005 .35684 .34114 .35797 .34695 .35595 .34585 .35481 Metetra
.664 .741 .907 r
.34585 .35481 .34695 .35595 .35276 .35391 .35167 .35277 Metetra
.664 .741 .907 r
.35167 .35277 .35276 .35391 .35859 .35187 .3575 .35073 Metetra
.664 .741 .907 r
.3575 .35073 .35859 .35187 .36443 .34983 .36334 .34869 Metetra
.664 .741 .907 r
.36334 .34869 .36443 .34983 .37028 .34778 .3692 .34664 Metetra
.664 .741 .907 r
.3692 .34664 .37028 .34778 .37614 .34573 .37507 .34458 Metetra
.664 .741 .907 r
.37507 .34458 .37614 .34573 .38202 .34367 .38095 .34252 Metetra
.664 .741 .907 r
.38095 .34252 .38202 .34367 .38791 .34161 .38684 .34046 Metetra
.664 .741 .907 r
.38684 .34046 .38791 .34161 .39382 .33955 .39275 .33839 Metetra
.664 .741 .907 r
.39275 .33839 .39382 .33955 .39974 .33748 .39867 .33632 Metetra
.664 .741 .907 r
.39867 .33632 .39974 .33748 .40567 .3354 .4046 .33424 Metetra
.664 .741 .907 r
.4046 .33424 .40567 .3354 .41161 .33332 .41055 .33216 Metetra
.664 .741 .907 r
.41055 .33216 .41161 .33332 .41757 .33124 .4165 .33008 Metetra
.664 .741 .907 r
.4165 .33008 .41757 .33124 .42354 .32915 .42248 .32798 Metetra
.664 .741 .907 r
.42248 .32798 .42354 .32915 .42906 .34219 .42846 .32589 Metetra
.556 .358 .568 r
.42846 .32589 .42906 .34219 .43552 .32496 .43446 .32379 Metetra
.664 .741 .907 r
.43446 .32379 .43552 .32496 .44153 .32286 .44047 .32168 Metetra
.664 .741 .907 r
.44047 .32168 .44153 .32286 .44755 .32075 .4465 .31957 Metetra
.664 .741 .907 r
.4465 .31957 .44755 .32075 .45359 .31864 .45254 .31746 Metetra
.664 .741 .907 r
.45254 .31746 .45359 .31864 .45964 .31652 .45859 .31534 Metetra
.664 .741 .907 r
.45859 .31534 .45964 .31652 .4657 .3144 .46466 .31322 Metetra
.664 .741 .907 r
.46466 .31322 .4657 .3144 .47178 .31228 .47074 .31109 Metetra
.664 .741 .907 r
.47074 .31109 .47178 .31228 .47787 .31014 .47683 .30895 Metetra
.664 .741 .907 r
.47683 .30895 .47787 .31014 .48397 .30801 .48294 .30682 Metetra
.664 .741 .907 r
.48294 .30682 .48397 .30801 .49009 .30587 .48906 .30467 Metetra
.664 .741 .907 r
.48906 .30467 .49009 .30587 .49622 .30372 .49519 .30253 Metetra
.664 .741 .907 r
.49519 .30253 .49622 .30372 .50236 .30157 .50134 .30037 Metetra
.664 .741 .907 r
.50134 .30037 .50236 .30157 .50852 .29942 .5075 .29822 Metetra
.664 .741 .907 r
.5075 .29822 .50852 .29942 .5147 .29726 .51368 .29605 Metetra
.664 .741 .907 r
.51368 .29605 .5147 .29726 .52088 .2951 .51987 .29389 Metetra
.664 .741 .907 r
.51987 .29389 .52088 .2951 .52709 .29293 .52607 .29171 Metetra
.959 .621 .304 r
.52607 .29171 .52709 .29293 .5333 .29075 .53239 .33363 Metetra
.381 .18 .477 r
.53239 .33363 .5333 .29075 .53953 .28857 .53852 .28736 Metetra
.664 .741 .907 r
.53852 .28736 .53953 .28857 .54577 .28639 .54477 .28517 Metetra
.664 .741 .907 r
.54477 .28517 .54577 .28639 .55203 .2842 .55103 .28298 Metetra
.664 .741 .907 r
.55103 .28298 .55203 .2842 .5583 .28201 .5573 .28078 Metetra
.664 .741 .907 r
.5573 .28078 .5583 .28201 .56459 .27981 .56359 .27858 Metetra
.664 .741 .907 r
.56359 .27858 .56459 .27981 .57089 .2776 .56989 .27637 Metetra
.664 .741 .907 r
.56989 .27637 .57089 .2776 .5772 .27539 .57621 .27416 Metetra
.664 .741 .907 r
.57621 .27416 .5772 .27539 .58353 .27318 .58254 .27194 Metetra
.664 .741 .907 r
.58254 .27194 .58353 .27318 .58987 .27096 .58889 .26972 Metetra
.664 .741 .907 r
.58889 .26972 .58987 .27096 .59623 .26874 .59525 .26749 Metetra
.664 .741 .907 r
.59525 .26749 .59623 .26874 .6026 .26651 .60162 .26526 Metetra
.664 .741 .907 r
.60162 .26526 .6026 .26651 .60899 .26427 .60801 .26302 Metetra
.664 .741 .907 r
.60801 .26302 .60899 .26427 .61539 .26203 .61442 .26078 Metetra
.664 .741 .907 r
.61442 .26078 .61539 .26203 .62181 .25979 .62084 .25854 Metetra
.664 .741 .907 r
.62084 .25854 .62181 .25979 .62824 .25754 .62727 .25628 Metetra
.664 .741 .907 r
.62727 .25628 .62824 .25754 .63468 .25528 .63372 .25402 Metetra
.664 .741 .907 r
.63372 .25402 .63468 .25528 .64114 .25302 .64018 .25176 Metetra
.664 .741 .907 r
.64018 .25176 .64114 .25302 .64762 .25076 .64666 .24949 Metetra
.664 .741 .907 r
.64666 .24949 .64762 .25076 .65411 .24849 .65315 .24722 Metetra
.664 .741 .907 r
.65315 .24722 .65411 .24849 .66062 .24621 .65966 .24494 Metetra
.664 .741 .907 r
.65966 .24494 .66062 .24621 .66714 .24393 .66619 .24266 Metetra
.664 .741 .907 r
.66619 .24266 .66714 .24393 .67367 .24165 .67272 .24037 Metetra
.664 .741 .907 r
.67272 .24037 .67367 .24165 .68022 .23935 .67928 .23807 Metetra
.664 .741 .907 r
.67928 .23807 .68022 .23935 .68679 .23706 .68585 .23577 Metetra
.664 .741 .907 r
.68585 .23577 .68679 .23706 .69337 .23475 .69243 .23347 Metetra
.664 .741 .907 r
.69243 .23347 .69337 .23475 .69997 .23245 .69903 .23116 Metetra
.664 .741 .907 r
.69903 .23116 .69997 .23245 .70658 .23013 .70565 .22884 Metetra
.664 .741 .907 r
.70565 .22884 .70658 .23013 .7132 .22782 .71228 .22652 Metetra
.664 .741 .907 r
.71228 .22652 .7132 .22782 .71985 .22549 .71892 .22419 Metetra
.664 .741 .907 r
.71892 .22419 .71985 .22549 .72651 .22316 .72558 .22186 Metetra
.664 .741 .907 r
.72558 .22186 .72651 .22316 .73318 .22083 .73226 .21952 Metetra
.664 .741 .907 r
.73226 .21952 .73318 .22083 .73987 .21849 .73895 .21718 Metetra
.664 .741 .907 r
.73895 .21718 .73987 .21849 .74657 .21614 .74566 .21483 Metetra
.932 .57 .157 r
.74566 .21483 .74657 .21614 .75455 .23049 .75584 .25853 Metetra
.299 .12 .462 r
.75584 .25853 .75455 .23049 .76003 .21143 .75913 .21012 Metetra
.664 .741 .907 r
.75913 .21012 .76003 .21143 .76678 .20907 .76588 .20775 Metetra
.664 .741 .907 r
.76588 .20775 .76678 .20907 .77355 .2067 .77266 .20538 Metetra
.664 .741 .907 r
.77266 .20538 .77355 .2067 .78034 .20433 .77944 .203 Metetra
.664 .741 .907 r
.77944 .203 .78034 .20433 .78714 .20195 .78625 .20062 Metetra
.664 .741 .907 r
.78625 .20062 .78714 .20195 .79396 .19957 .79307 .19823 Metetra
.664 .741 .907 r
.79307 .19823 .79396 .19957 .80079 .19718 .7999 .19584 Metetra
.664 .741 .907 r
.7999 .19584 .80079 .19718 .80764 .19478 .80676 .19344 Metetra
.664 .741 .907 r
.80676 .19344 .80764 .19478 .8145 .19238 .81362 .19104 Metetra
.664 .741 .907 r
.1978 .40517 .19895 .40624 .20445 .40432 .20331 .40324 Metetra
.664 .741 .907 r
.20331 .40324 .20445 .40432 .20997 .40239 .20882 .40131 Metetra
.664 .741 .907 r
.20882 .40131 .20997 .40239 .21549 .40045 .21435 .39937 Metetra
.664 .741 .907 r
.21435 .39937 .21549 .40045 .22102 .39852 .21988 .39743 Metetra
.664 .741 .907 r
.21988 .39743 .22102 .39852 .22657 .39657 .22543 .39549 Metetra
.664 .741 .907 r
.22543 .39549 .22657 .39657 .23213 .39463 .23099 .39354 Metetra
.664 .741 .907 r
.23099 .39354 .23213 .39463 .23676 .40317 .23656 .39159 Metetra
.563 .375 .584 r
.23656 .39159 .23676 .40317 .24328 .39072 .24215 .38963 Metetra
.664 .741 .907 r
.24215 .38963 .24328 .39072 .24888 .38876 .24775 .38767 Metetra
.664 .741 .907 r
.24775 .38767 .24888 .38876 .25448 .3868 .25336 .3857 Metetra
.664 .741 .907 r
.25336 .3857 .25448 .3868 .2601 .38483 .25898 .38374 Metetra
.664 .741 .907 r
.25898 .38374 .2601 .38483 .26573 .38286 .26461 .38176 Metetra
.664 .741 .907 r
.26461 .38176 .26573 .38286 .27138 .38089 .27025 .37978 Metetra
.664 .741 .907 r
.27025 .37978 .27138 .38089 .27587 .39396 .27591 .3778 Metetra
.556 .358 .568 r
.27591 .3778 .27587 .39396 .2827 .37692 .28158 .37581 Metetra
.664 .741 .907 r
.28158 .37581 .2827 .37692 .28838 .37493 .28726 .37382 Metetra
.664 .741 .907 r
.28726 .37382 .28838 .37493 .29407 .37294 .29296 .37183 Metetra
.664 .741 .907 r
.29296 .37183 .29407 .37294 .29977 .37094 .29866 .36983 Metetra
.664 .741 .907 r
.29866 .36983 .29977 .37094 .30549 .36894 .30438 .36783 Metetra
.664 .741 .907 r
.30438 .36783 .30549 .36894 .31122 .36694 .31011 .36582 Metetra
.664 .741 .907 r
.31011 .36582 .31122 .36694 .31696 .36493 .31586 .3638 Metetra
.664 .741 .907 r
.31586 .3638 .31696 .36493 .32271 .36291 .32161 .36179 Metetra
.953 .674 .472 r
.32161 .36179 .32271 .36291 .32809 .36727 .31924 .49092 Metetra
.486 .267 .507 r
.31924 .49092 .32809 .36727 .33251 .388 .32786 .4457 Metetra
.252 .073 .434 r
.32786 .4457 .33251 .388 .34005 .35684 .33895 .35571 Metetra
.664 .741 .907 r
.33895 .35571 .34005 .35684 .34585 .35481 .34476 .35368 Metetra
.664 .741 .907 r
.34476 .35368 .34585 .35481 .35167 .35277 .35058 .35164 Metetra
.664 .741 .907 r
.35058 .35164 .35167 .35277 .3575 .35073 .35641 .34959 Metetra
.664 .741 .907 r
.35641 .34959 .3575 .35073 .36334 .34869 .36226 .34755 Metetra
.664 .741 .907 r
.36226 .34755 .36334 .34869 .3692 .34664 .36811 .34549 Metetra
.664 .741 .907 r
.36811 .34549 .3692 .34664 .37507 .34458 .37398 .34344 Metetra
.664 .741 .907 r
.37398 .34344 .37507 .34458 .38095 .34252 .37987 .34137 Metetra
.664 .741 .907 r
.37987 .34137 .38095 .34252 .38684 .34046 .38576 .33931 Metetra
.664 .741 .907 r
.38576 .33931 .38684 .34046 .39275 .33839 .39167 .33724 Metetra
.664 .741 .907 r
.39167 .33724 .39275 .33839 .39867 .33632 .3976 .33516 Metetra
.664 .741 .907 r
.3976 .33516 .39867 .33632 .4046 .33424 .40353 .33308 Metetra
.664 .741 .907 r
.40353 .33308 .4046 .33424 .41055 .33216 .40948 .331 Metetra
.664 .741 .907 r
.40948 .331 .41055 .33216 .4165 .33008 .41544 .32891 Metetra
.664 .741 .907 r
.41544 .32891 .4165 .33008 .42248 .32798 .42142 .32682 Metetra
.664 .741 .907 r
.42142 .32682 .42248 .32798 .42846 .32589 .4274 .32472 Metetra
.664 .741 .907 r
.4274 .32472 .42846 .32589 .43446 .32379 .43341 .32261 Metetra
.664 .741 .907 r
.43341 .32261 .43446 .32379 .44047 .32168 .43942 .32051 Metetra
.664 .741 .907 r
.43942 .32051 .44047 .32168 .4465 .31957 .44545 .31839 Metetra
.664 .741 .907 r
.44545 .31839 .4465 .31957 .45254 .31746 .45149 .31628 Metetra
.664 .741 .907 r
.45149 .31628 .45254 .31746 .45859 .31534 .45755 .31416 Metetra
.664 .741 .907 r
.45755 .31416 .45859 .31534 .46466 .31322 .46361 .31203 Metetra
.664 .741 .907 r
.46361 .31203 .46466 .31322 .47074 .31109 .4697 .3099 Metetra
.664 .741 .907 r
.4697 .3099 .47074 .31109 .47683 .30895 .47579 .30776 Metetra
.664 .741 .907 r
.47579 .30776 .47683 .30895 .48294 .30682 .4819 .30562 Metetra
.664 .741 .907 r
.4819 .30562 .48294 .30682 .48906 .30467 .48802 .30348 Metetra
.664 .741 .907 r
.48802 .30348 .48906 .30467 .49519 .30253 .49416 .30133 Metetra
.664 .741 .907 r
.49416 .30133 .49519 .30253 .50134 .30037 .50031 .29917 Metetra
.664 .741 .907 r
.50031 .29917 .50134 .30037 .5075 .29822 .50648 .29701 Metetra
.664 .741 .907 r
.50648 .29701 .5075 .29822 .51368 .29605 .51266 .29485 Metetra
.664 .741 .907 r
.51266 .29485 .51368 .29605 .51987 .29389 .51885 .29268 Metetra
.664 .741 .907 r
.51885 .29268 .51987 .29389 .52607 .29171 .52505 .2905 Metetra
.969 .673 .409 r
.52505 .2905 .52607 .29171 .53239 .33363 .53166 .47357 Metetra
.333 .152 .479 r
.53166 .47357 .53239 .33363 .53852 .28736 .53751 .28614 Metetra
.664 .741 .907 r
.53751 .28614 .53852 .28736 .54477 .28517 .54376 .28395 Metetra
.664 .741 .907 r
.54376 .28395 .54477 .28517 .55103 .28298 .55002 .28175 Metetra
.664 .741 .907 r
.55002 .28175 .55103 .28298 .5573 .28078 .5563 .27955 Metetra
.664 .741 .907 r
.5563 .27955 .5573 .28078 .56359 .27858 .56259 .27735 Metetra
.664 .741 .907 r
.56259 .27735 .56359 .27858 .56989 .27637 .5689 .27514 Metetra
.664 .741 .907 r
.5689 .27514 .56989 .27637 .57621 .27416 .57522 .27292 Metetra
.664 .741 .907 r
.57522 .27292 .57621 .27416 .58254 .27194 .58155 .2707 Metetra
.664 .741 .907 r
.58155 .2707 .58254 .27194 .58889 .26972 .5879 .26848 Metetra
.664 .741 .907 r
.5879 .26848 .58889 .26972 .59525 .26749 .59426 .26625 Metetra
.664 .741 .907 r
.59426 .26625 .59525 .26749 .60162 .26526 .60064 .26401 Metetra
.664 .741 .907 r
.60064 .26401 .60162 .26526 .60801 .26302 .60703 .26177 Metetra
.664 .741 .907 r
.60703 .26177 .60801 .26302 .61442 .26078 .61344 .25953 Metetra
.664 .741 .907 r
.61344 .25953 .61442 .26078 .62084 .25854 .61986 .25728 Metetra
.664 .741 .907 r
.61986 .25728 .62084 .25854 .62727 .25628 .6263 .25502 Metetra
.664 .741 .907 r
.6263 .25502 .62727 .25628 .63372 .25402 .63275 .25276 Metetra
.664 .741 .907 r
.63275 .25276 .63372 .25402 .64018 .25176 .63922 .2505 Metetra
.664 .741 .907 r
.63922 .2505 .64018 .25176 .64666 .24949 .6457 .24823 Metetra
.664 .741 .907 r
.6457 .24823 .64666 .24949 .65315 .24722 .6522 .24595 Metetra
.664 .741 .907 r
.6522 .24595 .65315 .24722 .65966 .24494 .65871 .24367 Metetra
.664 .741 .907 r
.65871 .24367 .65966 .24494 .66619 .24266 .66523 .24138 Metetra
.664 .741 .907 r
.66523 .24138 .66619 .24266 .67272 .24037 .67178 .23909 Metetra
.664 .741 .907 r
.67178 .23909 .67272 .24037 .67928 .23807 .67833 .23679 Metetra
.664 .741 .907 r
.67833 .23679 .67928 .23807 .68585 .23577 .68491 .23449 Metetra
.664 .741 .907 r
.68491 .23449 .68585 .23577 .69243 .23347 .69149 .23218 Metetra
.664 .741 .907 r
.69149 .23218 .69243 .23347 .69903 .23116 .6981 .22987 Metetra
.664 .741 .907 r
.6981 .22987 .69903 .23116 .70565 .22884 .70471 .22755 Metetra
.664 .741 .907 r
.70471 .22755 .70565 .22884 .71228 .22652 .71135 .22522 Metetra
.664 .741 .907 r
.71135 .22522 .71228 .22652 .71892 .22419 .718 .22289 Metetra
.664 .741 .907 r
.718 .22289 .71892 .22419 .72558 .22186 .72466 .22056 Metetra
.664 .741 .907 r
.72466 .22056 .72558 .22186 .73226 .21952 .73134 .21822 Metetra
.664 .741 .907 r
.73134 .21822 .73226 .21952 .73895 .21718 .73804 .21587 Metetra
.664 .741 .907 r
.73804 .21587 .73895 .21718 .74566 .21483 .74475 .21352 Metetra
.962 .632 .265 r
.74475 .21352 .74566 .21483 .75584 .25853 .75941 .31739 Metetra
.278 .116 .473 r
.75941 .31739 .75584 .25853 .75913 .21012 .75822 .2088 Metetra
.664 .741 .907 r
.75822 .2088 .75913 .21012 .76588 .20775 .76498 .20643 Metetra
.664 .741 .907 r
.76498 .20643 .76588 .20775 .77266 .20538 .77176 .20406 Metetra
.664 .741 .907 r
.77176 .20406 .77266 .20538 .77944 .203 .77855 .20168 Metetra
.664 .741 .907 r
.77855 .20168 .77944 .203 .78625 .20062 .78535 .19929 Metetra
.664 .741 .907 r
.78535 .19929 .78625 .20062 .79307 .19823 .79218 .1969 Metetra
.664 .741 .907 r
.79218 .1969 .79307 .19823 .7999 .19584 .79902 .1945 Metetra
.664 .741 .907 r
.79902 .1945 .7999 .19584 .80676 .19344 .80587 .1921 Metetra
.664 .741 .907 r
.80587 .1921 .80676 .19344 .81362 .19104 .81275 .18969 Metetra
.664 .741 .907 r
.19665 .4041 .1978 .40517 .20331 .40324 .20216 .40217 Metetra
.664 .741 .907 r
.20216 .40217 .20331 .40324 .20882 .40131 .20767 .40023 Metetra
.664 .741 .907 r
.20767 .40023 .20882 .40131 .21435 .39937 .2132 .39829 Metetra
.664 .741 .907 r
.2132 .39829 .21435 .39937 .21988 .39743 .21874 .39635 Metetra
.664 .741 .907 r
.21874 .39635 .21988 .39743 .22543 .39549 .22429 .3944 Metetra
.664 .741 .907 r
.22429 .3944 .22543 .39549 .23099 .39354 .22985 .39245 Metetra
.664 .741 .907 r
.22985 .39245 .23099 .39354 .23656 .39159 .23543 .3905 Metetra
.664 .741 .907 r
.23543 .3905 .23656 .39159 .24215 .38963 .24102 .38854 Metetra
.664 .741 .907 r
.24102 .38854 .24215 .38963 .24775 .38767 .24661 .38657 Metetra
.664 .741 .907 r
.24661 .38657 .24775 .38767 .25336 .3857 .25223 .38461 Metetra
.664 .741 .907 r
.25223 .38461 .25336 .3857 .25898 .38374 .25785 .38264 Metetra
.664 .741 .907 r
.25785 .38264 .25898 .38374 .26461 .38176 .26348 .38066 Metetra
.664 .741 .907 r
.26348 .38066 .26461 .38176 .27025 .37978 .26913 .37868 Metetra
.664 .741 .907 r
.26913 .37868 .27025 .37978 .27591 .3778 .27479 .37669 Metetra
.664 .741 .907 r
.27479 .37669 .27591 .3778 .28158 .37581 .28046 .3747 Metetra
.664 .741 .907 r
.28046 .3747 .28158 .37581 .28726 .37382 .28615 .37271 Metetra
.664 .741 .907 r
.28615 .37271 .28726 .37382 .29296 .37183 .29184 .37071 Metetra
.664 .741 .907 r
.29184 .37071 .29296 .37183 .29866 .36983 .29755 .36871 Metetra
.664 .741 .907 r
.29755 .36871 .29866 .36983 .30438 .36783 .30327 .36671 Metetra
.664 .741 .907 r
.30327 .36671 .30438 .36783 .31011 .36582 .309 .3647 Metetra
.664 .741 .907 r
.309 .3647 .31011 .36582 .31586 .3638 .31475 .36268 Metetra
.664 .741 .907 r
.31475 .36268 .31586 .3638 .32161 .36179 .32051 .36066 Metetra
.952 .679 .482 r
.32051 .36066 .32161 .36179 .31924 .49092 .3137 .5602 Metetra
.137 0 .395 r
.3137 .5602 .31924 .49092 .32786 .4457 .32795 .42437 Metetra
.766 .522 .566 r
.32795 .42437 .32786 .4457 .33895 .35571 .33786 .35458 Metetra
.664 .741 .907 r
.33786 .35458 .33895 .35571 .34476 .35368 .34367 .35254 Metetra
.664 .741 .907 r
.34367 .35254 .34476 .35368 .35058 .35164 .34949 .3505 Metetra
.664 .741 .907 r
.34949 .3505 .35058 .35164 .35641 .34959 .35532 .34845 Metetra
.664 .741 .907 r
.35532 .34845 .35641 .34959 .36226 .34755 .36117 .3464 Metetra
.664 .741 .907 r
.36117 .3464 .36226 .34755 .36811 .34549 .36703 .34435 Metetra
.664 .741 .907 r
.36703 .34435 .36811 .34549 .37398 .34344 .3729 .34229 Metetra
.664 .741 .907 r
.3729 .34229 .37398 .34344 .37987 .34137 .37879 .34022 Metetra
.664 .741 .907 r
.37879 .34022 .37987 .34137 .38576 .33931 .38469 .33815 Metetra
.664 .741 .907 r
.38469 .33815 .38576 .33931 .39167 .33724 .3906 .33608 Metetra
.664 .741 .907 r
.3906 .33608 .39167 .33724 .3976 .33516 .39652 .334 Metetra
.664 .741 .907 r
.39652 .334 .3976 .33516 .40353 .33308 .40246 .33192 Metetra
.664 .741 .907 r
.40246 .33192 .40353 .33308 .40948 .331 .40841 .32983 Metetra
.664 .741 .907 r
.40841 .32983 .40948 .331 .41544 .32891 .41438 .32774 Metetra
.664 .741 .907 r
.41438 .32774 .41544 .32891 .42142 .32682 .42035 .32565 Metetra
.664 .741 .907 r
.42035 .32565 .42142 .32682 .4274 .32472 .42634 .32355 Metetra
.664 .741 .907 r
.42634 .32355 .4274 .32472 .43341 .32261 .43235 .32144 Metetra
.664 .741 .907 r
.43235 .32144 .43341 .32261 .43942 .32051 .43837 .31933 Metetra
.664 .741 .907 r
.43837 .31933 .43942 .32051 .44545 .31839 .4444 .31721 Metetra
.664 .741 .907 r
.4444 .31721 .44545 .31839 .45149 .31628 .45044 .31509 Metetra
.664 .741 .907 r
.45044 .31509 .45149 .31628 .45755 .31416 .4565 .31297 Metetra
.664 .741 .907 r
.4565 .31297 .45755 .31416 .46361 .31203 .46257 .31084 Metetra
.664 .741 .907 r
.46257 .31084 .46361 .31203 .4697 .3099 .46865 .30871 Metetra
.664 .741 .907 r
.46865 .30871 .4697 .3099 .47579 .30776 .47475 .30657 Metetra
.664 .741 .907 r
.47475 .30657 .47579 .30776 .4819 .30562 .48087 .30443 Metetra
.664 .741 .907 r
.48087 .30443 .4819 .30562 .48802 .30348 .48699 .30228 Metetra
.664 .741 .907 r
.48699 .30228 .48802 .30348 .49416 .30133 .49313 .30012 Metetra
.664 .741 .907 r
.49313 .30012 .49416 .30133 .50031 .29917 .49928 .29797 Metetra
.664 .741 .907 r
.49928 .29797 .50031 .29917 .50648 .29701 .50545 .2958 Metetra
.664 .741 .907 r
.50545 .2958 .50648 .29701 .51266 .29485 .51163 .29364 Metetra
.664 .741 .907 r
.51163 .29364 .51266 .29485 .51885 .29268 .51783 .29146 Metetra
.664 .741 .907 r
.51783 .29146 .51885 .29268 .52505 .2905 .52404 .28929 Metetra
.96 .627 .315 r
.52404 .28929 .52505 .2905 .53166 .47357 .53034 .33468 Metetra
.577 .348 .532 r
.53034 .33468 .53166 .47357 .53751 .28614 .5365 .28492 Metetra
.664 .741 .907 r
.5365 .28492 .53751 .28614 .54376 .28395 .54275 .28272 Metetra
.664 .741 .907 r
.54275 .28272 .54376 .28395 .55002 .28175 .54901 .28053 Metetra
.664 .741 .907 r
.54901 .28053 .55002 .28175 .5563 .27955 .55529 .27832 Metetra
.664 .741 .907 r
.55529 .27832 .5563 .27955 .56259 .27735 .56159 .27612 Metetra
.664 .741 .907 r
.56159 .27612 .56259 .27735 .5689 .27514 .5679 .2739 Metetra
.664 .741 .907 r
.5679 .2739 .5689 .27514 .57522 .27292 .57422 .27169 Metetra
.664 .741 .907 r
.57422 .27169 .57522 .27292 .58155 .2707 .58056 .26946 Metetra
.664 .741 .907 r
.58056 .26946 .58155 .2707 .5879 .26848 .58691 .26724 Metetra
.664 .741 .907 r
.58691 .26724 .5879 .26848 .59426 .26625 .59328 .265 Metetra
.664 .741 .907 r
.59328 .265 .59426 .26625 .60064 .26401 .59966 .26277 Metetra
.664 .741 .907 r
.59966 .26277 .60064 .26401 .60703 .26177 .60605 .26052 Metetra
.664 .741 .907 r
.60605 .26052 .60703 .26177 .61344 .25953 .61246 .25828 Metetra
.664 .741 .907 r
.61246 .25828 .61344 .25953 .61986 .25728 .61889 .25602 Metetra
.664 .741 .907 r
.61889 .25602 .61986 .25728 .6263 .25502 .62533 .25376 Metetra
.664 .741 .907 r
.62533 .25376 .6263 .25502 .63275 .25276 .63178 .2515 Metetra
.664 .741 .907 r
.63178 .2515 .63275 .25276 .63922 .2505 .63825 .24923 Metetra
.664 .741 .907 r
.63825 .24923 .63922 .2505 .6457 .24823 .64474 .24696 Metetra
.664 .741 .907 r
.64474 .24696 .6457 .24823 .6522 .24595 .65124 .24468 Metetra
.664 .741 .907 r
.65124 .24468 .6522 .24595 .65871 .24367 .65775 .24239 Metetra
.664 .741 .907 r
.65775 .24239 .65871 .24367 .66523 .24138 .66428 .2401 Metetra
.664 .741 .907 r
.66428 .2401 .66523 .24138 .67178 .23909 .67083 .23781 Metetra
.664 .741 .907 r
.67083 .23781 .67178 .23909 .67833 .23679 .67739 .23551 Metetra
.664 .741 .907 r
.67739 .23551 .67833 .23679 .68491 .23449 .68396 .2332 Metetra
.664 .741 .907 r
.68396 .2332 .68491 .23449 .69149 .23218 .69055 .23089 Metetra
.664 .741 .907 r
.69055 .23089 .69149 .23218 .6981 .22987 .69716 .22857 Metetra
.664 .741 .907 r
.69716 .22857 .6981 .22987 .70471 .22755 .70378 .22625 Metetra
.664 .741 .907 r
.70378 .22625 .70471 .22755 .71135 .22522 .71042 .22392 Metetra
.664 .741 .907 r
.71042 .22392 .71135 .22522 .718 .22289 .71707 .22159 Metetra
.664 .741 .907 r
.71707 .22159 .718 .22289 .72466 .22056 .72374 .21925 Metetra
.664 .741 .907 r
.72374 .21925 .72466 .22056 .73134 .21822 .73042 .21691 Metetra
.664 .741 .907 r
.73042 .21691 .73134 .21822 .73804 .21587 .73712 .21456 Metetra
.664 .741 .907 r
.73712 .21456 .73804 .21587 .74475 .21352 .74384 .2122 Metetra
.855 .454 0 r
.74384 .2122 .74475 .21352 .75941 .31739 .75247 .23543 Metetra
.573 .346 .533 r
.75247 .23543 .75941 .31739 .75822 .2088 .75731 .20748 Metetra
.664 .741 .907 r
.75731 .20748 .75822 .2088 .76498 .20643 .76408 .20511 Metetra
.664 .741 .907 r
.76408 .20511 .76498 .20643 .77176 .20406 .77086 .20273 Metetra
.664 .741 .907 r
.77086 .20273 .77176 .20406 .77855 .20168 .77765 .20035 Metetra
.664 .741 .907 r
.77765 .20035 .77855 .20168 .78535 .19929 .78446 .19796 Metetra
.664 .741 .907 r
.78446 .19796 .78535 .19929 .79218 .1969 .79129 .19556 Metetra
.664 .741 .907 r
.79129 .19556 .79218 .1969 .79902 .1945 .79813 .19316 Metetra
.664 .741 .907 r
.79813 .19316 .79902 .1945 .80587 .1921 .80499 .19076 Metetra
.664 .741 .907 r
.80499 .19076 .80587 .1921 .81275 .18969 .81187 .18835 Metetra
.664 .741 .907 r
.1955 .40302 .19665 .4041 .20216 .40217 .20101 .40109 Metetra
.664 .741 .907 r
.20101 .40109 .20216 .40217 .20767 .40023 .20653 .39915 Metetra
.664 .741 .907 r
.20653 .39915 .20767 .40023 .2132 .39829 .21205 .39721 Metetra
.664 .741 .907 r
.21205 .39721 .2132 .39829 .21874 .39635 .2176 .39526 Metetra
.664 .741 .907 r
.2176 .39526 .21874 .39635 .22429 .3944 .22315 .39332 Metetra
.875 .438 .07 r
.22315 .39332 .22429 .3944 .22985 .39245 .22761 .40331 Metetra
.587 .319 .477 r
.22761 .40331 .22985 .39245 .23543 .3905 .23249 .40936 Metetra
.328 .109 .422 r
.23249 .40936 .23543 .3905 .24102 .38854 .23988 .38744 Metetra
.664 .741 .907 r
.23988 .38744 .24102 .38854 .24661 .38657 .24548 .38548 Metetra
.664 .741 .907 r
.24548 .38548 .24661 .38657 .25223 .38461 .25109 .38351 Metetra
.664 .741 .907 r
.25109 .38351 .25223 .38461 .25785 .38264 .25672 .38153 Metetra
.664 .741 .907 r
.25672 .38153 .25785 .38264 .26348 .38066 .26236 .37955 Metetra
.664 .741 .907 r
.26236 .37955 .26348 .38066 .26913 .37868 .26801 .37757 Metetra
.664 .741 .907 r
.26801 .37757 .26913 .37868 .27479 .37669 .27367 .37559 Metetra
.664 .741 .907 r
.27367 .37559 .27479 .37669 .28046 .3747 .27934 .37359 Metetra
.664 .741 .907 r
.27934 .37359 .28046 .3747 .28615 .37271 .28503 .3716 Metetra
.664 .741 .907 r
.28503 .3716 .28615 .37271 .29184 .37071 .29073 .3696 Metetra
.664 .741 .907 r
.29073 .3696 .29184 .37071 .29755 .36871 .29644 .36759 Metetra
.664 .741 .907 r
.29644 .36759 .29755 .36871 .30327 .36671 .30216 .36558 Metetra
.664 .741 .907 r
.30216 .36558 .30327 .36671 .309 .3647 .3079 .36357 Metetra
.664 .741 .907 r
.3079 .36357 .309 .3647 .31475 .36268 .31364 .36155 Metetra
.664 .741 .907 r
.31364 .36155 .31475 .36268 .32051 .36066 .3194 .35953 Metetra
.952 .679 .482 r
.3194 .35953 .32051 .36066 .3137 .5602 .31266 .55681 Metetra
.94 .685 .523 r
.31266 .55681 .3137 .5602 .32795 .42437 .33096 .35548 Metetra
.54 .322 .533 r
.33096 .35548 .32795 .42437 .33786 .35458 .33676 .35344 Metetra
.664 .741 .907 r
.33676 .35344 .33786 .35458 .34367 .35254 .34257 .3514 Metetra
.664 .741 .907 r
.34257 .3514 .34367 .35254 .34949 .3505 .3484 .34936 Metetra
.664 .741 .907 r
.3484 .34936 .34949 .3505 .35532 .34845 .35423 .34731 Metetra
.664 .741 .907 r
.35423 .34731 .35532 .34845 .36117 .3464 .36008 .34526 Metetra
.664 .741 .907 r
.36008 .34526 .36117 .3464 .36703 .34435 .36594 .3432 Metetra
.664 .741 .907 r
.36594 .3432 .36703 .34435 .3729 .34229 .37182 .34114 Metetra
.664 .741 .907 r
.37182 .34114 .3729 .34229 .37879 .34022 .37771 .33907 Metetra
.664 .741 .907 r
.37771 .33907 .37879 .34022 .38469 .33815 .38361 .337 Metetra
.664 .741 .907 r
.38361 .337 .38469 .33815 .3906 .33608 .38952 .33492 Metetra
.664 .741 .907 r
.38952 .33492 .3906 .33608 .39652 .334 .39545 .33284 Metetra
.664 .741 .907 r
.39545 .33284 .39652 .334 .40246 .33192 .40139 .33076 Metetra
.664 .741 .907 r
.40139 .33076 .40246 .33192 .40841 .32983 .40734 .32867 Metetra
.664 .741 .907 r
.40734 .32867 .40841 .32983 .41438 .32774 .41331 .32657 Metetra
.664 .741 .907 r
.41331 .32657 .41438 .32774 .42035 .32565 .41929 .32447 Metetra
.664 .741 .907 r
.41929 .32447 .42035 .32565 .42634 .32355 .42528 .32237 Metetra
.664 .741 .907 r
.42528 .32237 .42634 .32355 .43235 .32144 .43129 .32026 Metetra
.664 .741 .907 r
.43129 .32026 .43235 .32144 .43837 .31933 .43731 .31815 Metetra
.664 .741 .907 r
.43731 .31815 .43837 .31933 .4444 .31721 .44334 .31603 Metetra
.664 .741 .907 r
.44334 .31603 .4444 .31721 .45044 .31509 .44939 .31391 Metetra
.664 .741 .907 r
.44939 .31391 .45044 .31509 .4565 .31297 .45545 .31178 Metetra
.664 .741 .907 r
.45545 .31178 .4565 .31297 .46257 .31084 .46152 .30965 Metetra
.664 .741 .907 r
.46152 .30965 .46257 .31084 .46865 .30871 .46761 .30752 Metetra
.664 .741 .907 r
.46761 .30752 .46865 .30871 .47475 .30657 .47371 .30537 Metetra
.664 .741 .907 r
.47371 .30537 .47475 .30657 .48087 .30443 .47983 .30323 Metetra
.664 .741 .907 r
.47983 .30323 .48087 .30443 .48699 .30228 .48596 .30108 Metetra
.664 .741 .907 r
.48596 .30108 .48699 .30228 .49313 .30012 .4921 .29892 Metetra
.664 .741 .907 r
.4921 .29892 .49313 .30012 .49928 .29797 .49825 .29676 Metetra
.664 .741 .907 r
.49825 .29676 .49928 .29797 .50545 .2958 .50442 .29459 Metetra
.664 .741 .907 r
.50442 .29459 .50545 .2958 .51163 .29364 .51061 .29242 Metetra
.664 .741 .907 r
.51061 .29242 .51163 .29364 .51783 .29146 .51681 .29025 Metetra
.944 .581 .232 r
.51681 .29025 .51783 .29146 .52404 .28929 .523 .31832 Metetra
.482 .252 .488 r
.523 .31832 .52404 .28929 .53034 .33468 .52927 .30695 Metetra
.624 .398 .554 r
.52927 .30695 .53034 .33468 .5365 .28492 .53548 .28369 Metetra
.664 .741 .907 r
.53548 .28369 .5365 .28492 .54275 .28272 .54174 .2815 Metetra
.664 .741 .907 r
.54174 .2815 .54275 .28272 .54901 .28053 .54801 .2793 Metetra
.664 .741 .907 r
.54801 .2793 .54901 .28053 .55529 .27832 .55429 .27709 Metetra
.664 .741 .907 r
.55429 .27709 .55529 .27832 .56159 .27612 .56059 .27488 Metetra
.664 .741 .907 r
.56059 .27488 .56159 .27612 .5679 .2739 .5669 .27267 Metetra
.664 .741 .907 r
.5669 .27267 .5679 .2739 .57422 .27169 .57322 .27045 Metetra
.664 .741 .907 r
.57322 .27045 .57422 .27169 .58056 .26946 .57956 .26822 Metetra
.664 .741 .907 r
.57956 .26822 .58056 .26946 .58691 .26724 .58592 .26599 Metetra
.664 .741 .907 r
.58592 .26599 .58691 .26724 .59328 .265 .59229 .26376 Metetra
.664 .741 .907 r
.59229 .26376 .59328 .265 .59966 .26277 .59867 .26152 Metetra
.664 .741 .907 r
.59867 .26152 .59966 .26277 .60605 .26052 .60507 .25927 Metetra
.664 .741 .907 r
.60507 .25927 .60605 .26052 .61246 .25828 .61149 .25702 Metetra
.664 .741 .907 r
.61149 .25702 .61246 .25828 .61889 .25602 .61791 .25476 Metetra
.664 .741 .907 r
.61791 .25476 .61889 .25602 .62533 .25376 .62436 .2525 Metetra
.664 .741 .907 r
.62436 .2525 .62533 .25376 .63178 .2515 .63081 .25024 Metetra
.621 .724 .92 r
.63081 .25024 .63178 .2515 .63825 .24923 .63731 .24863 Metetra
.693 .891 .97 r
.63731 .24863 .63825 .24923 .64474 .24696 .64377 .24569 Metetra
.664 .741 .907 r
.64377 .24569 .64474 .24696 .65124 .24468 .65028 .2434 Metetra
.664 .741 .907 r
.65028 .2434 .65124 .24468 .65775 .24239 .65679 .24112 Metetra
.664 .741 .907 r
.65679 .24112 .65775 .24239 .66428 .2401 .66333 .23882 Metetra
.664 .741 .907 r
.66333 .23882 .66428 .2401 .67083 .23781 .66988 .23653 Metetra
.664 .741 .907 r
.66988 .23653 .67083 .23781 .67739 .23551 .67644 .23422 Metetra
.664 .741 .907 r
.67644 .23422 .67739 .23551 .68396 .2332 .68302 .23191 Metetra
.664 .741 .907 r
.68302 .23191 .68396 .2332 .69055 .23089 .68961 .2296 Metetra
.664 .741 .907 r
.68961 .2296 .69055 .23089 .69716 .22857 .69622 .22728 Metetra
.664 .741 .907 r
.69622 .22728 .69716 .22857 .70378 .22625 .70285 .22495 Metetra
.664 .741 .907 r
.70285 .22495 .70378 .22625 .71042 .22392 .70949 .22262 Metetra
.664 .741 .907 r
.70949 .22262 .71042 .22392 .71707 .22159 .71614 .22029 Metetra
.664 .741 .907 r
.71614 .22029 .71707 .22159 .72374 .21925 .72281 .21795 Metetra
.664 .741 .907 r
.72281 .21795 .72374 .21925 .73042 .21691 .7295 .2156 Metetra
.841 .433 0 r
.7295 .2156 .73042 .21691 .73712 .21456 .73783 .23659 Metetra
.382 .174 .468 r
.73783 .23659 .73712 .21456 .74384 .2122 .74292 .21089 Metetra
.664 .741 .907 r
.74292 .21089 .74384 .2122 .75247 .23543 .74966 .20852 Metetra
.548 .34 .551 r
.74966 .20852 .75247 .23543 .75731 .20748 .75641 .20616 Metetra
.664 .741 .907 r
.75641 .20616 .75731 .20748 .76408 .20511 .76317 .20378 Metetra
.664 .741 .907 r
.76317 .20378 .76408 .20511 .77086 .20273 .76995 .2014 Metetra
.664 .741 .907 r
.76995 .2014 .77086 .20273 .77765 .20035 .77675 .19901 Metetra
.664 .741 .907 r
.77675 .19901 .77765 .20035 .78446 .19796 .78357 .19662 Metetra
.664 .741 .907 r
.78357 .19662 .78446 .19796 .79129 .19556 .7904 .19423 Metetra
.664 .741 .907 r
.7904 .19423 .79129 .19556 .79813 .19316 .79724 .19182 Metetra
.664 .741 .907 r
.79724 .19182 .79813 .19316 .80499 .19076 .80411 .18941 Metetra
.664 .741 .907 r
.80411 .18941 .80499 .19076 .81187 .18835 .81099 .187 Metetra
.664 .741 .907 r
.19435 .40194 .1955 .40302 .20101 .40109 .19986 .40001 Metetra
.664 .741 .907 r
.19986 .40001 .20101 .40109 .20653 .39915 .20538 .39807 Metetra
.664 .741 .907 r
.20538 .39807 .20653 .39915 .21205 .39721 .21091 .39613 Metetra
.664 .741 .907 r
.21091 .39613 .21205 .39721 .2176 .39526 .21645 .39418 Metetra
.664 .741 .907 r
.21645 .39418 .2176 .39526 .22315 .39332 .22201 .39223 Metetra
.946 .653 .452 r
.22201 .39223 .22315 .39332 .22761 .40331 .22296 .44012 Metetra
.306 .105 .435 r
.22296 .44012 .22761 .40331 .23249 .40936 .23265 .39382 Metetra
.596 .391 .574 r
.23265 .39382 .23249 .40936 .23988 .38744 .23874 .38635 Metetra
.664 .741 .907 r
.23874 .38635 .23988 .38744 .24548 .38548 .24435 .38438 Metetra
.664 .741 .907 r
.24435 .38438 .24548 .38548 .25109 .38351 .24996 .38241 Metetra
.664 .741 .907 r
.24996 .38241 .25109 .38351 .25672 .38153 .25559 .38043 Metetra
.664 .741 .907 r
.25559 .38043 .25672 .38153 .26236 .37955 .26123 .37845 Metetra
.664 .741 .907 r
.26123 .37845 .26236 .37955 .26801 .37757 .26688 .37646 Metetra
.664 .741 .907 r
.26688 .37646 .26801 .37757 .27367 .37559 .27254 .37447 Metetra
.664 .741 .907 r
.27254 .37447 .27367 .37559 .27934 .37359 .27822 .37248 Metetra
.664 .741 .907 r
.27822 .37248 .27934 .37359 .28503 .3716 .28391 .37048 Metetra
.664 .741 .907 r
.28391 .37048 .28503 .3716 .29073 .3696 .28961 .36848 Metetra
.664 .741 .907 r
.28961 .36848 .29073 .3696 .29644 .36759 .29532 .36647 Metetra
.664 .741 .907 r
.29532 .36647 .29644 .36759 .30216 .36558 .30105 .36446 Metetra
.664 .741 .907 r
.30105 .36446 .30216 .36558 .3079 .36357 .30678 .36245 Metetra
.664 .741 .907 r
.30678 .36245 .3079 .36357 .31364 .36155 .31253 .36043 Metetra
.664 .741 .907 r
.31253 .36043 .31364 .36155 .3194 .35953 .3183 .3584 Metetra
.953 .669 .459 r
.3183 .3584 .3194 .35953 .31266 .55681 .31814 .45033 Metetra
.633 .398 .543 r
.31814 .45033 .31266 .55681 .33096 .35548 .32986 .35434 Metetra
.664 .741 .907 r
.32986 .35434 .33096 .35548 .33676 .35344 .33566 .3523 Metetra
.664 .741 .907 r
.33566 .3523 .33676 .35344 .34257 .3514 .34148 .35026 Metetra
.664 .741 .907 r
.34148 .35026 .34257 .3514 .3484 .34936 .3473 .34821 Metetra
.664 .741 .907 r
.3473 .34821 .3484 .34936 .35423 .34731 .35314 .34616 Metetra
.664 .741 .907 r
.35314 .34616 .35423 .34731 .36008 .34526 .35899 .34411 Metetra
.664 .741 .907 r
.35899 .34411 .36008 .34526 .36594 .3432 .36486 .34205 Metetra
.664 .741 .907 r
.36486 .34205 .36594 .3432 .37182 .34114 .37073 .33998 Metetra
.664 .741 .907 r
.37073 .33998 .37182 .34114 .37771 .33907 .37663 .33791 Metetra
.664 .741 .907 r
.37663 .33791 .37771 .33907 .38361 .337 .38253 .33584 Metetra
.664 .741 .907 r
.38253 .33584 .38361 .337 .38952 .33492 .38845 .33376 Metetra
.664 .741 .907 r
.38845 .33376 .38952 .33492 .39545 .33284 .39438 .33168 Metetra
.664 .741 .907 r
.39438 .33168 .39545 .33284 .40139 .33076 .40032 .32959 Metetra
.664 .741 .907 r
.40032 .32959 .40139 .33076 .40734 .32867 .40627 .3275 Metetra
.671 .187 0 r
.40627 .3275 .40734 .32867 .41331 .32657 .41189 .33521 Metetra
.301 .059 .37 r
.41189 .33521 .41331 .32657 .41929 .32447 .41823 .3233 Metetra
.664 .741 .907 r
.41823 .3233 .41929 .32447 .42528 .32237 .42422 .3212 Metetra
.664 .741 .907 r
.42422 .3212 .42528 .32237 .43129 .32026 .43023 .31909 Metetra
.664 .741 .907 r
.43023 .31909 .43129 .32026 .43731 .31815 .43625 .31697 Metetra
.664 .741 .907 r
.43625 .31697 .43731 .31815 .44334 .31603 .44229 .31485 Metetra
.664 .741 .907 r
.44229 .31485 .44334 .31603 .44939 .31391 .44834 .31272 Metetra
.664 .741 .907 r
.44834 .31272 .44939 .31391 .45545 .31178 .4544 .3106 Metetra
.664 .741 .907 r
.4544 .3106 .45545 .31178 .46152 .30965 .46048 .30846 Metetra
.664 .741 .907 r
.46048 .30846 .46152 .30965 .46761 .30752 .46657 .30632 Metetra
.664 .741 .907 r
.46657 .30632 .46761 .30752 .47371 .30537 .47267 .30418 Metetra
.664 .741 .907 r
.47267 .30418 .47371 .30537 .47983 .30323 .47879 .30203 Metetra
.664 .741 .907 r
.47879 .30203 .47983 .30323 .48596 .30108 .48492 .29987 Metetra
.664 .741 .907 r
.48492 .29987 .48596 .30108 .4921 .29892 .49106 .29772 Metetra
.664 .741 .907 r
.49106 .29772 .4921 .29892 .49825 .29676 .49722 .29555 Metetra
.664 .741 .907 r
.49722 .29555 .49825 .29676 .50442 .29459 .5034 .29338 Metetra
.664 .741 .907 r
.5034 .29338 .50442 .29459 .51061 .29242 .50958 .29121 Metetra
.664 .741 .907 r
.50958 .29121 .51061 .29242 .51681 .29025 .51578 .28903 Metetra
.664 .741 .907 r
.51578 .28903 .51681 .29025 .523 .31832 .522 .28685 Metetra
.52 .316 .543 r
.522 .28685 .523 .31832 .52927 .30695 .52823 .29135 Metetra
.601 .394 .572 r
.52823 .29135 .52927 .30695 .53548 .28369 .53447 .28247 Metetra
.664 .741 .907 r
.53447 .28247 .53548 .28369 .54174 .2815 .54073 .28027 Metetra
.664 .741 .907 r
.54073 .28027 .54174 .2815 .54801 .2793 .547 .27807 Metetra
.664 .741 .907 r
.547 .27807 .54801 .2793 .55429 .27709 .55328 .27586 Metetra
.664 .741 .907 r
.55328 .27586 .55429 .27709 .56059 .27488 .55958 .27365 Metetra
.664 .741 .907 r
.55958 .27365 .56059 .27488 .5669 .27267 .5659 .27143 Metetra
.664 .741 .907 r
.5659 .27143 .5669 .27267 .57322 .27045 .57223 .26921 Metetra
.664 .741 .907 r
.57223 .26921 .57322 .27045 .57956 .26822 .57857 .26698 Metetra
.664 .741 .907 r
.57857 .26698 .57956 .26822 .58592 .26599 .58493 .26475 Metetra
.664 .741 .907 r
.58493 .26475 .58592 .26599 .59229 .26376 .5913 .26251 Metetra
.664 .741 .907 r
.5913 .26251 .59229 .26376 .59867 .26152 .59769 .26026 Metetra
.664 .741 .907 r
.59769 .26026 .59867 .26152 .60507 .25927 .60409 .25802 Metetra
.664 .741 .907 r
.60409 .25802 .60507 .25927 .61149 .25702 .61051 .25576 Metetra
.664 .741 .907 r
.61051 .25576 .61149 .25702 .61791 .25476 .61694 .2535 Metetra
.664 .741 .907 r
.61694 .2535 .61791 .25476 .62436 .2525 .62338 .25124 Metetra
.664 .741 .907 r
.62338 .25124 .62436 .2525 .63081 .25024 .62984 .24897 Metetra
.664 .741 .907 r
.62984 .24897 .63081 .25024 .63731 .24863 .63632 .24669 Metetra
.651 .64 .826 r
.63632 .24669 .63731 .24863 .64377 .24569 .64281 .24441 Metetra
.664 .741 .907 r
.64281 .24441 .64377 .24569 .65028 .2434 .64932 .24213 Metetra
.664 .741 .907 r
.64932 .24213 .65028 .2434 .65679 .24112 .65584 .23984 Metetra
.664 .741 .907 r
.65584 .23984 .65679 .24112 .66333 .23882 .66237 .23754 Metetra
.664 .741 .907 r
.66237 .23754 .66333 .23882 .66988 .23653 .66892 .23524 Metetra
.664 .741 .907 r
.66892 .23524 .66988 .23653 .67644 .23422 .67549 .23293 Metetra
.664 .741 .907 r
.67549 .23293 .67644 .23422 .68302 .23191 .68207 .23062 Metetra
.664 .741 .907 r
.68207 .23062 .68302 .23191 .68961 .2296 .68867 .22831 Metetra
.664 .741 .907 r
.68867 .22831 .68961 .2296 .69622 .22728 .69528 .22598 Metetra
.664 .741 .907 r
.69528 .22598 .69622 .22728 .70285 .22495 .70191 .22365 Metetra
.664 .741 .907 r
.70191 .22365 .70285 .22495 .70949 .22262 .70855 .22132 Metetra
.664 .741 .907 r
.70855 .22132 .70949 .22262 .71614 .22029 .71521 .21898 Metetra
.664 .741 .907 r
.71521 .21898 .71614 .22029 .72281 .21795 .72189 .21664 Metetra
.664 .741 .907 r
.72189 .21664 .72281 .21795 .7295 .2156 .72858 .21429 Metetra
.664 .741 .907 r
.72858 .21429 .7295 .2156 .73783 .23659 .73528 .21193 Metetra
.549 .343 .553 r
.73528 .21193 .73783 .23659 .74292 .21089 .742 .20957 Metetra
.652 .736 .911 r
.742 .20957 .74292 .21089 .74966 .20852 .74876 .2074 Metetra
.676 .784 .931 r
.74876 .2074 .74966 .20852 .75641 .20616 .7555 .20483 Metetra
.664 .741 .907 r
.7555 .20483 .75641 .20616 .76317 .20378 .76227 .20245 Metetra
.664 .741 .907 r
.76227 .20245 .76317 .20378 .76995 .2014 .76905 .20007 Metetra
.664 .741 .907 r
.76905 .20007 .76995 .2014 .77675 .19901 .77585 .19768 Metetra
.664 .741 .907 r
.77585 .19768 .77675 .19901 .78357 .19662 .78267 .19529 Metetra
.664 .741 .907 r
.78267 .19529 .78357 .19662 .7904 .19423 .7895 .19289 Metetra
.664 .741 .907 r
.7895 .19289 .7904 .19423 .79724 .19182 .79635 .19048 Metetra
.664 .741 .907 r
.79635 .19048 .79724 .19182 .80411 .18941 .80322 .18807 Metetra
.664 .741 .907 r
.80322 .18807 .80411 .18941 .81099 .187 .8101 .18565 Metetra
.664 .741 .907 r
.19319 .40086 .19435 .40194 .19986 .40001 .1987 .39893 Metetra
.664 .741 .907 r
.1987 .39893 .19986 .40001 .20538 .39807 .20422 .39699 Metetra
.664 .741 .907 r
.20422 .39699 .20538 .39807 .21091 .39613 .20976 .39504 Metetra
.664 .741 .907 r
.20976 .39504 .21091 .39613 .21645 .39418 .2153 .39309 Metetra
.664 .741 .907 r
.2153 .39309 .21645 .39418 .22201 .39223 .22086 .39114 Metetra
.908 .499 .166 r
.22086 .39114 .22201 .39223 .22296 .44012 .22513 .40322 Metetra
.588 .368 .549 r
.22513 .40322 .22296 .44012 .23265 .39382 .23201 .38722 Metetra
.581 .419 .627 r
.23201 .38722 .23265 .39382 .23874 .38635 .2376 .38525 Metetra
.664 .741 .907 r
.2376 .38525 .23874 .38635 .24435 .38438 .24321 .38328 Metetra
.664 .741 .907 r
.24321 .38328 .24435 .38438 .24996 .38241 .24883 .38131 Metetra
.664 .741 .907 r
.24883 .38131 .24996 .38241 .25559 .38043 .25446 .37933 Metetra
.664 .741 .907 r
.25446 .37933 .25559 .38043 .26123 .37845 .2601 .37734 Metetra
.664 .741 .907 r
.2601 .37734 .26123 .37845 .26688 .37646 .26575 .37536 Metetra
.664 .741 .907 r
.26575 .37536 .26688 .37646 .27254 .37447 .27142 .37336 Metetra
.664 .741 .907 r
.27142 .37336 .27254 .37447 .27822 .37248 .2771 .37137 Metetra
.664 .741 .907 r
.2771 .37137 .27822 .37248 .28391 .37048 .28279 .36937 Metetra
.664 .741 .907 r
.28279 .36937 .28391 .37048 .28961 .36848 .28849 .36736 Metetra
.664 .741 .907 r
.28849 .36736 .28961 .36848 .29532 .36647 .2942 .36535 Metetra
.664 .741 .907 r
.2942 .36535 .29532 .36647 .30105 .36446 .29993 .36334 Metetra
.664 .741 .907 r
.29993 .36334 .30105 .36446 .30678 .36245 .30567 .36132 Metetra
.664 .741 .907 r
.30567 .36132 .30678 .36245 .31253 .36043 .31143 .3593 Metetra
.664 .741 .907 r
.31143 .3593 .31253 .36043 .3183 .3584 .31719 .35727 Metetra
.664 .741 .907 r
.31719 .35727 .3183 .3584 .31814 .45033 .32297 .35524 Metetra
.514 .299 .525 r
.32297 .35524 .31814 .45033 .32986 .35434 .32771 .3702 Metetra
.33 .109 .419 r
.32771 .3702 .32986 .35434 .33566 .3523 .33456 .35117 Metetra
.664 .741 .907 r
.33456 .35117 .33566 .3523 .34148 .35026 .34038 .34912 Metetra
.664 .741 .907 r
.34038 .34912 .34148 .35026 .3473 .34821 .34621 .34707 Metetra
.664 .741 .907 r
.34621 .34707 .3473 .34821 .35314 .34616 .35205 .34502 Metetra
.664 .741 .907 r
.35205 .34502 .35314 .34616 .35899 .34411 .3579 .34296 Metetra
.664 .741 .907 r
.3579 .34296 .35899 .34411 .36486 .34205 .36377 .3409 Metetra
.664 .741 .907 r
.36377 .3409 .36486 .34205 .37073 .33998 .36965 .33883 Metetra
.664 .741 .907 r
.36965 .33883 .37073 .33998 .37663 .33791 .37554 .33676 Metetra
.664 .741 .907 r
.37554 .33676 .37663 .33791 .38253 .33584 .38145 .33468 Metetra
.664 .741 .907 r
.38145 .33468 .38253 .33584 .38845 .33376 .38737 .3326 Metetra
.664 .741 .907 r
.38737 .3326 .38845 .33376 .39438 .33168 .3933 .33052 Metetra
.664 .741 .907 r
.3933 .33052 .39438 .33168 .40032 .32959 .39924 .32843 Metetra
.664 .741 .907 r
.39924 .32843 .40032 .32959 .40627 .3275 .4052 .32633 Metetra
.664 .741 .907 r
.4052 .32633 .40627 .3275 .41189 .33521 .41117 .32423 Metetra
.565 .379 .588 r
.41117 .32423 .41189 .33521 .41823 .3233 .41716 .32213 Metetra
.538 .054 0 r
.41716 .32213 .41823 .3233 .42422 .3212 .42288 .32856 Metetra
.286 .036 .349 r
.42288 .32856 .42422 .3212 .43023 .31909 .42917 .31791 Metetra
.664 .741 .907 r
.42917 .31791 .43023 .31909 .43625 .31697 .43519 .31579 Metetra
.664 .741 .907 r
.43519 .31579 .43625 .31697 .44229 .31485 .44123 .31367 Metetra
.664 .741 .907 r
.44123 .31367 .44229 .31485 .44834 .31272 .44728 .31154 Metetra
.664 .741 .907 r
.44728 .31154 .44834 .31272 .4544 .3106 .45335 .30941 Metetra
.664 .741 .907 r
.45335 .30941 .4544 .3106 .46048 .30846 .45943 .30727 Metetra
.664 .741 .907 r
.45943 .30727 .46048 .30846 .46657 .30632 .46552 .30513 Metetra
.664 .741 .907 r
.46552 .30513 .46657 .30632 .47267 .30418 .47163 .30298 Metetra
.664 .741 .907 r
.47163 .30298 .47267 .30418 .47879 .30203 .47775 .30083 Metetra
.664 .741 .907 r
.47775 .30083 .47879 .30203 .48492 .29987 .48388 .29867 Metetra
.664 .741 .907 r
.48388 .29867 .48492 .29987 .49106 .29772 .49003 .29651 Metetra
.664 .741 .907 r
.49003 .29651 .49106 .29772 .49722 .29555 .49619 .29434 Metetra
.664 .741 .907 r
.49619 .29434 .49722 .29555 .5034 .29338 .50237 .29217 Metetra
.664 .741 .907 r
.50237 .29217 .5034 .29338 .50958 .29121 .50856 .29 Metetra
.664 .741 .907 r
.50856 .29 .50958 .29121 .51578 .28903 .51476 .28782 Metetra
.664 .741 .907 r
.51476 .28782 .51578 .28903 .522 .28685 .52098 .28563 Metetra
.664 .741 .907 r
.52098 .28563 .522 .28685 .52823 .29135 .52721 .28344 Metetra
.576 .405 .614 r
.52721 .28344 .52823 .29135 .53447 .28247 .53345 .28124 Metetra
.664 .741 .907 r
.53345 .28124 .53447 .28247 .54073 .28027 .53971 .27904 Metetra
.664 .741 .907 r
.53971 .27904 .54073 .28027 .547 .27807 .54599 .27684 Metetra
.664 .741 .907 r
.54599 .27684 .547 .27807 .55328 .27586 .55228 .27463 Metetra
.664 .741 .907 r
.55228 .27463 .55328 .27586 .55958 .27365 .55858 .27241 Metetra
.664 .741 .907 r
.55858 .27241 .55958 .27365 .5659 .27143 .5649 .27019 Metetra
.664 .741 .907 r
.5649 .27019 .5659 .27143 .57223 .26921 .57123 .26796 Metetra
.664 .741 .907 r
.57123 .26796 .57223 .26921 .57857 .26698 .57757 .26573 Metetra
.664 .741 .907 r
.57757 .26573 .57857 .26698 .58493 .26475 .58394 .2635 Metetra
.664 .741 .907 r
.58394 .2635 .58493 .26475 .5913 .26251 .59031 .26126 Metetra
.664 .741 .907 r
.59031 .26126 .5913 .26251 .59769 .26026 .5967 .25901 Metetra
.664 .741 .907 r
.5967 .25901 .59769 .26026 .60409 .25802 .60311 .25676 Metetra
.664 .741 .907 r
.60311 .25676 .60409 .25802 .61051 .25576 .60952 .2545 Metetra
.664 .741 .907 r
.60952 .2545 .61051 .25576 .61694 .2535 .61596 .25224 Metetra
.664 .741 .907 r
.61596 .25224 .61694 .2535 .62338 .25124 .62241 .24997 Metetra
.664 .741 .907 r
.62241 .24997 .62338 .25124 .62984 .24897 .62887 .2477 Metetra
.664 .741 .907 r
.62887 .2477 .62984 .24897 .63632 .24669 .63535 .24542 Metetra
.664 .741 .907 r
.63535 .24542 .63632 .24669 .64281 .24441 .64184 .24314 Metetra
.664 .741 .907 r
.64184 .24314 .64281 .24441 .64932 .24213 .64835 .24085 Metetra
.664 .741 .907 r
.64835 .24085 .64932 .24213 .65584 .23984 .65488 .23856 Metetra
.664 .741 .907 r
.65488 .23856 .65584 .23984 .66237 .23754 .66142 .23626 Metetra
.664 .741 .907 r
.66142 .23626 .66237 .23754 .66892 .23524 .66797 .23396 Metetra
.664 .741 .907 r
.66797 .23396 .66892 .23524 .67549 .23293 .67454 .23165 Metetra
.664 .741 .907 r
.67454 .23165 .67549 .23293 .68207 .23062 .68112 .22933 Metetra
.664 .741 .907 r
.68112 .22933 .68207 .23062 .68867 .22831 .68773 .22701 Metetra
.664 .741 .907 r
.68773 .22701 .68867 .22831 .69528 .22598 .69434 .22468 Metetra
.664 .741 .907 r
.69434 .22468 .69528 .22598 .70191 .22365 .70097 .22235 Metetra
.664 .741 .907 r
.70097 .22235 .70191 .22365 .70855 .22132 .70762 .22002 Metetra
.664 .741 .907 r
.70762 .22002 .70855 .22132 .71521 .21898 .71428 .21767 Metetra
.664 .741 .907 r
.71428 .21767 .71521 .21898 .72189 .21664 .72096 .21533 Metetra
.664 .741 .907 r
.72096 .21533 .72189 .21664 .72858 .21429 .72765 .21297 Metetra
.664 .741 .907 r
.72765 .21297 .72858 .21429 .73528 .21193 .73436 .21062 Metetra
.664 .741 .907 r
.73436 .21062 .73528 .21193 .742 .20957 .74109 .20825 Metetra
.911 .536 .101 r
.74109 .20825 .742 .20957 .74876 .2074 .75051 .24237 Metetra
.392 .191 .483 r
.75051 .24237 .74876 .2074 .7555 .20483 .75459 .20351 Metetra
.664 .741 .907 r
.75459 .20351 .7555 .20483 .76227 .20245 .76136 .20112 Metetra
.664 .741 .907 r
.76136 .20112 .76227 .20245 .76905 .20007 .76815 .19874 Metetra
.664 .741 .907 r
.76815 .19874 .76905 .20007 .77585 .19768 .77495 .19635 Metetra
.664 .741 .907 r
.77495 .19635 .77585 .19768 .78267 .19529 .78177 .19395 Metetra
.664 .741 .907 r
.78177 .19395 .78267 .19529 .7895 .19289 .78861 .19154 Metetra
.664 .741 .907 r
.78861 .19154 .7895 .19289 .79635 .19048 .79546 .18913 Metetra
.664 .741 .907 r
.79546 .18913 .79635 .19048 .80322 .18807 .80233 .18672 Metetra
.664 .741 .907 r
.80233 .18672 .80322 .18807 .8101 .18565 .80922 .1843 Metetra
.664 .741 .907 r
.19204 .39978 .19319 .40086 .1987 .39893 .19755 .39784 Metetra
.664 .741 .907 r
.19755 .39784 .1987 .39893 .20422 .39699 .20307 .3959 Metetra
.664 .741 .907 r
.20307 .3959 .20422 .39699 .20976 .39504 .20861 .39395 Metetra
.664 .741 .907 r
.20861 .39395 .20976 .39504 .2153 .39309 .21416 .392 Metetra
.664 .741 .907 r
.21416 .392 .2153 .39309 .22086 .39114 .21972 .39005 Metetra
.465 .671 .953 r
.21972 .39005 .22086 .39114 .22513 .40322 .2251 .39012 Metetra
.578 .381 .579 r
.2251 .39012 .22513 .40322 .23201 .38722 .23087 .38612 Metetra
.664 .741 .907 r
.23087 .38612 .23201 .38722 .2376 .38525 .23647 .38415 Metetra
.664 .741 .907 r
.23647 .38415 .2376 .38525 .24321 .38328 .24207 .38218 Metetra
.664 .741 .907 r
.24207 .38218 .24321 .38328 .24883 .38131 .24769 .3802 Metetra
.664 .741 .907 r
.24769 .3802 .24883 .38131 .25446 .37933 .25332 .37822 Metetra
.664 .741 .907 r
.25332 .37822 .25446 .37933 .2601 .37734 .25897 .37623 Metetra
.664 .741 .907 r
.25897 .37623 .2601 .37734 .26575 .37536 .26462 .37424 Metetra
.664 .741 .907 r
.26462 .37424 .26575 .37536 .27142 .37336 .27029 .37225 Metetra
.664 .741 .907 r
.27029 .37225 .27142 .37336 .2771 .37137 .27597 .37025 Metetra
.664 .741 .907 r
.27597 .37025 .2771 .37137 .28279 .36937 .28166 .36825 Metetra
.664 .741 .907 r
.28166 .36825 .28279 .36937 .28849 .36736 .28737 .36624 Metetra
.664 .741 .907 r
.28737 .36624 .28849 .36736 .2942 .36535 .29309 .36423 Metetra
.664 .741 .907 r
.29309 .36423 .2942 .36535 .29993 .36334 .29882 .36221 Metetra
.664 .741 .907 r
.29882 .36221 .29993 .36334 .30567 .36132 .30456 .36019 Metetra
.664 .741 .907 r
.30456 .36019 .30567 .36132 .31143 .3593 .31031 .35817 Metetra
.664 .741 .907 r
.31031 .35817 .31143 .3593 .31719 .35727 .31608 .35614 Metetra
.664 .741 .907 r
.31608 .35614 .31719 .35727 .32297 .35524 .32186 .35411 Metetra
.664 .741 .907 r
.32186 .35411 .32297 .35524 .32771 .3702 .32765 .35207 Metetra
.553 .352 .562 r
.32765 .35207 .32771 .3702 .33456 .35117 .33346 .35003 Metetra
.664 .741 .907 r
.33346 .35003 .33456 .35117 .34038 .34912 .33928 .34798 Metetra
.664 .741 .907 r
.33928 .34798 .34038 .34912 .34621 .34707 .34511 .34593 Metetra
.664 .741 .907 r
.34511 .34593 .34621 .34707 .35205 .34502 .35095 .34387 Metetra
.664 .741 .907 r
.35095 .34387 .35205 .34502 .3579 .34296 .35681 .34181 Metetra
.664 .741 .907 r
.35681 .34181 .3579 .34296 .36377 .3409 .36268 .33975 Metetra
.664 .741 .907 r
.36268 .33975 .36377 .3409 .36965 .33883 .36856 .33768 Metetra
.664 .741 .907 r
.36856 .33768 .36965 .33883 .37554 .33676 .37446 .3356 Metetra
.664 .741 .907 r
.37446 .3356 .37554 .33676 .38145 .33468 .38037 .33352 Metetra
.664 .741 .907 r
.38037 .33352 .38145 .33468 .38737 .3326 .38629 .33144 Metetra
.664 .741 .907 r
.38629 .33144 .38737 .3326 .3933 .33052 .39222 .32935 Metetra
.664 .741 .907 r
.39222 .32935 .3933 .33052 .39924 .32843 .39817 .32726 Metetra
.664 .741 .907 r
.39817 .32726 .39924 .32843 .4052 .32633 .40413 .32516 Metetra
.664 .741 .907 r
.40413 .32516 .4052 .32633 .41117 .32423 .4101 .32306 Metetra
.664 .741 .907 r
.4101 .32306 .41117 .32423 .41716 .32213 .41609 .32095 Metetra
.962 .671 .436 r
.41609 .32095 .41716 .32213 .42288 .32856 .41807 .44177 Metetra
.366 .172 .479 r
.41807 .44177 .42288 .32856 .42917 .31791 .42807 .31799 Metetra
.633 .961 .902 r
.42807 .31799 .42917 .31791 .43519 .31579 .43413 .3146 Metetra
.664 .741 .907 r
.43413 .3146 .43519 .31579 .44123 .31367 .44018 .31248 Metetra
.664 .741 .907 r
.44018 .31248 .44123 .31367 .44728 .31154 .44623 .31035 Metetra
.664 .741 .907 r
.44623 .31035 .44728 .31154 .45335 .30941 .4523 .30821 Metetra
.664 .741 .907 r
.4523 .30821 .45335 .30941 .45943 .30727 .45838 .30607 Metetra
.664 .741 .907 r
.45838 .30607 .45943 .30727 .46552 .30513 .46447 .30393 Metetra
.664 .741 .907 r
.46447 .30393 .46552 .30513 .47163 .30298 .47058 .30178 Metetra
.664 .741 .907 r
.47058 .30178 .47163 .30298 .47775 .30083 .47671 .29963 Metetra
.664 .741 .907 r
.47671 .29963 .47775 .30083 .48388 .29867 .48284 .29747 Metetra
.664 .741 .907 r
.48284 .29747 .48388 .29867 .49003 .29651 .48899 .2953 Metetra
.664 .741 .907 r
.48899 .2953 .49003 .29651 .49619 .29434 .49516 .29313 Metetra
.664 .741 .907 r
.49516 .29313 .49619 .29434 .50237 .29217 .50134 .29096 Metetra
.664 .741 .907 r
.50134 .29096 .50237 .29217 .50856 .29 .50753 .28878 Metetra
.664 .741 .907 r
.50753 .28878 .50856 .29 .51476 .28782 .51373 .2866 Metetra
.664 .741 .907 r
.51373 .2866 .51476 .28782 .52098 .28563 .51995 .28441 Metetra
.664 .741 .907 r
.51995 .28441 .52098 .28563 .52721 .28344 .52619 .28222 Metetra
.664 .741 .907 r
.52619 .28222 .52721 .28344 .53345 .28124 .53244 .28002 Metetra
.664 .741 .907 r
.53244 .28002 .53345 .28124 .53971 .27904 .5387 .27781 Metetra
.664 .741 .907 r
.5387 .27781 .53971 .27904 .54599 .27684 .54498 .27561 Metetra
.664 .741 .907 r
.54498 .27561 .54599 .27684 .55228 .27463 .55127 .27339 Metetra
.664 .741 .907 r
.55127 .27339 .55228 .27463 .55858 .27241 .55757 .27117 Metetra
.664 .741 .907 r
.55757 .27117 .55858 .27241 .5649 .27019 .56389 .26895 Metetra
.664 .741 .907 r
.56389 .26895 .5649 .27019 .57123 .26796 .57023 .26672 Metetra
.664 .741 .907 r
.57023 .26672 .57123 .26796 .57757 .26573 .57658 .26449 Metetra
.664 .741 .907 r
.57658 .26449 .57757 .26573 .58394 .2635 .58294 .26225 Metetra
.664 .741 .907 r
.58294 .26225 .58394 .2635 .59031 .26126 .58932 .26 Metetra
.664 .741 .907 r
.58932 .26 .59031 .26126 .5967 .25901 .59571 .25776 Metetra
.664 .741 .907 r
.59571 .25776 .5967 .25901 .60311 .25676 .60212 .2555 Metetra
.664 .741 .907 r
.60212 .2555 .60311 .25676 .60952 .2545 .60854 .25324 Metetra
.664 .741 .907 r
.60854 .25324 .60952 .2545 .61596 .25224 .61498 .25098 Metetra
.664 .741 .907 r
.61498 .25098 .61596 .25224 .62241 .24997 .62143 .24871 Metetra
.664 .741 .907 r
.62143 .24871 .62241 .24997 .62887 .2477 .6279 .24643 Metetra
.664 .741 .907 r
.6279 .24643 .62887 .2477 .63535 .24542 .63438 .24415 Metetra
.664 .741 .907 r
.63438 .24415 .63535 .24542 .64184 .24314 .64088 .24186 Metetra
.664 .741 .907 r
.64088 .24186 .64184 .24314 .64835 .24085 .64739 .23957 Metetra
.664 .741 .907 r
.64739 .23957 .64835 .24085 .65488 .23856 .65392 .23728 Metetra
.664 .741 .907 r
.65392 .23728 .65488 .23856 .66142 .23626 .66046 .23498 Metetra
.664 .741 .907 r
.66046 .23498 .66142 .23626 .66797 .23396 .66702 .23267 Metetra
.664 .741 .907 r
.66702 .23267 .66797 .23396 .67454 .23165 .67359 .23036 Metetra
.664 .741 .907 r
.67359 .23036 .67454 .23165 .68112 .22933 .68018 .22804 Metetra
.664 .741 .907 r
.68018 .22804 .68112 .22933 .68773 .22701 .68678 .22571 Metetra
.664 .741 .907 r
.68678 .22571 .68773 .22701 .69434 .22468 .6934 .22339 Metetra
.664 .741 .907 r
.6934 .22339 .69434 .22468 .70097 .22235 .70003 .22105 Metetra
.664 .741 .907 r
.70003 .22105 .70097 .22235 .70762 .22002 .70668 .21871 Metetra
.664 .741 .907 r
.70668 .21871 .70762 .22002 .71428 .21767 .71335 .21637 Metetra
.664 .741 .907 r
.71335 .21637 .71428 .21767 .72096 .21533 .72003 .21402 Metetra
.664 .741 .907 r
.72003 .21402 .72096 .21533 .72765 .21297 .72673 .21166 Metetra
.664 .741 .907 r
.72673 .21166 .72765 .21297 .73436 .21062 .73344 .2093 Metetra
.772 .349 0 r
.73344 .2093 .73436 .21062 .74109 .20825 .74152 .22602 Metetra
.656 .376 .484 r
.74152 .22602 .74109 .20825 .75051 .24237 .75042 .25233 Metetra
0 0 .203 r
.75042 .25233 .75051 .24237 .75459 .20351 .75367 .20218 Metetra
.664 .741 .907 r
.75367 .20218 .75459 .20351 .76136 .20112 .76045 .19979 Metetra
.664 .741 .907 r
.76045 .19979 .76136 .20112 .76815 .19874 .76724 .1974 Metetra
.664 .741 .907 r
.76724 .1974 .76815 .19874 .77495 .19635 .77405 .19501 Metetra
.664 .741 .907 r
.77405 .19501 .77495 .19635 .78177 .19395 .78087 .19261 Metetra
.664 .741 .907 r
.78087 .19261 .78177 .19395 .78861 .19154 .78772 .1902 Metetra
.664 .741 .907 r
.78772 .1902 .78861 .19154 .79546 .18913 .79457 .18779 Metetra
.664 .741 .907 r
.79457 .18779 .79546 .18913 .80233 .18672 .80145 .18537 Metetra
.664 .741 .907 r
.80145 .18537 .80233 .18672 .80922 .1843 .80834 .18295 Metetra
.664 .741 .907 r
.19088 .3987 .19204 .39978 .19755 .39784 .19639 .39676 Metetra
.664 .741 .907 r
.19639 .39676 .19755 .39784 .20307 .3959 .20192 .39481 Metetra
.664 .741 .907 r
.20192 .39481 .20307 .3959 .20861 .39395 .20746 .39286 Metetra
.664 .741 .907 r
.20746 .39286 .20861 .39395 .21416 .392 .21301 .39091 Metetra
.664 .741 .907 r
.21301 .39091 .21416 .392 .21972 .39005 .21857 .38895 Metetra
.664 .741 .907 r
.21857 .38895 .21972 .39005 .2251 .39012 .22414 .38699 Metetra
.618 .522 .722 r
.22414 .38699 .2251 .39012 .23087 .38612 .22973 .38502 Metetra
.664 .741 .907 r
.22973 .38502 .23087 .38612 .23647 .38415 .23532 .38305 Metetra
.664 .741 .907 r
.23532 .38305 .23647 .38415 .24207 .38218 .24093 .38108 Metetra
.664 .741 .907 r
.24093 .38108 .24207 .38218 .24769 .3802 .24656 .3791 Metetra
.664 .741 .907 r
.24656 .3791 .24769 .3802 .25332 .37822 .25219 .37711 Metetra
.664 .741 .907 r
.25219 .37711 .25332 .37822 .25897 .37623 .25784 .37513 Metetra
.664 .741 .907 r
.25784 .37513 .25897 .37623 .26462 .37424 .26349 .37313 Metetra
.664 .741 .907 r
.26349 .37313 .26462 .37424 .27029 .37225 .26916 .37114 Metetra
.664 .741 .907 r
.26916 .37114 .27029 .37225 .27597 .37025 .27485 .36914 Metetra
.664 .741 .907 r
.27485 .36914 .27597 .37025 .28166 .36825 .28054 .36713 Metetra
.664 .741 .907 r
.28054 .36713 .28166 .36825 .28737 .36624 .28625 .36512 Metetra
.664 .741 .907 r
.28625 .36512 .28737 .36624 .29309 .36423 .29197 .36311 Metetra
.664 .741 .907 r
.29197 .36311 .29309 .36423 .29882 .36221 .2977 .36109 Metetra
.664 .741 .907 r
.2977 .36109 .29882 .36221 .30456 .36019 .30345 .35906 Metetra
.664 .741 .907 r
.30345 .35906 .30456 .36019 .31031 .35817 .3092 .35704 Metetra
.664 .741 .907 r
.3092 .35704 .31031 .35817 .31608 .35614 .31497 .35501 Metetra
.664 .741 .907 r
.31497 .35501 .31608 .35614 .32186 .35411 .32075 .35297 Metetra
.664 .741 .907 r
.32075 .35297 .32186 .35411 .32765 .35207 .32655 .35093 Metetra
.664 .741 .907 r
.32655 .35093 .32765 .35207 .33346 .35003 .33236 .34888 Metetra
.664 .741 .907 r
.33236 .34888 .33346 .35003 .33928 .34798 .33818 .34683 Metetra
.664 .741 .907 r
.33818 .34683 .33928 .34798 .34511 .34593 .34401 .34478 Metetra
.664 .741 .907 r
.34401 .34478 .34511 .34593 .35095 .34387 .34986 .34272 Metetra
.664 .741 .907 r
.34986 .34272 .35095 .34387 .35681 .34181 .35572 .34066 Metetra
.664 .741 .907 r
.35572 .34066 .35681 .34181 .36268 .33975 .36159 .33859 Metetra
.664 .741 .907 r
.36159 .33859 .36268 .33975 .36856 .33768 .36747 .33652 Metetra
.664 .741 .907 r
.36747 .33652 .36856 .33768 .37446 .3356 .37337 .33444 Metetra
.664 .741 .907 r
.37337 .33444 .37446 .3356 .38037 .33352 .37928 .33236 Metetra
.664 .741 .907 r
.37928 .33236 .38037 .33352 .38629 .33144 .38521 .33028 Metetra
.664 .741 .907 r
.38521 .33028 .38629 .33144 .39222 .32935 .39114 .32818 Metetra
.664 .741 .907 r
.39114 .32818 .39222 .32935 .39817 .32726 .39709 .32609 Metetra
.664 .741 .907 r
.39709 .32609 .39817 .32726 .40413 .32516 .40306 .32399 Metetra
.664 .741 .907 r
.40306 .32399 .40413 .32516 .4101 .32306 .40903 .32188 Metetra
.959 .64 .372 r
.40903 .32188 .4101 .32306 .41609 .32095 .41335 .36752 Metetra
.771 .502 .528 r
.41335 .36752 .41609 .32095 .41807 .44177 .41338 .54873 Metetra
.097 0 .394 r
.41338 .54873 .41807 .44177 .42807 .31799 .42704 .31554 Metetra
.635 .576 .771 r
.42704 .31554 .42807 .31799 .43413 .3146 .43307 .31342 Metetra
.664 .741 .907 r
.43307 .31342 .43413 .3146 .44018 .31248 .43912 .31129 Metetra
.664 .741 .907 r
.43912 .31129 .44018 .31248 .44623 .31035 .44517 .30916 Metetra
.664 .741 .907 r
.44517 .30916 .44623 .31035 .4523 .30821 .45124 .30702 Metetra
.664 .741 .907 r
.45124 .30702 .4523 .30821 .45838 .30607 .45733 .30488 Metetra
.664 .741 .907 r
.45733 .30488 .45838 .30607 .46447 .30393 .46343 .30273 Metetra
.664 .741 .907 r
.46343 .30273 .46447 .30393 .47058 .30178 .46954 .30058 Metetra
.664 .741 .907 r
.46954 .30058 .47058 .30178 .47671 .29963 .47566 .29842 Metetra
.664 .741 .907 r
.47566 .29842 .47671 .29963 .48284 .29747 .4818 .29626 Metetra
.664 .741 .907 r
.4818 .29626 .48284 .29747 .48899 .2953 .48796 .29409 Metetra
.664 .741 .907 r
.48796 .29409 .48899 .2953 .49516 .29313 .49412 .29192 Metetra
.664 .741 .907 r
.49412 .29192 .49516 .29313 .50134 .29096 .5003 .28975 Metetra
.664 .741 .907 r
.5003 .28975 .50134 .29096 .50753 .28878 .5065 .28756 Metetra
.664 .741 .907 r
.5065 .28756 .50753 .28878 .51373 .2866 .51271 .28538 Metetra
.664 .741 .907 r
.51271 .28538 .51373 .2866 .51995 .28441 .51893 .28319 Metetra
.664 .741 .907 r
.51893 .28319 .51995 .28441 .52619 .28222 .52517 .28099 Metetra
.664 .741 .907 r
.52517 .28099 .52619 .28222 .53244 .28002 .53142 .27879 Metetra
.664 .741 .907 r
.53142 .27879 .53244 .28002 .5387 .27781 .53769 .27658 Metetra
.664 .741 .907 r
.53769 .27658 .5387 .27781 .54498 .27561 .54396 .27437 Metetra
.664 .741 .907 r
.54396 .27437 .54498 .27561 .55127 .27339 .55026 .27216 Metetra
.664 .741 .907 r
.55026 .27216 .55127 .27339 .55757 .27117 .55657 .26993 Metetra
.664 .741 .907 r
.55657 .26993 .55757 .27117 .56389 .26895 .56289 .26771 Metetra
.664 .741 .907 r
.56289 .26771 .56389 .26895 .57023 .26672 .56923 .26548 Metetra
.664 .741 .907 r
.56923 .26548 .57023 .26672 .57658 .26449 .57558 .26324 Metetra
.664 .741 .907 r
.57558 .26324 .57658 .26449 .58294 .26225 .58195 .261 Metetra
.664 .741 .907 r
.58195 .261 .58294 .26225 .58932 .26 .58833 .25875 Metetra
.664 .741 .907 r
.58833 .25875 .58932 .26 .59571 .25776 .59472 .2565 Metetra
.664 .741 .907 r
.59472 .2565 .59571 .25776 .60212 .2555 .60113 .25424 Metetra
.664 .741 .907 r
.60113 .25424 .60212 .2555 .60854 .25324 .60756 .25198 Metetra
.664 .741 .907 r
.60756 .25198 .60854 .25324 .61498 .25098 .614 .24971 Metetra
.664 .741 .907 r
.614 .24971 .61498 .25098 .62143 .24871 .62045 .24744 Metetra
.664 .741 .907 r
.62045 .24744 .62143 .24871 .6279 .24643 .62692 .24516 Metetra
.664 .741 .907 r
.62692 .24516 .6279 .24643 .63438 .24415 .63341 .24288 Metetra
.664 .741 .907 r
.63341 .24288 .63438 .24415 .64088 .24186 .63991 .24059 Metetra
.664 .741 .907 r
.63991 .24059 .64088 .24186 .64739 .23957 .64642 .23829 Metetra
.664 .741 .907 r
.64642 .23829 .64739 .23957 .65392 .23728 .65295 .23599 Metetra
.664 .741 .907 r
.65295 .23599 .65392 .23728 .66046 .23498 .6595 .23369 Metetra
.664 .741 .907 r
.6595 .23369 .66046 .23498 .66702 .23267 .66606 .23138 Metetra
.664 .741 .907 r
.66606 .23138 .66702 .23267 .67359 .23036 .67264 .22906 Metetra
.664 .741 .907 r
.67264 .22906 .67359 .23036 .68018 .22804 .67923 .22674 Metetra
.664 .741 .907 r
.67923 .22674 .68018 .22804 .68678 .22571 .68583 .22442 Metetra
.664 .741 .907 r
.68583 .22442 .68678 .22571 .6934 .22339 .69246 .22208 Metetra
.664 .741 .907 r
.69246 .22208 .6934 .22339 .70003 .22105 .69909 .21975 Metetra
.664 .741 .907 r
.69909 .21975 .70003 .22105 .70668 .21871 .70575 .2174 Metetra
.664 .741 .907 r
.70575 .2174 .70668 .21871 .71335 .21637 .71242 .21506 Metetra
.664 .741 .907 r
.71242 .21506 .71335 .21637 .72003 .21402 .7191 .2127 Metetra
0 .036 .582 r
.7191 .2127 .72003 .21402 .72673 .21166 .72649 .2207 Metetra
.337 .103 .404 r
.72649 .2207 .72673 .21166 .73344 .2093 .73252 .20798 Metetra
.664 .741 .907 r
.73252 .20798 .73344 .2093 .74152 .22602 .73925 .20561 Metetra
.359 .212 .542 r
.73925 .20561 .74152 .22602 .75042 .25233 .74821 .23346 Metetra
.691 .451 .555 r
.74821 .23346 .75042 .25233 .75367 .20218 .75276 .20085 Metetra
.664 .741 .907 r
.75276 .20085 .75367 .20218 .76045 .19979 .75954 .19846 Metetra
.664 .741 .907 r
.75954 .19846 .76045 .19979 .76724 .1974 .76634 .19607 Metetra
.664 .741 .907 r
.76634 .19607 .76724 .1974 .77405 .19501 .77315 .19367 Metetra
.664 .741 .907 r
.77315 .19367 .77405 .19501 .78087 .19261 .77998 .19127 Metetra
.664 .741 .907 r
.77998 .19127 .78087 .19261 .78772 .1902 .78682 .18886 Metetra
.664 .741 .907 r
.78682 .18886 .78772 .1902 .79457 .18779 .79368 .18644 Metetra
.664 .741 .907 r
.79368 .18644 .79457 .18779 .80145 .18537 .80056 .18402 Metetra
.664 .741 .907 r
.80056 .18402 .80145 .18537 .80834 .18295 .80745 .18159 Metetra
.664 .741 .907 r
.18972 .39762 .19088 .3987 .19639 .39676 .19524 .39568 Metetra
.664 .741 .907 r
.19524 .39568 .19639 .39676 .20192 .39481 .20076 .39373 Metetra
.664 .741 .907 r
.20076 .39373 .20192 .39481 .20746 .39286 .2063 .39178 Metetra
.664 .741 .907 r
.2063 .39178 .20746 .39286 .21301 .39091 .21186 .38982 Metetra
.664 .741 .907 r
.21186 .38982 .21301 .39091 .21857 .38895 .21742 .38786 Metetra
.664 .741 .907 r
.21742 .38786 .21857 .38895 .22414 .38699 .223 .38589 Metetra
.664 .741 .907 r
.223 .38589 .22414 .38699 .22973 .38502 .22858 .38392 Metetra
.664 .741 .907 r
.22858 .38392 .22973 .38502 .23532 .38305 .23418 .38195 Metetra
.664 .741 .907 r
.23418 .38195 .23532 .38305 .24093 .38108 .23979 .37997 Metetra
.664 .741 .907 r
.23979 .37997 .24093 .38108 .24656 .3791 .24542 .37799 Metetra
.664 .741 .907 r
.24542 .37799 .24656 .3791 .25219 .37711 .25105 .37601 Metetra
.664 .741 .907 r
.25105 .37601 .25219 .37711 .25784 .37513 .2567 .37401 Metetra
.664 .741 .907 r
.2567 .37401 .25784 .37513 .26349 .37313 .26236 .37202 Metetra
.653 .738 .912 r
.26236 .37202 .26349 .37313 .26916 .37114 .26802 .37018 Metetra
.923 .538 .241 r
.26802 .37018 .26916 .37114 .27485 .36914 .27235 .38542 Metetra
.323 .101 .414 r
.27235 .38542 .27485 .36914 .28054 .36713 .27942 .36601 Metetra
.664 .741 .907 r
.27942 .36601 .28054 .36713 .28625 .36512 .28513 .364 Metetra
.664 .741 .907 r
.28513 .364 .28625 .36512 .29197 .36311 .29085 .36198 Metetra
.664 .741 .907 r
.29085 .36198 .29197 .36311 .2977 .36109 .29658 .35996 Metetra
.664 .741 .907 r
.29658 .35996 .2977 .36109 .30345 .35906 .30233 .35793 Metetra
.664 .741 .907 r
.30233 .35793 .30345 .35906 .3092 .35704 .30809 .35591 Metetra
.664 .741 .907 r
.30809 .35591 .3092 .35704 .31497 .35501 .31386 .35387 Metetra
.664 .741 .907 r
.31386 .35387 .31497 .35501 .32075 .35297 .31965 .35183 Metetra
.664 .741 .907 r
.31965 .35183 .32075 .35297 .32655 .35093 .32544 .34979 Metetra
.664 .741 .907 r
.32544 .34979 .32655 .35093 .33236 .34888 .33125 .34774 Metetra
.664 .741 .907 r
.33125 .34774 .33236 .34888 .33818 .34683 .33708 .34569 Metetra
.664 .741 .907 r
.33708 .34569 .33818 .34683 .34401 .34478 .34291 .34363 Metetra
.664 .741 .907 r
.34291 .34363 .34401 .34478 .34986 .34272 .34876 .34157 Metetra
.664 .741 .907 r
.34876 .34157 .34986 .34272 .35572 .34066 .35462 .33951 Metetra
.664 .741 .907 r
.35462 .33951 .35572 .34066 .36159 .33859 .3605 .33744 Metetra
.664 .741 .907 r
.3605 .33744 .36159 .33859 .36747 .33652 .36638 .33536 Metetra
.664 .741 .907 r
.36638 .33536 .36747 .33652 .37337 .33444 .37228 .33328 Metetra
.664 .741 .907 r
.37228 .33328 .37337 .33444 .37928 .33236 .3782 .3312 Metetra
.664 .741 .907 r
.3782 .3312 .37928 .33236 .38521 .33028 .38412 .32911 Metetra
.664 .741 .907 r
.38412 .32911 .38521 .33028 .39114 .32818 .39006 .32702 Metetra
.664 .741 .907 r
.39006 .32702 .39114 .32818 .39709 .32609 .39602 .32492 Metetra
.664 .741 .907 r
.39602 .32492 .39709 .32609 .40306 .32399 .40198 .32282 Metetra
.664 .741 .907 r
.40198 .32282 .40306 .32399 .40903 .32188 .40796 .32071 Metetra
.961 .663 .419 r
.40796 .32071 .40903 .32188 .41335 .36752 .41101 .40194 Metetra
.733 .465 .523 r
.41101 .40194 .41335 .36752 .41338 .54873 .41391 .49737 Metetra
.781 .522 .545 r
.41391 .49737 .41338 .54873 .42704 .31554 .42598 .31436 Metetra
.664 .741 .907 r
.42598 .31436 .42704 .31554 .43307 .31342 .43201 .31223 Metetra
.664 .741 .907 r
.43201 .31223 .43307 .31342 .43912 .31129 .43806 .3101 Metetra
.664 .741 .907 r
.43806 .3101 .43912 .31129 .44517 .30916 .44412 .30797 Metetra
.664 .741 .907 r
.44412 .30797 .44517 .30916 .45124 .30702 .45019 .30583 Metetra
.664 .741 .907 r
.45019 .30583 .45124 .30702 .45733 .30488 .45628 .30368 Metetra
.664 .741 .907 r
.45628 .30368 .45733 .30488 .46343 .30273 .46238 .30153 Metetra
.664 .741 .907 r
.46238 .30153 .46343 .30273 .46954 .30058 .46849 .29938 Metetra
.664 .741 .907 r
.46849 .29938 .46954 .30058 .47566 .29842 .47462 .29722 Metetra
.664 .741 .907 r
.47462 .29722 .47566 .29842 .4818 .29626 .48076 .29505 Metetra
.664 .741 .907 r
.48076 .29505 .4818 .29626 .48796 .29409 .48692 .29288 Metetra
.664 .741 .907 r
.48692 .29288 .48796 .29409 .49412 .29192 .49309 .29071 Metetra
.664 .741 .907 r
.49309 .29071 .49412 .29192 .5003 .28975 .49927 .28853 Metetra
.664 .741 .907 r
.49927 .28853 .5003 .28975 .5065 .28756 .50547 .28635 Metetra
.664 .741 .907 r
.50547 .28635 .5065 .28756 .51271 .28538 .51168 .28416 Metetra
.664 .741 .907 r
.51168 .28416 .51271 .28538 .51893 .28319 .51791 .28196 Metetra
.664 .741 .907 r
.51791 .28196 .51893 .28319 .52517 .28099 .52415 .27976 Metetra
.664 .741 .907 r
.52415 .27976 .52517 .28099 .53142 .27879 .5304 .27756 Metetra
.664 .741 .907 r
.5304 .27756 .53142 .27879 .53769 .27658 .53667 .27535 Metetra
.664 .741 .907 r
.53667 .27535 .53769 .27658 .54396 .27437 .54295 .27314 Metetra
.664 .741 .907 r
.54295 .27314 .54396 .27437 .55026 .27216 .54925 .27092 Metetra
.664 .741 .907 r
.54925 .27092 .55026 .27216 .55657 .26993 .55556 .26869 Metetra
.664 .741 .907 r
.55556 .26869 .55657 .26993 .56289 .26771 .56189 .26646 Metetra
.664 .741 .907 r
.56189 .26646 .56289 .26771 .56923 .26548 .56823 .26423 Metetra
.664 .741 .907 r
.56823 .26423 .56923 .26548 .57558 .26324 .57458 .26199 Metetra
.664 .741 .907 r
.57458 .26199 .57558 .26324 .58195 .261 .58095 .25974 Metetra
.664 .741 .907 r
.58095 .25974 .58195 .261 .58833 .25875 .58733 .25749 Metetra
.664 .741 .907 r
.58733 .25749 .58833 .25875 .59472 .2565 .59373 .25524 Metetra
.664 .741 .907 r
.59373 .25524 .59472 .2565 .60113 .25424 .60015 .25298 Metetra
.664 .741 .907 r
.60015 .25298 .60113 .25424 .60756 .25198 .60657 .25071 Metetra
.664 .741 .907 r
.60657 .25071 .60756 .25198 .614 .24971 .61302 .24844 Metetra
.664 .741 .907 r
.61302 .24844 .614 .24971 .62045 .24744 .61948 .24617 Metetra
.664 .741 .907 r
.61948 .24617 .62045 .24744 .62692 .24516 .62595 .24389 Metetra
.664 .741 .907 r
.62595 .24389 .62692 .24516 .63341 .24288 .63244 .2416 Metetra
.664 .741 .907 r
.63244 .2416 .63341 .24288 .63991 .24059 .63894 .23931 Metetra
.664 .741 .907 r
.63894 .23931 .63991 .24059 .64642 .23829 .64546 .23701 Metetra
.664 .741 .907 r
.64546 .23701 .64642 .23829 .65295 .23599 .65199 .23471 Metetra
.664 .741 .907 r
.65199 .23471 .65295 .23599 .6595 .23369 .65854 .2324 Metetra
.664 .741 .907 r
.65854 .2324 .6595 .23369 .66606 .23138 .6651 .23009 Metetra
.664 .741 .907 r
.6651 .23009 .66606 .23138 .67264 .22906 .67168 .22777 Metetra
.664 .741 .907 r
.67168 .22777 .67264 .22906 .67923 .22674 .67828 .22545 Metetra
.664 .741 .907 r
.67828 .22545 .67923 .22674 .68583 .22442 .68489 .22312 Metetra
.664 .741 .907 r
.68489 .22312 .68583 .22442 .69246 .22208 .69151 .22078 Metetra
.664 .741 .907 r
.69151 .22078 .69246 .22208 .69909 .21975 .69815 .21844 Metetra
.664 .741 .907 r
.69815 .21844 .69909 .21975 .70575 .2174 .70481 .21609 Metetra
.664 .741 .907 r
.70481 .21609 .70575 .2174 .71242 .21506 .71148 .21374 Metetra
.664 .741 .907 r
.71148 .21374 .71242 .21506 .7191 .2127 .71817 .21139 Metetra
.235 .51 .908 r
.71817 .21139 .7191 .2127 .72649 .2207 .72519 .21379 Metetra
.645 .463 .623 r
.72519 .21379 .72649 .2207 .73252 .20798 .73159 .20666 Metetra
.664 .741 .907 r
.73159 .20666 .73252 .20798 .73925 .20561 .73833 .20428 Metetra
.664 .741 .907 r
.73833 .20428 .73925 .20561 .74821 .23346 .74508 .2019 Metetra
.545 .335 .545 r
.74508 .2019 .74821 .23346 .75276 .20085 .75185 .19952 Metetra
.664 .741 .907 r
.75185 .19952 .75276 .20085 .75954 .19846 .75863 .19713 Metetra
.664 .741 .907 r
.75863 .19713 .75954 .19846 .76634 .19607 .76543 .19473 Metetra
.664 .741 .907 r
.76543 .19473 .76634 .19607 .77315 .19367 .77224 .19233 Metetra
.664 .741 .907 r
.77224 .19233 .77315 .19367 .77998 .19127 .77907 .18992 Metetra
.664 .741 .907 r
.77907 .18992 .77998 .19127 .78682 .18886 .78592 .18751 Metetra
.664 .741 .907 r
.78592 .18751 .78682 .18886 .79368 .18644 .79279 .18509 Metetra
.664 .741 .907 r
.79279 .18509 .79368 .18644 .80056 .18402 .79967 .18267 Metetra
.664 .741 .907 r
.79967 .18267 .80056 .18402 .80745 .18159 .80656 .18024 Metetra
.664 .741 .907 r
.18856 .39654 .18972 .39762 .19524 .39568 .19408 .39459 Metetra
.664 .741 .907 r
.19408 .39459 .19524 .39568 .20076 .39373 .19961 .39264 Metetra
.664 .741 .907 r
.19961 .39264 .20076 .39373 .2063 .39178 .20515 .39068 Metetra
.664 .741 .907 r
.20515 .39068 .2063 .39178 .21186 .38982 .2107 .38873 Metetra
.664 .741 .907 r
.2107 .38873 .21186 .38982 .21742 .38786 .21627 .38676 Metetra
.664 .741 .907 r
.21627 .38676 .21742 .38786 .223 .38589 .22185 .3848 Metetra
.664 .741 .907 r
.22185 .3848 .223 .38589 .22858 .38392 .22744 .38282 Metetra
.664 .741 .907 r
.22744 .38282 .22858 .38392 .23418 .38195 .23304 .38085 Metetra
.664 .741 .907 r
.23304 .38085 .23418 .38195 .23979 .37997 .23865 .37887 Metetra
.664 .741 .907 r
.23865 .37887 .23979 .37997 .24542 .37799 .24428 .37688 Metetra
.664 .741 .907 r
.24428 .37688 .24542 .37799 .25105 .37601 .24992 .3749 Metetra
.664 .741 .907 r
.24992 .3749 .25105 .37601 .2567 .37401 .25557 .3729 Metetra
.664 .741 .907 r
.25557 .3729 .2567 .37401 .26236 .37202 .26123 .37091 Metetra
.934 .563 .265 r
.26123 .37091 .26236 .37202 .26802 .37018 .26535 .38808 Metetra
.324 .105 .418 r
.26535 .38808 .26802 .37018 .27235 .38542 .27259 .3669 Metetra
.552 .35 .561 r
.27259 .3669 .27235 .38542 .27942 .36601 .27829 .36489 Metetra
.664 .741 .907 r
.27829 .36489 .27942 .36601 .28513 .364 .284 .36287 Metetra
.664 .741 .907 r
.284 .36287 .28513 .364 .29085 .36198 .28973 .36085 Metetra
.664 .741 .907 r
.28973 .36085 .29085 .36198 .29658 .35996 .29546 .35883 Metetra
.664 .741 .907 r
.29546 .35883 .29658 .35996 .30233 .35793 .30121 .3568 Metetra
.664 .741 .907 r
.30121 .3568 .30233 .35793 .30809 .35591 .30697 .35477 Metetra
.664 .741 .907 r
.30697 .35477 .30809 .35591 .31386 .35387 .31275 .35273 Metetra
.664 .741 .907 r
.31275 .35273 .31386 .35387 .31965 .35183 .31854 .35069 Metetra
.664 .741 .907 r
.31854 .35069 .31965 .35183 .32544 .34979 .32434 .34865 Metetra
.664 .741 .907 r
.32434 .34865 .32544 .34979 .33125 .34774 .33015 .3466 Metetra
.664 .741 .907 r
.33015 .3466 .33125 .34774 .33708 .34569 .33597 .34454 Metetra
.664 .741 .907 r
.33597 .34454 .33708 .34569 .34291 .34363 .34181 .34248 Metetra
.664 .741 .907 r
.34181 .34248 .34291 .34363 .34876 .34157 .34766 .34042 Metetra
.664 .741 .907 r
.34766 .34042 .34876 .34157 .35462 .33951 .35353 .33835 Metetra
.664 .741 .907 r
.35353 .33835 .35462 .33951 .3605 .33744 .3594 .33628 Metetra
.664 .741 .907 r
.3594 .33628 .3605 .33744 .36638 .33536 .36529 .3342 Metetra
.664 .741 .907 r
.36529 .3342 .36638 .33536 .37228 .33328 .37119 .33212 Metetra
.664 .741 .907 r
.37119 .33212 .37228 .33328 .3782 .3312 .37711 .33003 Metetra
.664 .741 .907 r
.37711 .33003 .3782 .3312 .38412 .32911 .38304 .32794 Metetra
.664 .741 .907 r
.38304 .32794 .38412 .32911 .39006 .32702 .38898 .32585 Metetra
.664 .741 .907 r
.38898 .32585 .39006 .32702 .39602 .32492 .39494 .32375 Metetra
.664 .741 .907 r
.39494 .32375 .39602 .32492 .40198 .32282 .4009 .32164 Metetra
.664 .741 .907 r
.4009 .32164 .40198 .32282 .40796 .32071 .40689 .31953 Metetra
.664 .741 .907 r
.40689 .31953 .40796 .32071 .41101 .40194 .41288 .31742 Metetra
.362 .18 .494 r
.41288 .31742 .41101 .40194 .41391 .49737 .41562 .41204 Metetra
.653 .412 .542 r
.41562 .41204 .41391 .49737 .42598 .31436 .42491 .31317 Metetra
.664 .741 .907 r
.42491 .31317 .42598 .31436 .43201 .31223 .43095 .31105 Metetra
.664 .741 .907 r
.43095 .31105 .43201 .31223 .43806 .3101 .437 .30891 Metetra
.664 .741 .907 r
.437 .30891 .43806 .3101 .44412 .30797 .44306 .30677 Metetra
.664 .741 .907 r
.44306 .30677 .44412 .30797 .45019 .30583 .44913 .30463 Metetra
.664 .741 .907 r
.44913 .30463 .45019 .30583 .45628 .30368 .45522 .30248 Metetra
.664 .741 .907 r
.45522 .30248 .45628 .30368 .46238 .30153 .46133 .30033 Metetra
.664 .741 .907 r
.46133 .30033 .46238 .30153 .46849 .29938 .46744 .29817 Metetra
.664 .741 .907 r
.46744 .29817 .46849 .29938 .47462 .29722 .47357 .29601 Metetra
.664 .741 .907 r
.47357 .29601 .47462 .29722 .48076 .29505 .47972 .29384 Metetra
.664 .741 .907 r
.47972 .29384 .48076 .29505 .48692 .29288 .48588 .29167 Metetra
.664 .741 .907 r
.48588 .29167 .48692 .29288 .49309 .29071 .49205 .28949 Metetra
.664 .741 .907 r
.49205 .28949 .49309 .29071 .49927 .28853 .49824 .28731 Metetra
.664 .741 .907 r
.49824 .28731 .49927 .28853 .50547 .28635 .50444 .28513 Metetra
.664 .741 .907 r
.50444 .28513 .50547 .28635 .51168 .28416 .51065 .28293 Metetra
.664 .741 .907 r
.51065 .28293 .51168 .28416 .51791 .28196 .51688 .28074 Metetra
.664 .741 .907 r
.51688 .28074 .51791 .28196 .52415 .27976 .52312 .27853 Metetra
.664 .741 .907 r
.52312 .27853 .52415 .27976 .5304 .27756 .52938 .27633 Metetra
.664 .741 .907 r
.52938 .27633 .5304 .27756 .53667 .27535 .53565 .27412 Metetra
.664 .741 .907 r
.53565 .27412 .53667 .27535 .54295 .27314 .54194 .2719 Metetra
.664 .741 .907 r
.54194 .2719 .54295 .27314 .54925 .27092 .54824 .26968 Metetra
.664 .741 .907 r
.54824 .26968 .54925 .27092 .55556 .26869 .55455 .26745 Metetra
.664 .741 .907 r
.55455 .26745 .55556 .26869 .56189 .26646 .56088 .26522 Metetra
.664 .741 .907 r
.56088 .26522 .56189 .26646 .56823 .26423 .56722 .26298 Metetra
.664 .741 .907 r
.56722 .26298 .56823 .26423 .57458 .26199 .57358 .26074 Metetra
.664 .741 .907 r
.57358 .26074 .57458 .26199 .58095 .25974 .57995 .25849 Metetra
.664 .741 .907 r
.57995 .25849 .58095 .25974 .58733 .25749 .58634 .25624 Metetra
.664 .741 .907 r
.58634 .25624 .58733 .25749 .59373 .25524 .59274 .25398 Metetra
.664 .741 .907 r
.59274 .25398 .59373 .25524 .60015 .25298 .59916 .25172 Metetra
.664 .741 .907 r
.59916 .25172 .60015 .25298 .60657 .25071 .60559 .24945 Metetra
.664 .741 .907 r
.60559 .24945 .60657 .25071 .61302 .24844 .61204 .24717 Metetra
.664 .741 .907 r
.61204 .24717 .61302 .24844 .61948 .24617 .6185 .2449 Metetra
.664 .741 .907 r
.6185 .2449 .61948 .24617 .62595 .24389 .62497 .24261 Metetra
.664 .741 .907 r
.62497 .24261 .62595 .24389 .63244 .2416 .63146 .24032 Metetra
.664 .741 .907 r
.63146 .24032 .63244 .2416 .63894 .23931 .63797 .23803 Metetra
.664 .741 .907 r
.63797 .23803 .63894 .23931 .64546 .23701 .64449 .23573 Metetra
.664 .741 .907 r
.64449 .23573 .64546 .23701 .65199 .23471 .65103 .23342 Metetra
.664 .741 .907 r
.65103 .23342 .65199 .23471 .65854 .2324 .65758 .23111 Metetra
.664 .741 .907 r
.65758 .23111 .65854 .2324 .6651 .23009 .66415 .2288 Metetra
.664 .741 .907 r
.66415 .2288 .6651 .23009 .67168 .22777 .67073 .22647 Metetra
.664 .741 .907 r
.67073 .22647 .67168 .22777 .67828 .22545 .67733 .22415 Metetra
.664 .741 .907 r
.67733 .22415 .67828 .22545 .68489 .22312 .68394 .22181 Metetra
.664 .741 .907 r
.68394 .22181 .68489 .22312 .69151 .22078 .69057 .21948 Metetra
.664 .741 .907 r
.69057 .21948 .69151 .22078 .69815 .21844 .69721 .21713 Metetra
.664 .741 .907 r
.69721 .21713 .69815 .21844 .70481 .21609 .70387 .21478 Metetra
.664 .741 .907 r
.70387 .21478 .70481 .21609 .71148 .21374 .71055 .21243 Metetra
.664 .741 .907 r
.71055 .21243 .71148 .21374 .71817 .21139 .71724 .21007 Metetra
.664 .741 .907 r
.71724 .21007 .71817 .21139 .72519 .21379 .72394 .2077 Metetra
.587 .435 .642 r
.72394 .2077 .72519 .21379 .73159 .20666 .73067 .20533 Metetra
.664 .741 .907 r
.73067 .20533 .73159 .20666 .73833 .20428 .7374 .20296 Metetra
.664 .741 .907 r
.7374 .20296 .73833 .20428 .74508 .2019 .74416 .20057 Metetra
.664 .741 .907 r
.74416 .20057 .74508 .2019 .75185 .19952 .75093 .19819 Metetra
.664 .741 .907 r
.75093 .19819 .75185 .19952 .75863 .19713 .75772 .19579 Metetra
.664 .741 .907 r
.75772 .19579 .75863 .19713 .76543 .19473 .76452 .19339 Metetra
.664 .741 .907 r
.76452 .19339 .76543 .19473 .77224 .19233 .77134 .19099 Metetra
.664 .741 .907 r
.77134 .19099 .77224 .19233 .77907 .18992 .77817 .18858 Metetra
.664 .741 .907 r
.77817 .18858 .77907 .18992 .78592 .18751 .78502 .18616 Metetra
.664 .741 .907 r
.78502 .18616 .78592 .18751 .79279 .18509 .79189 .18374 Metetra
.664 .741 .907 r
.79189 .18374 .79279 .18509 .79967 .18267 .79878 .18131 Metetra
.664 .741 .907 r
.79878 .18131 .79967 .18267 .80656 .18024 .80568 .17888 Metetra
.664 .741 .907 r
.1874 .39545 .18856 .39654 .19408 .39459 .19292 .3935 Metetra
.664 .741 .907 r
.19292 .3935 .19408 .39459 .19961 .39264 .19845 .39155 Metetra
.664 .741 .907 r
.19845 .39155 .19961 .39264 .20515 .39068 .20399 .38959 Metetra
.664 .741 .907 r
.20399 .38959 .20515 .39068 .2107 .38873 .20955 .38763 Metetra
.664 .741 .907 r
.20955 .38763 .2107 .38873 .21627 .38676 .21512 .38567 Metetra
.664 .741 .907 r
.21512 .38567 .21627 .38676 .22185 .3848 .2207 .3837 Metetra
.664 .741 .907 r
.2207 .3837 .22185 .3848 .22744 .38282 .22629 .38172 Metetra
.664 .741 .907 r
.22629 .38172 .22744 .38282 .23304 .38085 .23189 .37974 Metetra
.664 .741 .907 r
.23189 .37974 .23304 .38085 .23865 .37887 .23751 .37776 Metetra
.664 .741 .907 r
.23751 .37776 .23865 .37887 .24428 .37688 .24314 .37578 Metetra
.664 .741 .907 r
.24314 .37578 .24428 .37688 .24992 .3749 .24878 .37378 Metetra
.664 .741 .907 r
.24878 .37378 .24992 .3749 .25557 .3729 .25443 .37179 Metetra
.664 .741 .907 r
.25443 .37179 .25557 .3729 .26123 .37091 .26009 .36979 Metetra
.925 .538 .221 r
.26009 .36979 .26123 .37091 .26535 .38808 .26439 .38482 Metetra
.834 .639 .639 r
.26439 .38482 .26535 .38808 .27259 .3669 .27146 .36578 Metetra
.664 .741 .907 r
.27146 .36578 .27259 .3669 .27829 .36489 .27716 .36376 Metetra
.664 .741 .907 r
.27716 .36376 .27829 .36489 .284 .36287 .28288 .36175 Metetra
.664 .741 .907 r
.28288 .36175 .284 .36287 .28973 .36085 .2886 .35973 Metetra
.664 .741 .907 r
.2886 .35973 .28973 .36085 .29546 .35883 .29434 .3577 Metetra
.664 .741 .907 r
.29434 .3577 .29546 .35883 .30121 .3568 .30009 .35567 Metetra
.664 .741 .907 r
.30009 .35567 .30121 .3568 .30697 .35477 .30586 .35364 Metetra
.664 .741 .907 r
.30586 .35364 .30697 .35477 .31275 .35273 .31163 .3516 Metetra
.664 .741 .907 r
.31163 .3516 .31275 .35273 .31854 .35069 .31742 .34955 Metetra
.664 .741 .907 r
.31742 .34955 .31854 .35069 .32434 .34865 .32323 .3475 Metetra
.664 .741 .907 r
.32323 .3475 .32434 .34865 .33015 .3466 .32904 .34545 Metetra
.664 .741 .907 r
.32904 .34545 .33015 .3466 .33597 .34454 .33487 .3434 Metetra
.664 .741 .907 r
.33487 .3434 .33597 .34454 .34181 .34248 .34071 .34133 Metetra
.664 .741 .907 r
.34071 .34133 .34181 .34248 .34766 .34042 .34656 .33927 Metetra
.664 .741 .907 r
.34656 .33927 .34766 .34042 .35353 .33835 .35243 .3372 Metetra
.664 .741 .907 r
.35243 .3372 .35353 .33835 .3594 .33628 .35831 .33512 Metetra
.664 .741 .907 r
.35831 .33512 .3594 .33628 .36529 .3342 .3642 .33304 Metetra
.664 .741 .907 r
.3642 .33304 .36529 .3342 .37119 .33212 .3701 .33096 Metetra
.664 .741 .907 r
.3701 .33096 .37119 .33212 .37711 .33003 .37602 .32887 Metetra
.664 .741 .907 r
.37602 .32887 .37711 .33003 .38304 .32794 .38195 .32677 Metetra
.664 .741 .907 r
.38195 .32677 .38304 .32794 .38898 .32585 .3879 .32468 Metetra
.664 .741 .907 r
.3879 .32468 .38898 .32585 .39494 .32375 .39386 .32257 Metetra
.664 .741 .907 r
.39386 .32257 .39494 .32375 .4009 .32164 .39983 .32047 Metetra
.664 .741 .907 r
.39983 .32047 .4009 .32164 .40689 .31953 .40581 .31835 Metetra
.664 .741 .907 r
.40581 .31835 .40689 .31953 .41288 .31742 .41181 .31624 Metetra
.664 .741 .907 r
.41181 .31624 .41288 .31742 .41562 .41204 .41782 .31411 Metetra
.537 .317 .528 r
.41782 .31411 .41562 .41204 .42491 .31317 .42384 .31199 Metetra
.664 .741 .907 r
.42384 .31199 .42491 .31317 .43095 .31105 .42988 .30986 Metetra
.664 .741 .907 r
.42988 .30986 .43095 .31105 .437 .30891 .43593 .30772 Metetra
.664 .741 .907 r
.43593 .30772 .437 .30891 .44306 .30677 .442 .30558 Metetra
.664 .741 .907 r
.442 .30558 .44306 .30677 .44913 .30463 .44808 .30343 Metetra
.664 .741 .907 r
.44808 .30343 .44913 .30463 .45522 .30248 .45417 .30128 Metetra
.664 .741 .907 r
.45417 .30128 .45522 .30248 .46133 .30033 .46027 .29913 Metetra
.664 .741 .907 r
.46027 .29913 .46133 .30033 .46744 .29817 .46639 .29697 Metetra
.664 .741 .907 r
.46639 .29697 .46744 .29817 .47357 .29601 .47253 .2948 Metetra
.664 .741 .907 r
.47253 .2948 .47357 .29601 .47972 .29384 .47867 .29263 Metetra
.664 .741 .907 r
.47867 .29263 .47972 .29384 .48588 .29167 .48484 .29046 Metetra
.664 .741 .907 r
.48484 .29046 .48588 .29167 .49205 .28949 .49101 .28828 Metetra
.664 .741 .907 r
.49101 .28828 .49205 .28949 .49824 .28731 .4972 .28609 Metetra
.664 .741 .907 r
.4972 .28609 .49824 .28731 .50444 .28513 .5034 .2839 Metetra
.664 .741 .907 r
.5034 .2839 .50444 .28513 .51065 .28293 .50962 .28171 Metetra
.664 .741 .907 r
.50962 .28171 .51065 .28293 .51688 .28074 .51585 .27951 Metetra
.844 .411 0 r
.51585 .27951 .51688 .28074 .52312 .27853 .52208 .29339 Metetra
.345 .125 .429 r
.52208 .29339 .52312 .27853 .52938 .27633 .52836 .27509 Metetra
.664 .741 .907 r
.52836 .27509 .52938 .27633 .53565 .27412 .53463 .27288 Metetra
.664 .741 .907 r
.53463 .27288 .53565 .27412 .54194 .2719 .54092 .27066 Metetra
.664 .741 .907 r
.54092 .27066 .54194 .2719 .54824 .26968 .54722 .26844 Metetra
.664 .741 .907 r
.54722 .26844 .54824 .26968 .55455 .26745 .55354 .26621 Metetra
.664 .741 .907 r
.55354 .26621 .55455 .26745 .56088 .26522 .55987 .26397 Metetra
.664 .741 .907 r
.55987 .26397 .56088 .26522 .56722 .26298 .56622 .26173 Metetra
.664 .741 .907 r
.56622 .26173 .56722 .26298 .57358 .26074 .57258 .25949 Metetra
.664 .741 .907 r
.57258 .25949 .57358 .26074 .57995 .25849 .57895 .25723 Metetra
.664 .741 .907 r
.57895 .25723 .57995 .25849 .58634 .25624 .58534 .25498 Metetra
.664 .741 .907 r
.58534 .25498 .58634 .25624 .59274 .25398 .59175 .25272 Metetra
.664 .741 .907 r
.59175 .25272 .59274 .25398 .59916 .25172 .59817 .25045 Metetra
.664 .741 .907 r
.59817 .25045 .59916 .25172 .60559 .24945 .6046 .24818 Metetra
.664 .741 .907 r
.6046 .24818 .60559 .24945 .61204 .24717 .61105 .2459 Metetra
.664 .741 .907 r
.61105 .2459 .61204 .24717 .6185 .2449 .61751 .24362 Metetra
.664 .741 .907 r
.61751 .24362 .6185 .2449 .62497 .24261 .62399 .24134 Metetra
.664 .741 .907 r
.62399 .24134 .62497 .24261 .63146 .24032 .63049 .23904 Metetra
.664 .741 .907 r
.63049 .23904 .63146 .24032 .63797 .23803 .637 .23675 Metetra
.664 .741 .907 r
.637 .23675 .63797 .23803 .64449 .23573 .64352 .23444 Metetra
.664 .741 .907 r
.64352 .23444 .64449 .23573 .65103 .23342 .65006 .23213 Metetra
.664 .741 .907 r
.65006 .23213 .65103 .23342 .65758 .23111 .65662 .22982 Metetra
.664 .741 .907 r
.65662 .22982 .65758 .23111 .66415 .2288 .66319 .2275 Metetra
.664 .741 .907 r
.66319 .2275 .66415 .2288 .67073 .22647 .66977 .22518 Metetra
.664 .741 .907 r
.66977 .22518 .67073 .22647 .67733 .22415 .67637 .22285 Metetra
.664 .741 .907 r
.67637 .22285 .67733 .22415 .68394 .22181 .68299 .22051 Metetra
.664 .741 .907 r
.68299 .22051 .68394 .22181 .69057 .21948 .68962 .21817 Metetra
.664 .741 .907 r
.68962 .21817 .69057 .21948 .69721 .21713 .69627 .21582 Metetra
.664 .741 .907 r
.69627 .21582 .69721 .21713 .70387 .21478 .70293 .21347 Metetra
.664 .741 .907 r
.70293 .21347 .70387 .21478 .71055 .21243 .70961 .21111 Metetra
.664 .741 .907 r
.70961 .21111 .71055 .21243 .71724 .21007 .7163 .20875 Metetra
.664 .741 .907 r
.7163 .20875 .71724 .21007 .72394 .2077 .72301 .20638 Metetra
.664 .741 .907 r
.72301 .20638 .72394 .2077 .73067 .20533 .72974 .20401 Metetra
.664 .741 .907 r
.72974 .20401 .73067 .20533 .7374 .20296 .73648 .20163 Metetra
.664 .741 .907 r
.73648 .20163 .7374 .20296 .74416 .20057 .74324 .19924 Metetra
.664 .741 .907 r
.74324 .19924 .74416 .20057 .75093 .19819 .75001 .19685 Metetra
.664 .741 .907 r
.75001 .19685 .75093 .19819 .75772 .19579 .7568 .19446 Metetra
.664 .741 .907 r
.7568 .19446 .75772 .19579 .76452 .19339 .76361 .19205 Metetra
.664 .741 .907 r
.76361 .19205 .76452 .19339 .77134 .19099 .77043 .18964 Metetra
.664 .741 .907 r
.77043 .18964 .77134 .19099 .77817 .18858 .77727 .18723 Metetra
.664 .741 .907 r
.77727 .18723 .77817 .18858 .78502 .18616 .78412 .18481 Metetra
.664 .741 .907 r
.78412 .18481 .78502 .18616 .79189 .18374 .791 .18239 Metetra
.664 .741 .907 r
.791 .18239 .79189 .18374 .79878 .18131 .79788 .17995 Metetra
.664 .741 .907 r
.79788 .17995 .79878 .18131 .80568 .17888 .80479 .17752 Metetra
.664 .741 .907 r
.18623 .39436 .1874 .39545 .19292 .3935 .19176 .39241 Metetra
.664 .741 .907 r
.19176 .39241 .19292 .3935 .19845 .39155 .19729 .39046 Metetra
.664 .741 .907 r
.19729 .39046 .19845 .39155 .20399 .38959 .20284 .3885 Metetra
.664 .741 .907 r
.20284 .3885 .20399 .38959 .20955 .38763 .2084 .38654 Metetra
.664 .741 .907 r
.2084 .38654 .20955 .38763 .21512 .38567 .21397 .38457 Metetra
.664 .741 .907 r
.21397 .38457 .21512 .38567 .2207 .3837 .21955 .3826 Metetra
.664 .741 .907 r
.21955 .3826 .2207 .3837 .22629 .38172 .22514 .38062 Metetra
.664 .741 .907 r
.22514 .38062 .22629 .38172 .23189 .37974 .23075 .37864 Metetra
.664 .741 .907 r
.23075 .37864 .23189 .37974 .23751 .37776 .23637 .37665 Metetra
.664 .741 .907 r
.23637 .37665 .23751 .37776 .24314 .37578 .242 .37467 Metetra
.664 .741 .907 r
.242 .37467 .24314 .37578 .24878 .37378 .24764 .37267 Metetra
.664 .741 .907 r
.24764 .37267 .24878 .37378 .25443 .37179 .25329 .37067 Metetra
.664 .741 .907 r
.25329 .37067 .25443 .37179 .26009 .36979 .25896 .36867 Metetra
.664 .741 .907 r
.25896 .36867 .26009 .36979 .26439 .38482 .26464 .36667 Metetra
.552 .35 .561 r
.26464 .36667 .26439 .38482 .27146 .36578 .27033 .36466 Metetra
.664 .741 .907 r
.27033 .36466 .27146 .36578 .27716 .36376 .27603 .36264 Metetra
.664 .741 .907 r
.27603 .36264 .27716 .36376 .28288 .36175 .28175 .36062 Metetra
.664 .741 .907 r
.28175 .36062 .28288 .36175 .2886 .35973 .28748 .3586 Metetra
.664 .741 .907 r
.28748 .3586 .2886 .35973 .29434 .3577 .29322 .35657 Metetra
.664 .741 .907 r
.29322 .35657 .29434 .3577 .30009 .35567 .29897 .35454 Metetra
.664 .741 .907 r
.29897 .35454 .30009 .35567 .30586 .35364 .30474 .3525 Metetra
.664 .741 .907 r
.30474 .3525 .30586 .35364 .31163 .3516 .31052 .35046 Metetra
.664 .741 .907 r
.31052 .35046 .31163 .3516 .31742 .34955 .31631 .34841 Metetra
.664 .741 .907 r
.31631 .34841 .31742 .34955 .32323 .3475 .32212 .34636 Metetra
.664 .741 .907 r
.32212 .34636 .32323 .3475 .32904 .34545 .32793 .34431 Metetra
.664 .741 .907 r
.32793 .34431 .32904 .34545 .33487 .3434 .33376 .34225 Metetra
.664 .741 .907 r
.33376 .34225 .33487 .3434 .34071 .34133 .3396 .34018 Metetra
.664 .741 .907 r
.3396 .34018 .34071 .34133 .34656 .33927 .34546 .33811 Metetra
.664 .741 .907 r
.34546 .33811 .34656 .33927 .35243 .3372 .35133 .33604 Metetra
.664 .741 .907 r
.35133 .33604 .35243 .3372 .35831 .33512 .35721 .33396 Metetra
.664 .741 .907 r
.35721 .33396 .35831 .33512 .3642 .33304 .3631 .33188 Metetra
.664 .741 .907 r
.3631 .33188 .3642 .33304 .3701 .33096 .36901 .32979 Metetra
.664 .741 .907 r
.36901 .32979 .3701 .33096 .37602 .32887 .37493 .3277 Metetra
.664 .741 .907 r
.37493 .3277 .37602 .32887 .38195 .32677 .38087 .3256 Metetra
.664 .741 .907 r
.38087 .3256 .38195 .32677 .3879 .32468 .38681 .3235 Metetra
.664 .741 .907 r
.38681 .3235 .3879 .32468 .39386 .32257 .39277 .3214 Metetra
.664 .741 .907 r
.39277 .3214 .39386 .32257 .39983 .32047 .39875 .31929 Metetra
.664 .741 .907 r
.39875 .31929 .39983 .32047 .40581 .31835 .40473 .31717 Metetra
.664 .741 .907 r
.40473 .31717 .40581 .31835 .41181 .31624 .41073 .31505 Metetra
.664 .741 .907 r
.41073 .31505 .41181 .31624 .41782 .31411 .41675 .31293 Metetra
.664 .741 .907 r
.41675 .31293 .41782 .31411 .42384 .31199 .42277 .3108 Metetra
.664 .741 .907 r
.42277 .3108 .42384 .31199 .42988 .30986 .42882 .30867 Metetra
.664 .741 .907 r
.42882 .30867 .42988 .30986 .43593 .30772 .43487 .30653 Metetra
.664 .741 .907 r
.43487 .30653 .43593 .30772 .442 .30558 .44094 .30438 Metetra
.664 .741 .907 r
.44094 .30438 .442 .30558 .44808 .30343 .44702 .30223 Metetra
.664 .741 .907 r
.44702 .30223 .44808 .30343 .45417 .30128 .45311 .30008 Metetra
.664 .741 .907 r
.45311 .30008 .45417 .30128 .46027 .29913 .45922 .29792 Metetra
.664 .741 .907 r
.45922 .29792 .46027 .29913 .46639 .29697 .46534 .29576 Metetra
.664 .741 .907 r
.46534 .29576 .46639 .29697 .47253 .2948 .47148 .29359 Metetra
.664 .741 .907 r
.47148 .29359 .47253 .2948 .47867 .29263 .47763 .29142 Metetra
.664 .741 .907 r
.47763 .29142 .47867 .29263 .48484 .29046 .48379 .28924 Metetra
.664 .741 .907 r
.48379 .28924 .48484 .29046 .49101 .28828 .48997 .28706 Metetra
.664 .741 .907 r
.48997 .28706 .49101 .28828 .4972 .28609 .49616 .28487 Metetra
.664 .741 .907 r
.49616 .28487 .4972 .28609 .5034 .2839 .50237 .28268 Metetra
.664 .741 .907 r
.50237 .28268 .5034 .2839 .50962 .28171 .50859 .28048 Metetra
.664 .741 .907 r
.50859 .28048 .50962 .28171 .51585 .27951 .51482 .27828 Metetra
.969 .67 .403 r
.51482 .27828 .51585 .27951 .52208 .29339 .52088 .43232 Metetra
.365 .174 .484 r
.52088 .43232 .52208 .29339 .52836 .27509 .52733 .27386 Metetra
.664 .741 .907 r
.52733 .27386 .52836 .27509 .53463 .27288 .53361 .27164 Metetra
.664 .741 .907 r
.53361 .27164 .53463 .27288 .54092 .27066 .5399 .26942 Metetra
.664 .741 .907 r
.5399 .26942 .54092 .27066 .54722 .26844 .54621 .26719 Metetra
.664 .741 .907 r
.54621 .26719 .54722 .26844 .55354 .26621 .55253 .26496 Metetra
.664 .741 .907 r
.55253 .26496 .55354 .26621 .55987 .26397 .55886 .26272 Metetra
.664 .741 .907 r
.55886 .26272 .55987 .26397 .56622 .26173 .56521 .26048 Metetra
.664 .741 .907 r
.56521 .26048 .56622 .26173 .57258 .25949 .57157 .25823 Metetra
.664 .741 .907 r
.57157 .25823 .57258 .25949 .57895 .25723 .57795 .25598 Metetra
.664 .741 .907 r
.57795 .25598 .57895 .25723 .58534 .25498 .58435 .25372 Metetra
.664 .741 .907 r
.58435 .25372 .58534 .25498 .59175 .25272 .59075 .25146 Metetra
.664 .741 .907 r
.59075 .25146 .59175 .25272 .59817 .25045 .59718 .24919 Metetra
.664 .741 .907 r
.59718 .24919 .59817 .25045 .6046 .24818 .60361 .24691 Metetra
.664 .741 .907 r
.60361 .24691 .6046 .24818 .61105 .2459 .61007 .24463 Metetra
.664 .741 .907 r
.61007 .24463 .61105 .2459 .61751 .24362 .61653 .24235 Metetra
.664 .741 .907 r
.61653 .24235 .61751 .24362 .62399 .24134 .62301 .24006 Metetra
.664 .741 .907 r
.62301 .24006 .62399 .24134 .63049 .23904 .62951 .23776 Metetra
.664 .741 .907 r
.62951 .23776 .63049 .23904 .637 .23675 .63602 .23546 Metetra
.664 .741 .907 r
.63602 .23546 .637 .23675 .64352 .23444 .64255 .23316 Metetra
.664 .741 .907 r
.64255 .23316 .64352 .23444 .65006 .23213 .64909 .23084 Metetra
.664 .741 .907 r
.64909 .23084 .65006 .23213 .65662 .22982 .65565 .22853 Metetra
.664 .741 .907 r
.65565 .22853 .65662 .22982 .66319 .2275 .66223 .22621 Metetra
.664 .741 .907 r
.66223 .22621 .66319 .2275 .66977 .22518 .66881 .22388 Metetra
.664 .741 .907 r
.66881 .22388 .66977 .22518 .67637 .22285 .67542 .22154 Metetra
.664 .741 .907 r
.67542 .22154 .67637 .22285 .68299 .22051 .68204 .21921 Metetra
.664 .741 .907 r
.68204 .21921 .68299 .22051 .68962 .21817 .68867 .21686 Metetra
.664 .741 .907 r
.68867 .21686 .68962 .21817 .69627 .21582 .69532 .21451 Metetra
.664 .741 .907 r
.69532 .21451 .69627 .21582 .70293 .21347 .70199 .21216 Metetra
.664 .741 .907 r
.70199 .21216 .70293 .21347 .70961 .21111 .70867 .2098 Metetra
.664 .741 .907 r
.70867 .2098 .70961 .21111 .7163 .20875 .71537 .20743 Metetra
.664 .741 .907 r
.71537 .20743 .7163 .20875 .72301 .20638 .72208 .20506 Metetra
.664 .741 .907 r
.72208 .20506 .72301 .20638 .72974 .20401 .72881 .20268 Metetra
.664 .741 .907 r
.72881 .20268 .72974 .20401 .73648 .20163 .73556 .2003 Metetra
.664 .741 .907 r
.73556 .2003 .73648 .20163 .74324 .19924 .74232 .19791 Metetra
.664 .741 .907 r
.74232 .19791 .74324 .19924 .75001 .19685 .74909 .19552 Metetra
.664 .741 .907 r
.74909 .19552 .75001 .19685 .7568 .19446 .75589 .19312 Metetra
.664 .741 .907 r
.75589 .19312 .7568 .19446 .76361 .19205 .7627 .19071 Metetra
.664 .741 .907 r
.7627 .19071 .76361 .19205 .77043 .18964 .76952 .1883 Metetra
.664 .741 .907 r
.76952 .1883 .77043 .18964 .77727 .18723 .77637 .18588 Metetra
.664 .741 .907 r
.77637 .18588 .77727 .18723 .78412 .18481 .78322 .18346 Metetra
.664 .741 .907 r
.78322 .18346 .78412 .18481 .791 .18239 .7901 .18103 Metetra
.664 .741 .907 r
.7901 .18103 .791 .18239 .79788 .17995 .79699 .1786 Metetra
.664 .741 .907 r
.79699 .1786 .79788 .17995 .80479 .17752 .8039 .17616 Metetra
.664 .741 .907 r
.18507 .39328 .18623 .39436 .19176 .39241 .19059 .39132 Metetra
.664 .741 .907 r
.19059 .39132 .19176 .39241 .19729 .39046 .19613 .38937 Metetra
.664 .741 .907 r
.19613 .38937 .19729 .39046 .20284 .3885 .20168 .3874 Metetra
.664 .741 .907 r
.20168 .3874 .20284 .3885 .2084 .38654 .20724 .38544 Metetra
.664 .741 .907 r
.20724 .38544 .2084 .38654 .21397 .38457 .21281 .38347 Metetra
.664 .741 .907 r
.21281 .38347 .21397 .38457 .21955 .3826 .2184 .38149 Metetra
.664 .741 .907 r
.2184 .38149 .21955 .3826 .22514 .38062 .22399 .37952 Metetra
.664 .741 .907 r
.22399 .37952 .22514 .38062 .23075 .37864 .2296 .37753 Metetra
.664 .741 .907 r
.2296 .37753 .23075 .37864 .23637 .37665 .23522 .37555 Metetra
.664 .741 .907 r
.23522 .37555 .23637 .37665 .242 .37467 .24085 .37355 Metetra
.664 .741 .907 r
.24085 .37355 .242 .37467 .24764 .37267 .2465 .37156 Metetra
.664 .741 .907 r
.2465 .37156 .24764 .37267 .25329 .37067 .25215 .36956 Metetra
.664 .741 .907 r
.25215 .36956 .25329 .37067 .25896 .36867 .25782 .36755 Metetra
.664 .741 .907 r
.25782 .36755 .25896 .36867 .26464 .36667 .2635 .36555 Metetra
.664 .741 .907 r
.2635 .36555 .26464 .36667 .27033 .36466 .2692 .36353 Metetra
.664 .741 .907 r
.2692 .36353 .27033 .36466 .27603 .36264 .2749 .36151 Metetra
.664 .741 .907 r
.2749 .36151 .27603 .36264 .28175 .36062 .28062 .35949 Metetra
.664 .741 .907 r
.28062 .35949 .28175 .36062 .28748 .3586 .28635 .35747 Metetra
.664 .741 .907 r
.28635 .35747 .28748 .3586 .29322 .35657 .2921 .35544 Metetra
.664 .741 .907 r
.2921 .35544 .29322 .35657 .29897 .35454 .29785 .3534 Metetra
.664 .741 .907 r
.29785 .3534 .29897 .35454 .30474 .3525 .30362 .35136 Metetra
.664 .741 .907 r
.30362 .35136 .30474 .3525 .31052 .35046 .3094 .34932 Metetra
.664 .741 .907 r
.3094 .34932 .31052 .35046 .31631 .34841 .3152 .34727 Metetra
.664 .741 .907 r
.3152 .34727 .31631 .34841 .32212 .34636 .321 .34521 Metetra
.664 .741 .907 r
.321 .34521 .32212 .34636 .32793 .34431 .32682 .34316 Metetra
.664 .741 .907 r
.32682 .34316 .32793 .34431 .33376 .34225 .33265 .3411 Metetra
.664 .741 .907 r
.33265 .3411 .33376 .34225 .3396 .34018 .3385 .33903 Metetra
.664 .741 .907 r
.3385 .33903 .3396 .34018 .34546 .33811 .34436 .33696 Metetra
.664 .741 .907 r
.34436 .33696 .34546 .33811 .35133 .33604 .35023 .33488 Metetra
.664 .741 .907 r
.35023 .33488 .35133 .33604 .35721 .33396 .35611 .3328 Metetra
.664 .741 .907 r
.35611 .3328 .35721 .33396 .3631 .33188 .36201 .33072 Metetra
.664 .741 .907 r
.36201 .33072 .3631 .33188 .36901 .32979 .36792 .32863 Metetra
.664 .741 .907 r
.36792 .32863 .36901 .32979 .37493 .3277 .37384 .32653 Metetra
.664 .741 .907 r
.37384 .32653 .37493 .3277 .38087 .3256 .37978 .32443 Metetra
.664 .741 .907 r
.37978 .32443 .38087 .3256 .38681 .3235 .38573 .32233 Metetra
.664 .741 .907 r
.38573 .32233 .38681 .3235 .39277 .3214 .39169 .32022 Metetra
.664 .741 .907 r
.39169 .32022 .39277 .3214 .39875 .31929 .39767 .31811 Metetra
.664 .741 .907 r
.39767 .31811 .39875 .31929 .40473 .31717 .40366 .31599 Metetra
.664 .741 .907 r
.40366 .31599 .40473 .31717 .41073 .31505 .40966 .31387 Metetra
.664 .741 .907 r
.40966 .31387 .41073 .31505 .41675 .31293 .41567 .31174 Metetra
.664 .741 .907 r
.41567 .31174 .41675 .31293 .42277 .3108 .4217 .30961 Metetra
.664 .741 .907 r
.4217 .30961 .42277 .3108 .42882 .30867 .42775 .30747 Metetra
.664 .741 .907 r
.42775 .30747 .42882 .30867 .43487 .30653 .4338 .30533 Metetra
.664 .741 .907 r
.4338 .30533 .43487 .30653 .44094 .30438 .43987 .30319 Metetra
.664 .741 .907 r
.43987 .30319 .44094 .30438 .44702 .30223 .44596 .30103 Metetra
.664 .741 .907 r
.44596 .30103 .44702 .30223 .45311 .30008 .45206 .29888 Metetra
.664 .741 .907 r
.45206 .29888 .45311 .30008 .45922 .29792 .45817 .29672 Metetra
.664 .741 .907 r
.45817 .29672 .45922 .29792 .46534 .29576 .46429 .29455 Metetra
.664 .741 .907 r
.46429 .29455 .46534 .29576 .47148 .29359 .47043 .29238 Metetra
.664 .741 .907 r
.47043 .29238 .47148 .29359 .47763 .29142 .47658 .29021 Metetra
.664 .741 .907 r
.47658 .29021 .47763 .29142 .48379 .28924 .48275 .28803 Metetra
.664 .741 .907 r
.48275 .28803 .48379 .28924 .48997 .28706 .48893 .28584 Metetra
.664 .741 .907 r
.48893 .28584 .48997 .28706 .49616 .28487 .49512 .28365 Metetra
.664 .741 .907 r
.49512 .28365 .49616 .28487 .50237 .28268 .50133 .28145 Metetra
.664 .741 .907 r
.50133 .28145 .50237 .28268 .50859 .28048 .50756 .27925 Metetra
.968 .662 .387 r
.50756 .27925 .50859 .28048 .51482 .27828 .51343 .37938 Metetra
.585 .345 .519 r
.51343 .37938 .51482 .27828 .52088 .43232 .5198 .4316 Metetra
.972 .703 .463 r
.5198 .4316 .52088 .43232 .52733 .27386 .52631 .27262 Metetra
.664 .741 .907 r
.52631 .27262 .52733 .27386 .53361 .27164 .53259 .2704 Metetra
.664 .741 .907 r
.53259 .2704 .53361 .27164 .5399 .26942 .53888 .26818 Metetra
.664 .741 .907 r
.53888 .26818 .5399 .26942 .54621 .26719 .54519 .26595 Metetra
.664 .741 .907 r
.54519 .26595 .54621 .26719 .55253 .26496 .55151 .26371 Metetra
.664 .741 .907 r
.55151 .26371 .55253 .26496 .55886 .26272 .55785 .26147 Metetra
.664 .741 .907 r
.55785 .26147 .55886 .26272 .56521 .26048 .5642 .25923 Metetra
.664 .741 .907 r
.5642 .25923 .56521 .26048 .57157 .25823 .57057 .25697 Metetra
.664 .741 .907 r
.57057 .25697 .57157 .25823 .57795 .25598 .57695 .25472 Metetra
.664 .741 .907 r
.57695 .25472 .57795 .25598 .58435 .25372 .58335 .25246 Metetra
.664 .741 .907 r
.58335 .25246 .58435 .25372 .59075 .25146 .58976 .25019 Metetra
.664 .741 .907 r
.58976 .25019 .59075 .25146 .59718 .24919 .59618 .24792 Metetra
.664 .741 .907 r
.59618 .24792 .59718 .24919 .60361 .24691 .60262 .24564 Metetra
.664 .741 .907 r
.60262 .24564 .60361 .24691 .61007 .24463 .60908 .24336 Metetra
.664 .741 .907 r
.60908 .24336 .61007 .24463 .61653 .24235 .61555 .24107 Metetra
.664 .741 .907 r
.61555 .24107 .61653 .24235 .62301 .24006 .62203 .23878 Metetra
.664 .741 .907 r
.62203 .23878 .62301 .24006 .62951 .23776 .62853 .23648 Metetra
.664 .741 .907 r
.62853 .23648 .62951 .23776 .63602 .23546 .63505 .23418 Metetra
.664 .741 .907 r
.63505 .23418 .63602 .23546 .64255 .23316 .64158 .23187 Metetra
.664 .741 .907 r
.64158 .23187 .64255 .23316 .64909 .23084 .64813 .22955 Metetra
.664 .741 .907 r
.64813 .22955 .64909 .23084 .65565 .22853 .65469 .22723 Metetra
.664 .741 .907 r
.65469 .22723 .65565 .22853 .66223 .22621 .66126 .22491 Metetra
.664 .741 .907 r
.66126 .22491 .66223 .22621 .66881 .22388 .66786 .22258 Metetra
.664 .741 .907 r
.66786 .22258 .66881 .22388 .67542 .22154 .67446 .22024 Metetra
.664 .741 .907 r
.67446 .22024 .67542 .22154 .68204 .21921 .68108 .2179 Metetra
.664 .741 .907 r
.68108 .2179 .68204 .21921 .68867 .21686 .68772 .21555 Metetra
.664 .741 .907 r
.68772 .21555 .68867 .21686 .69532 .21451 .69438 .2132 Metetra
.664 .741 .907 r
.69438 .2132 .69532 .21451 .70199 .21216 .70105 .21084 Metetra
.664 .741 .907 r
.70105 .21084 .70199 .21216 .70867 .2098 .70773 .20848 Metetra
.664 .741 .907 r
.70773 .20848 .70867 .2098 .71537 .20743 .71443 .20611 Metetra
.664 .741 .907 r
.71443 .20611 .71537 .20743 .72208 .20506 .72115 .20373 Metetra
.664 .741 .907 r
.72115 .20373 .72208 .20506 .72881 .20268 .72788 .20135 Metetra
.664 .741 .907 r
.72788 .20135 .72881 .20268 .73556 .2003 .73463 .19897 Metetra
.664 .741 .907 r
.73463 .19897 .73556 .2003 .74232 .19791 .7414 .19658 Metetra
.664 .741 .907 r
.7414 .19658 .74232 .19791 .74909 .19552 .74818 .19418 Metetra
.664 .741 .907 r
.74818 .19418 .74909 .19552 .75589 .19312 .75497 .19177 Metetra
.664 .741 .907 r
.75497 .19177 .75589 .19312 .7627 .19071 .76179 .18937 Metetra
.664 .741 .907 r
.76179 .18937 .7627 .19071 .76952 .1883 .76861 .18695 Metetra
.664 .741 .907 r
.76861 .18695 .76952 .1883 .77637 .18588 .77546 .18453 Metetra
.664 .741 .907 r
.77546 .18453 .77637 .18588 .78322 .18346 .78232 .1821 Metetra
.664 .741 .907 r
.78232 .1821 .78322 .18346 .7901 .18103 .7892 .17967 Metetra
.664 .741 .907 r
.7892 .17967 .7901 .18103 .79699 .1786 .79609 .17724 Metetra
.664 .741 .907 r
.79609 .17724 .79699 .1786 .8039 .17616 .80301 .17479 Metetra
.664 .741 .907 r
.1839 .39219 .18507 .39328 .19059 .39132 .18943 .39023 Metetra
.664 .741 .907 r
.18943 .39023 .19059 .39132 .19613 .38937 .19497 .38827 Metetra
.664 .741 .907 r
.19497 .38827 .19613 .38937 .20168 .3874 .20052 .38631 Metetra
.664 .741 .907 r
.20052 .38631 .20168 .3874 .20724 .38544 .20608 .38434 Metetra
.664 .741 .907 r
.20608 .38434 .20724 .38544 .21281 .38347 .21166 .38237 Metetra
.664 .741 .907 r
.21166 .38237 .21281 .38347 .2184 .38149 .21724 .38039 Metetra
.664 .741 .907 r
.21724 .38039 .2184 .38149 .22399 .37952 .22284 .37841 Metetra
.664 .741 .907 r
.22284 .37841 .22399 .37952 .2296 .37753 .22845 .37643 Metetra
.664 .741 .907 r
.22845 .37643 .2296 .37753 .23522 .37555 .23407 .37444 Metetra
.664 .741 .907 r
.23407 .37444 .23522 .37555 .24085 .37355 .23971 .37244 Metetra
.664 .741 .907 r
.23971 .37244 .24085 .37355 .2465 .37156 .24535 .37044 Metetra
.664 .741 .907 r
.24535 .37044 .2465 .37156 .25215 .36956 .25101 .36844 Metetra
.664 .741 .907 r
.25101 .36844 .25215 .36956 .25782 .36755 .25668 .36643 Metetra
.664 .741 .907 r
.25668 .36643 .25782 .36755 .2635 .36555 .26237 .36442 Metetra
.664 .741 .907 r
.26237 .36442 .2635 .36555 .2692 .36353 .26806 .36241 Metetra
.664 .741 .907 r
.26806 .36241 .2692 .36353 .2749 .36151 .27377 .36039 Metetra
.664 .741 .907 r
.27377 .36039 .2749 .36151 .28062 .35949 .27949 .35836 Metetra
.664 .741 .907 r
.27949 .35836 .28062 .35949 .28635 .35747 .28523 .35633 Metetra
.664 .741 .907 r
.28523 .35633 .28635 .35747 .2921 .35544 .29097 .3543 Metetra
.664 .741 .907 r
.29097 .3543 .2921 .35544 .29785 .3534 .29673 .35226 Metetra
.664 .741 .907 r
.29673 .35226 .29785 .3534 .30362 .35136 .3025 .35022 Metetra
.664 .741 .907 r
.3025 .35022 .30362 .35136 .3094 .34932 .30828 .34817 Metetra
.56 .061 0 r
.30828 .34817 .3094 .34932 .3152 .34727 .31356 .35399 Metetra
.254 0 .315 r
.31356 .35399 .3152 .34727 .321 .34521 .31989 .34407 Metetra
.664 .741 .907 r
.31989 .34407 .321 .34521 .32682 .34316 .32571 .34201 Metetra
.664 .741 .907 r
.32571 .34201 .32682 .34316 .33265 .3411 .33155 .33994 Metetra
.664 .741 .907 r
.33155 .33994 .33265 .3411 .3385 .33903 .33739 .33787 Metetra
.664 .741 .907 r
.33739 .33787 .3385 .33903 .34436 .33696 .34325 .3358 Metetra
.664 .741 .907 r
.34325 .3358 .34436 .33696 .35023 .33488 .34913 .33372 Metetra
.664 .741 .907 r
.34913 .33372 .35023 .33488 .35611 .3328 .35501 .33164 Metetra
.664 .741 .907 r
.35501 .33164 .35611 .3328 .36201 .33072 .36091 .32955 Metetra
.664 .741 .907 r
.36091 .32955 .36201 .33072 .36792 .32863 .36683 .32746 Metetra
.664 .741 .907 r
.36683 .32746 .36792 .32863 .37384 .32653 .37275 .32536 Metetra
.664 .741 .907 r
.37275 .32536 .37384 .32653 .37978 .32443 .37869 .32326 Metetra
.664 .741 .907 r
.37869 .32326 .37978 .32443 .38573 .32233 .38464 .32115 Metetra
.664 .741 .907 r
.38464 .32115 .38573 .32233 .39169 .32022 .39061 .31904 Metetra
.664 .741 .907 r
.39061 .31904 .39169 .32022 .39767 .31811 .39658 .31693 Metetra
.664 .741 .907 r
.39658 .31693 .39767 .31811 .40366 .31599 .40258 .31481 Metetra
.664 .741 .907 r
.40258 .31481 .40366 .31599 .40966 .31387 .40858 .31268 Metetra
.664 .741 .907 r
.40858 .31268 .40966 .31387 .41567 .31174 .4146 .31055 Metetra
.664 .741 .907 r
.4146 .31055 .41567 .31174 .4217 .30961 .42063 .30842 Metetra
.664 .741 .907 r
.42063 .30842 .4217 .30961 .42775 .30747 .42668 .30628 Metetra
.664 .741 .907 r
.42668 .30628 .42775 .30747 .4338 .30533 .43274 .30414 Metetra
.664 .741 .907 r
.43274 .30414 .4338 .30533 .43987 .30319 .43881 .30199 Metetra
.664 .741 .907 r
.43881 .30199 .43987 .30319 .44596 .30103 .4449 .29983 Metetra
.664 .741 .907 r
.4449 .29983 .44596 .30103 .45206 .29888 .451 .29767 Metetra
.664 .741 .907 r
.451 .29767 .45206 .29888 .45817 .29672 .45711 .29551 Metetra
.664 .741 .907 r
.45711 .29551 .45817 .29672 .46429 .29455 .46324 .29334 Metetra
.664 .741 .907 r
.46324 .29334 .46429 .29455 .47043 .29238 .46938 .29117 Metetra
.664 .741 .907 r
.46938 .29117 .47043 .29238 .47658 .29021 .47553 .28899 Metetra
.664 .741 .907 r
.47553 .28899 .47658 .29021 .48275 .28803 .4817 .28681 Metetra
.664 .741 .907 r
.4817 .28681 .48275 .28803 .48893 .28584 .48789 .28462 Metetra
.664 .741 .907 r
.48789 .28462 .48893 .28584 .49512 .28365 .49408 .28243 Metetra
.664 .741 .907 r
.49408 .28243 .49512 .28365 .50133 .28145 .5003 .28023 Metetra
.664 .741 .907 r
.5003 .28023 .50133 .28145 .50756 .27925 .50652 .27803 Metetra
.969 .675 .415 r
.50652 .27803 .50756 .27925 .51343 .37938 .51194 .48529 Metetra
.246 .082 .45 r
.51194 .48529 .51343 .37938 .5198 .4316 .51896 .30439 Metetra
.564 .336 .529 r
.51896 .30439 .5198 .4316 .52631 .27262 .52528 .27139 Metetra
.664 .741 .907 r
.52528 .27139 .52631 .27262 .53259 .2704 .53157 .26916 Metetra
.664 .741 .907 r
.53157 .26916 .53259 .2704 .53888 .26818 .53786 .26693 Metetra
.664 .741 .907 r
.53786 .26693 .53888 .26818 .54519 .26595 .54417 .2647 Metetra
.664 .741 .907 r
.54417 .2647 .54519 .26595 .55151 .26371 .5505 .26246 Metetra
.664 .741 .907 r
.5505 .26246 .55151 .26371 .55785 .26147 .55684 .26022 Metetra
.664 .741 .907 r
.55684 .26022 .55785 .26147 .5642 .25923 .56319 .25797 Metetra
.664 .741 .907 r
.56319 .25797 .5642 .25923 .57057 .25697 .56956 .25572 Metetra
.664 .741 .907 r
.56956 .25572 .57057 .25697 .57695 .25472 .57595 .25346 Metetra
.664 .741 .907 r
.57595 .25346 .57695 .25472 .58335 .25246 .58235 .25119 Metetra
.664 .741 .907 r
.58235 .25119 .58335 .25246 .58976 .25019 .58876 .24892 Metetra
.664 .741 .907 r
.58876 .24892 .58976 .25019 .59618 .24792 .59519 .24665 Metetra
.664 .741 .907 r
.59519 .24665 .59618 .24792 .60262 .24564 .60163 .24437 Metetra
.664 .741 .907 r
.60163 .24437 .60262 .24564 .60908 .24336 .60809 .24208 Metetra
.664 .741 .907 r
.60809 .24208 .60908 .24336 .61555 .24107 .61456 .23979 Metetra
.664 .741 .907 r
.61456 .23979 .61555 .24107 .62203 .23878 .62105 .2375 Metetra
.664 .741 .907 r
.62105 .2375 .62203 .23878 .62853 .23648 .62756 .2352 Metetra
.664 .741 .907 r
.62756 .2352 .62853 .23648 .63505 .23418 .63407 .23289 Metetra
.664 .741 .907 r
.63407 .23289 .63505 .23418 .64158 .23187 .64061 .23058 Metetra
.664 .741 .907 r
.64061 .23058 .64158 .23187 .64813 .22955 .64716 .22826 Metetra
.664 .741 .907 r
.64716 .22826 .64813 .22955 .65469 .22723 .65372 .22594 Metetra
.664 .741 .907 r
.65372 .22594 .65469 .22723 .66126 .22491 .6603 .22361 Metetra
.664 .741 .907 r
.6603 .22361 .66126 .22491 .66786 .22258 .6669 .22127 Metetra
.664 .741 .907 r
.6669 .22127 .66786 .22258 .67446 .22024 .67351 .21894 Metetra
.664 .741 .907 r
.67351 .21894 .67446 .22024 .68108 .2179 .68013 .21659 Metetra
.664 .741 .907 r
.68013 .21659 .68108 .2179 .68772 .21555 .68677 .21424 Metetra
.664 .741 .907 r
.68677 .21424 .68772 .21555 .69438 .2132 .69343 .21189 Metetra
.664 .741 .907 r
.69343 .21189 .69438 .2132 .70105 .21084 .7001 .20952 Metetra
.664 .741 .907 r
.7001 .20952 .70105 .21084 .70773 .20848 .70679 .20716 Metetra
.664 .741 .907 r
.70679 .20716 .70773 .20848 .71443 .20611 .7135 .20478 Metetra
.664 .741 .907 r
.7135 .20478 .71443 .20611 .72115 .20373 .72022 .20241 Metetra
.664 .741 .907 r
.72022 .20241 .72115 .20373 .72788 .20135 .72695 .20002 Metetra
.664 .741 .907 r
.72695 .20002 .72788 .20135 .73463 .19897 .7337 .19763 Metetra
.664 .741 .907 r
.7337 .19763 .73463 .19897 .7414 .19658 .74047 .19524 Metetra
.664 .741 .907 r
.74047 .19524 .7414 .19658 .74818 .19418 .74726 .19284 Metetra
.664 .741 .907 r
.74726 .19284 .74818 .19418 .75497 .19177 .75406 .19043 Metetra
.664 .741 .907 r
.75406 .19043 .75497 .19177 .76179 .18937 .76087 .18802 Metetra
.664 .741 .907 r
.76087 .18802 .76179 .18937 .76861 .18695 .7677 .1856 Metetra
.664 .741 .907 r
.7677 .1856 .76861 .18695 .77546 .18453 .77455 .18318 Metetra
.664 .741 .907 r
.77455 .18318 .77546 .18453 .78232 .1821 .78142 .18075 Metetra
.664 .741 .907 r
.78142 .18075 .78232 .1821 .7892 .17967 .7883 .17831 Metetra
.664 .741 .907 r
.7883 .17831 .7892 .17967 .79609 .17724 .7952 .17587 Metetra
.664 .741 .907 r
.7952 .17587 .79609 .17724 .80301 .17479 .80211 .17343 Metetra
.664 .741 .907 r
.18274 .3911 .1839 .39219 .18943 .39023 .18827 .38914 Metetra
.664 .741 .907 r
.18827 .38914 .18943 .39023 .19497 .38827 .19381 .38718 Metetra
.664 .741 .907 r
.19381 .38718 .19497 .38827 .20052 .38631 .19936 .38521 Metetra
.664 .741 .907 r
.19936 .38521 .20052 .38631 .20608 .38434 .20492 .38324 Metetra
.664 .741 .907 r
.20492 .38324 .20608 .38434 .21166 .38237 .2105 .38127 Metetra
.664 .741 .907 r
.2105 .38127 .21166 .38237 .21724 .38039 .21609 .37929 Metetra
.664 .741 .907 r
.21609 .37929 .21724 .38039 .22284 .37841 .22169 .3773 Metetra
.664 .741 .907 r
.22169 .3773 .22284 .37841 .22845 .37643 .2273 .37532 Metetra
.664 .741 .907 r
.2273 .37532 .22845 .37643 .23407 .37444 .23292 .37332 Metetra
.664 .741 .907 r
.23292 .37332 .23407 .37444 .23971 .37244 .23856 .37133 Metetra
.664 .741 .907 r
.23856 .37133 .23971 .37244 .24535 .37044 .24421 .36933 Metetra
.664 .741 .907 r
.24421 .36933 .24535 .37044 .25101 .36844 .24987 .36732 Metetra
.664 .741 .907 r
.24987 .36732 .25101 .36844 .25668 .36643 .25554 .36531 Metetra
.664 .741 .907 r
.25554 .36531 .25668 .36643 .26237 .36442 .26123 .3633 Metetra
.664 .741 .907 r
.26123 .3633 .26237 .36442 .26806 .36241 .26693 .36128 Metetra
.664 .741 .907 r
.26693 .36128 .26806 .36241 .27377 .36039 .27264 .35926 Metetra
.664 .741 .907 r
.27264 .35926 .27377 .36039 .27949 .35836 .27836 .35723 Metetra
.664 .741 .907 r
.27836 .35723 .27949 .35836 .28523 .35633 .2841 .3552 Metetra
.664 .741 .907 r
.2841 .3552 .28523 .35633 .29097 .3543 .28985 .35316 Metetra
.664 .741 .907 r
.28985 .35316 .29097 .3543 .29673 .35226 .29561 .35112 Metetra
.664 .741 .907 r
.29561 .35112 .29673 .35226 .3025 .35022 .30138 .34908 Metetra
0 .37 .831 r
.30138 .34908 .3025 .35022 .30828 .34817 .30682 .35199 Metetra
.153 0 .174 r
.30682 .35199 .30828 .34817 .31356 .35399 .31296 .34498 Metetra
.569 .391 .6 r
.31296 .34498 .31356 .35399 .31989 .34407 .31877 .34292 Metetra
.664 .741 .907 r
.31877 .34292 .31989 .34407 .32571 .34201 .3246 .34086 Metetra
.664 .741 .907 r
.3246 .34086 .32571 .34201 .33155 .33994 .33044 .33879 Metetra
.664 .741 .907 r
.33044 .33879 .33155 .33994 .33739 .33787 .33629 .33672 Metetra
.664 .741 .907 r
.33629 .33672 .33739 .33787 .34325 .3358 .34215 .33464 Metetra
.664 .741 .907 r
.34215 .33464 .34325 .3358 .34913 .33372 .34802 .33256 Metetra
.664 .741 .907 r
.34802 .33256 .34913 .33372 .35501 .33164 .35391 .33047 Metetra
.664 .741 .907 r
.35391 .33047 .35501 .33164 .36091 .32955 .35981 .32838 Metetra
.664 .741 .907 r
.35981 .32838 .36091 .32955 .36683 .32746 .36573 .32629 Metetra
.664 .741 .907 r
.36573 .32629 .36683 .32746 .37275 .32536 .37166 .32419 Metetra
.664 .741 .907 r
.37166 .32419 .37275 .32536 .37869 .32326 .3776 .32209 Metetra
.664 .741 .907 r
.3776 .32209 .37869 .32326 .38464 .32115 .38355 .31998 Metetra
.664 .741 .907 r
.38355 .31998 .38464 .32115 .39061 .31904 .38952 .31786 Metetra
.664 .741 .907 r
.38952 .31786 .39061 .31904 .39658 .31693 .3955 .31575 Metetra
.664 .741 .907 r
.3955 .31575 .39658 .31693 .40258 .31481 .4015 .31362 Metetra
.664 .741 .907 r
.4015 .31362 .40258 .31481 .40858 .31268 .4075 .3115 Metetra
.664 .741 .907 r
.4075 .3115 .40858 .31268 .4146 .31055 .41352 .30936 Metetra
.664 .741 .907 r
.41352 .30936 .4146 .31055 .42063 .30842 .41956 .30723 Metetra
.664 .741 .907 r
.41956 .30723 .42063 .30842 .42668 .30628 .42561 .30508 Metetra
.664 .741 .907 r
.42561 .30508 .42668 .30628 .43274 .30414 .43167 .30294 Metetra
.664 .741 .907 r
.43167 .30294 .43274 .30414 .43881 .30199 .43774 .30079 Metetra
.664 .741 .907 r
.43774 .30079 .43881 .30199 .4449 .29983 .44383 .29863 Metetra
.664 .741 .907 r
.44383 .29863 .4449 .29983 .451 .29767 .44994 .29647 Metetra
.664 .741 .907 r
.44994 .29647 .451 .29767 .45711 .29551 .45605 .2943 Metetra
.664 .741 .907 r
.45605 .2943 .45711 .29551 .46324 .29334 .46218 .29213 Metetra
.664 .741 .907 r
.46218 .29213 .46324 .29334 .46938 .29117 .46833 .28995 Metetra
.664 .741 .907 r
.46833 .28995 .46938 .29117 .47553 .28899 .47449 .28777 Metetra
.664 .741 .907 r
.47449 .28777 .47553 .28899 .4817 .28681 .48066 .28559 Metetra
.664 .741 .907 r
.48066 .28559 .4817 .28681 .48789 .28462 .48684 .2834 Metetra
.664 .741 .907 r
.48684 .2834 .48789 .28462 .49408 .28243 .49304 .2812 Metetra
.664 .741 .907 r
.49304 .2812 .49408 .28243 .5003 .28023 .49926 .279 Metetra
.664 .741 .907 r
.49926 .279 .5003 .28023 .50652 .27803 .50549 .27679 Metetra
.959 .624 .31 r
.50549 .27679 .50652 .27803 .51194 .48529 .51154 .31977 Metetra
.565 .337 .528 r
.51154 .31977 .51194 .48529 .51896 .30439 .51798 .27484 Metetra
.554 .341 .546 r
.51798 .27484 .51896 .30439 .52528 .27139 .52426 .27015 Metetra
.664 .741 .907 r
.52426 .27015 .52528 .27139 .53157 .26916 .53054 .26792 Metetra
.664 .741 .907 r
.53054 .26792 .53157 .26916 .53786 .26693 .53684 .26569 Metetra
.664 .741 .907 r
.53684 .26569 .53786 .26693 .54417 .2647 .54316 .26345 Metetra
.664 .741 .907 r
.54316 .26345 .54417 .2647 .5505 .26246 .54948 .26121 Metetra
.664 .741 .907 r
.54948 .26121 .5505 .26246 .55684 .26022 .55583 .25897 Metetra
.664 .741 .907 r
.55583 .25897 .55684 .26022 .56319 .25797 .56218 .25671 Metetra
.664 .741 .907 r
.56218 .25671 .56319 .25797 .56956 .25572 .56856 .25446 Metetra
.664 .741 .907 r
.56856 .25446 .56956 .25572 .57595 .25346 .57494 .2522 Metetra
.664 .741 .907 r
.57494 .2522 .57595 .25346 .58235 .25119 .58135 .24993 Metetra
.664 .741 .907 r
.58135 .24993 .58235 .25119 .58876 .24892 .58776 .24766 Metetra
.664 .741 .907 r
.58776 .24766 .58876 .24892 .59519 .24665 .59419 .24538 Metetra
.664 .741 .907 r
.59419 .24538 .59519 .24665 .60163 .24437 .60064 .24309 Metetra
.664 .741 .907 r
.60064 .24309 .60163 .24437 .60809 .24208 .6071 .24081 Metetra
.664 .741 .907 r
.6071 .24081 .60809 .24208 .61456 .23979 .61358 .23851 Metetra
.664 .741 .907 r
.61358 .23851 .61456 .23979 .62105 .2375 .62007 .23621 Metetra
.664 .741 .907 r
.62007 .23621 .62105 .2375 .62756 .2352 .62658 .23391 Metetra
.664 .741 .907 r
.62658 .23391 .62756 .2352 .63407 .23289 .6331 .2316 Metetra
.664 .741 .907 r
.6331 .2316 .63407 .23289 .64061 .23058 .63963 .22929 Metetra
.664 .741 .907 r
.63963 .22929 .64061 .23058 .64716 .22826 .64619 .22696 Metetra
.664 .741 .907 r
.64619 .22696 .64716 .22826 .65372 .22594 .65275 .22464 Metetra
.664 .741 .907 r
.65275 .22464 .65372 .22594 .6603 .22361 .65934 .22231 Metetra
.664 .741 .907 r
.65934 .22231 .6603 .22361 .6669 .22127 .66593 .21997 Metetra
.664 .741 .907 r
.66593 .21997 .6669 .22127 .67351 .21894 .67255 .21763 Metetra
.664 .741 .907 r
.67255 .21763 .67351 .21894 .68013 .21659 .67918 .21528 Metetra
.664 .741 .907 r
.67918 .21528 .68013 .21659 .68677 .21424 .68582 .21293 Metetra
.664 .741 .907 r
.68582 .21293 .68677 .21424 .69343 .21189 .69248 .21057 Metetra
.664 .741 .907 r
.69248 .21057 .69343 .21189 .7001 .20952 .69916 .2082 Metetra
.664 .741 .907 r
.69916 .2082 .7001 .20952 .70679 .20716 .70585 .20583 Metetra
.664 .741 .907 r
.70585 .20583 .70679 .20716 .7135 .20478 .71256 .20346 Metetra
.664 .741 .907 r
.71256 .20346 .7135 .20478 .72022 .20241 .71928 .20108 Metetra
.664 .741 .907 r
.71928 .20108 .72022 .20241 .72695 .20002 .72602 .19869 Metetra
.664 .741 .907 r
.72602 .19869 .72695 .20002 .7337 .19763 .73277 .1963 Metetra
.664 .741 .907 r
.73277 .1963 .7337 .19763 .74047 .19524 .73955 .1939 Metetra
.664 .741 .907 r
.73955 .1939 .74047 .19524 .74726 .19284 .74633 .1915 Metetra
.664 .741 .907 r
.74633 .1915 .74726 .19284 .75406 .19043 .75314 .18909 Metetra
.664 .741 .907 r
.75314 .18909 .75406 .19043 .76087 .18802 .75996 .18667 Metetra
.664 .741 .907 r
.75996 .18667 .76087 .18802 .7677 .1856 .76679 .18425 Metetra
.664 .741 .907 r
.76679 .18425 .7677 .1856 .77455 .18318 .77365 .18182 Metetra
.664 .741 .907 r
.77365 .18182 .77455 .18318 .78142 .18075 .78051 .17939 Metetra
.664 .741 .907 r
.78051 .17939 .78142 .18075 .7883 .17831 .7874 .17695 Metetra
.664 .741 .907 r
.7874 .17695 .7883 .17831 .7952 .17587 .7943 .17451 Metetra
.664 .741 .907 r
.7943 .17451 .7952 .17587 .80211 .17343 .80122 .17206 Metetra
.664 .741 .907 r
.18157 .39001 .18274 .3911 .18827 .38914 .1871 .38805 Metetra
.664 .741 .907 r
.1871 .38805 .18827 .38914 .19381 .38718 .19264 .38608 Metetra
.664 .741 .907 r
.19264 .38608 .19381 .38718 .19936 .38521 .1982 .38411 Metetra
.664 .741 .907 r
.1982 .38411 .19936 .38521 .20492 .38324 .20376 .38214 Metetra
.664 .741 .907 r
.20376 .38214 .20492 .38324 .2105 .38127 .20934 .38016 Metetra
.664 .741 .907 r
.20934 .38016 .2105 .38127 .21609 .37929 .21493 .37818 Metetra
.664 .741 .907 r
.21493 .37818 .21609 .37929 .22169 .3773 .22053 .3762 Metetra
.664 .741 .907 r
.22053 .3762 .22169 .3773 .2273 .37532 .22615 .37421 Metetra
.664 .741 .907 r
.22615 .37421 .2273 .37532 .23292 .37332 .23177 .37221 Metetra
.664 .741 .907 r
.23177 .37221 .23292 .37332 .23856 .37133 .23741 .37021 Metetra
.664 .741 .907 r
.23741 .37021 .23856 .37133 .24421 .36933 .24306 .36821 Metetra
.664 .741 .907 r
.24306 .36821 .24421 .36933 .24987 .36732 .24873 .3662 Metetra
.664 .741 .907 r
.24873 .3662 .24987 .36732 .25554 .36531 .2544 .36419 Metetra
.664 .741 .907 r
.2544 .36419 .25554 .36531 .26123 .3633 .26009 .36217 Metetra
.664 .741 .907 r
.26009 .36217 .26123 .3633 .26693 .36128 .26579 .36015 Metetra
.664 .741 .907 r
.26579 .36015 .26693 .36128 .27264 .35926 .2715 .35813 Metetra
.664 .741 .907 r
.2715 .35813 .27264 .35926 .27836 .35723 .27723 .3561 Metetra
.664 .741 .907 r
.27723 .3561 .27836 .35723 .2841 .3552 .28297 .35407 Metetra
.664 .741 .907 r
.28297 .35407 .2841 .3552 .28985 .35316 .28872 .35203 Metetra
.664 .741 .907 r
.28872 .35203 .28985 .35316 .29561 .35112 .29448 .34998 Metetra
.664 .741 .907 r
.29448 .34998 .29561 .35112 .30138 .34908 .30026 .34794 Metetra
.664 .741 .907 r
.30026 .34794 .30138 .34908 .30682 .35199 .30604 .34589 Metetra
.584 .428 .635 r
.30604 .34589 .30682 .35199 .31296 .34498 .31184 .34383 Metetra
.664 .741 .907 r
.31184 .34383 .31296 .34498 .31877 .34292 .31766 .34177 Metetra
.664 .741 .907 r
.31766 .34177 .31877 .34292 .3246 .34086 .32349 .3397 Metetra
.664 .741 .907 r
.32349 .3397 .3246 .34086 .33044 .33879 .32932 .33763 Metetra
.664 .741 .907 r
.32932 .33763 .33044 .33879 .33629 .33672 .33518 .33556 Metetra
.664 .741 .907 r
.33518 .33556 .33629 .33672 .34215 .33464 .34104 .33348 Metetra
.664 .741 .907 r
.34104 .33348 .34215 .33464 .34802 .33256 .34692 .3314 Metetra
.664 .741 .907 r
.34692 .3314 .34802 .33256 .35391 .33047 .35281 .32931 Metetra
.664 .741 .907 r
.35281 .32931 .35391 .33047 .35981 .32838 .35872 .32722 Metetra
.664 .741 .907 r
.35872 .32722 .35981 .32838 .36573 .32629 .36463 .32512 Metetra
.664 .741 .907 r
.36463 .32512 .36573 .32629 .37166 .32419 .37056 .32302 Metetra
.664 .741 .907 r
.37056 .32302 .37166 .32419 .3776 .32209 .37651 .32091 Metetra
.664 .741 .907 r
.37651 .32091 .3776 .32209 .38355 .31998 .38246 .3188 Metetra
.664 .741 .907 r
.38246 .3188 .38355 .31998 .38952 .31786 .38843 .31668 Metetra
.664 .741 .907 r
.38843 .31668 .38952 .31786 .3955 .31575 .39442 .31456 Metetra
.664 .741 .907 r
.39442 .31456 .3955 .31575 .4015 .31362 .40041 .31244 Metetra
.664 .741 .907 r
.40041 .31244 .4015 .31362 .4075 .3115 .40642 .31031 Metetra
.5 .677 .945 r
.40642 .31031 .4075 .3115 .41352 .30936 .41238 .31011 Metetra
.403 .809 .598 r
.41238 .31011 .41352 .30936 .41956 .30723 .41849 .30603 Metetra
.664 .741 .907 r
.41849 .30603 .41956 .30723 .42561 .30508 .42454 .30389 Metetra
.664 .741 .907 r
.42454 .30389 .42561 .30508 .43167 .30294 .4306 .30174 Metetra
.664 .741 .907 r
.4306 .30174 .43167 .30294 .43774 .30079 .43668 .29958 Metetra
.664 .741 .907 r
.43668 .29958 .43774 .30079 .44383 .29863 .44277 .29742 Metetra
.664 .741 .907 r
.44277 .29742 .44383 .29863 .44994 .29647 .44888 .29526 Metetra
.664 .741 .907 r
.44888 .29526 .44994 .29647 .45605 .2943 .45499 .29309 Metetra
.664 .741 .907 r
.45499 .29309 .45605 .2943 .46218 .29213 .46113 .29092 Metetra
.664 .741 .907 r
.46113 .29092 .46218 .29213 .46833 .28995 .46727 .28874 Metetra
.664 .741 .907 r
.46727 .28874 .46833 .28995 .47449 .28777 .47343 .28655 Metetra
.664 .741 .907 r
.47343 .28655 .47449 .28777 .48066 .28559 .47961 .28437 Metetra
.664 .741 .907 r
.47961 .28437 .48066 .28559 .48684 .2834 .4858 .28217 Metetra
.664 .741 .907 r
.4858 .28217 .48684 .2834 .49304 .2812 .492 .27997 Metetra
.664 .741 .907 r
.492 .27997 .49304 .2812 .49926 .279 .49822 .27777 Metetra
.664 .741 .907 r
.49822 .27777 .49926 .279 .50549 .27679 .50445 .27556 Metetra
.664 .741 .907 r
.50445 .27556 .50549 .27679 .51154 .31977 .51069 .27335 Metetra
.54 .324 .536 r
.51069 .27335 .51154 .31977 .51798 .27484 .51695 .27113 Metetra
.611 .502 .704 r
.51695 .27113 .51798 .27484 .52426 .27015 .52323 .26891 Metetra
.664 .741 .907 r
.52323 .26891 .52426 .27015 .53054 .26792 .52952 .26668 Metetra
.664 .741 .907 r
.52952 .26668 .53054 .26792 .53684 .26569 .53582 .26444 Metetra
.664 .741 .907 r
.53582 .26444 .53684 .26569 .54316 .26345 .54214 .2622 Metetra
.664 .741 .907 r
.54214 .2622 .54316 .26345 .54948 .26121 .54847 .25996 Metetra
.664 .741 .907 r
.54847 .25996 .54948 .26121 .55583 .25897 .55481 .25771 Metetra
.664 .741 .907 r
.55481 .25771 .55583 .25897 .56218 .25671 .56117 .25546 Metetra
.664 .741 .907 r
.56117 .25546 .56218 .25671 .56856 .25446 .56755 .2532 Metetra
.664 .741 .907 r
.56755 .2532 .56856 .25446 .57494 .2522 .57394 .25093 Metetra
.664 .741 .907 r
.57394 .25093 .57494 .2522 .58135 .24993 .58034 .24866 Metetra
.664 .741 .907 r
.58034 .24866 .58135 .24993 .58776 .24766 .58676 .24639 Metetra
.664 .741 .907 r
.58676 .24639 .58776 .24766 .59419 .24538 .5932 .24411 Metetra
.664 .741 .907 r
.5932 .24411 .59419 .24538 .60064 .24309 .59965 .24182 Metetra
.664 .741 .907 r
.59965 .24182 .60064 .24309 .6071 .24081 .60611 .23953 Metetra
.664 .741 .907 r
.60611 .23953 .6071 .24081 .61358 .23851 .61259 .23723 Metetra
.664 .741 .907 r
.61259 .23723 .61358 .23851 .62007 .23621 .61908 .23493 Metetra
.664 .741 .907 r
.61908 .23493 .62007 .23621 .62658 .23391 .62559 .23262 Metetra
.664 .741 .907 r
.62559 .23262 .62658 .23391 .6331 .2316 .63212 .23031 Metetra
.664 .741 .907 r
.63212 .23031 .6331 .2316 .63963 .22929 .63866 .22799 Metetra
.664 .741 .907 r
.63866 .22799 .63963 .22929 .64619 .22696 .64521 .22567 Metetra
.664 .741 .907 r
.64521 .22567 .64619 .22696 .65275 .22464 .65178 .22334 Metetra
.664 .741 .907 r
.65178 .22334 .65275 .22464 .65934 .22231 .65837 .221 Metetra
.664 .741 .907 r
.65837 .221 .65934 .22231 .66593 .21997 .66497 .21867 Metetra
.664 .741 .907 r
.66497 .21867 .66593 .21997 .67255 .21763 .67159 .21632 Metetra
.664 .741 .907 r
.67159 .21632 .67255 .21763 .67918 .21528 .67822 .21397 Metetra
.664 .741 .907 r
.67822 .21397 .67918 .21528 .68582 .21293 .68487 .21161 Metetra
.664 .741 .907 r
.68487 .21161 .68582 .21293 .69248 .21057 .69153 .20925 Metetra
.664 .741 .907 r
.69153 .20925 .69248 .21057 .69916 .2082 .69821 .20688 Metetra
.664 .741 .907 r
.69821 .20688 .69916 .2082 .70585 .20583 .70491 .20451 Metetra
.664 .741 .907 r
.70491 .20451 .70585 .20583 .71256 .20346 .71162 .20213 Metetra
.664 .741 .907 r
.71162 .20213 .71256 .20346 .71928 .20108 .71834 .19975 Metetra
.664 .741 .907 r
.71834 .19975 .71928 .20108 .72602 .19869 .72509 .19736 Metetra
.664 .741 .907 r
.72509 .19736 .72602 .19869 .73277 .1963 .73185 .19496 Metetra
.664 .741 .907 r
.73185 .19496 .73277 .1963 .73955 .1939 .73862 .19256 Metetra
.664 .741 .907 r
.73862 .19256 .73955 .1939 .74633 .1915 .74541 .19015 Metetra
.664 .741 .907 r
.74541 .19015 .74633 .1915 .75314 .18909 .75222 .18774 Metetra
.664 .741 .907 r
.75222 .18774 .75314 .18909 .75996 .18667 .75904 .18532 Metetra
.664 .741 .907 r
.75904 .18532 .75996 .18667 .76679 .18425 .76588 .1829 Metetra
.664 .741 .907 r
.76588 .1829 .76679 .18425 .77365 .18182 .77274 .18047 Metetra
.664 .741 .907 r
.77274 .18047 .77365 .18182 .78051 .17939 .77961 .17803 Metetra
.664 .741 .907 r
.77961 .17803 .78051 .17939 .7874 .17695 .7865 .17559 Metetra
.664 .741 .907 r
.7865 .17559 .7874 .17695 .7943 .17451 .7934 .17314 Metetra
.664 .741 .907 r
.7934 .17314 .7943 .17451 .80122 .17206 .80032 .17069 Metetra
.664 .741 .907 r
.1804 .38891 .18157 .39001 .1871 .38805 .18593 .38695 Metetra
.664 .741 .907 r
.18593 .38695 .1871 .38805 .19264 .38608 .19148 .38498 Metetra
.664 .741 .907 r
.19148 .38498 .19264 .38608 .1982 .38411 .19703 .38301 Metetra
.664 .741 .907 r
.19703 .38301 .1982 .38411 .20376 .38214 .2026 .38104 Metetra
.664 .741 .907 r
.2026 .38104 .20376 .38214 .20934 .38016 .20818 .37906 Metetra
.664 .741 .907 r
.20818 .37906 .20934 .38016 .21493 .37818 .21377 .37707 Metetra
.664 .741 .907 r
.21377 .37707 .21493 .37818 .22053 .3762 .21938 .37509 Metetra
.664 .741 .907 r
.21938 .37509 .22053 .3762 .22615 .37421 .22499 .37309 Metetra
.664 .741 .907 r
.22499 .37309 .22615 .37421 .23177 .37221 .23062 .3711 Metetra
.664 .741 .907 r
.23062 .3711 .23177 .37221 .23741 .37021 .23626 .3691 Metetra
.664 .741 .907 r
.23626 .3691 .23741 .37021 .24306 .36821 .24192 .36709 Metetra
.664 .741 .907 r
.24192 .36709 .24306 .36821 .24873 .3662 .24758 .36508 Metetra
.664 .741 .907 r
.24758 .36508 .24873 .3662 .2544 .36419 .25326 .36307 Metetra
.664 .741 .907 r
.25326 .36307 .2544 .36419 .26009 .36217 .25895 .36105 Metetra
.664 .741 .907 r
.25895 .36105 .26009 .36217 .26579 .36015 .26465 .35902 Metetra
.664 .741 .907 r
.26465 .35902 .26579 .36015 .2715 .35813 .27037 .357 Metetra
.664 .741 .907 r
.27037 .357 .2715 .35813 .27723 .3561 .2761 .35497 Metetra
.664 .741 .907 r
.2761 .35497 .27723 .3561 .28297 .35407 .28184 .35293 Metetra
.664 .741 .907 r
.28184 .35293 .28297 .35407 .28872 .35203 .28759 .35089 Metetra
.664 .741 .907 r
.28759 .35089 .28872 .35203 .29448 .34998 .29335 .34884 Metetra
.664 .741 .907 r
.29335 .34884 .29448 .34998 .30026 .34794 .29913 .34679 Metetra
.664 .741 .907 r
.29913 .34679 .30026 .34794 .30604 .34589 .30492 .34474 Metetra
.664 .741 .907 r
.30492 .34474 .30604 .34589 .31184 .34383 .31073 .34268 Metetra
.664 .741 .907 r
.31073 .34268 .31184 .34383 .31766 .34177 .31654 .34062 Metetra
.664 .741 .907 r
.31654 .34062 .31766 .34177 .32349 .3397 .32237 .33855 Metetra
.664 .741 .907 r
.32237 .33855 .32349 .3397 .32932 .33763 .32821 .33648 Metetra
.664 .741 .907 r
.32821 .33648 .32932 .33763 .33518 .33556 .33407 .3344 Metetra
.664 .741 .907 r
.33407 .3344 .33518 .33556 .34104 .33348 .33993 .33232 Metetra
.664 .741 .907 r
.33993 .33232 .34104 .33348 .34692 .3314 .34581 .33023 Metetra
.664 .741 .907 r
.34581 .33023 .34692 .3314 .35281 .32931 .35171 .32814 Metetra
.664 .741 .907 r
.35171 .32814 .35281 .32931 .35872 .32722 .35761 .32605 Metetra
.664 .741 .907 r
.35761 .32605 .35872 .32722 .36463 .32512 .36353 .32395 Metetra
.664 .741 .907 r
.36353 .32395 .36463 .32512 .37056 .32302 .36947 .32184 Metetra
.664 .741 .907 r
.36947 .32184 .37056 .32302 .37651 .32091 .37541 .31973 Metetra
.664 .741 .907 r
.37541 .31973 .37651 .32091 .38246 .3188 .38137 .31762 Metetra
.664 .741 .907 r
.38137 .31762 .38246 .3188 .38843 .31668 .38735 .3155 Metetra
.664 .741 .907 r
.38735 .3155 .38843 .31668 .39442 .31456 .39333 .31338 Metetra
.664 .741 .907 r
.39333 .31338 .39442 .31456 .40041 .31244 .39933 .31125 Metetra
.664 .741 .907 r
.39933 .31125 .40041 .31244 .40642 .31031 .40534 .30912 Metetra
.962 .675 .443 r
.40534 .30912 .40642 .31031 .41238 .31011 .40582 .45994 Metetra
.375 .178 .48 r
.40582 .45994 .41238 .31011 .41849 .30603 .41733 .30713 Metetra
.41733 .30713 .41849 .30603 .42454 .30389 .42346 .30269 Metetra
.664 .741 .907 r
.42346 .30269 .42454 .30389 .4306 .30174 .42953 .30054 Metetra
.664 .741 .907 r
.42953 .30054 .4306 .30174 .43668 .29958 .43561 .29838 Metetra
.664 .741 .907 r
.43561 .29838 .43668 .29958 .44277 .29742 .4417 .29622 Metetra
.664 .741 .907 r
.4417 .29622 .44277 .29742 .44888 .29526 .44781 .29405 Metetra
.664 .741 .907 r
.44781 .29405 .44888 .29526 .45499 .29309 .45393 .29188 Metetra
.664 .741 .907 r
.45393 .29188 .45499 .29309 .46113 .29092 .46007 .2897 Metetra
.664 .741 .907 r
.46007 .2897 .46113 .29092 .46727 .28874 .46622 .28752 Metetra
.664 .741 .907 r
.46622 .28752 .46727 .28874 .47343 .28655 .47238 .28533 Metetra
.664 .741 .907 r
.47238 .28533 .47343 .28655 .47961 .28437 .47856 .28314 Metetra
.664 .741 .907 r
.47856 .28314 .47961 .28437 .4858 .28217 .48475 .28095 Metetra
.664 .741 .907 r
.48475 .28095 .4858 .28217 .492 .27997 .49096 .27875 Metetra
.664 .741 .907 r
.49096 .27875 .492 .27997 .49822 .27777 .49718 .27654 Metetra
.664 .741 .907 r
.49718 .27654 .49822 .27777 .50445 .27556 .50341 .27433 Metetra
.664 .741 .907 r
.50341 .27433 .50445 .27556 .51069 .27335 .50966 .27211 Metetra
.664 .741 .907 r
.50966 .27211 .51069 .27335 .51695 .27113 .51592 .26989 Metetra
.664 .741 .907 r
.51592 .26989 .51695 .27113 .52323 .26891 .5222 .26766 Metetra
.664 .741 .907 r
.5222 .26766 .52323 .26891 .52952 .26668 .52849 .26543 Metetra
.664 .741 .907 r
.52849 .26543 .52952 .26668 .53582 .26444 .53479 .26319 Metetra
.664 .741 .907 r
.53479 .26319 .53582 .26444 .54214 .2622 .54111 .26095 Metetra
.664 .741 .907 r
.54111 .26095 .54214 .2622 .54847 .25996 .54745 .25871 Metetra
.664 .741 .907 r
.54745 .25871 .54847 .25996 .55481 .25771 .5538 .25645 Metetra
.664 .741 .907 r
.5538 .25645 .55481 .25771 .56117 .25546 .56016 .2542 Metetra
.664 .741 .907 r
.56016 .2542 .56117 .25546 .56755 .2532 .56654 .25193 Metetra
.664 .741 .907 r
.56654 .25193 .56755 .2532 .57394 .25093 .57293 .24967 Metetra
.664 .741 .907 r
.57293 .24967 .57394 .25093 .58034 .24866 .57934 .24739 Metetra
.664 .741 .907 r
.57934 .24739 .58034 .24866 .58676 .24639 .58576 .24511 Metetra
.664 .741 .907 r
.58576 .24511 .58676 .24639 .5932 .24411 .5922 .24283 Metetra
.664 .741 .907 r
.5922 .24283 .5932 .24411 .59965 .24182 .59865 .24054 Metetra
.664 .741 .907 r
.59865 .24054 .59965 .24182 .60611 .23953 .60512 .23825 Metetra
.664 .741 .907 r
.60512 .23825 .60611 .23953 .61259 .23723 .6116 .23595 Metetra
.664 .741 .907 r
.6116 .23595 .61259 .23723 .61908 .23493 .6181 .23364 Metetra
.664 .741 .907 r
.6181 .23364 .61908 .23493 .62559 .23262 .62461 .23133 Metetra
.664 .741 .907 r
.62461 .23133 .62559 .23262 .63212 .23031 .63114 .22902 Metetra
.664 .741 .907 r
.63114 .22902 .63212 .23031 .63866 .22799 .63768 .2267 Metetra
.664 .741 .907 r
.63768 .2267 .63866 .22799 .64521 .22567 .64424 .22437 Metetra
.664 .741 .907 r
.64424 .22437 .64521 .22567 .65178 .22334 .65081 .22204 Metetra
.664 .741 .907 r
.65081 .22204 .65178 .22334 .65837 .221 .6574 .2197 Metetra
.664 .741 .907 r
.6574 .2197 .65837 .221 .66497 .21867 .66401 .21736 Metetra
.664 .741 .907 r
.66401 .21736 .66497 .21867 .67159 .21632 .67063 .21501 Metetra
.664 .741 .907 r
.67063 .21501 .67159 .21632 .67822 .21397 .67726 .21266 Metetra
.664 .741 .907 r
.67726 .21266 .67822 .21397 .68487 .21161 .68391 .2103 Metetra
.664 .741 .907 r
.68391 .2103 .68487 .21161 .69153 .20925 .69058 .20793 Metetra
.664 .741 .907 r
.69058 .20793 .69153 .20925 .69821 .20688 .69726 .20556 Metetra
.664 .741 .907 r
.69726 .20556 .69821 .20688 .70491 .20451 .70396 .20318 Metetra
.664 .741 .907 r
.70396 .20318 .70491 .20451 .71162 .20213 .71068 .2008 Metetra
.664 .741 .907 r
.71068 .2008 .71162 .20213 .71834 .19975 .71741 .19842 Metetra
.664 .741 .907 r
.71741 .19842 .71834 .19975 .72509 .19736 .72415 .19602 Metetra
.664 .741 .907 r
.72415 .19602 .72509 .19736 .73185 .19496 .73091 .19362 Metetra
.907 .529 .092 r
.73091 .19362 .73185 .19496 .73862 .19256 .74019 .22657 Metetra
.387 .184 .478 r
.74019 .22657 .73862 .19256 .74541 .19015 .74449 .18881 Metetra
.664 .741 .907 r
.74449 .18881 .74541 .19015 .75222 .18774 .7513 .18639 Metetra
.664 .741 .907 r
.7513 .18639 .75222 .18774 .75904 .18532 .75812 .18397 Metetra
.664 .741 .907 r
.75812 .18397 .75904 .18532 .76588 .1829 .76497 .18154 Metetra
.664 .741 .907 r
.76497 .18154 .76588 .1829 .77274 .18047 .77183 .17911 Metetra
.664 .741 .907 r
.77183 .17911 .77274 .18047 .77961 .17803 .7787 .17667 Metetra
.664 .741 .907 r
.7787 .17667 .77961 .17803 .7865 .17559 .78559 .17423 Metetra
.664 .741 .907 r
.78559 .17423 .7865 .17559 .7934 .17314 .7925 .17178 Metetra
.664 .741 .907 r
.7925 .17178 .7934 .17314 .80032 .17069 .79943 .16932 Metetra
.664 .741 .907 r
.17923 .38782 .1804 .38891 .18593 .38695 .18476 .38585 Metetra
.664 .741 .907 r
.18476 .38585 .18593 .38695 .19148 .38498 .19031 .38389 Metetra
.664 .741 .907 r
.19031 .38389 .19148 .38498 .19703 .38301 .19587 .38191 Metetra
.664 .741 .907 r
.19587 .38191 .19703 .38301 .2026 .38104 .20144 .37993 Metetra
.664 .741 .907 r
.20144 .37993 .2026 .38104 .20818 .37906 .20702 .37795 Metetra
.664 .741 .907 r
.20702 .37795 .20818 .37906 .21377 .37707 .21261 .37597 Metetra
.664 .741 .907 r
.21261 .37597 .21377 .37707 .21938 .37509 .21822 .37398 Metetra
.664 .741 .907 r
.21822 .37398 .21938 .37509 .22499 .37309 .22384 .37198 Metetra
.664 .741 .907 r
.22384 .37198 .22499 .37309 .23062 .3711 .22947 .36998 Metetra
.664 .741 .907 r
.22947 .36998 .23062 .3711 .23626 .3691 .23511 .36798 Metetra
.664 .741 .907 r
.23511 .36798 .23626 .3691 .24192 .36709 .24077 .36597 Metetra
.664 .741 .907 r
.24077 .36597 .24192 .36709 .24758 .36508 .24644 .36396 Metetra
.664 .741 .907 r
.24644 .36396 .24758 .36508 .25326 .36307 .25212 .36194 Metetra
.664 .741 .907 r
.25212 .36194 .25326 .36307 .25895 .36105 .25781 .35992 Metetra
.664 .741 .907 r
.25781 .35992 .25895 .36105 .26465 .35902 .26351 .35789 Metetra
.664 .741 .907 r
.26351 .35789 .26465 .35902 .27037 .357 .26923 .35586 Metetra
.664 .741 .907 r
.26923 .35586 .27037 .357 .2761 .35497 .27496 .35383 Metetra
.664 .741 .907 r
.27496 .35383 .2761 .35497 .28184 .35293 .2807 .35179 Metetra
.664 .741 .907 r
.2807 .35179 .28184 .35293 .28759 .35089 .28646 .34975 Metetra
.664 .741 .907 r
.28646 .34975 .28759 .35089 .29335 .34884 .29223 .3477 Metetra
.664 .741 .907 r
.29223 .3477 .29335 .34884 .29913 .34679 .29801 .34565 Metetra
.664 .741 .907 r
.29801 .34565 .29913 .34679 .30492 .34474 .3038 .34359 Metetra
.664 .741 .907 r
.3038 .34359 .30492 .34474 .31073 .34268 .3096 .34153 Metetra
.664 .741 .907 r
.3096 .34153 .31073 .34268 .31654 .34062 .31542 .33947 Metetra
.664 .741 .907 r
.31542 .33947 .31654 .34062 .32237 .33855 .32125 .3374 Metetra
.664 .741 .907 r
.32125 .3374 .32237 .33855 .32821 .33648 .3271 .33532 Metetra
.664 .741 .907 r
.3271 .33532 .32821 .33648 .33407 .3344 .33295 .33324 Metetra
.664 .741 .907 r
.33295 .33324 .33407 .3344 .33993 .33232 .33882 .33116 Metetra
.664 .741 .907 r
.33882 .33116 .33993 .33232 .34581 .33023 .34471 .32907 Metetra
.664 .741 .907 r
.34471 .32907 .34581 .33023 .35171 .32814 .3506 .32697 Metetra
.664 .741 .907 r
.3506 .32697 .35171 .32814 .35761 .32605 .35651 .32488 Metetra
.664 .741 .907 r
.35651 .32488 .35761 .32605 .36353 .32395 .36243 .32277 Metetra
.664 .741 .907 r
.36243 .32277 .36353 .32395 .36947 .32184 .36837 .32067 Metetra
.664 .741 .907 r
.36837 .32067 .36947 .32184 .37541 .31973 .37432 .31856 Metetra
.664 .741 .907 r
.37432 .31856 .37541 .31973 .38137 .31762 .38028 .31644 Metetra
.664 .741 .907 r
.38028 .31644 .38137 .31762 .38735 .3155 .38626 .31432 Metetra
.664 .741 .907 r
.38626 .31432 .38735 .3155 .39333 .31338 .39224 .31219 Metetra
.664 .741 .907 r
.39224 .31219 .39333 .31338 .39933 .31125 .39825 .31006 Metetra
.956 .623 .337 r
.39825 .31006 .39933 .31125 .40534 .30912 .40283 .3451 Metetra
.808 .533 .522 r
.40283 .3451 .40534 .30912 .40582 .45994 .4018 .53753 Metetra
0 0 .273 r
.4018 .53753 .40582 .45994 .41733 .30713 .41633 .30364 Metetra
.614 .509 .712 r
.41633 .30364 .41733 .30713 .42346 .30269 .42239 .30149 Metetra
.664 .741 .907 r
.42239 .30149 .42346 .30269 .42953 .30054 .42846 .29933 Metetra
.664 .741 .907 r
.42846 .29933 .42953 .30054 .43561 .29838 .43454 .29717 Metetra
.664 .741 .907 r
.43454 .29717 .43561 .29838 .4417 .29622 .44064 .29501 Metetra
.664 .741 .907 r
.44064 .29501 .4417 .29622 .44781 .29405 .44675 .29284 Metetra
.664 .741 .907 r
.44675 .29284 .44781 .29405 .45393 .29188 .45287 .29067 Metetra
.664 .741 .907 r
.45287 .29067 .45393 .29188 .46007 .2897 .45901 .28849 Metetra
.664 .741 .907 r
.45901 .28849 .46007 .2897 .46622 .28752 .46516 .2863 Metetra
.664 .741 .907 r
.46516 .2863 .46622 .28752 .47238 .28533 .47133 .28411 Metetra
.664 .741 .907 r
.47133 .28411 .47238 .28533 .47856 .28314 .47751 .28192 Metetra
.664 .741 .907 r
.47751 .28192 .47856 .28314 .48475 .28095 .4837 .27972 Metetra
.664 .741 .907 r
.4837 .27972 .48475 .28095 .49096 .27875 .48991 .27752 Metetra
.664 .741 .907 r
.48991 .27752 .49096 .27875 .49718 .27654 .49613 .27531 Metetra
.664 .741 .907 r
.49613 .27531 .49718 .27654 .50341 .27433 .50237 .27309 Metetra
.664 .741 .907 r
.50237 .27309 .50341 .27433 .50966 .27211 .50862 .27087 Metetra
.664 .741 .907 r
.50862 .27087 .50966 .27211 .51592 .26989 .51489 .26865 Metetra
.664 .741 .907 r
.51489 .26865 .51592 .26989 .5222 .26766 .52117 .26642 Metetra
.664 .741 .907 r
.52117 .26642 .5222 .26766 .52849 .26543 .52746 .26418 Metetra
.664 .741 .907 r
.52746 .26418 .52849 .26543 .53479 .26319 .53377 .26195 Metetra
.664 .741 .907 r
.53377 .26195 .53479 .26319 .54111 .26095 .54009 .2597 Metetra
.664 .741 .907 r
.54009 .2597 .54111 .26095 .54745 .25871 .54643 .25745 Metetra
.664 .741 .907 r
.54643 .25745 .54745 .25871 .5538 .25645 .55278 .2552 Metetra
.664 .741 .907 r
.55278 .2552 .5538 .25645 .56016 .2542 .55915 .25294 Metetra
.664 .741 .907 r
.55915 .25294 .56016 .2542 .56654 .25193 .56553 .25067 Metetra
.664 .741 .907 r
.56553 .25067 .56654 .25193 .57293 .24967 .57192 .2484 Metetra
.664 .741 .907 r
.57192 .2484 .57293 .24967 .57934 .24739 .57833 .24612 Metetra
.664 .741 .907 r
.57833 .24612 .57934 .24739 .58576 .24511 .58476 .24384 Metetra
.664 .741 .907 r
.58476 .24384 .58576 .24511 .5922 .24283 .5912 .24155 Metetra
.664 .741 .907 r
.5912 .24155 .5922 .24283 .59865 .24054 .59766 .23926 Metetra
.664 .741 .907 r
.59766 .23926 .59865 .24054 .60512 .23825 .60413 .23697 Metetra
.664 .741 .907 r
.60413 .23697 .60512 .23825 .6116 .23595 .61061 .23466 Metetra
.664 .741 .907 r
.61061 .23466 .6116 .23595 .6181 .23364 .61711 .23236 Metetra
.664 .741 .907 r
.61711 .23236 .6181 .23364 .62461 .23133 .62363 .23004 Metetra
.664 .741 .907 r
.62363 .23004 .62461 .23133 .63114 .22902 .63016 .22772 Metetra
.664 .741 .907 r
.63016 .22772 .63114 .22902 .63768 .2267 .6367 .2254 Metetra
.664 .741 .907 r
.6367 .2254 .63768 .2267 .64424 .22437 .64327 .22307 Metetra
.664 .741 .907 r
.64327 .22307 .64424 .22437 .65081 .22204 .64984 .22073 Metetra
.664 .741 .907 r
.64984 .22073 .65081 .22204 .6574 .2197 .65644 .21839 Metetra
.664 .741 .907 r
.65644 .21839 .6574 .2197 .66401 .21736 .66304 .21605 Metetra
.664 .741 .907 r
.66304 .21605 .66401 .21736 .67063 .21501 .66967 .2137 Metetra
.664 .741 .907 r
.66967 .2137 .67063 .21501 .67726 .21266 .6763 .21134 Metetra
.664 .741 .907 r
.6763 .21134 .67726 .21266 .68391 .2103 .68296 .20898 Metetra
.664 .741 .907 r
.68296 .20898 .68391 .2103 .69058 .20793 .68963 .20661 Metetra
.664 .741 .907 r
.68963 .20661 .69058 .20793 .69726 .20556 .69631 .20424 Metetra
.664 .741 .907 r
.69631 .20424 .69726 .20556 .70396 .20318 .70302 .20186 Metetra
.664 .741 .907 r
.70302 .20186 .70396 .20318 .71068 .2008 .70973 .19947 Metetra
.664 .741 .907 r
.70973 .19947 .71068 .2008 .71741 .19842 .71647 .19708 Metetra
.664 .741 .907 r
.71647 .19708 .71741 .19842 .72415 .19602 .72322 .19468 Metetra
.664 .741 .907 r
.72322 .19468 .72415 .19602 .73091 .19362 .72998 .19228 Metetra
.869 .473 .006 r
.72998 .19228 .73091 .19362 .74019 .22657 .73869 .21728 Metetra
.777 .534 .569 r
.73869 .21728 .74019 .22657 .74449 .18881 .74356 .18746 Metetra
.664 .741 .907 r
.74356 .18746 .74449 .18881 .7513 .18639 .75037 .18504 Metetra
.664 .741 .907 r
.75037 .18504 .7513 .18639 .75812 .18397 .75721 .18262 Metetra
.664 .741 .907 r
.75721 .18262 .75812 .18397 .76497 .18154 .76405 .18019 Metetra
.664 .741 .907 r
.76405 .18019 .76497 .18154 .77183 .17911 .77091 .17775 Metetra
.664 .741 .907 r
.77091 .17775 .77183 .17911 .7787 .17667 .77779 .17531 Metetra
.664 .741 .907 r
.77779 .17531 .7787 .17667 .78559 .17423 .78469 .17286 Metetra
.664 .741 .907 r
.78469 .17286 .78559 .17423 .7925 .17178 .7916 .17041 Metetra
.664 .741 .907 r
.7916 .17041 .7925 .17178 .79943 .16932 .79853 .16795 Metetra
.664 .741 .907 r
.17805 .38672 .17923 .38782 .18476 .38585 .18359 .38476 Metetra
.664 .741 .907 r
.18359 .38476 .18476 .38585 .19031 .38389 .18914 .38279 Metetra
.664 .741 .907 r
.18914 .38279 .19031 .38389 .19587 .38191 .1947 .38081 Metetra
.664 .741 .907 r
.1947 .38081 .19587 .38191 .20144 .37993 .20027 .37883 Metetra
.664 .741 .907 r
.20027 .37883 .20144 .37993 .20702 .37795 .20586 .37684 Metetra
.664 .741 .907 r
.20586 .37684 .20702 .37795 .21261 .37597 .21145 .37486 Metetra
.664 .741 .907 r
.21145 .37486 .21261 .37597 .21822 .37398 .21706 .37286 Metetra
.664 .741 .907 r
.21706 .37286 .21822 .37398 .22384 .37198 .22268 .37087 Metetra
.664 .741 .907 r
.22268 .37087 .22384 .37198 .22947 .36998 .22832 .36886 Metetra
.664 .741 .907 r
.22832 .36886 .22947 .36998 .23511 .36798 .23396 .36686 Metetra
.664 .741 .907 r
.23396 .36686 .23511 .36798 .24077 .36597 .23962 .36485 Metetra
.664 .741 .907 r
.23962 .36485 .24077 .36597 .24644 .36396 .24529 .36283 Metetra
.664 .741 .907 r
.24529 .36283 .24644 .36396 .25212 .36194 .25097 .36081 Metetra
.361 .619 .95 r
.25097 .36081 .25212 .36194 .25781 .35992 .25643 .36159 Metetra
.816 .468 .397 r
.25643 .36159 .25781 .35992 .26351 .35789 .26079 .37593 Metetra
.321 .1 .415 r
.26079 .37593 .26351 .35789 .26923 .35586 .26809 .35473 Metetra
.664 .741 .907 r
.26809 .35473 .26923 .35586 .27496 .35383 .27382 .35269 Metetra
.664 .741 .907 r
.27382 .35269 .27496 .35383 .2807 .35179 .27957 .35065 Metetra
.664 .741 .907 r
.27957 .35065 .2807 .35179 .28646 .34975 .28533 .34861 Metetra
.664 .741 .907 r
.28533 .34861 .28646 .34975 .29223 .3477 .2911 .34656 Metetra
.664 .741 .907 r
.2911 .34656 .29223 .3477 .29801 .34565 .29688 .3445 Metetra
.664 .741 .907 r
.29688 .3445 .29801 .34565 .3038 .34359 .30267 .34244 Metetra
.664 .741 .907 r
.30267 .34244 .3038 .34359 .3096 .34153 .30848 .34038 Metetra
.664 .741 .907 r
.30848 .34038 .3096 .34153 .31542 .33947 .3143 .33831 Metetra
.664 .741 .907 r
.3143 .33831 .31542 .33947 .32125 .3374 .32014 .33624 Metetra
.664 .741 .907 r
.32014 .33624 .32125 .3374 .3271 .33532 .32598 .33416 Metetra
.664 .741 .907 r
.32598 .33416 .3271 .33532 .33295 .33324 .33184 .33208 Metetra
.664 .741 .907 r
.33184 .33208 .33295 .33324 .33882 .33116 .33771 .32999 Metetra
.664 .741 .907 r
.33771 .32999 .33882 .33116 .34471 .32907 .3436 .3279 Metetra
.664 .741 .907 r
.3436 .3279 .34471 .32907 .3506 .32697 .3495 .32581 Metetra
.664 .741 .907 r
.3495 .32581 .3506 .32697 .35651 .32488 .35541 .3237 Metetra
.664 .741 .907 r
.35541 .3237 .35651 .32488 .36243 .32277 .36133 .3216 Metetra
.664 .741 .907 r
.36133 .3216 .36243 .32277 .36837 .32067 .36727 .31949 Metetra
.664 .741 .907 r
.36727 .31949 .36837 .32067 .37432 .31856 .37322 .31738 Metetra
.664 .741 .907 r
.37322 .31738 .37432 .31856 .38028 .31644 .37919 .31526 Metetra
.664 .741 .907 r
.37919 .31526 .38028 .31644 .38626 .31432 .38516 .31313 Metetra
.664 .741 .907 r
.38516 .31313 .38626 .31432 .39224 .31219 .39116 .311 Metetra
.664 .741 .907 r
.39116 .311 .39224 .31219 .39825 .31006 .39716 .30887 Metetra
.961 .663 .421 r
.39716 .30887 .39825 .31006 .40283 .3451 .39985 .39222 Metetra
.698 .436 .524 r
.39985 .39222 .40283 .3451 .4018 .53753 .40238 .48916 Metetra
.791 .531 .543 r
.40238 .48916 .4018 .53753 .41633 .30364 .41525 .30244 Metetra
.664 .741 .907 r
.41525 .30244 .41633 .30364 .42239 .30149 .42131 .30029 Metetra
.664 .741 .907 r
.42131 .30029 .42239 .30149 .42846 .29933 .42738 .29813 Metetra
.664 .741 .907 r
.42738 .29813 .42846 .29933 .43454 .29717 .43347 .29597 Metetra
.664 .741 .907 r
.43347 .29597 .43454 .29717 .44064 .29501 .43957 .2938 Metetra
.664 .741 .907 r
.43957 .2938 .44064 .29501 .44675 .29284 .44568 .29163 Metetra
.664 .741 .907 r
.44568 .29163 .44675 .29284 .45287 .29067 .45181 .28945 Metetra
.664 .741 .907 r
.45181 .28945 .45287 .29067 .45901 .28849 .45795 .28727 Metetra
.664 .741 .907 r
.45795 .28727 .45901 .28849 .46516 .2863 .46411 .28508 Metetra
.664 .741 .907 r
.46411 .28508 .46516 .2863 .47133 .28411 .47027 .28289 Metetra
.664 .741 .907 r
.47027 .28289 .47133 .28411 .47751 .28192 .47646 .28069 Metetra
.664 .741 .907 r
.47646 .28069 .47751 .28192 .4837 .27972 .48265 .27849 Metetra
.664 .741 .907 r
.48265 .27849 .4837 .27972 .48991 .27752 .48887 .27628 Metetra
.664 .741 .907 r
.48887 .27628 .48991 .27752 .49613 .27531 .49509 .27407 Metetra
.664 .741 .907 r
.49509 .27407 .49613 .27531 .50237 .27309 .50133 .27186 Metetra
.664 .741 .907 r
.50133 .27186 .50237 .27309 .50862 .27087 .50758 .26963 Metetra
.664 .741 .907 r
.50758 .26963 .50862 .27087 .51489 .26865 .51385 .26741 Metetra
.664 .741 .907 r
.51385 .26741 .51489 .26865 .52117 .26642 .52013 .26517 Metetra
.664 .741 .907 r
.52013 .26517 .52117 .26642 .52746 .26418 .52643 .26294 Metetra
.664 .741 .907 r
.52643 .26294 .52746 .26418 .53377 .26195 .53274 .26069 Metetra
.664 .741 .907 r
.53274 .26069 .53377 .26195 .54009 .2597 .53907 .25845 Metetra
.664 .741 .907 r
.53907 .25845 .54009 .2597 .54643 .25745 .54541 .25619 Metetra
.664 .741 .907 r
.54541 .25619 .54643 .25745 .55278 .2552 .55176 .25394 Metetra
.664 .741 .907 r
.55176 .25394 .55278 .2552 .55915 .25294 .55813 .25167 Metetra
.664 .741 .907 r
.55813 .25167 .55915 .25294 .56553 .25067 .56452 .2494 Metetra
.664 .741 .907 r
.56452 .2494 .56553 .25067 .57192 .2484 .57091 .24713 Metetra
.664 .741 .907 r
.57091 .24713 .57192 .2484 .57833 .24612 .57733 .24485 Metetra
.664 .741 .907 r
.57733 .24485 .57833 .24612 .58476 .24384 .58376 .24257 Metetra
.664 .741 .907 r
.58376 .24257 .58476 .24384 .5912 .24155 .5902 .24028 Metetra
.664 .741 .907 r
.5902 .24028 .5912 .24155 .59766 .23926 .59666 .23798 Metetra
.664 .741 .907 r
.59666 .23798 .59766 .23926 .60413 .23697 .60313 .23568 Metetra
.664 .741 .907 r
.60313 .23568 .60413 .23697 .61061 .23466 .60962 .23338 Metetra
.664 .741 .907 r
.60962 .23338 .61061 .23466 .61711 .23236 .61612 .23107 Metetra
.664 .741 .907 r
.61612 .23107 .61711 .23236 .62363 .23004 .62264 .22875 Metetra
.664 .741 .907 r
.62264 .22875 .62363 .23004 .63016 .22772 .62918 .22643 Metetra
.664 .741 .907 r
.62918 .22643 .63016 .22772 .6367 .2254 .63573 .2241 Metetra
.664 .741 .907 r
.63573 .2241 .6367 .2254 .64327 .22307 .64229 .22177 Metetra
.664 .741 .907 r
.64229 .22177 .64327 .22307 .64984 .22073 .64887 .21943 Metetra
.664 .741 .907 r
.64887 .21943 .64984 .22073 .65644 .21839 .65547 .21709 Metetra
.664 .741 .907 r
.65547 .21709 .65644 .21839 .66304 .21605 .66208 .21474 Metetra
.664 .741 .907 r
.66208 .21474 .66304 .21605 .66967 .2137 .6687 .21238 Metetra
.664 .741 .907 r
.6687 .21238 .66967 .2137 .6763 .21134 .67534 .21002 Metetra
.664 .741 .907 r
.67534 .21002 .6763 .21134 .68296 .20898 .682 .20766 Metetra
.664 .741 .907 r
.682 .20766 .68296 .20898 .68963 .20661 .68868 .20529 Metetra
.664 .741 .907 r
.68868 .20529 .68963 .20661 .69631 .20424 .69536 .20291 Metetra
.664 .741 .907 r
.69536 .20291 .69631 .20424 .70302 .20186 .70207 .20053 Metetra
.664 .741 .907 r
.70207 .20053 .70302 .20186 .70973 .19947 .70879 .19814 Metetra
.664 .741 .907 r
.70879 .19814 .70973 .19947 .71647 .19708 .71553 .19575 Metetra
.664 .741 .907 r
.71553 .19575 .71647 .19708 .72322 .19468 .72228 .19335 Metetra
.664 .741 .907 r
.72228 .19335 .72322 .19468 .72998 .19228 .72905 .19094 Metetra
.664 .741 .907 r
.72905 .19094 .72998 .19228 .73869 .21728 .73583 .18853 Metetra
.544 .334 .546 r
.73583 .18853 .73869 .21728 .74356 .18746 .74263 .18611 Metetra
.664 .741 .907 r
.74263 .18611 .74356 .18746 .75037 .18504 .74945 .18369 Metetra
.664 .741 .907 r
.74945 .18369 .75037 .18504 .75721 .18262 .75629 .18126 Metetra
.664 .741 .907 r
.75629 .18126 .75721 .18262 .76405 .18019 .76314 .17883 Metetra
.664 .741 .907 r
.76314 .17883 .76405 .18019 .77091 .17775 .77 .17639 Metetra
.664 .741 .907 r
.77 .17639 .77091 .17775 .77779 .17531 .77688 .17394 Metetra
.664 .741 .907 r
.77688 .17394 .77779 .17531 .78469 .17286 .78378 .17149 Metetra
.664 .741 .907 r
.78378 .17149 .78469 .17286 .7916 .17041 .7907 .16903 Metetra
.664 .741 .907 r
.7907 .16903 .7916 .17041 .79853 .16795 .79763 .16657 Metetra
.664 .741 .907 r
.17688 .38563 .17805 .38672 .18359 .38476 .18242 .38366 Metetra
.664 .741 .907 r
.18242 .38366 .18359 .38476 .18914 .38279 .18797 .38168 Metetra
.664 .741 .907 r
.18797 .38168 .18914 .38279 .1947 .38081 .19353 .37971 Metetra
.664 .741 .907 r
.19353 .37971 .1947 .38081 .20027 .37883 .19911 .37772 Metetra
.664 .741 .907 r
.19911 .37772 .20027 .37883 .20586 .37684 .20469 .37574 Metetra
.664 .741 .907 r
.20469 .37574 .20586 .37684 .21145 .37486 .21029 .37375 Metetra
.664 .741 .907 r
.21029 .37375 .21145 .37486 .21706 .37286 .2159 .37175 Metetra
.664 .741 .907 r
.2159 .37175 .21706 .37286 .22268 .37087 .22153 .36975 Metetra
.664 .741 .907 r
.22153 .36975 .22268 .37087 .22832 .36886 .22716 .36775 Metetra
.664 .741 .907 r
.22716 .36775 .22832 .36886 .23396 .36686 .23281 .36574 Metetra
.664 .741 .907 r
.23281 .36574 .23396 .36686 .23962 .36485 .23847 .36373 Metetra
.664 .741 .907 r
.23847 .36373 .23962 .36485 .24529 .36283 .24414 .36171 Metetra
.664 .741 .907 r
.24414 .36171 .24529 .36283 .25097 .36081 .24982 .35969 Metetra
.946 .606 .345 r
.24982 .35969 .25097 .36081 .25643 .36159 .25334 .38345 Metetra
.306 .093 .417 r
.25334 .38345 .25643 .36159 .26079 .37593 .26117 .3564 Metetra
.554 .349 .557 r
.26117 .3564 .26079 .37593 .26809 .35473 .26695 .3536 Metetra
.664 .741 .907 r
.26695 .3536 .26809 .35473 .27382 .35269 .27269 .35156 Metetra
.664 .741 .907 r
.27269 .35156 .27382 .35269 .27957 .35065 .27843 .34951 Metetra
.664 .741 .907 r
.27843 .34951 .27957 .35065 .28533 .34861 .28419 .34746 Metetra
.664 .741 .907 r
.28419 .34746 .28533 .34861 .2911 .34656 .28996 .34541 Metetra
.664 .741 .907 r
.28996 .34541 .2911 .34656 .29688 .3445 .29575 .34335 Metetra
.664 .741 .907 r
.29575 .34335 .29688 .3445 .30267 .34244 .30155 .34129 Metetra
.664 .741 .907 r
.30155 .34129 .30267 .34244 .30848 .34038 .30736 .33923 Metetra
.664 .741 .907 r
.30736 .33923 .30848 .34038 .3143 .33831 .31318 .33716 Metetra
.664 .741 .907 r
.31318 .33716 .3143 .33831 .32014 .33624 .31902 .33508 Metetra
.664 .741 .907 r
.31902 .33508 .32014 .33624 .32598 .33416 .32487 .333 Metetra
.664 .741 .907 r
.32487 .333 .32598 .33416 .33184 .33208 .33073 .33092 Metetra
.664 .741 .907 r
.33073 .33092 .33184 .33208 .33771 .32999 .3366 .32883 Metetra
.664 .741 .907 r
.3366 .32883 .33771 .32999 .3436 .3279 .34249 .32673 Metetra
.664 .741 .907 r
.34249 .32673 .3436 .3279 .3495 .32581 .34839 .32463 Metetra
.664 .741 .907 r
.34839 .32463 .3495 .32581 .35541 .3237 .3543 .32253 Metetra
.664 .741 .907 r
.3543 .32253 .35541 .3237 .36133 .3216 .36023 .32042 Metetra
.664 .741 .907 r
.36023 .32042 .36133 .3216 .36727 .31949 .36617 .31831 Metetra
.664 .741 .907 r
.36617 .31831 .36727 .31949 .37322 .31738 .37212 .31619 Metetra
.664 .741 .907 r
.37212 .31619 .37322 .31738 .37919 .31526 .37809 .31407 Metetra
.664 .741 .907 r
.37809 .31407 .37919 .31526 .38516 .31313 .38407 .31195 Metetra
.664 .741 .907 r
.38407 .31195 .38516 .31313 .39116 .311 .39007 .30981 Metetra
.664 .741 .907 r
.39007 .30981 .39116 .311 .39716 .30887 .39607 .30768 Metetra
.697 .217 0 r
.39607 .30768 .39716 .30887 .39985 .39222 .40169 .31582 Metetra
.392 .202 .5 r
.40169 .31582 .39985 .39222 .40238 .48916 .40502 .38649 Metetra
.624 .386 .537 r
.40502 .38649 .40238 .48916 .41525 .30244 .41417 .30124 Metetra
.664 .741 .907 r
.41417 .30124 .41525 .30244 .42131 .30029 .42024 .29908 Metetra
.664 .741 .907 r
.42024 .29908 .42131 .30029 .42738 .29813 .42631 .29692 Metetra
.664 .741 .907 r
.42631 .29692 .42738 .29813 .43347 .29597 .4324 .29476 Metetra
.664 .741 .907 r
.4324 .29476 .43347 .29597 .43957 .2938 .4385 .29259 Metetra
.664 .741 .907 r
.4385 .29259 .43957 .2938 .44568 .29163 .44462 .29041 Metetra
.664 .741 .907 r
.44462 .29041 .44568 .29163 .45181 .28945 .45075 .28823 Metetra
.664 .741 .907 r
.45075 .28823 .45181 .28945 .45795 .28727 .45689 .28605 Metetra
.664 .741 .907 r
.45689 .28605 .45795 .28727 .46411 .28508 .46305 .28386 Metetra
.664 .741 .907 r
.46305 .28386 .46411 .28508 .47027 .28289 .46922 .28167 Metetra
.664 .741 .907 r
.46922 .28167 .47027 .28289 .47646 .28069 .4754 .27947 Metetra
.664 .741 .907 r
.4754 .27947 .47646 .28069 .48265 .27849 .4816 .27726 Metetra
.664 .741 .907 r
.4816 .27726 .48265 .27849 .48887 .27628 .48782 .27505 Metetra
.664 .741 .907 r
.48782 .27505 .48887 .27628 .49509 .27407 .49405 .27284 Metetra
.664 .741 .907 r
.49405 .27284 .49509 .27407 .50133 .27186 .50029 .27062 Metetra
.664 .741 .907 r
.50029 .27062 .50133 .27186 .50758 .26963 .50654 .26839 Metetra
.664 .741 .907 r
.50654 .26839 .50758 .26963 .51385 .26741 .51282 .26616 Metetra
.664 .741 .907 r
.51282 .26616 .51385 .26741 .52013 .26517 .5191 .26393 Metetra
.664 .741 .907 r
.5191 .26393 .52013 .26517 .52643 .26294 .5254 .26169 Metetra
.664 .741 .907 r
.5254 .26169 .52643 .26294 .53274 .26069 .53171 .25944 Metetra
.664 .741 .907 r
.53171 .25944 .53274 .26069 .53907 .25845 .53804 .25719 Metetra
.664 .741 .907 r
.53804 .25719 .53907 .25845 .54541 .25619 .54439 .25493 Metetra
.664 .741 .907 r
.54439 .25493 .54541 .25619 .55176 .25394 .55074 .25267 Metetra
.664 .741 .907 r
.55074 .25267 .55176 .25394 .55813 .25167 .55712 .25041 Metetra
.664 .741 .907 r
.55712 .25041 .55813 .25167 .56452 .2494 .5635 .24814 Metetra
.664 .741 .907 r
.5635 .24814 .56452 .2494 .57091 .24713 .5699 .24586 Metetra
.664 .741 .907 r
.5699 .24586 .57091 .24713 .57733 .24485 .57632 .24358 Metetra
.664 .741 .907 r
.57632 .24358 .57733 .24485 .58376 .24257 .58275 .24129 Metetra
.664 .741 .907 r
.58275 .24129 .58376 .24257 .5902 .24028 .5892 .239 Metetra
.664 .741 .907 r
.5892 .239 .5902 .24028 .59666 .23798 .59566 .2367 Metetra
.664 .741 .907 r
.59566 .2367 .59666 .23798 .60313 .23568 .60214 .2344 Metetra
.664 .741 .907 r
.60214 .2344 .60313 .23568 .60962 .23338 .60863 .23209 Metetra
.664 .741 .907 r
.60863 .23209 .60962 .23338 .61612 .23107 .61513 .22977 Metetra
.664 .741 .907 r
.61513 .22977 .61612 .23107 .62264 .22875 .62166 .22746 Metetra
.664 .741 .907 r
.62166 .22746 .62264 .22875 .62918 .22643 .62819 .22513 Metetra
.664 .741 .907 r
.62819 .22513 .62918 .22643 .63573 .2241 .63475 .2228 Metetra
.664 .741 .907 r
.63475 .2228 .63573 .2241 .64229 .22177 .64131 .22046 Metetra
.664 .741 .907 r
.64131 .22046 .64229 .22177 .64887 .21943 .6479 .21812 Metetra
.664 .741 .907 r
.6479 .21812 .64887 .21943 .65547 .21709 .65449 .21578 Metetra
.664 .741 .907 r
.65449 .21578 .65547 .21709 .66208 .21474 .66111 .21343 Metetra
.664 .741 .907 r
.66111 .21343 .66208 .21474 .6687 .21238 .66774 .21107 Metetra
.664 .741 .907 r
.66774 .21107 .6687 .21238 .67534 .21002 .67438 .2087 Metetra
.664 .741 .907 r
.67438 .2087 .67534 .21002 .682 .20766 .68104 .20634 Metetra
.664 .741 .907 r
.68104 .20634 .682 .20766 .68868 .20529 .68772 .20396 Metetra
.664 .741 .907 r
.68772 .20396 .68868 .20529 .69536 .20291 .69441 .20158 Metetra
.664 .741 .907 r
.69441 .20158 .69536 .20291 .70207 .20053 .70112 .1992 Metetra
.664 .741 .907 r
.70112 .1992 .70207 .20053 .70879 .19814 .70785 .1968 Metetra
.664 .741 .907 r
.70785 .1968 .70879 .19814 .71553 .19575 .71459 .19441 Metetra
.664 .741 .907 r
.71459 .19441 .71553 .19575 .72228 .19335 .72134 .19201 Metetra
.664 .741 .907 r
.72134 .19201 .72228 .19335 .72905 .19094 .72811 .1896 Metetra
.664 .741 .907 r
.72811 .1896 .72905 .19094 .73583 .18853 .7349 .18718 Metetra
.664 .741 .907 r
.7349 .18718 .73583 .18853 .74263 .18611 .74171 .18476 Metetra
.664 .741 .907 r
.74171 .18476 .74263 .18611 .74945 .18369 .74853 .18234 Metetra
.664 .741 .907 r
.74853 .18234 .74945 .18369 .75629 .18126 .75536 .17991 Metetra
.664 .741 .907 r
.75536 .17991 .75629 .18126 .76314 .17883 .76222 .17747 Metetra
.664 .741 .907 r
.76222 .17747 .76314 .17883 .77 .17639 .76909 .17503 Metetra
.664 .741 .907 r
.76909 .17503 .77 .17639 .77688 .17394 .77597 .17258 Metetra
.664 .741 .907 r
.77597 .17258 .77688 .17394 .78378 .17149 .78288 .17012 Metetra
.664 .741 .907 r
.78288 .17012 .78378 .17149 .7907 .16903 .7898 .16766 Metetra
.664 .741 .907 r
.7898 .16766 .7907 .16903 .79763 .16657 .79673 .16519 Metetra
.664 .741 .907 r
.1757 .38453 .17688 .38563 .18242 .38366 .18124 .38256 Metetra
.664 .741 .907 r
.18124 .38256 .18242 .38366 .18797 .38168 .1868 .38058 Metetra
.664 .741 .907 r
.1868 .38058 .18797 .38168 .19353 .37971 .19236 .3786 Metetra
.664 .741 .907 r
.19236 .3786 .19353 .37971 .19911 .37772 .19794 .37662 Metetra
.664 .741 .907 r
.19794 .37662 .19911 .37772 .20469 .37574 .20353 .37463 Metetra
.664 .741 .907 r
.20353 .37463 .20469 .37574 .21029 .37375 .20913 .37263 Metetra
.664 .741 .907 r
.20913 .37263 .21029 .37375 .2159 .37175 .21474 .37063 Metetra
.664 .741 .907 r
.21474 .37063 .2159 .37175 .22153 .36975 .22037 .36863 Metetra
.664 .741 .907 r
.22037 .36863 .22153 .36975 .22716 .36775 .226 .36663 Metetra
.664 .741 .907 r
.226 .36663 .22716 .36775 .23281 .36574 .23165 .36462 Metetra
.664 .741 .907 r
.23165 .36462 .23281 .36574 .23847 .36373 .23732 .3626 Metetra
.664 .741 .907 r
.23732 .3626 .23847 .36373 .24414 .36171 .24299 .36058 Metetra
.664 .741 .907 r
.24299 .36058 .24414 .36171 .24982 .35969 .24868 .35856 Metetra
.499 .683 .949 r
.24868 .35856 .24982 .35969 .25334 .38345 .25422 .35834 Metetra
.554 .344 .549 r
.25422 .35834 .25334 .38345 .26117 .3564 .26009 .3545 Metetra
.647 .625 .814 r
.26009 .3545 .26117 .3564 .26695 .3536 .26581 .35246 Metetra
.664 .741 .907 r
.26581 .35246 .26695 .3536 .27269 .35156 .27155 .35042 Metetra
.664 .741 .907 r
.27155 .35042 .27269 .35156 .27843 .34951 .2773 .34837 Metetra
.664 .741 .907 r
.2773 .34837 .27843 .34951 .28419 .34746 .28306 .34632 Metetra
.664 .741 .907 r
.28306 .34632 .28419 .34746 .28996 .34541 .28883 .34426 Metetra
.664 .741 .907 r
.28883 .34426 .28996 .34541 .29575 .34335 .29462 .34221 Metetra
.664 .741 .907 r
.29462 .34221 .29575 .34335 .30155 .34129 .30042 .34014 Metetra
.664 .741 .907 r
.30042 .34014 .30155 .34129 .30736 .33923 .30623 .33807 Metetra
.664 .741 .907 r
.30623 .33807 .30736 .33923 .31318 .33716 .31206 .336 Metetra
.664 .741 .907 r
.31206 .336 .31318 .33716 .31902 .33508 .3179 .33392 Metetra
.664 .741 .907 r
.3179 .33392 .31902 .33508 .32487 .333 .32375 .33184 Metetra
.664 .741 .907 r
.32375 .33184 .32487 .333 .33073 .33092 .32961 .32975 Metetra
.664 .741 .907 r
.32961 .32975 .33073 .33092 .3366 .32883 .33549 .32766 Metetra
.664 .741 .907 r
.33549 .32766 .3366 .32883 .34249 .32673 .34138 .32556 Metetra
.957 .654 .417 r
.34138 .32556 .34249 .32673 .34839 .32463 .34393 .3829 Metetra
.359 .156 .463 r
.34393 .3829 .34839 .32463 .3543 .32253 .3532 .32136 Metetra
.664 .741 .907 r
.3532 .32136 .3543 .32253 .36023 .32042 .35913 .31925 Metetra
.664 .741 .907 r
.35913 .31925 .36023 .32042 .36617 .31831 .36507 .31713 Metetra
.664 .741 .907 r
.36507 .31713 .36617 .31831 .37212 .31619 .37103 .31501 Metetra
.664 .741 .907 r
.37103 .31501 .37212 .31619 .37809 .31407 .377 .31289 Metetra
.664 .741 .907 r
.377 .31289 .37809 .31407 .38407 .31195 .38298 .31076 Metetra
.664 .741 .907 r
.38298 .31076 .38407 .31195 .39007 .30981 .38897 .30862 Metetra
.664 .741 .907 r
.38897 .30862 .39007 .30981 .39607 .30768 .39498 .30648 Metetra
.664 .741 .907 r
.39498 .30648 .39607 .30768 .40169 .31582 .40101 .30434 Metetra
.561 .373 .584 r
.40101 .30434 .40169 .31582 .40502 .38649 .40704 .30219 Metetra
.535 .315 .527 r
.40704 .30219 .40502 .38649 .41417 .30124 .41309 .30004 Metetra
.664 .741 .907 r
.41309 .30004 .41417 .30124 .42024 .29908 .41916 .29788 Metetra
.664 .741 .907 r
.41916 .29788 .42024 .29908 .42631 .29692 .42523 .29572 Metetra
.664 .741 .907 r
.42523 .29572 .42631 .29692 .4324 .29476 .43132 .29355 Metetra
.664 .741 .907 r
.43132 .29355 .4324 .29476 .4385 .29259 .43743 .29138 Metetra
.664 .741 .907 r
.43743 .29138 .4385 .29259 .44462 .29041 .44355 .2892 Metetra
.664 .741 .907 r
.44355 .2892 .44462 .29041 .45075 .28823 .44968 .28702 Metetra
.664 .741 .907 r
.44968 .28702 .45075 .28823 .45689 .28605 .45583 .28483 Metetra
.664 .741 .907 r
.45583 .28483 .45689 .28605 .46305 .28386 .46199 .28264 Metetra
.664 .741 .907 r
.46199 .28264 .46305 .28386 .46922 .28167 .46816 .28044 Metetra
.664 .741 .907 r
.46816 .28044 .46922 .28167 .4754 .27947 .47435 .27824 Metetra
.664 .741 .907 r
.47435 .27824 .4754 .27947 .4816 .27726 .48055 .27603 Metetra
.664 .741 .907 r
.48055 .27603 .4816 .27726 .48782 .27505 .48677 .27382 Metetra
.664 .741 .907 r
.48677 .27382 .48782 .27505 .49405 .27284 .493 .2716 Metetra
.664 .741 .907 r
.493 .2716 .49405 .27284 .50029 .27062 .49924 .26938 Metetra
.664 .741 .907 r
.49924 .26938 .50029 .27062 .50654 .26839 .5055 .26715 Metetra
.664 .741 .907 r
.5055 .26715 .50654 .26839 .51282 .26616 .51178 .26492 Metetra
.664 .741 .907 r
.51178 .26492 .51282 .26616 .5191 .26393 .51807 .26268 Metetra
.664 .741 .907 r
.51807 .26268 .5191 .26393 .5254 .26169 .52437 .26043 Metetra
.664 .741 .907 r
.52437 .26043 .5254 .26169 .53171 .25944 .53068 .25819 Metetra
.664 .741 .907 r
.53068 .25819 .53171 .25944 .53804 .25719 .53702 .25593 Metetra
.664 .741 .907 r
.53702 .25593 .53804 .25719 .54439 .25493 .54336 .25367 Metetra
.664 .741 .907 r
.54336 .25367 .54439 .25493 .55074 .25267 .54972 .25141 Metetra
.664 .741 .907 r
.54972 .25141 .55074 .25267 .55712 .25041 .5561 .24914 Metetra
.664 .741 .907 r
.5561 .24914 .55712 .25041 .5635 .24814 .56249 .24687 Metetra
.664 .741 .907 r
.56249 .24687 .5635 .24814 .5699 .24586 .56889 .24459 Metetra
.664 .741 .907 r
.56889 .24459 .5699 .24586 .57632 .24358 .57531 .2423 Metetra
.664 .741 .907 r
.57531 .2423 .57632 .24358 .58275 .24129 .58175 .24001 Metetra
.664 .741 .907 r
.58175 .24001 .58275 .24129 .5892 .239 .5882 .23772 Metetra
.664 .741 .907 r
.5882 .23772 .5892 .239 .59566 .2367 .59466 .23542 Metetra
.664 .741 .907 r
.59466 .23542 .59566 .2367 .60214 .2344 .60114 .23311 Metetra
.664 .741 .907 r
.60114 .23311 .60214 .2344 .60863 .23209 .60763 .2308 Metetra
.664 .741 .907 r
.60763 .2308 .60863 .23209 .61513 .22977 .61414 .22848 Metetra
.664 .741 .907 r
.61414 .22848 .61513 .22977 .62166 .22746 .62067 .22616 Metetra
.664 .741 .907 r
.62067 .22616 .62166 .22746 .62819 .22513 .62721 .22383 Metetra
.664 .741 .907 r
.62721 .22383 .62819 .22513 .63475 .2228 .63376 .2215 Metetra
.664 .741 .907 r
.63376 .2215 .63475 .2228 .64131 .22046 .64034 .21916 Metetra
.664 .741 .907 r
.64034 .21916 .64131 .22046 .6479 .21812 .64692 .21682 Metetra
.664 .741 .907 r
.64692 .21682 .6479 .21812 .65449 .21578 .65352 .21447 Metetra
.664 .741 .907 r
.65352 .21447 .65449 .21578 .66111 .21343 .66014 .21211 Metetra
.664 .741 .907 r
.66014 .21211 .66111 .21343 .66774 .21107 .66677 .20975 Metetra
.664 .741 .907 r
.66677 .20975 .66774 .21107 .67438 .2087 .67342 .20738 Metetra
.664 .741 .907 r
.67342 .20738 .67438 .2087 .68104 .20634 .68009 .20501 Metetra
.664 .741 .907 r
.68009 .20501 .68104 .20634 .68772 .20396 .68677 .20263 Metetra
.664 .741 .907 r
.68677 .20263 .68772 .20396 .69441 .20158 .69346 .20025 Metetra
.664 .741 .907 r
.69346 .20025 .69441 .20158 .70112 .1992 .70017 .19786 Metetra
.664 .741 .907 r
.70017 .19786 .70112 .1992 .70785 .1968 .7069 .19547 Metetra
.664 .741 .907 r
.7069 .19547 .70785 .1968 .71459 .19441 .71364 .19307 Metetra
.664 .741 .907 r
.71364 .19307 .71459 .19441 .72134 .19201 .7204 .19066 Metetra
.664 .741 .907 r
.7204 .19066 .72134 .19201 .72811 .1896 .72718 .18825 Metetra
.664 .741 .907 r
.72718 .18825 .72811 .1896 .7349 .18718 .73397 .18583 Metetra
.664 .741 .907 r
.73397 .18583 .7349 .18718 .74171 .18476 .74078 .18341 Metetra
.664 .741 .907 r
.74078 .18341 .74171 .18476 .74853 .18234 .7476 .18098 Metetra
.664 .741 .907 r
.7476 .18098 .74853 .18234 .75536 .17991 .75444 .17855 Metetra
.664 .741 .907 r
.75444 .17855 .75536 .17991 .76222 .17747 .7613 .17611 Metetra
.664 .741 .907 r
.7613 .17611 .76222 .17747 .76909 .17503 .76817 .17366 Metetra
.664 .741 .907 r
.76817 .17366 .76909 .17503 .77597 .17258 .77506 .17121 Metetra
.664 .741 .907 r
.77506 .17121 .77597 .17258 .78288 .17012 .78197 .16875 Metetra
.664 .741 .907 r
.78197 .16875 .78288 .17012 .7898 .16766 .78889 .16629 Metetra
.664 .741 .907 r
.78889 .16629 .7898 .16766 .79673 .16519 .79583 .16382 Metetra
.664 .741 .907 r
.17453 .38343 .1757 .38453 .18124 .38256 .18007 .38146 Metetra
.664 .741 .907 r
.18007 .38146 .18124 .38256 .1868 .38058 .18562 .37948 Metetra
.664 .741 .907 r
.18562 .37948 .1868 .38058 .19236 .3786 .19119 .37749 Metetra
.664 .741 .907 r
.19119 .37749 .19236 .3786 .19794 .37662 .19677 .37551 Metetra
.664 .741 .907 r
.19677 .37551 .19794 .37662 .20353 .37463 .20236 .37351 Metetra
.664 .741 .907 r
.20236 .37351 .20353 .37463 .20913 .37263 .20796 .37152 Metetra
.664 .741 .907 r
.20796 .37152 .20913 .37263 .21474 .37063 .21358 .36952 Metetra
.664 .741 .907 r
.21358 .36952 .21474 .37063 .22037 .36863 .21921 .36751 Metetra
.664 .741 .907 r
.21921 .36751 .22037 .36863 .226 .36663 .22485 .36551 Metetra
.664 .741 .907 r
.22485 .36551 .226 .36663 .23165 .36462 .2305 .36349 Metetra
.664 .741 .907 r
.2305 .36349 .23165 .36462 .23732 .3626 .23616 .36147 Metetra
.664 .741 .907 r
.23616 .36147 .23732 .3626 .24299 .36058 .24184 .35945 Metetra
.848 .395 0 r
.24184 .35945 .24299 .36058 .24868 .35856 .24653 .36889 Metetra
.282 .043 .363 r
.24653 .36889 .24868 .35856 .25422 .35834 .25323 .3554 Metetra
.622 .535 .735 r
.25323 .3554 .25422 .35834 .26009 .3545 .25894 .35336 Metetra
.664 .741 .907 r
.25894 .35336 .26009 .3545 .26581 .35246 .26467 .35132 Metetra
.664 .741 .907 r
.26467 .35132 .26581 .35246 .27155 .35042 .27041 .34928 Metetra
.664 .741 .907 r
.27041 .34928 .27155 .35042 .2773 .34837 .27616 .34723 Metetra
.664 .741 .907 r
.27616 .34723 .2773 .34837 .28306 .34632 .28192 .34517 Metetra
.664 .741 .907 r
.28192 .34517 .28306 .34632 .28883 .34426 .2877 .34312 Metetra
.664 .741 .907 r
.2877 .34312 .28883 .34426 .29462 .34221 .29349 .34105 Metetra
.664 .741 .907 r
.29349 .34105 .29462 .34221 .30042 .34014 .29929 .33899 Metetra
.664 .741 .907 r
.29929 .33899 .30042 .34014 .30623 .33807 .30511 .33692 Metetra
.664 .741 .907 r
.30511 .33692 .30623 .33807 .31206 .336 .31093 .33484 Metetra
.664 .741 .907 r
.31093 .33484 .31206 .336 .3179 .33392 .31677 .33276 Metetra
.664 .741 .907 r
.31677 .33276 .3179 .33392 .32375 .33184 .32263 .33067 Metetra
.664 .741 .907 r
.32263 .33067 .32375 .33184 .32961 .32975 .32849 .32859 Metetra
.664 .741 .907 r
.32849 .32859 .32961 .32975 .33549 .32766 .33437 .32649 Metetra
.664 .741 .907 r
.33437 .32649 .33549 .32766 .34138 .32556 .34027 .32439 Metetra
.956 .678 .468 r
.34027 .32439 .34138 .32556 .34393 .3829 .33575 .5057 Metetra
.253 .077 .439 r
.33575 .5057 .34393 .3829 .3532 .32136 .35209 .32018 Metetra
.664 .741 .907 r
.35209 .32018 .3532 .32136 .35913 .31925 .35802 .31807 Metetra
.664 .741 .907 r
.35802 .31807 .35913 .31925 .36507 .31713 .36397 .31595 Metetra
.664 .741 .907 r
.36397 .31595 .36507 .31713 .37103 .31501 .36993 .31383 Metetra
.664 .741 .907 r
.36993 .31383 .37103 .31501 .377 .31289 .3759 .3117 Metetra
.664 .741 .907 r
.3759 .3117 .377 .31289 .38298 .31076 .38188 .30957 Metetra
.664 .741 .907 r
.38188 .30957 .38298 .31076 .38897 .30862 .38788 .30743 Metetra
.664 .741 .907 r
.38788 .30743 .38897 .30862 .39498 .30648 .39389 .30529 Metetra
.664 .741 .907 r
.39389 .30529 .39498 .30648 .40101 .30434 .39992 .30314 Metetra
.664 .741 .907 r
.39992 .30314 .40101 .30434 .40704 .30219 .40596 .30099 Metetra
.664 .741 .907 r
.40596 .30099 .40704 .30219 .41309 .30004 .41201 .29884 Metetra
.664 .741 .907 r
.41201 .29884 .41309 .30004 .41916 .29788 .41808 .29667 Metetra
.664 .741 .907 r
.41808 .29667 .41916 .29788 .42523 .29572 .42416 .29451 Metetra
.664 .741 .907 r
.42416 .29451 .42523 .29572 .43132 .29355 .43025 .29234 Metetra
.664 .741 .907 r
.43025 .29234 .43132 .29355 .43743 .29138 .43636 .29016 Metetra
.664 .741 .907 r
.43636 .29016 .43743 .29138 .44355 .2892 .44248 .28798 Metetra
.664 .741 .907 r
.44248 .28798 .44355 .2892 .44968 .28702 .44861 .2858 Metetra
.664 .741 .907 r
.44861 .2858 .44968 .28702 .45583 .28483 .45476 .28361 Metetra
.664 .741 .907 r
.45476 .28361 .45583 .28483 .46199 .28264 .46093 .28141 Metetra
.664 .741 .907 r
.46093 .28141 .46199 .28264 .46816 .28044 .4671 .27921 Metetra
.664 .741 .907 r
.4671 .27921 .46816 .28044 .47435 .27824 .47329 .27701 Metetra
.664 .741 .907 r
.47329 .27701 .47435 .27824 .48055 .27603 .4795 .2748 Metetra
.664 .741 .907 r
.4795 .2748 .48055 .27603 .48677 .27382 .48572 .27258 Metetra
.664 .741 .907 r
.48572 .27258 .48677 .27382 .493 .2716 .49195 .27036 Metetra
.664 .741 .907 r
.49195 .27036 .493 .2716 .49924 .26938 .4982 .26813 Metetra
.664 .741 .907 r
.4982 .26813 .49924 .26938 .5055 .26715 .50446 .2659 Metetra
.664 .741 .907 r
.50446 .2659 .5055 .26715 .51178 .26492 .51074 .26367 Metetra
.664 .741 .907 r
.51074 .26367 .51178 .26492 .51807 .26268 .51703 .26143 Metetra
.664 .741 .907 r
.51703 .26143 .51807 .26268 .52437 .26043 .52333 .25918 Metetra
.664 .741 .907 r
.52333 .25918 .52437 .26043 .53068 .25819 .52965 .25693 Metetra
.664 .741 .907 r
.52965 .25693 .53068 .25819 .53702 .25593 .53599 .25467 Metetra
.664 .741 .907 r
.53599 .25467 .53702 .25593 .54336 .25367 .54234 .25241 Metetra
.664 .741 .907 r
.54234 .25241 .54336 .25367 .54972 .25141 .5487 .25015 Metetra
.664 .741 .907 r
.5487 .25015 .54972 .25141 .5561 .24914 .55508 .24787 Metetra
.664 .741 .907 r
.55508 .24787 .5561 .24914 .56249 .24687 .56147 .2456 Metetra
.664 .741 .907 r
.56147 .2456 .56249 .24687 .56889 .24459 .56788 .24331 Metetra
.664 .741 .907 r
.56788 .24331 .56889 .24459 .57531 .2423 .5743 .24103 Metetra
.664 .741 .907 r
.5743 .24103 .57531 .2423 .58175 .24001 .58074 .23873 Metetra
.664 .741 .907 r
.58074 .23873 .58175 .24001 .5882 .23772 .58719 .23643 Metetra
.967 .645 .327 r
.58719 .23643 .5882 .23772 .59466 .23542 .5955 .31599 Metetra
.384 .186 .484 r
.5955 .31599 .59466 .23542 .60114 .23311 .60014 .23182 Metetra
.664 .741 .907 r
.60014 .23182 .60114 .23311 .60763 .2308 .60664 .22951 Metetra
.664 .741 .907 r
.60664 .22951 .60763 .2308 .61414 .22848 .61315 .22719 Metetra
.664 .741 .907 r
.61315 .22719 .61414 .22848 .62067 .22616 .61968 .22486 Metetra
.664 .741 .907 r
.61968 .22486 .62067 .22616 .62721 .22383 .62622 .22253 Metetra
.664 .741 .907 r
.62622 .22253 .62721 .22383 .63376 .2215 .63278 .22019 Metetra
.664 .741 .907 r
.63278 .22019 .63376 .2215 .64034 .21916 .63936 .21785 Metetra
.664 .741 .907 r
.63936 .21785 .64034 .21916 .64692 .21682 .64594 .21551 Metetra
.664 .741 .907 r
.64594 .21551 .64692 .21682 .65352 .21447 .65255 .21315 Metetra
.664 .741 .907 r
.65255 .21315 .65352 .21447 .66014 .21211 .65917 .21079 Metetra
.664 .741 .907 r
.65917 .21079 .66014 .21211 .66677 .20975 .66581 .20843 Metetra
.664 .741 .907 r
.66581 .20843 .66677 .20975 .67342 .20738 .67246 .20606 Metetra
.664 .741 .907 r
.67246 .20606 .67342 .20738 .68009 .20501 .67913 .20369 Metetra
.664 .741 .907 r
.67913 .20369 .68009 .20501 .68677 .20263 .68581 .20131 Metetra
.664 .741 .907 r
.68581 .20131 .68677 .20263 .69346 .20025 .69251 .19892 Metetra
.664 .741 .907 r
.69251 .19892 .69346 .20025 .70017 .19786 .69922 .19653 Metetra
.664 .741 .907 r
.69922 .19653 .70017 .19786 .7069 .19547 .70595 .19413 Metetra
.664 .741 .907 r
.70595 .19413 .7069 .19547 .71364 .19307 .7127 .19173 Metetra
.664 .741 .907 r
.7127 .19173 .71364 .19307 .7204 .19066 .71946 .18932 Metetra
.664 .741 .907 r
.71946 .18932 .7204 .19066 .72718 .18825 .72624 .1869 Metetra
.664 .741 .907 r
.72624 .1869 .72718 .18825 .73397 .18583 .73304 .18448 Metetra
.664 .741 .907 r
.73304 .18448 .73397 .18583 .74078 .18341 .73985 .18206 Metetra
.664 .741 .907 r
.73985 .18206 .74078 .18341 .7476 .18098 .74667 .17962 Metetra
.664 .741 .907 r
.74667 .17962 .7476 .18098 .75444 .17855 .75352 .17719 Metetra
.664 .741 .907 r
.75352 .17719 .75444 .17855 .7613 .17611 .76038 .17474 Metetra
.664 .741 .907 r
.76038 .17474 .7613 .17611 .76817 .17366 .76726 .17229 Metetra
.664 .741 .907 r
.76726 .17229 .76817 .17366 .77506 .17121 .77415 .16984 Metetra
.664 .741 .907 r
.77415 .16984 .77506 .17121 .78197 .16875 .78106 .16738 Metetra
.664 .741 .907 r
.78106 .16738 .78197 .16875 .78889 .16629 .78799 .16491 Metetra
.664 .741 .907 r
.78799 .16491 .78889 .16629 .79583 .16382 .79493 .16244 Metetra
.664 .741 .907 r
.17335 .38233 .17453 .38343 .18007 .38146 .17889 .38035 Metetra
.664 .741 .907 r
.17889 .38035 .18007 .38146 .18562 .37948 .18445 .37837 Metetra
.664 .741 .907 r
.18445 .37837 .18562 .37948 .19119 .37749 .19002 .37639 Metetra
.664 .741 .907 r
.19002 .37639 .19119 .37749 .19677 .37551 .1956 .3744 Metetra
.664 .741 .907 r
.1956 .3744 .19677 .37551 .20236 .37351 .20119 .3724 Metetra
.664 .741 .907 r
.20119 .3724 .20236 .37351 .20796 .37152 .2068 .3704 Metetra
.664 .741 .907 r
.2068 .3704 .20796 .37152 .21358 .36952 .21241 .3684 Metetra
.664 .741 .907 r
.21241 .3684 .21358 .36952 .21921 .36751 .21804 .36639 Metetra
.664 .741 .907 r
.21804 .36639 .21921 .36751 .22485 .36551 .22369 .36438 Metetra
.664 .741 .907 r
.22369 .36438 .22485 .36551 .2305 .36349 .22934 .36237 Metetra
.664 .741 .907 r
.22934 .36237 .2305 .36349 .23616 .36147 .23501 .36035 Metetra
.664 .741 .907 r
.23501 .36035 .23616 .36147 .24184 .35945 .24069 .35832 Metetra
.664 .741 .907 r
.24069 .35832 .24184 .35945 .24653 .36889 .24638 .35629 Metetra
.558 .366 .577 r
.24638 .35629 .24653 .36889 .25323 .3554 .25208 .35426 Metetra
.664 .741 .907 r
.25208 .35426 .25323 .3554 .25894 .35336 .2578 .35222 Metetra
.664 .741 .907 r
.2578 .35222 .25894 .35336 .26467 .35132 .26352 .35018 Metetra
.664 .741 .907 r
.26352 .35018 .26467 .35132 .27041 .34928 .26927 .34813 Metetra
.664 .741 .907 r
.26927 .34813 .27041 .34928 .27616 .34723 .27502 .34608 Metetra
.664 .741 .907 r
.27502 .34608 .27616 .34723 .28192 .34517 .28078 .34403 Metetra
.664 .741 .907 r
.28078 .34403 .28192 .34517 .2877 .34312 .28656 .34197 Metetra
.664 .741 .907 r
.28656 .34197 .2877 .34312 .29349 .34105 .29236 .3399 Metetra
.664 .741 .907 r
.29236 .3399 .29349 .34105 .29929 .33899 .29816 .33783 Metetra
.664 .741 .907 r
.29816 .33783 .29929 .33899 .30511 .33692 .30398 .33576 Metetra
.664 .741 .907 r
.30398 .33576 .30511 .33692 .31093 .33484 .30981 .33368 Metetra
.664 .741 .907 r
.30981 .33368 .31093 .33484 .31677 .33276 .31565 .3316 Metetra
.664 .741 .907 r
.31565 .3316 .31677 .33276 .32263 .33067 .32151 .32951 Metetra
.664 .741 .907 r
.32151 .32951 .32263 .33067 .32849 .32859 .32737 .32742 Metetra
.664 .741 .907 r
.32737 .32742 .32849 .32859 .33437 .32649 .33326 .32532 Metetra
.956 .677 .467 r
.33326 .32532 .33437 .32649 .34027 .32439 .32928 .49045 Metetra
.57 .335 .52 r
.32928 .49045 .34027 .32439 .33575 .5057 .33185 .55199 Metetra
.771 .664 .111 r
.33185 .55199 .33575 .5057 .35209 .32018 .35098 .319 Metetra
.664 .741 .907 r
.35098 .319 .35209 .32018 .35802 .31807 .35692 .31689 Metetra
.664 .741 .907 r
.35692 .31689 .35802 .31807 .36397 .31595 .36286 .31477 Metetra
.664 .741 .907 r
.36286 .31477 .36397 .31595 .36993 .31383 .36882 .31264 Metetra
.664 .741 .907 r
.36882 .31264 .36993 .31383 .3759 .3117 .3748 .31051 Metetra
.664 .741 .907 r
.3748 .31051 .3759 .3117 .38188 .30957 .38079 .30838 Metetra
.664 .741 .907 r
.38079 .30838 .38188 .30957 .38788 .30743 .38679 .30624 Metetra
.664 .741 .907 r
.38679 .30624 .38788 .30743 .39389 .30529 .3928 .30409 Metetra
.664 .741 .907 r
.3928 .30409 .39389 .30529 .39992 .30314 .39883 .30194 Metetra
.664 .741 .907 r
.39883 .30194 .39992 .30314 .40596 .30099 .40487 .29979 Metetra
.664 .741 .907 r
.40487 .29979 .40596 .30099 .41201 .29884 .41093 .29763 Metetra
.664 .741 .907 r
.41093 .29763 .41201 .29884 .41808 .29667 .417 .29547 Metetra
.664 .741 .907 r
.417 .29547 .41808 .29667 .42416 .29451 .42308 .2933 Metetra
.664 .741 .907 r
.42308 .2933 .42416 .29451 .43025 .29234 .42917 .29113 Metetra
.664 .741 .907 r
.42917 .29113 .43025 .29234 .43636 .29016 .43528 .28895 Metetra
.664 .741 .907 r
.43528 .28895 .43636 .29016 .44248 .28798 .44141 .28676 Metetra
.664 .741 .907 r
.44141 .28676 .44248 .28798 .44861 .2858 .44755 .28458 Metetra
.664 .741 .907 r
.44755 .28458 .44861 .2858 .45476 .28361 .4537 .28238 Metetra
.664 .741 .907 r
.4537 .28238 .45476 .28361 .46093 .28141 .45986 .28018 Metetra
.664 .741 .907 r
.45986 .28018 .46093 .28141 .4671 .27921 .46604 .27798 Metetra
.664 .741 .907 r
.46604 .27798 .4671 .27921 .47329 .27701 .47224 .27577 Metetra
.664 .741 .907 r
.47224 .27577 .47329 .27701 .4795 .2748 .47844 .27356 Metetra
.664 .741 .907 r
.47844 .27356 .4795 .2748 .48572 .27258 .48467 .27134 Metetra
.664 .741 .907 r
.48467 .27134 .48572 .27258 .49195 .27036 .4909 .26912 Metetra
.664 .741 .907 r
.4909 .26912 .49195 .27036 .4982 .26813 .49715 .26689 Metetra
.664 .741 .907 r
.49715 .26689 .4982 .26813 .50446 .2659 .50342 .26466 Metetra
.664 .741 .907 r
.50342 .26466 .50446 .2659 .51074 .26367 .5097 .26242 Metetra
.664 .741 .907 r
.5097 .26242 .51074 .26367 .51703 .26143 .51599 .26018 Metetra
.664 .741 .907 r
.51599 .26018 .51703 .26143 .52333 .25918 .5223 .25793 Metetra
.664 .741 .907 r
.5223 .25793 .52333 .25918 .52965 .25693 .52862 .25567 Metetra
.664 .741 .907 r
.52862 .25567 .52965 .25693 .53599 .25467 .53496 .25341 Metetra
.664 .741 .907 r
.53496 .25341 .53599 .25467 .54234 .25241 .54131 .25115 Metetra
.664 .741 .907 r
.54131 .25115 .54234 .25241 .5487 .25015 .54768 .24888 Metetra
.664 .741 .907 r
.54768 .24888 .5487 .25015 .55508 .24787 .55406 .2466 Metetra
.664 .741 .907 r
.55406 .2466 .55508 .24787 .56147 .2456 .56045 .24432 Metetra
.664 .741 .907 r
.56045 .24432 .56147 .2456 .56788 .24331 .56686 .24204 Metetra
.664 .741 .907 r
.56686 .24204 .56788 .24331 .5743 .24103 .57329 .23975 Metetra
.779 .336 0 r
.57329 .23975 .5743 .24103 .58074 .23873 .58 .25265 Metetra
.341 .118 .423 r
.58 .25265 .58074 .23873 .58719 .23643 .58619 .23515 Metetra
.928 .551 .158 r
.58619 .23515 .58719 .23643 .5955 .31599 .59332 .26257 Metetra
.597 .366 .536 r
.59332 .26257 .5955 .31599 .60014 .23182 .59914 .23053 Metetra
.664 .741 .907 r
.59914 .23053 .60014 .23182 .60664 .22951 .60564 .22821 Metetra
.664 .741 .907 r
.60564 .22821 .60664 .22951 .61315 .22719 .61216 .22589 Metetra
.664 .741 .907 r
.61216 .22589 .61315 .22719 .61968 .22486 .61869 .22356 Metetra
.664 .741 .907 r
.61869 .22356 .61968 .22486 .62622 .22253 .62524 .22123 Metetra
.664 .741 .907 r
.62524 .22123 .62622 .22253 .63278 .22019 .6318 .21889 Metetra
.664 .741 .907 r
.6318 .21889 .63278 .22019 .63936 .21785 .63837 .21654 Metetra
.664 .741 .907 r
.63837 .21654 .63936 .21785 .64594 .21551 .64497 .21419 Metetra
.664 .741 .907 r
.64497 .21419 .64594 .21551 .65255 .21315 .65158 .21184 Metetra
.664 .741 .907 r
.65158 .21184 .65255 .21315 .65917 .21079 .6582 .20948 Metetra
.664 .741 .907 r
.6582 .20948 .65917 .21079 .66581 .20843 .66484 .20711 Metetra
.664 .741 .907 r
.66484 .20711 .66581 .20843 .67246 .20606 .67149 .20474 Metetra
.664 .741 .907 r
.67149 .20474 .67246 .20606 .67913 .20369 .67816 .20236 Metetra
.664 .741 .907 r
.67816 .20236 .67913 .20369 .68581 .20131 .68485 .19998 Metetra
.664 .741 .907 r
.68485 .19998 .68581 .20131 .69251 .19892 .69155 .19759 Metetra
.664 .741 .907 r
.69155 .19759 .69251 .19892 .69922 .19653 .69827 .19519 Metetra
.664 .741 .907 r
.69827 .19519 .69922 .19653 .70595 .19413 .705 .19279 Metetra
.664 .741 .907 r
.705 .19279 .70595 .19413 .7127 .19173 .71175 .19038 Metetra
.664 .741 .907 r
.71175 .19038 .7127 .19173 .71946 .18932 .71852 .18797 Metetra
.664 .741 .907 r
.71852 .18797 .71946 .18932 .72624 .1869 .7253 .18555 Metetra
.664 .741 .907 r
.7253 .18555 .72624 .1869 .73304 .18448 .7321 .18313 Metetra
.664 .741 .907 r
.7321 .18313 .73304 .18448 .73985 .18206 .73892 .1807 Metetra
.664 .741 .907 r
.73892 .1807 .73985 .18206 .74667 .17962 .74575 .17827 Metetra
.664 .741 .907 r
.74575 .17827 .74667 .17962 .75352 .17719 .75259 .17582 Metetra
.664 .741 .907 r
.75259 .17582 .75352 .17719 .76038 .17474 .75946 .17338 Metetra
.664 .741 .907 r
.75946 .17338 .76038 .17474 .76726 .17229 .76634 .17092 Metetra
.664 .741 .907 r
.76634 .17092 .76726 .17229 .77415 .16984 .77323 .16847 Metetra
.664 .741 .907 r
.77323 .16847 .77415 .16984 .78106 .16738 .78015 .166 Metetra
.664 .741 .907 r
.78015 .166 .78106 .16738 .78799 .16491 .78708 .16353 Metetra
.664 .741 .907 r
.78708 .16353 .78799 .16491 .79493 .16244 .79402 .16105 Metetra
.664 .741 .907 r
.17217 .38123 .17335 .38233 .17889 .38035 .17771 .37925 Metetra
.664 .741 .907 r
.17771 .37925 .17889 .38035 .18445 .37837 .18327 .37726 Metetra
.664 .741 .907 r
.18327 .37726 .18445 .37837 .19002 .37639 .18884 .37528 Metetra
.664 .741 .907 r
.18884 .37528 .19002 .37639 .1956 .3744 .19443 .37328 Metetra
.664 .741 .907 r
.19443 .37328 .1956 .3744 .20119 .3724 .20002 .37129 Metetra
.664 .741 .907 r
.20002 .37129 .20119 .3724 .2068 .3704 .20563 .36929 Metetra
.664 .741 .907 r
.20563 .36929 .2068 .3704 .21241 .3684 .21125 .36728 Metetra
.664 .741 .907 r
.21125 .36728 .21241 .3684 .21804 .36639 .21688 .36527 Metetra
.664 .741 .907 r
.21688 .36527 .21804 .36639 .22369 .36438 .22253 .36326 Metetra
.874 .436 .063 r
.22253 .36326 .22369 .36438 .22934 .36237 .22704 .37351 Metetra
.284 .048 .368 r
.22704 .37351 .22934 .36237 .23501 .36035 .23385 .35922 Metetra
.664 .741 .907 r
.23385 .35922 .23501 .36035 .24069 .35832 .23953 .35719 Metetra
.664 .741 .907 r
.23953 .35719 .24069 .35832 .24638 .35629 .24522 .35516 Metetra
.664 .741 .907 r
.24522 .35516 .24638 .35629 .25208 .35426 .25093 .35312 Metetra
.664 .741 .907 r
.25093 .35312 .25208 .35426 .2578 .35222 .25665 .35108 Metetra
.664 .741 .907 r
.25665 .35108 .2578 .35222 .26352 .35018 .26238 .34904 Metetra
.664 .741 .907 r
.26238 .34904 .26352 .35018 .26927 .34813 .26812 .34699 Metetra
.664 .741 .907 r
.26812 .34699 .26927 .34813 .27502 .34608 .27388 .34494 Metetra
.664 .741 .907 r
.27388 .34494 .27502 .34608 .28078 .34403 .27965 .34288 Metetra
.664 .741 .907 r
.27965 .34288 .28078 .34403 .28656 .34197 .28543 .34082 Metetra
.664 .741 .907 r
.28543 .34082 .28656 .34197 .29236 .3399 .29122 .33875 Metetra
.664 .741 .907 r
.29122 .33875 .29236 .3399 .29816 .33783 .29703 .33668 Metetra
.664 .741 .907 r
.29703 .33668 .29816 .33783 .30398 .33576 .30285 .3346 Metetra
.664 .741 .907 r
.30285 .3346 .30398 .33576 .30981 .33368 .30868 .33252 Metetra
.664 .741 .907 r
.30868 .33252 .30981 .33368 .31565 .3316 .31453 .33043 Metetra
.664 .741 .907 r
.31453 .33043 .31565 .3316 .32151 .32951 .32038 .32834 Metetra
.664 .741 .907 r
.32038 .32834 .32151 .32951 .32737 .32742 .32625 .32625 Metetra
.664 .741 .907 r
.32625 .32625 .32737 .32742 .33326 .32532 .33214 .32415 Metetra
.956 .674 .461 r
.33214 .32415 .33326 .32532 .32928 .49045 .33001 .45706 Metetra
.641 .41 .553 r
.33001 .45706 .32928 .49045 .33185 .55199 .33803 .42277 Metetra
.623 .385 .536 r
.33803 .42277 .33185 .55199 .35098 .319 .34987 .31782 Metetra
.664 .741 .907 r
.34987 .31782 .35098 .319 .35692 .31689 .35581 .3157 Metetra
.664 .741 .907 r
.35581 .3157 .35692 .31689 .36286 .31477 .36176 .31358 Metetra
.664 .741 .907 r
.36176 .31358 .36286 .31477 .36882 .31264 .36772 .31145 Metetra
.664 .741 .907 r
.36772 .31145 .36882 .31264 .3748 .31051 .3737 .30932 Metetra
.664 .741 .907 r
.3737 .30932 .3748 .31051 .38079 .30838 .37969 .30718 Metetra
.664 .741 .907 r
.37969 .30718 .38079 .30838 .38679 .30624 .38569 .30504 Metetra
.664 .741 .907 r
.38569 .30504 .38679 .30624 .3928 .30409 .39171 .30289 Metetra
.664 .741 .907 r
.39171 .30289 .3928 .30409 .39883 .30194 .39774 .30074 Metetra
.664 .741 .907 r
.39774 .30074 .39883 .30194 .40487 .29979 .40378 .29859 Metetra
.664 .741 .907 r
.40378 .29859 .40487 .29979 .41093 .29763 .40984 .29642 Metetra
.664 .741 .907 r
.40984 .29642 .41093 .29763 .417 .29547 .41591 .29426 Metetra
.664 .741 .907 r
.41591 .29426 .417 .29547 .42308 .2933 .422 .29209 Metetra
.664 .741 .907 r
.422 .29209 .42308 .2933 .42917 .29113 .4281 .28991 Metetra
.664 .741 .907 r
.4281 .28991 .42917 .29113 .43528 .28895 .43421 .28773 Metetra
.664 .741 .907 r
.43421 .28773 .43528 .28895 .44141 .28676 .44034 .28554 Metetra
.664 .741 .907 r
.44034 .28554 .44141 .28676 .44755 .28458 .44648 .28335 Metetra
.664 .741 .907 r
.44648 .28335 .44755 .28458 .4537 .28238 .45263 .28116 Metetra
.664 .741 .907 r
.45263 .28116 .4537 .28238 .45986 .28018 .4588 .27896 Metetra
.664 .741 .907 r
.4588 .27896 .45986 .28018 .46604 .27798 .46498 .27675 Metetra
.664 .741 .907 r
.46498 .27675 .46604 .27798 .47224 .27577 .47118 .27454 Metetra
.664 .741 .907 r
.47118 .27454 .47224 .27577 .47844 .27356 .47739 .27232 Metetra
.664 .741 .907 r
.47739 .27232 .47844 .27356 .48467 .27134 .48361 .2701 Metetra
.664 .741 .907 r
.48361 .2701 .48467 .27134 .4909 .26912 .48985 .26788 Metetra
.664 .741 .907 r
.48985 .26788 .4909 .26912 .49715 .26689 .49611 .26565 Metetra
.664 .741 .907 r
.49611 .26565 .49715 .26689 .50342 .26466 .50237 .26341 Metetra
.664 .741 .907 r
.50237 .26341 .50342 .26466 .5097 .26242 .50866 .26117 Metetra
.664 .741 .907 r
.50866 .26117 .5097 .26242 .51599 .26018 .51495 .25892 Metetra
.664 .741 .907 r
.51495 .25892 .51599 .26018 .5223 .25793 .52126 .25667 Metetra
.664 .741 .907 r
.52126 .25667 .5223 .25793 .52862 .25567 .52759 .25441 Metetra
.664 .741 .907 r
.52759 .25441 .52862 .25567 .53496 .25341 .53393 .25215 Metetra
.664 .741 .907 r
.53393 .25215 .53496 .25341 .54131 .25115 .54028 .24988 Metetra
.664 .741 .907 r
.54028 .24988 .54131 .25115 .54768 .24888 .54665 .24761 Metetra
.664 .741 .907 r
.54665 .24761 .54768 .24888 .55406 .2466 .55304 .24533 Metetra
.664 .741 .907 r
.55304 .24533 .55406 .2466 .56045 .24432 .55943 .24305 Metetra
.664 .741 .907 r
.55943 .24305 .56045 .24432 .56686 .24204 .56585 .24076 Metetra
.664 .741 .907 r
.56585 .24076 .56686 .24204 .57329 .23975 .57228 .23847 Metetra
.664 .741 .907 r
.57228 .23847 .57329 .23975 .58 .25265 .57872 .23617 Metetra
.343 .2 .538 r
.57872 .23617 .58 .25265 .58619 .23515 .58565 .2577 Metetra
.361 .149 .451 r
.58565 .2577 .58619 .23515 .59332 .26257 .59165 .23155 Metetra
.542 .33 .542 r
.59165 .23155 .59332 .26257 .59914 .23053 .59814 .22924 Metetra
.664 .741 .907 r
.59814 .22924 .59914 .23053 .60564 .22821 .60464 .22692 Metetra
.664 .741 .907 r
.60464 .22692 .60564 .22821 .61216 .22589 .61116 .22459 Metetra
.664 .741 .907 r
.61116 .22459 .61216 .22589 .61869 .22356 .6177 .22226 Metetra
.664 .741 .907 r
.6177 .22226 .61869 .22356 .62524 .22123 .62425 .21992 Metetra
.664 .741 .907 r
.62425 .21992 .62524 .22123 .6318 .21889 .63081 .21758 Metetra
.664 .741 .907 r
.63081 .21758 .6318 .21889 .63837 .21654 .63739 .21523 Metetra
.664 .741 .907 r
.63739 .21523 .63837 .21654 .64497 .21419 .64399 .21288 Metetra
.664 .741 .907 r
.64399 .21288 .64497 .21419 .65158 .21184 .6506 .21052 Metetra
.664 .741 .907 r
.6506 .21052 .65158 .21184 .6582 .20948 .65723 .20816 Metetra
.664 .741 .907 r
.65723 .20816 .6582 .20948 .66484 .20711 .66387 .20579 Metetra
.664 .741 .907 r
.66387 .20579 .66484 .20711 .67149 .20474 .67053 .20341 Metetra
.664 .741 .907 r
.67053 .20341 .67149 .20474 .67816 .20236 .6772 .20103 Metetra
.664 .741 .907 r
.6772 .20103 .67816 .20236 .68485 .19998 .68389 .19864 Metetra
.664 .741 .907 r
.68389 .19864 .68485 .19998 .69155 .19759 .6906 .19625 Metetra
.664 .741 .907 r
.6906 .19625 .69155 .19759 .69827 .19519 .69732 .19385 Metetra
.664 .741 .907 r
.69732 .19385 .69827 .19519 .705 .19279 .70405 .19145 Metetra
.664 .741 .907 r
.70405 .19145 .705 .19279 .71175 .19038 .71081 .18904 Metetra
.664 .741 .907 r
.71081 .18904 .71175 .19038 .71852 .18797 .71758 .18662 Metetra
.664 .741 .907 r
.71758 .18662 .71852 .18797 .7253 .18555 .72436 .1842 Metetra
.664 .741 .907 r
.72436 .1842 .7253 .18555 .7321 .18313 .73116 .18178 Metetra
.664 .741 .907 r
.73116 .18178 .7321 .18313 .73892 .1807 .73798 .17934 Metetra
.664 .741 .907 r
.73798 .17934 .73892 .1807 .74575 .17827 .74482 .17691 Metetra
.664 .741 .907 r
.74482 .17691 .74575 .17827 .75259 .17582 .75167 .17446 Metetra
.664 .741 .907 r
.75167 .17446 .75259 .17582 .75946 .17338 .75854 .17201 Metetra
.664 .741 .907 r
.75854 .17201 .75946 .17338 .76634 .17092 .76542 .16955 Metetra
.664 .741 .907 r
.76542 .16955 .76634 .17092 .77323 .16847 .77232 .16709 Metetra
.664 .741 .907 r
.77232 .16709 .77323 .16847 .78015 .166 .77924 .16462 Metetra
.664 .741 .907 r
.77924 .16462 .78015 .166 .78708 .16353 .78617 .16215 Metetra
.664 .741 .907 r
.78617 .16215 .78708 .16353 .79402 .16105 .79312 .15967 Metetra
.664 .741 .907 r
.17099 .38012 .17217 .38123 .17771 .37925 .17654 .37814 Metetra
.664 .741 .907 r
.17654 .37814 .17771 .37925 .18327 .37726 .1821 .37616 Metetra
.664 .741 .907 r
.1821 .37616 .18327 .37726 .18884 .37528 .18767 .37417 Metetra
.664 .741 .907 r
.18767 .37417 .18884 .37528 .19443 .37328 .19325 .37217 Metetra
.664 .741 .907 r
.19325 .37217 .19443 .37328 .20002 .37129 .19885 .37017 Metetra
.664 .741 .907 r
.19885 .37017 .20002 .37129 .20563 .36929 .20446 .36817 Metetra
.664 .741 .907 r
.20446 .36817 .20563 .36929 .21125 .36728 .21008 .36616 Metetra
.664 .741 .907 r
.21008 .36616 .21125 .36728 .21688 .36527 .21572 .36415 Metetra
.869 .427 .05 r
.21572 .36415 .21688 .36527 .22253 .36326 .22022 .37408 Metetra
.486 .222 .439 r
.22022 .37408 .22253 .36326 .22704 .37351 .22595 .3716 Metetra
.853 .692 .683 r
.22595 .3716 .22704 .37351 .23385 .35922 .23269 .35809 Metetra
.664 .741 .907 r
.23269 .35809 .23385 .35922 .23953 .35719 .23837 .35606 Metetra
.664 .741 .907 r
.23837 .35606 .23953 .35719 .24522 .35516 .24407 .35403 Metetra
.664 .741 .907 r
.24407 .35403 .24522 .35516 .25093 .35312 .24978 .35199 Metetra
.664 .741 .907 r
.24978 .35199 .25093 .35312 .25665 .35108 .2555 .34994 Metetra
.664 .741 .907 r
.2555 .34994 .25665 .35108 .26238 .34904 .26123 .3479 Metetra
.664 .741 .907 r
.26123 .3479 .26238 .34904 .26812 .34699 .26698 .34585 Metetra
.664 .741 .907 r
.26698 .34585 .26812 .34699 .27388 .34494 .27274 .34379 Metetra
.664 .741 .907 r
.27274 .34379 .27388 .34494 .27965 .34288 .27851 .34173 Metetra
.664 .741 .907 r
.27851 .34173 .27965 .34288 .28543 .34082 .28429 .33966 Metetra
.664 .741 .907 r
.28429 .33966 .28543 .34082 .29122 .33875 .29009 .33759 Metetra
.664 .741 .907 r
.29009 .33759 .29122 .33875 .29703 .33668 .29589 .33552 Metetra
.664 .741 .907 r
.29589 .33552 .29703 .33668 .30285 .3346 .30172 .33344 Metetra
.664 .741 .907 r
.30172 .33344 .30285 .3346 .30868 .33252 .30755 .33136 Metetra
.664 .741 .907 r
.30755 .33136 .30868 .33252 .31453 .33043 .3134 .32927 Metetra
.664 .741 .907 r
.3134 .32927 .31453 .33043 .32038 .32834 .31926 .32718 Metetra
.664 .741 .907 r
.31926 .32718 .32038 .32834 .32625 .32625 .32513 .32508 Metetra
.664 .741 .907 r
.32513 .32508 .32625 .32625 .33214 .32415 .33102 .32298 Metetra
.956 .643 .394 r
.33102 .32298 .33214 .32415 .33001 .45706 .33418 .36662 Metetra
.527 .307 .524 r
.33418 .36662 .33001 .45706 .33803 .42277 .3399 .36932 Metetra
.637 .401 .544 r
.3399 .36932 .33803 .42277 .34987 .31782 .34876 .31664 Metetra
.664 .741 .907 r
.34876 .31664 .34987 .31782 .35581 .3157 .3547 .31452 Metetra
.664 .741 .907 r
.3547 .31452 .35581 .3157 .36176 .31358 .36065 .31239 Metetra
.664 .741 .907 r
.36065 .31239 .36176 .31358 .36772 .31145 .36662 .31026 Metetra
.664 .741 .907 r
.36662 .31026 .36772 .31145 .3737 .30932 .3726 .30813 Metetra
.664 .741 .907 r
.3726 .30813 .3737 .30932 .37969 .30718 .37859 .30599 Metetra
.664 .741 .907 r
.37859 .30599 .37969 .30718 .38569 .30504 .38459 .30384 Metetra
.664 .741 .907 r
.38459 .30384 .38569 .30504 .39171 .30289 .39061 .3017 Metetra
.664 .741 .907 r
.39061 .3017 .39171 .30289 .39774 .30074 .39665 .29954 Metetra
.664 .741 .907 r
.39665 .29954 .39774 .30074 .40378 .29859 .40269 .29738 Metetra
.664 .741 .907 r
.40269 .29738 .40378 .29859 .40984 .29642 .40875 .29522 Metetra
.664 .741 .907 r
.40875 .29522 .40984 .29642 .41591 .29426 .41483 .29305 Metetra
.664 .741 .907 r
.41483 .29305 .41591 .29426 .422 .29209 .42092 .29087 Metetra
.664 .741 .907 r
.42092 .29087 .422 .29209 .4281 .28991 .42702 .2887 Metetra
.664 .741 .907 r
.42702 .2887 .4281 .28991 .43421 .28773 .43313 .28651 Metetra
.664 .741 .907 r
.43313 .28651 .43421 .28773 .44034 .28554 .43926 .28432 Metetra
.865 .436 .013 r
.43926 .28432 .44034 .28554 .44648 .28335 .445 .29793 Metetra
.328 .105 .414 r
.445 .29793 .44648 .28335 .45263 .28116 .45156 .27993 Metetra
.664 .741 .907 r
.45156 .27993 .45263 .28116 .4588 .27896 .45773 .27773 Metetra
.664 .741 .907 r
.45773 .27773 .4588 .27896 .46498 .27675 .46392 .27552 Metetra
.664 .741 .907 r
.46392 .27552 .46498 .27675 .47118 .27454 .47012 .2733 Metetra
.664 .741 .907 r
.47012 .2733 .47118 .27454 .47739 .27232 .47633 .27109 Metetra
.664 .741 .907 r
.47633 .27109 .47739 .27232 .48361 .2701 .48256 .26886 Metetra
.664 .741 .907 r
.48256 .26886 .48361 .2701 .48985 .26788 .4888 .26663 Metetra
.664 .741 .907 r
.4888 .26663 .48985 .26788 .49611 .26565 .49506 .2644 Metetra
.664 .741 .907 r
.49506 .2644 .49611 .26565 .50237 .26341 .50133 .26216 Metetra
.664 .741 .907 r
.50133 .26216 .50237 .26341 .50866 .26117 .50761 .25992 Metetra
.664 .741 .907 r
.50761 .25992 .50866 .26117 .51495 .25892 .51391 .25767 Metetra
.664 .741 .907 r
.51391 .25767 .51495 .25892 .52126 .25667 .52022 .25541 Metetra
.664 .741 .907 r
.52022 .25541 .52126 .25667 .52759 .25441 .52655 .25315 Metetra
.664 .741 .907 r
.52655 .25315 .52759 .25441 .53393 .25215 .5329 .25089 Metetra
.664 .741 .907 r
.5329 .25089 .53393 .25215 .54028 .24988 .53925 .24862 Metetra
.664 .741 .907 r
.53925 .24862 .54028 .24988 .54665 .24761 .54563 .24634 Metetra
.664 .741 .907 r
.54563 .24634 .54665 .24761 .55304 .24533 .55201 .24406 Metetra
.664 .741 .907 r
.55201 .24406 .55304 .24533 .55943 .24305 .55841 .24177 Metetra
.664 .741 .907 r
.55841 .24177 .55943 .24305 .56585 .24076 .56483 .23948 Metetra
.664 .741 .907 r
.56483 .23948 .56585 .24076 .57228 .23847 .57126 .23719 Metetra
.664 .741 .907 r
.57126 .23719 .57228 .23847 .57872 .23617 .57771 .23488 Metetra
.664 .741 .907 r
.57771 .23488 .57872 .23617 .58565 .2577 .58417 .23258 Metetra
.544 .336 .548 r
.58417 .23258 .58565 .2577 .59165 .23155 .59065 .23026 Metetra
.664 .741 .907 r
.59065 .23026 .59165 .23155 .59814 .22924 .59714 .22795 Metetra
.664 .741 .907 r
.59714 .22795 .59814 .22924 .60464 .22692 .60365 .22562 Metetra
.664 .741 .907 r
.60365 .22562 .60464 .22692 .61116 .22459 .61017 .22329 Metetra
.664 .741 .907 r
.61017 .22329 .61116 .22459 .6177 .22226 .6167 .22096 Metetra
.664 .741 .907 r
.6167 .22096 .6177 .22226 .62425 .21992 .62326 .21862 Metetra
.664 .741 .907 r
.62326 .21862 .62425 .21992 .63081 .21758 .62983 .21627 Metetra
.664 .741 .907 r
.62983 .21627 .63081 .21758 .63739 .21523 .63641 .21392 Metetra
.664 .741 .907 r
.63641 .21392 .63739 .21523 .64399 .21288 .64301 .21157 Metetra
.664 .741 .907 r
.64301 .21157 .64399 .21288 .6506 .21052 .64962 .2092 Metetra
.664 .741 .907 r
.64962 .2092 .6506 .21052 .65723 .20816 .65625 .20684 Metetra
.664 .741 .907 r
.65625 .20684 .65723 .20816 .66387 .20579 .6629 .20446 Metetra
.664 .741 .907 r
.6629 .20446 .66387 .20579 .67053 .20341 .66956 .20208 Metetra
.664 .741 .907 r
.66956 .20208 .67053 .20341 .6772 .20103 .67624 .1997 Metetra
.664 .741 .907 r
.67624 .1997 .6772 .20103 .68389 .19864 .68293 .19731 Metetra
.664 .741 .907 r
.68293 .19731 .68389 .19864 .6906 .19625 .68964 .19491 Metetra
.664 .741 .907 r
.68964 .19491 .6906 .19625 .69732 .19385 .69636 .19251 Metetra
.664 .741 .907 r
.69636 .19251 .69732 .19385 .70405 .19145 .7031 .19011 Metetra
.664 .741 .907 r
.7031 .19011 .70405 .19145 .71081 .18904 .70986 .18769 Metetra
.664 .741 .907 r
.70986 .18769 .71081 .18904 .71758 .18662 .71663 .18527 Metetra
.664 .741 .907 r
.71663 .18527 .71758 .18662 .72436 .1842 .72342 .18285 Metetra
.664 .741 .907 r
.72342 .18285 .72436 .1842 .73116 .18178 .73023 .18042 Metetra
.664 .741 .907 r
.73023 .18042 .73116 .18178 .73798 .17934 .73705 .17798 Metetra
.664 .741 .907 r
.73705 .17798 .73798 .17934 .74482 .17691 .74389 .17554 Metetra
.664 .741 .907 r
.74389 .17554 .74482 .17691 .75167 .17446 .75074 .17309 Metetra
.664 .741 .907 r
.75074 .17309 .75167 .17446 .75854 .17201 .75761 .17064 Metetra
.664 .741 .907 r
.75761 .17064 .75854 .17201 .76542 .16955 .7645 .16818 Metetra
.664 .741 .907 r
.7645 .16818 .76542 .16955 .77232 .16709 .7714 .16572 Metetra
.664 .741 .907 r
.7714 .16572 .77232 .16709 .77924 .16462 .77832 .16325 Metetra
.664 .741 .907 r
.77832 .16325 .77924 .16462 .78617 .16215 .78526 .16077 Metetra
.664 .741 .907 r
.78526 .16077 .78617 .16215 .79312 .15967 .79221 .15828 Metetra
.664 .741 .907 r
.1698 .37902 .17099 .38012 .17654 .37814 .17535 .37703 Metetra
.664 .741 .907 r
.17535 .37703 .17654 .37814 .1821 .37616 .18092 .37505 Metetra
.664 .741 .907 r
.18092 .37505 .1821 .37616 .18767 .37417 .18649 .37305 Metetra
.664 .741 .907 r
.18649 .37305 .18767 .37417 .19325 .37217 .19208 .37106 Metetra
.664 .741 .907 r
.19208 .37106 .19325 .37217 .19885 .37017 .19768 .36906 Metetra
.664 .741 .907 r
.19768 .36906 .19885 .37017 .20446 .36817 .20329 .36705 Metetra
.664 .741 .907 r
.20329 .36705 .20446 .36817 .21008 .36616 .20891 .36504 Metetra
.664 .741 .907 r
.20891 .36504 .21008 .36616 .21572 .36415 .21455 .36303 Metetra
.947 .633 .405 r
.21455 .36303 .21572 .36415 .22022 .37408 .21694 .39502 Metetra
.164 0 .358 r
.21694 .39502 .22022 .37408 .22595 .3716 .22586 .35898 Metetra
.557 .365 .576 r
.22586 .35898 .22595 .3716 .23269 .35809 .23153 .35696 Metetra
.664 .741 .907 r
.23153 .35696 .23269 .35809 .23837 .35606 .23722 .35493 Metetra
.664 .741 .907 r
.23722 .35493 .23837 .35606 .24407 .35403 .24292 .35289 Metetra
.664 .741 .907 r
.24292 .35289 .24407 .35403 .24978 .35199 .24863 .35085 Metetra
.664 .741 .907 r
.24863 .35085 .24978 .35199 .2555 .34994 .25435 .3488 Metetra
.664 .741 .907 r
.25435 .3488 .2555 .34994 .26123 .3479 .26008 .34675 Metetra
.664 .741 .907 r
.26008 .34675 .26123 .3479 .26698 .34585 .26583 .3447 Metetra
.664 .741 .907 r
.26583 .3447 .26698 .34585 .27274 .34379 .27159 .34264 Metetra
.664 .741 .907 r
.27159 .34264 .27274 .34379 .27851 .34173 .27736 .34058 Metetra
.664 .741 .907 r
.27736 .34058 .27851 .34173 .28429 .33966 .28315 .33851 Metetra
.664 .741 .907 r
.28315 .33851 .28429 .33966 .29009 .33759 .28895 .33644 Metetra
.664 .741 .907 r
.28895 .33644 .29009 .33759 .29589 .33552 .29476 .33436 Metetra
.664 .741 .907 r
.29476 .33436 .29589 .33552 .30172 .33344 .30058 .33228 Metetra
.664 .741 .907 r
.30058 .33228 .30172 .33344 .30755 .33136 .30642 .33019 Metetra
.664 .741 .907 r
.30642 .33019 .30755 .33136 .3134 .32927 .31227 .3281 Metetra
.664 .741 .907 r
.31227 .3281 .3134 .32927 .31926 .32718 .31813 .32601 Metetra
.664 .741 .907 r
.31813 .32601 .31926 .32718 .32513 .32508 .32401 .32391 Metetra
.664 .741 .907 r
.32401 .32391 .32513 .32508 .33102 .32298 .3299 .3218 Metetra
.664 .741 .907 r
.3299 .3218 .33102 .32298 .33418 .36662 .3358 .31969 Metetra
.533 .317 .532 r
.3358 .31969 .33418 .36662 .3399 .36932 .34163 .31913 Metetra
.541 .322 .532 r
.34163 .31913 .3399 .36932 .34876 .31664 .34765 .31546 Metetra
.664 .741 .907 r
.34765 .31546 .34876 .31664 .3547 .31452 .35359 .31334 Metetra
.664 .741 .907 r
.35359 .31334 .3547 .31452 .36065 .31239 .35954 .31121 Metetra
.664 .741 .907 r
.35954 .31121 .36065 .31239 .36662 .31026 .36551 .30907 Metetra
.664 .741 .907 r
.36551 .30907 .36662 .31026 .3726 .30813 .37149 .30694 Metetra
.664 .741 .907 r
.37149 .30694 .3726 .30813 .37859 .30599 .37749 .30479 Metetra
.664 .741 .907 r
.37749 .30479 .37859 .30599 .38459 .30384 .3835 .30265 Metetra
.664 .741 .907 r
.3835 .30265 .38459 .30384 .39061 .3017 .38952 .30049 Metetra
.664 .741 .907 r
.38952 .30049 .39061 .3017 .39665 .29954 .39555 .29834 Metetra
.664 .741 .907 r
.39555 .29834 .39665 .29954 .40269 .29738 .4016 .29617 Metetra
.664 .741 .907 r
.4016 .29617 .40269 .29738 .40875 .29522 .40767 .29401 Metetra
.664 .741 .907 r
.40767 .29401 .40875 .29522 .41483 .29305 .41374 .29184 Metetra
.664 .741 .907 r
.41374 .29184 .41483 .29305 .42092 .29087 .41983 .28966 Metetra
.664 .741 .907 r
.41983 .28966 .42092 .29087 .42702 .2887 .42594 .28748 Metetra
.664 .741 .907 r
.42594 .28748 .42702 .2887 .43313 .28651 .43206 .28529 Metetra
.664 .741 .907 r
.43206 .28529 .43313 .28651 .43926 .28432 .43819 .2831 Metetra
.664 .741 .907 r
.43819 .2831 .43926 .28432 .445 .29793 .44433 .2809 Metetra
.551 .35 .562 r
.44433 .2809 .445 .29793 .45156 .27993 .45049 .2787 Metetra
.664 .741 .907 r
.45049 .2787 .45156 .27993 .45773 .27773 .45667 .2765 Metetra
.664 .741 .907 r
.45667 .2765 .45773 .27773 .46392 .27552 .46285 .27428 Metetra
.664 .741 .907 r
.46285 .27428 .46392 .27552 .47012 .2733 .46906 .27207 Metetra
.664 .741 .907 r
.46906 .27207 .47012 .2733 .47633 .27109 .47527 .26985 Metetra
.664 .741 .907 r
.47527 .26985 .47633 .27109 .48256 .26886 .4815 .26762 Metetra
.664 .741 .907 r
.4815 .26762 .48256 .26886 .4888 .26663 .48775 .26539 Metetra
.664 .741 .907 r
.48775 .26539 .4888 .26663 .49506 .2644 .49401 .26315 Metetra
.664 .741 .907 r
.49401 .26315 .49506 .2644 .50133 .26216 .50028 .26091 Metetra
.664 .741 .907 r
.50028 .26091 .50133 .26216 .50761 .25992 .50657 .25866 Metetra
.664 .741 .907 r
.50657 .25866 .50761 .25992 .51391 .25767 .51287 .25641 Metetra
.664 .741 .907 r
.51287 .25641 .51391 .25767 .52022 .25541 .51919 .25415 Metetra
.664 .741 .907 r
.51919 .25415 .52022 .25541 .52655 .25315 .52552 .25189 Metetra
.664 .741 .907 r
.52552 .25189 .52655 .25315 .5329 .25089 .53186 .24962 Metetra
.664 .741 .907 r
.53186 .24962 .5329 .25089 .53925 .24862 .53822 .24735 Metetra
.664 .741 .907 r
.53822 .24735 .53925 .24862 .54563 .24634 .5446 .24507 Metetra
.664 .741 .907 r
.5446 .24507 .54563 .24634 .55201 .24406 .55099 .24279 Metetra
.664 .741 .907 r
.55099 .24279 .55201 .24406 .55841 .24177 .55739 .2405 Metetra
.664 .741 .907 r
.55739 .2405 .55841 .24177 .56483 .23948 .56381 .2382 Metetra
.664 .741 .907 r
.56381 .2382 .56483 .23948 .57126 .23719 .57025 .2359 Metetra
.664 .741 .907 r
.57025 .2359 .57126 .23719 .57771 .23488 .5767 .2336 Metetra
.664 .741 .907 r
.5767 .2336 .57771 .23488 .58417 .23258 .58316 .23129 Metetra
.664 .741 .907 r
.58316 .23129 .58417 .23258 .59065 .23026 .58964 .22897 Metetra
.664 .741 .907 r
.58964 .22897 .59065 .23026 .59714 .22795 .59614 .22665 Metetra
.664 .741 .907 r
.59614 .22665 .59714 .22795 .60365 .22562 .60265 .22432 Metetra
.664 .741 .907 r
.60265 .22432 .60365 .22562 .61017 .22329 .60917 .22199 Metetra
.664 .741 .907 r
.60917 .22199 .61017 .22329 .6167 .22096 .61571 .21965 Metetra
.664 .741 .907 r
.61571 .21965 .6167 .22096 .62326 .21862 .62227 .21731 Metetra
.664 .741 .907 r
.62227 .21731 .62326 .21862 .62983 .21627 .62884 .21496 Metetra
.664 .741 .907 r
.62884 .21496 .62983 .21627 .63641 .21392 .63542 .21261 Metetra
.664 .741 .907 r
.63542 .21261 .63641 .21392 .64301 .21157 .64203 .21025 Metetra
.664 .741 .907 r
.64203 .21025 .64301 .21157 .64962 .2092 .64864 .20788 Metetra
.664 .741 .907 r
.64864 .20788 .64962 .2092 .65625 .20684 .65528 .20551 Metetra
.664 .741 .907 r
.65528 .20551 .65625 .20684 .6629 .20446 .66193 .20314 Metetra
.664 .741 .907 r
.66193 .20314 .6629 .20446 .66956 .20208 .66859 .20076 Metetra
.664 .741 .907 r
.66859 .20076 .66956 .20208 .67624 .1997 .67527 .19837 Metetra
.664 .741 .907 r
.67527 .19837 .67624 .1997 .68293 .19731 .68197 .19597 Metetra
.664 .741 .907 r
.68197 .19597 .68293 .19731 .68964 .19491 .68868 .19358 Metetra
.664 .741 .907 r
.68868 .19358 .68964 .19491 .69636 .19251 .69541 .19117 Metetra
.664 .741 .907 r
.69541 .19117 .69636 .19251 .7031 .19011 .70215 .18876 Metetra
.664 .741 .907 r
.70215 .18876 .7031 .19011 .70986 .18769 .70891 .18634 Metetra
.664 .741 .907 r
.70891 .18634 .70986 .18769 .71663 .18527 .71569 .18392 Metetra
.664 .741 .907 r
.71569 .18392 .71663 .18527 .72342 .18285 .72248 .1815 Metetra
.664 .741 .907 r
.72248 .1815 .72342 .18285 .73023 .18042 .72929 .17906 Metetra
.664 .741 .907 r
.72929 .17906 .73023 .18042 .73705 .17798 .73611 .17662 Metetra
.664 .741 .907 r
.73611 .17662 .73705 .17798 .74389 .17554 .74296 .17418 Metetra
.664 .741 .907 r
.74296 .17418 .74389 .17554 .75074 .17309 .74981 .17173 Metetra
.664 .741 .907 r
.74981 .17173 .75074 .17309 .75761 .17064 .75669 .16927 Metetra
.664 .741 .907 r
.75669 .16927 .75761 .17064 .7645 .16818 .76358 .16681 Metetra
.664 .741 .907 r
.76358 .16681 .7645 .16818 .7714 .16572 .77048 .16434 Metetra
.664 .741 .907 r
.77048 .16434 .7714 .16572 .77832 .16325 .77741 .16186 Metetra
.664 .741 .907 r
.77741 .16186 .77832 .16325 .78526 .16077 .78435 .15938 Metetra
.664 .741 .907 r
.78435 .15938 .78526 .16077 .79221 .15828 .79131 .1569 Metetra
.664 .741 .907 r
.16862 .37791 .1698 .37902 .17535 .37703 .17417 .37593 Metetra
.664 .741 .907 r
.17417 .37593 .17535 .37703 .18092 .37505 .17974 .37394 Metetra
.664 .741 .907 r
.17974 .37394 .18092 .37505 .18649 .37305 .18532 .37194 Metetra
.664 .741 .907 r
.18532 .37194 .18649 .37305 .19208 .37106 .1909 .36994 Metetra
.664 .741 .907 r
.1909 .36994 .19208 .37106 .19768 .36906 .19651 .36794 Metetra
.664 .741 .907 r
.19651 .36794 .19768 .36906 .20329 .36705 .20212 .36593 Metetra
.664 .741 .907 r
.20212 .36593 .20329 .36705 .20891 .36504 .20775 .36392 Metetra
.664 .741 .907 r
.20775 .36392 .20891 .36504 .21455 .36303 .21338 .3619 Metetra
.807 .334 0 r
.21338 .3619 .21455 .36303 .21694 .39502 .21806 .37 Metetra
.591 .374 .554 r
.21806 .37 .21694 .39502 .22586 .35898 .2247 .35785 Metetra
.664 .741 .907 r
.2247 .35785 .22586 .35898 .23153 .35696 .23037 .35582 Metetra
.664 .741 .907 r
.23037 .35582 .23153 .35696 .23722 .35493 .23606 .35379 Metetra
.664 .741 .907 r
.23606 .35379 .23722 .35493 .24292 .35289 .24176 .35175 Metetra
.664 .741 .907 r
.24176 .35175 .24292 .35289 .24863 .35085 .24747 .34971 Metetra
.664 .741 .907 r
.24747 .34971 .24863 .35085 .25435 .3488 .2532 .34766 Metetra
.664 .741 .907 r
.2532 .34766 .25435 .3488 .26008 .34675 .25893 .34561 Metetra
.664 .741 .907 r
.25893 .34561 .26008 .34675 .26583 .3447 .26468 .34355 Metetra
.664 .741 .907 r
.26468 .34355 .26583 .3447 .27159 .34264 .27045 .34149 Metetra
.664 .741 .907 r
.27045 .34149 .27159 .34264 .27736 .34058 .27622 .33942 Metetra
.664 .741 .907 r
.27622 .33942 .27736 .34058 .28315 .33851 .28201 .33735 Metetra
.664 .741 .907 r
.28201 .33735 .28315 .33851 .28895 .33644 .28781 .33528 Metetra
.664 .741 .907 r
.28781 .33528 .28895 .33644 .29476 .33436 .29362 .3332 Metetra
.664 .741 .907 r
.29362 .3332 .29476 .33436 .30058 .33228 .29945 .33112 Metetra
.664 .741 .907 r
.29945 .33112 .30058 .33228 .30642 .33019 .30529 .32903 Metetra
.664 .741 .907 r
.30529 .32903 .30642 .33019 .31227 .3281 .31114 .32693 Metetra
.664 .741 .907 r
.31114 .32693 .31227 .3281 .31813 .32601 .31701 .32484 Metetra
.664 .741 .907 r
.31701 .32484 .31813 .32601 .32401 .32391 .32289 .32273 Metetra
.664 .741 .907 r
.32289 .32273 .32401 .32391 .3299 .3218 .32878 .32063 Metetra
.664 .741 .907 r
.32878 .32063 .3299 .3218 .3358 .31969 .33468 .31851 Metetra
.664 .741 .907 r
.33468 .31851 .3358 .31969 .34163 .31913 .3406 .3164 Metetra
.628 .554 .752 r
.3406 .3164 .34163 .31913 .34765 .31546 .34653 .31428 Metetra
.664 .741 .907 r
.34653 .31428 .34765 .31546 .35359 .31334 .35248 .31215 Metetra
.664 .741 .907 r
.35248 .31215 .35359 .31334 .35954 .31121 .35843 .31002 Metetra
.664 .741 .907 r
.35843 .31002 .35954 .31121 .36551 .30907 .3644 .30788 Metetra
.664 .741 .907 r
.3644 .30788 .36551 .30907 .37149 .30694 .37039 .30574 Metetra
.664 .741 .907 r
.37039 .30574 .37149 .30694 .37749 .30479 .37639 .3036 Metetra
.664 .741 .907 r
.37639 .3036 .37749 .30479 .3835 .30265 .3824 .30145 Metetra
.664 .741 .907 r
.3824 .30145 .3835 .30265 .38952 .30049 .38842 .29929 Metetra
.664 .741 .907 r
.38842 .29929 .38952 .30049 .39555 .29834 .39446 .29713 Metetra
.962 .674 .442 r
.39446 .29713 .39555 .29834 .4016 .29617 .39461 .44297 Metetra
.382 .182 .479 r
.39461 .44297 .4016 .29617 .40767 .29401 .40619 .30309 Metetra
.29 .048 .363 r
.40619 .30309 .40767 .29401 .41374 .29184 .41266 .29062 Metetra
.664 .741 .907 r
.41266 .29062 .41374 .29184 .41983 .28966 .41875 .28844 Metetra
.664 .741 .907 r
.41875 .28844 .41983 .28966 .42594 .28748 .42486 .28626 Metetra
.664 .741 .907 r
.42486 .28626 .42594 .28748 .43206 .28529 .43098 .28407 Metetra
.664 .741 .907 r
.43098 .28407 .43206 .28529 .43819 .2831 .43711 .28188 Metetra
.664 .741 .907 r
.43711 .28188 .43819 .2831 .44433 .2809 .44326 .27968 Metetra
.664 .741 .907 r
.44326 .27968 .44433 .2809 .45049 .2787 .44942 .27747 Metetra
.664 .741 .907 r
.44942 .27747 .45049 .2787 .45667 .2765 .4556 .27526 Metetra
.664 .741 .907 r
.4556 .27526 .45667 .2765 .46285 .27428 .46179 .27305 Metetra
.664 .741 .907 r
.46179 .27305 .46285 .27428 .46906 .27207 .46799 .27083 Metetra
.664 .741 .907 r
.46799 .27083 .46906 .27207 .47527 .26985 .47421 .2686 Metetra
.664 .741 .907 r
.47421 .2686 .47527 .26985 .4815 .26762 .48045 .26638 Metetra
.664 .741 .907 r
.48045 .26638 .4815 .26762 .48775 .26539 .48669 .26414 Metetra
.664 .741 .907 r
.48669 .26414 .48775 .26539 .49401 .26315 .49295 .2619 Metetra
.664 .741 .907 r
.49295 .2619 .49401 .26315 .50028 .26091 .49923 .25966 Metetra
.664 .741 .907 r
.49923 .25966 .50028 .26091 .50657 .25866 .50552 .25741 Metetra
.664 .741 .907 r
.50552 .25741 .50657 .25866 .51287 .25641 .51183 .25515 Metetra
.664 .741 .907 r
.51183 .25515 .51287 .25641 .51919 .25415 .51815 .25289 Metetra
.664 .741 .907 r
.51815 .25289 .51919 .25415 .52552 .25189 .52448 .25062 Metetra
.664 .741 .907 r
.52448 .25062 .52552 .25189 .53186 .24962 .53083 .24835 Metetra
.664 .741 .907 r
.53083 .24835 .53186 .24962 .53822 .24735 .53719 .24608 Metetra
.664 .741 .907 r
.53719 .24608 .53822 .24735 .5446 .24507 .54357 .2438 Metetra
.664 .741 .907 r
.54357 .2438 .5446 .24507 .55099 .24279 .54996 .24151 Metetra
.664 .741 .907 r
.54996 .24151 .55099 .24279 .55739 .2405 .55637 .23922 Metetra
.664 .741 .907 r
.55637 .23922 .55739 .2405 .56381 .2382 .56279 .23692 Metetra
.664 .741 .907 r
.56279 .23692 .56381 .2382 .57025 .2359 .56923 .23462 Metetra
.664 .741 .907 r
.56923 .23462 .57025 .2359 .5767 .2336 .57568 .23231 Metetra
.664 .741 .907 r
.57568 .23231 .5767 .2336 .58316 .23129 .58215 .23 Metetra
.664 .741 .907 r
.58215 .23 .58316 .23129 .58964 .22897 .58863 .22768 Metetra
.664 .741 .907 r
.58863 .22768 .58964 .22897 .59614 .22665 .59513 .22535 Metetra
.664 .741 .907 r
.59513 .22535 .59614 .22665 .60265 .22432 .60164 .22302 Metetra
.664 .741 .907 r
.60164 .22302 .60265 .22432 .60917 .22199 .60817 .22069 Metetra
.664 .741 .907 r
.60817 .22069 .60917 .22199 .61571 .21965 .61472 .21835 Metetra
.664 .741 .907 r
.61472 .21835 .61571 .21965 .62227 .21731 .62127 .216 Metetra
.664 .741 .907 r
.62127 .216 .62227 .21731 .62884 .21496 .62785 .21365 Metetra
.664 .741 .907 r
.62785 .21365 .62884 .21496 .63542 .21261 .63444 .21129 Metetra
.664 .741 .907 r
.63444 .21129 .63542 .21261 .64203 .21025 .64104 .20893 Metetra
.664 .741 .907 r
.64104 .20893 .64203 .21025 .64864 .20788 .64766 .20656 Metetra
.664 .741 .907 r
.64766 .20656 .64864 .20788 .65528 .20551 .6543 .20419 Metetra
.664 .741 .907 r
.6543 .20419 .65528 .20551 .66193 .20314 .66095 .20181 Metetra
.664 .741 .907 r
.66095 .20181 .66193 .20314 .66859 .20076 .66762 .19942 Metetra
.664 .741 .907 r
.66762 .19942 .66859 .20076 .67527 .19837 .6743 .19703 Metetra
.664 .741 .907 r
.6743 .19703 .67527 .19837 .68197 .19597 .681 .19464 Metetra
.664 .741 .907 r
.681 .19464 .68197 .19597 .68868 .19358 .68772 .19224 Metetra
.664 .741 .907 r
.68772 .19224 .68868 .19358 .69541 .19117 .69445 .18983 Metetra
.664 .741 .907 r
.69445 .18983 .69541 .19117 .70215 .18876 .7012 .18741 Metetra
.664 .741 .907 r
.7012 .18741 .70215 .18876 .70891 .18634 .70796 .18499 Metetra
.664 .741 .907 r
.70796 .18499 .70891 .18634 .71569 .18392 .71474 .18257 Metetra
.897 .513 .068 r
.71474 .18257 .71569 .18392 .72248 .1815 .72364 .21227 Metetra
.568 .315 .493 r
.72364 .21227 .72248 .1815 .72929 .17906 .73157 .22514 Metetra
.386 .186 .482 r
.73157 .22514 .72929 .17906 .73611 .17662 .73518 .17526 Metetra
.664 .741 .907 r
.73518 .17526 .73611 .17662 .74296 .17418 .74202 .17281 Metetra
.664 .741 .907 r
.74202 .17281 .74296 .17418 .74981 .17173 .74888 .17036 Metetra
.664 .741 .907 r
.74888 .17036 .74981 .17173 .75669 .16927 .75576 .1679 Metetra
.664 .741 .907 r
.75576 .1679 .75669 .16927 .76358 .16681 .76266 .16543 Metetra
.664 .741 .907 r
.76266 .16543 .76358 .16681 .77048 .16434 .76957 .16296 Metetra
.664 .741 .907 r
.76957 .16296 .77048 .16434 .77741 .16186 .77649 .16048 Metetra
.664 .741 .907 r
.77649 .16048 .77741 .16186 .78435 .15938 .78344 .158 Metetra
.664 .741 .907 r
.78344 .158 .78435 .15938 .79131 .1569 .7904 .15551 Metetra
.664 .741 .907 r
.16743 .37681 .16862 .37791 .17417 .37593 .17299 .37482 Metetra
.664 .741 .907 r
.17299 .37482 .17417 .37593 .17974 .37394 .17856 .37282 Metetra
.664 .741 .907 r
.17856 .37282 .17974 .37394 .18532 .37194 .18414 .37083 Metetra
.664 .741 .907 r
.18414 .37083 .18532 .37194 .1909 .36994 .18973 .36882 Metetra
.664 .741 .907 r
.18973 .36882 .1909 .36994 .19651 .36794 .19533 .36682 Metetra
.664 .741 .907 r
.19533 .36682 .19651 .36794 .20212 .36593 .20095 .36481 Metetra
.664 .741 .907 r
.20095 .36481 .20212 .36593 .20775 .36392 .20657 .36279 Metetra
.664 .741 .907 r
.20657 .36279 .20775 .36392 .21338 .3619 .21221 .36077 Metetra
.664 .741 .907 r
.21221 .36077 .21338 .3619 .21806 .37 .21787 .35875 Metetra
.56 .371 .583 r
.21787 .35875 .21806 .37 .2247 .35785 .22353 .35672 Metetra
.664 .741 .907 r
.22353 .35672 .2247 .35785 .23037 .35582 .22921 .35469 Metetra
.664 .741 .907 r
.22921 .35469 .23037 .35582 .23606 .35379 .2349 .35265 Metetra
.664 .741 .907 r
.2349 .35265 .23606 .35379 .24176 .35175 .2406 .35061 Metetra
.664 .741 .907 r
.2406 .35061 .24176 .35175 .24747 .34971 .24632 .34857 Metetra
.664 .741 .907 r
.24632 .34857 .24747 .34971 .2532 .34766 .25204 .34652 Metetra
.664 .741 .907 r
.25204 .34652 .2532 .34766 .25893 .34561 .25778 .34446 Metetra
.664 .741 .907 r
.25778 .34446 .25893 .34561 .26468 .34355 .26353 .3424 Metetra
.664 .741 .907 r
.26353 .3424 .26468 .34355 .27045 .34149 .2693 .34034 Metetra
.664 .741 .907 r
.2693 .34034 .27045 .34149 .27622 .33942 .27508 .33827 Metetra
.664 .741 .907 r
.27508 .33827 .27622 .33942 .28201 .33735 .28087 .3362 Metetra
.664 .741 .907 r
.28087 .3362 .28201 .33735 .28781 .33528 .28667 .33412 Metetra
.664 .741 .907 r
.28667 .33412 .28781 .33528 .29362 .3332 .29249 .33204 Metetra
.664 .741 .907 r
.29249 .33204 .29362 .3332 .29945 .33112 .29832 .32995 Metetra
.664 .741 .907 r
.29832 .32995 .29945 .33112 .30529 .32903 .30416 .32786 Metetra
.664 .741 .907 r
.30416 .32786 .30529 .32903 .31114 .32693 .31001 .32576 Metetra
.664 .741 .907 r
.31001 .32576 .31114 .32693 .31701 .32484 .31588 .32366 Metetra
.664 .741 .907 r
.31588 .32366 .31701 .32484 .32289 .32273 .32176 .32156 Metetra
.664 .741 .907 r
.32176 .32156 .32289 .32273 .32878 .32063 .32765 .31945 Metetra
.664 .741 .907 r
.32765 .31945 .32878 .32063 .33468 .31851 .33356 .31733 Metetra
.664 .741 .907 r
.33356 .31733 .33468 .31851 .3406 .3164 .33948 .31521 Metetra
.664 .741 .907 r
.33948 .31521 .3406 .3164 .34653 .31428 .34542 .31309 Metetra
.664 .741 .907 r
.34542 .31309 .34653 .31428 .35248 .31215 .35136 .31096 Metetra
.664 .741 .907 r
.35136 .31096 .35248 .31215 .35843 .31002 .35732 .30883 Metetra
.664 .741 .907 r
.35732 .30883 .35843 .31002 .3644 .30788 .3633 .30669 Metetra
.664 .741 .907 r
.3633 .30669 .3644 .30788 .37039 .30574 .36928 .30455 Metetra
.664 .741 .907 r
.36928 .30455 .37039 .30574 .37639 .3036 .37528 .3024 Metetra
.664 .741 .907 r
.37528 .3024 .37639 .3036 .3824 .30145 .3813 .30025 Metetra
.664 .741 .907 r
.3813 .30025 .3824 .30145 .38842 .29929 .38732 .29809 Metetra
.901 .49 .107 r
.38732 .29809 .38842 .29929 .39446 .29713 .39264 .31315 Metetra
.89 .607 .5 r
.39264 .31315 .39446 .29713 .39461 .44297 .39006 .52617 Metetra
0 0 .313 r
.39006 .52617 .39461 .44297 .40619 .30309 .40506 .30263 Metetra
.944 .831 .703 r
.40506 .30263 .40619 .30309 .41266 .29062 .41157 .28941 Metetra
.664 .741 .907 r
.41157 .28941 .41266 .29062 .41875 .28844 .41766 .28723 Metetra
.664 .741 .907 r
.41766 .28723 .41875 .28844 .42486 .28626 .42377 .28504 Metetra
.664 .741 .907 r
.42377 .28504 .42486 .28626 .43098 .28407 .4299 .28285 Metetra
.664 .741 .907 r
.4299 .28285 .43098 .28407 .43711 .28188 .43603 .28065 Metetra
.664 .741 .907 r
.43603 .28065 .43711 .28188 .44326 .27968 .44218 .27845 Metetra
.664 .741 .907 r
.44218 .27845 .44326 .27968 .44942 .27747 .44835 .27624 Metetra
.664 .741 .907 r
.44835 .27624 .44942 .27747 .4556 .27526 .45453 .27403 Metetra
.664 .741 .907 r
.45453 .27403 .4556 .27526 .46179 .27305 .46072 .27181 Metetra
.664 .741 .907 r
.46072 .27181 .46179 .27305 .46799 .27083 .46693 .26959 Metetra
.664 .741 .907 r
.46693 .26959 .46799 .27083 .47421 .2686 .47315 .26736 Metetra
.664 .741 .907 r
.47315 .26736 .47421 .2686 .48045 .26638 .47939 .26513 Metetra
.664 .741 .907 r
.47939 .26513 .48045 .26638 .48669 .26414 .48564 .26289 Metetra
.664 .741 .907 r
.48564 .26289 .48669 .26414 .49295 .2619 .4919 .26065 Metetra
.664 .741 .907 r
.4919 .26065 .49295 .2619 .49923 .25966 .49818 .2584 Metetra
.664 .741 .907 r
.49818 .2584 .49923 .25966 .50552 .25741 .50447 .25615 Metetra
.664 .741 .907 r
.50447 .25615 .50552 .25741 .51183 .25515 .51078 .25389 Metetra
.664 .741 .907 r
.51078 .25389 .51183 .25515 .51815 .25289 .5171 .25163 Metetra
.664 .741 .907 r
.5171 .25163 .51815 .25289 .52448 .25062 .52344 .24936 Metetra
.664 .741 .907 r
.52344 .24936 .52448 .25062 .53083 .24835 .52979 .24708 Metetra
.664 .741 .907 r
.52979 .24708 .53083 .24835 .53719 .24608 .53616 .24481 Metetra
.664 .741 .907 r
.53616 .24481 .53719 .24608 .54357 .2438 .54254 .24252 Metetra
.664 .741 .907 r
.54254 .24252 .54357 .2438 .54996 .24151 .54894 .24023 Metetra
.664 .741 .907 r
.54894 .24023 .54996 .24151 .55637 .23922 .55535 .23794 Metetra
.664 .741 .907 r
.55535 .23794 .55637 .23922 .56279 .23692 .56177 .23564 Metetra
.664 .741 .907 r
.56177 .23564 .56279 .23692 .56923 .23462 .56821 .23333 Metetra
.664 .741 .907 r
.56821 .23333 .56923 .23462 .57568 .23231 .57467 .23102 Metetra
.664 .741 .907 r
.57467 .23102 .57568 .23231 .58215 .23 .58114 .2287 Metetra
.664 .741 .907 r
.58114 .2287 .58215 .23 .58863 .22768 .58762 .22638 Metetra
.664 .741 .907 r
.58762 .22638 .58863 .22768 .59513 .22535 .59412 .22405 Metetra
.664 .741 .907 r
.59412 .22405 .59513 .22535 .60164 .22302 .60064 .22172 Metetra
.664 .741 .907 r
.60064 .22172 .60164 .22302 .60817 .22069 .60717 .21938 Metetra
.664 .741 .907 r
.60717 .21938 .60817 .22069 .61472 .21835 .61372 .21704 Metetra
.664 .741 .907 r
.61372 .21704 .61472 .21835 .62127 .216 .62028 .21469 Metetra
.664 .741 .907 r
.62028 .21469 .62127 .216 .62785 .21365 .62686 .21234 Metetra
.664 .741 .907 r
.62686 .21234 .62785 .21365 .63444 .21129 .63345 .20998 Metetra
.664 .741 .907 r
.63345 .20998 .63444 .21129 .64104 .20893 .64006 .20761 Metetra
.664 .741 .907 r
.64006 .20761 .64104 .20893 .64766 .20656 .64668 .20524 Metetra
.664 .741 .907 r
.64668 .20524 .64766 .20656 .6543 .20419 .65332 .20286 Metetra
.664 .741 .907 r
.65332 .20286 .6543 .20419 .66095 .20181 .65998 .20048 Metetra
.664 .741 .907 r
.65998 .20048 .66095 .20181 .66762 .19942 .66665 .19809 Metetra
.664 .741 .907 r
.66665 .19809 .66762 .19942 .6743 .19703 .67334 .1957 Metetra
.664 .741 .907 r
.67334 .1957 .6743 .19703 .681 .19464 .68004 .1933 Metetra
.664 .741 .907 r
.68004 .1933 .681 .19464 .68772 .19224 .68676 .19089 Metetra
.664 .741 .907 r
.68676 .19089 .68772 .19224 .69445 .18983 .69349 .18848 Metetra
.664 .741 .907 r
.69349 .18848 .69445 .18983 .7012 .18741 .70024 .18607 Metetra
.392 .606 .934 r
.70024 .18607 .7012 .18741 .70796 .18499 .70721 .18701 Metetra
.052 0 .005 r
.70721 .18701 .70796 .18499 .71474 .18257 .71379 .18121 Metetra
.664 .741 .907 r
.71379 .18121 .71474 .18257 .72364 .21227 .72059 .17878 Metetra
.288 .147 .509 r
.72059 .17878 .72364 .21227 .73157 .22514 .73148 .23661 Metetra
0 0 .16 r
.73148 .23661 .73157 .22514 .73518 .17526 .73424 .1739 Metetra
.664 .741 .907 r
.73424 .1739 .73518 .17526 .74202 .17281 .74109 .17144 Metetra
.664 .741 .907 r
.74109 .17144 .74202 .17281 .74888 .17036 .74795 .16899 Metetra
.664 .741 .907 r
.74795 .16899 .74888 .17036 .75576 .1679 .75483 .16652 Metetra
.664 .741 .907 r
.75483 .16652 .75576 .1679 .76266 .16543 .76173 .16405 Metetra
.664 .741 .907 r
.76173 .16405 .76266 .16543 .76957 .16296 .76865 .16158 Metetra
.664 .741 .907 r
.76865 .16158 .76957 .16296 .77649 .16048 .77558 .1591 Metetra
.664 .741 .907 r
.77558 .1591 .77649 .16048 .78344 .158 .78252 .15661 Metetra
.664 .741 .907 r
.78252 .15661 .78344 .158 .7904 .15551 .78949 .15412 Metetra
.664 .741 .907 r
.16625 .3757 .16743 .37681 .17299 .37482 .1718 .37371 Metetra
.664 .741 .907 r
.1718 .37371 .17299 .37482 .17856 .37282 .17737 .37171 Metetra
.664 .741 .907 r
.17737 .37171 .17856 .37282 .18414 .37083 .18295 .36971 Metetra
.664 .741 .907 r
.18295 .36971 .18414 .37083 .18973 .36882 .18855 .36771 Metetra
.664 .741 .907 r
.18855 .36771 .18973 .36882 .19533 .36682 .19415 .3657 Metetra
.664 .741 .907 r
.19415 .3657 .19533 .36682 .20095 .36481 .19977 .36369 Metetra
.664 .741 .907 r
.19977 .36369 .20095 .36481 .20657 .36279 .2054 .36167 Metetra
.664 .741 .907 r
.2054 .36167 .20657 .36279 .21221 .36077 .21104 .35965 Metetra
.664 .741 .907 r
.21104 .35965 .21221 .36077 .21787 .35875 .2167 .35762 Metetra
.664 .741 .907 r
.2167 .35762 .21787 .35875 .22353 .35672 .22237 .35559 Metetra
.664 .741 .907 r
.22237 .35559 .22353 .35672 .22921 .35469 .22805 .35356 Metetra
.664 .741 .907 r
.22805 .35356 .22921 .35469 .2349 .35265 .23374 .35152 Metetra
.664 .741 .907 r
.23374 .35152 .2349 .35265 .2406 .35061 .23944 .34947 Metetra
.664 .741 .907 r
.23944 .34947 .2406 .35061 .24632 .34857 .24516 .34742 Metetra
.664 .741 .907 r
.24516 .34742 .24632 .34857 .25204 .34652 .25089 .34537 Metetra
.664 .741 .907 r
.25089 .34537 .25204 .34652 .25778 .34446 .25663 .34331 Metetra
.664 .741 .907 r
.25663 .34331 .25778 .34446 .26353 .3424 .26238 .34125 Metetra
.664 .741 .907 r
.26238 .34125 .26353 .3424 .2693 .34034 .26815 .33919 Metetra
.664 .741 .907 r
.26815 .33919 .2693 .34034 .27508 .33827 .27393 .33711 Metetra
.664 .741 .907 r
.27393 .33711 .27508 .33827 .28087 .3362 .27972 .33504 Metetra
.664 .741 .907 r
.27972 .33504 .28087 .3362 .28667 .33412 .28553 .33296 Metetra
.664 .741 .907 r
.28553 .33296 .28667 .33412 .29249 .33204 .29135 .33087 Metetra
.664 .741 .907 r
.29135 .33087 .29249 .33204 .29832 .32995 .29718 .32879 Metetra
.664 .741 .907 r
.29718 .32879 .29832 .32995 .30416 .32786 .30302 .32669 Metetra
.664 .741 .907 r
.30302 .32669 .30416 .32786 .31001 .32576 .30888 .32459 Metetra
.664 .741 .907 r
.30888 .32459 .31001 .32576 .31588 .32366 .31475 .32249 Metetra
.664 .741 .907 r
.31475 .32249 .31588 .32366 .32176 .32156 .32063 .32038 Metetra
.664 .741 .907 r
.32063 .32038 .32176 .32156 .32765 .31945 .32653 .31827 Metetra
.664 .741 .907 r
.32653 .31827 .32765 .31945 .33356 .31733 .33244 .31615 Metetra
.664 .741 .907 r
.33244 .31615 .33356 .31733 .33948 .31521 .33836 .31403 Metetra
.664 .741 .907 r
.33836 .31403 .33948 .31521 .34542 .31309 .3443 .3119 Metetra
.664 .741 .907 r
.3443 .3119 .34542 .31309 .35136 .31096 .35025 .30977 Metetra
.664 .741 .907 r
.35025 .30977 .35136 .31096 .35732 .30883 .35621 .30764 Metetra
.664 .741 .907 r
.35621 .30764 .35732 .30883 .3633 .30669 .36219 .30549 Metetra
.664 .741 .907 r
.36219 .30549 .3633 .30669 .36928 .30455 .36817 .30335 Metetra
.664 .741 .907 r
.36817 .30335 .36928 .30455 .37528 .3024 .37418 .3012 Metetra
.664 .741 .907 r
.37418 .3012 .37528 .3024 .3813 .30025 .38019 .29904 Metetra
.664 .741 .907 r
.38019 .29904 .3813 .30025 .38732 .29809 .38622 .29688 Metetra
.961 .658 .408 r
.38622 .29688 .38732 .29809 .39264 .31315 .38925 .3656 Metetra
.742 .474 .525 r
.38925 .3656 .39264 .31315 .39006 .52617 .38888 .52503 Metetra
.96 .696 .489 r
.38888 .52503 .39006 .52617 .40506 .30263 .40439 .29037 Metetra
.558 .367 .578 r
.40439 .29037 .40506 .30263 .41157 .28941 .41048 .28819 Metetra
.664 .741 .907 r
.41048 .28819 .41157 .28941 .41766 .28723 .41658 .28601 Metetra
.664 .741 .907 r
.41658 .28601 .41766 .28723 .42377 .28504 .42269 .28382 Metetra
.664 .741 .907 r
.42269 .28382 .42377 .28504 .4299 .28285 .42882 .28162 Metetra
.664 .741 .907 r
.42882 .28162 .4299 .28285 .43603 .28065 .43495 .27942 Metetra
.664 .741 .907 r
.43495 .27942 .43603 .28065 .44218 .27845 .44111 .27722 Metetra
.664 .741 .907 r
.44111 .27722 .44218 .27845 .44835 .27624 .44728 .27501 Metetra
.664 .741 .907 r
.44728 .27501 .44835 .27624 .45453 .27403 .45346 .27279 Metetra
.664 .741 .907 r
.45346 .27279 .45453 .27403 .46072 .27181 .45965 .27057 Metetra
.664 .741 .907 r
.45965 .27057 .46072 .27181 .46693 .26959 .46586 .26835 Metetra
.664 .741 .907 r
.46586 .26835 .46693 .26959 .47315 .26736 .47209 .26612 Metetra
.664 .741 .907 r
.47209 .26612 .47315 .26736 .47939 .26513 .47833 .26388 Metetra
.664 .741 .907 r
.47833 .26388 .47939 .26513 .48564 .26289 .48458 .26164 Metetra
.664 .741 .907 r
.48458 .26164 .48564 .26289 .4919 .26065 .49085 .2594 Metetra
.664 .741 .907 r
.49085 .2594 .4919 .26065 .49818 .2584 .49713 .25715 Metetra
.664 .741 .907 r
.49713 .25715 .49818 .2584 .50447 .25615 .50343 .25489 Metetra
.664 .741 .907 r
.50343 .25489 .50447 .25615 .51078 .25389 .50974 .25263 Metetra
.664 .741 .907 r
.50974 .25263 .51078 .25389 .5171 .25163 .51606 .25036 Metetra
.664 .741 .907 r
.51606 .25036 .5171 .25163 .52344 .24936 .5224 .24809 Metetra
.664 .741 .907 r
.5224 .24809 .52344 .24936 .52979 .24708 .52876 .24581 Metetra
.664 .741 .907 r
.52876 .24581 .52979 .24708 .53616 .24481 .53512 .24353 Metetra
.664 .741 .907 r
.53512 .24353 .53616 .24481 .54254 .24252 .54151 .24125 Metetra
.664 .741 .907 r
.54151 .24125 .54254 .24252 .54894 .24023 .54791 .23895 Metetra
.664 .741 .907 r
.54791 .23895 .54894 .24023 .55535 .23794 .55432 .23665 Metetra
.664 .741 .907 r
.55432 .23665 .55535 .23794 .56177 .23564 .56075 .23435 Metetra
.664 .741 .907 r
.56075 .23435 .56177 .23564 .56821 .23333 .56719 .23204 Metetra
.664 .741 .907 r
.56719 .23204 .56821 .23333 .57467 .23102 .57365 .22973 Metetra
.664 .741 .907 r
.57365 .22973 .57467 .23102 .58114 .2287 .58012 .22741 Metetra
.664 .741 .907 r
.58012 .22741 .58114 .2287 .58762 .22638 .58661 .22508 Metetra
.664 .741 .907 r
.58661 .22508 .58762 .22638 .59412 .22405 .59312 .22275 Metetra
.664 .741 .907 r
.59312 .22275 .59412 .22405 .60064 .22172 .59964 .22042 Metetra
.664 .741 .907 r
.59964 .22042 .60064 .22172 .60717 .21938 .60617 .21808 Metetra
.664 .741 .907 r
.60617 .21808 .60717 .21938 .61372 .21704 .61272 .21573 Metetra
.664 .741 .907 r
.61272 .21573 .61372 .21704 .62028 .21469 .61929 .21338 Metetra
.664 .741 .907 r
.61929 .21338 .62028 .21469 .62686 .21234 .62587 .21102 Metetra
.664 .741 .907 r
.62587 .21102 .62686 .21234 .63345 .20998 .63246 .20866 Metetra
.664 .741 .907 r
.63246 .20866 .63345 .20998 .64006 .20761 .63907 .20629 Metetra
.664 .741 .907 r
.63907 .20629 .64006 .20761 .64668 .20524 .6457 .20391 Metetra
.664 .741 .907 r
.6457 .20391 .64668 .20524 .65332 .20286 .65234 .20153 Metetra
.664 .741 .907 r
.65234 .20153 .65332 .20286 .65998 .20048 .659 .19915 Metetra
.664 .741 .907 r
.659 .19915 .65998 .20048 .66665 .19809 .66568 .19676 Metetra
.664 .741 .907 r
.66568 .19676 .66665 .19809 .67334 .1957 .67237 .19436 Metetra
.664 .741 .907 r
.67237 .19436 .67334 .1957 .68004 .1933 .67907 .19196 Metetra
.664 .741 .907 r
.67907 .19196 .68004 .1933 .68676 .19089 .68579 .18955 Metetra
.664 .741 .907 r
.68579 .18955 .68676 .19089 .69349 .18848 .69253 .18713 Metetra
.664 .741 .907 r
.69253 .18713 .69349 .18848 .70024 .18607 .69929 .18472 Metetra
0 .001 .549 r
.69929 .18472 .70024 .18607 .70721 .18701 .70671 .19317 Metetra
.193 0 .313 r
.70671 .19317 .70721 .18701 .71379 .18121 .71284 .17986 Metetra
.664 .741 .907 r
.71284 .17986 .71379 .18121 .72059 .17878 .71965 .17742 Metetra
.664 .741 .907 r
.71965 .17742 .72059 .17878 .73148 .23661 .72647 .17498 Metetra
.535 .316 .529 r
.72647 .17498 .73148 .23661 .73424 .1739 .7333 .17253 Metetra
.664 .741 .907 r
.7333 .17253 .73424 .1739 .74109 .17144 .74015 .17007 Metetra
.664 .741 .907 r
.74015 .17007 .74109 .17144 .74795 .16899 .74702 .16761 Metetra
.664 .741 .907 r
.74702 .16761 .74795 .16899 .75483 .16652 .7539 .16515 Metetra
.664 .741 .907 r
.7539 .16515 .75483 .16652 .76173 .16405 .76081 .16267 Metetra
.664 .741 .907 r
.76081 .16267 .76173 .16405 .76865 .16158 .76772 .16019 Metetra
.664 .741 .907 r
.76772 .16019 .76865 .16158 .77558 .1591 .77466 .15771 Metetra
.664 .741 .907 r
.77466 .15771 .77558 .1591 .78252 .15661 .78161 .15522 Metetra
.664 .741 .907 r
.78161 .15522 .78252 .15661 .78949 .15412 .78858 .15272 Metetra
.664 .741 .907 r
.16506 .37459 .16625 .3757 .1718 .37371 .17062 .37259 Metetra
.664 .741 .907 r
.17062 .37259 .1718 .37371 .17737 .37171 .17619 .3706 Metetra
.664 .741 .907 r
.17619 .3706 .17737 .37171 .18295 .36971 .18177 .36859 Metetra
.664 .741 .907 r
.18177 .36859 .18295 .36971 .18855 .36771 .18737 .36659 Metetra
.664 .741 .907 r
.18737 .36659 .18855 .36771 .19415 .3657 .19298 .36458 Metetra
.664 .741 .907 r
.19298 .36458 .19415 .3657 .19977 .36369 .1986 .36256 Metetra
.664 .741 .907 r
.1986 .36256 .19977 .36369 .2054 .36167 .20423 .36054 Metetra
.664 .741 .907 r
.20423 .36054 .2054 .36167 .21104 .35965 .20987 .35852 Metetra
.664 .741 .907 r
.20987 .35852 .21104 .35965 .2167 .35762 .21553 .35649 Metetra
.664 .741 .907 r
.21553 .35649 .2167 .35762 .22237 .35559 .2212 .35446 Metetra
.664 .741 .907 r
.2212 .35446 .22237 .35559 .22805 .35356 .22688 .35242 Metetra
.664 .741 .907 r
.22688 .35242 .22805 .35356 .23374 .35152 .23257 .35038 Metetra
.664 .741 .907 r
.23257 .35038 .23374 .35152 .23944 .34947 .23828 .34833 Metetra
.676 .177 0 r
.23828 .34833 .23944 .34947 .24516 .34742 .24325 .35478 Metetra
.523 .236 .419 r
.24325 .35478 .24516 .34742 .25089 .34537 .24875 .3555 Metetra
.275 .035 .356 r
.24875 .3555 .25089 .34537 .25663 .34331 .25548 .34216 Metetra
.664 .741 .907 r
.25548 .34216 .25663 .34331 .26238 .34125 .26123 .3401 Metetra
.664 .741 .907 r
.26123 .3401 .26238 .34125 .26815 .33919 .267 .33803 Metetra
.664 .741 .907 r
.267 .33803 .26815 .33919 .27393 .33711 .27278 .33596 Metetra
.664 .741 .907 r
.27278 .33596 .27393 .33711 .27972 .33504 .27858 .33388 Metetra
.664 .741 .907 r
.27858 .33388 .27972 .33504 .28553 .33296 .28439 .3318 Metetra
.664 .741 .907 r
.28439 .3318 .28553 .33296 .29135 .33087 .29021 .32971 Metetra
.664 .741 .907 r
.29021 .32971 .29135 .33087 .29718 .32879 .29604 .32762 Metetra
.664 .741 .907 r
.29604 .32762 .29718 .32879 .30302 .32669 .30189 .32552 Metetra
.664 .741 .907 r
.30189 .32552 .30302 .32669 .30888 .32459 .30775 .32342 Metetra
.664 .741 .907 r
.30775 .32342 .30888 .32459 .31475 .32249 .31362 .32131 Metetra
.664 .741 .907 r
.31362 .32131 .31475 .32249 .32063 .32038 .31951 .3192 Metetra
.664 .741 .907 r
.31951 .3192 .32063 .32038 .32653 .31827 .3254 .31709 Metetra
.664 .741 .907 r
.3254 .31709 .32653 .31827 .33244 .31615 .33132 .31497 Metetra
.664 .741 .907 r
.33132 .31497 .33244 .31615 .33836 .31403 .33724 .31284 Metetra
.664 .741 .907 r
.33724 .31284 .33836 .31403 .3443 .3119 .34318 .31071 Metetra
.664 .741 .907 r
.34318 .31071 .3443 .3119 .35025 .30977 .34913 .30858 Metetra
.664 .741 .907 r
.34913 .30858 .35025 .30977 .35621 .30764 .3551 .30644 Metetra
.664 .741 .907 r
.3551 .30644 .35621 .30764 .36219 .30549 .36107 .3043 Metetra
.664 .741 .907 r
.36107 .3043 .36219 .30549 .36817 .30335 .36707 .30215 Metetra
.664 .741 .907 r
.36707 .30215 .36817 .30335 .37418 .3012 .37307 .3 Metetra
.664 .741 .907 r
.37307 .3 .37418 .3012 .38019 .29904 .37909 .29784 Metetra
.664 .741 .907 r
.37909 .29784 .38019 .29904 .38622 .29688 .38512 .29567 Metetra
.961 .654 .4 r
.38512 .29567 .38622 .29688 .38925 .3656 .38842 .35752 Metetra
.877 .637 .112 r
.38842 .35752 .38925 .3656 .38888 .52503 .3922 .41398 Metetra
.65 .406 .537 r
.3922 .41398 .38888 .52503 .40439 .29037 .4033 .28916 Metetra
.664 .741 .907 r
.4033 .28916 .40439 .29037 .41048 .28819 .40939 .28697 Metetra
.664 .741 .907 r
.40939 .28697 .41048 .28819 .41658 .28601 .41549 .28479 Metetra
.664 .741 .907 r
.41549 .28479 .41658 .28601 .42269 .28382 .4216 .28259 Metetra
.664 .741 .907 r
.4216 .28259 .42269 .28382 .42882 .28162 .42773 .2804 Metetra
.664 .741 .907 r
.42773 .2804 .42882 .28162 .43495 .27942 .43387 .27819 Metetra
.664 .741 .907 r
.43387 .27819 .43495 .27942 .44111 .27722 .44003 .27599 Metetra
.664 .741 .907 r
.44003 .27599 .44111 .27722 .44728 .27501 .4462 .27377 Metetra
.664 .741 .907 r
.4462 .27377 .44728 .27501 .45346 .27279 .45239 .27155 Metetra
.664 .741 .907 r
.45239 .27155 .45346 .27279 .45965 .27057 .45858 .26933 Metetra
.664 .741 .907 r
.45858 .26933 .45965 .27057 .46586 .26835 .4648 .2671 Metetra
.664 .741 .907 r
.4648 .2671 .46586 .26835 .47209 .26612 .47102 .26487 Metetra
.664 .741 .907 r
.47102 .26487 .47209 .26612 .47833 .26388 .47727 .26263 Metetra
.664 .741 .907 r
.47727 .26263 .47833 .26388 .48458 .26164 .48352 .26039 Metetra
.664 .741 .907 r
.48352 .26039 .48458 .26164 .49085 .2594 .48979 .25814 Metetra
.664 .741 .907 r
.48979 .25814 .49085 .2594 .49713 .25715 .49608 .25589 Metetra
.664 .741 .907 r
.49608 .25589 .49713 .25715 .50343 .25489 .50238 .25363 Metetra
.664 .741 .907 r
.50238 .25363 .50343 .25489 .50974 .25263 .50869 .25137 Metetra
.664 .741 .907 r
.50869 .25137 .50974 .25263 .51606 .25036 .51502 .2491 Metetra
.664 .741 .907 r
.51502 .2491 .51606 .25036 .5224 .24809 .52136 .24682 Metetra
.664 .741 .907 r
.52136 .24682 .5224 .24809 .52876 .24581 .52772 .24454 Metetra
.664 .741 .907 r
.52772 .24454 .52876 .24581 .53512 .24353 .53409 .24226 Metetra
.664 .741 .907 r
.53409 .24226 .53512 .24353 .54151 .24125 .54048 .23997 Metetra
.664 .741 .907 r
.54048 .23997 .54151 .24125 .54791 .23895 .54688 .23767 Metetra
.664 .741 .907 r
.54688 .23767 .54791 .23895 .55432 .23665 .55329 .23537 Metetra
.664 .741 .907 r
.55329 .23537 .55432 .23665 .56075 .23435 .55973 .23306 Metetra
.664 .741 .907 r
.55973 .23306 .56075 .23435 .56719 .23204 .56617 .23075 Metetra
.664 .741 .907 r
.56617 .23075 .56719 .23204 .57365 .22973 .57263 .22844 Metetra
.664 .741 .907 r
.57263 .22844 .57365 .22973 .58012 .22741 .57911 .22611 Metetra
.664 .741 .907 r
.57911 .22611 .58012 .22741 .58661 .22508 .5856 .22379 Metetra
.664 .741 .907 r
.5856 .22379 .58661 .22508 .59312 .22275 .59211 .22145 Metetra
.664 .741 .907 r
.59211 .22145 .59312 .22275 .59964 .22042 .59863 .21911 Metetra
.664 .741 .907 r
.59863 .21911 .59964 .22042 .60617 .21808 .60517 .21677 Metetra
.664 .741 .907 r
.60517 .21677 .60617 .21808 .61272 .21573 .61172 .21442 Metetra
.664 .741 .907 r
.61172 .21442 .61272 .21573 .61929 .21338 .61829 .21206 Metetra
.664 .741 .907 r
.61829 .21206 .61929 .21338 .62587 .21102 .62487 .2097 Metetra
.664 .741 .907 r
.62487 .2097 .62587 .21102 .63246 .20866 .63147 .20734 Metetra
.664 .741 .907 r
.63147 .20734 .63246 .20866 .63907 .20629 .63809 .20497 Metetra
.664 .741 .907 r
.63809 .20497 .63907 .20629 .6457 .20391 .64472 .20259 Metetra
.664 .741 .907 r
.64472 .20259 .6457 .20391 .65234 .20153 .65136 .2002 Metetra
.664 .741 .907 r
.65136 .2002 .65234 .20153 .659 .19915 .65803 .19782 Metetra
.664 .741 .907 r
.65803 .19782 .659 .19915 .66568 .19676 .6647 .19542 Metetra
.664 .741 .907 r
.6647 .19542 .66568 .19676 .67237 .19436 .6714 .19302 Metetra
.664 .741 .907 r
.6714 .19302 .67237 .19436 .67907 .19196 .67811 .19061 Metetra
.664 .741 .907 r
.67811 .19061 .67907 .19196 .68579 .18955 .68483 .1882 Metetra
.664 .741 .907 r
.68483 .1882 .68579 .18955 .69253 .18713 .69157 .18579 Metetra
.664 .741 .907 r
.69157 .18579 .69253 .18713 .69929 .18472 .69833 .18336 Metetra
.664 .741 .907 r
.69833 .18336 .69929 .18472 .70671 .19317 .7051 .18093 Metetra
.558 .369 .58 r
.7051 .18093 .70671 .19317 .71284 .17986 .71189 .1785 Metetra
.664 .741 .907 r
.71189 .1785 .71284 .17986 .71965 .17742 .7187 .17606 Metetra
.664 .741 .907 r
.7187 .17606 .71965 .17742 .72647 .17498 .72552 .17361 Metetra
.664 .741 .907 r
.72552 .17361 .72647 .17498 .7333 .17253 .73236 .17116 Metetra
.664 .741 .907 r
.73236 .17116 .7333 .17253 .74015 .17007 .73922 .1687 Metetra
.664 .741 .907 r
.73922 .1687 .74015 .17007 .74702 .16761 .74609 .16624 Metetra
.664 .741 .907 r
.74609 .16624 .74702 .16761 .7539 .16515 .75298 .16377 Metetra
.664 .741 .907 r
.75298 .16377 .7539 .16515 .76081 .16267 .75988 .16129 Metetra
.664 .741 .907 r
.75988 .16129 .76081 .16267 .76772 .16019 .7668 .15881 Metetra
.664 .741 .907 r
.7668 .15881 .76772 .16019 .77466 .15771 .77374 .15632 Metetra
.664 .741 .907 r
.77374 .15632 .77466 .15771 .78161 .15522 .78069 .15383 Metetra
.664 .741 .907 r
.78069 .15383 .78161 .15522 .78858 .15272 .78767 .15133 Metetra
.664 .741 .907 r
.16387 .37348 .16506 .37459 .17062 .37259 .16943 .37148 Metetra
.664 .741 .907 r
.16943 .37148 .17062 .37259 .17619 .3706 .175 .36948 Metetra
.664 .741 .907 r
.175 .36948 .17619 .3706 .18177 .36859 .18059 .36747 Metetra
.664 .741 .907 r
.18059 .36747 .18177 .36859 .18737 .36659 .18619 .36547 Metetra
.664 .741 .907 r
.18619 .36547 .18737 .36659 .19298 .36458 .1918 .36345 Metetra
.664 .741 .907 r
.1918 .36345 .19298 .36458 .1986 .36256 .19742 .36143 Metetra
.664 .741 .907 r
.19742 .36143 .1986 .36256 .20423 .36054 .20305 .35941 Metetra
.664 .741 .907 r
.20305 .35941 .20423 .36054 .20987 .35852 .2087 .35739 Metetra
.664 .741 .907 r
.2087 .35739 .20987 .35852 .21553 .35649 .21436 .35536 Metetra
.664 .741 .907 r
.21436 .35536 .21553 .35649 .2212 .35446 .22003 .35332 Metetra
.664 .741 .907 r
.22003 .35332 .2212 .35446 .22688 .35242 .22571 .35128 Metetra
.664 .741 .907 r
.22571 .35128 .22688 .35242 .23257 .35038 .23141 .34924 Metetra
.664 .741 .907 r
.23141 .34924 .23257 .35038 .23828 .34833 .23712 .34719 Metetra
.948 .618 .367 r
.23712 .34719 .23828 .34833 .24325 .35478 .24026 .37416 Metetra
.201 .001 .37 r
.24026 .37416 .24325 .35478 .24875 .3555 .24857 .34308 Metetra
.557 .365 .576 r
.24857 .34308 .24875 .3555 .25548 .34216 .25432 .34101 Metetra
.664 .741 .907 r
.25432 .34101 .25548 .34216 .26123 .3401 .26008 .33895 Metetra
.664 .741 .907 r
.26008 .33895 .26123 .3401 .267 .33803 .26585 .33688 Metetra
.664 .741 .907 r
.26585 .33688 .267 .33803 .27278 .33596 .27164 .3348 Metetra
.664 .741 .907 r
.27164 .3348 .27278 .33596 .27858 .33388 .27743 .33272 Metetra
.664 .741 .907 r
.27743 .33272 .27858 .33388 .28439 .3318 .28324 .33063 Metetra
.664 .741 .907 r
.28324 .33063 .28439 .3318 .29021 .32971 .28907 .32854 Metetra
.664 .741 .907 r
.28907 .32854 .29021 .32971 .29604 .32762 .2949 .32645 Metetra
.664 .741 .907 r
.2949 .32645 .29604 .32762 .30189 .32552 .30075 .32435 Metetra
.664 .741 .907 r
.30075 .32435 .30189 .32552 .30775 .32342 .30661 .32225 Metetra
.664 .741 .907 r
.30661 .32225 .30775 .32342 .31362 .32131 .31249 .32014 Metetra
.664 .741 .907 r
.31249 .32014 .31362 .32131 .31951 .3192 .31838 .31802 Metetra
.664 .741 .907 r
.31838 .31802 .31951 .3192 .3254 .31709 .32428 .31591 Metetra
.664 .741 .907 r
.32428 .31591 .3254 .31709 .33132 .31497 .33019 .31378 Metetra
.664 .741 .907 r
.33019 .31378 .33132 .31497 .33724 .31284 .33612 .31166 Metetra
.664 .741 .907 r
.33612 .31166 .33724 .31284 .34318 .31071 .34206 .30953 Metetra
.664 .741 .907 r
.34206 .30953 .34318 .31071 .34913 .30858 .34801 .30739 Metetra
.664 .741 .907 r
.34801 .30739 .34913 .30858 .3551 .30644 .35398 .30525 Metetra
.664 .741 .907 r
.35398 .30525 .3551 .30644 .36107 .3043 .35996 .3031 Metetra
.664 .741 .907 r
.35996 .3031 .36107 .3043 .36707 .30215 .36596 .30095 Metetra
.664 .741 .907 r
.36596 .30095 .36707 .30215 .37307 .3 .37196 .29879 Metetra
.664 .741 .907 r
.37196 .29879 .37307 .3 .37909 .29784 .37798 .29663 Metetra
.664 .741 .907 r
.37798 .29663 .37909 .29784 .38512 .29567 .38402 .29447 Metetra
.664 .741 .907 r
.38402 .29447 .38512 .29567 .38842 .35752 .39007 .2923 Metetra
.412 .218 .504 r
.39007 .2923 .38842 .35752 .3922 .41398 .39394 .34305 Metetra
.616 .38 .537 r
.39394 .34305 .3922 .41398 .4033 .28916 .40221 .28794 Metetra
.664 .741 .907 r
.40221 .28794 .4033 .28916 .40939 .28697 .4083 .28575 Metetra
.664 .741 .907 r
.4083 .28575 .40939 .28697 .41549 .28479 .4144 .28356 Metetra
.664 .741 .907 r
.4144 .28356 .41549 .28479 .4216 .28259 .42052 .28137 Metetra
.664 .741 .907 r
.42052 .28137 .4216 .28259 .42773 .2804 .42665 .27917 Metetra
.664 .741 .907 r
.42665 .27917 .42773 .2804 .43387 .27819 .43279 .27696 Metetra
.664 .741 .907 r
.43279 .27696 .43387 .27819 .44003 .27599 .43895 .27475 Metetra
.664 .741 .907 r
.43895 .27475 .44003 .27599 .4462 .27377 .44513 .27254 Metetra
.664 .741 .907 r
.44513 .27254 .4462 .27377 .45239 .27155 .45131 .27032 Metetra
.664 .741 .907 r
.45131 .27032 .45239 .27155 .45858 .26933 .45751 .26809 Metetra
.664 .741 .907 r
.45751 .26809 .45858 .26933 .4648 .2671 .46373 .26586 Metetra
.664 .741 .907 r
.46373 .26586 .4648 .2671 .47102 .26487 .46996 .26362 Metetra
.664 .741 .907 r
.46996 .26362 .47102 .26487 .47727 .26263 .4762 .26138 Metetra
.664 .741 .907 r
.4762 .26138 .47727 .26263 .48352 .26039 .48246 .25914 Metetra
.664 .741 .907 r
.48246 .25914 .48352 .26039 .48979 .25814 .48873 .25689 Metetra
.664 .741 .907 r
.48873 .25689 .48979 .25814 .49608 .25589 .49502 .25463 Metetra
.664 .741 .907 r
.49502 .25463 .49608 .25589 .50238 .25363 .50132 .25237 Metetra
.664 .741 .907 r
.50132 .25237 .50238 .25363 .50869 .25137 .50764 .2501 Metetra
.664 .741 .907 r
.50764 .2501 .50869 .25137 .51502 .2491 .51397 .24783 Metetra
.664 .741 .907 r
.51397 .24783 .51502 .2491 .52136 .24682 .52032 .24555 Metetra
.664 .741 .907 r
.52032 .24555 .52136 .24682 .52772 .24454 .52668 .24327 Metetra
.664 .741 .907 r
.52668 .24327 .52772 .24454 .53409 .24226 .53305 .24098 Metetra
.664 .741 .907 r
.53305 .24098 .53409 .24226 .54048 .23997 .53944 .23869 Metetra
.664 .741 .907 r
.53944 .23869 .54048 .23997 .54688 .23767 .54585 .23639 Metetra
.664 .741 .907 r
.54585 .23639 .54688 .23767 .55329 .23537 .55227 .23409 Metetra
.664 .741 .907 r
.55227 .23409 .55329 .23537 .55973 .23306 .5587 .23178 Metetra
.664 .741 .907 r
.5587 .23178 .55973 .23306 .56617 .23075 .56515 .22946 Metetra
.664 .741 .907 r
.56515 .22946 .56617 .23075 .57263 .22844 .57161 .22714 Metetra
.664 .741 .907 r
.57161 .22714 .57263 .22844 .57911 .22611 .57809 .22482 Metetra
.664 .741 .907 r
.57809 .22482 .57911 .22611 .5856 .22379 .58459 .22248 Metetra
.664 .741 .907 r
.58459 .22248 .5856 .22379 .59211 .22145 .5911 .22015 Metetra
.664 .741 .907 r
.5911 .22015 .59211 .22145 .59863 .21911 .59762 .21781 Metetra
.664 .741 .907 r
.59762 .21781 .59863 .21911 .60517 .21677 .60416 .21546 Metetra
.664 .741 .907 r
.60416 .21546 .60517 .21677 .61172 .21442 .61072 .21311 Metetra
.664 .741 .907 r
.61072 .21311 .61172 .21442 .61829 .21206 .61729 .21075 Metetra
.664 .741 .907 r
.61729 .21075 .61829 .21206 .62487 .2097 .62388 .20838 Metetra
.664 .741 .907 r
.62388 .20838 .62487 .2097 .63147 .20734 .63048 .20601 Metetra
.664 .741 .907 r
.63048 .20601 .63147 .20734 .63809 .20497 .6371 .20364 Metetra
.664 .741 .907 r
.6371 .20364 .63809 .20497 .64472 .20259 .64373 .20126 Metetra
.664 .741 .907 r
.64373 .20126 .64472 .20259 .65136 .2002 .65038 .19887 Metetra
.664 .741 .907 r
.65038 .19887 .65136 .2002 .65803 .19782 .65705 .19648 Metetra
.664 .741 .907 r
.65705 .19648 .65803 .19782 .6647 .19542 .66373 .19408 Metetra
.664 .741 .907 r
.66373 .19408 .6647 .19542 .6714 .19302 .67042 .19168 Metetra
.664 .741 .907 r
.67042 .19168 .6714 .19302 .67811 .19061 .67714 .18927 Metetra
.664 .741 .907 r
.67714 .18927 .67811 .19061 .68483 .1882 .68387 .18686 Metetra
.664 .741 .907 r
.68387 .18686 .68483 .1882 .69157 .18579 .69061 .18444 Metetra
.664 .741 .907 r
.69061 .18444 .69157 .18579 .69833 .18336 .69737 .18201 Metetra
.664 .741 .907 r
.69737 .18201 .69833 .18336 .7051 .18093 .70415 .17958 Metetra
.664 .741 .907 r
.70415 .17958 .7051 .18093 .71189 .1785 .71094 .17714 Metetra
.664 .741 .907 r
.71094 .17714 .71189 .1785 .7187 .17606 .71775 .17469 Metetra
.664 .741 .907 r
.71775 .17469 .7187 .17606 .72552 .17361 .72458 .17225 Metetra
.664 .741 .907 r
.72458 .17225 .72552 .17361 .73236 .17116 .73142 .16979 Metetra
.664 .741 .907 r
.73142 .16979 .73236 .17116 .73922 .1687 .73828 .16733 Metetra
.664 .741 .907 r
.73828 .16733 .73922 .1687 .74609 .16624 .74515 .16486 Metetra
.664 .741 .907 r
.74515 .16486 .74609 .16624 .75298 .16377 .75204 .16239 Metetra
.664 .741 .907 r
.75204 .16239 .75298 .16377 .75988 .16129 .75895 .15991 Metetra
.664 .741 .907 r
.75895 .15991 .75988 .16129 .7668 .15881 .76588 .15742 Metetra
.664 .741 .907 r
.76588 .15742 .7668 .15881 .77374 .15632 .77282 .15493 Metetra
.664 .741 .907 r
.77282 .15493 .77374 .15632 .78069 .15383 .77978 .15243 Metetra
.664 .741 .907 r
.77978 .15243 .78069 .15383 .78767 .15133 .78675 .14993 Metetra
.664 .741 .907 r
.16268 .37236 .16387 .37348 .16943 .37148 .16824 .37036 Metetra
.664 .741 .907 r
.16824 .37036 .16943 .37148 .175 .36948 .17382 .36836 Metetra
.664 .741 .907 r
.17382 .36836 .175 .36948 .18059 .36747 .1794 .36635 Metetra
.664 .741 .907 r
.1794 .36635 .18059 .36747 .18619 .36547 .185 .36434 Metetra
.664 .741 .907 r
.185 .36434 .18619 .36547 .1918 .36345 .19062 .36233 Metetra
.664 .741 .907 r
.19062 .36233 .1918 .36345 .19742 .36143 .19624 .36031 Metetra
.664 .741 .907 r
.19624 .36031 .19742 .36143 .20305 .35941 .20188 .35828 Metetra
.664 .741 .907 r
.20188 .35828 .20305 .35941 .2087 .35739 .20753 .35625 Metetra
.664 .741 .907 r
.20753 .35625 .2087 .35739 .21436 .35536 .21319 .35422 Metetra
.664 .741 .907 r
.21319 .35422 .21436 .35536 .22003 .35332 .21886 .35218 Metetra
.664 .741 .907 r
.21886 .35218 .22003 .35332 .22571 .35128 .22455 .35014 Metetra
.664 .741 .907 r
.22455 .35014 .22571 .35128 .23141 .34924 .23024 .34809 Metetra
.664 .741 .907 r
.23024 .34809 .23141 .34924 .23712 .34719 .23596 .34604 Metetra
0 .085 .585 r
.23596 .34604 .23712 .34719 .24026 .37416 .24109 .35054 Metetra
.577 .362 .553 r
.24109 .35054 .24026 .37416 .24857 .34308 .24741 .34193 Metetra
.664 .741 .907 r
.24741 .34193 .24857 .34308 .25432 .34101 .25316 .33986 Metetra
.664 .741 .907 r
.25316 .33986 .25432 .34101 .26008 .33895 .25892 .33779 Metetra
.664 .741 .907 r
.25892 .33779 .26008 .33895 .26585 .33688 .2647 .33572 Metetra
.664 .741 .907 r
.2647 .33572 .26585 .33688 .27164 .3348 .27049 .33364 Metetra
.664 .741 .907 r
.27049 .33364 .27164 .3348 .27743 .33272 .27629 .33156 Metetra
.664 .741 .907 r
.27629 .33156 .27743 .33272 .28324 .33063 .2821 .32947 Metetra
.664 .741 .907 r
.2821 .32947 .28324 .33063 .28907 .32854 .28792 .32738 Metetra
.664 .741 .907 r
.28792 .32738 .28907 .32854 .2949 .32645 .29376 .32528 Metetra
.664 .741 .907 r
.29376 .32528 .2949 .32645 .30075 .32435 .29961 .32318 Metetra
.664 .741 .907 r
.29961 .32318 .30075 .32435 .30661 .32225 .30548 .32107 Metetra
.664 .741 .907 r
.30548 .32107 .30661 .32225 .31249 .32014 .31135 .31896 Metetra
.664 .741 .907 r
.31135 .31896 .31249 .32014 .31838 .31802 .31724 .31684 Metetra
.664 .741 .907 r
.31724 .31684 .31838 .31802 .32428 .31591 .32315 .31472 Metetra
.664 .741 .907 r
.32315 .31472 .32428 .31591 .33019 .31378 .32906 .3126 Metetra
.664 .741 .907 r
.32906 .3126 .33019 .31378 .33612 .31166 .33499 .31047 Metetra
.664 .741 .907 r
.33499 .31047 .33612 .31166 .34206 .30953 .34094 .30833 Metetra
.664 .741 .907 r
.34094 .30833 .34206 .30953 .34801 .30739 .34689 .30619 Metetra
.664 .741 .907 r
.34689 .30619 .34801 .30739 .35398 .30525 .35286 .30405 Metetra
.664 .741 .907 r
.35286 .30405 .35398 .30525 .35996 .3031 .35885 .3019 Metetra
.664 .741 .907 r
.35885 .3019 .35996 .3031 .36596 .30095 .36484 .29975 Metetra
.664 .741 .907 r
.36484 .29975 .36596 .30095 .37196 .29879 .37085 .29759 Metetra
.664 .741 .907 r
.37085 .29759 .37196 .29879 .37798 .29663 .37688 .29542 Metetra
.664 .741 .907 r
.37688 .29542 .37798 .29663 .38402 .29447 .38292 .29326 Metetra
.664 .741 .907 r
.38292 .29326 .38402 .29447 .39007 .2923 .38897 .29108 Metetra
.664 .741 .907 r
.38897 .29108 .39007 .2923 .39394 .34305 .39503 .2889 Metetra
.535 .316 .529 r
.39503 .2889 .39394 .34305 .40221 .28794 .40111 .28672 Metetra
.664 .741 .907 r
.40111 .28672 .40221 .28794 .4083 .28575 .4072 .28453 Metetra
.664 .741 .907 r
.4072 .28453 .4083 .28575 .4144 .28356 .41331 .28234 Metetra
.664 .741 .907 r
.41331 .28234 .4144 .28356 .42052 .28137 .41943 .28014 Metetra
.664 .741 .907 r
.41943 .28014 .42052 .28137 .42665 .27917 .42556 .27794 Metetra
.664 .741 .907 r
.42556 .27794 .42665 .27917 .43279 .27696 .43171 .27573 Metetra
.664 .741 .907 r
.43171 .27573 .43279 .27696 .43895 .27475 .43787 .27352 Metetra
.664 .741 .907 r
.43787 .27352 .43895 .27475 .44513 .27254 .44405 .2713 Metetra
.664 .741 .907 r
.44405 .2713 .44513 .27254 .45131 .27032 .45024 .26908 Metetra
.664 .741 .907 r
.45024 .26908 .45131 .27032 .45751 .26809 .45644 .26685 Metetra
.664 .741 .907 r
.45644 .26685 .45751 .26809 .46373 .26586 .46266 .26461 Metetra
.664 .741 .907 r
.46266 .26461 .46373 .26586 .46996 .26362 .46889 .26237 Metetra
.664 .741 .907 r
.46889 .26237 .46996 .26362 .4762 .26138 .47514 .26013 Metetra
.664 .741 .907 r
.47514 .26013 .4762 .26138 .48246 .25914 .4814 .25788 Metetra
.664 .741 .907 r
.4814 .25788 .48246 .25914 .48873 .25689 .48768 .25563 Metetra
.664 .741 .907 r
.48768 .25563 .48873 .25689 .49502 .25463 .49397 .25337 Metetra
.966 .65 .361 r
.49397 .25337 .49502 .25463 .50132 .25237 .49969 .32427 Metetra
.371 .17 .474 r
.49969 .32427 .50132 .25237 .50764 .2501 .50659 .24883 Metetra
.664 .741 .907 r
.50659 .24883 .50764 .2501 .51397 .24783 .51292 .24656 Metetra
.664 .741 .907 r
.51292 .24656 .51397 .24783 .52032 .24555 .51927 .24428 Metetra
.664 .741 .907 r
.51927 .24428 .52032 .24555 .52668 .24327 .52564 .24199 Metetra
.664 .741 .907 r
.52564 .24199 .52668 .24327 .53305 .24098 .53201 .2397 Metetra
.664 .741 .907 r
.53201 .2397 .53305 .24098 .53944 .23869 .53841 .23741 Metetra
.664 .741 .907 r
.53841 .23741 .53944 .23869 .54585 .23639 .54481 .2351 Metetra
.664 .741 .907 r
.54481 .2351 .54585 .23639 .55227 .23409 .55124 .2328 Metetra
.664 .741 .907 r
.55124 .2328 .55227 .23409 .5587 .23178 .55767 .23049 Metetra
.664 .741 .907 r
.55767 .23049 .5587 .23178 .56515 .22946 .56413 .22817 Metetra
.664 .741 .907 r
.56413 .22817 .56515 .22946 .57161 .22714 .57059 .22584 Metetra
.664 .741 .907 r
.57059 .22584 .57161 .22714 .57809 .22482 .57708 .22352 Metetra
.664 .741 .907 r
.57708 .22352 .57809 .22482 .58459 .22248 .58357 .22118 Metetra
.664 .741 .907 r
.58357 .22118 .58459 .22248 .5911 .22015 .59009 .21884 Metetra
.664 .741 .907 r
.59009 .21884 .5911 .22015 .59762 .21781 .59662 .2165 Metetra
.664 .741 .907 r
.59662 .2165 .59762 .21781 .60416 .21546 .60316 .21415 Metetra
.664 .741 .907 r
.60316 .21415 .60416 .21546 .61072 .21311 .60972 .21179 Metetra
.664 .741 .907 r
.60972 .21179 .61072 .21311 .61729 .21075 .61629 .20943 Metetra
.664 .741 .907 r
.61629 .20943 .61729 .21075 .62388 .20838 .62288 .20706 Metetra
.664 .741 .907 r
.62288 .20706 .62388 .20838 .63048 .20601 .62949 .20469 Metetra
.664 .741 .907 r
.62949 .20469 .63048 .20601 .6371 .20364 .63611 .20231 Metetra
.664 .741 .907 r
.63611 .20231 .6371 .20364 .64373 .20126 .64275 .19993 Metetra
.664 .741 .907 r
.64275 .19993 .64373 .20126 .65038 .19887 .6494 .19754 Metetra
.664 .741 .907 r
.6494 .19754 .65038 .19887 .65705 .19648 .65607 .19514 Metetra
.664 .741 .907 r
.65607 .19514 .65705 .19648 .66373 .19408 .66275 .19274 Metetra
.664 .741 .907 r
.66275 .19274 .66373 .19408 .67042 .19168 .66945 .19034 Metetra
.664 .741 .907 r
.66945 .19034 .67042 .19168 .67714 .18927 .67617 .18792 Metetra
.664 .741 .907 r
.67617 .18792 .67714 .18927 .68387 .18686 .6829 .18551 Metetra
.664 .741 .907 r
.6829 .18551 .68387 .18686 .69061 .18444 .68965 .18308 Metetra
.664 .741 .907 r
.68965 .18308 .69061 .18444 .69737 .18201 .69641 .18065 Metetra
.664 .741 .907 r
.69641 .18065 .69737 .18201 .70415 .17958 .70319 .17822 Metetra
.664 .741 .907 r
.70319 .17822 .70415 .17958 .71094 .17714 .70999 .17578 Metetra
.664 .741 .907 r
.70999 .17578 .71094 .17714 .71775 .17469 .7168 .17333 Metetra
.664 .741 .907 r
.7168 .17333 .71775 .17469 .72458 .17225 .72363 .17088 Metetra
.664 .741 .907 r
.72363 .17088 .72458 .17225 .73142 .16979 .73048 .16842 Metetra
.664 .741 .907 r
.73048 .16842 .73142 .16979 .73828 .16733 .73734 .16595 Metetra
.664 .741 .907 r
.73734 .16595 .73828 .16733 .74515 .16486 .74422 .16348 Metetra
.664 .741 .907 r
.74422 .16348 .74515 .16486 .75204 .16239 .75111 .16101 Metetra
.664 .741 .907 r
.75111 .16101 .75204 .16239 .75895 .15991 .75802 .15852 Metetra
.664 .741 .907 r
.75802 .15852 .75895 .15991 .76588 .15742 .76495 .15603 Metetra
.664 .741 .907 r
.76495 .15603 .76588 .15742 .77282 .15493 .7719 .15354 Metetra
.664 .741 .907 r
.7719 .15354 .77282 .15493 .77978 .15243 .77886 .15104 Metetra
.664 .741 .907 r
.77886 .15104 .77978 .15243 .78675 .14993 .78584 .14853 Metetra
.664 .741 .907 r
.16148 .37125 .16268 .37236 .16824 .37036 .16705 .36925 Metetra
.664 .741 .907 r
.16705 .36925 .16824 .37036 .17382 .36836 .17263 .36724 Metetra
.664 .741 .907 r
.17263 .36724 .17382 .36836 .1794 .36635 .17822 .36523 Metetra
.664 .741 .907 r
.17822 .36523 .1794 .36635 .185 .36434 .18382 .36322 Metetra
.664 .741 .907 r
.18382 .36322 .185 .36434 .19062 .36233 .18943 .3612 Metetra
.664 .741 .907 r
.18943 .3612 .19062 .36233 .19624 .36031 .19506 .35918 Metetra
.664 .741 .907 r
.19506 .35918 .19624 .36031 .20188 .35828 .2007 .35715 Metetra
.664 .741 .907 r
.2007 .35715 .20188 .35828 .20753 .35625 .20635 .35512 Metetra
.664 .741 .907 r
.20635 .35512 .20753 .35625 .21319 .35422 .21201 .35308 Metetra
.664 .741 .907 r
.21201 .35308 .21319 .35422 .21886 .35218 .21769 .35104 Metetra
.664 .741 .907 r
.21769 .35104 .21886 .35218 .22455 .35014 .22338 .349 Metetra
.664 .741 .907 r
.22338 .349 .22455 .35014 .23024 .34809 .22908 .34695 Metetra
.664 .741 .907 r
.22908 .34695 .23024 .34809 .23596 .34604 .23479 .3449 Metetra
.664 .741 .907 r
.23479 .3449 .23596 .34604 .24109 .35054 .24052 .34284 Metetra
.572 .401 .611 r
.24052 .34284 .24109 .35054 .24741 .34193 .24625 .34078 Metetra
.664 .741 .907 r
.24625 .34078 .24741 .34193 .25316 .33986 .252 .33871 Metetra
.664 .741 .907 r
.252 .33871 .25316 .33986 .25892 .33779 .25777 .33664 Metetra
.664 .741 .907 r
.25777 .33664 .25892 .33779 .2647 .33572 .26354 .33456 Metetra
.664 .741 .907 r
.26354 .33456 .2647 .33572 .27049 .33364 .26933 .33248 Metetra
.664 .741 .907 r
.26933 .33248 .27049 .33364 .27629 .33156 .27514 .33039 Metetra
.664 .741 .907 r
.27514 .33039 .27629 .33156 .2821 .32947 .28095 .3283 Metetra
.664 .741 .907 r
.28095 .3283 .2821 .32947 .28792 .32738 .28678 .32621 Metetra
.664 .741 .907 r
.28678 .32621 .28792 .32738 .29376 .32528 .29262 .32411 Metetra
.664 .741 .907 r
.29262 .32411 .29376 .32528 .29961 .32318 .29847 .322 Metetra
.664 .741 .907 r
.29847 .322 .29961 .32318 .30548 .32107 .30434 .31989 Metetra
.664 .741 .907 r
.30434 .31989 .30548 .32107 .31135 .31896 .31022 .31778 Metetra
.664 .741 .907 r
.31022 .31778 .31135 .31896 .31724 .31684 .31611 .31566 Metetra
.664 .741 .907 r
.31611 .31566 .31724 .31684 .32315 .31472 .32202 .31354 Metetra
.664 .741 .907 r
.32202 .31354 .32315 .31472 .32906 .3126 .32794 .31141 Metetra
.664 .741 .907 r
.32794 .31141 .32906 .3126 .33499 .31047 .33387 .30928 Metetra
.664 .741 .907 r
.33387 .30928 .33499 .31047 .34094 .30833 .33981 .30714 Metetra
.664 .741 .907 r
.33981 .30714 .34094 .30833 .34689 .30619 .34577 .305 Metetra
.664 .741 .907 r
.34577 .305 .34689 .30619 .35286 .30405 .35175 .30285 Metetra
.664 .741 .907 r
.35175 .30285 .35286 .30405 .35885 .3019 .35773 .3007 Metetra
.664 .741 .907 r
.35773 .3007 .35885 .3019 .36484 .29975 .36373 .29854 Metetra
.664 .741 .907 r
.36373 .29854 .36484 .29975 .37085 .29759 .36974 .29638 Metetra
.664 .741 .907 r
.36974 .29638 .37085 .29759 .37688 .29542 .37577 .29422 Metetra
.664 .741 .907 r
.37577 .29422 .37688 .29542 .38292 .29326 .38181 .29204 Metetra
.664 .741 .907 r
.38181 .29204 .38292 .29326 .38897 .29108 .38786 .28987 Metetra
.664 .741 .907 r
.38786 .28987 .38897 .29108 .39503 .2889 .39393 .28769 Metetra
.664 .741 .907 r
.39393 .28769 .39503 .2889 .40111 .28672 .40001 .2855 Metetra
.664 .741 .907 r
.40001 .2855 .40111 .28672 .4072 .28453 .40611 .28331 Metetra
.664 .741 .907 r
.40611 .28331 .4072 .28453 .41331 .28234 .41222 .28111 Metetra
.664 .741 .907 r
.41222 .28111 .41331 .28234 .41943 .28014 .41834 .27891 Metetra
.664 .741 .907 r
.41834 .27891 .41943 .28014 .42556 .27794 .42447 .27671 Metetra
.664 .741 .907 r
.42447 .27671 .42556 .27794 .43171 .27573 .43063 .2745 Metetra
.664 .741 .907 r
.43063 .2745 .43171 .27573 .43787 .27352 .43679 .27228 Metetra
.664 .741 .907 r
.43679 .27228 .43787 .27352 .44405 .2713 .44297 .27006 Metetra
.664 .741 .907 r
.44297 .27006 .44405 .2713 .45024 .26908 .44916 .26783 Metetra
.664 .741 .907 r
.44916 .26783 .45024 .26908 .45644 .26685 .45537 .2656 Metetra
.664 .741 .907 r
.45537 .2656 .45644 .26685 .46266 .26461 .46159 .26337 Metetra
.664 .741 .907 r
.46159 .26337 .46266 .26461 .46889 .26237 .46782 .26112 Metetra
.664 .741 .907 r
.46782 .26112 .46889 .26237 .47514 .26013 .47407 .25888 Metetra
.664 .741 .907 r
.47407 .25888 .47514 .26013 .4814 .25788 .48034 .25663 Metetra
.664 .741 .907 r
.48034 .25663 .4814 .25788 .48768 .25563 .48662 .25437 Metetra
.967 .654 .371 r
.48662 .25437 .48768 .25563 .49397 .25337 .49207 .33259 Metetra
.661 .402 .518 r
.49207 .33259 .49397 .25337 .49969 .32427 .49753 .45192 Metetra
.256 .086 .449 r
.49753 .45192 .49969 .32427 .50659 .24883 .50554 .24757 Metetra
.664 .741 .907 r
.50554 .24757 .50659 .24883 .51292 .24656 .51188 .24529 Metetra
.664 .741 .907 r
.51188 .24529 .51292 .24656 .51927 .24428 .51823 .243 Metetra
.664 .741 .907 r
.51823 .243 .51927 .24428 .52564 .24199 .52459 .24072 Metetra
.664 .741 .907 r
.52459 .24072 .52564 .24199 .53201 .2397 .53097 .23842 Metetra
.664 .741 .907 r
.53097 .23842 .53201 .2397 .53841 .23741 .53737 .23612 Metetra
.664 .741 .907 r
.53737 .23612 .53841 .23741 .54481 .2351 .54378 .23382 Metetra
.664 .741 .907 r
.54378 .23382 .54481 .2351 .55124 .2328 .55021 .23151 Metetra
.664 .741 .907 r
.55021 .23151 .55124 .2328 .55767 .23049 .55665 .22919 Metetra
.664 .741 .907 r
.55665 .22919 .55767 .23049 .56413 .22817 .5631 .22687 Metetra
.664 .741 .907 r
.5631 .22687 .56413 .22817 .57059 .22584 .56957 .22455 Metetra
.664 .741 .907 r
.56957 .22455 .57059 .22584 .57708 .22352 .57606 .22222 Metetra
.664 .741 .907 r
.57606 .22222 .57708 .22352 .58357 .22118 .58256 .21988 Metetra
.664 .741 .907 r
.58256 .21988 .58357 .22118 .59009 .21884 .58907 .21754 Metetra
.664 .741 .907 r
.58907 .21754 .59009 .21884 .59662 .2165 .59561 .21519 Metetra
.664 .741 .907 r
.59561 .21519 .59662 .2165 .60316 .21415 .60215 .21283 Metetra
.664 .741 .907 r
.60215 .21283 .60316 .21415 .60972 .21179 .60872 .21048 Metetra
.664 .741 .907 r
.60872 .21048 .60972 .21179 .61629 .20943 .61529 .20811 Metetra
.664 .741 .907 r
.61529 .20811 .61629 .20943 .62288 .20706 .62189 .20574 Metetra
.664 .741 .907 r
.62189 .20574 .62288 .20706 .62949 .20469 .62849 .20337 Metetra
.664 .741 .907 r
.62849 .20337 .62949 .20469 .63611 .20231 .63512 .20098 Metetra
.664 .741 .907 r
.63512 .20098 .63611 .20231 .64275 .19993 .64176 .1986 Metetra
.664 .741 .907 r
.64176 .1986 .64275 .19993 .6494 .19754 .64841 .1962 Metetra
.664 .741 .907 r
.64841 .1962 .6494 .19754 .65607 .19514 .65509 .19381 Metetra
.664 .741 .907 r
.65509 .19381 .65607 .19514 .66275 .19274 .66177 .1914 Metetra
.664 .741 .907 r
.66177 .1914 .66275 .19274 .66945 .19034 .66848 .18899 Metetra
.664 .741 .907 r
.66848 .18899 .66945 .19034 .67617 .18792 .6752 .18658 Metetra
.664 .741 .907 r
.6752 .18658 .67617 .18792 .6829 .18551 .68193 .18416 Metetra
.664 .741 .907 r
.68193 .18416 .6829 .18551 .68965 .18308 .68868 .18173 Metetra
.664 .741 .907 r
.68868 .18173 .68965 .18308 .69641 .18065 .69545 .1793 Metetra
.664 .741 .907 r
.69545 .1793 .69641 .18065 .70319 .17822 .70223 .17686 Metetra
.664 .741 .907 r
.70223 .17686 .70319 .17822 .70999 .17578 .70903 .17441 Metetra
.664 .741 .907 r
.70903 .17441 .70999 .17578 .7168 .17333 .71585 .17196 Metetra
.664 .741 .907 r
.71585 .17196 .7168 .17333 .72363 .17088 .72268 .16951 Metetra
.664 .741 .907 r
.72268 .16951 .72363 .17088 .73048 .16842 .72953 .16704 Metetra
.664 .741 .907 r
.72953 .16704 .73048 .16842 .73734 .16595 .7364 .16458 Metetra
.664 .741 .907 r
.7364 .16458 .73734 .16595 .74422 .16348 .74328 .1621 Metetra
.664 .741 .907 r
.74328 .1621 .74422 .16348 .75111 .16101 .75018 .15962 Metetra
.664 .741 .907 r
.75018 .15962 .75111 .16101 .75802 .15852 .75709 .15714 Metetra
.664 .741 .907 r
.75709 .15714 .75802 .15852 .76495 .15603 .76403 .15464 Metetra
.664 .741 .907 r
.76403 .15464 .76495 .15603 .7719 .15354 .77097 .15215 Metetra
.664 .741 .907 r
.77097 .15215 .7719 .15354 .77886 .15104 .77794 .14964 Metetra
.664 .741 .907 r
.77794 .14964 .77886 .15104 .78584 .14853 .78492 .14713 Metetra
.664 .741 .907 r
.16029 .37013 .16148 .37125 .16705 .36925 .16586 .36813 Metetra
.664 .741 .907 r
.16586 .36813 .16705 .36925 .17263 .36724 .17144 .36612 Metetra
.664 .741 .907 r
.17144 .36612 .17263 .36724 .17822 .36523 .17703 .36411 Metetra
.664 .741 .907 r
.17703 .36411 .17822 .36523 .18382 .36322 .18263 .36209 Metetra
.664 .741 .907 r
.18263 .36209 .18382 .36322 .18943 .3612 .18825 .36007 Metetra
.664 .741 .907 r
.18825 .36007 .18943 .3612 .19506 .35918 .19388 .35805 Metetra
.664 .741 .907 r
.19388 .35805 .19506 .35918 .2007 .35715 .19952 .35602 Metetra
.664 .741 .907 r
.19952 .35602 .2007 .35715 .20635 .35512 .20517 .35399 Metetra
.664 .741 .907 r
.20517 .35399 .20635 .35512 .21201 .35308 .21084 .35195 Metetra
.664 .741 .907 r
.21084 .35195 .21201 .35308 .21769 .35104 .21652 .3499 Metetra
.664 .741 .907 r
.21652 .3499 .21769 .35104 .22338 .349 .22221 .34786 Metetra
.664 .741 .907 r
.22221 .34786 .22338 .349 .22908 .34695 .22791 .34581 Metetra
.664 .741 .907 r
.22791 .34581 .22908 .34695 .23479 .3449 .23362 .34375 Metetra
.664 .741 .907 r
.23362 .34375 .23479 .3449 .24052 .34284 .23935 .34169 Metetra
.664 .741 .907 r
.23935 .34169 .24052 .34284 .24625 .34078 .24509 .33962 Metetra
.664 .741 .907 r
.24509 .33962 .24625 .34078 .252 .33871 .25085 .33755 Metetra
.664 .741 .907 r
.25085 .33755 .252 .33871 .25777 .33664 .25661 .33548 Metetra
.664 .741 .907 r
.25661 .33548 .25777 .33664 .26354 .33456 .26239 .3334 Metetra
.664 .741 .907 r
.26239 .3334 .26354 .33456 .26933 .33248 .26818 .33132 Metetra
.664 .741 .907 r
.26818 .33132 .26933 .33248 .27514 .33039 .27399 .32923 Metetra
.664 .741 .907 r
.27399 .32923 .27514 .33039 .28095 .3283 .2798 .32713 Metetra
.664 .741 .907 r
.2798 .32713 .28095 .3283 .28678 .32621 .28563 .32504 Metetra
.664 .741 .907 r
.28563 .32504 .28678 .32621 .29262 .32411 .29148 .32293 Metetra
.664 .741 .907 r
.29148 .32293 .29262 .32411 .29847 .322 .29733 .32083 Metetra
.664 .741 .907 r
.29733 .32083 .29847 .322 .30434 .31989 .3032 .31872 Metetra
.664 .741 .907 r
.3032 .31872 .30434 .31989 .31022 .31778 .30908 .3166 Metetra
.664 .741 .907 r
.30908 .3166 .31022 .31778 .31611 .31566 .31498 .31448 Metetra
.664 .741 .907 r
.31498 .31448 .31611 .31566 .32202 .31354 .32089 .31235 Metetra
.664 .741 .907 r
.32089 .31235 .32202 .31354 .32794 .31141 .32681 .31022 Metetra
.664 .741 .907 r
.32681 .31022 .32794 .31141 .33387 .30928 .33274 .30809 Metetra
.664 .741 .907 r
.33274 .30809 .33387 .30928 .33981 .30714 .33869 .30595 Metetra
.664 .741 .907 r
.33869 .30595 .33981 .30714 .34577 .305 .34465 .3038 Metetra
.664 .741 .907 r
.34465 .3038 .34577 .305 .35175 .30285 .35063 .30165 Metetra
.664 .741 .907 r
.35063 .30165 .35175 .30285 .35773 .3007 .35662 .2995 Metetra
.664 .741 .907 r
.35662 .2995 .35773 .3007 .36373 .29854 .36262 .29734 Metetra
.664 .741 .907 r
.36262 .29734 .36373 .29854 .36974 .29638 .36863 .29517 Metetra
.664 .741 .907 r
.36863 .29517 .36974 .29638 .37577 .29422 .37466 .29301 Metetra
.664 .741 .907 r
.37466 .29301 .37577 .29422 .38181 .29204 .3807 .29083 Metetra
.664 .741 .907 r
.3807 .29083 .38181 .29204 .38786 .28987 .38676 .28865 Metetra
.664 .741 .907 r
.38676 .28865 .38786 .28987 .39393 .28769 .39283 .28647 Metetra
.664 .741 .907 r
.39283 .28647 .39393 .28769 .40001 .2855 .39891 .28428 Metetra
.664 .741 .907 r
.39891 .28428 .40001 .2855 .40611 .28331 .40501 .28209 Metetra
.664 .741 .907 r
.40501 .28209 .40611 .28331 .41222 .28111 .41112 .27989 Metetra
.664 .741 .907 r
.41112 .27989 .41222 .28111 .41834 .27891 .41725 .27768 Metetra
.664 .741 .907 r
.41725 .27768 .41834 .27891 .42447 .27671 .42339 .27547 Metetra
.664 .741 .907 r
.42339 .27547 .42447 .27671 .43063 .2745 .42954 .27326 Metetra
.664 .741 .907 r
.42954 .27326 .43063 .2745 .43679 .27228 .43571 .27104 Metetra
.664 .741 .907 r
.43571 .27104 .43679 .27228 .44297 .27006 .44189 .26882 Metetra
.664 .741 .907 r
.44189 .26882 .44297 .27006 .44916 .26783 .44808 .26659 Metetra
.664 .741 .907 r
.44808 .26659 .44916 .26783 .45537 .2656 .45429 .26435 Metetra
.664 .741 .907 r
.45429 .26435 .45537 .2656 .46159 .26337 .46052 .26212 Metetra
.664 .741 .907 r
.46052 .26212 .46159 .26337 .46782 .26112 .46676 .25987 Metetra
.664 .741 .907 r
.46676 .25987 .46782 .26112 .47407 .25888 .47301 .25762 Metetra
.664 .741 .907 r
.47301 .25762 .47407 .25888 .48034 .25663 .47927 .25537 Metetra
.664 .741 .907 r
.47927 .25537 .48034 .25663 .48662 .25437 .48556 .25311 Metetra
.969 .672 .408 r
.48556 .25311 .48662 .25437 .49207 .33259 .49004 .41907 Metetra
.408 .2 .483 r
.49004 .41907 .49207 .33259 .49753 .45192 .4973 .34782 Metetra
.634 .39 .531 r
.4973 .34782 .49753 .45192 .50554 .24757 .50449 .2463 Metetra
.664 .741 .907 r
.50449 .2463 .50554 .24757 .51188 .24529 .51083 .24402 Metetra
.664 .741 .907 r
.51083 .24402 .51188 .24529 .51823 .243 .51718 .24173 Metetra
.664 .741 .907 r
.51718 .24173 .51823 .243 .52459 .24072 .52355 .23944 Metetra
.664 .741 .907 r
.52355 .23944 .52459 .24072 .53097 .23842 .52993 .23714 Metetra
.664 .741 .907 r
.52993 .23714 .53097 .23842 .53737 .23612 .53633 .23484 Metetra
.664 .741 .907 r
.53633 .23484 .53737 .23612 .54378 .23382 .54275 .23253 Metetra
.664 .741 .907 r
.54275 .23253 .54378 .23382 .55021 .23151 .54917 .23022 Metetra
.664 .741 .907 r
.54917 .23022 .55021 .23151 .55665 .22919 .55562 .2279 Metetra
.664 .741 .907 r
.55562 .2279 .55665 .22919 .5631 .22687 .56208 .22558 Metetra
.664 .741 .907 r
.56208 .22558 .5631 .22687 .56957 .22455 .56855 .22325 Metetra
.664 .741 .907 r
.56855 .22325 .56957 .22455 .57606 .22222 .57504 .22091 Metetra
.664 .741 .907 r
.57504 .22091 .57606 .22222 .58256 .21988 .58154 .21857 Metetra
.664 .741 .907 r
.58154 .21857 .58256 .21988 .58907 .21754 .58806 .21623 Metetra
.664 .741 .907 r
.58806 .21623 .58907 .21754 .59561 .21519 .5946 .21388 Metetra
.664 .741 .907 r
.5946 .21388 .59561 .21519 .60215 .21283 .60115 .21152 Metetra
.664 .741 .907 r
.60115 .21152 .60215 .21283 .60872 .21048 .60771 .20916 Metetra
.664 .741 .907 r
.60771 .20916 .60872 .21048 .61529 .20811 .61429 .20679 Metetra
.664 .741 .907 r
.61429 .20679 .61529 .20811 .62189 .20574 .62089 .20442 Metetra
.664 .741 .907 r
.62089 .20442 .62189 .20574 .62849 .20337 .6275 .20204 Metetra
.664 .741 .907 r
.6275 .20204 .62849 .20337 .63512 .20098 .63413 .19965 Metetra
.664 .741 .907 r
.63413 .19965 .63512 .20098 .64176 .1986 .64077 .19726 Metetra
.664 .741 .907 r
.64077 .19726 .64176 .1986 .64841 .1962 .64743 .19487 Metetra
.664 .741 .907 r
.64743 .19487 .64841 .1962 .65509 .19381 .6541 .19247 Metetra
.664 .741 .907 r
.6541 .19247 .65509 .19381 .66177 .1914 .66079 .19006 Metetra
.664 .741 .907 r
.66079 .19006 .66177 .1914 .66848 .18899 .6675 .18765 Metetra
.664 .741 .907 r
.6675 .18765 .66848 .18899 .6752 .18658 .67422 .18523 Metetra
.664 .741 .907 r
.67422 .18523 .6752 .18658 .68193 .18416 .68096 .1828 Metetra
.664 .741 .907 r
.68096 .1828 .68193 .18416 .68868 .18173 .68772 .18037 Metetra
.664 .741 .907 r
.68772 .18037 .68868 .18173 .69545 .1793 .69449 .17794 Metetra
.664 .741 .907 r
.69449 .17794 .69545 .1793 .70223 .17686 .70127 .17549 Metetra
.664 .741 .907 r
.70127 .17549 .70223 .17686 .70903 .17441 .70808 .17305 Metetra
.664 .741 .907 r
.70808 .17305 .70903 .17441 .71585 .17196 .7149 .17059 Metetra
.664 .741 .907 r
.7149 .17059 .71585 .17196 .72268 .16951 .72173 .16813 Metetra
.664 .741 .907 r
.72173 .16813 .72268 .16951 .72953 .16704 .72859 .16567 Metetra
.664 .741 .907 r
.72859 .16567 .72953 .16704 .7364 .16458 .73546 .1632 Metetra
.664 .741 .907 r
.73546 .1632 .7364 .16458 .74328 .1621 .74234 .16072 Metetra
.664 .741 .907 r
.74234 .16072 .74328 .1621 .75018 .15962 .74924 .15824 Metetra
.664 .741 .907 r
.74924 .15824 .75018 .15962 .75709 .15714 .75616 .15575 Metetra
.664 .741 .907 r
.75616 .15575 .75709 .15714 .76403 .15464 .7631 .15325 Metetra
.664 .741 .907 r
.7631 .15325 .76403 .15464 .77097 .15215 .77005 .15075 Metetra
.664 .741 .907 r
.77005 .15075 .77097 .15215 .77794 .14964 .77702 .14824 Metetra
.664 .741 .907 r
.77702 .14824 .77794 .14964 .78492 .14713 .78401 .14573 Metetra
.664 .741 .907 r
.15909 .36902 .16029 .37013 .16586 .36813 .16466 .36701 Metetra
.664 .741 .907 r
.16466 .36701 .16586 .36813 .17144 .36612 .17025 .365 Metetra
.664 .741 .907 r
.17025 .365 .17144 .36612 .17703 .36411 .17584 .36299 Metetra
.664 .741 .907 r
.17584 .36299 .17703 .36411 .18263 .36209 .18145 .36097 Metetra
.664 .741 .907 r
.18145 .36097 .18263 .36209 .18825 .36007 .18706 .35894 Metetra
.664 .741 .907 r
.18706 .35894 .18825 .36007 .19388 .35805 .19269 .35692 Metetra
.664 .741 .907 r
.19269 .35692 .19388 .35805 .19952 .35602 .19834 .35489 Metetra
.664 .741 .907 r
.19834 .35489 .19952 .35602 .20517 .35399 .20399 .35285 Metetra
.664 .741 .907 r
.20399 .35285 .20517 .35399 .21084 .35195 .20966 .35081 Metetra
.664 .741 .907 r
.20966 .35081 .21084 .35195 .21652 .3499 .21534 .34876 Metetra
.664 .741 .907 r
.21534 .34876 .21652 .3499 .22221 .34786 .22103 .34671 Metetra
.664 .741 .907 r
.22103 .34671 .22221 .34786 .22791 .34581 .22674 .34466 Metetra
.664 .741 .907 r
.22674 .34466 .22791 .34581 .23362 .34375 .23246 .3426 Metetra
.664 .741 .907 r
.23246 .3426 .23362 .34375 .23935 .34169 .23819 .34054 Metetra
.664 .741 .907 r
.23819 .34054 .23935 .34169 .24509 .33962 .24393 .33847 Metetra
.664 .741 .907 r
.24393 .33847 .24509 .33962 .25085 .33755 .24968 .3364 Metetra
.664 .741 .907 r
.24968 .3364 .25085 .33755 .25661 .33548 .25545 .33432 Metetra
.664 .741 .907 r
.25545 .33432 .25661 .33548 .26239 .3334 .26123 .33224 Metetra
.664 .741 .907 r
.26123 .33224 .26239 .3334 .26818 .33132 .26703 .33015 Metetra
.664 .741 .907 r
.26703 .33015 .26818 .33132 .27399 .32923 .27283 .32806 Metetra
.664 .741 .907 r
.27283 .32806 .27399 .32923 .2798 .32713 .27865 .32596 Metetra
.664 .741 .907 r
.27865 .32596 .2798 .32713 .28563 .32504 .28449 .32386 Metetra
.664 .741 .907 r
.28449 .32386 .28563 .32504 .29148 .32293 .29033 .32176 Metetra
.664 .741 .907 r
.29033 .32176 .29148 .32293 .29733 .32083 .29619 .31965 Metetra
.664 .741 .907 r
.29619 .31965 .29733 .32083 .3032 .31872 .30206 .31754 Metetra
.664 .741 .907 r
.30206 .31754 .3032 .31872 .30908 .3166 .30794 .31542 Metetra
.664 .741 .907 r
.30794 .31542 .30908 .3166 .31498 .31448 .31384 .31329 Metetra
.664 .741 .907 r
.31384 .31329 .31498 .31448 .32089 .31235 .31975 .31117 Metetra
.664 .741 .907 r
.31975 .31117 .32089 .31235 .32681 .31022 .32568 .30903 Metetra
.664 .741 .907 r
.32568 .30903 .32681 .31022 .33274 .30809 .33161 .30689 Metetra
.664 .741 .907 r
.33161 .30689 .33274 .30809 .33869 .30595 .33756 .30475 Metetra
.664 .741 .907 r
.33756 .30475 .33869 .30595 .34465 .3038 .34353 .3026 Metetra
.664 .741 .907 r
.34353 .3026 .34465 .3038 .35063 .30165 .34951 .30045 Metetra
.664 .741 .907 r
.34951 .30045 .35063 .30165 .35662 .2995 .3555 .29829 Metetra
.664 .741 .907 r
.3555 .29829 .35662 .2995 .36262 .29734 .3615 .29613 Metetra
.664 .741 .907 r
.3615 .29613 .36262 .29734 .36863 .29517 .36752 .29397 Metetra
.664 .741 .907 r
.36752 .29397 .36863 .29517 .37466 .29301 .37355 .29179 Metetra
.664 .741 .907 r
.37355 .29179 .37466 .29301 .3807 .29083 .3796 .28962 Metetra
.664 .741 .907 r
.3796 .28962 .3807 .29083 .38676 .28865 .38565 .28743 Metetra
.664 .741 .907 r
.38565 .28743 .38676 .28865 .39283 .28647 .39173 .28525 Metetra
.664 .741 .907 r
.39173 .28525 .39283 .28647 .39891 .28428 .39781 .28306 Metetra
.664 .741 .907 r
.39781 .28306 .39891 .28428 .40501 .28209 .40391 .28086 Metetra
.664 .741 .907 r
.40391 .28086 .40501 .28209 .41112 .27989 .41003 .27866 Metetra
.664 .741 .907 r
.41003 .27866 .41112 .27989 .41725 .27768 .41615 .27645 Metetra
.664 .741 .907 r
.41615 .27645 .41725 .27768 .42339 .27547 .4223 .27424 Metetra
.664 .741 .907 r
.4223 .27424 .42339 .27547 .42954 .27326 .42845 .27202 Metetra
.664 .741 .907 r
.42845 .27202 .42954 .27326 .43571 .27104 .43462 .2698 Metetra
.664 .741 .907 r
.43462 .2698 .43571 .27104 .44189 .26882 .44081 .26758 Metetra
.664 .741 .907 r
.44081 .26758 .44189 .26882 .44808 .26659 .447 .26534 Metetra
.664 .741 .907 r
.447 .26534 .44808 .26659 .45429 .26435 .45322 .26311 Metetra
.664 .741 .907 r
.45322 .26311 .45429 .26435 .46052 .26212 .45944 .26086 Metetra
.664 .741 .907 r
.45944 .26086 .46052 .26212 .46676 .25987 .46568 .25862 Metetra
.664 .741 .907 r
.46568 .25862 .46676 .25987 .47301 .25762 .47194 .25636 Metetra
.664 .741 .907 r
.47194 .25636 .47301 .25762 .47927 .25537 .47821 .25411 Metetra
.664 .741 .907 r
.47821 .25411 .47927 .25537 .48556 .25311 .48449 .25184 Metetra
.968 .669 .401 r
.48449 .25184 .48556 .25311 .49004 .41907 .48925 .38879 Metetra
.817 .549 .533 r
.48925 .38879 .49004 .41907 .4973 .34782 .4971 .2473 Metetra
.531 .308 .522 r
.4971 .2473 .4973 .34782 .50449 .2463 .50343 .24502 Metetra
.664 .741 .907 r
.50343 .24502 .50449 .2463 .51083 .24402 .50978 .24274 Metetra
.664 .741 .907 r
.50978 .24274 .51083 .24402 .51718 .24173 .51613 .24045 Metetra
.664 .741 .907 r
.51613 .24045 .51718 .24173 .52355 .23944 .5225 .23816 Metetra
.664 .741 .907 r
.5225 .23816 .52355 .23944 .52993 .23714 .52889 .23586 Metetra
.664 .741 .907 r
.52889 .23586 .52993 .23714 .53633 .23484 .53529 .23355 Metetra
.664 .741 .907 r
.53529 .23355 .53633 .23484 .54275 .23253 .54171 .23124 Metetra
.664 .741 .907 r
.54171 .23124 .54275 .23253 .54917 .23022 .54814 .22893 Metetra
.664 .741 .907 r
.54814 .22893 .54917 .23022 .55562 .2279 .55459 .2266 Metetra
.664 .741 .907 r
.55459 .2266 .55562 .2279 .56208 .22558 .56105 .22428 Metetra
.664 .741 .907 r
.56105 .22428 .56208 .22558 .56855 .22325 .56752 .22195 Metetra
.664 .741 .907 r
.56752 .22195 .56855 .22325 .57504 .22091 .57402 .21961 Metetra
.664 .741 .907 r
.57402 .21961 .57504 .22091 .58154 .21857 .58052 .21727 Metetra
.664 .741 .907 r
.58052 .21727 .58154 .21857 .58806 .21623 .58705 .21492 Metetra
.664 .741 .907 r
.58705 .21492 .58806 .21623 .5946 .21388 .59358 .21256 Metetra
.664 .741 .907 r
.59358 .21256 .5946 .21388 .60115 .21152 .60014 .2102 Metetra
.664 .741 .907 r
.60014 .2102 .60115 .21152 .60771 .20916 .6067 .20784 Metetra
.664 .741 .907 r
.6067 .20784 .60771 .20916 .61429 .20679 .61329 .20547 Metetra
.664 .741 .907 r
.61329 .20547 .61429 .20679 .62089 .20442 .61989 .20309 Metetra
.664 .741 .907 r
.61989 .20309 .62089 .20442 .6275 .20204 .6265 .20071 Metetra
.664 .741 .907 r
.6265 .20071 .6275 .20204 .63413 .19965 .63313 .19832 Metetra
.664 .741 .907 r
.63313 .19832 .63413 .19965 .64077 .19726 .63978 .19593 Metetra
.664 .741 .907 r
.63978 .19593 .64077 .19726 .64743 .19487 .64644 .19353 Metetra
.664 .741 .907 r
.64644 .19353 .64743 .19487 .6541 .19247 .65312 .19112 Metetra
.664 .741 .907 r
.65312 .19112 .6541 .19247 .66079 .19006 .65981 .18871 Metetra
.664 .741 .907 r
.65981 .18871 .66079 .19006 .6675 .18765 .66652 .1863 Metetra
.664 .741 .907 r
.66652 .1863 .6675 .18765 .67422 .18523 .67325 .18388 Metetra
.664 .741 .907 r
.67325 .18388 .67422 .18523 .68096 .1828 .67999 .18145 Metetra
.664 .741 .907 r
.67999 .18145 .68096 .1828 .68772 .18037 .68675 .17901 Metetra
.664 .741 .907 r
.68675 .17901 .68772 .18037 .69449 .17794 .69352 .17657 Metetra
.664 .741 .907 r
.69352 .17657 .69449 .17794 .70127 .17549 .70031 .17413 Metetra
.664 .741 .907 r
.70031 .17413 .70127 .17549 .70808 .17305 .70712 .17168 Metetra
.664 .741 .907 r
.70712 .17168 .70808 .17305 .7149 .17059 .71394 .16922 Metetra
.664 .741 .907 r
.71394 .16922 .7149 .17059 .72173 .16813 .72078 .16676 Metetra
.664 .741 .907 r
.72078 .16676 .72173 .16813 .72859 .16567 .72764 .16429 Metetra
.664 .741 .907 r
.72764 .16429 .72859 .16567 .73546 .1632 .73451 .16182 Metetra
.664 .741 .907 r
.73451 .16182 .73546 .1632 .74234 .16072 .7414 .15933 Metetra
.664 .741 .907 r
.7414 .15933 .74234 .16072 .74924 .15824 .74831 .15685 Metetra
.664 .741 .907 r
.74831 .15685 .74924 .15824 .75616 .15575 .75523 .15436 Metetra
.664 .741 .907 r
.75523 .15436 .75616 .15575 .7631 .15325 .76217 .15186 Metetra
.664 .741 .907 r
.76217 .15186 .7631 .15325 .77005 .15075 .76912 .14935 Metetra
.664 .741 .907 r
.76912 .14935 .77005 .15075 .77702 .14824 .7761 .14684 Metetra
.664 .741 .907 r
.7761 .14684 .77702 .14824 .78401 .14573 .78309 .14432 Metetra
.664 .741 .907 r
.1579 .3679 .15909 .36902 .16466 .36701 .16347 .36589 Metetra
.664 .741 .907 r
.16347 .36589 .16466 .36701 .17025 .365 .16905 .36388 Metetra
.664 .741 .907 r
.16905 .36388 .17025 .365 .17584 .36299 .17465 .36186 Metetra
.664 .741 .907 r
.17465 .36186 .17584 .36299 .18145 .36097 .18026 .35984 Metetra
.664 .741 .907 r
.18026 .35984 .18145 .36097 .18706 .35894 .18588 .35781 Metetra
.664 .741 .907 r
.18588 .35781 .18706 .35894 .19269 .35692 .19151 .35578 Metetra
.664 .741 .907 r
.19151 .35578 .19269 .35692 .19834 .35489 .19716 .35375 Metetra
.664 .741 .907 r
.19716 .35375 .19834 .35489 .20399 .35285 .20281 .35171 Metetra
.664 .741 .907 r
.20281 .35171 .20399 .35285 .20966 .35081 .20848 .34967 Metetra
.664 .741 .907 r
.20848 .34967 .20966 .35081 .21534 .34876 .21416 .34762 Metetra
.664 .741 .907 r
.21416 .34762 .21534 .34876 .22103 .34671 .21986 .34557 Metetra
.664 .741 .907 r
.21986 .34557 .22103 .34671 .22674 .34466 .22557 .34351 Metetra
.664 .741 .907 r
.22557 .34351 .22674 .34466 .23246 .3426 .23129 .34145 Metetra
.664 .741 .907 r
.23129 .34145 .23246 .3426 .23819 .34054 .23702 .33938 Metetra
.664 .741 .907 r
.23702 .33938 .23819 .34054 .24393 .33847 .24276 .33731 Metetra
.664 .741 .907 r
.24276 .33731 .24393 .33847 .24968 .3364 .24852 .33524 Metetra
.664 .741 .907 r
.24852 .33524 .24968 .3364 .25545 .33432 .25429 .33316 Metetra
.664 .741 .907 r
.25429 .33316 .25545 .33432 .26123 .33224 .26008 .33107 Metetra
.664 .741 .907 r
.26008 .33107 .26123 .33224 .26703 .33015 .26587 .32899 Metetra
.664 .741 .907 r
.26587 .32899 .26703 .33015 .27283 .32806 .27168 .32689 Metetra
.664 .741 .907 r
.27168 .32689 .27283 .32806 .27865 .32596 .2775 .32479 Metetra
.851 .403 0 r
.2775 .32479 .27865 .32596 .28449 .32386 .28239 .33505 Metetra
.284 .048 .368 r
.28239 .33505 .28449 .32386 .29033 .32176 .28918 .32058 Metetra
.664 .741 .907 r
.28918 .32058 .29033 .32176 .29619 .31965 .29504 .31847 Metetra
.664 .741 .907 r
.29504 .31847 .29619 .31965 .30206 .31754 .30092 .31635 Metetra
.664 .741 .907 r
.30092 .31635 .30206 .31754 .30794 .31542 .30681 .31423 Metetra
.664 .741 .907 r
.30681 .31423 .30794 .31542 .31384 .31329 .31271 .31211 Metetra
.664 .741 .907 r
.31271 .31211 .31384 .31329 .31975 .31117 .31862 .30998 Metetra
.664 .741 .907 r
.31862 .30998 .31975 .31117 .32568 .30903 .32454 .30784 Metetra
.664 .741 .907 r
.32454 .30784 .32568 .30903 .33161 .30689 .33048 .3057 Metetra
.664 .741 .907 r
.33048 .3057 .33161 .30689 .33756 .30475 .33644 .30355 Metetra
.664 .741 .907 r
.33644 .30355 .33756 .30475 .34353 .3026 .3424 .3014 Metetra
.664 .741 .907 r
.3424 .3014 .34353 .3026 .34951 .30045 .34838 .29925 Metetra
.664 .741 .907 r
.34838 .29925 .34951 .30045 .3555 .29829 .35438 .29709 Metetra
.664 .741 .907 r
.35438 .29709 .3555 .29829 .3615 .29613 .36038 .29492 Metetra
.664 .741 .907 r
.36038 .29492 .3615 .29613 .36752 .29397 .3664 .29275 Metetra
.664 .741 .907 r
.3664 .29275 .36752 .29397 .37355 .29179 .37244 .29058 Metetra
.664 .741 .907 r
.37244 .29058 .37355 .29179 .3796 .28962 .37849 .2884 Metetra
.664 .741 .907 r
.37849 .2884 .3796 .28962 .38565 .28743 .38455 .28622 Metetra
.664 .741 .907 r
.38455 .28622 .38565 .28743 .39173 .28525 .39062 .28403 Metetra
.664 .741 .907 r
.39062 .28403 .39173 .28525 .39781 .28306 .39671 .28183 Metetra
.664 .741 .907 r
.39671 .28183 .39781 .28306 .40391 .28086 .40281 .27963 Metetra
.664 .741 .907 r
.40281 .27963 .40391 .28086 .41003 .27866 .40893 .27743 Metetra
.664 .741 .907 r
.40893 .27743 .41003 .27866 .41615 .27645 .41506 .27522 Metetra
.664 .741 .907 r
.41506 .27522 .41615 .27645 .4223 .27424 .42121 .273 Metetra
.664 .741 .907 r
.42121 .273 .4223 .27424 .42845 .27202 .42736 .27079 Metetra
.664 .741 .907 r
.42736 .27079 .42845 .27202 .43462 .2698 .43354 .26856 Metetra
.664 .741 .907 r
.43354 .26856 .43462 .2698 .44081 .26758 .43972 .26633 Metetra
.664 .741 .907 r
.43972 .26633 .44081 .26758 .447 .26534 .44592 .2641 Metetra
.664 .741 .907 r
.44592 .2641 .447 .26534 .45322 .26311 .45214 .26186 Metetra
.664 .741 .907 r
.45214 .26186 .45322 .26311 .45944 .26086 .45837 .25961 Metetra
.664 .741 .907 r
.45837 .25961 .45944 .26086 .46568 .25862 .46461 .25736 Metetra
.664 .741 .907 r
.46461 .25736 .46568 .25862 .47194 .25636 .47087 .25511 Metetra
.664 .741 .907 r
.47087 .25511 .47194 .25636 .47821 .25411 .47714 .25285 Metetra
.664 .741 .907 r
.47714 .25285 .47821 .25411 .48449 .25184 .48343 .25058 Metetra
.664 .741 .907 r
.48343 .25058 .48449 .25184 .48925 .38879 .48973 .24831 Metetra
.503 .285 .515 r
.48973 .24831 .48925 .38879 .4971 .2473 .49579 .27383 Metetra
.351 .14 .447 r
.49579 .27383 .4971 .2473 .50343 .24502 .50238 .24375 Metetra
.664 .741 .907 r
.50238 .24375 .50343 .24502 .50978 .24274 .50872 .24146 Metetra
.664 .741 .907 r
.50872 .24146 .50978 .24274 .51613 .24045 .51508 .23917 Metetra
.664 .741 .907 r
.51508 .23917 .51613 .24045 .5225 .23816 .52146 .23687 Metetra
.664 .741 .907 r
.52146 .23687 .5225 .23816 .52889 .23586 .52785 .23457 Metetra
.664 .741 .907 r
.52785 .23457 .52889 .23586 .53529 .23355 .53425 .23226 Metetra
.664 .741 .907 r
.53425 .23226 .53529 .23355 .54171 .23124 .54067 .22995 Metetra
.664 .741 .907 r
.54067 .22995 .54171 .23124 .54814 .22893 .54711 .22763 Metetra
.664 .741 .907 r
.54711 .22763 .54814 .22893 .55459 .2266 .55355 .22531 Metetra
.664 .741 .907 r
.55355 .22531 .55459 .2266 .56105 .22428 .56002 .22298 Metetra
.664 .741 .907 r
.56002 .22298 .56105 .22428 .56752 .22195 .5665 .22064 Metetra
.664 .741 .907 r
.5665 .22064 .56752 .22195 .57402 .21961 .57299 .2183 Metetra
.664 .741 .907 r
.57299 .2183 .57402 .21961 .58052 .21727 .5795 .21596 Metetra
.664 .741 .907 r
.5795 .21596 .58052 .21727 .58705 .21492 .58603 .2136 Metetra
.664 .741 .907 r
.58603 .2136 .58705 .21492 .59358 .21256 .59257 .21125 Metetra
.664 .741 .907 r
.59257 .21125 .59358 .21256 .60014 .2102 .59913 .20888 Metetra
.664 .741 .907 r
.59913 .20888 .60014 .2102 .6067 .20784 .6057 .20652 Metetra
.664 .741 .907 r
.6057 .20652 .6067 .20784 .61329 .20547 .61228 .20414 Metetra
.664 .741 .907 r
.61228 .20414 .61329 .20547 .61989 .20309 .61889 .20176 Metetra
.664 .741 .907 r
.61889 .20176 .61989 .20309 .6265 .20071 .62551 .19938 Metetra
.664 .741 .907 r
.62551 .19938 .6265 .20071 .63313 .19832 .63214 .19699 Metetra
.664 .741 .907 r
.63214 .19699 .63313 .19832 .63978 .19593 .63879 .19459 Metetra
.664 .741 .907 r
.63879 .19459 .63978 .19593 .64644 .19353 .64545 .19219 Metetra
.664 .741 .907 r
.64545 .19219 .64644 .19353 .65312 .19112 .65214 .18978 Metetra
.664 .741 .907 r
.65214 .18978 .65312 .19112 .65981 .18871 .65883 .18737 Metetra
.664 .741 .907 r
.65883 .18737 .65981 .18871 .66652 .1863 .66555 .18495 Metetra
.664 .741 .907 r
.66555 .18495 .66652 .1863 .67325 .18388 .67227 .18252 Metetra
.664 .741 .907 r
.67227 .18252 .67325 .18388 .67999 .18145 .67902 .18009 Metetra
.664 .741 .907 r
.67902 .18009 .67999 .18145 .68675 .17901 .68578 .17765 Metetra
.664 .741 .907 r
.68578 .17765 .68675 .17901 .69352 .17657 .69256 .17521 Metetra
.664 .741 .907 r
.69256 .17521 .69352 .17657 .70031 .17413 .69935 .17276 Metetra
.664 .741 .907 r
.69935 .17276 .70031 .17413 .70712 .17168 .70616 .17031 Metetra
.664 .741 .907 r
.70616 .17031 .70712 .17168 .71394 .16922 .71299 .16785 Metetra
.664 .741 .907 r
.71299 .16785 .71394 .16922 .72078 .16676 .71983 .16538 Metetra
.664 .741 .907 r
.71983 .16538 .72078 .16676 .72764 .16429 .72669 .16291 Metetra
.664 .741 .907 r
.72669 .16291 .72764 .16429 .73451 .16182 .73357 .16043 Metetra
.664 .741 .907 r
.73357 .16043 .73451 .16182 .7414 .15933 .74046 .15795 Metetra
.664 .741 .907 r
.74046 .15795 .7414 .15933 .74831 .15685 .74737 .15546 Metetra
.664 .741 .907 r
.74737 .15546 .74831 .15685 .75523 .15436 .7543 .15296 Metetra
.664 .741 .907 r
.7543 .15296 .75523 .15436 .76217 .15186 .76124 .15046 Metetra
.664 .741 .907 r
.76124 .15046 .76217 .15186 .76912 .14935 .7682 .14795 Metetra
.664 .741 .907 r
.7682 .14795 .76912 .14935 .7761 .14684 .77517 .14544 Metetra
.664 .741 .907 r
.77517 .14544 .7761 .14684 .78309 .14432 .78217 .14292 Metetra
.664 .741 .907 r
.1567 .36678 .1579 .3679 .16347 .36589 .16227 .36477 Metetra
.664 .741 .907 r
.16227 .36477 .16347 .36589 .16905 .36388 .16786 .36275 Metetra
.664 .741 .907 r
.16786 .36275 .16905 .36388 .17465 .36186 .17346 .36073 Metetra
.664 .741 .907 r
.17346 .36073 .17465 .36186 .18026 .35984 .17907 .35871 Metetra
.664 .741 .907 r
.17907 .35871 .18026 .35984 .18588 .35781 .18469 .35668 Metetra
.664 .741 .907 r
.18469 .35668 .18588 .35781 .19151 .35578 .19032 .35465 Metetra
.664 .741 .907 r
.19032 .35465 .19151 .35578 .19716 .35375 .19597 .35261 Metetra
.664 .741 .907 r
.19597 .35261 .19716 .35375 .20281 .35171 .20163 .35057 Metetra
.664 .741 .907 r
.20163 .35057 .20281 .35171 .20848 .34967 .2073 .34853 Metetra
.664 .741 .907 r
.2073 .34853 .20848 .34967 .21416 .34762 .21299 .34648 Metetra
.664 .741 .907 r
.21299 .34648 .21416 .34762 .21986 .34557 .21868 .34442 Metetra
.664 .741 .907 r
.21868 .34442 .21986 .34557 .22557 .34351 .22439 .34236 Metetra
.664 .741 .907 r
.22439 .34236 .22557 .34351 .23129 .34145 .23012 .3403 Metetra
.664 .741 .907 r
.23012 .3403 .23129 .34145 .23702 .33938 .23585 .33823 Metetra
.664 .741 .907 r
.23585 .33823 .23702 .33938 .24276 .33731 .2416 .33616 Metetra
.664 .741 .907 r
.2416 .33616 .24276 .33731 .24852 .33524 .24736 .33408 Metetra
.664 .741 .907 r
.24736 .33408 .24852 .33524 .25429 .33316 .25313 .332 Metetra
.664 .741 .907 r
.25313 .332 .25429 .33316 .26008 .33107 .25892 .32991 Metetra
.664 .741 .907 r
.25892 .32991 .26008 .33107 .26587 .32899 .26471 .32782 Metetra
.664 .741 .907 r
.26471 .32782 .26587 .32899 .27168 .32689 .27053 .32572 Metetra
.664 .741 .907 r
.27053 .32572 .27168 .32689 .2775 .32479 .27635 .32362 Metetra
.664 .741 .907 r
.27635 .32362 .2775 .32479 .28239 .33505 .28219 .32152 Metetra
.553 .358 .571 r
.28219 .32152 .28239 .33505 .28918 .32058 .28804 .31941 Metetra
.664 .741 .907 r
.28804 .31941 .28918 .32058 .29504 .31847 .2939 .31729 Metetra
.664 .741 .907 r
.2939 .31729 .29504 .31847 .30092 .31635 .29978 .31517 Metetra
.664 .741 .907 r
.29978 .31517 .30092 .31635 .30681 .31423 .30566 .31305 Metetra
.664 .741 .907 r
.30566 .31305 .30681 .31423 .31271 .31211 .31157 .31092 Metetra
.664 .741 .907 r
.31157 .31092 .31271 .31211 .31862 .30998 .31748 .30879 Metetra
.664 .741 .907 r
.31748 .30879 .31862 .30998 .32454 .30784 .32341 .30665 Metetra
.664 .741 .907 r
.32341 .30665 .32454 .30784 .33048 .3057 .32935 .3045 Metetra
.664 .741 .907 r
.32935 .3045 .33048 .3057 .33644 .30355 .33531 .30236 Metetra
.664 .741 .907 r
.33531 .30236 .33644 .30355 .3424 .3014 .34128 .3002 Metetra
.664 .741 .907 r
.34128 .3002 .3424 .3014 .34838 .29925 .34726 .29804 Metetra
.664 .741 .907 r
.34726 .29804 .34838 .29925 .35438 .29709 .35326 .29588 Metetra
.664 .741 .907 r
.35326 .29588 .35438 .29709 .36038 .29492 .35927 .29371 Metetra
.664 .741 .907 r
.35927 .29371 .36038 .29492 .3664 .29275 .36529 .29154 Metetra
.664 .741 .907 r
.36529 .29154 .3664 .29275 .37244 .29058 .37132 .28936 Metetra
.664 .741 .907 r
.37132 .28936 .37244 .29058 .37849 .2884 .37738 .28718 Metetra
.664 .741 .907 r
.37738 .28718 .37849 .2884 .38455 .28622 .38344 .285 Metetra
.959 .634 .358 r
.38344 .285 .38455 .28622 .39062 .28403 .38761 .32663 Metetra
.35 .144 .454 r
.38761 .32663 .39062 .28403 .39671 .28183 .39561 .28061 Metetra
.664 .741 .907 r
.39561 .28061 .39671 .28183 .40281 .27963 .40171 .2784 Metetra
.664 .741 .907 r
.40171 .2784 .40281 .27963 .40893 .27743 .40783 .2762 Metetra
.664 .741 .907 r
.40783 .2762 .40893 .27743 .41506 .27522 .41397 .27398 Metetra
.664 .741 .907 r
.41397 .27398 .41506 .27522 .42121 .273 .42011 .27177 Metetra
.664 .741 .907 r
.42011 .27177 .42121 .273 .42736 .27079 .42627 .26955 Metetra
.664 .741 .907 r
.42627 .26955 .42736 .27079 .43354 .26856 .43245 .26732 Metetra
.664 .741 .907 r
.43245 .26732 .43354 .26856 .43972 .26633 .43864 .26509 Metetra
.664 .741 .907 r
.43864 .26509 .43972 .26633 .44592 .2641 .44484 .26285 Metetra
.664 .741 .907 r
.44484 .26285 .44592 .2641 .45214 .26186 .45106 .26061 Metetra
.664 .741 .907 r
.45106 .26061 .45214 .26186 .45837 .25961 .45729 .25836 Metetra
.664 .741 .907 r
.45729 .25836 .45837 .25961 .46461 .25736 .46354 .2561 Metetra
.664 .741 .907 r
.46354 .2561 .46461 .25736 .47087 .25511 .4698 .25385 Metetra
.664 .741 .907 r
.4698 .25385 .47087 .25511 .47714 .25285 .47607 .25158 Metetra
.664 .741 .907 r
.47607 .25158 .47714 .25285 .48343 .25058 .48236 .24931 Metetra
.664 .741 .907 r
.48236 .24931 .48343 .25058 .48973 .24831 .48867 .24704 Metetra
.664 .741 .907 r
.48867 .24704 .48973 .24831 .49579 .27383 .49499 .24476 Metetra
.54 .328 .541 r
.49499 .24476 .49579 .27383 .50238 .24375 .50132 .24248 Metetra
.664 .741 .907 r
.50132 .24248 .50238 .24375 .50872 .24146 .50767 .24019 Metetra
.664 .741 .907 r
.50767 .24019 .50872 .24146 .51508 .23917 .51403 .23789 Metetra
.664 .741 .907 r
.51403 .23789 .51508 .23917 .52146 .23687 .52041 .23559 Metetra
.664 .741 .907 r
.52041 .23559 .52146 .23687 .52785 .23457 .5268 .23329 Metetra
.664 .741 .907 r
.5268 .23329 .52785 .23457 .53425 .23226 .53321 .23097 Metetra
.664 .741 .907 r
.53321 .23097 .53425 .23226 .54067 .22995 .53963 .22866 Metetra
.664 .741 .907 r
.53963 .22866 .54067 .22995 .54711 .22763 .54607 .22634 Metetra
.664 .741 .907 r
.54607 .22634 .54711 .22763 .55355 .22531 .55252 .22401 Metetra
.664 .741 .907 r
.55252 .22401 .55355 .22531 .56002 .22298 .55899 .22168 Metetra
.664 .741 .907 r
.55899 .22168 .56002 .22298 .5665 .22064 .56547 .21934 Metetra
.664 .741 .907 r
.56547 .21934 .5665 .22064 .57299 .2183 .57197 .21699 Metetra
.664 .741 .907 r
.57197 .21699 .57299 .2183 .5795 .21596 .57848 .21464 Metetra
.664 .741 .907 r
.57848 .21464 .5795 .21596 .58603 .2136 .58501 .21229 Metetra
.664 .741 .907 r
.58501 .21229 .58603 .2136 .59257 .21125 .59155 .20993 Metetra
.664 .741 .907 r
.59155 .20993 .59257 .21125 .59913 .20888 .59811 .20756 Metetra
.664 .741 .907 r
.59811 .20756 .59913 .20888 .6057 .20652 .60469 .20519 Metetra
.664 .741 .907 r
.60469 .20519 .6057 .20652 .61228 .20414 .61128 .20282 Metetra
.664 .741 .907 r
.61128 .20282 .61228 .20414 .61889 .20176 .61788 .20043 Metetra
.664 .741 .907 r
.61788 .20043 .61889 .20176 .62551 .19938 .62451 .19804 Metetra
.664 .741 .907 r
.62451 .19804 .62551 .19938 .63214 .19699 .63114 .19565 Metetra
.664 .741 .907 r
.63114 .19565 .63214 .19699 .63879 .19459 .6378 .19325 Metetra
.664 .741 .907 r
.6378 .19325 .63879 .19459 .64545 .19219 .64446 .19085 Metetra
.664 .741 .907 r
.64446 .19085 .64545 .19219 .65214 .18978 .65115 .18843 Metetra
.664 .741 .907 r
.65115 .18843 .65214 .18978 .65883 .18737 .65785 .18602 Metetra
.664 .741 .907 r
.65785 .18602 .65883 .18737 .66555 .18495 .66457 .1836 Metetra
.664 .741 .907 r
.66457 .1836 .66555 .18495 .67227 .18252 .6713 .18117 Metetra
.664 .741 .907 r
.6713 .18117 .67227 .18252 .67902 .18009 .67805 .17873 Metetra
.664 .741 .907 r
.67805 .17873 .67902 .18009 .68578 .17765 .68481 .17629 Metetra
.664 .741 .907 r
.68481 .17629 .68578 .17765 .69256 .17521 .69159 .17385 Metetra
.664 .741 .907 r
.69159 .17385 .69256 .17521 .69935 .17276 .69839 .1714 Metetra
.664 .741 .907 r
.69839 .1714 .69935 .17276 .70616 .17031 .7052 .16894 Metetra
.664 .741 .907 r
.7052 .16894 .70616 .17031 .71299 .16785 .71203 .16647 Metetra
.664 .741 .907 r
.71203 .16647 .71299 .16785 .71983 .16538 .71888 .164 Metetra
.664 .741 .907 r
.71888 .164 .71983 .16538 .72669 .16291 .72574 .16153 Metetra
.664 .741 .907 r
.72574 .16153 .72669 .16291 .73357 .16043 .73262 .15905 Metetra
.664 .741 .907 r
.73262 .15905 .73357 .16043 .74046 .15795 .73952 .15656 Metetra
.664 .741 .907 r
.73952 .15656 .74046 .15795 .74737 .15546 .74643 .15407 Metetra
.664 .741 .907 r
.74643 .15407 .74737 .15546 .7543 .15296 .75336 .15157 Metetra
.664 .741 .907 r
.75336 .15157 .7543 .15296 .76124 .15046 .76031 .14906 Metetra
.664 .741 .907 r
.76031 .14906 .76124 .15046 .7682 .14795 .76727 .14655 Metetra
.664 .741 .907 r
.76727 .14655 .7682 .14795 .77517 .14544 .77425 .14403 Metetra
.664 .741 .907 r
.77425 .14403 .77517 .14544 .78217 .14292 .78125 .14151 Metetra
.664 .741 .907 r
.1555 .36566 .1567 .36678 .16227 .36477 .16107 .36365 Metetra
.664 .741 .907 r
.16107 .36365 .16227 .36477 .16786 .36275 .16666 .36163 Metetra
.664 .741 .907 r
.16666 .36163 .16786 .36275 .17346 .36073 .17226 .35961 Metetra
.664 .741 .907 r
.17226 .35961 .17346 .36073 .17907 .35871 .17787 .35758 Metetra
.664 .741 .907 r
.17787 .35758 .17907 .35871 .18469 .35668 .1835 .35555 Metetra
.664 .741 .907 r
.1835 .35555 .18469 .35668 .19032 .35465 .18914 .35351 Metetra
.664 .741 .907 r
.18914 .35351 .19032 .35465 .19597 .35261 .19479 .35148 Metetra
.664 .741 .907 r
.19479 .35148 .19597 .35261 .20163 .35057 .20045 .34943 Metetra
.664 .741 .907 r
.20045 .34943 .20163 .35057 .2073 .34853 .20612 .34738 Metetra
.664 .741 .907 r
.20612 .34738 .2073 .34853 .21299 .34648 .21181 .34533 Metetra
.664 .741 .907 r
.21181 .34533 .21299 .34648 .21868 .34442 .21751 .34327 Metetra
.664 .741 .907 r
.21751 .34327 .21868 .34442 .22439 .34236 .22322 .34121 Metetra
.664 .741 .907 r
.22322 .34121 .22439 .34236 .23012 .3403 .22894 .33914 Metetra
.664 .741 .907 r
.22894 .33914 .23012 .3403 .23585 .33823 .23468 .33707 Metetra
.664 .741 .907 r
.23468 .33707 .23585 .33823 .2416 .33616 .24043 .335 Metetra
.664 .741 .907 r
.24043 .335 .2416 .33616 .24736 .33408 .24619 .33292 Metetra
.664 .741 .907 r
.24619 .33292 .24736 .33408 .25313 .332 .25197 .33083 Metetra
.664 .741 .907 r
.25197 .33083 .25313 .332 .25892 .32991 .25775 .32874 Metetra
.664 .741 .907 r
.25775 .32874 .25892 .32991 .26471 .32782 .26356 .32665 Metetra
.664 .741 .907 r
.26356 .32665 .26471 .32782 .27053 .32572 .26937 .32455 Metetra
.664 .741 .907 r
.26937 .32455 .27053 .32572 .27635 .32362 .2752 .32245 Metetra
.664 .741 .907 r
.2752 .32245 .27635 .32362 .28219 .32152 .28103 .32034 Metetra
.664 .741 .907 r
.28103 .32034 .28219 .32152 .28804 .31941 .28689 .31823 Metetra
.664 .741 .907 r
.28689 .31823 .28804 .31941 .2939 .31729 .29275 .31611 Metetra
.664 .741 .907 r
.29275 .31611 .2939 .31729 .29978 .31517 .29863 .31399 Metetra
.664 .741 .907 r
.29863 .31399 .29978 .31517 .30566 .31305 .30452 .31186 Metetra
.664 .741 .907 r
.30452 .31186 .30566 .31305 .31157 .31092 .31043 .30973 Metetra
.664 .741 .907 r
.31043 .30973 .31157 .31092 .31748 .30879 .31635 .30759 Metetra
.664 .741 .907 r
.31635 .30759 .31748 .30879 .32341 .30665 .32228 .30545 Metetra
.664 .741 .907 r
.32228 .30545 .32341 .30665 .32935 .3045 .32822 .30331 Metetra
.664 .741 .907 r
.32822 .30331 .32935 .3045 .33531 .30236 .33418 .30116 Metetra
.664 .741 .907 r
.33418 .30116 .33531 .30236 .34128 .3002 .34015 .299 Metetra
.664 .741 .907 r
.34015 .299 .34128 .3002 .34726 .29804 .34614 .29684 Metetra
.664 .741 .907 r
.34614 .29684 .34726 .29804 .35326 .29588 .35213 .29467 Metetra
.664 .741 .907 r
.35213 .29467 .35326 .29588 .35927 .29371 .35815 .2925 Metetra
.664 .741 .907 r
.35815 .2925 .35927 .29371 .36529 .29154 .36417 .29033 Metetra
.664 .741 .907 r
.36417 .29033 .36529 .29154 .37132 .28936 .37021 .28815 Metetra
.664 .741 .907 r
.37021 .28815 .37132 .28936 .37738 .28718 .37626 .28596 Metetra
.91 .506 .132 r
.37626 .28596 .37738 .28718 .38344 .285 .38149 .30199 Metetra
.887 .603 .5 r
.38149 .30199 .38344 .285 .38761 .32663 .37816 .51466 Metetra
.33 .139 .463 r
.37816 .51466 .38761 .32663 .39561 .28061 .39391 .29348 Metetra
.307 .078 .393 r
.39391 .29348 .39561 .28061 .40171 .2784 .40061 .27717 Metetra
.664 .741 .907 r
.40061 .27717 .40171 .2784 .40783 .2762 .40673 .27496 Metetra
.664 .741 .907 r
.40673 .27496 .40783 .2762 .41397 .27398 .41287 .27275 Metetra
.664 .741 .907 r
.41287 .27275 .41397 .27398 .42011 .27177 .41902 .27053 Metetra
.664 .741 .907 r
.41902 .27053 .42011 .27177 .42627 .26955 .42518 .2683 Metetra
.664 .741 .907 r
.42518 .2683 .42627 .26955 .43245 .26732 .43136 .26607 Metetra
.664 .741 .907 r
.43136 .26607 .43245 .26732 .43864 .26509 .43755 .26384 Metetra
.664 .741 .907 r
.43755 .26384 .43864 .26509 .44484 .26285 .44376 .2616 Metetra
.664 .741 .907 r
.44376 .2616 .44484 .26285 .45106 .26061 .44998 .25935 Metetra
.664 .741 .907 r
.44998 .25935 .45106 .26061 .45729 .25836 .45621 .2571 Metetra
.664 .741 .907 r
.45621 .2571 .45729 .25836 .46354 .2561 .46246 .25485 Metetra
.664 .741 .907 r
.46246 .25485 .46354 .2561 .4698 .25385 .46873 .25258 Metetra
.664 .741 .907 r
.46873 .25258 .4698 .25385 .47607 .25158 .47501 .25032 Metetra
.664 .741 .907 r
.47501 .25032 .47607 .25158 .48236 .24931 .4813 .24805 Metetra
.664 .741 .907 r
.4813 .24805 .48236 .24931 .48867 .24704 .4876 .24577 Metetra
.664 .741 .907 r
.4876 .24577 .48867 .24704 .49499 .24476 .49393 .24349 Metetra
.664 .741 .907 r
.49393 .24349 .49499 .24476 .50132 .24248 .50026 .2412 Metetra
.664 .741 .907 r
.50026 .2412 .50132 .24248 .50767 .24019 .50661 .23891 Metetra
.664 .741 .907 r
.50661 .23891 .50767 .24019 .51403 .23789 .51298 .23661 Metetra
.664 .741 .907 r
.51298 .23661 .51403 .23789 .52041 .23559 .51936 .23431 Metetra
.664 .741 .907 r
.51936 .23431 .52041 .23559 .5268 .23329 .52576 .232 Metetra
.664 .741 .907 r
.52576 .232 .5268 .23329 .53321 .23097 .53217 .22968 Metetra
.664 .741 .907 r
.53217 .22968 .53321 .23097 .53963 .22866 .53859 .22736 Metetra
.664 .741 .907 r
.53859 .22736 .53963 .22866 .54607 .22634 .54503 .22504 Metetra
.664 .741 .907 r
.54503 .22504 .54607 .22634 .55252 .22401 .55149 .22271 Metetra
.664 .741 .907 r
.55149 .22271 .55252 .22401 .55899 .22168 .55796 .22037 Metetra
.664 .741 .907 r
.55796 .22037 .55899 .22168 .56547 .21934 .56444 .21803 Metetra
.664 .741 .907 r
.56444 .21803 .56547 .21934 .57197 .21699 .57094 .21568 Metetra
.664 .741 .907 r
.57094 .21568 .57197 .21699 .57848 .21464 .57746 .21333 Metetra
.664 .741 .907 r
.57746 .21333 .57848 .21464 .58501 .21229 .58399 .21097 Metetra
.664 .741 .907 r
.58399 .21097 .58501 .21229 .59155 .20993 .59054 .20861 Metetra
.664 .741 .907 r
.59054 .20861 .59155 .20993 .59811 .20756 .5971 .20624 Metetra
.664 .741 .907 r
.5971 .20624 .59811 .20756 .60469 .20519 .60368 .20387 Metetra
.664 .741 .907 r
.60368 .20387 .60469 .20519 .61128 .20282 .61027 .20149 Metetra
.664 .741 .907 r
.61027 .20149 .61128 .20282 .61788 .20043 .61688 .1991 Metetra
.664 .741 .907 r
.61688 .1991 .61788 .20043 .62451 .19804 .62351 .19671 Metetra
.664 .741 .907 r
.62351 .19671 .62451 .19804 .63114 .19565 .63015 .19431 Metetra
.664 .741 .907 r
.63015 .19431 .63114 .19565 .6378 .19325 .6368 .19191 Metetra
.664 .741 .907 r
.6368 .19191 .6378 .19325 .64446 .19085 .64347 .1895 Metetra
.664 .741 .907 r
.64347 .1895 .64446 .19085 .65115 .18843 .65016 .18709 Metetra
.664 .741 .907 r
.65016 .18709 .65115 .18843 .65785 .18602 .65687 .18467 Metetra
.664 .741 .907 r
.65687 .18467 .65785 .18602 .66457 .1836 .66359 .18224 Metetra
.664 .741 .907 r
.66359 .18224 .66457 .1836 .6713 .18117 .67032 .17981 Metetra
.664 .741 .907 r
.67032 .17981 .6713 .18117 .67805 .17873 .67707 .17737 Metetra
.664 .741 .907 r
.67707 .17737 .67805 .17873 .68481 .17629 .68384 .17493 Metetra
.664 .741 .907 r
.68384 .17493 .68481 .17629 .69159 .17385 .69063 .17248 Metetra
.691 .255 0 r
.69063 .17248 .69159 .17385 .69839 .1714 .69833 .18576 Metetra
.346 .124 .428 r
.69833 .18576 .69839 .1714 .7052 .16894 .70424 .16756 Metetra
.664 .741 .907 r
.70424 .16756 .7052 .16894 .71203 .16647 .71108 .1651 Metetra
.94 .586 .183 r
.71108 .1651 .71203 .16647 .71888 .164 .72138 .21609 Metetra
.382 .182 .48 r
.72138 .21609 .71888 .164 .72574 .16153 .72479 .16015 Metetra
.664 .741 .907 r
.72479 .16015 .72574 .16153 .73262 .15905 .73168 .15766 Metetra
.664 .741 .907 r
.73168 .15766 .73262 .15905 .73952 .15656 .73857 .15517 Metetra
.664 .741 .907 r
.73857 .15517 .73952 .15656 .74643 .15407 .74549 .15267 Metetra
.664 .741 .907 r
.74549 .15267 .74643 .15407 .75336 .15157 .75242 .15017 Metetra
.664 .741 .907 r
.75242 .15017 .75336 .15157 .76031 .14906 .75937 .14766 Metetra
.664 .741 .907 r
.75937 .14766 .76031 .14906 .76727 .14655 .76634 .14515 Metetra
.664 .741 .907 r
.76634 .14515 .76727 .14655 .77425 .14403 .77332 .14263 Metetra
.664 .741 .907 r
.77332 .14263 .77425 .14403 .78125 .14151 .78033 .1401 Metetra
.664 .741 .907 r
.1543 .36454 .1555 .36566 .16107 .36365 .15987 .36252 Metetra
.664 .741 .907 r
.15987 .36252 .16107 .36365 .16666 .36163 .16546 .3605 Metetra
.664 .741 .907 r
.16546 .3605 .16666 .36163 .17226 .35961 .17107 .35848 Metetra
.664 .741 .907 r
.17107 .35848 .17226 .35961 .17787 .35758 .17668 .35645 Metetra
.664 .741 .907 r
.17668 .35645 .17787 .35758 .1835 .35555 .18231 .35442 Metetra
.664 .741 .907 r
.18231 .35442 .1835 .35555 .18914 .35351 .18795 .35238 Metetra
.664 .741 .907 r
.18795 .35238 .18914 .35351 .19479 .35148 .1936 .35034 Metetra
.664 .741 .907 r
.1936 .35034 .19479 .35148 .20045 .34943 .19926 .34829 Metetra
.664 .741 .907 r
.19926 .34829 .20045 .34943 .20612 .34738 .20494 .34624 Metetra
.664 .741 .907 r
.20494 .34624 .20612 .34738 .21181 .34533 .21063 .34418 Metetra
.664 .741 .907 r
.21063 .34418 .21181 .34533 .21751 .34327 .21633 .34212 Metetra
.664 .741 .907 r
.21633 .34212 .21751 .34327 .22322 .34121 .22204 .34006 Metetra
.664 .741 .907 r
.22204 .34006 .22322 .34121 .22894 .33914 .22777 .33799 Metetra
.664 .741 .907 r
.22777 .33799 .22894 .33914 .23468 .33707 .23351 .33592 Metetra
.664 .741 .907 r
.23351 .33592 .23468 .33707 .24043 .335 .23926 .33384 Metetra
.664 .741 .907 r
.23926 .33384 .24043 .335 .24619 .33292 .24503 .33176 Metetra
.664 .741 .907 r
.24503 .33176 .24619 .33292 .25197 .33083 .2508 .32967 Metetra
.664 .741 .907 r
.2508 .32967 .25197 .33083 .25775 .32874 .25659 .32758 Metetra
.664 .741 .907 r
.25659 .32758 .25775 .32874 .26356 .32665 .2624 .32548 Metetra
.664 .741 .907 r
.2624 .32548 .26356 .32665 .26937 .32455 .26821 .32338 Metetra
.664 .741 .907 r
.26821 .32338 .26937 .32455 .2752 .32245 .27404 .32127 Metetra
.664 .741 .907 r
.27404 .32127 .2752 .32245 .28103 .32034 .27988 .31916 Metetra
.664 .741 .907 r
.27988 .31916 .28103 .32034 .28689 .31823 .28574 .31705 Metetra
.664 .741 .907 r
.28574 .31705 .28689 .31823 .29275 .31611 .2916 .31493 Metetra
.664 .741 .907 r
.2916 .31493 .29275 .31611 .29863 .31399 .29749 .3128 Metetra
.664 .741 .907 r
.29749 .3128 .29863 .31399 .30452 .31186 .30338 .31067 Metetra
.664 .741 .907 r
.30338 .31067 .30452 .31186 .31043 .30973 .30929 .30854 Metetra
.664 .741 .907 r
.30929 .30854 .31043 .30973 .31635 .30759 .31521 .3064 Metetra
.664 .741 .907 r
.31521 .3064 .31635 .30759 .32228 .30545 .32114 .30426 Metetra
.664 .741 .907 r
.32114 .30426 .32228 .30545 .32822 .30331 .32709 .30211 Metetra
.664 .741 .907 r
.32709 .30211 .32822 .30331 .33418 .30116 .33305 .29995 Metetra
.664 .741 .907 r
.33305 .29995 .33418 .30116 .34015 .299 .33902 .2978 Metetra
.664 .741 .907 r
.33902 .2978 .34015 .299 .34614 .29684 .34501 .29563 Metetra
.664 .741 .907 r
.34501 .29563 .34614 .29684 .35213 .29467 .35101 .29346 Metetra
.664 .741 .907 r
.35101 .29346 .35213 .29467 .35815 .2925 .35702 .29129 Metetra
.664 .741 .907 r
.35702 .29129 .35815 .2925 .36417 .29033 .36305 .28911 Metetra
.664 .741 .907 r
.36305 .28911 .36417 .29033 .37021 .28815 .36909 .28693 Metetra
.664 .741 .907 r
.36909 .28693 .37021 .28815 .37626 .28596 .37515 .28474 Metetra
.961 .657 .407 r
.37515 .28474 .37626 .28596 .38149 .30199 .378 .352 Metetra
.748 .479 .523 r
.378 .352 .38149 .30199 .37816 .51466 .37703 .51194 Metetra
.955 .69 .493 r
.37703 .51194 .37816 .51466 .39391 .29348 .3934 .27815 Metetra
.55 .352 .564 r
.3934 .27815 .39391 .29348 .40061 .27717 .39951 .27594 Metetra
.664 .741 .907 r
.39951 .27594 .40061 .27717 .40673 .27496 .40563 .27373 Metetra
.664 .741 .907 r
.40563 .27373 .40673 .27496 .41287 .27275 .41177 .27151 Metetra
.664 .741 .907 r
.41177 .27151 .41287 .27275 .41902 .27053 .41792 .26929 Metetra
.664 .741 .907 r
.41792 .26929 .41902 .27053 .42518 .2683 .42409 .26706 Metetra
.664 .741 .907 r
.42409 .26706 .42518 .2683 .43136 .26607 .43027 .26483 Metetra
.664 .741 .907 r
.43027 .26483 .43136 .26607 .43755 .26384 .43647 .26259 Metetra
.664 .741 .907 r
.43647 .26259 .43755 .26384 .44376 .2616 .44267 .26035 Metetra
.664 .741 .907 r
.44267 .26035 .44376 .2616 .44998 .25935 .4489 .2581 Metetra
.664 .741 .907 r
.4489 .2581 .44998 .25935 .45621 .2571 .45514 .25584 Metetra
.664 .741 .907 r
.45514 .25584 .45621 .2571 .46246 .25485 .46139 .25358 Metetra
.664 .741 .907 r
.46139 .25358 .46246 .25485 .46873 .25258 .46765 .25132 Metetra
.664 .741 .907 r
.46765 .25132 .46873 .25258 .47501 .25032 .47393 .24905 Metetra
.664 .741 .907 r
.47393 .24905 .47501 .25032 .4813 .24805 .48023 .24678 Metetra
.664 .741 .907 r
.48023 .24678 .4813 .24805 .4876 .24577 .48654 .2445 Metetra
.664 .741 .907 r
.48654 .2445 .4876 .24577 .49393 .24349 .49286 .24221 Metetra
.664 .741 .907 r
.49286 .24221 .49393 .24349 .50026 .2412 .4992 .23992 Metetra
.664 .741 .907 r
.4992 .23992 .50026 .2412 .50661 .23891 .50556 .23763 Metetra
.664 .741 .907 r
.50556 .23763 .50661 .23891 .51298 .23661 .51193 .23533 Metetra
.664 .741 .907 r
.51193 .23533 .51298 .23661 .51936 .23431 .51831 .23302 Metetra
.664 .741 .907 r
.51831 .23302 .51936 .23431 .52576 .232 .52471 .23071 Metetra
.664 .741 .907 r
.52471 .23071 .52576 .232 .53217 .22968 .53112 .22839 Metetra
.664 .741 .907 r
.53112 .22839 .53217 .22968 .53859 .22736 .53755 .22607 Metetra
.664 .741 .907 r
.53755 .22607 .53859 .22736 .54503 .22504 .54399 .22374 Metetra
.664 .741 .907 r
.54399 .22374 .54503 .22504 .55149 .22271 .55045 .22141 Metetra
.664 .741 .907 r
.55045 .22141 .55149 .22271 .55796 .22037 .55692 .21907 Metetra
.664 .741 .907 r
.55692 .21907 .55796 .22037 .56444 .21803 .56341 .21672 Metetra
.664 .741 .907 r
.56341 .21672 .56444 .21803 .57094 .21568 .56992 .21437 Metetra
.664 .741 .907 r
.56992 .21437 .57094 .21568 .57746 .21333 .57644 .21202 Metetra
.664 .741 .907 r
.57644 .21202 .57746 .21333 .58399 .21097 .58297 .20966 Metetra
.664 .741 .907 r
.58297 .20966 .58399 .21097 .59054 .20861 .58952 .20729 Metetra
.664 .741 .907 r
.58952 .20729 .59054 .20861 .5971 .20624 .59609 .20492 Metetra
.664 .741 .907 r
.59609 .20492 .5971 .20624 .60368 .20387 .60267 .20254 Metetra
.664 .741 .907 r
.60267 .20254 .60368 .20387 .61027 .20149 .60926 .20016 Metetra
.664 .741 .907 r
.60926 .20016 .61027 .20149 .61688 .1991 .61588 .19777 Metetra
.664 .741 .907 r
.61588 .19777 .61688 .1991 .62351 .19671 .6225 .19537 Metetra
.664 .741 .907 r
.6225 .19537 .62351 .19671 .63015 .19431 .62915 .19297 Metetra
.664 .741 .907 r
.62915 .19297 .63015 .19431 .6368 .19191 .63581 .19057 Metetra
.664 .741 .907 r
.63581 .19057 .6368 .19191 .64347 .1895 .64248 .18816 Metetra
.664 .741 .907 r
.64248 .18816 .64347 .1895 .65016 .18709 .64917 .18574 Metetra
.664 .741 .907 r
.64917 .18574 .65016 .18709 .65687 .18467 .65588 .18331 Metetra
.664 .741 .907 r
.65588 .18331 .65687 .18467 .66359 .18224 .6626 .18089 Metetra
.664 .741 .907 r
.6626 .18089 .66359 .18224 .67032 .17981 .66934 .17845 Metetra
.664 .741 .907 r
.66934 .17845 .67032 .17981 .67707 .17737 .6761 .17601 Metetra
.664 .741 .907 r
.6761 .17601 .67707 .17737 .68384 .17493 .68287 .17356 Metetra
.664 .741 .907 r
.68287 .17356 .68384 .17493 .69063 .17248 .68966 .17111 Metetra
.664 .741 .907 r
.68966 .17111 .69063 .17248 .69833 .18576 .69646 .16865 Metetra
.548 .347 .56 r
.69646 .16865 .69833 .18576 .70424 .16756 .70328 .16619 Metetra
.664 .741 .907 r
.70328 .16619 .70424 .16756 .71108 .1651 .71012 .16372 Metetra
0 .337 .818 r
.71012 .16372 .71108 .1651 .72138 .21609 .71742 .16822 Metetra
.55 .328 .531 r
.71742 .16822 .72138 .21609 .72479 .16015 .72384 .15876 Metetra
.664 .741 .907 r
.72384 .15876 .72479 .16015 .73168 .15766 .73073 .15627 Metetra
.664 .741 .907 r
.73073 .15627 .73168 .15766 .73857 .15517 .73763 .15378 Metetra
.664 .741 .907 r
.73763 .15378 .73857 .15517 .74549 .15267 .74455 .15128 Metetra
.664 .741 .907 r
.74455 .15128 .74549 .15267 .75242 .15017 .75149 .14877 Metetra
.664 .741 .907 r
.75149 .14877 .75242 .15017 .75937 .14766 .75844 .14626 Metetra
.664 .741 .907 r
.75844 .14626 .75937 .14766 .76634 .14515 .76541 .14374 Metetra
.664 .741 .907 r
.76541 .14374 .76634 .14515 .77332 .14263 .7724 .14122 Metetra
.664 .741 .907 r
.7724 .14122 .77332 .14263 .78033 .1401 .7794 .13869 Metetra
.664 .741 .907 r
.15309 .36341 .1543 .36454 .15987 .36252 .15867 .36139 Metetra
.664 .741 .907 r
.15867 .36139 .15987 .36252 .16546 .3605 .16427 .35937 Metetra
.664 .741 .907 r
.16427 .35937 .16546 .3605 .17107 .35848 .16987 .35735 Metetra
.664 .741 .907 r
.16987 .35735 .17107 .35848 .17668 .35645 .17549 .35532 Metetra
.664 .741 .907 r
.17549 .35532 .17668 .35645 .18231 .35442 .18112 .35328 Metetra
.664 .741 .907 r
.18112 .35328 .18231 .35442 .18795 .35238 .18676 .35124 Metetra
.664 .741 .907 r
.18676 .35124 .18795 .35238 .1936 .35034 .19241 .3492 Metetra
.664 .741 .907 r
.19241 .3492 .1936 .35034 .19926 .34829 .19808 .34715 Metetra
.664 .741 .907 r
.19808 .34715 .19926 .34829 .20494 .34624 .20376 .34509 Metetra
.664 .741 .907 r
.20376 .34509 .20494 .34624 .21063 .34418 .20945 .34304 Metetra
.664 .741 .907 r
.20945 .34304 .21063 .34418 .21633 .34212 .21515 .34097 Metetra
.664 .741 .907 r
.21515 .34097 .21633 .34212 .22204 .34006 .22087 .33891 Metetra
.664 .741 .907 r
.22087 .33891 .22204 .34006 .22777 .33799 .22659 .33683 Metetra
.946 .609 .35 r
.22659 .33683 .22777 .33799 .23351 .33592 .22987 .36142 Metetra
.445 .209 .461 r
.22987 .36142 .23351 .33592 .23926 .33384 .23663 .34875 Metetra
.295 .067 .388 r
.23663 .34875 .23926 .33384 .24503 .33176 .24386 .33059 Metetra
.664 .741 .907 r
.24386 .33059 .24503 .33176 .2508 .32967 .24964 .3285 Metetra
.664 .741 .907 r
.24964 .3285 .2508 .32967 .25659 .32758 .25543 .32641 Metetra
.664 .741 .907 r
.25543 .32641 .25659 .32758 .2624 .32548 .26123 .32431 Metetra
.664 .741 .907 r
.26123 .32431 .2624 .32548 .26821 .32338 .26705 .3222 Metetra
.664 .741 .907 r
.26705 .3222 .26821 .32338 .27404 .32127 .27288 .3201 Metetra
.664 .741 .907 r
.27288 .3201 .27404 .32127 .27988 .31916 .27873 .31798 Metetra
.664 .741 .907 r
.27873 .31798 .27988 .31916 .28574 .31705 .28458 .31587 Metetra
.664 .741 .907 r
.28458 .31587 .28574 .31705 .2916 .31493 .29045 .31374 Metetra
.664 .741 .907 r
.29045 .31374 .2916 .31493 .29749 .3128 .29634 .31162 Metetra
.664 .741 .907 r
.29634 .31162 .29749 .3128 .30338 .31067 .30223 .30948 Metetra
.664 .741 .907 r
.30223 .30948 .30338 .31067 .30929 .30854 .30814 .30735 Metetra
.664 .741 .907 r
.30814 .30735 .30929 .30854 .31521 .3064 .31407 .3052 Metetra
.664 .741 .907 r
.31407 .3052 .31521 .3064 .32114 .30426 .32 .30306 Metetra
.664 .741 .907 r
.32 .30306 .32114 .30426 .32709 .30211 .32595 .30091 Metetra
.664 .741 .907 r
.32595 .30091 .32709 .30211 .33305 .29995 .33192 .29875 Metetra
.664 .741 .907 r
.33192 .29875 .33305 .29995 .33902 .2978 .33789 .29659 Metetra
.664 .741 .907 r
.33789 .29659 .33902 .2978 .34501 .29563 .34388 .29442 Metetra
.664 .741 .907 r
.34388 .29442 .34501 .29563 .35101 .29346 .34988 .29225 Metetra
.664 .741 .907 r
.34988 .29225 .35101 .29346 .35702 .29129 .3559 .29008 Metetra
.664 .741 .907 r
.3559 .29008 .35702 .29129 .36305 .28911 .36193 .2879 Metetra
.664 .741 .907 r
.36193 .2879 .36305 .28911 .36909 .28693 .36798 .28571 Metetra
.664 .741 .907 r
.36798 .28571 .36909 .28693 .37515 .28474 .37403 .28352 Metetra
.961 .652 .397 r
.37403 .28352 .37515 .28474 .378 .352 .37724 .34277 Metetra
.908 .666 .162 r
.37724 .34277 .378 .352 .37703 .51194 .38026 .41177 Metetra
.667 .419 .536 r
.38026 .41177 .37703 .51194 .3934 .27815 .39229 .27692 Metetra
.664 .741 .907 r
.39229 .27692 .3934 .27815 .39951 .27594 .3984 .27471 Metetra
.664 .741 .907 r
.3984 .27471 .39951 .27594 .40563 .27373 .40453 .27249 Metetra
.664 .741 .907 r
.40453 .27249 .40563 .27373 .41177 .27151 .41067 .27027 Metetra
.664 .741 .907 r
.41067 .27027 .41177 .27151 .41792 .26929 .41683 .26805 Metetra
.664 .741 .907 r
.41683 .26805 .41792 .26929 .42409 .26706 .423 .26582 Metetra
.664 .741 .907 r
.423 .26582 .42409 .26706 .43027 .26483 .42918 .26358 Metetra
.664 .741 .907 r
.42918 .26358 .43027 .26483 .43647 .26259 .43538 .26134 Metetra
.664 .741 .907 r
.43538 .26134 .43647 .26259 .44267 .26035 .44159 .25909 Metetra
.664 .741 .907 r
.44159 .25909 .44267 .26035 .4489 .2581 .44781 .25684 Metetra
.664 .741 .907 r
.44781 .25684 .4489 .2581 .45514 .25584 .45405 .25458 Metetra
.664 .741 .907 r
.45405 .25458 .45514 .25584 .46139 .25358 .46031 .25232 Metetra
.664 .741 .907 r
.46031 .25232 .46139 .25358 .46765 .25132 .46658 .25006 Metetra
.664 .741 .907 r
.46658 .25006 .46765 .25132 .47393 .24905 .47286 .24778 Metetra
.664 .741 .907 r
.47286 .24778 .47393 .24905 .48023 .24678 .47916 .24551 Metetra
.664 .741 .907 r
.47916 .24551 .48023 .24678 .48654 .2445 .48547 .24322 Metetra
.664 .741 .907 r
.48547 .24322 .48654 .2445 .49286 .24221 .4918 .24094 Metetra
.664 .741 .907 r
.4918 .24094 .49286 .24221 .4992 .23992 .49814 .23864 Metetra
.664 .741 .907 r
.49814 .23864 .4992 .23992 .50556 .23763 .5045 .23634 Metetra
.664 .741 .907 r
.5045 .23634 .50556 .23763 .51193 .23533 .51087 .23404 Metetra
.664 .741 .907 r
.51087 .23404 .51193 .23533 .51831 .23302 .51726 .23173 Metetra
.664 .741 .907 r
.51726 .23173 .51831 .23302 .52471 .23071 .52366 .22942 Metetra
.664 .741 .907 r
.52366 .22942 .52471 .23071 .53112 .22839 .53007 .2271 Metetra
.664 .741 .907 r
.53007 .2271 .53112 .22839 .53755 .22607 .53651 .22477 Metetra
.664 .741 .907 r
.53651 .22477 .53755 .22607 .54399 .22374 .54295 .22244 Metetra
.664 .741 .907 r
.54295 .22244 .54399 .22374 .55045 .22141 .54941 .2201 Metetra
.664 .741 .907 r
.54941 .2201 .55045 .22141 .55692 .21907 .55589 .21776 Metetra
.664 .741 .907 r
.55589 .21776 .55692 .21907 .56341 .21672 .56238 .21541 Metetra
.664 .741 .907 r
.56238 .21541 .56341 .21672 .56992 .21437 .56889 .21306 Metetra
.664 .741 .907 r
.56889 .21306 .56992 .21437 .57644 .21202 .57541 .2107 Metetra
.664 .741 .907 r
.57541 .2107 .57644 .21202 .58297 .20966 .58195 .20834 Metetra
.664 .741 .907 r
.58195 .20834 .58297 .20966 .58952 .20729 .5885 .20597 Metetra
.664 .741 .907 r
.5885 .20597 .58952 .20729 .59609 .20492 .59507 .20359 Metetra
.664 .741 .907 r
.59507 .20359 .59609 .20492 .60267 .20254 .60165 .20121 Metetra
.664 .741 .907 r
.60165 .20121 .60267 .20254 .60926 .20016 .60825 .19883 Metetra
.664 .741 .907 r
.60825 .19883 .60926 .20016 .61588 .19777 .61487 .19643 Metetra
.664 .741 .907 r
.61487 .19643 .61588 .19777 .6225 .19537 .6215 .19404 Metetra
.664 .741 .907 r
.6215 .19404 .6225 .19537 .62915 .19297 .62815 .19163 Metetra
.664 .741 .907 r
.62815 .19163 .62915 .19297 .63581 .19057 .63481 .18922 Metetra
.664 .741 .907 r
.63481 .18922 .63581 .19057 .64248 .18816 .64149 .18681 Metetra
.664 .741 .907 r
.64149 .18681 .64248 .18816 .64917 .18574 .64818 .18439 Metetra
.664 .741 .907 r
.64818 .18439 .64917 .18574 .65588 .18331 .65489 .18196 Metetra
.664 .741 .907 r
.65489 .18196 .65588 .18331 .6626 .18089 .66162 .17953 Metetra
.664 .741 .907 r
.66162 .17953 .6626 .18089 .66934 .17845 .66836 .17709 Metetra
.664 .741 .907 r
.66836 .17709 .66934 .17845 .6761 .17601 .67512 .17465 Metetra
.664 .741 .907 r
.67512 .17465 .6761 .17601 .68287 .17356 .6819 .1722 Metetra
.664 .741 .907 r
.6819 .1722 .68287 .17356 .68966 .17111 .68869 .16974 Metetra
.664 .741 .907 r
.68869 .16974 .68966 .17111 .69646 .16865 .69549 .16728 Metetra
.664 .741 .907 r
.69549 .16728 .69646 .16865 .70328 .16619 .70232 .16481 Metetra
.664 .741 .907 r
.70232 .16481 .70328 .16619 .71012 .16372 .70916 .16234 Metetra
.664 .741 .907 r
.70916 .16234 .71012 .16372 .71742 .16822 .71601 .15986 Metetra
.57 .397 .608 r
.71601 .15986 .71742 .16822 .72384 .15876 .72289 .15737 Metetra
.664 .741 .907 r
.72289 .15737 .72384 .15876 .73073 .15627 .72978 .15488 Metetra
.664 .741 .907 r
.72978 .15488 .73073 .15627 .73763 .15378 .73668 .15239 Metetra
.664 .741 .907 r
.73668 .15239 .73763 .15378 .74455 .15128 .74361 .14988 Metetra
.664 .741 .907 r
.74361 .14988 .74455 .15128 .75149 .14877 .75055 .14737 Metetra
.664 .741 .907 r
.75055 .14737 .75149 .14877 .75844 .14626 .7575 .14486 Metetra
.664 .741 .907 r
.7575 .14486 .75844 .14626 .76541 .14374 .76448 .14233 Metetra
.664 .741 .907 r
.76448 .14233 .76541 .14374 .7724 .14122 .77147 .13981 Metetra
.664 .741 .907 r
.77147 .13981 .7724 .14122 .7794 .13869 .77848 .13727 Metetra
.664 .741 .907 r
.15189 .36229 .15309 .36341 .15867 .36139 .15747 .36027 Metetra
.664 .741 .907 r
.15747 .36027 .15867 .36139 .16427 .35937 .16307 .35824 Metetra
.664 .741 .907 r
.16307 .35824 .16427 .35937 .16987 .35735 .16867 .35621 Metetra
.664 .741 .907 r
.16867 .35621 .16987 .35735 .17549 .35532 .17429 .35418 Metetra
.664 .741 .907 r
.17429 .35418 .17549 .35532 .18112 .35328 .17992 .35214 Metetra
.664 .741 .907 r
.17992 .35214 .18112 .35328 .18676 .35124 .18557 .3501 Metetra
.664 .741 .907 r
.18557 .3501 .18676 .35124 .19241 .3492 .19122 .34805 Metetra
.664 .741 .907 r
.19122 .34805 .19241 .3492 .19808 .34715 .19689 .346 Metetra
.664 .741 .907 r
.19689 .346 .19808 .34715 .20376 .34509 .20257 .34395 Metetra
.664 .741 .907 r
.20257 .34395 .20376 .34509 .20945 .34304 .20826 .34189 Metetra
.664 .741 .907 r
.20826 .34189 .20945 .34304 .21515 .34097 .21397 .33982 Metetra
.664 .741 .907 r
.21397 .33982 .21515 .34097 .22087 .33891 .21969 .33775 Metetra
.664 .741 .907 r
.21969 .33775 .22087 .33891 .22659 .33683 .22542 .33568 Metetra
.942 .59 .314 r
.22542 .33568 .22659 .33683 .22987 .36142 .22904 .35641 Metetra
.818 .604 .614 r
.22904 .35641 .22987 .36142 .23663 .34875 .23692 .33152 Metetra
.547 .345 .558 r
.23692 .33152 .23663 .34875 .24386 .33059 .24269 .32943 Metetra
.664 .741 .907 r
.24269 .32943 .24386 .33059 .24964 .3285 .24847 .32733 Metetra
.664 .741 .907 r
.24847 .32733 .24964 .3285 .25543 .32641 .25426 .32524 Metetra
.664 .741 .907 r
.25426 .32524 .25543 .32641 .26123 .32431 .26007 .32314 Metetra
.664 .741 .907 r
.26007 .32314 .26123 .32431 .26705 .3222 .26589 .32103 Metetra
.664 .741 .907 r
.26589 .32103 .26705 .3222 .27288 .3201 .27173 .31892 Metetra
.664 .741 .907 r
.27173 .31892 .27288 .3201 .27873 .31798 .27757 .3168 Metetra
.664 .741 .907 r
.27757 .3168 .27873 .31798 .28458 .31587 .28343 .31468 Metetra
.664 .741 .907 r
.28343 .31468 .28458 .31587 .29045 .31374 .2893 .31256 Metetra
.664 .741 .907 r
.2893 .31256 .29045 .31374 .29634 .31162 .29519 .31043 Metetra
.664 .741 .907 r
.29519 .31043 .29634 .31162 .30223 .30948 .30109 .30829 Metetra
.664 .741 .907 r
.30109 .30829 .30223 .30948 .30814 .30735 .307 .30615 Metetra
.664 .741 .907 r
.307 .30615 .30814 .30735 .31407 .3052 .31293 .30401 Metetra
.664 .741 .907 r
.31293 .30401 .31407 .3052 .32 .30306 .31886 .30186 Metetra
.664 .741 .907 r
.31886 .30186 .32 .30306 .32595 .30091 .32482 .2997 Metetra
.664 .741 .907 r
.32482 .2997 .32595 .30091 .33192 .29875 .33078 .29755 Metetra
.664 .741 .907 r
.33078 .29755 .33192 .29875 .33789 .29659 .33676 .29538 Metetra
.664 .741 .907 r
.33676 .29538 .33789 .29659 .34388 .29442 .34275 .29321 Metetra
.664 .741 .907 r
.34275 .29321 .34388 .29442 .34988 .29225 .34876 .29104 Metetra
.664 .741 .907 r
.34876 .29104 .34988 .29225 .3559 .29008 .35478 .28886 Metetra
.664 .741 .907 r
.35478 .28886 .3559 .29008 .36193 .2879 .36081 .28668 Metetra
.664 .741 .907 r
.36081 .28668 .36193 .2879 .36798 .28571 .36686 .28449 Metetra
.664 .741 .907 r
.36686 .28449 .36798 .28571 .37403 .28352 .37292 .2823 Metetra
.664 .741 .907 r
.37292 .2823 .37403 .28352 .37724 .34277 .37899 .2801 Metetra
.386 .195 .496 r
.37899 .2801 .37724 .34277 .38026 .41177 .38244 .33646 Metetra
.618 .38 .534 r
.38244 .33646 .38026 .41177 .39229 .27692 .39118 .27569 Metetra
.664 .741 .907 r
.39118 .27569 .39229 .27692 .3984 .27471 .3973 .27347 Metetra
.664 .741 .907 r
.3973 .27347 .3984 .27471 .40453 .27249 .40343 .27125 Metetra
.664 .741 .907 r
.40343 .27125 .40453 .27249 .41067 .27027 .40957 .26903 Metetra
.664 .741 .907 r
.40957 .26903 .41067 .27027 .41683 .26805 .41573 .2668 Metetra
.664 .741 .907 r
.41573 .2668 .41683 .26805 .423 .26582 .4219 .26457 Metetra
.664 .741 .907 r
.4219 .26457 .423 .26582 .42918 .26358 .42809 .26233 Metetra
.664 .741 .907 r
.42809 .26233 .42918 .26358 .43538 .26134 .43429 .26009 Metetra
.664 .741 .907 r
.43429 .26009 .43538 .26134 .44159 .25909 .4405 .25784 Metetra
.664 .741 .907 r
.4405 .25784 .44159 .25909 .44781 .25684 .44673 .25558 Metetra
.664 .741 .907 r
.44673 .25558 .44781 .25684 .45405 .25458 .45297 .25332 Metetra
.664 .741 .907 r
.45297 .25332 .45405 .25458 .46031 .25232 .45923 .25106 Metetra
.664 .741 .907 r
.45923 .25106 .46031 .25232 .46658 .25006 .4655 .24879 Metetra
.664 .741 .907 r
.4655 .24879 .46658 .25006 .47286 .24778 .47179 .24651 Metetra
.664 .741 .907 r
.47179 .24651 .47286 .24778 .47916 .24551 .47809 .24423 Metetra
.664 .741 .907 r
.47809 .24423 .47916 .24551 .48547 .24322 .48441 .24195 Metetra
.664 .741 .907 r
.48441 .24195 .48547 .24322 .4918 .24094 .49074 .23966 Metetra
.664 .741 .907 r
.49074 .23966 .4918 .24094 .49814 .23864 .49708 .23736 Metetra
.664 .741 .907 r
.49708 .23736 .49814 .23864 .5045 .23634 .50344 .23506 Metetra
.664 .741 .907 r
.50344 .23506 .5045 .23634 .51087 .23404 .50981 .23275 Metetra
.664 .741 .907 r
.50981 .23275 .51087 .23404 .51726 .23173 .5162 .23044 Metetra
.664 .741 .907 r
.5162 .23044 .51726 .23173 .52366 .22942 .52261 .22812 Metetra
.664 .741 .907 r
.52261 .22812 .52366 .22942 .53007 .2271 .52903 .2258 Metetra
.664 .741 .907 r
.52903 .2258 .53007 .2271 .53651 .22477 .53546 .22347 Metetra
.664 .741 .907 r
.53546 .22347 .53651 .22477 .54295 .22244 .54191 .22114 Metetra
.664 .741 .907 r
.54191 .22114 .54295 .22244 .54941 .2201 .54838 .2188 Metetra
.664 .741 .907 r
.54838 .2188 .54941 .2201 .55589 .21776 .55485 .21645 Metetra
.664 .741 .907 r
.55485 .21645 .55589 .21776 .56238 .21541 .56135 .2141 Metetra
.664 .741 .907 r
.56135 .2141 .56238 .21541 .56889 .21306 .56786 .21175 Metetra
.664 .741 .907 r
.56786 .21175 .56889 .21306 .57541 .2107 .57438 .20938 Metetra
.664 .741 .907 r
.57438 .20938 .57541 .2107 .58195 .20834 .58093 .20702 Metetra
.664 .741 .907 r
.58093 .20702 .58195 .20834 .5885 .20597 .58748 .20464 Metetra
.664 .741 .907 r
.58748 .20464 .5885 .20597 .59507 .20359 .59405 .20227 Metetra
.664 .741 .907 r
.59405 .20227 .59507 .20359 .60165 .20121 .60064 .19988 Metetra
.664 .741 .907 r
.60064 .19988 .60165 .20121 .60825 .19883 .60724 .19749 Metetra
.664 .741 .907 r
.60724 .19749 .60825 .19883 .61487 .19643 .61386 .1951 Metetra
.664 .741 .907 r
.61386 .1951 .61487 .19643 .6215 .19404 .6205 .1927 Metetra
.664 .741 .907 r
.6205 .1927 .6215 .19404 .62815 .19163 .62715 .19029 Metetra
.664 .741 .907 r
.62715 .19029 .62815 .19163 .63481 .18922 .63381 .18788 Metetra
.664 .741 .907 r
.63381 .18788 .63481 .18922 .64149 .18681 .64049 .18546 Metetra
.664 .741 .907 r
.64049 .18546 .64149 .18681 .64818 .18439 .64719 .18303 Metetra
.664 .741 .907 r
.64719 .18303 .64818 .18439 .65489 .18196 .6539 .1806 Metetra
.664 .741 .907 r
.6539 .1806 .65489 .18196 .66162 .17953 .66063 .17817 Metetra
.664 .741 .907 r
.66063 .17817 .66162 .17953 .66836 .17709 .66738 .17573 Metetra
.664 .741 .907 r
.66738 .17573 .66836 .17709 .67512 .17465 .67414 .17328 Metetra
.664 .741 .907 r
.67414 .17328 .67512 .17465 .6819 .1722 .68092 .17083 Metetra
.664 .741 .907 r
.68092 .17083 .6819 .1722 .68869 .16974 .68771 .16837 Metetra
.664 .741 .907 r
.68771 .16837 .68869 .16974 .69549 .16728 .69453 .1659 Metetra
.664 .741 .907 r
.69453 .1659 .69549 .16728 .70232 .16481 .70135 .16343 Metetra
.664 .741 .907 r
.70135 .16343 .70232 .16481 .70916 .16234 .7082 .16096 Metetra
0 .123 .66 r
.7082 .16096 .70916 .16234 .71601 .15986 .71566 .16797 Metetra
.307 .064 .372 r
.71566 .16797 .71601 .15986 .72289 .15737 .72193 .15599 Metetra
.664 .741 .907 r
.72193 .15599 .72289 .15737 .72978 .15488 .72883 .15349 Metetra
.664 .741 .907 r
.72883 .15349 .72978 .15488 .73668 .15239 .73574 .15099 Metetra
.664 .741 .907 r
.73574 .15099 .73668 .15239 .74361 .14988 .74266 .14848 Metetra
.664 .741 .907 r
.74266 .14848 .74361 .14988 .75055 .14737 .74961 .14597 Metetra
.664 .741 .907 r
.74961 .14597 .75055 .14737 .7575 .14486 .75657 .14345 Metetra
.664 .741 .907 r
.75657 .14345 .7575 .14486 .76448 .14233 .76355 .14093 Metetra
.664 .741 .907 r
.76355 .14093 .76448 .14233 .77147 .13981 .77054 .13839 Metetra
.664 .741 .907 r
.77054 .13839 .77147 .13981 .77848 .13727 .77755 .13586 Metetra
.664 .741 .907 r
.15068 .36116 .15189 .36229 .15747 .36027 .15627 .35914 Metetra
.664 .741 .907 r
.15627 .35914 .15747 .36027 .16307 .35824 .16186 .35711 Metetra
.664 .741 .907 r
.16186 .35711 .16307 .35824 .16867 .35621 .16747 .35508 Metetra
.664 .741 .907 r
.16747 .35508 .16867 .35621 .17429 .35418 .17309 .35304 Metetra
.664 .741 .907 r
.17309 .35304 .17429 .35418 .17992 .35214 .17873 .351 Metetra
.664 .741 .907 r
.17873 .351 .17992 .35214 .18557 .3501 .18437 .34896 Metetra
.664 .741 .907 r
.18437 .34896 .18557 .3501 .19122 .34805 .19003 .34691 Metetra
.664 .741 .907 r
.19003 .34691 .19122 .34805 .19689 .346 .1957 .34486 Metetra
.664 .741 .907 r
.1957 .34486 .19689 .346 .20257 .34395 .20138 .3428 Metetra
.664 .741 .907 r
.20138 .3428 .20257 .34395 .20826 .34189 .20708 .34073 Metetra
.664 .741 .907 r
.20708 .34073 .20826 .34189 .21397 .33982 .21279 .33867 Metetra
.664 .741 .907 r
.21279 .33867 .21397 .33982 .21969 .33775 .21851 .33659 Metetra
.664 .741 .907 r
.21851 .33659 .21969 .33775 .22542 .33568 .22424 .33452 Metetra
.54 .7 .943 r
.22424 .33452 .22542 .33568 .22904 .35641 .22985 .3339 Metetra
.55 .34 .548 r
.22985 .3339 .22904 .35641 .23692 .33152 .23574 .33035 Metetra
.664 .741 .907 r
.23574 .33035 .23692 .33152 .24269 .32943 .24152 .32826 Metetra
.664 .741 .907 r
.24152 .32826 .24269 .32943 .24847 .32733 .2473 .32617 Metetra
.664 .741 .907 r
.2473 .32617 .24847 .32733 .25426 .32524 .2531 .32407 Metetra
.664 .741 .907 r
.2531 .32407 .25426 .32524 .26007 .32314 .25891 .32196 Metetra
.664 .741 .907 r
.25891 .32196 .26007 .32314 .26589 .32103 .26473 .31985 Metetra
.664 .741 .907 r
.26473 .31985 .26589 .32103 .27173 .31892 .27057 .31774 Metetra
.664 .741 .907 r
.27057 .31774 .27173 .31892 .27757 .3168 .27641 .31562 Metetra
.664 .741 .907 r
.27641 .31562 .27757 .3168 .28343 .31468 .28228 .3135 Metetra
.664 .741 .907 r
.28228 .3135 .28343 .31468 .2893 .31256 .28815 .31137 Metetra
.664 .741 .907 r
.28815 .31137 .2893 .31256 .29519 .31043 .29404 .30924 Metetra
.664 .741 .907 r
.29404 .30924 .29519 .31043 .30109 .30829 .29994 .3071 Metetra
.664 .741 .907 r
.29994 .3071 .30109 .30829 .307 .30615 .30585 .30496 Metetra
.664 .741 .907 r
.30585 .30496 .307 .30615 .31293 .30401 .31178 .30281 Metetra
.664 .741 .907 r
.31178 .30281 .31293 .30401 .31886 .30186 .31772 .30066 Metetra
.664 .741 .907 r
.31772 .30066 .31886 .30186 .32482 .2997 .32368 .2985 Metetra
.664 .741 .907 r
.32368 .2985 .32482 .2997 .33078 .29755 .32965 .29634 Metetra
.664 .741 .907 r
.32965 .29634 .33078 .29755 .33676 .29538 .33563 .29417 Metetra
.664 .741 .907 r
.33563 .29417 .33676 .29538 .34275 .29321 .34162 .292 Metetra
.664 .741 .907 r
.34162 .292 .34275 .29321 .34876 .29104 .34763 .28983 Metetra
.96 .664 .429 r
.34763 .28983 .34876 .29104 .35478 .28886 .34897 .37274 Metetra
.353 .151 .461 r
.34897 .37274 .35478 .28886 .36081 .28668 .35969 .28546 Metetra
.664 .741 .907 r
.35969 .28546 .36081 .28668 .36686 .28449 .36574 .28327 Metetra
.664 .741 .907 r
.36574 .28327 .36686 .28449 .37292 .2823 .3718 .28107 Metetra
.664 .741 .907 r
.3718 .28107 .37292 .2823 .37899 .2801 .37788 .27887 Metetra
.664 .741 .907 r
.37788 .27887 .37899 .2801 .38244 .33646 .38397 .27666 Metetra
.531 .311 .525 r
.38397 .27666 .38244 .33646 .39118 .27569 .39007 .27445 Metetra
.664 .741 .907 r
.39007 .27445 .39118 .27569 .3973 .27347 .39619 .27224 Metetra
.664 .741 .907 r
.39619 .27224 .3973 .27347 .40343 .27125 .40232 .27002 Metetra
.664 .741 .907 r
.40232 .27002 .40343 .27125 .40957 .26903 .40847 .26779 Metetra
.664 .741 .907 r
.40847 .26779 .40957 .26903 .41573 .2668 .41463 .26556 Metetra
.664 .741 .907 r
.41463 .26556 .41573 .2668 .4219 .26457 .4208 .26332 Metetra
.664 .741 .907 r
.4208 .26332 .4219 .26457 .42809 .26233 .42699 .26108 Metetra
.664 .741 .907 r
.42699 .26108 .42809 .26233 .43429 .26009 .4332 .25883 Metetra
.664 .741 .907 r
.4332 .25883 .43429 .26009 .4405 .25784 .43941 .25658 Metetra
.664 .741 .907 r
.43941 .25658 .4405 .25784 .44673 .25558 .44564 .25432 Metetra
.664 .741 .907 r
.44564 .25432 .44673 .25558 .45297 .25332 .45189 .25206 Metetra
.664 .741 .907 r
.45189 .25206 .45297 .25332 .45923 .25106 .45815 .24979 Metetra
.664 .741 .907 r
.45815 .24979 .45923 .25106 .4655 .24879 .46442 .24752 Metetra
.664 .741 .907 r
.46442 .24752 .4655 .24879 .47179 .24651 .47071 .24524 Metetra
.664 .741 .907 r
.47071 .24524 .47179 .24651 .47809 .24423 .47702 .24296 Metetra
.664 .741 .907 r
.47702 .24296 .47809 .24423 .48441 .24195 .48334 .24067 Metetra
.664 .741 .907 r
.48334 .24067 .48441 .24195 .49074 .23966 .48967 .23838 Metetra
.664 .741 .907 r
.48967 .23838 .49074 .23966 .49708 .23736 .49602 .23608 Metetra
.664 .741 .907 r
.49602 .23608 .49708 .23736 .50344 .23506 .50238 .23377 Metetra
.664 .741 .907 r
.50238 .23377 .50344 .23506 .50981 .23275 .50876 .23146 Metetra
.664 .741 .907 r
.50876 .23146 .50981 .23275 .5162 .23044 .51515 .22915 Metetra
.664 .741 .907 r
.51515 .22915 .5162 .23044 .52261 .22812 .52156 .22683 Metetra
.664 .741 .907 r
.52156 .22683 .52261 .22812 .52903 .2258 .52798 .2245 Metetra
.664 .741 .907 r
.52798 .2245 .52903 .2258 .53546 .22347 .53442 .22217 Metetra
.664 .741 .907 r
.53442 .22217 .53546 .22347 .54191 .22114 .54087 .21983 Metetra
.664 .741 .907 r
.54087 .21983 .54191 .22114 .54838 .2188 .54734 .21749 Metetra
.664 .741 .907 r
.54734 .21749 .54838 .2188 .55485 .21645 .55382 .21514 Metetra
.664 .741 .907 r
.55382 .21514 .55485 .21645 .56135 .2141 .56032 .21279 Metetra
.664 .741 .907 r
.56032 .21279 .56135 .2141 .56786 .21175 .56683 .21043 Metetra
.664 .741 .907 r
.56683 .21043 .56786 .21175 .57438 .20938 .57336 .20806 Metetra
.664 .741 .907 r
.57336 .20806 .57438 .20938 .58093 .20702 .5799 .20569 Metetra
.664 .741 .907 r
.5799 .20569 .58093 .20702 .58748 .20464 .58646 .20332 Metetra
.664 .741 .907 r
.58646 .20332 .58748 .20464 .59405 .20227 .59304 .20094 Metetra
.664 .741 .907 r
.59304 .20094 .59405 .20227 .60064 .19988 .59963 .19855 Metetra
.664 .741 .907 r
.59963 .19855 .60064 .19988 .60724 .19749 .60623 .19616 Metetra
.664 .741 .907 r
.60623 .19616 .60724 .19749 .61386 .1951 .61285 .19376 Metetra
.664 .741 .907 r
.61285 .19376 .61386 .1951 .6205 .1927 .61949 .19135 Metetra
.664 .741 .907 r
.61949 .19135 .6205 .1927 .62715 .19029 .62614 .18894 Metetra
.664 .741 .907 r
.62614 .18894 .62715 .19029 .63381 .18788 .63281 .18653 Metetra
.915 .534 .116 r
.63281 .18653 .63381 .18788 .64049 .18546 .64068 .2152 Metetra
.364 .156 .459 r
.64068 .2152 .64049 .18546 .64719 .18303 .6462 .18168 Metetra
.664 .741 .907 r
.6462 .18168 .64719 .18303 .6539 .1806 .65292 .17925 Metetra
.664 .741 .907 r
.65292 .17925 .6539 .1806 .66063 .17817 .65965 .17681 Metetra
.664 .741 .907 r
.65965 .17681 .66063 .17817 .66738 .17573 .6664 .17436 Metetra
.664 .741 .907 r
.6664 .17436 .66738 .17573 .67414 .17328 .67316 .17191 Metetra
.664 .741 .907 r
.67316 .17191 .67414 .17328 .68092 .17083 .67994 .16946 Metetra
.664 .741 .907 r
.67994 .16946 .68092 .17083 .68771 .16837 .68674 .16699 Metetra
.664 .741 .907 r
.68674 .16699 .68771 .16837 .69453 .1659 .69356 .16453 Metetra
.664 .741 .907 r
.69356 .16453 .69453 .1659 .70135 .16343 .70039 .16205 Metetra
.664 .741 .907 r
.70039 .16205 .70135 .16343 .7082 .16096 .70723 .15957 Metetra
.664 .741 .907 r
.70723 .15957 .7082 .16096 .71566 .16797 .7141 .15709 Metetra
.56 .374 .587 r
.7141 .15709 .71566 .16797 .72193 .15599 .72098 .15459 Metetra
.664 .741 .907 r
.72098 .15459 .72193 .15599 .72883 .15349 .72787 .1521 Metetra
.664 .741 .907 r
.72787 .1521 .72883 .15349 .73574 .15099 .73479 .14959 Metetra
.664 .741 .907 r
.73479 .14959 .73574 .15099 .74266 .14848 .74172 .14708 Metetra
.664 .741 .907 r
.74172 .14708 .74266 .14848 .74961 .14597 .74867 .14457 Metetra
.664 .741 .907 r
.74867 .14457 .74961 .14597 .75657 .14345 .75563 .14204 Metetra
.664 .741 .907 r
.75563 .14204 .75657 .14345 .76355 .14093 .76261 .13951 Metetra
.664 .741 .907 r
.76261 .13951 .76355 .14093 .77054 .13839 .76961 .13698 Metetra
.664 .741 .907 r
.76961 .13698 .77054 .13839 .77755 .13586 .77662 .13444 Metetra
.664 .741 .907 r
.14948 .36003 .15068 .36116 .15627 .35914 .15506 .35801 Metetra
.664 .741 .907 r
.15506 .35801 .15627 .35914 .16186 .35711 .16066 .35598 Metetra
.664 .741 .907 r
.16066 .35598 .16186 .35711 .16747 .35508 .16627 .35395 Metetra
.664 .741 .907 r
.16627 .35395 .16747 .35508 .17309 .35304 .17189 .35191 Metetra
.664 .741 .907 r
.17189 .35191 .17309 .35304 .17873 .351 .17753 .34986 Metetra
.664 .741 .907 r
.17753 .34986 .17873 .351 .18437 .34896 .18318 .34782 Metetra
.664 .741 .907 r
.18318 .34782 .18437 .34896 .19003 .34691 .18884 .34576 Metetra
.664 .741 .907 r
.18884 .34576 .19003 .34691 .1957 .34486 .19451 .34371 Metetra
.664 .741 .907 r
.19451 .34371 .1957 .34486 .20138 .3428 .2002 .34165 Metetra
.664 .741 .907 r
.2002 .34165 .20138 .3428 .20708 .34073 .20589 .33958 Metetra
.664 .741 .907 r
.20589 .33958 .20708 .34073 .21279 .33867 .2116 .33751 Metetra
.664 .741 .907 r
.2116 .33751 .21279 .33867 .21851 .33659 .21733 .33544 Metetra
.664 .741 .907 r
.21733 .33544 .21851 .33659 .22424 .33452 .22306 .33336 Metetra
.664 .741 .907 r
.22306 .33336 .22424 .33452 .22985 .3339 .22881 .33127 Metetra
.629 .56 .758 r
.22881 .33127 .22985 .3339 .23574 .33035 .23457 .32919 Metetra
.664 .741 .907 r
.23457 .32919 .23574 .33035 .24152 .32826 .24034 .32709 Metetra
.664 .741 .907 r
.24034 .32709 .24152 .32826 .2473 .32617 .24613 .325 Metetra
.664 .741 .907 r
.24613 .325 .2473 .32617 .2531 .32407 .25193 .32289 Metetra
.664 .741 .907 r
.25193 .32289 .2531 .32407 .25891 .32196 .25774 .32079 Metetra
.664 .741 .907 r
.25774 .32079 .25891 .32196 .26473 .31985 .26357 .31867 Metetra
.664 .741 .907 r
.26357 .31867 .26473 .31985 .27057 .31774 .2694 .31656 Metetra
.664 .741 .907 r
.2694 .31656 .27057 .31774 .27641 .31562 .27526 .31444 Metetra
.664 .741 .907 r
.27526 .31444 .27641 .31562 .28228 .3135 .28112 .31231 Metetra
.664 .741 .907 r
.28112 .31231 .28228 .3135 .28815 .31137 .287 .31018 Metetra
.664 .741 .907 r
.287 .31018 .28815 .31137 .29404 .30924 .29289 .30804 Metetra
.664 .741 .907 r
.29289 .30804 .29404 .30924 .29994 .3071 .29879 .3059 Metetra
.664 .741 .907 r
.29879 .3059 .29994 .3071 .30585 .30496 .30471 .30376 Metetra
.664 .741 .907 r
.30471 .30376 .30585 .30496 .31178 .30281 .31064 .30161 Metetra
.664 .741 .907 r
.31064 .30161 .31178 .30281 .31772 .30066 .31658 .29946 Metetra
.664 .741 .907 r
.31658 .29946 .31772 .30066 .32368 .2985 .32254 .2973 Metetra
.664 .741 .907 r
.32254 .2973 .32368 .2985 .32965 .29634 .32851 .29513 Metetra
.664 .741 .907 r
.32851 .29513 .32965 .29634 .33563 .29417 .33449 .29296 Metetra
.664 .741 .907 r
.33449 .29296 .33563 .29417 .34162 .292 .34049 .29079 Metetra
.959 .672 .447 r
.34049 .29079 .34162 .292 .34763 .28983 .33966 .40792 Metetra
.619 .371 .52 r
.33966 .40792 .34763 .28983 .34897 .37274 .33968 .5182 Metetra
.213 .044 .423 r
.33968 .5182 .34897 .37274 .35969 .28546 .35856 .28424 Metetra
.664 .741 .907 r
.35856 .28424 .35969 .28546 .36574 .28327 .36461 .28204 Metetra
.664 .741 .907 r
.36461 .28204 .36574 .28327 .3718 .28107 .37068 .27984 Metetra
.664 .741 .907 r
.37068 .27984 .3718 .28107 .37788 .27887 .37676 .27764 Metetra
.664 .741 .907 r
.37676 .27764 .37788 .27887 .38397 .27666 .38285 .27543 Metetra
.664 .741 .907 r
.38285 .27543 .38397 .27666 .39007 .27445 .38896 .27322 Metetra
.664 .741 .907 r
.38896 .27322 .39007 .27445 .39619 .27224 .39508 .271 Metetra
.664 .741 .907 r
.39508 .271 .39619 .27224 .40232 .27002 .40122 .26877 Metetra
.664 .741 .907 r
.40122 .26877 .40232 .27002 .40847 .26779 .40736 .26654 Metetra
.664 .741 .907 r
.40736 .26654 .40847 .26779 .41463 .26556 .41353 .26431 Metetra
.664 .741 .907 r
.41353 .26431 .41463 .26556 .4208 .26332 .41971 .26207 Metetra
.664 .741 .907 r
.41971 .26207 .4208 .26332 .42699 .26108 .4259 .25983 Metetra
.664 .741 .907 r
.4259 .25983 .42699 .26108 .4332 .25883 .4321 .25758 Metetra
.664 .741 .907 r
.4321 .25758 .4332 .25883 .43941 .25658 .43832 .25532 Metetra
.664 .741 .907 r
.43832 .25532 .43941 .25658 .44564 .25432 .44456 .25306 Metetra
.664 .741 .907 r
.44456 .25306 .44564 .25432 .45189 .25206 .4508 .2508 Metetra
.664 .741 .907 r
.4508 .2508 .45189 .25206 .45815 .24979 .45707 .24853 Metetra
.664 .741 .907 r
.45707 .24853 .45815 .24979 .46442 .24752 .46335 .24625 Metetra
.664 .741 .907 r
.46335 .24625 .46442 .24752 .47071 .24524 .46964 .24397 Metetra
.664 .741 .907 r
.46964 .24397 .47071 .24524 .47702 .24296 .47594 .24168 Metetra
.664 .741 .907 r
.47594 .24168 .47702 .24296 .48334 .24067 .48227 .23939 Metetra
.664 .741 .907 r
.48227 .23939 .48334 .24067 .48967 .23838 .4886 .2371 Metetra
.664 .741 .907 r
.4886 .2371 .48967 .23838 .49602 .23608 .49495 .23479 Metetra
.664 .741 .907 r
.49495 .23479 .49602 .23608 .50238 .23377 .50132 .23249 Metetra
.664 .741 .907 r
.50132 .23249 .50238 .23377 .50876 .23146 .5077 .23017 Metetra
.664 .741 .907 r
.5077 .23017 .50876 .23146 .51515 .22915 .51409 .22785 Metetra
.664 .741 .907 r
.51409 .22785 .51515 .22915 .52156 .22683 .5205 .22553 Metetra
.664 .741 .907 r
.5205 .22553 .52156 .22683 .52798 .2245 .52693 .2232 Metetra
.664 .741 .907 r
.52693 .2232 .52798 .2245 .53442 .22217 .53337 .22087 Metetra
.664 .741 .907 r
.53337 .22087 .53442 .22217 .54087 .21983 .53982 .21853 Metetra
.664 .741 .907 r
.53982 .21853 .54087 .21983 .54734 .21749 .54629 .21618 Metetra
.664 .741 .907 r
.54629 .21618 .54734 .21749 .55382 .21514 .55278 .21383 Metetra
.664 .741 .907 r
.55278 .21383 .55382 .21514 .56032 .21279 .55928 .21147 Metetra
.664 .741 .907 r
.55928 .21147 .56032 .21279 .56683 .21043 .5658 .20911 Metetra
.664 .741 .907 r
.5658 .20911 .56683 .21043 .57336 .20806 .57233 .20674 Metetra
.664 .741 .907 r
.57233 .20674 .57336 .20806 .5799 .20569 .57888 .20437 Metetra
.664 .741 .907 r
.57888 .20437 .5799 .20569 .58646 .20332 .58544 .20199 Metetra
.664 .741 .907 r
.58544 .20199 .58646 .20332 .59304 .20094 .59202 .19961 Metetra
.664 .741 .907 r
.59202 .19961 .59304 .20094 .59963 .19855 .59861 .19722 Metetra
.664 .741 .907 r
.59861 .19722 .59963 .19855 .60623 .19616 .60522 .19482 Metetra
.664 .741 .907 r
.60522 .19482 .60623 .19616 .61285 .19376 .61184 .19242 Metetra
.664 .741 .907 r
.61184 .19242 .61285 .19376 .61949 .19135 .61848 .19001 Metetra
.664 .741 .907 r
.61848 .19001 .61949 .19135 .62614 .18894 .62514 .1876 Metetra
.451 .642 .939 r
.62514 .1876 .62614 .18894 .63281 .18653 .63191 .18788 Metetra
.941 .596 .338 r
.63191 .18788 .63281 .18653 .64068 .2152 .64089 .24595 Metetra
.175 .017 .414 r
.64089 .24595 .64068 .2152 .6462 .18168 .6452 .18032 Metetra
.664 .741 .907 r
.6452 .18032 .6462 .18168 .65292 .17925 .65192 .17789 Metetra
.664 .741 .907 r
.65192 .17789 .65292 .17925 .65965 .17681 .65866 .17545 Metetra
.664 .741 .907 r
.65866 .17545 .65965 .17681 .6664 .17436 .66541 .173 Metetra
.664 .741 .907 r
.66541 .173 .6664 .17436 .67316 .17191 .67218 .17054 Metetra
.664 .741 .907 r
.67218 .17054 .67316 .17191 .67994 .16946 .67897 .16808 Metetra
.664 .741 .907 r
.67897 .16808 .67994 .16946 .68674 .16699 .68577 .16562 Metetra
.664 .741 .907 r
.68577 .16562 .68674 .16699 .69356 .16453 .69259 .16315 Metetra
.664 .741 .907 r
.69259 .16315 .69356 .16453 .70039 .16205 .69942 .16067 Metetra
.664 .741 .907 r
.69942 .16067 .70039 .16205 .70723 .15957 .70627 .15819 Metetra
.664 .741 .907 r
.70627 .15819 .70723 .15957 .7141 .15709 .71314 .1557 Metetra
.664 .741 .907 r
.71314 .1557 .7141 .15709 .72098 .15459 .72002 .1532 Metetra
.664 .741 .907 r
.72002 .1532 .72098 .15459 .72787 .1521 .72692 .1507 Metetra
.664 .741 .907 r
.72692 .1507 .72787 .1521 .73479 .14959 .73384 .14819 Metetra
.664 .741 .907 r
.73384 .14819 .73479 .14959 .74172 .14708 .74077 .14568 Metetra
.664 .741 .907 r
.74077 .14568 .74172 .14708 .74867 .14457 .74772 .14316 Metetra
.664 .741 .907 r
.74772 .14316 .74867 .14457 .75563 .14204 .75469 .14063 Metetra
.664 .741 .907 r
.75469 .14063 .75563 .14204 .76261 .13951 .76168 .1381 Metetra
.664 .741 .907 r
.76168 .1381 .76261 .13951 .76961 .13698 .76868 .13556 Metetra
.664 .741 .907 r
.76868 .13556 .76961 .13698 .77662 .13444 .7757 .13302 Metetra
.664 .741 .907 r
.14827 .3589 .14948 .36003 .15506 .35801 .15386 .35688 Metetra
.664 .741 .907 r
.15386 .35688 .15506 .35801 .16066 .35598 .15946 .35485 Metetra
.664 .741 .907 r
.15946 .35485 .16066 .35598 .16627 .35395 .16507 .35281 Metetra
.664 .741 .907 r
.16507 .35281 .16627 .35395 .17189 .35191 .17069 .35077 Metetra
.664 .741 .907 r
.17069 .35077 .17189 .35191 .17753 .34986 .17633 .34872 Metetra
.664 .741 .907 r
.17633 .34872 .17753 .34986 .18318 .34782 .18198 .34667 Metetra
.664 .741 .907 r
.18198 .34667 .18318 .34782 .18884 .34576 .18764 .34462 Metetra
.664 .741 .907 r
.18764 .34462 .18884 .34576 .19451 .34371 .19332 .34256 Metetra
.664 .741 .907 r
.19332 .34256 .19451 .34371 .2002 .34165 .19901 .3405 Metetra
.664 .741 .907 r
.19901 .3405 .2002 .34165 .20589 .33958 .20471 .33843 Metetra
.664 .741 .907 r
.20471 .33843 .20589 .33958 .2116 .33751 .21042 .33636 Metetra
.664 .741 .907 r
.21042 .33636 .2116 .33751 .21733 .33544 .21614 .33428 Metetra
.664 .741 .907 r
.21614 .33428 .21733 .33544 .22306 .33336 .22188 .3322 Metetra
.664 .741 .907 r
.22188 .3322 .22306 .33336 .22881 .33127 .22763 .33011 Metetra
.664 .741 .907 r
.22763 .33011 .22881 .33127 .23457 .32919 .23339 .32802 Metetra
.664 .741 .907 r
.23339 .32802 .23457 .32919 .24034 .32709 .23917 .32592 Metetra
.664 .741 .907 r
.23917 .32592 .24034 .32709 .24613 .325 .24496 .32382 Metetra
.664 .741 .907 r
.24496 .32382 .24613 .325 .25193 .32289 .25076 .32172 Metetra
.664 .741 .907 r
.25076 .32172 .25193 .32289 .25774 .32079 .25657 .31961 Metetra
.664 .741 .907 r
.25657 .31961 .25774 .32079 .26357 .31867 .2624 .31749 Metetra
.664 .741 .907 r
.2624 .31749 .26357 .31867 .2694 .31656 .26824 .31538 Metetra
.664 .741 .907 r
.26824 .31538 .2694 .31656 .27526 .31444 .2741 .31325 Metetra
.664 .741 .907 r
.2741 .31325 .27526 .31444 .28112 .31231 .27996 .31112 Metetra
.664 .741 .907 r
.27996 .31112 .28112 .31231 .287 .31018 .28584 .30899 Metetra
.664 .741 .907 r
.28584 .30899 .287 .31018 .29289 .30804 .29173 .30685 Metetra
.664 .741 .907 r
.29173 .30685 .29289 .30804 .29879 .3059 .29764 .30471 Metetra
.664 .741 .907 r
.29764 .30471 .29879 .3059 .30471 .30376 .30356 .30256 Metetra
.664 .741 .907 r
.30356 .30256 .30471 .30376 .31064 .30161 .30949 .30041 Metetra
.664 .741 .907 r
.30949 .30041 .31064 .30161 .31658 .29946 .31544 .29825 Metetra
.664 .741 .907 r
.31544 .29825 .31658 .29946 .32254 .2973 .3214 .29609 Metetra
.664 .741 .907 r
.3214 .29609 .32254 .2973 .32851 .29513 .32737 .29392 Metetra
.664 .741 .907 r
.32737 .29392 .32851 .29513 .33449 .29296 .33336 .29175 Metetra
.664 .741 .907 r
.33336 .29175 .33449 .29296 .34049 .29079 .33936 .28957 Metetra
.958 .678 .461 r
.33936 .28957 .34049 .29079 .33966 .40792 .3344 .47735 Metetra
.331 .132 .452 r
.3344 .47735 .33966 .40792 .33968 .5182 .34506 .39876 Metetra
.635 .392 .533 r
.34506 .39876 .33968 .5182 .35856 .28424 .35744 .28301 Metetra
.664 .741 .907 r
.35744 .28301 .35856 .28424 .36461 .28204 .36349 .28082 Metetra
.664 .741 .907 r
.36349 .28082 .36461 .28204 .37068 .27984 .36956 .27862 Metetra
.664 .741 .907 r
.36956 .27862 .37068 .27984 .37676 .27764 .37564 .27641 Metetra
.664 .741 .907 r
.37564 .27641 .37676 .27764 .38285 .27543 .38174 .2742 Metetra
.664 .741 .907 r
.38174 .2742 .38285 .27543 .38896 .27322 .38785 .27198 Metetra
.664 .741 .907 r
.38785 .27198 .38896 .27322 .39508 .271 .39397 .26976 Metetra
.664 .741 .907 r
.39397 .26976 .39508 .271 .40122 .26877 .40011 .26753 Metetra
.664 .741 .907 r
.40011 .26753 .40122 .26877 .40736 .26654 .40626 .2653 Metetra
.664 .741 .907 r
.40626 .2653 .40736 .26654 .41353 .26431 .41243 .26306 Metetra
.664 .741 .907 r
.41243 .26306 .41353 .26431 .41971 .26207 .41861 .26082 Metetra
.664 .741 .907 r
.41861 .26082 .41971 .26207 .4259 .25983 .4248 .25857 Metetra
.664 .741 .907 r
.4248 .25857 .4259 .25983 .4321 .25758 .43101 .25632 Metetra
.664 .741 .907 r
.43101 .25632 .4321 .25758 .43832 .25532 .43723 .25406 Metetra
.664 .741 .907 r
.43723 .25406 .43832 .25532 .44456 .25306 .44347 .2518 Metetra
.664 .741 .907 r
.44347 .2518 .44456 .25306 .4508 .2508 .44972 .24953 Metetra
.664 .741 .907 r
.44972 .24953 .4508 .2508 .45707 .24853 .45598 .24726 Metetra
.664 .741 .907 r
.45598 .24726 .45707 .24853 .46335 .24625 .46227 .24498 Metetra
.664 .741 .907 r
.46227 .24498 .46335 .24625 .46964 .24397 .46856 .2427 Metetra
.664 .741 .907 r
.46856 .2427 .46964 .24397 .47594 .24168 .47487 .24041 Metetra
.664 .741 .907 r
.47487 .24041 .47594 .24168 .48227 .23939 .48119 .23811 Metetra
.664 .741 .907 r
.48119 .23811 .48227 .23939 .4886 .2371 .48753 .23581 Metetra
.664 .741 .907 r
.48753 .23581 .4886 .2371 .49495 .23479 .49389 .23351 Metetra
.664 .741 .907 r
.49389 .23351 .49495 .23479 .50132 .23249 .50025 .2312 Metetra
.664 .741 .907 r
.50025 .2312 .50132 .23249 .5077 .23017 .50664 .22888 Metetra
.664 .741 .907 r
.50664 .22888 .5077 .23017 .51409 .22785 .51304 .22656 Metetra
.664 .741 .907 r
.51304 .22656 .51409 .22785 .5205 .22553 .51945 .22423 Metetra
.664 .741 .907 r
.51945 .22423 .5205 .22553 .52693 .2232 .52588 .2219 Metetra
.664 .741 .907 r
.52588 .2219 .52693 .2232 .53337 .22087 .53232 .21956 Metetra
.664 .741 .907 r
.53232 .21956 .53337 .22087 .53982 .21853 .53878 .21722 Metetra
.664 .741 .907 r
.53878 .21722 .53982 .21853 .54629 .21618 .54525 .21487 Metetra
.664 .741 .907 r
.54525 .21487 .54629 .21618 .55278 .21383 .55174 .21252 Metetra
.664 .741 .907 r
.55174 .21252 .55278 .21383 .55928 .21147 .55824 .21016 Metetra
.664 .741 .907 r
.55824 .21016 .55928 .21147 .5658 .20911 .56476 .20779 Metetra
.664 .741 .907 r
.56476 .20779 .5658 .20911 .57233 .20674 .5713 .20542 Metetra
.664 .741 .907 r
.5713 .20542 .57233 .20674 .57888 .20437 .57785 .20304 Metetra
.664 .741 .907 r
.57785 .20304 .57888 .20437 .58544 .20199 .58441 .20066 Metetra
.664 .741 .907 r
.58441 .20066 .58544 .20199 .59202 .19961 .59099 .19827 Metetra
.664 .741 .907 r
.59099 .19827 .59202 .19961 .59861 .19722 .59759 .19588 Metetra
.664 .741 .907 r
.59759 .19588 .59861 .19722 .60522 .19482 .6042 .19348 Metetra
.664 .741 .907 r
.6042 .19348 .60522 .19482 .61184 .19242 .61083 .19108 Metetra
.664 .741 .907 r
.61083 .19108 .61184 .19242 .61848 .19001 .61748 .18867 Metetra
0 .331 .813 r
.61748 .18867 .61848 .19001 .62514 .1876 .62435 .1929 Metetra
.244 0 .29 r
.62435 .1929 .62514 .1876 .63191 .18788 .63081 .18383 Metetra
.389 .353 .698 r
.63081 .18383 .63191 .18788 .64089 .24595 .63775 .18802 Metetra
.545 .321 .526 r
.63775 .18802 .64089 .24595 .6452 .18032 .64421 .17897 Metetra
.664 .741 .907 r
.64421 .17897 .6452 .18032 .65192 .17789 .65093 .17653 Metetra
.664 .741 .907 r
.65093 .17653 .65192 .17789 .65866 .17545 .65767 .17408 Metetra
.664 .741 .907 r
.65767 .17408 .65866 .17545 .66541 .173 .66443 .17163 Metetra
.664 .741 .907 r
.66443 .17163 .66541 .173 .67218 .17054 .6712 .16917 Metetra
.664 .741 .907 r
.6712 .16917 .67218 .17054 .67897 .16808 .67799 .16671 Metetra
.664 .741 .907 r
.67799 .16671 .67897 .16808 .68577 .16562 .68479 .16424 Metetra
.664 .741 .907 r
.68479 .16424 .68577 .16562 .69259 .16315 .69161 .16177 Metetra
.664 .741 .907 r
.69161 .16177 .69259 .16315 .69942 .16067 .69845 .15929 Metetra
.664 .741 .907 r
.69845 .15929 .69942 .16067 .70627 .15819 .70531 .1568 Metetra
.664 .741 .907 r
.70531 .1568 .70627 .15819 .71314 .1557 .71218 .15431 Metetra
.664 .741 .907 r
.71218 .15431 .71314 .1557 .72002 .1532 .71906 .15181 Metetra
.664 .741 .907 r
.71906 .15181 .72002 .1532 .72692 .1507 .72597 .1493 Metetra
.664 .741 .907 r
.72597 .1493 .72692 .1507 .73384 .14819 .73289 .14679 Metetra
.664 .741 .907 r
.73289 .14679 .73384 .14819 .74077 .14568 .73982 .14427 Metetra
.664 .741 .907 r
.73982 .14427 .74077 .14568 .74772 .14316 .74678 .14175 Metetra
.664 .741 .907 r
.74678 .14175 .74772 .14316 .75469 .14063 .75375 .13922 Metetra
.664 .741 .907 r
.75375 .13922 .75469 .14063 .76168 .1381 .76074 .13669 Metetra
.664 .741 .907 r
.76074 .13669 .76168 .1381 .76868 .13556 .76774 .13414 Metetra
.664 .741 .907 r
.76774 .13414 .76868 .13556 .7757 .13302 .77477 .1316 Metetra
.664 .741 .907 r
.14706 .35777 .14827 .3589 .15386 .35688 .15265 .35574 Metetra
.664 .741 .907 r
.15265 .35574 .15386 .35688 .15946 .35485 .15825 .35371 Metetra
.664 .741 .907 r
.15825 .35371 .15946 .35485 .16507 .35281 .16386 .35167 Metetra
.664 .741 .907 r
.16386 .35167 .16507 .35281 .17069 .35077 .16949 .34963 Metetra
.664 .741 .907 r
.16949 .34963 .17069 .35077 .17633 .34872 .17513 .34758 Metetra
.664 .741 .907 r
.17513 .34758 .17633 .34872 .18198 .34667 .18078 .34553 Metetra
.664 .741 .907 r
.18078 .34553 .18198 .34667 .18764 .34462 .18645 .34347 Metetra
.664 .741 .907 r
.18645 .34347 .18764 .34462 .19332 .34256 .19213 .34141 Metetra
.664 .741 .907 r
.19213 .34141 .19332 .34256 .19901 .3405 .19781 .33934 Metetra
.664 .741 .907 r
.19781 .33934 .19901 .3405 .20471 .33843 .20352 .33727 Metetra
.664 .741 .907 r
.20352 .33727 .20471 .33843 .21042 .33636 .20923 .3352 Metetra
.949 .632 .4 r
.20923 .3352 .21042 .33636 .21614 .33428 .21156 .36768 Metetra
.321 .109 .428 r
.21156 .36768 .21614 .33428 .22188 .3322 .2207 .33103 Metetra
.664 .741 .907 r
.2207 .33103 .22188 .3322 .22763 .33011 .22645 .32894 Metetra
.664 .741 .907 r
.22645 .32894 .22763 .33011 .23339 .32802 .23222 .32685 Metetra
.664 .741 .907 r
.23222 .32685 .23339 .32802 .23917 .32592 .23799 .32475 Metetra
.664 .741 .907 r
.23799 .32475 .23917 .32592 .24496 .32382 .24378 .32265 Metetra
.664 .741 .907 r
.24378 .32265 .24496 .32382 .25076 .32172 .24959 .32054 Metetra
.664 .741 .907 r
.24959 .32054 .25076 .32172 .25657 .31961 .25541 .31843 Metetra
.664 .741 .907 r
.25541 .31843 .25657 .31961 .2624 .31749 .26124 .31631 Metetra
.664 .741 .907 r
.26124 .31631 .2624 .31749 .26824 .31538 .26708 .31419 Metetra
.664 .741 .907 r
.26708 .31419 .26824 .31538 .2741 .31325 .27293 .31207 Metetra
.664 .741 .907 r
.27293 .31207 .2741 .31325 .27996 .31112 .2788 .30993 Metetra
.664 .741 .907 r
.2788 .30993 .27996 .31112 .28584 .30899 .28468 .3078 Metetra
.664 .741 .907 r
.28468 .3078 .28584 .30899 .29173 .30685 .29058 .30566 Metetra
.664 .741 .907 r
.29058 .30566 .29173 .30685 .29764 .30471 .29649 .30351 Metetra
.664 .741 .907 r
.29649 .30351 .29764 .30471 .30356 .30256 .30241 .30136 Metetra
.664 .741 .907 r
.30241 .30136 .30356 .30256 .30949 .30041 .30834 .29921 Metetra
.664 .741 .907 r
.30834 .29921 .30949 .30041 .31544 .29825 .31429 .29705 Metetra
.664 .741 .907 r
.31429 .29705 .31544 .29825 .3214 .29609 .32025 .29488 Metetra
.664 .741 .907 r
.32025 .29488 .3214 .29609 .32737 .29392 .32623 .29271 Metetra
.664 .741 .907 r
.32623 .29271 .32737 .29392 .33336 .29175 .33222 .29054 Metetra
.664 .741 .907 r
.33222 .29054 .33336 .29175 .33936 .28957 .33822 .28836 Metetra
.959 .673 .451 r
.33822 .28836 .33936 .28957 .3344 .47735 .33659 .41776 Metetra
.662 .419 .541 r
.33659 .41776 .3344 .47735 .34506 .39876 .34715 .33941 Metetra
.633 .394 .538 r
.34715 .33941 .34506 .39876 .35744 .28301 .35631 .28179 Metetra
.664 .741 .907 r
.35631 .28179 .35744 .28301 .36349 .28082 .36237 .27959 Metetra
.664 .741 .907 r
.36237 .27959 .36349 .28082 .36956 .27862 .36844 .27738 Metetra
.664 .741 .907 r
.36844 .27738 .36956 .27862 .37564 .27641 .37452 .27518 Metetra
.664 .741 .907 r
.37452 .27518 .37564 .27641 .38174 .2742 .38062 .27296 Metetra
.664 .741 .907 r
.38062 .27296 .38174 .2742 .38785 .27198 .38673 .27074 Metetra
.664 .741 .907 r
.38673 .27074 .38785 .27198 .39397 .26976 .39286 .26852 Metetra
.664 .741 .907 r
.39286 .26852 .39397 .26976 .40011 .26753 .399 .26629 Metetra
.664 .741 .907 r
.399 .26629 .40011 .26753 .40626 .2653 .40515 .26405 Metetra
.664 .741 .907 r
.40515 .26405 .40626 .2653 .41243 .26306 .41132 .26181 Metetra
.664 .741 .907 r
.41132 .26181 .41243 .26306 .41861 .26082 .4175 .25957 Metetra
.664 .741 .907 r
.4175 .25957 .41861 .26082 .4248 .25857 .4237 .25732 Metetra
.664 .741 .907 r
.4237 .25732 .4248 .25857 .43101 .25632 .42991 .25506 Metetra
.664 .741 .907 r
.42991 .25506 .43101 .25632 .43723 .25406 .43614 .2528 Metetra
.664 .741 .907 r
.43614 .2528 .43723 .25406 .44347 .2518 .44238 .25054 Metetra
.664 .741 .907 r
.44238 .25054 .44347 .2518 .44972 .24953 .44863 .24826 Metetra
.664 .741 .907 r
.44863 .24826 .44972 .24953 .45598 .24726 .4549 .24599 Metetra
.664 .741 .907 r
.4549 .24599 .45598 .24726 .46227 .24498 .46118 .24371 Metetra
.664 .741 .907 r
.46118 .24371 .46227 .24498 .46856 .2427 .46748 .24142 Metetra
.664 .741 .907 r
.46748 .24142 .46856 .2427 .47487 .24041 .47379 .23913 Metetra
.664 .741 .907 r
.47379 .23913 .47487 .24041 .48119 .23811 .48012 .23683 Metetra
.664 .741 .907 r
.48012 .23683 .48119 .23811 .48753 .23581 .48646 .23453 Metetra
.664 .741 .907 r
.48646 .23453 .48753 .23581 .49389 .23351 .49282 .23222 Metetra
.664 .741 .907 r
.49282 .23222 .49389 .23351 .50025 .2312 .49919 .2299 Metetra
.664 .741 .907 r
.49919 .2299 .50025 .2312 .50664 .22888 .50558 .22759 Metetra
.664 .741 .907 r
.50558 .22759 .50664 .22888 .51304 .22656 .51198 .22526 Metetra
.664 .741 .907 r
.51198 .22526 .51304 .22656 .51945 .22423 .51839 .22293 Metetra
.664 .741 .907 r
.51839 .22293 .51945 .22423 .52588 .2219 .52482 .2206 Metetra
.664 .741 .907 r
.52482 .2206 .52588 .2219 .53232 .21956 .53127 .21826 Metetra
.664 .741 .907 r
.53127 .21826 .53232 .21956 .53878 .21722 .53773 .21591 Metetra
.664 .741 .907 r
.53773 .21591 .53878 .21722 .54525 .21487 .54421 .21356 Metetra
.664 .741 .907 r
.54421 .21356 .54525 .21487 .55174 .21252 .5507 .2112 Metetra
.664 .741 .907 r
.5507 .2112 .55174 .21252 .55824 .21016 .55721 .20884 Metetra
.664 .741 .907 r
.55721 .20884 .55824 .21016 .56476 .20779 .56373 .20647 Metetra
.664 .741 .907 r
.56373 .20647 .56476 .20779 .5713 .20542 .57027 .2041 Metetra
.664 .741 .907 r
.57027 .2041 .5713 .20542 .57785 .20304 .57682 .20172 Metetra
.664 .741 .907 r
.57682 .20172 .57785 .20304 .58441 .20066 .58339 .19933 Metetra
.664 .741 .907 r
.58339 .19933 .58441 .20066 .59099 .19827 .58997 .19694 Metetra
.664 .741 .907 r
.58997 .19694 .59099 .19827 .59759 .19588 .59657 .19454 Metetra
.664 .741 .907 r
.59657 .19454 .59759 .19588 .6042 .19348 .60319 .19214 Metetra
.664 .741 .907 r
.60319 .19214 .6042 .19348 .61083 .19108 .60982 .18973 Metetra
.664 .741 .907 r
.60982 .18973 .61083 .19108 .61748 .18867 .61647 .18732 Metetra
.611 .161 0 r
.61647 .18732 .61748 .18867 .62435 .1929 .62354 .19746 Metetra
0 0 .152 r
.62354 .19746 .62435 .1929 .63081 .18383 .62981 .18247 Metetra
.664 .741 .907 r
.62981 .18247 .63081 .18383 .63775 .18802 .6365 .18004 Metetra
.571 .4 .611 r
.6365 .18004 .63775 .18802 .64421 .17897 .64321 .17761 Metetra
.664 .741 .907 r
.64321 .17761 .64421 .17897 .65093 .17653 .64994 .17516 Metetra
.664 .741 .907 r
.64994 .17516 .65093 .17653 .65767 .17408 .65668 .17271 Metetra
.664 .741 .907 r
.65668 .17271 .65767 .17408 .66443 .17163 .66344 .17026 Metetra
.664 .741 .907 r
.66344 .17026 .66443 .17163 .6712 .16917 .67022 .1678 Metetra
.664 .741 .907 r
.67022 .1678 .6712 .16917 .67799 .16671 .67701 .16533 Metetra
.664 .741 .907 r
.67701 .16533 .67799 .16671 .68479 .16424 .68382 .16286 Metetra
.664 .741 .907 r
.68382 .16286 .68479 .16424 .69161 .16177 .69064 .16038 Metetra
.664 .741 .907 r
.69064 .16038 .69161 .16177 .69845 .15929 .69748 .1579 Metetra
.664 .741 .907 r
.69748 .1579 .69845 .15929 .70531 .1568 .70434 .15541 Metetra
.664 .741 .907 r
.70434 .15541 .70531 .1568 .71218 .15431 .71121 .15291 Metetra
.664 .741 .907 r
.71121 .15291 .71218 .15431 .71906 .15181 .7181 .15041 Metetra
.664 .741 .907 r
.7181 .15041 .71906 .15181 .72597 .1493 .72501 .1479 Metetra
.664 .741 .907 r
.72501 .1479 .72597 .1493 .73289 .14679 .73194 .14539 Metetra
.664 .741 .907 r
.73194 .14539 .73289 .14679 .73982 .14427 .73888 .14287 Metetra
.664 .741 .907 r
.73888 .14287 .73982 .14427 .74678 .14175 .74583 .14034 Metetra
.664 .741 .907 r
.74583 .14034 .74678 .14175 .75375 .13922 .75281 .13781 Metetra
.664 .741 .907 r
.75281 .13781 .75375 .13922 .76074 .13669 .7598 .13527 Metetra
.664 .741 .907 r
.7598 .13527 .76074 .13669 .76774 .13414 .76681 .13272 Metetra
.664 .741 .907 r
.76681 .13272 .76774 .13414 .77477 .1316 .77384 .13017 Metetra
.664 .741 .907 r
.14584 .35664 .14706 .35777 .15265 .35574 .15144 .35461 Metetra
.664 .741 .907 r
.15144 .35461 .15265 .35574 .15825 .35371 .15704 .35257 Metetra
.664 .741 .907 r
.15704 .35257 .15825 .35371 .16386 .35167 .16266 .35053 Metetra
.664 .741 .907 r
.16266 .35053 .16386 .35167 .16949 .34963 .16829 .34849 Metetra
.664 .741 .907 r
.16829 .34849 .16949 .34963 .17513 .34758 .17393 .34644 Metetra
.664 .741 .907 r
.17393 .34644 .17513 .34758 .18078 .34553 .17958 .34438 Metetra
.664 .741 .907 r
.17958 .34438 .18078 .34553 .18645 .34347 .18525 .34232 Metetra
.664 .741 .907 r
.18525 .34232 .18645 .34347 .19213 .34141 .19093 .34026 Metetra
.664 .741 .907 r
.19093 .34026 .19213 .34141 .19781 .33934 .19662 .33819 Metetra
.664 .741 .907 r
.19662 .33819 .19781 .33934 .20352 .33727 .20233 .33612 Metetra
.929 .55 .246 r
.20233 .33612 .20352 .33727 .20923 .3352 .20626 .35181 Metetra
.366 .129 .416 r
.20626 .35181 .20923 .3352 .21156 .36768 .21325 .33725 Metetra
.559 .341 .541 r
.21325 .33725 .21156 .36768 .2207 .33103 .21951 .32987 Metetra
.664 .741 .907 r
.21951 .32987 .2207 .33103 .22645 .32894 .22527 .32778 Metetra
.664 .741 .907 r
.22527 .32778 .22645 .32894 .23222 .32685 .23104 .32568 Metetra
.664 .741 .907 r
.23104 .32568 .23222 .32685 .23799 .32475 .23682 .32358 Metetra
.664 .741 .907 r
.23682 .32358 .23799 .32475 .24378 .32265 .24261 .32147 Metetra
.664 .741 .907 r
.24261 .32147 .24378 .32265 .24959 .32054 .24842 .31936 Metetra
.664 .741 .907 r
.24842 .31936 .24959 .32054 .25541 .31843 .25424 .31725 Metetra
.664 .741 .907 r
.25424 .31725 .25541 .31843 .26124 .31631 .26007 .31513 Metetra
.664 .741 .907 r
.26007 .31513 .26124 .31631 .26708 .31419 .26591 .31301 Metetra
.664 .741 .907 r
.26591 .31301 .26708 .31419 .27293 .31207 .27177 .31088 Metetra
.664 .741 .907 r
.27177 .31088 .27293 .31207 .2788 .30993 .27764 .30874 Metetra
.664 .741 .907 r
.27764 .30874 .2788 .30993 .28468 .3078 .28353 .3066 Metetra
.664 .741 .907 r
.28353 .3066 .28468 .3078 .29058 .30566 .28942 .30446 Metetra
.664 .741 .907 r
.28942 .30446 .29058 .30566 .29649 .30351 .29533 .30231 Metetra
.664 .741 .907 r
.29533 .30231 .29649 .30351 .30241 .30136 .30126 .30016 Metetra
.664 .741 .907 r
.30126 .30016 .30241 .30136 .30834 .29921 .3072 .298 Metetra
.664 .741 .907 r
.3072 .298 .30834 .29921 .31429 .29705 .31315 .29584 Metetra
.664 .741 .907 r
.31315 .29584 .31429 .29705 .32025 .29488 .31911 .29367 Metetra
.664 .741 .907 r
.31911 .29367 .32025 .29488 .32623 .29271 .32509 .2915 Metetra
.664 .741 .907 r
.32509 .2915 .32623 .29271 .33222 .29054 .33108 .28932 Metetra
.664 .741 .907 r
.33108 .28932 .33222 .29054 .33822 .28836 .33708 .28714 Metetra
.872 .44 .037 r
.33708 .28714 .33822 .28836 .33659 .41776 .34225 .29951 Metetra
.495 .276 .511 r
.34225 .29951 .33659 .41776 .34715 .33941 .34677 .32451 Metetra
.757 .516 .567 r
.34677 .32451 .34715 .33941 .35631 .28179 .35518 .28056 Metetra
.664 .741 .907 r
.35518 .28056 .35631 .28179 .36237 .27959 .36124 .27836 Metetra
.664 .741 .907 r
.36124 .27836 .36237 .27959 .36844 .27738 .36731 .27615 Metetra
.664 .741 .907 r
.36731 .27615 .36844 .27738 .37452 .27518 .3734 .27394 Metetra
.664 .741 .907 r
.3734 .27394 .37452 .27518 .38062 .27296 .3795 .27172 Metetra
.664 .741 .907 r
.3795 .27172 .38062 .27296 .38673 .27074 .38562 .2695 Metetra
.664 .741 .907 r
.38562 .2695 .38673 .27074 .39286 .26852 .39175 .26727 Metetra
.664 .741 .907 r
.39175 .26727 .39286 .26852 .399 .26629 .39789 .26504 Metetra
.664 .741 .907 r
.39789 .26504 .399 .26629 .40515 .26405 .40405 .2628 Metetra
.664 .741 .907 r
.40405 .2628 .40515 .26405 .41132 .26181 .41022 .26056 Metetra
.664 .741 .907 r
.41022 .26056 .41132 .26181 .4175 .25957 .4164 .25831 Metetra
.664 .741 .907 r
.4164 .25831 .4175 .25957 .4237 .25732 .4226 .25606 Metetra
.664 .741 .907 r
.4226 .25606 .4237 .25732 .42991 .25506 .42881 .2538 Metetra
.664 .741 .907 r
.42881 .2538 .42991 .25506 .43614 .2528 .43504 .25154 Metetra
.664 .741 .907 r
.43504 .25154 .43614 .2528 .44238 .25054 .44129 .24927 Metetra
.664 .741 .907 r
.44129 .24927 .44238 .25054 .44863 .24826 .44754 .247 Metetra
.664 .741 .907 r
.44754 .247 .44863 .24826 .4549 .24599 .45381 .24472 Metetra
.664 .741 .907 r
.45381 .24472 .4549 .24599 .46118 .24371 .4601 .24243 Metetra
.913 .516 .126 r
.4601 .24243 .46118 .24371 .46748 .24142 .46599 .26165 Metetra
.333 .116 .427 r
.46599 .26165 .46748 .24142 .47379 .23913 .47272 .23785 Metetra
.664 .741 .907 r
.47272 .23785 .47379 .23913 .48012 .23683 .47905 .23555 Metetra
.664 .741 .907 r
.47905 .23555 .48012 .23683 .48646 .23453 .48539 .23324 Metetra
.664 .741 .907 r
.48539 .23324 .48646 .23453 .49282 .23222 .49175 .23093 Metetra
.664 .741 .907 r
.49175 .23093 .49282 .23222 .49919 .2299 .49812 .22861 Metetra
.664 .741 .907 r
.49812 .22861 .49919 .2299 .50558 .22759 .50451 .22629 Metetra
.664 .741 .907 r
.50451 .22629 .50558 .22759 .51198 .22526 .51092 .22396 Metetra
.664 .741 .907 r
.51092 .22396 .51198 .22526 .51839 .22293 .51734 .22163 Metetra
.664 .741 .907 r
.51734 .22163 .51839 .22293 .52482 .2206 .52377 .21929 Metetra
.664 .741 .907 r
.52377 .21929 .52482 .2206 .53127 .21826 .53022 .21695 Metetra
.664 .741 .907 r
.53022 .21695 .53127 .21826 .53773 .21591 .53668 .2146 Metetra
.664 .741 .907 r
.53668 .2146 .53773 .21591 .54421 .21356 .54316 .21224 Metetra
.664 .741 .907 r
.54316 .21224 .54421 .21356 .5507 .2112 .54966 .20988 Metetra
.664 .741 .907 r
.54966 .20988 .5507 .2112 .55721 .20884 .55617 .20752 Metetra
.664 .741 .907 r
.55617 .20752 .55721 .20884 .56373 .20647 .56269 .20515 Metetra
.664 .741 .907 r
.56269 .20515 .56373 .20647 .57027 .2041 .56923 .20277 Metetra
.664 .741 .907 r
.56923 .20277 .57027 .2041 .57682 .20172 .57579 .20039 Metetra
.664 .741 .907 r
.57579 .20039 .57682 .20172 .58339 .19933 .58236 .198 Metetra
.664 .741 .907 r
.58236 .198 .58339 .19933 .58997 .19694 .58895 .1956 Metetra
.664 .741 .907 r
.58895 .1956 .58997 .19694 .59657 .19454 .59555 .1932 Metetra
.664 .741 .907 r
.59555 .1932 .59657 .19454 .60319 .19214 .60217 .1908 Metetra
.664 .741 .907 r
.60217 .1908 .60319 .19214 .60982 .18973 .6088 .18839 Metetra
.664 .741 .907 r
.6088 .18839 .60982 .18973 .61647 .18732 .61545 .18597 Metetra
.664 .741 .907 r
.61545 .18597 .61647 .18732 .62354 .19746 .62212 .18355 Metetra
.552 .356 .57 r
.62212 .18355 .62354 .19746 .62981 .18247 .6288 .18112 Metetra
.664 .741 .907 r
.6288 .18112 .62981 .18247 .6365 .18004 .6355 .17868 Metetra
.664 .741 .907 r
.6355 .17868 .6365 .18004 .64321 .17761 .64221 .17624 Metetra
.664 .741 .907 r
.64221 .17624 .64321 .17761 .64994 .17516 .64894 .1738 Metetra
.664 .741 .907 r
.64894 .1738 .64994 .17516 .65668 .17271 .65569 .17135 Metetra
.664 .741 .907 r
.65569 .17135 .65668 .17271 .66344 .17026 .66245 .16889 Metetra
.664 .741 .907 r
.66245 .16889 .66344 .17026 .67022 .1678 .66923 .16643 Metetra
.664 .741 .907 r
.66923 .16643 .67022 .1678 .67701 .16533 .67603 .16396 Metetra
.664 .741 .907 r
.67603 .16396 .67701 .16533 .68382 .16286 .68284 .16148 Metetra
.664 .741 .907 r
.68284 .16148 .68382 .16286 .69064 .16038 .68967 .159 Metetra
.664 .741 .907 r
.68967 .159 .69064 .16038 .69748 .1579 .69651 .15651 Metetra
.664 .741 .907 r
.69651 .15651 .69748 .1579 .70434 .15541 .70337 .15402 Metetra
.664 .741 .907 r
.70337 .15402 .70434 .15541 .71121 .15291 .71025 .15152 Metetra
.664 .741 .907 r
.71025 .15152 .71121 .15291 .7181 .15041 .71714 .14901 Metetra
.664 .741 .907 r
.71714 .14901 .7181 .15041 .72501 .1479 .72405 .1465 Metetra
.664 .741 .907 r
.72405 .1465 .72501 .1479 .73194 .14539 .73098 .14398 Metetra
.664 .741 .907 r
.73098 .14398 .73194 .14539 .73888 .14287 .73793 .14146 Metetra
.664 .741 .907 r
.73793 .14146 .73888 .14287 .74583 .14034 .74489 .13893 Metetra
.664 .741 .907 r
.74489 .13893 .74583 .14034 .75281 .13781 .75187 .13639 Metetra
.664 .741 .907 r
.75187 .13639 .75281 .13781 .7598 .13527 .75886 .13385 Metetra
.664 .741 .907 r
.75886 .13385 .7598 .13527 .76681 .13272 .76587 .1313 Metetra
.664 .741 .907 r
.76587 .1313 .76681 .13272 .77384 .13017 .7729 .12875 Metetra
.664 .741 .907 r
.14463 .35551 .14584 .35664 .15144 .35461 .15023 .35347 Metetra
.664 .741 .907 r
.15023 .35347 .15144 .35461 .15704 .35257 .15583 .35144 Metetra
.664 .741 .907 r
.15583 .35144 .15704 .35257 .16266 .35053 .16145 .34939 Metetra
.664 .741 .907 r
.16145 .34939 .16266 .35053 .16829 .34849 .16708 .34734 Metetra
.664 .741 .907 r
.16708 .34734 .16829 .34849 .17393 .34644 .17273 .34529 Metetra
.664 .741 .907 r
.17273 .34529 .17393 .34644 .17958 .34438 .17838 .34323 Metetra
.664 .741 .907 r
.17838 .34323 .17958 .34438 .18525 .34232 .18405 .34117 Metetra
.664 .741 .907 r
.18405 .34117 .18525 .34232 .19093 .34026 .18973 .3391 Metetra
.664 .741 .907 r
.18973 .3391 .19093 .34026 .19662 .33819 .19543 .33703 Metetra
.664 .741 .907 r
.19543 .33703 .19662 .33819 .20233 .33612 .20113 .33496 Metetra
.645 .736 .915 r
.20113 .33496 .20233 .33612 .20626 .35181 .20683 .33315 Metetra
.546 .341 .553 r
.20683 .33315 .20626 .35181 .21325 .33725 .21258 .33079 Metetra
.577 .417 .627 r
.21258 .33079 .21325 .33725 .21951 .32987 .21833 .3287 Metetra
.664 .741 .907 r
.21833 .3287 .21951 .32987 .22527 .32778 .22409 .32661 Metetra
.664 .741 .907 r
.22409 .32661 .22527 .32778 .23104 .32568 .22986 .32451 Metetra
.664 .741 .907 r
.22986 .32451 .23104 .32568 .23682 .32358 .23564 .32241 Metetra
.664 .741 .907 r
.23564 .32241 .23682 .32358 .24261 .32147 .24143 .3203 Metetra
.664 .741 .907 r
.24143 .3203 .24261 .32147 .24842 .31936 .24724 .31819 Metetra
.664 .741 .907 r
.24724 .31819 .24842 .31936 .25424 .31725 .25306 .31607 Metetra
.664 .741 .907 r
.25306 .31607 .25424 .31725 .26007 .31513 .2589 .31395 Metetra
.664 .741 .907 r
.2589 .31395 .26007 .31513 .26591 .31301 .26475 .31182 Metetra
.664 .741 .907 r
.26475 .31182 .26591 .31301 .27177 .31088 .27061 .30969 Metetra
.664 .741 .907 r
.27061 .30969 .27177 .31088 .27764 .30874 .27648 .30755 Metetra
.664 .741 .907 r
.27648 .30755 .27764 .30874 .28353 .3066 .28237 .30541 Metetra
.664 .741 .907 r
.28237 .30541 .28353 .3066 .28942 .30446 .28827 .30326 Metetra
.664 .741 .907 r
.28827 .30326 .28942 .30446 .29533 .30231 .29418 .30111 Metetra
.664 .741 .907 r
.29418 .30111 .29533 .30231 .30126 .30016 .30011 .29896 Metetra
.664 .741 .907 r
.30011 .29896 .30126 .30016 .3072 .298 .30605 .2968 Metetra
.664 .741 .907 r
.30605 .2968 .3072 .298 .31315 .29584 .312 .29463 Metetra
.664 .741 .907 r
.312 .29463 .31315 .29584 .31911 .29367 .31797 .29246 Metetra
.664 .741 .907 r
.31797 .29246 .31911 .29367 .32509 .2915 .32395 .29029 Metetra
.664 .741 .907 r
.32395 .29029 .32509 .2915 .33108 .28932 .32994 .28811 Metetra
.664 .741 .907 r
.32994 .28811 .33108 .28932 .33708 .28714 .33595 .28592 Metetra
.664 .741 .907 r
.33595 .28592 .33708 .28714 .34225 .29951 .34197 .28373 Metetra
.512 .32 .557 r
.34197 .28373 .34225 .29951 .34677 .32451 .34776 .28575 Metetra
.548 .328 .534 r
.34776 .28575 .34677 .32451 .35518 .28056 .35405 .27934 Metetra
.664 .741 .907 r
.35405 .27934 .35518 .28056 .36124 .27836 .36011 .27713 Metetra
.664 .741 .907 r
.36011 .27713 .36124 .27836 .36731 .27615 .36619 .27492 Metetra
.664 .741 .907 r
.36619 .27492 .36731 .27615 .3734 .27394 .37228 .2727 Metetra
.961 .647 .385 r
.37228 .2727 .3734 .27394 .3795 .27172 .37575 .32613 Metetra
.348 .143 .454 r
.37575 .32613 .3795 .27172 .38562 .2695 .3845 .26826 Metetra
.664 .741 .907 r
.3845 .26826 .38562 .2695 .39175 .26727 .39063 .26603 Metetra
.664 .741 .907 r
.39063 .26603 .39175 .26727 .39789 .26504 .39678 .26379 Metetra
.664 .741 .907 r
.39678 .26379 .39789 .26504 .40405 .2628 .40294 .26155 Metetra
.664 .741 .907 r
.40294 .26155 .40405 .2628 .41022 .26056 .40911 .25931 Metetra
.664 .741 .907 r
.40911 .25931 .41022 .26056 .4164 .25831 .4153 .25706 Metetra
.664 .741 .907 r
.4153 .25706 .4164 .25831 .4226 .25606 .4215 .2548 Metetra
.664 .741 .907 r
.4215 .2548 .4226 .25606 .42881 .2538 .42772 .25254 Metetra
.664 .741 .907 r
.42772 .25254 .42881 .2538 .43504 .25154 .43395 .25027 Metetra
.664 .741 .907 r
.43395 .25027 .43504 .25154 .44129 .24927 .44019 .248 Metetra
.664 .741 .907 r
.44019 .248 .44129 .24927 .44754 .247 .44645 .24572 Metetra
.664 .741 .907 r
.44645 .24572 .44754 .247 .45381 .24472 .45273 .24344 Metetra
.664 .741 .907 r
.45273 .24344 .45381 .24472 .4601 .24243 .45902 .24115 Metetra
.664 .741 .907 r
.45902 .24115 .4601 .24243 .46599 .26165 .46532 .23886 Metetra
.541 .332 .546 r
.46532 .23886 .46599 .26165 .47272 .23785 .47164 .23656 Metetra
.664 .741 .907 r
.47164 .23656 .47272 .23785 .47905 .23555 .47797 .23426 Metetra
.664 .741 .907 r
.47797 .23426 .47905 .23555 .48539 .23324 .48432 .23195 Metetra
.664 .741 .907 r
.48432 .23195 .48539 .23324 .49175 .23093 .49068 .22964 Metetra
.664 .741 .907 r
.49068 .22964 .49175 .23093 .49812 .22861 .49706 .22732 Metetra
.664 .741 .907 r
.49706 .22732 .49812 .22861 .50451 .22629 .50345 .22499 Metetra
.664 .741 .907 r
.50345 .22499 .50451 .22629 .51092 .22396 .50985 .22266 Metetra
.664 .741 .907 r
.50985 .22266 .51092 .22396 .51734 .22163 .51628 .22033 Metetra
.664 .741 .907 r
.51628 .22033 .51734 .22163 .52377 .21929 .52271 .21798 Metetra
.664 .741 .907 r
.52271 .21798 .52377 .21929 .53022 .21695 .52917 .21564 Metetra
.664 .741 .907 r
.52917 .21564 .53022 .21695 .53668 .2146 .53563 .21329 Metetra
.664 .741 .907 r
.53563 .21329 .53668 .2146 .54316 .21224 .54212 .21093 Metetra
.664 .741 .907 r
.54212 .21093 .54316 .21224 .54966 .20988 .54861 .20856 Metetra
.664 .741 .907 r
.54861 .20856 .54966 .20988 .55617 .20752 .55513 .2062 Metetra
.664 .741 .907 r
.55513 .2062 .55617 .20752 .56269 .20515 .56165 .20382 Metetra
.664 .741 .907 r
.56165 .20382 .56269 .20515 .56923 .20277 .5682 .20144 Metetra
.664 .741 .907 r
.5682 .20144 .56923 .20277 .57579 .20039 .57476 .19905 Metetra
.664 .741 .907 r
.57476 .19905 .57579 .20039 .58236 .198 .58133 .19666 Metetra
.664 .741 .907 r
.58133 .19666 .58236 .198 .58895 .1956 .58792 .19427 Metetra
.664 .741 .907 r
.58792 .19427 .58895 .1956 .59555 .1932 .59453 .19186 Metetra
.664 .741 .907 r
.59453 .19186 .59555 .1932 .60217 .1908 .60115 .18945 Metetra
.664 .741 .907 r
.60115 .18945 .60217 .1908 .6088 .18839 .60779 .18704 Metetra
.664 .741 .907 r
.60779 .18704 .6088 .18839 .61545 .18597 .61444 .18462 Metetra
.664 .741 .907 r
.61444 .18462 .61545 .18597 .62212 .18355 .62111 .18219 Metetra
.664 .741 .907 r
.62111 .18219 .62212 .18355 .6288 .18112 .6278 .17976 Metetra
.664 .741 .907 r
.6278 .17976 .6288 .18112 .6355 .17868 .6345 .17732 Metetra
.664 .741 .907 r
.6345 .17732 .6355 .17868 .64221 .17624 .64121 .17488 Metetra
.664 .741 .907 r
.64121 .17488 .64221 .17624 .64894 .1738 .64795 .17243 Metetra
.664 .741 .907 r
.64795 .17243 .64894 .1738 .65569 .17135 .6547 .16998 Metetra
.664 .741 .907 r
.6547 .16998 .65569 .17135 .66245 .16889 .66146 .16752 Metetra
.664 .741 .907 r
.66146 .16752 .66245 .16889 .66923 .16643 .66825 .16505 Metetra
.664 .741 .907 r
.66825 .16505 .66923 .16643 .67603 .16396 .67504 .16258 Metetra
.664 .741 .907 r
.67504 .16258 .67603 .16396 .68284 .16148 .68186 .1601 Metetra
.664 .741 .907 r
.68186 .1601 .68284 .16148 .68967 .159 .68869 .15761 Metetra
.664 .741 .907 r
.68869 .15761 .68967 .159 .69651 .15651 .69554 .15512 Metetra
.664 .741 .907 r
.69554 .15512 .69651 .15651 .70337 .15402 .7024 .15262 Metetra
.664 .741 .907 r
.7024 .15262 .70337 .15402 .71025 .15152 .70928 .15012 Metetra
.664 .741 .907 r
.70928 .15012 .71025 .15152 .71714 .14901 .71618 .14761 Metetra
.664 .741 .907 r
.71618 .14761 .71714 .14901 .72405 .1465 .7231 .1451 Metetra
.664 .741 .907 r
.7231 .1451 .72405 .1465 .73098 .14398 .73003 .14258 Metetra
.664 .741 .907 r
.73003 .14258 .73098 .14398 .73793 .14146 .73697 .14005 Metetra
.664 .741 .907 r
.73697 .14005 .73793 .14146 .74489 .13893 .74394 .13752 Metetra
.664 .741 .907 r
.74394 .13752 .74489 .13893 .75187 .13639 .75092 .13498 Metetra
.664 .741 .907 r
.75092 .13498 .75187 .13639 .75886 .13385 .75792 .13243 Metetra
.664 .741 .907 r
.75792 .13243 .75886 .13385 .76587 .1313 .76494 .12988 Metetra
.664 .741 .907 r
.76494 .12988 .76587 .1313 .7729 .12875 .77197 .12732 Metetra
.664 .741 .907 r
.14342 .35438 .14463 .35551 .15023 .35347 .14901 .35234 Metetra
.664 .741 .907 r
.14901 .35234 .15023 .35347 .15583 .35144 .15462 .3503 Metetra
.664 .741 .907 r
.15462 .3503 .15583 .35144 .16145 .34939 .16024 .34825 Metetra
.664 .741 .907 r
.16024 .34825 .16145 .34939 .16708 .34734 .16588 .3462 Metetra
.664 .741 .907 r
.16588 .3462 .16708 .34734 .17273 .34529 .17152 .34414 Metetra
.664 .741 .907 r
.17152 .34414 .17273 .34529 .17838 .34323 .17718 .34208 Metetra
.664 .741 .907 r
.17718 .34208 .17838 .34323 .18405 .34117 .18285 .34002 Metetra
.664 .741 .907 r
.18285 .34002 .18405 .34117 .18973 .3391 .18854 .33795 Metetra
.664 .741 .907 r
.18854 .33795 .18973 .3391 .19543 .33703 .19423 .33588 Metetra
.664 .741 .907 r
.19423 .33588 .19543 .33703 .20113 .33496 .19994 .3338 Metetra
.664 .741 .907 r
.19994 .3338 .20113 .33496 .20683 .33315 .20566 .33171 Metetra
.659 .694 .871 r
.20566 .33171 .20683 .33315 .21258 .33079 .2114 .32963 Metetra
.664 .741 .907 r
.2114 .32963 .21258 .33079 .21833 .3287 .21714 .32754 Metetra
.664 .741 .907 r
.21714 .32754 .21833 .3287 .22409 .32661 .2229 .32544 Metetra
.664 .741 .907 r
.2229 .32544 .22409 .32661 .22986 .32451 .22867 .32334 Metetra
.664 .741 .907 r
.22867 .32334 .22986 .32451 .23564 .32241 .23446 .32123 Metetra
.664 .741 .907 r
.23446 .32123 .23564 .32241 .24143 .3203 .24026 .31912 Metetra
.664 .741 .907 r
.24026 .31912 .24143 .3203 .24724 .31819 .24607 .31701 Metetra
.664 .741 .907 r
.24607 .31701 .24724 .31819 .25306 .31607 .25189 .31489 Metetra
.664 .741 .907 r
.25189 .31489 .25306 .31607 .2589 .31395 .25773 .31276 Metetra
.664 .741 .907 r
.25773 .31276 .2589 .31395 .26475 .31182 .26358 .31063 Metetra
.664 .741 .907 r
.26358 .31063 .26475 .31182 .27061 .30969 .26944 .3085 Metetra
.664 .741 .907 r
.26944 .3085 .27061 .30969 .27648 .30755 .27532 .30636 Metetra
.664 .741 .907 r
.27532 .30636 .27648 .30755 .28237 .30541 .2812 .30421 Metetra
.664 .741 .907 r
.2812 .30421 .28237 .30541 .28827 .30326 .28711 .30206 Metetra
.664 .741 .907 r
.28711 .30206 .28827 .30326 .29418 .30111 .29302 .29991 Metetra
.664 .741 .907 r
.29302 .29991 .29418 .30111 .30011 .29896 .29895 .29775 Metetra
.664 .741 .907 r
.29895 .29775 .30011 .29896 .30605 .2968 .30489 .29559 Metetra
.664 .741 .907 r
.30489 .29559 .30605 .2968 .312 .29463 .31085 .29342 Metetra
.664 .741 .907 r
.31085 .29342 .312 .29463 .31797 .29246 .31682 .29125 Metetra
.664 .741 .907 r
.31682 .29125 .31797 .29246 .32395 .29029 .3228 .28907 Metetra
.664 .741 .907 r
.3228 .28907 .32395 .29029 .32994 .28811 .3288 .28689 Metetra
.664 .741 .907 r
.3288 .28689 .32994 .28811 .33595 .28592 .33481 .2847 Metetra
.664 .741 .907 r
.33481 .2847 .33595 .28592 .34197 .28373 .34083 .28251 Metetra
.664 .741 .907 r
.34083 .28251 .34197 .28373 .34776 .28575 .34687 .28031 Metetra
.586 .44 .649 r
.34687 .28031 .34776 .28575 .35405 .27934 .35292 .27811 Metetra
.664 .741 .907 r
.35292 .27811 .35405 .27934 .36011 .27713 .35898 .2759 Metetra
.664 .741 .907 r
.35898 .2759 .36011 .27713 .36619 .27492 .36506 .27369 Metetra
.747 .275 0 r
.36506 .27369 .36619 .27492 .37228 .2727 .3706 .28265 Metetra
.918 .632 .486 r
.3706 .28265 .37228 .2727 .37575 .32613 .3661 .50299 Metetra
.299 .112 .451 r
.3661 .50299 .37575 .32613 .3845 .26826 .38295 .27634 Metetra
.26 .009 .331 r
.38295 .27634 .3845 .26826 .39063 .26603 .38951 .26478 Metetra
.664 .741 .907 r
.38951 .26478 .39063 .26603 .39678 .26379 .39566 .26254 Metetra
.664 .741 .907 r
.39566 .26254 .39678 .26379 .40294 .26155 .40183 .2603 Metetra
.664 .741 .907 r
.40183 .2603 .40294 .26155 .40911 .25931 .408 .25805 Metetra
.664 .741 .907 r
.408 .25805 .40911 .25931 .4153 .25706 .41419 .2558 Metetra
.664 .741 .907 r
.41419 .2558 .4153 .25706 .4215 .2548 .4204 .25354 Metetra
.664 .741 .907 r
.4204 .25354 .4215 .2548 .42772 .25254 .42662 .25128 Metetra
.664 .741 .907 r
.42662 .25128 .42772 .25254 .43395 .25027 .43285 .24901 Metetra
.664 .741 .907 r
.43285 .24901 .43395 .25027 .44019 .248 .4391 .24673 Metetra
.664 .741 .907 r
.4391 .24673 .44019 .248 .44645 .24572 .44536 .24445 Metetra
.664 .741 .907 r
.44536 .24445 .44645 .24572 .45273 .24344 .45164 .24217 Metetra
.664 .741 .907 r
.45164 .24217 .45273 .24344 .45902 .24115 .45793 .23988 Metetra
.664 .741 .907 r
.45793 .23988 .45902 .24115 .46532 .23886 .46424 .23758 Metetra
.664 .741 .907 r
.46424 .23758 .46532 .23886 .47164 .23656 .47056 .23528 Metetra
.664 .741 .907 r
.47056 .23528 .47164 .23656 .47797 .23426 .47689 .23297 Metetra
.664 .741 .907 r
.47689 .23297 .47797 .23426 .48432 .23195 .48324 .23066 Metetra
.664 .741 .907 r
.48324 .23066 .48432 .23195 .49068 .22964 .48961 .22834 Metetra
.664 .741 .907 r
.48961 .22834 .49068 .22964 .49706 .22732 .49599 .22602 Metetra
.664 .741 .907 r
.49599 .22602 .49706 .22732 .50345 .22499 .50238 .22369 Metetra
.664 .741 .907 r
.50238 .22369 .50345 .22499 .50985 .22266 .50879 .22136 Metetra
.664 .741 .907 r
.50879 .22136 .50985 .22266 .51628 .22033 .51522 .21902 Metetra
.664 .741 .907 r
.51522 .21902 .51628 .22033 .52271 .21798 .52166 .21668 Metetra
.664 .741 .907 r
.52166 .21668 .52271 .21798 .52917 .21564 .52811 .21433 Metetra
.664 .741 .907 r
.52811 .21433 .52917 .21564 .53563 .21329 .53458 .21197 Metetra
.664 .741 .907 r
.53458 .21197 .53563 .21329 .54212 .21093 .54107 .20961 Metetra
.664 .741 .907 r
.54107 .20961 .54212 .21093 .54861 .20856 .54757 .20724 Metetra
.664 .741 .907 r
.54757 .20724 .54861 .20856 .55513 .2062 .55408 .20487 Metetra
.664 .741 .907 r
.55408 .20487 .55513 .2062 .56165 .20382 .56062 .20249 Metetra
.664 .741 .907 r
.56062 .20249 .56165 .20382 .5682 .20144 .56716 .20011 Metetra
.664 .741 .907 r
.56716 .20011 .5682 .20144 .57476 .19905 .57372 .19772 Metetra
.664 .741 .907 r
.57372 .19772 .57476 .19905 .58133 .19666 .5803 .19533 Metetra
.664 .741 .907 r
.5803 .19533 .58133 .19666 .58792 .19427 .5869 .19293 Metetra
.664 .741 .907 r
.5869 .19293 .58792 .19427 .59453 .19186 .59351 .19052 Metetra
.664 .741 .907 r
.59351 .19052 .59453 .19186 .60115 .18945 .60013 .18811 Metetra
.664 .741 .907 r
.60013 .18811 .60115 .18945 .60779 .18704 .60677 .18569 Metetra
.664 .741 .907 r
.60677 .18569 .60779 .18704 .61444 .18462 .61343 .18327 Metetra
.664 .741 .907 r
.61343 .18327 .61444 .18462 .62111 .18219 .6201 .18084 Metetra
.664 .741 .907 r
.6201 .18084 .62111 .18219 .6278 .17976 .62679 .1784 Metetra
.664 .741 .907 r
.62679 .1784 .6278 .17976 .6345 .17732 .63349 .17596 Metetra
.664 .741 .907 r
.63349 .17596 .6345 .17732 .64121 .17488 .64021 .17352 Metetra
.664 .741 .907 r
.64021 .17352 .64121 .17488 .64795 .17243 .64695 .17106 Metetra
.664 .741 .907 r
.64695 .17106 .64795 .17243 .6547 .16998 .6537 .1686 Metetra
.664 .741 .907 r
.6537 .1686 .6547 .16998 .66146 .16752 .66047 .16614 Metetra
.664 .741 .907 r
.66047 .16614 .66146 .16752 .66825 .16505 .66726 .16367 Metetra
.664 .741 .907 r
.66726 .16367 .66825 .16505 .67504 .16258 .67406 .16119 Metetra
.664 .741 .907 r
.67406 .16119 .67504 .16258 .68186 .1601 .68088 .15871 Metetra
.664 .741 .907 r
.68088 .15871 .68186 .1601 .68869 .15761 .68771 .15622 Metetra
.664 .741 .907 r
.68771 .15622 .68869 .15761 .69554 .15512 .69456 .15373 Metetra
.664 .741 .907 r
.69456 .15373 .69554 .15512 .7024 .15262 .70143 .15123 Metetra
.95 .606 .217 r
.70143 .15123 .7024 .15262 .70928 .15012 .71246 .21583 Metetra
.379 .18 .48 r
.71246 .21583 .70928 .15012 .71618 .14761 .71522 .14621 Metetra
.664 .741 .907 r
.71522 .14621 .71618 .14761 .7231 .1451 .72214 .14369 Metetra
.664 .741 .907 r
.72214 .14369 .7231 .1451 .73003 .14258 .72907 .14117 Metetra
.664 .741 .907 r
.72907 .14117 .73003 .14258 .73697 .14005 .73602 .13864 Metetra
.664 .741 .907 r
.73602 .13864 .73697 .14005 .74394 .13752 .74299 .1361 Metetra
.664 .741 .907 r
.74299 .1361 .74394 .13752 .75092 .13498 .74998 .13356 Metetra
.664 .741 .907 r
.74998 .13356 .75092 .13498 .75792 .13243 .75698 .13101 Metetra
.664 .741 .907 r
.75698 .13101 .75792 .13243 .76494 .12988 .764 .12845 Metetra
.664 .741 .907 r
.764 .12845 .76494 .12988 .77197 .12732 .77104 .12589 Metetra
.664 .741 .907 r
.1422 .35324 .14342 .35438 .14901 .35234 .1478 .3512 Metetra
.664 .741 .907 r
.1478 .3512 .14901 .35234 .15462 .3503 .15341 .34915 Metetra
.664 .741 .907 r
.15341 .34915 .15462 .3503 .16024 .34825 .15903 .34711 Metetra
.664 .741 .907 r
.15903 .34711 .16024 .34825 .16588 .3462 .16467 .34505 Metetra
.664 .741 .907 r
.16467 .34505 .16588 .3462 .17152 .34414 .17032 .34299 Metetra
.664 .741 .907 r
.17032 .34299 .17152 .34414 .17718 .34208 .17598 .34093 Metetra
.664 .741 .907 r
.17598 .34093 .17718 .34208 .18285 .34002 .18165 .33886 Metetra
.664 .741 .907 r
.18165 .33886 .18285 .34002 .18854 .33795 .18734 .33679 Metetra
.664 .741 .907 r
.18734 .33679 .18854 .33795 .19423 .33588 .19304 .33472 Metetra
.664 .741 .907 r
.19304 .33472 .19423 .33588 .19994 .3338 .19875 .33264 Metetra
.664 .741 .907 r
.19875 .33264 .19994 .3338 .20566 .33171 .20447 .33055 Metetra
.664 .741 .907 r
.20447 .33055 .20566 .33171 .2114 .32963 .21021 .32846 Metetra
.664 .741 .907 r
.21021 .32846 .2114 .32963 .21714 .32754 .21595 .32637 Metetra
.664 .741 .907 r
.21595 .32637 .21714 .32754 .2229 .32544 .22172 .32427 Metetra
.664 .741 .907 r
.22172 .32427 .2229 .32544 .22867 .32334 .22749 .32216 Metetra
.664 .741 .907 r
.22749 .32216 .22867 .32334 .23446 .32123 .23328 .32005 Metetra
.664 .741 .907 r
.23328 .32005 .23446 .32123 .24026 .31912 .23908 .31794 Metetra
.664 .741 .907 r
.23908 .31794 .24026 .31912 .24607 .31701 .24489 .31582 Metetra
.664 .741 .907 r
.24489 .31582 .24607 .31701 .25189 .31489 .25072 .3137 Metetra
.664 .741 .907 r
.25072 .3137 .25189 .31489 .25773 .31276 .25656 .31157 Metetra
.664 .741 .907 r
.25656 .31157 .25773 .31276 .26358 .31063 .26241 .30944 Metetra
.664 .741 .907 r
.26241 .30944 .26358 .31063 .26944 .3085 .26827 .3073 Metetra
.664 .741 .907 r
.26827 .3073 .26944 .3085 .27532 .30636 .27415 .30516 Metetra
.664 .741 .907 r
.27415 .30516 .27532 .30636 .2812 .30421 .28004 .30302 Metetra
.664 .741 .907 r
.28004 .30302 .2812 .30421 .28711 .30206 .28595 .30086 Metetra
.664 .741 .907 r
.28595 .30086 .28711 .30206 .29302 .29991 .29186 .29871 Metetra
.664 .741 .907 r
.29186 .29871 .29302 .29991 .29895 .29775 .2978 .29655 Metetra
.664 .741 .907 r
.2978 .29655 .29895 .29775 .30489 .29559 .30374 .29438 Metetra
.664 .741 .907 r
.30374 .29438 .30489 .29559 .31085 .29342 .3097 .29221 Metetra
.664 .741 .907 r
.3097 .29221 .31085 .29342 .31682 .29125 .31567 .29003 Metetra
.664 .741 .907 r
.31567 .29003 .31682 .29125 .3228 .28907 .32166 .28785 Metetra
.664 .741 .907 r
.32166 .28785 .3228 .28907 .3288 .28689 .32765 .28567 Metetra
.664 .741 .907 r
.32765 .28567 .3288 .28689 .33481 .2847 .33367 .28348 Metetra
.664 .741 .907 r
.33367 .28348 .33481 .2847 .34083 .28251 .33969 .28128 Metetra
.664 .741 .907 r
.33969 .28128 .34083 .28251 .34687 .28031 .34573 .27908 Metetra
.664 .741 .907 r
.34573 .27908 .34687 .28031 .35292 .27811 .35179 .27688 Metetra
.664 .741 .907 r
.35179 .27688 .35292 .27811 .35898 .2759 .35785 .27466 Metetra
.664 .741 .907 r
.35785 .27466 .35898 .2759 .36506 .27369 .36393 .27245 Metetra
.961 .654 .401 r
.36393 .27245 .36506 .27369 .3706 .28265 .36678 .33505 Metetra
.748 .477 .522 r
.36678 .33505 .3706 .28265 .3661 .50299 .36488 .50181 Metetra
.96 .696 .489 r
.36488 .50181 .3661 .50299 .38295 .27634 .38226 .26577 Metetra
.559 .373 .585 r
.38226 .26577 .38295 .27634 .38951 .26478 .3884 .26354 Metetra
.664 .741 .907 r
.3884 .26354 .38951 .26478 .39566 .26254 .39455 .26129 Metetra
.664 .741 .907 r
.39455 .26129 .39566 .26254 .40183 .2603 .40071 .25905 Metetra
.664 .741 .907 r
.40071 .25905 .40183 .2603 .408 .25805 .40689 .2568 Metetra
.664 .741 .907 r
.40689 .2568 .408 .25805 .41419 .2558 .41309 .25454 Metetra
.664 .741 .907 r
.41309 .25454 .41419 .2558 .4204 .25354 .41929 .25228 Metetra
.664 .741 .907 r
.41929 .25228 .4204 .25354 .42662 .25128 .42552 .25001 Metetra
.664 .741 .907 r
.42552 .25001 .42662 .25128 .43285 .24901 .43175 .24774 Metetra
.664 .741 .907 r
.43175 .24774 .43285 .24901 .4391 .24673 .438 .24546 Metetra
.664 .741 .907 r
.438 .24546 .4391 .24673 .44536 .24445 .44427 .24318 Metetra
.664 .741 .907 r
.44427 .24318 .44536 .24445 .45164 .24217 .45055 .24089 Metetra
.664 .741 .907 r
.45055 .24089 .45164 .24217 .45793 .23988 .45684 .2386 Metetra
.664 .741 .907 r
.45684 .2386 .45793 .23988 .46424 .23758 .46315 .2363 Metetra
.664 .741 .907 r
.46315 .2363 .46424 .23758 .47056 .23528 .46947 .23399 Metetra
.664 .741 .907 r
.46947 .23399 .47056 .23528 .47689 .23297 .47581 .23168 Metetra
.664 .741 .907 r
.47581 .23168 .47689 .23297 .48324 .23066 .48217 .22937 Metetra
.664 .741 .907 r
.48217 .22937 .48324 .23066 .48961 .22834 .48853 .22705 Metetra
.664 .741 .907 r
.48853 .22705 .48961 .22834 .49599 .22602 .49492 .22472 Metetra
.664 .741 .907 r
.49492 .22472 .49599 .22602 .50238 .22369 .50131 .22239 Metetra
.664 .741 .907 r
.50131 .22239 .50238 .22369 .50879 .22136 .50773 .22006 Metetra
.664 .741 .907 r
.50773 .22006 .50879 .22136 .51522 .21902 .51415 .21771 Metetra
.664 .741 .907 r
.51415 .21771 .51522 .21902 .52166 .21668 .5206 .21537 Metetra
.664 .741 .907 r
.5206 .21537 .52166 .21668 .52811 .21433 .52706 .21301 Metetra
.664 .741 .907 r
.52706 .21301 .52811 .21433 .53458 .21197 .53353 .21065 Metetra
.664 .741 .907 r
.53353 .21065 .53458 .21197 .54107 .20961 .54002 .20829 Metetra
.664 .741 .907 r
.54002 .20829 .54107 .20961 .54757 .20724 .54652 .20592 Metetra
.664 .741 .907 r
.54652 .20592 .54757 .20724 .55408 .20487 .55304 .20355 Metetra
.664 .741 .907 r
.55304 .20355 .55408 .20487 .56062 .20249 .55958 .20116 Metetra
.664 .741 .907 r
.55958 .20116 .56062 .20249 .56716 .20011 .56613 .19878 Metetra
.664 .741 .907 r
.56613 .19878 .56716 .20011 .57372 .19772 .57269 .19639 Metetra
.664 .741 .907 r
.57269 .19639 .57372 .19772 .5803 .19533 .57927 .19399 Metetra
.664 .741 .907 r
.57927 .19399 .5803 .19533 .5869 .19293 .58587 .19158 Metetra
.664 .741 .907 r
.58587 .19158 .5869 .19293 .59351 .19052 .59248 .18918 Metetra
.664 .741 .907 r
.59248 .18918 .59351 .19052 .60013 .18811 .59911 .18676 Metetra
.664 .741 .907 r
.59911 .18676 .60013 .18811 .60677 .18569 .60575 .18434 Metetra
.664 .741 .907 r
.60575 .18434 .60677 .18569 .61343 .18327 .61241 .18191 Metetra
.664 .741 .907 r
.61241 .18191 .61343 .18327 .6201 .18084 .61909 .17948 Metetra
.664 .741 .907 r
.61909 .17948 .6201 .18084 .62679 .1784 .62578 .17704 Metetra
.664 .741 .907 r
.62578 .17704 .62679 .1784 .63349 .17596 .63249 .1746 Metetra
.664 .741 .907 r
.63249 .1746 .63349 .17596 .64021 .17352 .63921 .17215 Metetra
.664 .741 .907 r
.63921 .17215 .64021 .17352 .64695 .17106 .64595 .16969 Metetra
.664 .741 .907 r
.64595 .16969 .64695 .17106 .6537 .1686 .65271 .16723 Metetra
.664 .741 .907 r
.65271 .16723 .6537 .1686 .66047 .16614 .65948 .16476 Metetra
.664 .741 .907 r
.65948 .16476 .66047 .16614 .66726 .16367 .66627 .16229 Metetra
.664 .741 .907 r
.66627 .16229 .66726 .16367 .67406 .16119 .67307 .15981 Metetra
.664 .741 .907 r
.67307 .15981 .67406 .16119 .68088 .15871 .6799 .15732 Metetra
0 .305 .797 r
.6799 .15732 .68088 .15871 .68771 .15622 .68713 .16208 Metetra
.263 0 .314 r
.68713 .16208 .68771 .15622 .69456 .15373 .69359 .15234 Metetra
.664 .741 .907 r
.69359 .15234 .69456 .15373 .70143 .15123 .70046 .14983 Metetra
.664 .741 .907 r
.70046 .14983 .70143 .15123 .71246 .21583 .70735 .14732 Metetra
.529 .307 .522 r
.70735 .14732 .71246 .21583 .71522 .14621 .71425 .14481 Metetra
.664 .741 .907 r
.71425 .14481 .71522 .14621 .72214 .14369 .72117 .14228 Metetra
.664 .741 .907 r
.72117 .14228 .72214 .14369 .72907 .14117 .72811 .13976 Metetra
.664 .741 .907 r
.72811 .13976 .72907 .14117 .73602 .13864 .73507 .13722 Metetra
.664 .741 .907 r
.73507 .13722 .73602 .13864 .74299 .1361 .74204 .13468 Metetra
.664 .741 .907 r
.74204 .13468 .74299 .1361 .74998 .13356 .74903 .13214 Metetra
.664 .741 .907 r
.74903 .13214 .74998 .13356 .75698 .13101 .75604 .12958 Metetra
.664 .741 .907 r
.75604 .12958 .75698 .13101 .764 .12845 .76306 .12702 Metetra
.664 .741 .907 r
.76306 .12702 .764 .12845 .77104 .12589 .7701 .12446 Metetra
.664 .741 .907 r
.14098 .3521 .1422 .35324 .1478 .3512 .14658 .35006 Metetra
.664 .741 .907 r
.14658 .35006 .1478 .3512 .15341 .34915 .1522 .34801 Metetra
.664 .741 .907 r
.1522 .34801 .15341 .34915 .15903 .34711 .15782 .34596 Metetra
.664 .741 .907 r
.15782 .34596 .15903 .34711 .16467 .34505 .16346 .34391 Metetra
.664 .741 .907 r
.16346 .34391 .16467 .34505 .17032 .34299 .16911 .34184 Metetra
.664 .741 .907 r
.16911 .34184 .17032 .34299 .17598 .34093 .17477 .33978 Metetra
.664 .741 .907 r
.17477 .33978 .17598 .34093 .18165 .33886 .18045 .33771 Metetra
.664 .741 .907 r
.18045 .33771 .18165 .33886 .18734 .33679 .18614 .33564 Metetra
.664 .741 .907 r
.18614 .33564 .18734 .33679 .19304 .33472 .19184 .33356 Metetra
.664 .741 .907 r
.19184 .33356 .19304 .33472 .19875 .33264 .19755 .33147 Metetra
.664 .741 .907 r
.19755 .33147 .19875 .33264 .20447 .33055 .20328 .32939 Metetra
.664 .741 .907 r
.20328 .32939 .20447 .33055 .21021 .32846 .20901 .32729 Metetra
.664 .741 .907 r
.20901 .32729 .21021 .32846 .21595 .32637 .21476 .3252 Metetra
.526 .022 0 r
.21476 .3252 .21595 .32637 .22172 .32427 .21982 .33039 Metetra
.53 .226 .396 r
.21982 .33039 .22172 .32427 .22749 .32216 .22528 .3318 Metetra
.253 .007 .334 r
.22528 .3318 .22749 .32216 .23328 .32005 .23209 .31888 Metetra
.664 .741 .907 r
.23209 .31888 .23328 .32005 .23908 .31794 .2379 .31676 Metetra
.664 .741 .907 r
.2379 .31676 .23908 .31794 .24489 .31582 .24371 .31464 Metetra
.664 .741 .907 r
.24371 .31464 .24489 .31582 .25072 .3137 .24954 .31251 Metetra
.664 .741 .907 r
.24954 .31251 .25072 .3137 .25656 .31157 .25538 .31038 Metetra
.664 .741 .907 r
.25538 .31038 .25656 .31157 .26241 .30944 .26124 .30825 Metetra
.664 .741 .907 r
.26124 .30825 .26241 .30944 .26827 .3073 .2671 .30611 Metetra
.664 .741 .907 r
.2671 .30611 .26827 .3073 .27415 .30516 .27298 .30397 Metetra
.664 .741 .907 r
.27298 .30397 .27415 .30516 .28004 .30302 .27888 .30182 Metetra
.664 .741 .907 r
.27888 .30182 .28004 .30302 .28595 .30086 .28479 .29966 Metetra
.664 .741 .907 r
.28479 .29966 .28595 .30086 .29186 .29871 .29071 .2975 Metetra
.664 .741 .907 r
.29071 .2975 .29186 .29871 .2978 .29655 .29664 .29534 Metetra
.664 .741 .907 r
.29664 .29534 .2978 .29655 .30374 .29438 .30259 .29317 Metetra
.664 .741 .907 r
.30259 .29317 .30374 .29438 .3097 .29221 .30855 .291 Metetra
.664 .741 .907 r
.30855 .291 .3097 .29221 .31567 .29003 .31452 .28882 Metetra
.664 .741 .907 r
.31452 .28882 .31567 .29003 .32166 .28785 .32051 .28663 Metetra
.664 .741 .907 r
.32051 .28663 .32166 .28785 .32765 .28567 .32651 .28445 Metetra
.664 .741 .907 r
.32651 .28445 .32765 .28567 .33367 .28348 .33252 .28225 Metetra
.664 .741 .907 r
.33252 .28225 .33367 .28348 .33969 .28128 .33855 .28005 Metetra
.664 .741 .907 r
.33855 .28005 .33969 .28128 .34573 .27908 .3446 .27785 Metetra
.664 .741 .907 r
.3446 .27785 .34573 .27908 .35179 .27688 .35065 .27564 Metetra
.664 .741 .907 r
.35065 .27564 .35179 .27688 .35785 .27466 .35672 .27343 Metetra
.664 .741 .907 r
.35672 .27343 .35785 .27466 .36393 .27245 .3628 .27121 Metetra
.961 .656 .405 r
.3628 .27121 .36393 .27245 .36678 .33505 .36546 .33724 Metetra
.905 .588 .435 r
.36546 .33724 .36678 .33505 .36488 .50181 .36932 .38415 Metetra
.639 .394 .531 r
.36932 .38415 .36488 .50181 .38226 .26577 .38114 .26452 Metetra
.664 .741 .907 r
.38114 .26452 .38226 .26577 .3884 .26354 .38728 .26229 Metetra
.664 .741 .907 r
.38728 .26229 .3884 .26354 .39455 .26129 .39343 .26004 Metetra
.664 .741 .907 r
.39343 .26004 .39455 .26129 .40071 .25905 .3996 .25779 Metetra
.664 .741 .907 r
.3996 .25779 .40071 .25905 .40689 .2568 .40578 .25554 Metetra
.664 .741 .907 r
.40578 .25554 .40689 .2568 .41309 .25454 .41198 .25328 Metetra
.664 .741 .907 r
.41198 .25328 .41309 .25454 .41929 .25228 .41819 .25101 Metetra
.664 .741 .907 r
.41819 .25101 .41929 .25228 .42552 .25001 .42441 .24874 Metetra
.664 .741 .907 r
.42441 .24874 .42552 .25001 .43175 .24774 .43065 .24647 Metetra
.664 .741 .907 r
.43065 .24647 .43175 .24774 .438 .24546 .43691 .24419 Metetra
.664 .741 .907 r
.43691 .24419 .438 .24546 .44427 .24318 .44317 .2419 Metetra
.664 .741 .907 r
.44317 .2419 .44427 .24318 .45055 .24089 .44946 .23961 Metetra
.664 .741 .907 r
.44946 .23961 .45055 .24089 .45684 .2386 .45575 .23732 Metetra
.664 .741 .907 r
.45575 .23732 .45684 .2386 .46315 .2363 .46206 .23501 Metetra
.664 .741 .907 r
.46206 .23501 .46315 .2363 .46947 .23399 .46839 .23271 Metetra
.664 .741 .907 r
.46839 .23271 .46947 .23399 .47581 .23168 .47473 .23039 Metetra
.664 .741 .907 r
.47473 .23039 .47581 .23168 .48217 .22937 .48109 .22808 Metetra
.664 .741 .907 r
.48109 .22808 .48217 .22937 .48853 .22705 .48746 .22575 Metetra
.664 .741 .907 r
.48746 .22575 .48853 .22705 .49492 .22472 .49384 .22342 Metetra
.664 .741 .907 r
.49384 .22342 .49492 .22472 .50131 .22239 .50025 .22109 Metetra
.664 .741 .907 r
.50025 .22109 .50131 .22239 .50773 .22006 .50666 .21875 Metetra
.664 .741 .907 r
.50666 .21875 .50773 .22006 .51415 .21771 .51309 .21641 Metetra
.664 .741 .907 r
.51309 .21641 .51415 .21771 .5206 .21537 .51954 .21405 Metetra
.664 .741 .907 r
.51954 .21405 .5206 .21537 .52706 .21301 .526 .2117 Metetra
.664 .741 .907 r
.526 .2117 .52706 .21301 .53353 .21065 .53248 .20934 Metetra
.664 .741 .907 r
.53248 .20934 .53353 .21065 .54002 .20829 .53897 .20697 Metetra
.664 .741 .907 r
.53897 .20697 .54002 .20829 .54652 .20592 .54547 .2046 Metetra
.664 .741 .907 r
.54547 .2046 .54652 .20592 .55304 .20355 .552 .20222 Metetra
.664 .741 .907 r
.552 .20222 .55304 .20355 .55958 .20116 .55853 .19983 Metetra
.664 .741 .907 r
.55853 .19983 .55958 .20116 .56613 .19878 .56509 .19744 Metetra
.664 .741 .907 r
.56509 .19744 .56613 .19878 .57269 .19639 .57166 .19505 Metetra
.664 .741 .907 r
.57166 .19505 .57269 .19639 .57927 .19399 .57824 .19265 Metetra
.664 .741 .907 r
.57824 .19265 .57927 .19399 .58587 .19158 .58484 .19024 Metetra
.664 .741 .907 r
.58484 .19024 .58587 .19158 .59248 .18918 .59145 .18783 Metetra
.664 .741 .907 r
.59145 .18783 .59248 .18918 .59911 .18676 .59809 .18541 Metetra
.664 .741 .907 r
.59809 .18541 .59911 .18676 .60575 .18434 .60473 .18299 Metetra
.664 .741 .907 r
.60473 .18299 .60575 .18434 .61241 .18191 .6114 .18056 Metetra
.664 .741 .907 r
.6114 .18056 .61241 .18191 .61909 .17948 .61808 .17812 Metetra
.664 .741 .907 r
.61808 .17812 .61909 .17948 .62578 .17704 .62477 .17568 Metetra
.664 .741 .907 r
.62477 .17568 .62578 .17704 .63249 .1746 .63148 .17323 Metetra
.664 .741 .907 r
.63148 .17323 .63249 .1746 .63921 .17215 .63821 .17078 Metetra
.664 .741 .907 r
.63821 .17078 .63921 .17215 .64595 .16969 .64495 .16832 Metetra
.664 .741 .907 r
.64495 .16832 .64595 .16969 .65271 .16723 .65171 .16586 Metetra
.664 .741 .907 r
.65171 .16586 .65271 .16723 .65948 .16476 .65849 .16338 Metetra
.664 .741 .907 r
.65849 .16338 .65948 .16476 .66627 .16229 .66528 .16091 Metetra
.664 .741 .907 r
.66528 .16091 .66627 .16229 .67307 .15981 .67209 .15842 Metetra
.664 .741 .907 r
.67209 .15842 .67307 .15981 .6799 .15732 .67891 .15594 Metetra
.664 .741 .907 r
.67891 .15594 .6799 .15732 .68713 .16208 .68575 .15344 Metetra
.567 .392 .604 r
.68575 .15344 .68713 .16208 .69359 .15234 .69261 .15094 Metetra
.664 .741 .907 r
.69261 .15094 .69359 .15234 .70046 .14983 .69949 .14843 Metetra
.664 .741 .907 r
.69949 .14843 .70046 .14983 .70735 .14732 .70638 .14592 Metetra
.664 .741 .907 r
.70638 .14592 .70735 .14732 .71425 .14481 .71329 .1434 Metetra
.664 .741 .907 r
.71329 .1434 .71425 .14481 .72117 .14228 .72021 .14088 Metetra
.664 .741 .907 r
.72021 .14088 .72117 .14228 .72811 .13976 .72715 .13834 Metetra
.664 .741 .907 r
.72715 .13834 .72811 .13976 .73507 .13722 .73411 .13581 Metetra
.664 .741 .907 r
.73411 .13581 .73507 .13722 .74204 .13468 .74109 .13326 Metetra
.664 .741 .907 r
.74109 .13326 .74204 .13468 .74903 .13214 .74808 .13071 Metetra
.664 .741 .907 r
.74808 .13071 .74903 .13214 .75604 .12958 .75509 .12816 Metetra
.664 .741 .907 r
.75509 .12816 .75604 .12958 .76306 .12702 .76212 .12559 Metetra
.664 .741 .907 r
.76212 .12559 .76306 .12702 .7701 .12446 .76916 .12302 Metetra
.664 .741 .907 r
.13976 .35096 .14098 .3521 .14658 .35006 .14537 .34892 Metetra
.664 .741 .907 r
.14537 .34892 .14658 .35006 .1522 .34801 .15098 .34687 Metetra
.664 .741 .907 r
.15098 .34687 .1522 .34801 .15782 .34596 .15661 .34482 Metetra
.664 .741 .907 r
.15661 .34482 .15782 .34596 .16346 .34391 .16225 .34276 Metetra
.664 .741 .907 r
.16225 .34276 .16346 .34391 .16911 .34184 .1679 .34069 Metetra
.664 .741 .907 r
.1679 .34069 .16911 .34184 .17477 .33978 .17357 .33863 Metetra
.664 .741 .907 r
.17357 .33863 .17477 .33978 .18045 .33771 .17924 .33655 Metetra
.664 .741 .907 r
.17924 .33655 .18045 .33771 .18614 .33564 .18493 .33448 Metetra
.664 .741 .907 r
.18493 .33448 .18614 .33564 .19184 .33356 .19064 .3324 Metetra
.664 .741 .907 r
.19064 .3324 .19184 .33356 .19755 .33147 .19635 .33031 Metetra
.664 .741 .907 r
.19635 .33031 .19755 .33147 .20328 .32939 .20208 .32822 Metetra
.664 .741 .907 r
.20208 .32822 .20328 .32939 .20901 .32729 .20782 .32612 Metetra
.664 .741 .907 r
.20782 .32612 .20901 .32729 .21476 .3252 .21357 .32402 Metetra
.949 .624 .379 r
.21357 .32402 .21476 .3252 .21982 .33039 .21631 .35314 Metetra
.222 .018 .377 r
.21631 .35314 .21982 .33039 .22528 .3318 .22512 .31981 Metetra
.554 .362 .575 r
.22512 .31981 .22528 .3318 .23209 .31888 .23091 .3177 Metetra
.664 .741 .907 r
.23091 .3177 .23209 .31888 .2379 .31676 .23671 .31558 Metetra
.664 .741 .907 r
.23671 .31558 .2379 .31676 .24371 .31464 .24253 .31346 Metetra
.664 .741 .907 r
.24253 .31346 .24371 .31464 .24954 .31251 .24836 .31133 Metetra
.664 .741 .907 r
.24836 .31133 .24954 .31251 .25538 .31038 .25421 .30919 Metetra
.664 .741 .907 r
.25421 .30919 .25538 .31038 .26124 .30825 .26006 .30706 Metetra
.664 .741 .907 r
.26006 .30706 .26124 .30825 .2671 .30611 .26593 .30491 Metetra
.664 .741 .907 r
.26593 .30491 .2671 .30611 .27298 .30397 .27182 .30277 Metetra
.664 .741 .907 r
.27182 .30277 .27298 .30397 .27888 .30182 .27771 .30062 Metetra
.664 .741 .907 r
.27771 .30062 .27888 .30182 .28479 .29966 .28362 .29846 Metetra
.664 .741 .907 r
.28362 .29846 .28479 .29966 .29071 .2975 .28954 .2963 Metetra
.664 .741 .907 r
.28954 .2963 .29071 .2975 .29664 .29534 .29548 .29413 Metetra
.664 .741 .907 r
.29548 .29413 .29664 .29534 .30259 .29317 .30143 .29196 Metetra
.664 .741 .907 r
.30143 .29196 .30259 .29317 .30855 .291 .30739 .28978 Metetra
.664 .741 .907 r
.30739 .28978 .30855 .291 .31452 .28882 .31337 .2876 Metetra
.664 .741 .907 r
.31337 .2876 .31452 .28882 .32051 .28663 .31936 .28541 Metetra
.664 .741 .907 r
.31936 .28541 .32051 .28663 .32651 .28445 .32536 .28322 Metetra
.664 .741 .907 r
.32536 .28322 .32651 .28445 .33252 .28225 .33138 .28103 Metetra
.664 .741 .907 r
.33138 .28103 .33252 .28225 .33855 .28005 .33741 .27883 Metetra
.664 .741 .907 r
.33741 .27883 .33855 .28005 .3446 .27785 .34346 .27662 Metetra
.664 .741 .907 r
.34346 .27662 .3446 .27785 .35065 .27564 .34952 .27441 Metetra
.664 .741 .907 r
.34952 .27441 .35065 .27564 .35672 .27343 .35559 .27219 Metetra
.664 .741 .907 r
.35559 .27219 .35672 .27343 .3628 .27121 .36167 .26997 Metetra
.664 .741 .907 r
.36167 .26997 .3628 .27121 .36546 .33724 .36777 .26774 Metetra
.409 .211 .497 r
.36777 .26774 .36546 .33724 .36932 .38415 .37126 .3192 Metetra
.622 .383 .534 r
.37126 .3192 .36932 .38415 .38114 .26452 .38002 .26328 Metetra
.664 .741 .907 r
.38002 .26328 .38114 .26452 .38728 .26229 .38616 .26103 Metetra
.664 .741 .907 r
.38616 .26103 .38728 .26229 .39343 .26004 .39231 .25879 Metetra
.664 .741 .907 r
.39231 .25879 .39343 .26004 .3996 .25779 .39848 .25654 Metetra
.664 .741 .907 r
.39848 .25654 .3996 .25779 .40578 .25554 .40467 .25428 Metetra
.664 .741 .907 r
.40467 .25428 .40578 .25554 .41198 .25328 .41087 .25202 Metetra
.664 .741 .907 r
.41087 .25202 .41198 .25328 .41819 .25101 .41708 .24975 Metetra
.664 .741 .907 r
.41708 .24975 .41819 .25101 .42441 .24874 .42331 .24748 Metetra
.664 .741 .907 r
.42331 .24748 .42441 .24874 .43065 .24647 .42955 .2452 Metetra
.664 .741 .907 r
.42955 .2452 .43065 .24647 .43691 .24419 .43581 .24291 Metetra
.664 .741 .907 r
.43581 .24291 .43691 .24419 .44317 .2419 .44208 .24063 Metetra
.664 .741 .907 r
.44208 .24063 .44317 .2419 .44946 .23961 .44836 .23833 Metetra
.664 .741 .907 r
.44836 .23833 .44946 .23961 .45575 .23732 .45466 .23603 Metetra
.664 .741 .907 r
.45466 .23603 .45575 .23732 .46206 .23501 .46098 .23373 Metetra
.664 .741 .907 r
.46098 .23373 .46206 .23501 .46839 .23271 .46731 .23142 Metetra
.664 .741 .907 r
.46731 .23142 .46839 .23271 .47473 .23039 .47365 .2291 Metetra
.664 .741 .907 r
.47365 .2291 .47473 .23039 .48109 .22808 .48001 .22678 Metetra
.664 .741 .907 r
.48001 .22678 .48109 .22808 .48746 .22575 .48638 .22445 Metetra
.664 .741 .907 r
.48638 .22445 .48746 .22575 .49384 .22342 .49277 .22212 Metetra
.664 .741 .907 r
.49277 .22212 .49384 .22342 .50025 .22109 .49918 .21979 Metetra
.664 .741 .907 r
.49918 .21979 .50025 .22109 .50666 .21875 .50559 .21744 Metetra
.664 .741 .907 r
.50559 .21744 .50666 .21875 .51309 .21641 .51203 .2151 Metetra
.664 .741 .907 r
.51203 .2151 .51309 .21641 .51954 .21405 .51848 .21274 Metetra
.664 .741 .907 r
.51848 .21274 .51954 .21405 .526 .2117 .52494 .21038 Metetra
.664 .741 .907 r
.52494 .21038 .526 .2117 .53248 .20934 .53142 .20802 Metetra
.664 .741 .907 r
.53142 .20802 .53248 .20934 .53897 .20697 .53791 .20565 Metetra
.664 .741 .907 r
.53791 .20565 .53897 .20697 .54547 .2046 .54442 .20327 Metetra
.664 .741 .907 r
.54442 .20327 .54547 .2046 .552 .20222 .55095 .20089 Metetra
.664 .741 .907 r
.55095 .20089 .552 .20222 .55853 .19983 .55749 .1985 Metetra
.664 .741 .907 r
.55749 .1985 .55853 .19983 .56509 .19744 .56405 .19611 Metetra
.664 .741 .907 r
.56405 .19611 .56509 .19744 .57166 .19505 .57062 .19371 Metetra
.664 .741 .907 r
.57062 .19371 .57166 .19505 .57824 .19265 .57721 .19131 Metetra
.664 .741 .907 r
.57721 .19131 .57824 .19265 .58484 .19024 .58381 .1889 Metetra
.664 .741 .907 r
.58381 .1889 .58484 .19024 .59145 .18783 .59043 .18648 Metetra
.664 .741 .907 r
.59043 .18648 .59145 .18783 .59809 .18541 .59706 .18406 Metetra
.664 .741 .907 r
.59706 .18406 .59809 .18541 .60473 .18299 .60371 .18163 Metetra
.664 .741 .907 r
.60371 .18163 .60473 .18299 .6114 .18056 .61038 .1792 Metetra
.664 .741 .907 r
.61038 .1792 .6114 .18056 .61808 .17812 .61706 .17676 Metetra
.664 .741 .907 r
.61706 .17676 .61808 .17812 .62477 .17568 .62376 .17432 Metetra
.664 .741 .907 r
.62376 .17432 .62477 .17568 .63148 .17323 .63047 .17187 Metetra
.664 .741 .907 r
.63047 .17187 .63148 .17323 .63821 .17078 .6372 .16941 Metetra
.664 .741 .907 r
.6372 .16941 .63821 .17078 .64495 .16832 .64395 .16695 Metetra
.664 .741 .907 r
.64395 .16695 .64495 .16832 .65171 .16586 .65071 .16448 Metetra
.664 .741 .907 r
.65071 .16448 .65171 .16586 .65849 .16338 .65749 .162 Metetra
.664 .741 .907 r
.65749 .162 .65849 .16338 .66528 .16091 .66429 .15952 Metetra
.664 .741 .907 r
.66429 .15952 .66528 .16091 .67209 .15842 .6711 .15704 Metetra
.664 .741 .907 r
.6711 .15704 .67209 .15842 .67891 .15594 .67793 .15455 Metetra
.664 .741 .907 r
.67793 .15455 .67891 .15594 .68575 .15344 .68477 .15205 Metetra
.664 .741 .907 r
.68477 .15205 .68575 .15344 .69261 .15094 .69163 .14954 Metetra
.664 .741 .907 r
.69163 .14954 .69261 .15094 .69949 .14843 .69851 .14703 Metetra
.664 .741 .907 r
.69851 .14703 .69949 .14843 .70638 .14592 .70541 .14452 Metetra
.664 .741 .907 r
.70541 .14452 .70638 .14592 .71329 .1434 .71232 .14199 Metetra
.664 .741 .907 r
.71232 .14199 .71329 .1434 .72021 .14088 .71925 .13946 Metetra
.664 .741 .907 r
.71925 .13946 .72021 .14088 .72715 .13834 .72619 .13693 Metetra
.664 .741 .907 r
.72619 .13693 .72715 .13834 .73411 .13581 .73316 .13439 Metetra
.664 .741 .907 r
.73316 .13439 .73411 .13581 .74109 .13326 .74014 .13184 Metetra
.664 .741 .907 r
.74014 .13184 .74109 .13326 .74808 .13071 .74713 .12929 Metetra
.664 .741 .907 r
.74713 .12929 .74808 .13071 .75509 .12816 .75415 .12673 Metetra
.664 .741 .907 r
.75415 .12673 .75509 .12816 .76212 .12559 .76118 .12416 Metetra
.664 .741 .907 r
.76118 .12416 .76212 .12559 .76916 .12302 .76822 .12159 Metetra
.664 .741 .907 r
.13854 .34982 .13976 .35096 .14537 .34892 .14415 .34778 Metetra
.664 .741 .907 r
.14415 .34778 .14537 .34892 .15098 .34687 .14977 .34572 Metetra
.664 .741 .907 r
.14977 .34572 .15098 .34687 .15661 .34482 .1554 .34367 Metetra
.664 .741 .907 r
.1554 .34367 .15661 .34482 .16225 .34276 .16104 .34161 Metetra
.664 .741 .907 r
.16104 .34161 .16225 .34276 .1679 .34069 .16669 .33954 Metetra
.664 .741 .907 r
.16669 .33954 .1679 .34069 .17357 .33863 .17236 .33747 Metetra
.664 .741 .907 r
.17236 .33747 .17357 .33863 .17924 .33655 .17804 .3354 Metetra
.664 .741 .907 r
.17804 .3354 .17924 .33655 .18493 .33448 .18373 .33332 Metetra
.664 .741 .907 r
.18373 .33332 .18493 .33448 .19064 .3324 .18944 .33123 Metetra
.664 .741 .907 r
.18944 .33123 .19064 .3324 .19635 .33031 .19515 .32914 Metetra
.664 .741 .907 r
.19515 .32914 .19635 .33031 .20208 .32822 .20088 .32705 Metetra
.664 .741 .907 r
.20088 .32705 .20208 .32822 .20782 .32612 .20663 .32495 Metetra
.664 .741 .907 r
.20663 .32495 .20782 .32612 .21357 .32402 .21238 .32285 Metetra
0 .093 .593 r
.21238 .32285 .21357 .32402 .21631 .35314 .21751 .32728 Metetra
.569 .352 .546 r
.21751 .32728 .21631 .35314 .22512 .31981 .22393 .31863 Metetra
.664 .741 .907 r
.22393 .31863 .22512 .31981 .23091 .3177 .22972 .31652 Metetra
.664 .741 .907 r
.22972 .31652 .23091 .3177 .23671 .31558 .23553 .31439 Metetra
.664 .741 .907 r
.23553 .31439 .23671 .31558 .24253 .31346 .24135 .31227 Metetra
.664 .741 .907 r
.24135 .31227 .24253 .31346 .24836 .31133 .24718 .31014 Metetra
.664 .741 .907 r
.24718 .31014 .24836 .31133 .25421 .30919 .25303 .308 Metetra
.664 .741 .907 r
.25303 .308 .25421 .30919 .26006 .30706 .25889 .30586 Metetra
.664 .741 .907 r
.25889 .30586 .26006 .30706 .26593 .30491 .26476 .30372 Metetra
.664 .741 .907 r
.26476 .30372 .26593 .30491 .27182 .30277 .27065 .30157 Metetra
.664 .741 .907 r
.27065 .30157 .27182 .30277 .27771 .30062 .27655 .29941 Metetra
.664 .741 .907 r
.27655 .29941 .27771 .30062 .28362 .29846 .28246 .29725 Metetra
.664 .741 .907 r
.28246 .29725 .28362 .29846 .28954 .2963 .28838 .29509 Metetra
.664 .741 .907 r
.28838 .29509 .28954 .2963 .29548 .29413 .29432 .29292 Metetra
.664 .741 .907 r
.29432 .29292 .29548 .29413 .30143 .29196 .30027 .29075 Metetra
.664 .741 .907 r
.30027 .29075 .30143 .29196 .30739 .28978 .30624 .28857 Metetra
.664 .741 .907 r
.30624 .28857 .30739 .28978 .31337 .2876 .31222 .28638 Metetra
.664 .741 .907 r
.31222 .28638 .31337 .2876 .31936 .28541 .31821 .28419 Metetra
.664 .741 .907 r
.31821 .28419 .31936 .28541 .32536 .28322 .32422 .282 Metetra
.664 .741 .907 r
.32422 .282 .32536 .28322 .33138 .28103 .33024 .2798 Metetra
.664 .741 .907 r
.33024 .2798 .33138 .28103 .33741 .27883 .33627 .2776 Metetra
.664 .741 .907 r
.33627 .2776 .33741 .27883 .34346 .27662 .34232 .27539 Metetra
.664 .741 .907 r
.34232 .27539 .34346 .27662 .34952 .27441 .34838 .27317 Metetra
.664 .741 .907 r
.34838 .27317 .34952 .27441 .35559 .27219 .35445 .27095 Metetra
.664 .741 .907 r
.35445 .27095 .35559 .27219 .36167 .26997 .36054 .26873 Metetra
.664 .741 .907 r
.36054 .26873 .36167 .26997 .36777 .26774 .36664 .2665 Metetra
.664 .741 .907 r
.36664 .2665 .36777 .26774 .37126 .3192 .37276 .26427 Metetra
.529 .309 .524 r
.37276 .26427 .37126 .3192 .38002 .26328 .37889 .26203 Metetra
.664 .741 .907 r
.37889 .26203 .38002 .26328 .38616 .26103 .38504 .25978 Metetra
.664 .741 .907 r
.38504 .25978 .38616 .26103 .39231 .25879 .39119 .25753 Metetra
.664 .741 .907 r
.39119 .25753 .39231 .25879 .39848 .25654 .39737 .25528 Metetra
.664 .741 .907 r
.39737 .25528 .39848 .25654 .40467 .25428 .40356 .25302 Metetra
.664 .741 .907 r
.40356 .25302 .40467 .25428 .41087 .25202 .40976 .25075 Metetra
.664 .741 .907 r
.40976 .25075 .41087 .25202 .41708 .24975 .41597 .24848 Metetra
.664 .741 .907 r
.41597 .24848 .41708 .24975 .42331 .24748 .4222 .24621 Metetra
.664 .741 .907 r
.4222 .24621 .42331 .24748 .42955 .2452 .42845 .24392 Metetra
.664 .741 .907 r
.42845 .24392 .42955 .2452 .43581 .24291 .43471 .24164 Metetra
.664 .741 .907 r
.43471 .24164 .43581 .24291 .44208 .24063 .44098 .23935 Metetra
.664 .741 .907 r
.44098 .23935 .44208 .24063 .44836 .23833 .44727 .23705 Metetra
.664 .741 .907 r
.44727 .23705 .44836 .23833 .45466 .23603 .45357 .23475 Metetra
.664 .741 .907 r
.45357 .23475 .45466 .23603 .46098 .23373 .45989 .23244 Metetra
.664 .741 .907 r
.45989 .23244 .46098 .23373 .46731 .23142 .46622 .23013 Metetra
.664 .741 .907 r
.46622 .23013 .46731 .23142 .47365 .2291 .47257 .22781 Metetra
.966 .649 .358 r
.47257 .22781 .47365 .2291 .48001 .22678 .47786 .29652 Metetra
.358 .156 .464 r
.47786 .29652 .48001 .22678 .48638 .22445 .48531 .22316 Metetra
.664 .741 .907 r
.48531 .22316 .48638 .22445 .49277 .22212 .4917 .22082 Metetra
.664 .741 .907 r
.4917 .22082 .49277 .22212 .49918 .21979 .4981 .21848 Metetra
.664 .741 .907 r
.4981 .21848 .49918 .21979 .50559 .21744 .50453 .21613 Metetra
.664 .741 .907 r
.50453 .21613 .50559 .21744 .51203 .2151 .51096 .21378 Metetra
.664 .741 .907 r
.51096 .21378 .51203 .2151 .51848 .21274 .51741 .21143 Metetra
.664 .741 .907 r
.51741 .21143 .51848 .21274 .52494 .21038 .52388 .20906 Metetra
.664 .741 .907 r
.52388 .20906 .52494 .21038 .53142 .20802 .53036 .2067 Metetra
.664 .741 .907 r
.53036 .2067 .53142 .20802 .53791 .20565 .53686 .20432 Metetra
.664 .741 .907 r
.53686 .20432 .53791 .20565 .54442 .20327 .54337 .20194 Metetra
.664 .741 .907 r
.54337 .20194 .54442 .20327 .55095 .20089 .5499 .19956 Metetra
.664 .741 .907 r
.5499 .19956 .55095 .20089 .55749 .1985 .55645 .19717 Metetra
.664 .741 .907 r
.55645 .19717 .55749 .1985 .56405 .19611 .56301 .19477 Metetra
.664 .741 .907 r
.56301 .19477 .56405 .19611 .57062 .19371 .56958 .19237 Metetra
.664 .741 .907 r
.56958 .19237 .57062 .19371 .57721 .19131 .57617 .18996 Metetra
.664 .741 .907 r
.57617 .18996 .57721 .19131 .58381 .1889 .58278 .18755 Metetra
.664 .741 .907 r
.58278 .18755 .58381 .1889 .59043 .18648 .5894 .18513 Metetra
.664 .741 .907 r
.5894 .18513 .59043 .18648 .59706 .18406 .59604 .18271 Metetra
.664 .741 .907 r
.59604 .18271 .59706 .18406 .60371 .18163 .60269 .18028 Metetra
.664 .741 .907 r
.60269 .18028 .60371 .18163 .61038 .1792 .60936 .17784 Metetra
.664 .741 .907 r
.60936 .17784 .61038 .1792 .61706 .17676 .61604 .1754 Metetra
.664 .741 .907 r
.61604 .1754 .61706 .17676 .62376 .17432 .62275 .17295 Metetra
.664 .741 .907 r
.62275 .17295 .62376 .17432 .63047 .17187 .62946 .1705 Metetra
.664 .741 .907 r
.62946 .1705 .63047 .17187 .6372 .16941 .6362 .16804 Metetra
.664 .741 .907 r
.6362 .16804 .6372 .16941 .64395 .16695 .64295 .16557 Metetra
.664 .741 .907 r
.64295 .16557 .64395 .16695 .65071 .16448 .64971 .1631 Metetra
.664 .741 .907 r
.64971 .1631 .65071 .16448 .65749 .162 .6565 .16062 Metetra
.664 .741 .907 r
.6565 .16062 .65749 .162 .66429 .15952 .6633 .15814 Metetra
.664 .741 .907 r
.6633 .15814 .66429 .15952 .6711 .15704 .67011 .15565 Metetra
.664 .741 .907 r
.67011 .15565 .6711 .15704 .67793 .15455 .67694 .15315 Metetra
.664 .741 .907 r
.67694 .15315 .67793 .15455 .68477 .15205 .68379 .15065 Metetra
.664 .741 .907 r
.68379 .15065 .68477 .15205 .69163 .14954 .69066 .14814 Metetra
.664 .741 .907 r
.69066 .14814 .69163 .14954 .69851 .14703 .69754 .14563 Metetra
.664 .741 .907 r
.69754 .14563 .69851 .14703 .70541 .14452 .70444 .14311 Metetra
.664 .741 .907 r
.70444 .14311 .70541 .14452 .71232 .14199 .71135 .14058 Metetra
.664 .741 .907 r
.71135 .14058 .71232 .14199 .71925 .13946 .71828 .13805 Metetra
.664 .741 .907 r
.71828 .13805 .71925 .13946 .72619 .13693 .72523 .13551 Metetra
.664 .741 .907 r
.72523 .13551 .72619 .13693 .73316 .13439 .7322 .13297 Metetra
.664 .741 .907 r
.7322 .13297 .73316 .13439 .74014 .13184 .73918 .13042 Metetra
.664 .741 .907 r
.73918 .13042 .74014 .13184 .74713 .12929 .74618 .12786 Metetra
.664 .741 .907 r
.74618 .12786 .74713 .12929 .75415 .12673 .7532 .1253 Metetra
.664 .741 .907 r
.7532 .1253 .75415 .12673 .76118 .12416 .76023 .12273 Metetra
.664 .741 .907 r
.76023 .12273 .76118 .12416 .76822 .12159 .76728 .12015 Metetra
.664 .741 .907 r
.13732 .34868 .13854 .34982 .14415 .34778 .14293 .34663 Metetra
.664 .741 .907 r
.14293 .34663 .14415 .34778 .14977 .34572 .14855 .34458 Metetra
.664 .741 .907 r
.14855 .34458 .14977 .34572 .1554 .34367 .15418 .34252 Metetra
.664 .741 .907 r
.15418 .34252 .1554 .34367 .16104 .34161 .15982 .34045 Metetra
.664 .741 .907 r
.15982 .34045 .16104 .34161 .16669 .33954 .16548 .33839 Metetra
.664 .741 .907 r
.16548 .33839 .16669 .33954 .17236 .33747 .17115 .33631 Metetra
.664 .741 .907 r
.17115 .33631 .17236 .33747 .17804 .3354 .17683 .33424 Metetra
.664 .741 .907 r
.17683 .33424 .17804 .3354 .18373 .33332 .18253 .33216 Metetra
.664 .741 .907 r
.18253 .33216 .18373 .33332 .18944 .33123 .18823 .33007 Metetra
.664 .741 .907 r
.18823 .33007 .18944 .33123 .19515 .32914 .19395 .32798 Metetra
.664 .741 .907 r
.19395 .32798 .19515 .32914 .20088 .32705 .19968 .32588 Metetra
.664 .741 .907 r
.19968 .32588 .20088 .32705 .20663 .32495 .20543 .32378 Metetra
.664 .741 .907 r
.20543 .32378 .20663 .32495 .21238 .32285 .21119 .32168 Metetra
.664 .741 .907 r
.21119 .32168 .21238 .32285 .21751 .32728 .21696 .31957 Metetra
.569 .397 .609 r
.21696 .31957 .21751 .32728 .22393 .31863 .22274 .31745 Metetra
.664 .741 .907 r
.22274 .31745 .22393 .31863 .22972 .31652 .22854 .31533 Metetra
.664 .741 .907 r
.22854 .31533 .22972 .31652 .23553 .31439 .23435 .31321 Metetra
.664 .741 .907 r
.23435 .31321 .23553 .31439 .24135 .31227 .24017 .31108 Metetra
.664 .741 .907 r
.24017 .31108 .24135 .31227 .24718 .31014 .246 .30895 Metetra
.664 .741 .907 r
.246 .30895 .24718 .31014 .25303 .308 .25185 .30681 Metetra
.664 .741 .907 r
.25185 .30681 .25303 .308 .25889 .30586 .25771 .30467 Metetra
.664 .741 .907 r
.25771 .30467 .25889 .30586 .26476 .30372 .26359 .30252 Metetra
.664 .741 .907 r
.26359 .30252 .26476 .30372 .27065 .30157 .26948 .30037 Metetra
.664 .741 .907 r
.26948 .30037 .27065 .30157 .27655 .29941 .27538 .29821 Metetra
.664 .741 .907 r
.27538 .29821 .27655 .29941 .28246 .29725 .28129 .29605 Metetra
.664 .741 .907 r
.28129 .29605 .28246 .29725 .28838 .29509 .28722 .29388 Metetra
.664 .741 .907 r
.28722 .29388 .28838 .29509 .29432 .29292 .29316 .29171 Metetra
.664 .741 .907 r
.29316 .29171 .29432 .29292 .30027 .29075 .29911 .28953 Metetra
.664 .741 .907 r
.29911 .28953 .30027 .29075 .30624 .28857 .30508 .28735 Metetra
.664 .741 .907 r
.30508 .28735 .30624 .28857 .31222 .28638 .31106 .28516 Metetra
.664 .741 .907 r
.31106 .28516 .31222 .28638 .31821 .28419 .31706 .28297 Metetra
.664 .741 .907 r
.31706 .28297 .31821 .28419 .32422 .282 .32307 .28077 Metetra
.664 .741 .907 r
.32307 .28077 .32422 .282 .33024 .2798 .32909 .27857 Metetra
.664 .741 .907 r
.32909 .27857 .33024 .2798 .33627 .2776 .33513 .27636 Metetra
.664 .741 .907 r
.33513 .27636 .33627 .2776 .34232 .27539 .34118 .27415 Metetra
.664 .741 .907 r
.34118 .27415 .34232 .27539 .34838 .27317 .34724 .27194 Metetra
.664 .741 .907 r
.34724 .27194 .34838 .27317 .35445 .27095 .35332 .26971 Metetra
.664 .741 .907 r
.35332 .26971 .35445 .27095 .36054 .26873 .35941 .26749 Metetra
.664 .741 .907 r
.35941 .26749 .36054 .26873 .36664 .2665 .36551 .26526 Metetra
.664 .741 .907 r
.36551 .26526 .36664 .2665 .37276 .26427 .37163 .26302 Metetra
.664 .741 .907 r
.37163 .26302 .37276 .26427 .37889 .26203 .37777 .26078 Metetra
.664 .741 .907 r
.37777 .26078 .37889 .26203 .38504 .25978 .38391 .25853 Metetra
.664 .741 .907 r
.38391 .25853 .38504 .25978 .39119 .25753 .39007 .25628 Metetra
.664 .741 .907 r
.39007 .25628 .39119 .25753 .39737 .25528 .39625 .25402 Metetra
.664 .741 .907 r
.39625 .25402 .39737 .25528 .40356 .25302 .40244 .25175 Metetra
.664 .741 .907 r
.40244 .25175 .40356 .25302 .40976 .25075 .40864 .24949 Metetra
.664 .741 .907 r
.40864 .24949 .40976 .25075 .41597 .24848 .41486 .24721 Metetra
.664 .741 .907 r
.41486 .24721 .41597 .24848 .4222 .24621 .4211 .24493 Metetra
.664 .741 .907 r
.4211 .24493 .4222 .24621 .42845 .24392 .42734 .24265 Metetra
.664 .741 .907 r
.42734 .24265 .42845 .24392 .43471 .24164 .4336 .24036 Metetra
.664 .741 .907 r
.4336 .24036 .43471 .24164 .44098 .23935 .43988 .23807 Metetra
.664 .741 .907 r
.43988 .23807 .44098 .23935 .44727 .23705 .44617 .23577 Metetra
.664 .741 .907 r
.44617 .23577 .44727 .23705 .45357 .23475 .45248 .23346 Metetra
.664 .741 .907 r
.45248 .23346 .45357 .23475 .45989 .23244 .4588 .23115 Metetra
.664 .741 .907 r
.4588 .23115 .45989 .23244 .46622 .23013 .46513 .22883 Metetra
.967 .655 .373 r
.46513 .22883 .46622 .23013 .47257 .22781 .47004 .30868 Metetra
.655 .394 .514 r
.47004 .30868 .47257 .22781 .47786 .29652 .47475 .42511 Metetra
.244 .073 .44 r
.47475 .42511 .47786 .29652 .48531 .22316 .48423 .22185 Metetra
.664 .741 .907 r
.48423 .22185 .48531 .22316 .4917 .22082 .49062 .21952 Metetra
.664 .741 .907 r
.49062 .21952 .4917 .22082 .4981 .21848 .49703 .21717 Metetra
.664 .741 .907 r
.49703 .21717 .4981 .21848 .50453 .21613 .50346 .21482 Metetra
.664 .741 .907 r
.50346 .21482 .50453 .21613 .51096 .21378 .5099 .21247 Metetra
.664 .741 .907 r
.5099 .21247 .51096 .21378 .51741 .21143 .51635 .21011 Metetra
.664 .741 .907 r
.51635 .21011 .51741 .21143 .52388 .20906 .52282 .20774 Metetra
.664 .741 .907 r
.52282 .20774 .52388 .20906 .53036 .2067 .52931 .20537 Metetra
.664 .741 .907 r
.52931 .20537 .53036 .2067 .53686 .20432 .53581 .203 Metetra
.664 .741 .907 r
.53581 .203 .53686 .20432 .54337 .20194 .54232 .20061 Metetra
.664 .741 .907 r
.54232 .20061 .54337 .20194 .5499 .19956 .54885 .19823 Metetra
.664 .741 .907 r
.54885 .19823 .5499 .19956 .55645 .19717 .5554 .19583 Metetra
.664 .741 .907 r
.5554 .19583 .55645 .19717 .56301 .19477 .56196 .19343 Metetra
.664 .741 .907 r
.56196 .19343 .56301 .19477 .56958 .19237 .56854 .19103 Metetra
.664 .741 .907 r
.56854 .19103 .56958 .19237 .57617 .18996 .57513 .18862 Metetra
.664 .741 .907 r
.57513 .18862 .57617 .18996 .58278 .18755 .58174 .1862 Metetra
.664 .741 .907 r
.58174 .1862 .58278 .18755 .5894 .18513 .58837 .18378 Metetra
.664 .741 .907 r
.58837 .18378 .5894 .18513 .59604 .18271 .59501 .18135 Metetra
.664 .741 .907 r
.59501 .18135 .59604 .18271 .60269 .18028 .60167 .17892 Metetra
.664 .741 .907 r
.60167 .17892 .60269 .18028 .60936 .17784 .60834 .17648 Metetra
.664 .741 .907 r
.60834 .17648 .60936 .17784 .61604 .1754 .61503 .17403 Metetra
.664 .741 .907 r
.61503 .17403 .61604 .1754 .62275 .17295 .62173 .17158 Metetra
.664 .741 .907 r
.62173 .17158 .62275 .17295 .62946 .1705 .62845 .16912 Metetra
.664 .741 .907 r
.62845 .16912 .62946 .1705 .6362 .16804 .63519 .16666 Metetra
.664 .741 .907 r
.63519 .16666 .6362 .16804 .64295 .16557 .64194 .16419 Metetra
.664 .741 .907 r
.64194 .16419 .64295 .16557 .64971 .1631 .64871 .16172 Metetra
.664 .741 .907 r
.64871 .16172 .64971 .1631 .6565 .16062 .6555 .15924 Metetra
.664 .741 .907 r
.6555 .15924 .6565 .16062 .6633 .15814 .6623 .15675 Metetra
.664 .741 .907 r
.6623 .15675 .6633 .15814 .67011 .15565 .66912 .15426 Metetra
.664 .741 .907 r
.66912 .15426 .67011 .15565 .67694 .15315 .67596 .15176 Metetra
.664 .741 .907 r
.67596 .15176 .67694 .15315 .68379 .15065 .68281 .14925 Metetra
.664 .741 .907 r
.68281 .14925 .68379 .15065 .69066 .14814 .68968 .14674 Metetra
.664 .741 .907 r
.68968 .14674 .69066 .14814 .69754 .14563 .69656 .14422 Metetra
.664 .741 .907 r
.69656 .14422 .69754 .14563 .70444 .14311 .70346 .1417 Metetra
.664 .741 .907 r
.70346 .1417 .70444 .14311 .71135 .14058 .71038 .13917 Metetra
.664 .741 .907 r
.71038 .13917 .71135 .14058 .71828 .13805 .71732 .13664 Metetra
.664 .741 .907 r
.71732 .13664 .71828 .13805 .72523 .13551 .72427 .13409 Metetra
.664 .741 .907 r
.72427 .13409 .72523 .13551 .7322 .13297 .73124 .13155 Metetra
.664 .741 .907 r
.73124 .13155 .7322 .13297 .73918 .13042 .73823 .12899 Metetra
.664 .741 .907 r
.73823 .12899 .73918 .13042 .74618 .12786 .74523 .12643 Metetra
.664 .741 .907 r
.74523 .12643 .74618 .12786 .7532 .1253 .75225 .12386 Metetra
.664 .741 .907 r
.75225 .12386 .7532 .1253 .76023 .12273 .75929 .12129 Metetra
.664 .741 .907 r
.75929 .12129 .76023 .12273 .76728 .12015 .76634 .11871 Metetra
.664 .741 .907 r
.1361 .34754 .13732 .34868 .14293 .34663 .14171 .34549 Metetra
.664 .741 .907 r
.14171 .34549 .14293 .34663 .14855 .34458 .14733 .34343 Metetra
.664 .741 .907 r
.14733 .34343 .14855 .34458 .15418 .34252 .15296 .34137 Metetra
.664 .741 .907 r
.15296 .34137 .15418 .34252 .15982 .34045 .15861 .3393 Metetra
.664 .741 .907 r
.15861 .3393 .15982 .34045 .16548 .33839 .16427 .33723 Metetra
.664 .741 .907 r
.16427 .33723 .16548 .33839 .17115 .33631 .16994 .33516 Metetra
.664 .741 .907 r
.16994 .33516 .17115 .33631 .17683 .33424 .17562 .33308 Metetra
.664 .741 .907 r
.17562 .33308 .17683 .33424 .18253 .33216 .18132 .33099 Metetra
.664 .741 .907 r
.18132 .33099 .18253 .33216 .18823 .33007 .18703 .3289 Metetra
.664 .741 .907 r
.18703 .3289 .18823 .33007 .19395 .32798 .19275 .32681 Metetra
.664 .741 .907 r
.19275 .32681 .19395 .32798 .19968 .32588 .19848 .32471 Metetra
.664 .741 .907 r
.19848 .32471 .19968 .32588 .20543 .32378 .20423 .32261 Metetra
.664 .741 .907 r
.20423 .32261 .20543 .32378 .21119 .32168 .20999 .3205 Metetra
.664 .741 .907 r
.20999 .3205 .21119 .32168 .21696 .31957 .21576 .31839 Metetra
.664 .741 .907 r
.21576 .31839 .21696 .31957 .22274 .31745 .22155 .31627 Metetra
.664 .741 .907 r
.22155 .31627 .22274 .31745 .22854 .31533 .22735 .31415 Metetra
.664 .741 .907 r
.22735 .31415 .22854 .31533 .23435 .31321 .23316 .31202 Metetra
.664 .741 .907 r
.23316 .31202 .23435 .31321 .24017 .31108 .23898 .30989 Metetra
.664 .741 .907 r
.23898 .30989 .24017 .31108 .246 .30895 .24482 .30776 Metetra
.664 .741 .907 r
.24482 .30776 .246 .30895 .25185 .30681 .25067 .30561 Metetra
.664 .741 .907 r
.25067 .30561 .25185 .30681 .25771 .30467 .25654 .30347 Metetra
.664 .741 .907 r
.25654 .30347 .25771 .30467 .26359 .30252 .26241 .30132 Metetra
.664 .741 .907 r
.26241 .30132 .26359 .30252 .26948 .30037 .2683 .29916 Metetra
.664 .741 .907 r
.2683 .29916 .26948 .30037 .27538 .29821 .27421 .297 Metetra
.664 .741 .907 r
.27421 .297 .27538 .29821 .28129 .29605 .28012 .29484 Metetra
.664 .741 .907 r
.28012 .29484 .28129 .29605 .28722 .29388 .28605 .29267 Metetra
.664 .741 .907 r
.28605 .29267 .28722 .29388 .29316 .29171 .292 .29049 Metetra
.664 .741 .907 r
.292 .29049 .29316 .29171 .29911 .28953 .29795 .28831 Metetra
.664 .741 .907 r
.29795 .28831 .29911 .28953 .30508 .28735 .30392 .28613 Metetra
.664 .741 .907 r
.30392 .28613 .30508 .28735 .31106 .28516 .30991 .28394 Metetra
.664 .741 .907 r
.30991 .28394 .31106 .28516 .31706 .28297 .31591 .28175 Metetra
.664 .741 .907 r
.31591 .28175 .31706 .28297 .32307 .28077 .32192 .27955 Metetra
.664 .741 .907 r
.32192 .27955 .32307 .28077 .32909 .27857 .32794 .27734 Metetra
.664 .741 .907 r
.32794 .27734 .32909 .27857 .33513 .27636 .33398 .27513 Metetra
.664 .741 .907 r
.33398 .27513 .33513 .27636 .34118 .27415 .34003 .27292 Metetra
.664 .741 .907 r
.34003 .27292 .34118 .27415 .34724 .27194 .3461 .2707 Metetra
.664 .741 .907 r
.3461 .2707 .34724 .27194 .35332 .26971 .35218 .26847 Metetra
.664 .741 .907 r
.35218 .26847 .35332 .26971 .35941 .26749 .35827 .26624 Metetra
.664 .741 .907 r
.35827 .26624 .35941 .26749 .36551 .26526 .36438 .26401 Metetra
.664 .741 .907 r
.36438 .26401 .36551 .26526 .37163 .26302 .3705 .26177 Metetra
.664 .741 .907 r
.3705 .26177 .37163 .26302 .37777 .26078 .37664 .25952 Metetra
.664 .741 .907 r
.37664 .25952 .37777 .26078 .38391 .25853 .38279 .25727 Metetra
.664 .741 .907 r
.38279 .25727 .38391 .25853 .39007 .25628 .38895 .25502 Metetra
.664 .741 .907 r
.38895 .25502 .39007 .25628 .39625 .25402 .39513 .25276 Metetra
.664 .741 .907 r
.39513 .25276 .39625 .25402 .40244 .25175 .40132 .25049 Metetra
.664 .741 .907 r
.40132 .25049 .40244 .25175 .40864 .24949 .40753 .24822 Metetra
.664 .741 .907 r
.40753 .24822 .40864 .24949 .41486 .24721 .41375 .24594 Metetra
.664 .741 .907 r
.41375 .24594 .41486 .24721 .4211 .24493 .41999 .24366 Metetra
.664 .741 .907 r
.41999 .24366 .4211 .24493 .42734 .24265 .42624 .24137 Metetra
.664 .741 .907 r
.42624 .24137 .42734 .24265 .4336 .24036 .4325 .23908 Metetra
.664 .741 .907 r
.4325 .23908 .4336 .24036 .43988 .23807 .43878 .23678 Metetra
.664 .741 .907 r
.43878 .23678 .43988 .23807 .44617 .23577 .44507 .23448 Metetra
.664 .741 .907 r
.44507 .23448 .44617 .23577 .45248 .23346 .45138 .23217 Metetra
.664 .741 .907 r
.45138 .23217 .45248 .23346 .4588 .23115 .45771 .22986 Metetra
.664 .741 .907 r
.45771 .22986 .4588 .23115 .46513 .22883 .46404 .22754 Metetra
.969 .672 .408 r
.46404 .22754 .46513 .22883 .47004 .30868 .46737 .39462 Metetra
.405 .194 .476 r
.46737 .39462 .47004 .30868 .47475 .42511 .47511 .32731 Metetra
.642 .394 .528 r
.47511 .32731 .47475 .42511 .48423 .22185 .48315 .22055 Metetra
.664 .741 .907 r
.48315 .22055 .48423 .22185 .49062 .21952 .48954 .21821 Metetra
.664 .741 .907 r
.48954 .21821 .49062 .21952 .49703 .21717 .49596 .21586 Metetra
.664 .741 .907 r
.49596 .21586 .49703 .21717 .50346 .21482 .50238 .21351 Metetra
.664 .741 .907 r
.50238 .21351 .50346 .21482 .5099 .21247 .50883 .21115 Metetra
.664 .741 .907 r
.50883 .21115 .5099 .21247 .51635 .21011 .51528 .20879 Metetra
.664 .741 .907 r
.51528 .20879 .51635 .21011 .52282 .20774 .52176 .20642 Metetra
.664 .741 .907 r
.52176 .20642 .52282 .20774 .52931 .20537 .52825 .20405 Metetra
.664 .741 .907 r
.52825 .20405 .52931 .20537 .53581 .203 .53475 .20167 Metetra
.664 .741 .907 r
.53475 .20167 .53581 .203 .54232 .20061 .54127 .19928 Metetra
.664 .741 .907 r
.54127 .19928 .54232 .20061 .54885 .19823 .5478 .19689 Metetra
.664 .741 .907 r
.5478 .19689 .54885 .19823 .5554 .19583 .55435 .1945 Metetra
.664 .741 .907 r
.55435 .1945 .5554 .19583 .56196 .19343 .56092 .19209 Metetra
.664 .741 .907 r
.56092 .19209 .56196 .19343 .56854 .19103 .5675 .18968 Metetra
.664 .741 .907 r
.5675 .18968 .56854 .19103 .57513 .18862 .5741 .18727 Metetra
.664 .741 .907 r
.5741 .18727 .57513 .18862 .58174 .1862 .58071 .18485 Metetra
.664 .741 .907 r
.58071 .18485 .58174 .1862 .58837 .18378 .58734 .18243 Metetra
.664 .741 .907 r
.58734 .18243 .58837 .18378 .59501 .18135 .59398 .17999 Metetra
.664 .741 .907 r
.59398 .17999 .59501 .18135 .60167 .17892 .60064 .17756 Metetra
.664 .741 .907 r
.60064 .17756 .60167 .17892 .60834 .17648 .60732 .17512 Metetra
.664 .741 .907 r
.60732 .17512 .60834 .17648 .61503 .17403 .61401 .17267 Metetra
.664 .741 .907 r
.61401 .17267 .61503 .17403 .62173 .17158 .62072 .17021 Metetra
.664 .741 .907 r
.62072 .17021 .62173 .17158 .62845 .16912 .62744 .16775 Metetra
.664 .741 .907 r
.62744 .16775 .62845 .16912 .63519 .16666 .63418 .16529 Metetra
.664 .741 .907 r
.63418 .16529 .63519 .16666 .64194 .16419 .64094 .16281 Metetra
.664 .741 .907 r
.64094 .16281 .64194 .16419 .64871 .16172 .64771 .16033 Metetra
.664 .741 .907 r
.64771 .16033 .64871 .16172 .6555 .15924 .6545 .15785 Metetra
.664 .741 .907 r
.6545 .15785 .6555 .15924 .6623 .15675 .66131 .15536 Metetra
.664 .741 .907 r
.66131 .15536 .6623 .15675 .66912 .15426 .66813 .15286 Metetra
.664 .741 .907 r
.66813 .15286 .66912 .15426 .67596 .15176 .67497 .15036 Metetra
.664 .741 .907 r
.67497 .15036 .67596 .15176 .68281 .14925 .68182 .14785 Metetra
.664 .741 .907 r
.68182 .14785 .68281 .14925 .68968 .14674 .68869 .14534 Metetra
.664 .741 .907 r
.68869 .14534 .68968 .14674 .69656 .14422 .69558 .14282 Metetra
.664 .741 .907 r
.69558 .14282 .69656 .14422 .70346 .1417 .70249 .14029 Metetra
.664 .741 .907 r
.70249 .14029 .70346 .1417 .71038 .13917 .70941 .13776 Metetra
.664 .741 .907 r
.70941 .13776 .71038 .13917 .71732 .13664 .71635 .13522 Metetra
.664 .741 .907 r
.71635 .13522 .71732 .13664 .72427 .13409 .7233 .13267 Metetra
.664 .741 .907 r
.7233 .13267 .72427 .13409 .73124 .13155 .73028 .13012 Metetra
.664 .741 .907 r
.73028 .13012 .73124 .13155 .73823 .12899 .73727 .12756 Metetra
.664 .741 .907 r
.73727 .12756 .73823 .12899 .74523 .12643 .74428 .125 Metetra
.664 .741 .907 r
.74428 .125 .74523 .12643 .75225 .12386 .7513 .12243 Metetra
.664 .741 .907 r
.7513 .12243 .75225 .12386 .75929 .12129 .75834 .11985 Metetra
.664 .741 .907 r
.75834 .11985 .75929 .12129 .76634 .11871 .7654 .11727 Metetra
.664 .741 .907 r
.13487 .34639 .1361 .34754 .14171 .34549 .14048 .34434 Metetra
.664 .741 .907 r
.14048 .34434 .14171 .34549 .14733 .34343 .14611 .34228 Metetra
.664 .741 .907 r
.14611 .34228 .14733 .34343 .15296 .34137 .15174 .34022 Metetra
.664 .741 .907 r
.15174 .34022 .15296 .34137 .15861 .3393 .15739 .33815 Metetra
.664 .741 .907 r
.15739 .33815 .15861 .3393 .16427 .33723 .16305 .33607 Metetra
.664 .741 .907 r
.16305 .33607 .16427 .33723 .16994 .33516 .16873 .334 Metetra
.664 .741 .907 r
.16873 .334 .16994 .33516 .17562 .33308 .17441 .33191 Metetra
.664 .741 .907 r
.17441 .33191 .17562 .33308 .18132 .33099 .18011 .32983 Metetra
.664 .741 .907 r
.18011 .32983 .18132 .33099 .18703 .3289 .18582 .32774 Metetra
.664 .741 .907 r
.18582 .32774 .18703 .3289 .19275 .32681 .19155 .32564 Metetra
.664 .741 .907 r
.19155 .32564 .19275 .32681 .19848 .32471 .19728 .32354 Metetra
.664 .741 .907 r
.19728 .32354 .19848 .32471 .20423 .32261 .20303 .32143 Metetra
.664 .741 .907 r
.20303 .32143 .20423 .32261 .20999 .3205 .20879 .31932 Metetra
.664 .741 .907 r
.20879 .31932 .20999 .3205 .21576 .31839 .21457 .31721 Metetra
.664 .741 .907 r
.21457 .31721 .21576 .31839 .22155 .31627 .22036 .31509 Metetra
.664 .741 .907 r
.22036 .31509 .22155 .31627 .22735 .31415 .22616 .31296 Metetra
.664 .741 .907 r
.22616 .31296 .22735 .31415 .23316 .31202 .23197 .31083 Metetra
.664 .741 .907 r
.23197 .31083 .23316 .31202 .23898 .30989 .2378 .3087 Metetra
.664 .741 .907 r
.2378 .3087 .23898 .30989 .24482 .30776 .24364 .30656 Metetra
.664 .741 .907 r
.24364 .30656 .24482 .30776 .25067 .30561 .24949 .30442 Metetra
.664 .741 .907 r
.24949 .30442 .25067 .30561 .25654 .30347 .25536 .30227 Metetra
.664 .741 .907 r
.25536 .30227 .25654 .30347 .26241 .30132 .26124 .30012 Metetra
.664 .741 .907 r
.26124 .30012 .26241 .30132 .2683 .29916 .26713 .29796 Metetra
.664 .741 .907 r
.26713 .29796 .2683 .29916 .27421 .297 .27304 .2958 Metetra
.664 .741 .907 r
.27304 .2958 .27421 .297 .28012 .29484 .27895 .29363 Metetra
.664 .741 .907 r
.27895 .29363 .28012 .29484 .28605 .29267 .28489 .29146 Metetra
.664 .741 .907 r
.28489 .29146 .28605 .29267 .292 .29049 .29083 .28928 Metetra
.664 .741 .907 r
.29083 .28928 .292 .29049 .29795 .28831 .29679 .2871 Metetra
.664 .741 .907 r
.29679 .2871 .29795 .28831 .30392 .28613 .30276 .28491 Metetra
.664 .741 .907 r
.30276 .28491 .30392 .28613 .30991 .28394 .30875 .28272 Metetra
.664 .741 .907 r
.30875 .28272 .30991 .28394 .31591 .28175 .31475 .28052 Metetra
.664 .741 .907 r
.31475 .28052 .31591 .28175 .32192 .27955 .32076 .27832 Metetra
.664 .741 .907 r
.32076 .27832 .32192 .27955 .32794 .27734 .32679 .27611 Metetra
.664 .741 .907 r
.32679 .27611 .32794 .27734 .33398 .27513 .33283 .2739 Metetra
.664 .741 .907 r
.33283 .2739 .33398 .27513 .34003 .27292 .33889 .27168 Metetra
.664 .741 .907 r
.33889 .27168 .34003 .27292 .3461 .2707 .34496 .26946 Metetra
.664 .741 .907 r
.34496 .26946 .3461 .2707 .35218 .26847 .35104 .26723 Metetra
.664 .741 .907 r
.35104 .26723 .35218 .26847 .35827 .26624 .35714 .265 Metetra
.664 .741 .907 r
.35714 .265 .35827 .26624 .36438 .26401 .36325 .26276 Metetra
.664 .741 .907 r
.36325 .26276 .36438 .26401 .3705 .26177 .36937 .26052 Metetra
.664 .741 .907 r
.36937 .26052 .3705 .26177 .37664 .25952 .37551 .25827 Metetra
.664 .741 .907 r
.37551 .25827 .37664 .25952 .38279 .25727 .38166 .25602 Metetra
.664 .741 .907 r
.38166 .25602 .38279 .25727 .38895 .25502 .38783 .25376 Metetra
.664 .741 .907 r
.38783 .25376 .38895 .25502 .39513 .25276 .39401 .25149 Metetra
.664 .741 .907 r
.39401 .25149 .39513 .25276 .40132 .25049 .40021 .24922 Metetra
.664 .741 .907 r
.40021 .24922 .40132 .25049 .40753 .24822 .40641 .24695 Metetra
.664 .741 .907 r
.40641 .24695 .40753 .24822 .41375 .24594 .41264 .24467 Metetra
.664 .741 .907 r
.41264 .24467 .41375 .24594 .41999 .24366 .41888 .24239 Metetra
.664 .741 .907 r
.41888 .24239 .41999 .24366 .42624 .24137 .42513 .2401 Metetra
.664 .741 .907 r
.42513 .2401 .42624 .24137 .4325 .23908 .4314 .2378 Metetra
.664 .741 .907 r
.4314 .2378 .4325 .23908 .43878 .23678 .43768 .2355 Metetra
.664 .741 .907 r
.43768 .2355 .43878 .23678 .44507 .23448 .44398 .23319 Metetra
.664 .741 .907 r
.44398 .23319 .44507 .23448 .45138 .23217 .45029 .23088 Metetra
.664 .741 .907 r
.45029 .23088 .45138 .23217 .45771 .22986 .45661 .22857 Metetra
.664 .741 .907 r
.45661 .22857 .45771 .22986 .46404 .22754 .46295 .22624 Metetra
.968 .669 .402 r
.46295 .22624 .46404 .22754 .46737 .39462 .46675 .36445 Metetra
.82 .55 .53 r
.46675 .36445 .46737 .39462 .47511 .32731 .47568 .22158 Metetra
.525 .3 .516 r
.47568 .22158 .47511 .32731 .48315 .22055 .48207 .21925 Metetra
.664 .741 .907 r
.48207 .21925 .48315 .22055 .48954 .21821 .48847 .2169 Metetra
.664 .741 .907 r
.48847 .2169 .48954 .21821 .49596 .21586 .49488 .21455 Metetra
.664 .741 .907 r
.49488 .21455 .49596 .21586 .50238 .21351 .50131 .2122 Metetra
.664 .741 .907 r
.50131 .2122 .50238 .21351 .50883 .21115 .50776 .20984 Metetra
.664 .741 .907 r
.50776 .20984 .50883 .21115 .51528 .20879 .51422 .20747 Metetra
.664 .741 .907 r
.51422 .20747 .51528 .20879 .52176 .20642 .52069 .2051 Metetra
.664 .741 .907 r
.52069 .2051 .52176 .20642 .52825 .20405 .52718 .20272 Metetra
.664 .741 .907 r
.52718 .20272 .52825 .20405 .53475 .20167 .53369 .20034 Metetra
.664 .741 .907 r
.53369 .20034 .53475 .20167 .54127 .19928 .54021 .19795 Metetra
.664 .741 .907 r
.54021 .19795 .54127 .19928 .5478 .19689 .54675 .19556 Metetra
.664 .741 .907 r
.54675 .19556 .5478 .19689 .55435 .1945 .5533 .19316 Metetra
.664 .741 .907 r
.5533 .19316 .55435 .1945 .56092 .19209 .55987 .19075 Metetra
.664 .741 .907 r
.55987 .19075 .56092 .19209 .5675 .18968 .56646 .18834 Metetra
.664 .741 .907 r
.56646 .18834 .5675 .18968 .5741 .18727 .57306 .18592 Metetra
.664 .741 .907 r
.57306 .18592 .5741 .18727 .58071 .18485 .57967 .1835 Metetra
.664 .741 .907 r
.57967 .1835 .58071 .18485 .58734 .18243 .5863 .18107 Metetra
.664 .741 .907 r
.5863 .18107 .58734 .18243 .59398 .17999 .59295 .17864 Metetra
.664 .741 .907 r
.59295 .17864 .59398 .17999 .60064 .17756 .59961 .1762 Metetra
.664 .741 .907 r
.59961 .1762 .60064 .17756 .60732 .17512 .60629 .17375 Metetra
.664 .741 .907 r
.60629 .17375 .60732 .17512 .61401 .17267 .61299 .1713 Metetra
.664 .741 .907 r
.61299 .1713 .61401 .17267 .62072 .17021 .6197 .16884 Metetra
.664 .741 .907 r
.6197 .16884 .62072 .17021 .62744 .16775 .62643 .16638 Metetra
.664 .741 .907 r
.62643 .16638 .62744 .16775 .63418 .16529 .63317 .16391 Metetra
.664 .741 .907 r
.63317 .16391 .63418 .16529 .64094 .16281 .63993 .16143 Metetra
.664 .741 .907 r
.63993 .16143 .64094 .16281 .64771 .16033 .64671 .15895 Metetra
.664 .741 .907 r
.64671 .15895 .64771 .16033 .6545 .15785 .6535 .15646 Metetra
.664 .741 .907 r
.6535 .15646 .6545 .15785 .66131 .15536 .66031 .15397 Metetra
.664 .741 .907 r
.66031 .15397 .66131 .15536 .66813 .15286 .66713 .15147 Metetra
.664 .741 .907 r
.66713 .15147 .66813 .15286 .67497 .15036 .67398 .14896 Metetra
.664 .741 .907 r
.67398 .14896 .67497 .15036 .68182 .14785 .68084 .14645 Metetra
.664 .741 .907 r
.68084 .14645 .68182 .14785 .68869 .14534 .68771 .14393 Metetra
.664 .741 .907 r
.68771 .14393 .68869 .14534 .69558 .14282 .6946 .14141 Metetra
.664 .741 .907 r
.6946 .14141 .69558 .14282 .70249 .14029 .70151 .13888 Metetra
.664 .741 .907 r
.70151 .13888 .70249 .14029 .70941 .13776 .70844 .13634 Metetra
.664 .741 .907 r
.70844 .13634 .70941 .13776 .71635 .13522 .71538 .1338 Metetra
.664 .741 .907 r
.71538 .1338 .71635 .13522 .7233 .13267 .72234 .13125 Metetra
.664 .741 .907 r
.72234 .13125 .7233 .13267 .73028 .13012 .72932 .1287 Metetra
.664 .741 .907 r
.72932 .1287 .73028 .13012 .73727 .12756 .73631 .12614 Metetra
.664 .741 .907 r
.73631 .12614 .73727 .12756 .74428 .125 .74332 .12357 Metetra
.664 .741 .907 r
.74332 .12357 .74428 .125 .7513 .12243 .75035 .12099 Metetra
.664 .741 .907 r
.75035 .12099 .7513 .12243 .75834 .11985 .75739 .11841 Metetra
.664 .741 .907 r
.75739 .11841 .75834 .11985 .7654 .11727 .76446 .11583 Metetra
.664 .741 .907 r
.13365 .34525 .13487 .34639 .14048 .34434 .13926 .34319 Metetra
.664 .741 .907 r
.13926 .34319 .14048 .34434 .14611 .34228 .14488 .34113 Metetra
.664 .741 .907 r
.14488 .34113 .14611 .34228 .15174 .34022 .15052 .33906 Metetra
.664 .741 .907 r
.15052 .33906 .15174 .34022 .15739 .33815 .15617 .33699 Metetra
.664 .741 .907 r
.15617 .33699 .15739 .33815 .16305 .33607 .16184 .33492 Metetra
.664 .741 .907 r
.16184 .33492 .16305 .33607 .16873 .334 .16751 .33284 Metetra
.664 .741 .907 r
.16751 .33284 .16873 .334 .17441 .33191 .1732 .33075 Metetra
.664 .741 .907 r
.1732 .33075 .17441 .33191 .18011 .32983 .1789 .32866 Metetra
.664 .741 .907 r
.1789 .32866 .18011 .32983 .18582 .32774 .18461 .32657 Metetra
.664 .741 .907 r
.18461 .32657 .18582 .32774 .19155 .32564 .19034 .32447 Metetra
.664 .741 .907 r
.19034 .32447 .19155 .32564 .19728 .32354 .19608 .32236 Metetra
.664 .741 .907 r
.19608 .32236 .19728 .32354 .20303 .32143 .20183 .32026 Metetra
.664 .741 .907 r
.20183 .32026 .20303 .32143 .20879 .31932 .2076 .31814 Metetra
.664 .741 .907 r
.2076 .31814 .20879 .31932 .21457 .31721 .21337 .31603 Metetra
.664 .741 .907 r
.21337 .31603 .21457 .31721 .22036 .31509 .21916 .3139 Metetra
.664 .741 .907 r
.21916 .3139 .22036 .31509 .22616 .31296 .22497 .31178 Metetra
.664 .741 .907 r
.22497 .31178 .22616 .31296 .23197 .31083 .23078 .30965 Metetra
.664 .741 .907 r
.23078 .30965 .23197 .31083 .2378 .3087 .23661 .30751 Metetra
.664 .741 .907 r
.23661 .30751 .2378 .3087 .24364 .30656 .24245 .30537 Metetra
.664 .741 .907 r
.24245 .30537 .24364 .30656 .24949 .30442 .24831 .30322 Metetra
.664 .741 .907 r
.24831 .30322 .24949 .30442 .25536 .30227 .25418 .30107 Metetra
.514 .017 0 r
.25418 .30107 .25536 .30227 .26124 .30012 .25942 .30648 Metetra
.202 0 .264 r
.25942 .30648 .26124 .30012 .26713 .29796 .26595 .29675 Metetra
.664 .741 .907 r
.26595 .29675 .26713 .29796 .27304 .2958 .27186 .29459 Metetra
.664 .741 .907 r
.27186 .29459 .27304 .2958 .27895 .29363 .27778 .29242 Metetra
.664 .741 .907 r
.27778 .29242 .27895 .29363 .28489 .29146 .28372 .29024 Metetra
.664 .741 .907 r
.28372 .29024 .28489 .29146 .29083 .28928 .28967 .28806 Metetra
.664 .741 .907 r
.28967 .28806 .29083 .28928 .29679 .2871 .29563 .28588 Metetra
.664 .741 .907 r
.29563 .28588 .29679 .2871 .30276 .28491 .3016 .28369 Metetra
.664 .741 .907 r
.3016 .28369 .30276 .28491 .30875 .28272 .30759 .28149 Metetra
.664 .741 .907 r
.30759 .28149 .30875 .28272 .31475 .28052 .3136 .27929 Metetra
.664 .741 .907 r
.3136 .27929 .31475 .28052 .32076 .27832 .31961 .27709 Metetra
.664 .741 .907 r
.31961 .27709 .32076 .27832 .32679 .27611 .32564 .27488 Metetra
.664 .741 .907 r
.32564 .27488 .32679 .27611 .33283 .2739 .33168 .27266 Metetra
.664 .741 .907 r
.33168 .27266 .33283 .2739 .33889 .27168 .33774 .27044 Metetra
.664 .741 .907 r
.33774 .27044 .33889 .27168 .34496 .26946 .34381 .26822 Metetra
.664 .741 .907 r
.34381 .26822 .34496 .26946 .35104 .26723 .3499 .26599 Metetra
.664 .741 .907 r
.3499 .26599 .35104 .26723 .35714 .265 .356 .26375 Metetra
.664 .741 .907 r
.356 .26375 .35714 .265 .36325 .26276 .36211 .26151 Metetra
.664 .741 .907 r
.36211 .26151 .36325 .26276 .36937 .26052 .36824 .25926 Metetra
.664 .741 .907 r
.36824 .25926 .36937 .26052 .37551 .25827 .37438 .25701 Metetra
.664 .741 .907 r
.37438 .25701 .37551 .25827 .38166 .25602 .38053 .25476 Metetra
.664 .741 .907 r
.38053 .25476 .38166 .25602 .38783 .25376 .3867 .25249 Metetra
.664 .741 .907 r
.3867 .25249 .38783 .25376 .39401 .25149 .39289 .25023 Metetra
.664 .741 .907 r
.39289 .25023 .39401 .25149 .40021 .24922 .39909 .24796 Metetra
.664 .741 .907 r
.39909 .24796 .40021 .24922 .40641 .24695 .4053 .24568 Metetra
.664 .741 .907 r
.4053 .24568 .40641 .24695 .41264 .24467 .41152 .2434 Metetra
.664 .741 .907 r
.41152 .2434 .41264 .24467 .41888 .24239 .41777 .24111 Metetra
.664 .741 .907 r
.41777 .24111 .41888 .24239 .42513 .2401 .42402 .23882 Metetra
.664 .741 .907 r
.42402 .23882 .42513 .2401 .4314 .2378 .43029 .23652 Metetra
.664 .741 .907 r
.43029 .23652 .4314 .2378 .43768 .2355 .43658 .23421 Metetra
.664 .741 .907 r
.43658 .23421 .43768 .2355 .44398 .23319 .44288 .23191 Metetra
.664 .741 .907 r
.44288 .23191 .44398 .23319 .45029 .23088 .44919 .22959 Metetra
.664 .741 .907 r
.44919 .22959 .45029 .23088 .45661 .22857 .45552 .22727 Metetra
.664 .741 .907 r
.45552 .22727 .45661 .22857 .46295 .22624 .46186 .22495 Metetra
.664 .741 .907 r
.46186 .22495 .46295 .22624 .46675 .36445 .46822 .22262 Metetra
.507 .284 .511 r
.46822 .22262 .46675 .36445 .47568 .22158 .4743 .23793 Metetra
.319 .096 .41 r
.4743 .23793 .47568 .22158 .48207 .21925 .48098 .21794 Metetra
.664 .741 .907 r
.48098 .21794 .48207 .21925 .48847 .2169 .48739 .21559 Metetra
.664 .741 .907 r
.48739 .21559 .48847 .2169 .49488 .21455 .4938 .21324 Metetra
.664 .741 .907 r
.4938 .21324 .49488 .21455 .50131 .2122 .50024 .21088 Metetra
.664 .741 .907 r
.50024 .21088 .50131 .2122 .50776 .20984 .50669 .20852 Metetra
.664 .741 .907 r
.50669 .20852 .50776 .20984 .51422 .20747 .51315 .20615 Metetra
.664 .741 .907 r
.51315 .20615 .51422 .20747 .52069 .2051 .51963 .20377 Metetra
.664 .741 .907 r
.51963 .20377 .52069 .2051 .52718 .20272 .52612 .20139 Metetra
.664 .741 .907 r
.52612 .20139 .52718 .20272 .53369 .20034 .53263 .19901 Metetra
.664 .741 .907 r
.53263 .19901 .53369 .20034 .54021 .19795 .53916 .19662 Metetra
.664 .741 .907 r
.53916 .19662 .54021 .19795 .54675 .19556 .5457 .19422 Metetra
.664 .741 .907 r
.5457 .19422 .54675 .19556 .5533 .19316 .55225 .19181 Metetra
.664 .741 .907 r
.55225 .19181 .5533 .19316 .55987 .19075 .55883 .18941 Metetra
.664 .741 .907 r
.55883 .18941 .55987 .19075 .56646 .18834 .56541 .18699 Metetra
.664 .741 .907 r
.56541 .18699 .56646 .18834 .57306 .18592 .57202 .18457 Metetra
.664 .741 .907 r
.57202 .18457 .57306 .18592 .57967 .1835 .57863 .18215 Metetra
.664 .741 .907 r
.57863 .18215 .57967 .1835 .5863 .18107 .58527 .17971 Metetra
.664 .741 .907 r
.58527 .17971 .5863 .18107 .59295 .17864 .59192 .17728 Metetra
.664 .741 .907 r
.59192 .17728 .59295 .17864 .59961 .1762 .59859 .17483 Metetra
.664 .741 .907 r
.59859 .17483 .59961 .1762 .60629 .17375 .60527 .17238 Metetra
.664 .741 .907 r
.60527 .17238 .60629 .17375 .61299 .1713 .61197 .16993 Metetra
.664 .741 .907 r
.61197 .16993 .61299 .1713 .6197 .16884 .61868 .16747 Metetra
.664 .741 .907 r
.61868 .16747 .6197 .16884 .62643 .16638 .62541 .165 Metetra
.664 .741 .907 r
.62541 .165 .62643 .16638 .63317 .16391 .63216 .16253 Metetra
.664 .741 .907 r
.63216 .16253 .63317 .16391 .63993 .16143 .63892 .16005 Metetra
.664 .741 .907 r
.63892 .16005 .63993 .16143 .64671 .15895 .6457 .15756 Metetra
.664 .741 .907 r
.6457 .15756 .64671 .15895 .6535 .15646 .6525 .15507 Metetra
.664 .741 .907 r
.6525 .15507 .6535 .15646 .66031 .15397 .65931 .15258 Metetra
.664 .741 .907 r
.65931 .15258 .66031 .15397 .66713 .15147 .66614 .15007 Metetra
.664 .741 .907 r
.66614 .15007 .66713 .15147 .67398 .14896 .67299 .14756 Metetra
.664 .741 .907 r
.67299 .14756 .67398 .14896 .68084 .14645 .67985 .14505 Metetra
.664 .741 .907 r
.67985 .14505 .68084 .14645 .68771 .14393 .68673 .14253 Metetra
.664 .741 .907 r
.68673 .14253 .68771 .14393 .6946 .14141 .69362 .14 Metetra
.664 .741 .907 r
.69362 .14 .6946 .14141 .70151 .13888 .70053 .13747 Metetra
.664 .741 .907 r
.70053 .13747 .70151 .13888 .70844 .13634 .70746 .13493 Metetra
.664 .741 .907 r
.70746 .13493 .70844 .13634 .71538 .1338 .71441 .13238 Metetra
.664 .741 .907 r
.71441 .13238 .71538 .1338 .72234 .13125 .72137 .12983 Metetra
.664 .741 .907 r
.72137 .12983 .72234 .13125 .72932 .1287 .72835 .12727 Metetra
.664 .741 .907 r
.72835 .12727 .72932 .1287 .73631 .12614 .73535 .1247 Metetra
.664 .741 .907 r
.73535 .1247 .73631 .12614 .74332 .12357 .74237 .12213 Metetra
.664 .741 .907 r
.74237 .12213 .74332 .12357 .75035 .12099 .7494 .11956 Metetra
.664 .741 .907 r
.7494 .11956 .75035 .12099 .75739 .11841 .75645 .11697 Metetra
.664 .741 .907 r
.75645 .11697 .75739 .11841 .76446 .11583 .76351 .11438 Metetra
.664 .741 .907 r
.13242 .3441 .13365 .34525 .13926 .34319 .13803 .34204 Metetra
.664 .741 .907 r
.13803 .34204 .13926 .34319 .14488 .34113 .14366 .33998 Metetra
.664 .741 .907 r
.14366 .33998 .14488 .34113 .15052 .33906 .1493 .33791 Metetra
.664 .741 .907 r
.1493 .33791 .15052 .33906 .15617 .33699 .15495 .33583 Metetra
.664 .741 .907 r
.15495 .33583 .15617 .33699 .16184 .33492 .16062 .33376 Metetra
.664 .741 .907 r
.16062 .33376 .16184 .33492 .16751 .33284 .1663 .33167 Metetra
.664 .741 .907 r
.1663 .33167 .16751 .33284 .1732 .33075 .17199 .32959 Metetra
.664 .741 .907 r
.17199 .32959 .1732 .33075 .1789 .32866 .17769 .32749 Metetra
.664 .741 .907 r
.17769 .32749 .1789 .32866 .18461 .32657 .18341 .3254 Metetra
.664 .741 .907 r
.18341 .3254 .18461 .32657 .19034 .32447 .18913 .3233 Metetra
.664 .741 .907 r
.18913 .3233 .19034 .32447 .19608 .32236 .19488 .32119 Metetra
.664 .741 .907 r
.19488 .32119 .19608 .32236 .20183 .32026 .20063 .31908 Metetra
.664 .741 .907 r
.20063 .31908 .20183 .32026 .2076 .31814 .2064 .31696 Metetra
.664 .741 .907 r
.2064 .31696 .2076 .31814 .21337 .31603 .21218 .31484 Metetra
.664 .741 .907 r
.21218 .31484 .21337 .31603 .21916 .3139 .21797 .31272 Metetra
.664 .741 .907 r
.21797 .31272 .21916 .3139 .22497 .31178 .22377 .31059 Metetra
.664 .741 .907 r
.22377 .31059 .22497 .31178 .23078 .30965 .22959 .30845 Metetra
.664 .741 .907 r
.22959 .30845 .23078 .30965 .23661 .30751 .23542 .30631 Metetra
.664 .741 .907 r
.23542 .30631 .23661 .30751 .24245 .30537 .24127 .30417 Metetra
.664 .741 .907 r
.24127 .30417 .24245 .30537 .24831 .30322 .24713 .30202 Metetra
.664 .741 .907 r
.24713 .30202 .24831 .30322 .25418 .30107 .253 .29987 Metetra
.664 .741 .907 r
.253 .29987 .25418 .30107 .25942 .30648 .25888 .29771 Metetra
.563 .385 .598 r
.25888 .29771 .25942 .30648 .26595 .29675 .26478 .29555 Metetra
.664 .741 .907 r
.26478 .29555 .26595 .29675 .27186 .29459 .27069 .29338 Metetra
.664 .741 .907 r
.27069 .29338 .27186 .29459 .27778 .29242 .27661 .29121 Metetra
.664 .741 .907 r
.27661 .29121 .27778 .29242 .28372 .29024 .28255 .28903 Metetra
.664 .741 .907 r
.28255 .28903 .28372 .29024 .28967 .28806 .2885 .28684 Metetra
.664 .741 .907 r
.2885 .28684 .28967 .28806 .29563 .28588 .29446 .28466 Metetra
.664 .741 .907 r
.29446 .28466 .29563 .28588 .3016 .28369 .30044 .28246 Metetra
.664 .741 .907 r
.30044 .28246 .3016 .28369 .30759 .28149 .30643 .28027 Metetra
.664 .741 .907 r
.30643 .28027 .30759 .28149 .3136 .27929 .31244 .27806 Metetra
.664 .741 .907 r
.31244 .27806 .3136 .27929 .31961 .27709 .31846 .27585 Metetra
.664 .741 .907 r
.31846 .27585 .31961 .27709 .32564 .27488 .32449 .27364 Metetra
.664 .741 .907 r
.32449 .27364 .32564 .27488 .33168 .27266 .33054 .27142 Metetra
.664 .741 .907 r
.33054 .27142 .33168 .27266 .33774 .27044 .3366 .2692 Metetra
.664 .741 .907 r
.3366 .2692 .33774 .27044 .34381 .26822 .34267 .26697 Metetra
.664 .741 .907 r
.34267 .26697 .34381 .26822 .3499 .26599 .34876 .26474 Metetra
.664 .741 .907 r
.34876 .26474 .3499 .26599 .356 .26375 .35486 .2625 Metetra
.664 .741 .907 r
.35486 .2625 .356 .26375 .36211 .26151 .36097 .26026 Metetra
.96 .64 .37 r
.36097 .26026 .36211 .26151 .36824 .25926 .36461 .30667 Metetra
.339 .132 .446 r
.36461 .30667 .36824 .25926 .37438 .25701 .37325 .25575 Metetra
.664 .741 .907 r
.37325 .25575 .37438 .25701 .38053 .25476 .37941 .2535 Metetra
.664 .741 .907 r
.37941 .2535 .38053 .25476 .3867 .25249 .38558 .25123 Metetra
.664 .741 .907 r
.38558 .25123 .3867 .25249 .39289 .25023 .39176 .24896 Metetra
.664 .741 .907 r
.39176 .24896 .39289 .25023 .39909 .24796 .39796 .24669 Metetra
.664 .741 .907 r
.39796 .24669 .39909 .24796 .4053 .24568 .40418 .24441 Metetra
.664 .741 .907 r
.40418 .24441 .4053 .24568 .41152 .2434 .41041 .24212 Metetra
.664 .741 .907 r
.41041 .24212 .41152 .2434 .41777 .24111 .41665 .23983 Metetra
.664 .741 .907 r
.41665 .23983 .41777 .24111 .42402 .23882 .42291 .23754 Metetra
.664 .741 .907 r
.42291 .23754 .42402 .23882 .43029 .23652 .42918 .23523 Metetra
.664 .741 .907 r
.42918 .23523 .43029 .23652 .43658 .23421 .43547 .23293 Metetra
.664 .741 .907 r
.43547 .23293 .43658 .23421 .44288 .23191 .44177 .23062 Metetra
.664 .741 .907 r
.44177 .23062 .44288 .23191 .44919 .22959 .44809 .2283 Metetra
.664 .741 .907 r
.44809 .2283 .44919 .22959 .45552 .22727 .45442 .22598 Metetra
.664 .741 .907 r
.45442 .22598 .45552 .22727 .46186 .22495 .46077 .22365 Metetra
.664 .741 .907 r
.46077 .22365 .46186 .22495 .46822 .22262 .46713 .22131 Metetra
.664 .741 .907 r
.46713 .22131 .46822 .22262 .4743 .23793 .47351 .21897 Metetra
.542 .337 .551 r
.47351 .21897 .4743 .23793 .48098 .21794 .4799 .21663 Metetra
.664 .741 .907 r
.4799 .21663 .48098 .21794 .48739 .21559 .4863 .21428 Metetra
.664 .741 .907 r
.4863 .21428 .48739 .21559 .4938 .21324 .49272 .21192 Metetra
.664 .741 .907 r
.49272 .21192 .4938 .21324 .50024 .21088 .49916 .20956 Metetra
.664 .741 .907 r
.49916 .20956 .50024 .21088 .50669 .20852 .50561 .2072 Metetra
.664 .741 .907 r
.50561 .2072 .50669 .20852 .51315 .20615 .51208 .20482 Metetra
.664 .741 .907 r
.51208 .20482 .51315 .20615 .51963 .20377 .51856 .20245 Metetra
.664 .741 .907 r
.51856 .20245 .51963 .20377 .52612 .20139 .52506 .20006 Metetra
.664 .741 .907 r
.52506 .20006 .52612 .20139 .53263 .19901 .53157 .19767 Metetra
.664 .741 .907 r
.53157 .19767 .53263 .19901 .53916 .19662 .5381 .19528 Metetra
.664 .741 .907 r
.5381 .19528 .53916 .19662 .5457 .19422 .54464 .19288 Metetra
.664 .741 .907 r
.54464 .19288 .5457 .19422 .55225 .19181 .5512 .19047 Metetra
.664 .741 .907 r
.5512 .19047 .55225 .19181 .55883 .18941 .55778 .18806 Metetra
.664 .741 .907 r
.55778 .18806 .55883 .18941 .56541 .18699 .56437 .18564 Metetra
.664 .741 .907 r
.56437 .18564 .56541 .18699 .57202 .18457 .57097 .18322 Metetra
.664 .741 .907 r
.57097 .18322 .57202 .18457 .57863 .18215 .5776 .18079 Metetra
.664 .741 .907 r
.5776 .18079 .57863 .18215 .58527 .17971 .58423 .17835 Metetra
.664 .741 .907 r
.58423 .17835 .58527 .17971 .59192 .17728 .59089 .17591 Metetra
.664 .741 .907 r
.59089 .17591 .59192 .17728 .59859 .17483 .59756 .17347 Metetra
.664 .741 .907 r
.59756 .17347 .59859 .17483 .60527 .17238 .60424 .17101 Metetra
.664 .741 .907 r
.60424 .17101 .60527 .17238 .61197 .16993 .61094 .16856 Metetra
.664 .741 .907 r
.61094 .16856 .61197 .16993 .61868 .16747 .61766 .16609 Metetra
.664 .741 .907 r
.61766 .16609 .61868 .16747 .62541 .165 .6244 .16362 Metetra
.664 .741 .907 r
.6244 .16362 .62541 .165 .63216 .16253 .63115 .16114 Metetra
.664 .741 .907 r
.63115 .16114 .63216 .16253 .63892 .16005 .63791 .15866 Metetra
.664 .741 .907 r
.63791 .15866 .63892 .16005 .6457 .15756 .6447 .15617 Metetra
.664 .741 .907 r
.6447 .15617 .6457 .15756 .6525 .15507 .6515 .15368 Metetra
.664 .741 .907 r
.6515 .15368 .6525 .15507 .65931 .15258 .65831 .15118 Metetra
.664 .741 .907 r
.65831 .15118 .65931 .15258 .66614 .15007 .66514 .14867 Metetra
.664 .741 .907 r
.66514 .14867 .66614 .15007 .67299 .14756 .67199 .14616 Metetra
.664 .741 .907 r
.67199 .14616 .67299 .14756 .67985 .14505 .67886 .14364 Metetra
.664 .741 .907 r
.67886 .14364 .67985 .14505 .68673 .14253 .68574 .14112 Metetra
.664 .741 .907 r
.68574 .14112 .68673 .14253 .69362 .14 .69264 .13859 Metetra
.664 .741 .907 r
.69264 .13859 .69362 .14 .70053 .13747 .69956 .13605 Metetra
.664 .741 .907 r
.69956 .13605 .70053 .13747 .70746 .13493 .70649 .13351 Metetra
.664 .741 .907 r
.70649 .13351 .70746 .13493 .71441 .13238 .71344 .13096 Metetra
.664 .741 .907 r
.71344 .13096 .71441 .13238 .72137 .12983 .7204 .1284 Metetra
.664 .741 .907 r
.7204 .1284 .72137 .12983 .72835 .12727 .72739 .12584 Metetra
.664 .741 .907 r
.72739 .12584 .72835 .12727 .73535 .1247 .73439 .12327 Metetra
.664 .741 .907 r
.73439 .12327 .73535 .1247 .74237 .12213 .74141 .1207 Metetra
.664 .741 .907 r
.74141 .1207 .74237 .12213 .7494 .11956 .74844 .11812 Metetra
.664 .741 .907 r
.74844 .11812 .7494 .11956 .75645 .11697 .7555 .11553 Metetra
.664 .741 .907 r
.7555 .11553 .75645 .11697 .76351 .11438 .76257 .11293 Metetra
.664 .741 .907 r
.13119 .34295 .13242 .3441 .13803 .34204 .13681 .34089 Metetra
.664 .741 .907 r
.13681 .34089 .13803 .34204 .14366 .33998 .14244 .33882 Metetra
.664 .741 .907 r
.14244 .33882 .14366 .33998 .1493 .33791 .14808 .33675 Metetra
.664 .741 .907 r
.14808 .33675 .1493 .33791 .15495 .33583 .15373 .33468 Metetra
.664 .741 .907 r
.15373 .33468 .15495 .33583 .16062 .33376 .1594 .3326 Metetra
.664 .741 .907 r
.1594 .3326 .16062 .33376 .1663 .33167 .16508 .33051 Metetra
.664 .741 .907 r
.16508 .33051 .1663 .33167 .17199 .32959 .17077 .32842 Metetra
.664 .741 .907 r
.17077 .32842 .17199 .32959 .17769 .32749 .17648 .32633 Metetra
.664 .741 .907 r
.17648 .32633 .17769 .32749 .18341 .3254 .1822 .32423 Metetra
.664 .741 .907 r
.1822 .32423 .18341 .3254 .18913 .3233 .18793 .32212 Metetra
.664 .741 .907 r
.18793 .32212 .18913 .3233 .19488 .32119 .19367 .32001 Metetra
.664 .741 .907 r
.19367 .32001 .19488 .32119 .20063 .31908 .19943 .3179 Metetra
.664 .741 .907 r
.19943 .3179 .20063 .31908 .2064 .31696 .20519 .31578 Metetra
.664 .741 .907 r
.20519 .31578 .2064 .31696 .21218 .31484 .21098 .31366 Metetra
.664 .741 .907 r
.21098 .31366 .21218 .31484 .21797 .31272 .21677 .31153 Metetra
.664 .741 .907 r
.21677 .31153 .21797 .31272 .22377 .31059 .22258 .3094 Metetra
.664 .741 .907 r
.22258 .3094 .22377 .31059 .22959 .30845 .2284 .30726 Metetra
.664 .741 .907 r
.2284 .30726 .22959 .30845 .23542 .30631 .23423 .30512 Metetra
.664 .741 .907 r
.23423 .30512 .23542 .30631 .24127 .30417 .24008 .30297 Metetra
.664 .741 .907 r
.24008 .30297 .24127 .30417 .24713 .30202 .24594 .30082 Metetra
.664 .741 .907 r
.24594 .30082 .24713 .30202 .253 .29987 .25181 .29867 Metetra
.664 .741 .907 r
.25181 .29867 .253 .29987 .25888 .29771 .2577 .2965 Metetra
.664 .741 .907 r
.2577 .2965 .25888 .29771 .26478 .29555 .2636 .29434 Metetra
.664 .741 .907 r
.2636 .29434 .26478 .29555 .27069 .29338 .26951 .29217 Metetra
.664 .741 .907 r
.26951 .29217 .27069 .29338 .27661 .29121 .27544 .28999 Metetra
.664 .741 .907 r
.27544 .28999 .27661 .29121 .28255 .28903 .28138 .28781 Metetra
.664 .741 .907 r
.28138 .28781 .28255 .28903 .2885 .28684 .28733 .28562 Metetra
.664 .741 .907 r
.28733 .28562 .2885 .28684 .29446 .28466 .2933 .28343 Metetra
.664 .741 .907 r
.2933 .28343 .29446 .28466 .30044 .28246 .29928 .28124 Metetra
.664 .741 .907 r
.29928 .28124 .30044 .28246 .30643 .28027 .30527 .27904 Metetra
.664 .741 .907 r
.30527 .27904 .30643 .28027 .31244 .27806 .31128 .27683 Metetra
.664 .741 .907 r
.31128 .27683 .31244 .27806 .31846 .27585 .3173 .27462 Metetra
.664 .741 .907 r
.3173 .27462 .31846 .27585 .32449 .27364 .32334 .2724 Metetra
.664 .741 .907 r
.32334 .2724 .32449 .27364 .33054 .27142 .32938 .27018 Metetra
.664 .741 .907 r
.32938 .27018 .33054 .27142 .3366 .2692 .33545 .26796 Metetra
.664 .741 .907 r
.33545 .26796 .3366 .2692 .34267 .26697 .34152 .26573 Metetra
.664 .741 .907 r
.34152 .26573 .34267 .26697 .34876 .26474 .34761 .26349 Metetra
.664 .741 .907 r
.34761 .26349 .34876 .26474 .35486 .2625 .35372 .26125 Metetra
.664 .741 .907 r
.35372 .26125 .35486 .2625 .36097 .26026 .35984 .259 Metetra
.961 .679 .453 r
.35984 .259 .36097 .26026 .36461 .30667 .35387 .49116 Metetra
.317 .124 .454 r
.35387 .49116 .36461 .30667 .37325 .25575 .37111 .27465 Metetra
.313 .091 .409 r
.37111 .27465 .37325 .25575 .37941 .2535 .37827 .25223 Metetra
.664 .741 .907 r
.37827 .25223 .37941 .2535 .38558 .25123 .38445 .24997 Metetra
.664 .741 .907 r
.38445 .24997 .38558 .25123 .39176 .24896 .39064 .24769 Metetra
.664 .741 .907 r
.39064 .24769 .39176 .24896 .39796 .24669 .39684 .24542 Metetra
.664 .741 .907 r
.39684 .24542 .39796 .24669 .40418 .24441 .40306 .24313 Metetra
.664 .741 .907 r
.40306 .24313 .40418 .24441 .41041 .24212 .40929 .24084 Metetra
.664 .741 .907 r
.40929 .24084 .41041 .24212 .41665 .23983 .41554 .23855 Metetra
.664 .741 .907 r
.41554 .23855 .41665 .23983 .42291 .23754 .4218 .23625 Metetra
.664 .741 .907 r
.4218 .23625 .42291 .23754 .42918 .23523 .42808 .23395 Metetra
.664 .741 .907 r
.42808 .23395 .42918 .23523 .43547 .23293 .43437 .23164 Metetra
.664 .741 .907 r
.43437 .23164 .43547 .23293 .44177 .23062 .44067 .22932 Metetra
.664 .741 .907 r
.44067 .22932 .44177 .23062 .44809 .2283 .44699 .227 Metetra
.664 .741 .907 r
.44699 .227 .44809 .2283 .45442 .22598 .45333 .22468 Metetra
.664 .741 .907 r
.45333 .22468 .45442 .22598 .46077 .22365 .45967 .22235 Metetra
.664 .741 .907 r
.45967 .22235 .46077 .22365 .46713 .22131 .46604 .22001 Metetra
.664 .741 .907 r
.46604 .22001 .46713 .22131 .47351 .21897 .47242 .21767 Metetra
.664 .741 .907 r
.47242 .21767 .47351 .21897 .4799 .21663 .47881 .21532 Metetra
.664 .741 .907 r
.47881 .21532 .4799 .21663 .4863 .21428 .48522 .21297 Metetra
.664 .741 .907 r
.48522 .21297 .4863 .21428 .49272 .21192 .49164 .21061 Metetra
.664 .741 .907 r
.49164 .21061 .49272 .21192 .49916 .20956 .49808 .20824 Metetra
.664 .741 .907 r
.49808 .20824 .49916 .20956 .50561 .2072 .50454 .20587 Metetra
.664 .741 .907 r
.50454 .20587 .50561 .2072 .51208 .20482 .51101 .2035 Metetra
.664 .741 .907 r
.51101 .2035 .51208 .20482 .51856 .20245 .51749 .20112 Metetra
.664 .741 .907 r
.51749 .20112 .51856 .20245 .52506 .20006 .52399 .19873 Metetra
.664 .741 .907 r
.52399 .19873 .52506 .20006 .53157 .19767 .53051 .19634 Metetra
.664 .741 .907 r
.53051 .19634 .53157 .19767 .5381 .19528 .53704 .19394 Metetra
.664 .741 .907 r
.53704 .19394 .5381 .19528 .54464 .19288 .54359 .19154 Metetra
.664 .741 .907 r
.54359 .19154 .54464 .19288 .5512 .19047 .55015 .18913 Metetra
.664 .741 .907 r
.55015 .18913 .5512 .19047 .55778 .18806 .55673 .18671 Metetra
.664 .741 .907 r
.55673 .18671 .55778 .18806 .56437 .18564 .56332 .18429 Metetra
.664 .741 .907 r
.56332 .18429 .56437 .18564 .57097 .18322 .56993 .18186 Metetra
.664 .741 .907 r
.56993 .18186 .57097 .18322 .5776 .18079 .57656 .17943 Metetra
.664 .741 .907 r
.57656 .17943 .5776 .18079 .58423 .17835 .5832 .17699 Metetra
.664 .741 .907 r
.5832 .17699 .58423 .17835 .59089 .17591 .58985 .17455 Metetra
.664 .741 .907 r
.58985 .17455 .59089 .17591 .59756 .17347 .59653 .1721 Metetra
.664 .741 .907 r
.59653 .1721 .59756 .17347 .60424 .17101 .60322 .16964 Metetra
.664 .741 .907 r
.60322 .16964 .60424 .17101 .61094 .16856 .60992 .16718 Metetra
.664 .741 .907 r
.60992 .16718 .61094 .16856 .61766 .16609 .61664 .16471 Metetra
.664 .741 .907 r
.61664 .16471 .61766 .16609 .6244 .16362 .62338 .16224 Metetra
.664 .741 .907 r
.62338 .16224 .6244 .16362 .63115 .16114 .63013 .15976 Metetra
.664 .741 .907 r
.63013 .15976 .63115 .16114 .63791 .15866 .6369 .15728 Metetra
.664 .741 .907 r
.6369 .15728 .63791 .15866 .6447 .15617 .64369 .15478 Metetra
.664 .741 .907 r
.64369 .15478 .6447 .15617 .6515 .15368 .65049 .15229 Metetra
.664 .741 .907 r
.65049 .15229 .6515 .15368 .65831 .15118 .65731 .14978 Metetra
.664 .741 .907 r
.65731 .14978 .65831 .15118 .66514 .14867 .66415 .14727 Metetra
.664 .741 .907 r
.66415 .14727 .66514 .14867 .67199 .14616 .671 .14476 Metetra
.664 .741 .907 r
.671 .14476 .67199 .14616 .67886 .14364 .67787 .14223 Metetra
.664 .741 .907 r
.67787 .14223 .67886 .14364 .68574 .14112 .68475 .13971 Metetra
.495 .661 .936 r
.68475 .13971 .68574 .14112 .69264 .13859 .69179 .1395 Metetra
.956 .614 .304 r
.69179 .1395 .69264 .13859 .69956 .13605 .70392 .22571 Metetra
.377 .178 .479 r
.70392 .22571 .69956 .13605 .70649 .13351 .70551 .13208 Metetra
.664 .741 .907 r
.70551 .13208 .70649 .13351 .71344 .13096 .71246 .12953 Metetra
.664 .741 .907 r
.71246 .12953 .71344 .13096 .7204 .1284 .71944 .12697 Metetra
.664 .741 .907 r
.71944 .12697 .7204 .1284 .72739 .12584 .72642 .12441 Metetra
.664 .741 .907 r
.72642 .12441 .72739 .12584 .73439 .12327 .73343 .12184 Metetra
.664 .741 .907 r
.73343 .12184 .73439 .12327 .74141 .1207 .74045 .11926 Metetra
.664 .741 .907 r
.74045 .11926 .74141 .1207 .74844 .11812 .74749 .11667 Metetra
.664 .741 .907 r
.74749 .11667 .74844 .11812 .7555 .11553 .75454 .11408 Metetra
.664 .741 .907 r
.75454 .11408 .7555 .11553 .76257 .11293 .76162 .11148 Metetra
.664 .741 .907 r
.12996 .3418 .13119 .34295 .13681 .34089 .13558 .33974 Metetra
.664 .741 .907 r
.13558 .33974 .13681 .34089 .14244 .33882 .14121 .33767 Metetra
.664 .741 .907 r
.14121 .33767 .14244 .33882 .14808 .33675 .14685 .33559 Metetra
.664 .741 .907 r
.14685 .33559 .14808 .33675 .15373 .33468 .15251 .33352 Metetra
.664 .741 .907 r
.15251 .33352 .15373 .33468 .1594 .3326 .15818 .33143 Metetra
.664 .741 .907 r
.15818 .33143 .1594 .3326 .16508 .33051 .16386 .32934 Metetra
.664 .741 .907 r
.16386 .32934 .16508 .33051 .17077 .32842 .16956 .32725 Metetra
.664 .741 .907 r
.16956 .32725 .17077 .32842 .17648 .32633 .17526 .32515 Metetra
.664 .741 .907 r
.17526 .32515 .17648 .32633 .1822 .32423 .18098 .32305 Metetra
.664 .741 .907 r
.18098 .32305 .1822 .32423 .18793 .32212 .18672 .32095 Metetra
.664 .741 .907 r
.18672 .32095 .18793 .32212 .19367 .32001 .19246 .31883 Metetra
.664 .741 .907 r
.19246 .31883 .19367 .32001 .19943 .3179 .19822 .31672 Metetra
.664 .741 .907 r
.19822 .31672 .19943 .3179 .20519 .31578 .20399 .3146 Metetra
.664 .741 .907 r
.20399 .3146 .20519 .31578 .21098 .31366 .20978 .31247 Metetra
.664 .741 .907 r
.20978 .31247 .21098 .31366 .21677 .31153 .21557 .31034 Metetra
.664 .741 .907 r
.21557 .31034 .21677 .31153 .22258 .3094 .22138 .30821 Metetra
.664 .741 .907 r
.22138 .30821 .22258 .3094 .2284 .30726 .22721 .30607 Metetra
.664 .741 .907 r
.22721 .30607 .2284 .30726 .23423 .30512 .23304 .30392 Metetra
.664 .741 .907 r
.23304 .30392 .23423 .30512 .24008 .30297 .23889 .30177 Metetra
.664 .741 .907 r
.23889 .30177 .24008 .30297 .24594 .30082 .24475 .29962 Metetra
.664 .741 .907 r
.24475 .29962 .24594 .30082 .25181 .29867 .25063 .29746 Metetra
.664 .741 .907 r
.25063 .29746 .25181 .29867 .2577 .2965 .25652 .2953 Metetra
.664 .741 .907 r
.25652 .2953 .2577 .2965 .2636 .29434 .26242 .29313 Metetra
.664 .741 .907 r
.26242 .29313 .2636 .29434 .26951 .29217 .26833 .29095 Metetra
.664 .741 .907 r
.26833 .29095 .26951 .29217 .27544 .28999 .27426 .28878 Metetra
.664 .741 .907 r
.27426 .28878 .27544 .28999 .28138 .28781 .28021 .28659 Metetra
.664 .741 .907 r
.28021 .28659 .28138 .28781 .28733 .28562 .28616 .2844 Metetra
.664 .741 .907 r
.28616 .2844 .28733 .28562 .2933 .28343 .29213 .28221 Metetra
.664 .741 .907 r
.29213 .28221 .2933 .28343 .29928 .28124 .29811 .28001 Metetra
.664 .741 .907 r
.29811 .28001 .29928 .28124 .30527 .27904 .30411 .27781 Metetra
.664 .741 .907 r
.30411 .27781 .30527 .27904 .31128 .27683 .31012 .2756 Metetra
.664 .741 .907 r
.31012 .2756 .31128 .27683 .3173 .27462 .31614 .27339 Metetra
.664 .741 .907 r
.31614 .27339 .3173 .27462 .32334 .2724 .32218 .27117 Metetra
.664 .741 .907 r
.32218 .27117 .32334 .2724 .32938 .27018 .32823 .26894 Metetra
.664 .741 .907 r
.32823 .26894 .32938 .27018 .33545 .26796 .3343 .26671 Metetra
.664 .741 .907 r
.3343 .26671 .33545 .26796 .34152 .26573 .34038 .26448 Metetra
.664 .741 .907 r
.34038 .26448 .34152 .26573 .34761 .26349 .34647 .26224 Metetra
.664 .741 .907 r
.34647 .26224 .34761 .26349 .35372 .26125 .35257 .26 Metetra
.956 .621 .334 r
.35257 .26 .35372 .26125 .35984 .259 .35671 .2946 Metetra
.813 .533 .515 r
.35671 .2946 .35984 .259 .35387 .49116 .35264 .48997 Metetra
.96 .696 .489 r
.35264 .48997 .35387 .49116 .37111 .27465 .37098 .25323 Metetra
.539 .331 .546 r
.37098 .25323 .37111 .27465 .37827 .25223 .37714 .25097 Metetra
.664 .741 .907 r
.37714 .25097 .37827 .25223 .38445 .24997 .38332 .2487 Metetra
.664 .741 .907 r
.38332 .2487 .38445 .24997 .39064 .24769 .38951 .24642 Metetra
.664 .741 .907 r
.38951 .24642 .39064 .24769 .39684 .24542 .39572 .24414 Metetra
.664 .741 .907 r
.39572 .24414 .39684 .24542 .40306 .24313 .40194 .24186 Metetra
.664 .741 .907 r
.40194 .24186 .40306 .24313 .40929 .24084 .40817 .23957 Metetra
.664 .741 .907 r
.40817 .23957 .40929 .24084 .41554 .23855 .41442 .23727 Metetra
.664 .741 .907 r
.41442 .23727 .41554 .23855 .4218 .23625 .42069 .23497 Metetra
.664 .741 .907 r
.42069 .23497 .4218 .23625 .42808 .23395 .42697 .23266 Metetra
.664 .741 .907 r
.42697 .23266 .42808 .23395 .43437 .23164 .43326 .23035 Metetra
.664 .741 .907 r
.43326 .23035 .43437 .23164 .44067 .22932 .43957 .22803 Metetra
.664 .741 .907 r
.43957 .22803 .44067 .22932 .44699 .227 .44589 .22571 Metetra
.664 .741 .907 r
.44589 .22571 .44699 .227 .45333 .22468 .45223 .22338 Metetra
.664 .741 .907 r
.45223 .22338 .45333 .22468 .45967 .22235 .45858 .22104 Metetra
.664 .741 .907 r
.45858 .22104 .45967 .22235 .46604 .22001 .46495 .2187 Metetra
.664 .741 .907 r
.46495 .2187 .46604 .22001 .47242 .21767 .47133 .21636 Metetra
.664 .741 .907 r
.47133 .21636 .47242 .21767 .47881 .21532 .47772 .21401 Metetra
.664 .741 .907 r
.47772 .21401 .47881 .21532 .48522 .21297 .48414 .21165 Metetra
.664 .741 .907 r
.48414 .21165 .48522 .21297 .49164 .21061 .49056 .20929 Metetra
.664 .741 .907 r
.49056 .20929 .49164 .21061 .49808 .20824 .49701 .20692 Metetra
.664 .741 .907 r
.49701 .20692 .49808 .20824 .50454 .20587 .50346 .20455 Metetra
.664 .741 .907 r
.50346 .20455 .50454 .20587 .51101 .2035 .50994 .20217 Metetra
.664 .741 .907 r
.50994 .20217 .51101 .2035 .51749 .20112 .51642 .19979 Metetra
.664 .741 .907 r
.51642 .19979 .51749 .20112 .52399 .19873 .52293 .1974 Metetra
.664 .741 .907 r
.52293 .1974 .52399 .19873 .53051 .19634 .52945 .195 Metetra
.664 .741 .907 r
.52945 .195 .53051 .19634 .53704 .19394 .53598 .1926 Metetra
.664 .741 .907 r
.53598 .1926 .53704 .19394 .54359 .19154 .54253 .19019 Metetra
.664 .741 .907 r
.54253 .19019 .54359 .19154 .55015 .18913 .5491 .18778 Metetra
.664 .741 .907 r
.5491 .18778 .55015 .18913 .55673 .18671 .55568 .18536 Metetra
.664 .741 .907 r
.55568 .18536 .55673 .18671 .56332 .18429 .56227 .18294 Metetra
.664 .741 .907 r
.56227 .18294 .56332 .18429 .56993 .18186 .56889 .18051 Metetra
.664 .741 .907 r
.56889 .18051 .56993 .18186 .57656 .17943 .57551 .17807 Metetra
.664 .741 .907 r
.57551 .17807 .57656 .17943 .5832 .17699 .58216 .17563 Metetra
.664 .741 .907 r
.58216 .17563 .5832 .17699 .58985 .17455 .58882 .17318 Metetra
.664 .741 .907 r
.58882 .17318 .58985 .17455 .59653 .1721 .59549 .17073 Metetra
.664 .741 .907 r
.59549 .17073 .59653 .1721 .60322 .16964 .60219 .16827 Metetra
.664 .741 .907 r
.60219 .16827 .60322 .16964 .60992 .16718 .6089 .16581 Metetra
.664 .741 .907 r
.6089 .16581 .60992 .16718 .61664 .16471 .61562 .16334 Metetra
.664 .741 .907 r
.61562 .16334 .61664 .16471 .62338 .16224 .62236 .16086 Metetra
.664 .741 .907 r
.62236 .16086 .62338 .16224 .63013 .15976 .62912 .15838 Metetra
.664 .741 .907 r
.62912 .15838 .63013 .15976 .6369 .15728 .63589 .15589 Metetra
.664 .741 .907 r
.63589 .15589 .6369 .15728 .64369 .15478 .64268 .15339 Metetra
.664 .741 .907 r
.64268 .15339 .64369 .15478 .65049 .15229 .64949 .15089 Metetra
.664 .741 .907 r
.64949 .15089 .65049 .15229 .65731 .14978 .65631 .14838 Metetra
.664 .741 .907 r
.65631 .14838 .65731 .14978 .66415 .14727 .66315 .14587 Metetra
.664 .741 .907 r
.66315 .14587 .66415 .14727 .671 .14476 .67 .14335 Metetra
.664 .741 .907 r
.67 .14335 .671 .14476 .67787 .14223 .67688 .14083 Metetra
.664 .741 .907 r
.67688 .14083 .67787 .14223 .68475 .13971 .68377 .13829 Metetra
.664 .741 .907 r
.68377 .13829 .68475 .13971 .69179 .1395 .69067 .13576 Metetra
0 0 .244 r
.69067 .13576 .69179 .1395 .70392 .22571 .69934 .16312 Metetra
.581 .344 .523 r
.69934 .16312 .70392 .22571 .70551 .13208 .70453 .13066 Metetra
.664 .741 .907 r
.70453 .13066 .70551 .13208 .71246 .12953 .71149 .12811 Metetra
.664 .741 .907 r
.71149 .12811 .71246 .12953 .71944 .12697 .71846 .12554 Metetra
.664 .741 .907 r
.71846 .12554 .71944 .12697 .72642 .12441 .72546 .12297 Metetra
.664 .741 .907 r
.72546 .12297 .72642 .12441 .73343 .12184 .73246 .1204 Metetra
.664 .741 .907 r
.73246 .1204 .73343 .12184 .74045 .11926 .73949 .11782 Metetra
.664 .741 .907 r
.73949 .11782 .74045 .11926 .74749 .11667 .74653 .11523 Metetra
.664 .741 .907 r
.74653 .11523 .74749 .11667 .75454 .11408 .75359 .11263 Metetra
.664 .741 .907 r
.75359 .11263 .75454 .11408 .76162 .11148 .76067 .11003 Metetra
.664 .741 .907 r
.12872 .34065 .12996 .3418 .13558 .33974 .13435 .33859 Metetra
.664 .741 .907 r
.13435 .33859 .13558 .33974 .14121 .33767 .13998 .33651 Metetra
.664 .741 .907 r
.13998 .33651 .14121 .33767 .14685 .33559 .14563 .33444 Metetra
.664 .741 .907 r
.14563 .33444 .14685 .33559 .15251 .33352 .15129 .33235 Metetra
.664 .741 .907 r
.15129 .33235 .15251 .33352 .15818 .33143 .15696 .33027 Metetra
.664 .741 .907 r
.15696 .33027 .15818 .33143 .16386 .32934 .16264 .32818 Metetra
.664 .741 .907 r
.16264 .32818 .16386 .32934 .16956 .32725 .16834 .32608 Metetra
.664 .741 .907 r
.16834 .32608 .16956 .32725 .17526 .32515 .17405 .32398 Metetra
.664 .741 .907 r
.17405 .32398 .17526 .32515 .18098 .32305 .17977 .32188 Metetra
.664 .741 .907 r
.17977 .32188 .18098 .32305 .18672 .32095 .18551 .31977 Metetra
.664 .741 .907 r
.18551 .31977 .18672 .32095 .19246 .31883 .19125 .31766 Metetra
.664 .741 .907 r
.19125 .31766 .19246 .31883 .19822 .31672 .19701 .31554 Metetra
.664 .741 .907 r
.19701 .31554 .19822 .31672 .20399 .3146 .20279 .31341 Metetra
.084 .459 .886 r
.20279 .31341 .20399 .3146 .20978 .31247 .20814 .31556 Metetra
.745 .406 .408 r
.20814 .31556 .20978 .31247 .21557 .31034 .21255 .32756 Metetra
.286 .06 .385 r
.21255 .32756 .21557 .31034 .22138 .30821 .22018 .30701 Metetra
.664 .741 .907 r
.22018 .30701 .22138 .30821 .22721 .30607 .22601 .30487 Metetra
.664 .741 .907 r
.22601 .30487 .22721 .30607 .23304 .30392 .23185 .30272 Metetra
.664 .741 .907 r
.23185 .30272 .23304 .30392 .23889 .30177 .2377 .30057 Metetra
.664 .741 .907 r
.2377 .30057 .23889 .30177 .24475 .29962 .24356 .29842 Metetra
.664 .741 .907 r
.24356 .29842 .24475 .29962 .25063 .29746 .24944 .29625 Metetra
.664 .741 .907 r
.24944 .29625 .25063 .29746 .25652 .2953 .25533 .29409 Metetra
.664 .741 .907 r
.25533 .29409 .25652 .2953 .26242 .29313 .26124 .29192 Metetra
.664 .741 .907 r
.26124 .29192 .26242 .29313 .26833 .29095 .26716 .28974 Metetra
.664 .741 .907 r
.26716 .28974 .26833 .29095 .27426 .28878 .27309 .28756 Metetra
.664 .741 .907 r
.27309 .28756 .27426 .28878 .28021 .28659 .27903 .28537 Metetra
.664 .741 .907 r
.27903 .28537 .28021 .28659 .28616 .2844 .28499 .28318 Metetra
.664 .741 .907 r
.28499 .28318 .28616 .2844 .29213 .28221 .29096 .28098 Metetra
.664 .741 .907 r
.29096 .28098 .29213 .28221 .29811 .28001 .29695 .27878 Metetra
.664 .741 .907 r
.29695 .27878 .29811 .28001 .30411 .27781 .30294 .27658 Metetra
.664 .741 .907 r
.30294 .27658 .30411 .27781 .31012 .2756 .30896 .27437 Metetra
.664 .741 .907 r
.30896 .27437 .31012 .2756 .31614 .27339 .31498 .27215 Metetra
.664 .741 .907 r
.31498 .27215 .31614 .27339 .32218 .27117 .32102 .26993 Metetra
.664 .741 .907 r
.32102 .26993 .32218 .27117 .32823 .26894 .32708 .2677 Metetra
.664 .741 .907 r
.32708 .2677 .32823 .26894 .3343 .26671 .33314 .26547 Metetra
.664 .741 .907 r
.33314 .26547 .3343 .26671 .34038 .26448 .33923 .26323 Metetra
.664 .741 .907 r
.33923 .26323 .34038 .26448 .34647 .26224 .34532 .26099 Metetra
.664 .741 .907 r
.34532 .26099 .34647 .26224 .35257 .26 .35143 .25874 Metetra
.961 .664 .421 r
.35143 .25874 .35257 .26 .35671 .2946 .35285 .34306 Metetra
.69 .424 .515 r
.35285 .34306 .35671 .2946 .35264 .48997 .3541 .43739 Metetra
.782 .519 .538 r
.3541 .43739 .35264 .48997 .37098 .25323 .36984 .25197 Metetra
.664 .741 .907 r
.36984 .25197 .37098 .25323 .37714 .25097 .37601 .2497 Metetra
.664 .741 .907 r
.37601 .2497 .37714 .25097 .38332 .2487 .38219 .24743 Metetra
.664 .741 .907 r
.38219 .24743 .38332 .2487 .38951 .24642 .38838 .24515 Metetra
.664 .741 .907 r
.38838 .24515 .38951 .24642 .39572 .24414 .39459 .24287 Metetra
.664 .741 .907 r
.39459 .24287 .39572 .24414 .40194 .24186 .40082 .24058 Metetra
.664 .741 .907 r
.40082 .24058 .40194 .24186 .40817 .23957 .40705 .23829 Metetra
.664 .741 .907 r
.40705 .23829 .40817 .23957 .41442 .23727 .41331 .23599 Metetra
.664 .741 .907 r
.41331 .23599 .41442 .23727 .42069 .23497 .41957 .23368 Metetra
.664 .741 .907 r
.41957 .23368 .42069 .23497 .42697 .23266 .42585 .23137 Metetra
.664 .741 .907 r
.42585 .23137 .42697 .23266 .43326 .23035 .43215 .22906 Metetra
.664 .741 .907 r
.43215 .22906 .43326 .23035 .43957 .22803 .43846 .22674 Metetra
.664 .741 .907 r
.43846 .22674 .43957 .22803 .44589 .22571 .44479 .22441 Metetra
.664 .741 .907 r
.44479 .22441 .44589 .22571 .45223 .22338 .45113 .22208 Metetra
.664 .741 .907 r
.45113 .22208 .45223 .22338 .45858 .22104 .45748 .21974 Metetra
.664 .741 .907 r
.45748 .21974 .45858 .22104 .46495 .2187 .46385 .2174 Metetra
.664 .741 .907 r
.46385 .2174 .46495 .2187 .47133 .21636 .47024 .21505 Metetra
.664 .741 .907 r
.47024 .21505 .47133 .21636 .47772 .21401 .47664 .21269 Metetra
.664 .741 .907 r
.47664 .21269 .47772 .21401 .48414 .21165 .48305 .21034 Metetra
.664 .741 .907 r
.48305 .21034 .48414 .21165 .49056 .20929 .48948 .20797 Metetra
.664 .741 .907 r
.48948 .20797 .49056 .20929 .49701 .20692 .49593 .2056 Metetra
.664 .741 .907 r
.49593 .2056 .49701 .20692 .50346 .20455 .50239 .20322 Metetra
.664 .741 .907 r
.50239 .20322 .50346 .20455 .50994 .20217 .50886 .20084 Metetra
.664 .741 .907 r
.50886 .20084 .50994 .20217 .51642 .19979 .51535 .19846 Metetra
.664 .741 .907 r
.51535 .19846 .51642 .19979 .52293 .1974 .52186 .19606 Metetra
.664 .741 .907 r
.52186 .19606 .52293 .1974 .52945 .195 .52838 .19366 Metetra
.664 .741 .907 r
.52838 .19366 .52945 .195 .53598 .1926 .53492 .19126 Metetra
.664 .741 .907 r
.53492 .19126 .53598 .1926 .54253 .19019 .54147 .18885 Metetra
.664 .741 .907 r
.54147 .18885 .54253 .19019 .5491 .18778 .54804 .18643 Metetra
.664 .741 .907 r
.54804 .18643 .5491 .18778 .55568 .18536 .55462 .18401 Metetra
.664 .741 .907 r
.55462 .18401 .55568 .18536 .56227 .18294 .56122 .18158 Metetra
.664 .741 .907 r
.56122 .18158 .56227 .18294 .56889 .18051 .56784 .17915 Metetra
.664 .741 .907 r
.56784 .17915 .56889 .18051 .57551 .17807 .57447 .17671 Metetra
.664 .741 .907 r
.57447 .17671 .57551 .17807 .58216 .17563 .58112 .17427 Metetra
.664 .741 .907 r
.58112 .17427 .58216 .17563 .58882 .17318 .58778 .17182 Metetra
.664 .741 .907 r
.58778 .17182 .58882 .17318 .59549 .17073 .59446 .16936 Metetra
.664 .741 .907 r
.59446 .16936 .59549 .17073 .60219 .16827 .60116 .1669 Metetra
.664 .741 .907 r
.60116 .1669 .60219 .16827 .6089 .16581 .60787 .16443 Metetra
.664 .741 .907 r
.60787 .16443 .6089 .16581 .61562 .16334 .6146 .16195 Metetra
.664 .741 .907 r
.6146 .16195 .61562 .16334 .62236 .16086 .62134 .15947 Metetra
.664 .741 .907 r
.62134 .15947 .62236 .16086 .62912 .15838 .6281 .15699 Metetra
.664 .741 .907 r
.6281 .15699 .62912 .15838 .63589 .15589 .63488 .1545 Metetra
.664 .741 .907 r
.63488 .1545 .63589 .15589 .64268 .15339 .64167 .152 Metetra
.664 .741 .907 r
.64167 .152 .64268 .15339 .64949 .15089 .64848 .14949 Metetra
.664 .741 .907 r
.64848 .14949 .64949 .15089 .65631 .14838 .6553 .14698 Metetra
.664 .741 .907 r
.6553 .14698 .65631 .14838 .66315 .14587 .66215 .14447 Metetra
.664 .741 .907 r
.66215 .14447 .66315 .14587 .67 .14335 .66901 .14194 Metetra
.664 .741 .907 r
.66901 .14194 .67 .14335 .67688 .14083 .67588 .13941 Metetra
.664 .741 .907 r
.67588 .13941 .67688 .14083 .68377 .13829 .68278 .13688 Metetra
.664 .741 .907 r
.68278 .13688 .68377 .13829 .69067 .13576 .68968 .13434 Metetra
.664 .741 .907 r
.68968 .13434 .69067 .13576 .69934 .16312 .69661 .13179 Metetra
.533 .318 .534 r
.69661 .13179 .69934 .16312 .70453 .13066 .70355 .12924 Metetra
.664 .741 .907 r
.70355 .12924 .70453 .13066 .71149 .12811 .71052 .12668 Metetra
.664 .741 .907 r
.71052 .12668 .71149 .12811 .71846 .12554 .71749 .12411 Metetra
.664 .741 .907 r
.71749 .12411 .71846 .12554 .72546 .12297 .72449 .12154 Metetra
.664 .741 .907 r
.72449 .12154 .72546 .12297 .73246 .1204 .7315 .11896 Metetra
.664 .741 .907 r
.7315 .11896 .73246 .1204 .73949 .11782 .73853 .11637 Metetra
.664 .741 .907 r
.73853 .11637 .73949 .11782 .74653 .11523 .74557 .11378 Metetra
.664 .741 .907 r
.74557 .11378 .74653 .11523 .75359 .11263 .75264 .11118 Metetra
.664 .741 .907 r
.75264 .11118 .75359 .11263 .76067 .11003 .75972 .10858 Metetra
.664 .741 .907 r
.12749 .3395 .12872 .34065 .13435 .33859 .13311 .33743 Metetra
.664 .741 .907 r
.13311 .33743 .13435 .33859 .13998 .33651 .13875 .33536 Metetra
.664 .741 .907 r
.13875 .33536 .13998 .33651 .14563 .33444 .1444 .33328 Metetra
.664 .741 .907 r
.1444 .33328 .14563 .33444 .15129 .33235 .15006 .33119 Metetra
.664 .741 .907 r
.15006 .33119 .15129 .33235 .15696 .33027 .15573 .3291 Metetra
.664 .741 .907 r
.15573 .3291 .15696 .33027 .16264 .32818 .16142 .32701 Metetra
.664 .741 .907 r
.16142 .32701 .16264 .32818 .16834 .32608 .16712 .32491 Metetra
.664 .741 .907 r
.16712 .32491 .16834 .32608 .17405 .32398 .17283 .32281 Metetra
.664 .741 .907 r
.17283 .32281 .17405 .32398 .17977 .32188 .17856 .3207 Metetra
.664 .741 .907 r
.17856 .3207 .17977 .32188 .18551 .31977 .18429 .31859 Metetra
.664 .741 .907 r
.18429 .31859 .18551 .31977 .19125 .31766 .19004 .31647 Metetra
.664 .741 .907 r
.19004 .31647 .19125 .31766 .19701 .31554 .19581 .31435 Metetra
.664 .741 .907 r
.19581 .31435 .19701 .31554 .20279 .31341 .20158 .31223 Metetra
.946 .609 .35 r
.20158 .31223 .20279 .31341 .20814 .31556 .20466 .3368 Metetra
.242 .03 .378 r
.20466 .3368 .20814 .31556 .21255 .32756 .21317 .30796 Metetra
.54 .333 .548 r
.21317 .30796 .21255 .32756 .22018 .30701 .21899 .30582 Metetra
.664 .741 .907 r
.21899 .30582 .22018 .30701 .22601 .30487 .22481 .30367 Metetra
.664 .741 .907 r
.22481 .30367 .22601 .30487 .23185 .30272 .23065 .30153 Metetra
.664 .741 .907 r
.23065 .30153 .23185 .30272 .2377 .30057 .23651 .29937 Metetra
.664 .741 .907 r
.23651 .29937 .2377 .30057 .24356 .29842 .24237 .29721 Metetra
.664 .741 .907 r
.24237 .29721 .24356 .29842 .24944 .29625 .24825 .29505 Metetra
.664 .741 .907 r
.24825 .29505 .24944 .29625 .25533 .29409 .25415 .29288 Metetra
.664 .741 .907 r
.25415 .29288 .25533 .29409 .26124 .29192 .26005 .2907 Metetra
.664 .741 .907 r
.26005 .2907 .26124 .29192 .26716 .28974 .26598 .28852 Metetra
.664 .741 .907 r
.26598 .28852 .26716 .28974 .27309 .28756 .27191 .28634 Metetra
.664 .741 .907 r
.27191 .28634 .27309 .28756 .27903 .28537 .27786 .28415 Metetra
.664 .741 .907 r
.27786 .28415 .27903 .28537 .28499 .28318 .28382 .28196 Metetra
.664 .741 .907 r
.28382 .28196 .28499 .28318 .29096 .28098 .28979 .27976 Metetra
.664 .741 .907 r
.28979 .27976 .29096 .28098 .29695 .27878 .29578 .27755 Metetra
.664 .741 .907 r
.29578 .27755 .29695 .27878 .30294 .27658 .30178 .27534 Metetra
.664 .741 .907 r
.30178 .27534 .30294 .27658 .30896 .27437 .30779 .27313 Metetra
.664 .741 .907 r
.30779 .27313 .30896 .27437 .31498 .27215 .31382 .27091 Metetra
.664 .741 .907 r
.31382 .27091 .31498 .27215 .32102 .26993 .31987 .26869 Metetra
.664 .741 .907 r
.31987 .26869 .32102 .26993 .32708 .2677 .32592 .26646 Metetra
.664 .741 .907 r
.32592 .26646 .32708 .2677 .33314 .26547 .33199 .26422 Metetra
.664 .741 .907 r
.33199 .26422 .33314 .26547 .33923 .26323 .33808 .26198 Metetra
.664 .741 .907 r
.33808 .26198 .33923 .26323 .34532 .26099 .34417 .25974 Metetra
.664 .741 .907 r
.34417 .25974 .34532 .26099 .35143 .25874 .35029 .25749 Metetra
.56 .074 0 r
.35029 .25749 .35143 .25874 .35285 .34306 .35593 .26403 Metetra
.364 .173 .482 r
.35593 .26403 .35285 .34306 .3541 .43739 .35801 .33907 Metetra
.625 .382 .529 r
.35801 .33907 .3541 .43739 .36984 .25197 .36871 .25071 Metetra
.664 .741 .907 r
.36871 .25071 .36984 .25197 .37601 .2497 .37487 .24844 Metetra
.664 .741 .907 r
.37487 .24844 .37601 .2497 .38219 .24743 .38106 .24616 Metetra
.664 .741 .907 r
.38106 .24616 .38219 .24743 .38838 .24515 .38725 .24388 Metetra
.664 .741 .907 r
.38725 .24388 .38838 .24515 .39459 .24287 .39347 .24159 Metetra
.664 .741 .907 r
.39347 .24159 .39459 .24287 .40082 .24058 .39969 .2393 Metetra
.664 .741 .907 r
.39969 .2393 .40082 .24058 .40705 .23829 .40593 .237 Metetra
.664 .741 .907 r
.40593 .237 .40705 .23829 .41331 .23599 .41219 .2347 Metetra
.664 .741 .907 r
.41219 .2347 .41331 .23599 .41957 .23368 .41846 .23239 Metetra
.664 .741 .907 r
.41846 .23239 .41957 .23368 .42585 .23137 .42474 .23008 Metetra
.664 .741 .907 r
.42474 .23008 .42585 .23137 .43215 .22906 .43104 .22776 Metetra
.664 .741 .907 r
.43104 .22776 .43215 .22906 .43846 .22674 .43735 .22544 Metetra
.664 .741 .907 r
.43735 .22544 .43846 .22674 .44479 .22441 .44368 .22311 Metetra
.664 .741 .907 r
.44368 .22311 .44479 .22441 .45113 .22208 .45002 .22077 Metetra
.664 .741 .907 r
.45002 .22077 .45113 .22208 .45748 .21974 .45638 .21843 Metetra
.664 .741 .907 r
.45638 .21843 .45748 .21974 .46385 .2174 .46275 .21609 Metetra
.664 .741 .907 r
.46275 .21609 .46385 .2174 .47024 .21505 .46914 .21374 Metetra
.664 .741 .907 r
.46914 .21374 .47024 .21505 .47664 .21269 .47555 .21138 Metetra
.664 .741 .907 r
.47555 .21138 .47664 .21269 .48305 .21034 .48196 .20902 Metetra
.664 .741 .907 r
.48196 .20902 .48305 .21034 .48948 .20797 .4884 .20665 Metetra
.664 .741 .907 r
.4884 .20665 .48948 .20797 .49593 .2056 .49484 .20428 Metetra
.664 .741 .907 r
.49484 .20428 .49593 .2056 .50239 .20322 .50131 .2019 Metetra
.664 .741 .907 r
.50131 .2019 .50239 .20322 .50886 .20084 .50779 .19951 Metetra
.664 .741 .907 r
.50779 .19951 .50886 .20084 .51535 .19846 .51428 .19712 Metetra
.664 .741 .907 r
.51428 .19712 .51535 .19846 .52186 .19606 .52079 .19472 Metetra
.664 .741 .907 r
.52079 .19472 .52186 .19606 .52838 .19366 .52731 .19232 Metetra
.664 .741 .907 r
.52731 .19232 .52838 .19366 .53492 .19126 .53386 .18992 Metetra
.664 .741 .907 r
.53386 .18992 .53492 .19126 .54147 .18885 .54041 .1875 Metetra
.664 .741 .907 r
.54041 .1875 .54147 .18885 .54804 .18643 .54698 .18508 Metetra
.664 .741 .907 r
.54698 .18508 .54804 .18643 .55462 .18401 .55357 .18266 Metetra
.664 .741 .907 r
.55357 .18266 .55462 .18401 .56122 .18158 .56017 .18023 Metetra
.664 .741 .907 r
.56017 .18023 .56122 .18158 .56784 .17915 .56679 .17779 Metetra
.664 .741 .907 r
.56679 .17779 .56784 .17915 .57447 .17671 .57343 .17535 Metetra
.664 .741 .907 r
.57343 .17535 .57447 .17671 .58112 .17427 .58008 .1729 Metetra
.664 .741 .907 r
.58008 .1729 .58112 .17427 .58778 .17182 .58674 .17045 Metetra
.664 .741 .907 r
.58674 .17045 .58778 .17182 .59446 .16936 .59343 .16799 Metetra
.664 .741 .907 r
.59343 .16799 .59446 .16936 .60116 .1669 .60013 .16552 Metetra
.664 .741 .907 r
.60013 .16552 .60116 .1669 .60787 .16443 .60684 .16305 Metetra
.664 .741 .907 r
.60684 .16305 .60787 .16443 .6146 .16195 .61357 .16057 Metetra
.664 .741 .907 r
.61357 .16057 .6146 .16195 .62134 .15947 .62032 .15809 Metetra
.664 .741 .907 r
.62032 .15809 .62134 .15947 .6281 .15699 .62708 .1556 Metetra
.664 .741 .907 r
.62708 .1556 .6281 .15699 .63488 .1545 .63386 .1531 Metetra
.664 .741 .907 r
.63386 .1531 .63488 .1545 .64167 .152 .64066 .1506 Metetra
.664 .741 .907 r
.64066 .1506 .64167 .152 .64848 .14949 .64747 .14809 Metetra
.664 .741 .907 r
.64747 .14809 .64848 .14949 .6553 .14698 .6543 .14558 Metetra
.664 .741 .907 r
.6543 .14558 .6553 .14698 .66215 .14447 .66115 .14306 Metetra
.664 .741 .907 r
.66115 .14306 .66215 .14447 .66901 .14194 .66801 .14053 Metetra
.664 .741 .907 r
.66801 .14053 .66901 .14194 .67588 .13941 .67489 .138 Metetra
.664 .741 .907 r
.67489 .138 .67588 .13941 .68278 .13688 .68178 .13546 Metetra
.664 .741 .907 r
.68178 .13546 .68278 .13688 .68968 .13434 .6887 .13292 Metetra
.664 .741 .907 r
.6887 .13292 .68968 .13434 .69661 .13179 .69563 .13037 Metetra
.664 .741 .907 r
.69563 .13037 .69661 .13179 .70355 .12924 .70257 .12781 Metetra
.664 .741 .907 r
.70257 .12781 .70355 .12924 .71052 .12668 .70954 .12525 Metetra
.664 .741 .907 r
.70954 .12525 .71052 .12668 .71749 .12411 .71652 .12268 Metetra
.664 .741 .907 r
.71652 .12268 .71749 .12411 .72449 .12154 .72352 .1201 Metetra
.664 .741 .907 r
.72352 .1201 .72449 .12154 .7315 .11896 .73053 .11752 Metetra
.664 .741 .907 r
.73053 .11752 .7315 .11896 .73853 .11637 .73757 .11493 Metetra
.664 .741 .907 r
.73757 .11493 .73853 .11637 .74557 .11378 .74462 .11233 Metetra
.664 .741 .907 r
.74462 .11233 .74557 .11378 .75264 .11118 .75168 .10973 Metetra
.664 .741 .907 r
.75168 .10973 .75264 .11118 .75972 .10858 .75877 .10712 Metetra
.664 .741 .907 r
.12625 .33835 .12749 .3395 .13311 .33743 .13188 .33627 Metetra
.664 .741 .907 r
.13188 .33627 .13311 .33743 .13875 .33536 .13752 .3342 Metetra
.664 .741 .907 r
.13752 .3342 .13875 .33536 .1444 .33328 .14317 .33211 Metetra
.664 .741 .907 r
.14317 .33211 .1444 .33328 .15006 .33119 .14883 .33003 Metetra
.664 .741 .907 r
.14883 .33003 .15006 .33119 .15573 .3291 .15451 .32794 Metetra
.664 .741 .907 r
.15451 .32794 .15573 .3291 .16142 .32701 .1602 .32584 Metetra
.664 .741 .907 r
.1602 .32584 .16142 .32701 .16712 .32491 .1659 .32374 Metetra
.664 .741 .907 r
.1659 .32374 .16712 .32491 .17283 .32281 .17161 .32164 Metetra
.664 .741 .907 r
.17161 .32164 .17283 .32281 .17856 .3207 .17734 .31953 Metetra
.664 .741 .907 r
.17734 .31953 .17856 .3207 .18429 .31859 .18308 .31741 Metetra
.664 .741 .907 r
.18308 .31741 .18429 .31859 .19004 .31647 .18883 .31529 Metetra
.664 .741 .907 r
.18883 .31529 .19004 .31647 .19581 .31435 .1946 .31317 Metetra
.664 .741 .907 r
.1946 .31317 .19581 .31435 .20158 .31223 .20037 .31104 Metetra
.53 .696 .945 r
.20037 .31104 .20158 .31223 .20466 .3368 .20601 .31047 Metetra
.543 .328 .539 r
.20601 .31047 .20466 .3368 .21317 .30796 .21197 .30677 Metetra
.664 .741 .907 r
.21197 .30677 .21317 .30796 .21899 .30582 .21778 .30462 Metetra
.664 .741 .907 r
.21778 .30462 .21899 .30582 .22481 .30367 .22361 .30248 Metetra
.664 .741 .907 r
.22361 .30248 .22481 .30367 .23065 .30153 .22946 .30032 Metetra
.664 .741 .907 r
.22946 .30032 .23065 .30153 .23651 .29937 .23531 .29817 Metetra
.664 .741 .907 r
.23531 .29817 .23651 .29937 .24237 .29721 .24118 .296 Metetra
.664 .741 .907 r
.24118 .296 .24237 .29721 .24825 .29505 .24707 .29384 Metetra
.664 .741 .907 r
.24707 .29384 .24825 .29505 .25415 .29288 .25296 .29166 Metetra
.664 .741 .907 r
.25296 .29166 .25415 .29288 .26005 .2907 .25887 .28949 Metetra
.664 .741 .907 r
.25887 .28949 .26005 .2907 .26598 .28852 .26479 .28731 Metetra
.664 .741 .907 r
.26479 .28731 .26598 .28852 .27191 .28634 .27073 .28512 Metetra
.664 .741 .907 r
.27073 .28512 .27191 .28634 .27786 .28415 .27668 .28293 Metetra
.664 .741 .907 r
.27668 .28293 .27786 .28415 .28382 .28196 .28264 .28073 Metetra
.664 .741 .907 r
.28264 .28073 .28382 .28196 .28979 .27976 .28862 .27853 Metetra
.664 .741 .907 r
.28862 .27853 .28979 .27976 .29578 .27755 .29461 .27632 Metetra
.957 .655 .418 r
.29461 .27632 .29578 .27755 .30178 .27534 .29617 .33537 Metetra
.333 .127 .443 r
.29617 .33537 .30178 .27534 .30779 .27313 .30663 .27189 Metetra
.664 .741 .907 r
.30663 .27189 .30779 .27313 .31382 .27091 .31266 .26967 Metetra
.664 .741 .907 r
.31266 .26967 .31382 .27091 .31987 .26869 .31871 .26744 Metetra
.664 .741 .907 r
.31871 .26744 .31987 .26869 .32592 .26646 .32476 .26521 Metetra
.664 .741 .907 r
.32476 .26521 .32592 .26646 .33199 .26422 .33084 .26297 Metetra
.664 .741 .907 r
.33084 .26297 .33199 .26422 .33808 .26198 .33692 .26073 Metetra
.664 .741 .907 r
.33692 .26073 .33808 .26198 .34417 .25974 .34302 .25848 Metetra
.664 .741 .907 r
.34302 .25848 .34417 .25974 .35029 .25749 .34914 .25623 Metetra
.664 .741 .907 r
.34914 .25623 .35029 .25749 .35593 .26403 .35527 .25397 Metetra
.558 .373 .587 r
.35527 .25397 .35593 .26403 .35801 .33907 .36141 .25171 Metetra
.524 .299 .515 r
.36141 .25171 .35801 .33907 .36871 .25071 .36757 .24944 Metetra
.664 .741 .907 r
.36757 .24944 .36871 .25071 .37487 .24844 .37374 .24717 Metetra
.664 .741 .907 r
.37374 .24717 .37487 .24844 .38106 .24616 .37992 .24489 Metetra
.664 .741 .907 r
.37992 .24489 .38106 .24616 .38725 .24388 .38612 .24261 Metetra
.664 .741 .907 r
.38612 .24261 .38725 .24388 .39347 .24159 .39234 .24032 Metetra
.664 .741 .907 r
.39234 .24032 .39347 .24159 .39969 .2393 .39857 .23802 Metetra
.664 .741 .907 r
.39857 .23802 .39969 .2393 .40593 .237 .40481 .23572 Metetra
.664 .741 .907 r
.40481 .23572 .40593 .237 .41219 .2347 .41107 .23342 Metetra
.664 .741 .907 r
.41107 .23342 .41219 .2347 .41846 .23239 .41734 .2311 Metetra
.664 .741 .907 r
.41734 .2311 .41846 .23239 .42474 .23008 .42363 .22879 Metetra
.664 .741 .907 r
.42363 .22879 .42474 .23008 .43104 .22776 .42993 .22647 Metetra
.664 .741 .907 r
.42993 .22647 .43104 .22776 .43735 .22544 .43624 .22414 Metetra
.664 .741 .907 r
.43624 .22414 .43735 .22544 .44368 .22311 .44258 .22181 Metetra
.664 .741 .907 r
.44258 .22181 .44368 .22311 .45002 .22077 .44892 .21947 Metetra
.664 .741 .907 r
.44892 .21947 .45002 .22077 .45638 .21843 .45528 .21713 Metetra
.664 .741 .907 r
.45528 .21713 .45638 .21843 .46275 .21609 .46166 .21478 Metetra
.664 .741 .907 r
.46166 .21478 .46275 .21609 .46914 .21374 .46805 .21242 Metetra
.664 .741 .907 r
.46805 .21242 .46914 .21374 .47555 .21138 .47445 .21006 Metetra
.664 .741 .907 r
.47445 .21006 .47555 .21138 .48196 .20902 .48087 .2077 Metetra
.664 .741 .907 r
.48087 .2077 .48196 .20902 .4884 .20665 .48731 .20533 Metetra
.664 .741 .907 r
.48731 .20533 .4884 .20665 .49484 .20428 .49376 .20295 Metetra
.664 .741 .907 r
.49376 .20295 .49484 .20428 .50131 .2019 .50023 .20057 Metetra
.664 .741 .907 r
.50023 .20057 .50131 .2019 .50779 .19951 .50671 .19818 Metetra
.664 .741 .907 r
.50671 .19818 .50779 .19951 .51428 .19712 .51321 .19579 Metetra
.664 .741 .907 r
.51321 .19579 .51428 .19712 .52079 .19472 .51972 .19339 Metetra
.664 .741 .907 r
.51972 .19339 .52079 .19472 .52731 .19232 .52625 .19098 Metetra
.664 .741 .907 r
.52625 .19098 .52731 .19232 .53386 .18992 .53279 .18857 Metetra
.664 .741 .907 r
.53279 .18857 .53386 .18992 .54041 .1875 .53935 .18615 Metetra
.664 .741 .907 r
.53935 .18615 .54041 .1875 .54698 .18508 .54592 .18373 Metetra
.664 .741 .907 r
.54592 .18373 .54698 .18508 .55357 .18266 .55252 .1813 Metetra
.664 .741 .907 r
.55252 .1813 .55357 .18266 .56017 .18023 .55912 .17887 Metetra
.664 .741 .907 r
.55912 .17887 .56017 .18023 .56679 .17779 .56574 .17643 Metetra
.664 .741 .907 r
.56574 .17643 .56679 .17779 .57343 .17535 .57238 .17398 Metetra
.664 .741 .907 r
.57238 .17398 .57343 .17535 .58008 .1729 .57903 .17153 Metetra
.664 .741 .907 r
.57903 .17153 .58008 .1729 .58674 .17045 .5857 .16908 Metetra
.664 .741 .907 r
.5857 .16908 .58674 .17045 .59343 .16799 .59239 .16661 Metetra
.664 .741 .907 r
.59239 .16661 .59343 .16799 .60013 .16552 .59909 .16414 Metetra
.664 .741 .907 r
.59909 .16414 .60013 .16552 .60684 .16305 .60581 .16167 Metetra
.664 .741 .907 r
.60581 .16167 .60684 .16305 .61357 .16057 .61254 .15919 Metetra
.664 .741 .907 r
.61254 .15919 .61357 .16057 .62032 .15809 .61929 .1567 Metetra
.664 .741 .907 r
.61929 .1567 .62032 .15809 .62708 .1556 .62606 .15421 Metetra
.664 .741 .907 r
.62606 .15421 .62708 .1556 .63386 .1531 .63285 .15171 Metetra
.664 .741 .907 r
.63285 .15171 .63386 .1531 .64066 .1506 .63964 .1492 Metetra
.664 .741 .907 r
.63964 .1492 .64066 .1506 .64747 .14809 .64646 .14669 Metetra
.664 .741 .907 r
.64646 .14669 .64747 .14809 .6543 .14558 .65329 .14417 Metetra
.664 .741 .907 r
.65329 .14417 .6543 .14558 .66115 .14306 .66014 .14165 Metetra
.664 .741 .907 r
.66014 .14165 .66115 .14306 .66801 .14053 .66701 .13912 Metetra
.664 .741 .907 r
.66701 .13912 .66801 .14053 .67489 .138 .67389 .13659 Metetra
.664 .741 .907 r
.67389 .13659 .67489 .138 .68178 .13546 .68079 .13404 Metetra
.664 .741 .907 r
.68079 .13404 .68178 .13546 .6887 .13292 .68771 .1315 Metetra
.664 .741 .907 r
.68771 .1315 .6887 .13292 .69563 .13037 .69464 .12894 Metetra
.664 .741 .907 r
.69464 .12894 .69563 .13037 .70257 .12781 .70159 .12638 Metetra
.664 .741 .907 r
.70159 .12638 .70257 .12781 .70954 .12525 .70856 .12381 Metetra
.664 .741 .907 r
.70856 .12381 .70954 .12525 .71652 .12268 .71554 .12124 Metetra
.664 .741 .907 r
.71554 .12124 .71652 .12268 .72352 .1201 .72255 .11866 Metetra
.664 .741 .907 r
.72255 .11866 .72352 .1201 .73053 .11752 .72957 .11607 Metetra
.664 .741 .907 r
.72957 .11607 .73053 .11752 .73757 .11493 .7366 .11348 Metetra
.664 .741 .907 r
.7366 .11348 .73757 .11493 .74462 .11233 .74366 .11088 Metetra
.664 .741 .907 r
.74366 .11088 .74462 .11233 .75168 .10973 .75073 .10828 Metetra
.664 .741 .907 r
.75073 .10828 .75168 .10973 .75877 .10712 .75782 .10567 Metetra
.664 .741 .907 r
.12502 .33719 .12625 .33835 .13188 .33627 .13064 .33512 Metetra
.664 .741 .907 r
.13064 .33512 .13188 .33627 .13752 .3342 .13629 .33304 Metetra
.664 .741 .907 r
.13629 .33304 .13752 .3342 .14317 .33211 .14194 .33095 Metetra
.664 .741 .907 r
.14194 .33095 .14317 .33211 .14883 .33003 .1476 .32886 Metetra
.664 .741 .907 r
.1476 .32886 .14883 .33003 .15451 .32794 .15328 .32677 Metetra
.664 .741 .907 r
.15328 .32677 .15451 .32794 .1602 .32584 .15897 .32467 Metetra
.664 .741 .907 r
.15897 .32467 .1602 .32584 .1659 .32374 .16468 .32257 Metetra
.664 .741 .907 r
.16468 .32257 .1659 .32374 .17161 .32164 .17039 .32046 Metetra
.664 .741 .907 r
.17039 .32046 .17161 .32164 .17734 .31953 .17612 .31835 Metetra
.664 .741 .907 r
.17612 .31835 .17734 .31953 .18308 .31741 .18186 .31623 Metetra
.664 .741 .907 r
.18186 .31623 .18308 .31741 .18883 .31529 .18762 .31411 Metetra
.664 .741 .907 r
.18762 .31411 .18883 .31529 .1946 .31317 .19338 .31198 Metetra
.815 .347 0 r
.19338 .31198 .1946 .31317 .20037 .31104 .19806 .3205 Metetra
.236 0 .319 r
.19806 .3205 .20037 .31104 .20601 .31047 .20496 .30771 Metetra
.625 .552 .752 r
.20496 .30771 .20601 .31047 .21197 .30677 .21076 .30557 Metetra
.664 .741 .907 r
.21076 .30557 .21197 .30677 .21778 .30462 .21658 .30343 Metetra
.664 .741 .907 r
.21658 .30343 .21778 .30462 .22361 .30248 .22241 .30128 Metetra
.664 .741 .907 r
.22241 .30128 .22361 .30248 .22946 .30032 .22826 .29912 Metetra
.664 .741 .907 r
.22826 .29912 .22946 .30032 .23531 .29817 .23412 .29696 Metetra
.664 .741 .907 r
.23412 .29696 .23531 .29817 .24118 .296 .23999 .2948 Metetra
.664 .741 .907 r
.23999 .2948 .24118 .296 .24707 .29384 .24588 .29263 Metetra
.664 .741 .907 r
.24588 .29263 .24707 .29384 .25296 .29166 .25177 .29045 Metetra
.664 .741 .907 r
.25177 .29045 .25296 .29166 .25887 .28949 .25768 .28827 Metetra
.664 .741 .907 r
.25768 .28827 .25887 .28949 .26479 .28731 .26361 .28609 Metetra
.664 .741 .907 r
.26361 .28609 .26479 .28731 .27073 .28512 .26955 .2839 Metetra
.664 .741 .907 r
.26955 .2839 .27073 .28512 .27668 .28293 .2755 .2817 Metetra
.664 .741 .907 r
.2755 .2817 .27668 .28293 .28264 .28073 .28147 .2795 Metetra
.664 .741 .907 r
.28147 .2795 .28264 .28073 .28862 .27853 .28744 .2773 Metetra
.664 .741 .907 r
.28744 .2773 .28862 .27853 .29461 .27632 .29344 .27509 Metetra
.956 .678 .468 r
.29344 .27509 .29461 .27632 .29617 .33537 .28588 .45906 Metetra
.216 .039 .414 r
.28588 .45906 .29617 .33537 .30663 .27189 .30538 .27188 Metetra
.676 .964 .934 r
.30538 .27188 .30663 .27189 .31266 .26967 .3115 .26843 Metetra
.664 .741 .907 r
.3115 .26843 .31266 .26967 .31871 .26744 .31754 .2662 Metetra
.664 .741 .907 r
.31754 .2662 .31871 .26744 .32476 .26521 .32361 .26396 Metetra
.664 .741 .907 r
.32361 .26396 .32476 .26521 .33084 .26297 .32968 .26172 Metetra
.664 .741 .907 r
.32968 .26172 .33084 .26297 .33692 .26073 .33577 .25948 Metetra
.664 .741 .907 r
.33577 .25948 .33692 .26073 .34302 .25848 .34187 .25723 Metetra
.664 .741 .907 r
.34187 .25723 .34302 .25848 .34914 .25623 .34799 .25497 Metetra
.664 .741 .907 r
.34799 .25497 .34914 .25623 .35527 .25397 .35412 .25271 Metetra
.664 .741 .907 r
.35412 .25271 .35527 .25397 .36141 .25171 .36027 .25045 Metetra
.664 .741 .907 r
.36027 .25045 .36141 .25171 .36757 .24944 .36643 .24817 Metetra
.664 .741 .907 r
.36643 .24817 .36757 .24944 .37374 .24717 .3726 .2459 Metetra
.664 .741 .907 r
.3726 .2459 .37374 .24717 .37992 .24489 .37879 .24362 Metetra
.664 .741 .907 r
.37879 .24362 .37992 .24489 .38612 .24261 .38499 .24133 Metetra
.664 .741 .907 r
.38499 .24133 .38612 .24261 .39234 .24032 .39121 .23904 Metetra
.664 .741 .907 r
.39121 .23904 .39234 .24032 .39857 .23802 .39744 .23674 Metetra
.664 .741 .907 r
.39744 .23674 .39857 .23802 .40481 .23572 .40369 .23444 Metetra
.664 .741 .907 r
.40369 .23444 .40481 .23572 .41107 .23342 .40995 .23213 Metetra
.664 .741 .907 r
.40995 .23213 .41107 .23342 .41734 .2311 .41622 .22981 Metetra
.664 .741 .907 r
.41622 .22981 .41734 .2311 .42363 .22879 .42251 .22749 Metetra
.664 .741 .907 r
.42251 .22749 .42363 .22879 .42993 .22647 .42881 .22517 Metetra
.664 .741 .907 r
.42881 .22517 .42993 .22647 .43624 .22414 .43513 .22284 Metetra
.664 .741 .907 r
.43513 .22284 .43624 .22414 .44258 .22181 .44147 .2205 Metetra
.664 .741 .907 r
.44147 .2205 .44258 .22181 .44892 .21947 .44782 .21816 Metetra
.664 .741 .907 r
.44782 .21816 .44892 .21947 .45528 .21713 .45418 .21582 Metetra
.664 .741 .907 r
.45418 .21582 .45528 .21713 .46166 .21478 .46056 .21346 Metetra
.664 .741 .907 r
.46056 .21346 .46166 .21478 .46805 .21242 .46695 .21111 Metetra
.664 .741 .907 r
.46695 .21111 .46805 .21242 .47445 .21006 .47336 .20874 Metetra
.664 .741 .907 r
.47336 .20874 .47445 .21006 .48087 .2077 .47978 .20638 Metetra
.664 .741 .907 r
.47978 .20638 .48087 .2077 .48731 .20533 .48622 .204 Metetra
.664 .741 .907 r
.48622 .204 .48731 .20533 .49376 .20295 .49268 .20162 Metetra
.664 .741 .907 r
.49268 .20162 .49376 .20295 .50023 .20057 .49915 .19924 Metetra
.664 .741 .907 r
.49915 .19924 .50023 .20057 .50671 .19818 .50563 .19684 Metetra
.664 .741 .907 r
.50563 .19684 .50671 .19818 .51321 .19579 .51213 .19445 Metetra
.664 .741 .907 r
.51213 .19445 .51321 .19579 .51972 .19339 .51865 .19205 Metetra
.664 .741 .907 r
.51865 .19205 .51972 .19339 .52625 .19098 .52518 .18964 Metetra
.664 .741 .907 r
.52518 .18964 .52625 .19098 .53279 .18857 .53172 .18722 Metetra
.664 .741 .907 r
.53172 .18722 .53279 .18857 .53935 .18615 .53829 .1848 Metetra
.664 .741 .907 r
.53829 .1848 .53935 .18615 .54592 .18373 .54486 .18238 Metetra
.968 .648 .332 r
.54486 .18238 .54592 .18373 .55252 .1813 .55224 .26782 Metetra
.362 .161 .468 r
.55224 .26782 .55252 .1813 .55912 .17887 .55807 .17751 Metetra
.664 .741 .907 r
.55807 .17751 .55912 .17887 .56574 .17643 .56469 .17507 Metetra
.664 .741 .907 r
.56469 .17507 .56574 .17643 .57238 .17398 .57133 .17262 Metetra
.664 .741 .907 r
.57133 .17262 .57238 .17398 .57903 .17153 .57799 .17016 Metetra
.664 .741 .907 r
.57799 .17016 .57903 .17153 .5857 .16908 .58466 .1677 Metetra
.664 .741 .907 r
.58466 .1677 .5857 .16908 .59239 .16661 .59135 .16524 Metetra
.664 .741 .907 r
.59135 .16524 .59239 .16661 .59909 .16414 .59806 .16276 Metetra
.664 .741 .907 r
.59806 .16276 .59909 .16414 .60581 .16167 .60478 .16029 Metetra
.664 .741 .907 r
.60478 .16029 .60581 .16167 .61254 .15919 .61152 .1578 Metetra
.664 .741 .907 r
.61152 .1578 .61254 .15919 .61929 .1567 .61827 .15531 Metetra
.664 .741 .907 r
.61827 .15531 .61929 .1567 .62606 .15421 .62504 .15281 Metetra
.664 .741 .907 r
.62504 .15281 .62606 .15421 .63285 .15171 .63183 .15031 Metetra
.664 .741 .907 r
.63183 .15031 .63285 .15171 .63964 .1492 .63863 .1478 Metetra
.664 .741 .907 r
.63863 .1478 .63964 .1492 .64646 .14669 .64545 .14529 Metetra
.664 .741 .907 r
.64545 .14529 .64646 .14669 .65329 .14417 .65229 .14277 Metetra
.664 .741 .907 r
.65229 .14277 .65329 .14417 .66014 .14165 .65914 .14024 Metetra
.664 .741 .907 r
.65914 .14024 .66014 .14165 .66701 .13912 .66601 .13771 Metetra
.664 .741 .907 r
.66601 .13771 .66701 .13912 .67389 .13659 .67289 .13517 Metetra
.664 .741 .907 r
.67289 .13517 .67389 .13659 .68079 .13404 .6798 .13262 Metetra
.664 .741 .907 r
.6798 .13262 .68079 .13404 .68771 .1315 .68672 .13007 Metetra
.664 .741 .907 r
.68672 .13007 .68771 .1315 .69464 .12894 .69366 .12751 Metetra
.664 .741 .907 r
.69366 .12751 .69464 .12894 .70159 .12638 .70061 .12495 Metetra
.664 .741 .907 r
.70061 .12495 .70159 .12638 .70856 .12381 .70758 .12238 Metetra
.664 .741 .907 r
.70758 .12238 .70856 .12381 .71554 .12124 .71457 .1198 Metetra
.664 .741 .907 r
.71457 .1198 .71554 .12124 .72255 .11866 .72157 .11722 Metetra
.664 .741 .907 r
.72157 .11722 .72255 .11866 .72957 .11607 .7286 .11463 Metetra
.664 .741 .907 r
.7286 .11463 .72957 .11607 .7366 .11348 .73564 .11203 Metetra
.664 .741 .907 r
.73564 .11203 .7366 .11348 .74366 .11088 .74269 .10943 Metetra
.664 .741 .907 r
.74269 .10943 .74366 .11088 .75073 .10828 .74977 .10682 Metetra
.664 .741 .907 r
.74977 .10682 .75073 .10828 .75782 .10567 .75686 .10421 Metetra
.664 .741 .907 r
.12378 .33603 .12502 .33719 .13064 .33512 .12941 .33396 Metetra
.664 .741 .907 r
.12941 .33396 .13064 .33512 .13629 .33304 .13505 .33187 Metetra
.664 .741 .907 r
.13505 .33187 .13629 .33304 .14194 .33095 .14071 .32979 Metetra
.664 .741 .907 r
.14071 .32979 .14194 .33095 .1476 .32886 .14637 .32769 Metetra
.664 .741 .907 r
.14637 .32769 .1476 .32886 .15328 .32677 .15205 .3256 Metetra
.664 .741 .907 r
.15205 .3256 .15328 .32677 .15897 .32467 .15775 .3235 Metetra
.664 .741 .907 r
.15775 .3235 .15897 .32467 .16468 .32257 .16345 .32139 Metetra
.664 .741 .907 r
.16345 .32139 .16468 .32257 .17039 .32046 .16917 .31928 Metetra
.664 .741 .907 r
.16917 .31928 .17039 .32046 .17612 .31835 .1749 .31717 Metetra
.664 .741 .907 r
.1749 .31717 .17612 .31835 .18186 .31623 .18065 .31505 Metetra
.664 .741 .907 r
.18065 .31505 .18186 .31623 .18762 .31411 .1864 .31292 Metetra
.664 .741 .907 r
.1864 .31292 .18762 .31411 .19338 .31198 .19217 .31079 Metetra
.664 .741 .907 r
.19217 .31079 .19338 .31198 .19806 .3205 .19795 .30866 Metetra
.552 .36 .574 r
.19795 .30866 .19806 .3205 .20496 .30771 .20375 .30652 Metetra
.664 .741 .907 r
.20375 .30652 .20496 .30771 .21076 .30557 .20956 .30438 Metetra
.664 .741 .907 r
.20956 .30438 .21076 .30557 .21658 .30343 .21538 .30223 Metetra
.664 .741 .907 r
.21538 .30223 .21658 .30343 .22241 .30128 .22121 .30007 Metetra
.664 .741 .907 r
.22121 .30007 .22241 .30128 .22826 .29912 .22706 .29792 Metetra
.664 .741 .907 r
.22706 .29792 .22826 .29912 .23412 .29696 .23292 .29575 Metetra
.664 .741 .907 r
.23292 .29575 .23412 .29696 .23999 .2948 .2388 .29359 Metetra
.664 .741 .907 r
.2388 .29359 .23999 .2948 .24588 .29263 .24468 .29141 Metetra
.664 .741 .907 r
.24468 .29141 .24588 .29263 .25177 .29045 .25058 .28924 Metetra
.664 .741 .907 r
.25058 .28924 .25177 .29045 .25768 .28827 .2565 .28705 Metetra
.664 .741 .907 r
.2565 .28705 .25768 .28827 .26361 .28609 .26243 .28487 Metetra
.664 .741 .907 r
.26243 .28487 .26361 .28609 .26955 .2839 .26837 .28267 Metetra
.664 .741 .907 r
.26837 .28267 .26955 .2839 .2755 .2817 .27432 .28048 Metetra
.664 .741 .907 r
.27432 .28048 .2755 .2817 .28147 .2795 .28029 .27827 Metetra
.378 .623 .948 r
.28029 .27827 .28147 .2795 .28744 .2773 .28605 .27891 Metetra
.942 .661 .478 r
.28605 .27891 .28744 .2773 .29344 .27509 .27962 .44217 Metetra
.562 .322 .509 r
.27962 .44217 .29344 .27509 .28588 .45906 .28116 .50525 Metetra
.82 .702 .166 r
.28116 .50525 .28588 .45906 .30538 .27188 .3043 .26941 Metetra
.634 .581 .777 r
.3043 .26941 .30538 .27188 .3115 .26843 .31033 .26719 Metetra
.664 .741 .907 r
.31033 .26719 .3115 .26843 .31754 .2662 .31638 .26495 Metetra
.664 .741 .907 r
.31638 .26495 .31754 .2662 .32361 .26396 .32245 .26272 Metetra
.664 .741 .907 r
.32245 .26272 .32361 .26396 .32968 .26172 .32852 .26047 Metetra
.664 .741 .907 r
.32852 .26047 .32968 .26172 .33577 .25948 .33462 .25822 Metetra
.664 .741 .907 r
.33462 .25822 .33577 .25948 .34187 .25723 .34072 .25597 Metetra
.664 .741 .907 r
.34072 .25597 .34187 .25723 .34799 .25497 .34684 .25371 Metetra
.664 .741 .907 r
.34684 .25371 .34799 .25497 .35412 .25271 .35297 .25145 Metetra
.664 .741 .907 r
.35297 .25145 .35412 .25271 .36027 .25045 .35912 .24918 Metetra
.664 .741 .907 r
.35912 .24918 .36027 .25045 .36643 .24817 .36529 .24691 Metetra
.664 .741 .907 r
.36529 .24691 .36643 .24817 .3726 .2459 .37146 .24463 Metetra
.664 .741 .907 r
.37146 .24463 .3726 .2459 .37879 .24362 .37765 .24234 Metetra
.664 .741 .907 r
.37765 .24234 .37879 .24362 .38499 .24133 .38386 .24005 Metetra
.664 .741 .907 r
.38386 .24005 .38499 .24133 .39121 .23904 .39008 .23776 Metetra
.664 .741 .907 r
.39008 .23776 .39121 .23904 .39744 .23674 .39631 .23545 Metetra
.664 .741 .907 r
.39631 .23545 .39744 .23674 .40369 .23444 .40256 .23315 Metetra
.664 .741 .907 r
.40256 .23315 .40369 .23444 .40995 .23213 .40882 .23084 Metetra
.664 .741 .907 r
.40882 .23084 .40995 .23213 .41622 .22981 .4151 .22852 Metetra
.664 .741 .907 r
.4151 .22852 .41622 .22981 .42251 .22749 .42139 .2262 Metetra
.664 .741 .907 r
.42139 .2262 .42251 .22749 .42881 .22517 .4277 .22387 Metetra
.664 .741 .907 r
.4277 .22387 .42881 .22517 .43513 .22284 .43402 .22154 Metetra
.664 .741 .907 r
.43402 .22154 .43513 .22284 .44147 .2205 .44036 .2192 Metetra
.664 .741 .907 r
.44036 .2192 .44147 .2205 .44782 .21816 .44671 .21685 Metetra
.664 .741 .907 r
.44671 .21685 .44782 .21816 .45418 .21582 .45308 .21451 Metetra
.664 .741 .907 r
.45308 .21451 .45418 .21582 .46056 .21346 .45946 .21215 Metetra
.664 .741 .907 r
.45946 .21215 .46056 .21346 .46695 .21111 .46585 .20979 Metetra
.664 .741 .907 r
.46585 .20979 .46695 .21111 .47336 .20874 .47227 .20742 Metetra
.664 .741 .907 r
.47227 .20742 .47336 .20874 .47978 .20638 .47869 .20505 Metetra
.664 .741 .907 r
.47869 .20505 .47978 .20638 .48622 .204 .48513 .20267 Metetra
.664 .741 .907 r
.48513 .20267 .48622 .204 .49268 .20162 .49159 .20029 Metetra
.664 .741 .907 r
.49159 .20029 .49268 .20162 .49915 .19924 .49806 .1979 Metetra
.664 .741 .907 r
.49806 .1979 .49915 .19924 .50563 .19684 .50455 .19551 Metetra
.664 .741 .907 r
.50455 .19551 .50563 .19684 .51213 .19445 .51106 .19311 Metetra
.664 .741 .907 r
.51106 .19311 .51213 .19445 .51865 .19205 .51757 .1907 Metetra
.664 .741 .907 r
.51757 .1907 .51865 .19205 .52518 .18964 .52411 .18829 Metetra
.664 .741 .907 r
.52411 .18829 .52518 .18964 .53172 .18722 .53066 .18587 Metetra
.848 .425 0 r
.53066 .18587 .53172 .18722 .53829 .1848 .5373 .20202 Metetra
.323 .102 .415 r
.5373 .20202 .53829 .1848 .54486 .18238 .5438 .18102 Metetra
.925 .546 .151 r
.5438 .18102 .54486 .18238 .55224 .26782 .55065 .20788 Metetra
.583 .347 .525 r
.55065 .20788 .55224 .26782 .55807 .17751 .55701 .17615 Metetra
.664 .741 .907 r
.55701 .17615 .55807 .17751 .56469 .17507 .56364 .1737 Metetra
.664 .741 .907 r
.56364 .1737 .56469 .17507 .57133 .17262 .57029 .17125 Metetra
.664 .741 .907 r
.57029 .17125 .57133 .17262 .57799 .17016 .57695 .16879 Metetra
.664 .741 .907 r
.57695 .16879 .57799 .17016 .58466 .1677 .58362 .16633 Metetra
.664 .741 .907 r
.58362 .16633 .58466 .1677 .59135 .16524 .59031 .16386 Metetra
.664 .741 .907 r
.59031 .16386 .59135 .16524 .59806 .16276 .59702 .16138 Metetra
.664 .741 .907 r
.59702 .16138 .59806 .16276 .60478 .16029 .60375 .1589 Metetra
.664 .741 .907 r
.60375 .1589 .60478 .16029 .61152 .1578 .61049 .15641 Metetra
.664 .741 .907 r
.61049 .15641 .61152 .1578 .61827 .15531 .61724 .15392 Metetra
.664 .741 .907 r
.61724 .15392 .61827 .15531 .62504 .15281 .62402 .15142 Metetra
.664 .741 .907 r
.62402 .15142 .62504 .15281 .63183 .15031 .63081 .14891 Metetra
.664 .741 .907 r
.63081 .14891 .63183 .15031 .63863 .1478 .63761 .1464 Metetra
.664 .741 .907 r
.63761 .1464 .63863 .1478 .64545 .14529 .64444 .14388 Metetra
.664 .741 .907 r
.64444 .14388 .64545 .14529 .65229 .14277 .65128 .14136 Metetra
.664 .741 .907 r
.65128 .14136 .65229 .14277 .65914 .14024 .65813 .13883 Metetra
.664 .741 .907 r
.65813 .13883 .65914 .14024 .66601 .13771 .66501 .13629 Metetra
.664 .741 .907 r
.66501 .13629 .66601 .13771 .67289 .13517 .6719 .13375 Metetra
.664 .741 .907 r
.6719 .13375 .67289 .13517 .6798 .13262 .6788 .1312 Metetra
.664 .741 .907 r
.6788 .1312 .6798 .13262 .68672 .13007 .68573 .12865 Metetra
.664 .741 .907 r
.68573 .12865 .68672 .13007 .69366 .12751 .69267 .12608 Metetra
.664 .741 .907 r
.69267 .12608 .69366 .12751 .70061 .12495 .69962 .12352 Metetra
.664 .741 .907 r
.69962 .12352 .70061 .12495 .70758 .12238 .7066 .12094 Metetra
.664 .741 .907 r
.7066 .12094 .70758 .12238 .71457 .1198 .71359 .11836 Metetra
.664 .741 .907 r
.71359 .11836 .71457 .1198 .72157 .11722 .7206 .11578 Metetra
.664 .741 .907 r
.7206 .11578 .72157 .11722 .7286 .11463 .72763 .11318 Metetra
.664 .741 .907 r
.72763 .11318 .7286 .11463 .73564 .11203 .73467 .11058 Metetra
.664 .741 .907 r
.73467 .11058 .73564 .11203 .74269 .10943 .74173 .10798 Metetra
.664 .741 .907 r
.74173 .10798 .74269 .10943 .74977 .10682 .74881 .10536 Metetra
.664 .741 .907 r
.74881 .10536 .74977 .10682 .75686 .10421 .75591 .10275 Metetra
.664 .741 .907 r
.12254 .33488 .12378 .33603 .12941 .33396 .12817 .33279 Metetra
.664 .741 .907 r
.12817 .33279 .12941 .33396 .13505 .33187 .13381 .33071 Metetra
.664 .741 .907 r
.13381 .33071 .13505 .33187 .14071 .32979 .13947 .32862 Metetra
.664 .741 .907 r
.13947 .32862 .14071 .32979 .14637 .32769 .14514 .32653 Metetra
.664 .741 .907 r
.14514 .32653 .14637 .32769 .15205 .3256 .15082 .32443 Metetra
.664 .741 .907 r
.15082 .32443 .15205 .3256 .15775 .3235 .15652 .32232 Metetra
.664 .741 .907 r
.15652 .32232 .15775 .3235 .16345 .32139 .16223 .32022 Metetra
.664 .741 .907 r
.16223 .32022 .16345 .32139 .16917 .31928 .16795 .3181 Metetra
.664 .741 .907 r
.16795 .3181 .16917 .31928 .1749 .31717 .17368 .31598 Metetra
.846 .391 0 r
.17368 .31598 .1749 .31717 .18065 .31505 .17818 .32517 Metetra
.238 0 .324 r
.17818 .32517 .18065 .31505 .1864 .31292 .18519 .31174 Metetra
.664 .741 .907 r
.18519 .31174 .1864 .31292 .19217 .31079 .19096 .3096 Metetra
.664 .741 .907 r
.19096 .3096 .19217 .31079 .19795 .30866 .19674 .30747 Metetra
.664 .741 .907 r
.19674 .30747 .19795 .30866 .20375 .30652 .20254 .30533 Metetra
.664 .741 .907 r
.20254 .30533 .20375 .30652 .20956 .30438 .20835 .30318 Metetra
.664 .741 .907 r
.20835 .30318 .20956 .30438 .21538 .30223 .21417 .30103 Metetra
.664 .741 .907 r
.21417 .30103 .21538 .30223 .22121 .30007 .22001 .29887 Metetra
.664 .741 .907 r
.22001 .29887 .22121 .30007 .22706 .29792 .22586 .29671 Metetra
.664 .741 .907 r
.22586 .29671 .22706 .29792 .23292 .29575 .23172 .29455 Metetra
.664 .741 .907 r
.23172 .29455 .23292 .29575 .2388 .29359 .2376 .29237 Metetra
.664 .741 .907 r
.2376 .29237 .2388 .29359 .24468 .29141 .24349 .2902 Metetra
.664 .741 .907 r
.24349 .2902 .24468 .29141 .25058 .28924 .24939 .28802 Metetra
.664 .741 .907 r
.24939 .28802 .25058 .28924 .2565 .28705 .25531 .28583 Metetra
.664 .741 .907 r
.25531 .28583 .2565 .28705 .26243 .28487 .26124 .28364 Metetra
.664 .741 .907 r
.26124 .28364 .26243 .28487 .26837 .28267 .26718 .28145 Metetra
.664 .741 .907 r
.26718 .28145 .26837 .28267 .27432 .28048 .27314 .27925 Metetra
.664 .741 .907 r
.27314 .27925 .27432 .28048 .28029 .27827 .27911 .27704 Metetra
.664 .741 .907 r
.27911 .27704 .28029 .27827 .28605 .27891 .28509 .27483 Metetra
.971 .693 .444 r
.28509 .27483 .28605 .27891 .27962 .44217 .28066 .41072 Metetra
.647 .411 .547 r
.28066 .41072 .27962 .44217 .28116 .50525 .2894 .37491 Metetra
.619 .376 .528 r
.2894 .37491 .28116 .50525 .3043 .26941 .30313 .26817 Metetra
.664 .741 .907 r
.30313 .26817 .3043 .26941 .31033 .26719 .30917 .26594 Metetra
.664 .741 .907 r
.30917 .26594 .31033 .26719 .31638 .26495 .31522 .26371 Metetra
.664 .741 .907 r
.31522 .26371 .31638 .26495 .32245 .26272 .32128 .26146 Metetra
.664 .741 .907 r
.32128 .26146 .32245 .26272 .32852 .26047 .32736 .25922 Metetra
.664 .741 .907 r
.32736 .25922 .32852 .26047 .33462 .25822 .33346 .25697 Metetra
.664 .741 .907 r
.33346 .25697 .33462 .25822 .34072 .25597 .33957 .25471 Metetra
.664 .741 .907 r
.33957 .25471 .34072 .25597 .34684 .25371 .34569 .25245 Metetra
.664 .741 .907 r
.34569 .25245 .34684 .25371 .35297 .25145 .35183 .25018 Metetra
.664 .741 .907 r
.35183 .25018 .35297 .25145 .35912 .24918 .35798 .24791 Metetra
.664 .741 .907 r
.35798 .24791 .35912 .24918 .36529 .24691 .36414 .24563 Metetra
.664 .741 .907 r
.36414 .24563 .36529 .24691 .37146 .24463 .37032 .24335 Metetra
.664 .741 .907 r
.37032 .24335 .37146 .24463 .37765 .24234 .37651 .24106 Metetra
.664 .741 .907 r
.37651 .24106 .37765 .24234 .38386 .24005 .38272 .23877 Metetra
.664 .741 .907 r
.38272 .23877 .38386 .24005 .39008 .23776 .38894 .23647 Metetra
.664 .741 .907 r
.38894 .23647 .39008 .23776 .39631 .23545 .39518 .23417 Metetra
.664 .741 .907 r
.39518 .23417 .39631 .23545 .40256 .23315 .40143 .23186 Metetra
.664 .741 .907 r
.40143 .23186 .40256 .23315 .40882 .23084 .4077 .22955 Metetra
.664 .741 .907 r
.4077 .22955 .40882 .23084 .4151 .22852 .41398 .22723 Metetra
.664 .741 .907 r
.41398 .22723 .4151 .22852 .42139 .2262 .42027 .2249 Metetra
.664 .741 .907 r
.42027 .2249 .42139 .2262 .4277 .22387 .42658 .22257 Metetra
.664 .741 .907 r
.42658 .22257 .4277 .22387 .43402 .22154 .43291 .22023 Metetra
.664 .741 .907 r
.43291 .22023 .43402 .22154 .44036 .2192 .43925 .21789 Metetra
.664 .741 .907 r
.43925 .21789 .44036 .2192 .44671 .21685 .4456 .21555 Metetra
.664 .741 .907 r
.4456 .21555 .44671 .21685 .45308 .21451 .45197 .21319 Metetra
.664 .741 .907 r
.45197 .21319 .45308 .21451 .45946 .21215 .45836 .21083 Metetra
.664 .741 .907 r
.45836 .21083 .45946 .21215 .46585 .20979 .46476 .20847 Metetra
.664 .741 .907 r
.46476 .20847 .46585 .20979 .47227 .20742 .47117 .2061 Metetra
.664 .741 .907 r
.47117 .2061 .47227 .20742 .47869 .20505 .4776 .20373 Metetra
.664 .741 .907 r
.4776 .20373 .47869 .20505 .48513 .20267 .48404 .20135 Metetra
.664 .741 .907 r
.48404 .20135 .48513 .20267 .49159 .20029 .4905 .19896 Metetra
.664 .741 .907 r
.4905 .19896 .49159 .20029 .49806 .1979 .49698 .19657 Metetra
.664 .741 .907 r
.49698 .19657 .49806 .1979 .50455 .19551 .50347 .19417 Metetra
.664 .741 .907 r
.50347 .19417 .50455 .19551 .51106 .19311 .50998 .19177 Metetra
.664 .741 .907 r
.50998 .19177 .51106 .19311 .51757 .1907 .5165 .18936 Metetra
.664 .741 .907 r
.5165 .18936 .51757 .1907 .52411 .18829 .52304 .18694 Metetra
.664 .741 .907 r
.52304 .18694 .52411 .18829 .53066 .18587 .52959 .18452 Metetra
.664 .741 .907 r
.52959 .18452 .53066 .18587 .5373 .20202 .53616 .1821 Metetra
.385 .218 .528 r
.53616 .1821 .5373 .20202 .5438 .18102 .54287 .20054 Metetra
.329 .11 .423 r
.54287 .20054 .5438 .18102 .55065 .20788 .54934 .17723 Metetra
.532 .317 .533 r
.54934 .17723 .55065 .20788 .55701 .17615 .55596 .17478 Metetra
.664 .741 .907 r
.55596 .17478 .55701 .17615 .56364 .1737 .56259 .17233 Metetra
.664 .741 .907 r
.56259 .17233 .56364 .1737 .57029 .17125 .56924 .16988 Metetra
.664 .741 .907 r
.56924 .16988 .57029 .17125 .57695 .16879 .5759 .16742 Metetra
.664 .741 .907 r
.5759 .16742 .57695 .16879 .58362 .16633 .58258 .16495 Metetra
.664 .741 .907 r
.58258 .16495 .58362 .16633 .59031 .16386 .58927 .16248 Metetra
.664 .741 .907 r
.58927 .16248 .59031 .16386 .59702 .16138 .59599 .16 Metetra
.664 .741 .907 r
.59599 .16 .59702 .16138 .60375 .1589 .60271 .15751 Metetra
.664 .741 .907 r
.60271 .15751 .60375 .1589 .61049 .15641 .60946 .15502 Metetra
.664 .741 .907 r
.60946 .15502 .61049 .15641 .61724 .15392 .61622 .15253 Metetra
.664 .741 .907 r
.61622 .15253 .61724 .15392 .62402 .15142 .62299 .15002 Metetra
.664 .741 .907 r
.62299 .15002 .62402 .15142 .63081 .14891 .62979 .14751 Metetra
.664 .741 .907 r
.62979 .14751 .63081 .14891 .63761 .1464 .6366 .145 Metetra
.664 .741 .907 r
.6366 .145 .63761 .1464 .64444 .14388 .64342 .14248 Metetra
.664 .741 .907 r
.64342 .14248 .64444 .14388 .65128 .14136 .65027 .13995 Metetra
.664 .741 .907 r
.65027 .13995 .65128 .14136 .65813 .13883 .65713 .13742 Metetra
.664 .741 .907 r
.65713 .13742 .65813 .13883 .66501 .13629 .664 .13488 Metetra
.664 .741 .907 r
.664 .13488 .66501 .13629 .6719 .13375 .6709 .13233 Metetra
.664 .741 .907 r
.6709 .13233 .6719 .13375 .6788 .1312 .67781 .12978 Metetra
.664 .741 .907 r
.67781 .12978 .6788 .1312 .68573 .12865 .68473 .12722 Metetra
.664 .741 .907 r
.68473 .12722 .68573 .12865 .69267 .12608 .69168 .12465 Metetra
.664 .741 .907 r
.69168 .12465 .69267 .12608 .69962 .12352 .69864 .12208 Metetra
.664 .741 .907 r
.69864 .12208 .69962 .12352 .7066 .12094 .70562 .1195 Metetra
.664 .741 .907 r
.70562 .1195 .7066 .12094 .71359 .11836 .71261 .11692 Metetra
.664 .741 .907 r
.71261 .11692 .71359 .11836 .7206 .11578 .71962 .11433 Metetra
.664 .741 .907 r
.71962 .11433 .7206 .11578 .72763 .11318 .72665 .11173 Metetra
.664 .741 .907 r
.72665 .11173 .72763 .11318 .73467 .11058 .7337 .10913 Metetra
.664 .741 .907 r
.7337 .10913 .73467 .11058 .74173 .10798 .74077 .10652 Metetra
.664 .741 .907 r
.74077 .10652 .74173 .10798 .74881 .10536 .74785 .10391 Metetra
.664 .741 .907 r
.74785 .10391 .74881 .10536 .75591 .10275 .75495 .10128 Metetra
.664 .741 .907 r
.1213 .33372 .12254 .33488 .12817 .33279 .12693 .33163 Metetra
.664 .741 .907 r
.12693 .33163 .12817 .33279 .13381 .33071 .13258 .32954 Metetra
.664 .741 .907 r
.13258 .32954 .13381 .33071 .13947 .32862 .13824 .32745 Metetra
.664 .741 .907 r
.13824 .32745 .13947 .32862 .14514 .32653 .14391 .32536 Metetra
.664 .741 .907 r
.14391 .32536 .14514 .32653 .15082 .32443 .14959 .32325 Metetra
.664 .741 .907 r
.14959 .32325 .15082 .32443 .15652 .32232 .15529 .32115 Metetra
.664 .741 .907 r
.15529 .32115 .15652 .32232 .16223 .32022 .161 .31904 Metetra
.664 .741 .907 r
.161 .31904 .16223 .32022 .16795 .3181 .16672 .31692 Metetra
.917 .519 .197 r
.16672 .31692 .16795 .3181 .17368 .31598 .17071 .33037 Metetra
.442 .185 .427 r
.17071 .33037 .17368 .31598 .17818 .32517 .17692 .32431 Metetra
.906 .77 .7 r
.17692 .32431 .17818 .32517 .18519 .31174 .18397 .31055 Metetra
.664 .741 .907 r
.18397 .31055 .18519 .31174 .19096 .3096 .18974 .30841 Metetra
.664 .741 .907 r
.18974 .30841 .19096 .3096 .19674 .30747 .19553 .30627 Metetra
.664 .741 .907 r
.19553 .30627 .19674 .30747 .20254 .30533 .20133 .30413 Metetra
.664 .741 .907 r
.20133 .30413 .20254 .30533 .20835 .30318 .20714 .30198 Metetra
.664 .741 .907 r
.20714 .30198 .20835 .30318 .21417 .30103 .21297 .29983 Metetra
.664 .741 .907 r
.21297 .29983 .21417 .30103 .22001 .29887 .21881 .29767 Metetra
.664 .741 .907 r
.21881 .29767 .22001 .29887 .22586 .29671 .22466 .2955 Metetra
.664 .741 .907 r
.22466 .2955 .22586 .29671 .23172 .29455 .23052 .29334 Metetra
.664 .741 .907 r
.23052 .29334 .23172 .29455 .2376 .29237 .2364 .29116 Metetra
.664 .741 .907 r
.2364 .29116 .2376 .29237 .24349 .2902 .24229 .28898 Metetra
.664 .741 .907 r
.24229 .28898 .24349 .2902 .24939 .28802 .2482 .2868 Metetra
.664 .741 .907 r
.2482 .2868 .24939 .28802 .25531 .28583 .25412 .28461 Metetra
.664 .741 .907 r
.25412 .28461 .25531 .28583 .26124 .28364 .26005 .28242 Metetra
.664 .741 .907 r
.26005 .28242 .26124 .28364 .26718 .28145 .266 .28022 Metetra
.664 .741 .907 r
.266 .28022 .26718 .28145 .27314 .27925 .27196 .27802 Metetra
.664 .741 .907 r
.27196 .27802 .27314 .27925 .27911 .27704 .27793 .27581 Metetra
.664 .741 .907 r
.27793 .27581 .27911 .27704 .28509 .27483 .28391 .2736 Metetra
.957 .65 .409 r
.28391 .2736 .28509 .27483 .28066 .41072 .28585 .32488 Metetra
.539 .311 .518 r
.28585 .32488 .28066 .41072 .2894 .37491 .29271 .31267 Metetra
.609 .371 .532 r
.29271 .31267 .2894 .37491 .30313 .26817 .30196 .26693 Metetra
.664 .741 .907 r
.30196 .26693 .30313 .26817 .30917 .26594 .308 .26469 Metetra
.664 .741 .907 r
.308 .26469 .30917 .26594 .31522 .26371 .31405 .26246 Metetra
.664 .741 .907 r
.31405 .26246 .31522 .26371 .32128 .26146 .32012 .26021 Metetra
.664 .741 .907 r
.32012 .26021 .32128 .26146 .32736 .25922 .3262 .25796 Metetra
.664 .741 .907 r
.3262 .25796 .32736 .25922 .33346 .25697 .3323 .25571 Metetra
.664 .741 .907 r
.3323 .25571 .33346 .25697 .33957 .25471 .33841 .25345 Metetra
.664 .741 .907 r
.33841 .25345 .33957 .25471 .34569 .25245 .34454 .25119 Metetra
.664 .741 .907 r
.34454 .25119 .34569 .25245 .35183 .25018 .35068 .24892 Metetra
.664 .741 .907 r
.35068 .24892 .35183 .25018 .35798 .24791 .35683 .24664 Metetra
.664 .741 .907 r
.35683 .24664 .35798 .24791 .36414 .24563 .363 .24436 Metetra
.664 .741 .907 r
.363 .24436 .36414 .24563 .37032 .24335 .36918 .24208 Metetra
.664 .741 .907 r
.36918 .24208 .37032 .24335 .37651 .24106 .37538 .23979 Metetra
.664 .741 .907 r
.37538 .23979 .37651 .24106 .38272 .23877 .38159 .23749 Metetra
.664 .741 .907 r
.38159 .23749 .38272 .23877 .38894 .23647 .38781 .23519 Metetra
.664 .741 .907 r
.38781 .23519 .38894 .23647 .39518 .23417 .39405 .23288 Metetra
.602 .719 .927 r
.39405 .23288 .39518 .23417 .40143 .23186 .40027 .23145 Metetra
.701 .923 .967 r
.40027 .23145 .40143 .23186 .4077 .22955 .40657 .22825 Metetra
.664 .741 .907 r
.40657 .22825 .4077 .22955 .41398 .22723 .41286 .22593 Metetra
.664 .741 .907 r
.41286 .22593 .41398 .22723 .42027 .2249 .41915 .2236 Metetra
.664 .741 .907 r
.41915 .2236 .42027 .2249 .42658 .22257 .42547 .22127 Metetra
.664 .741 .907 r
.42547 .22127 .42658 .22257 .43291 .22023 .43179 .21893 Metetra
.664 .741 .907 r
.43179 .21893 .43291 .22023 .43925 .21789 .43814 .21658 Metetra
.664 .741 .907 r
.43814 .21658 .43925 .21789 .4456 .21555 .44449 .21423 Metetra
.664 .741 .907 r
.44449 .21423 .4456 .21555 .45197 .21319 .45087 .21188 Metetra
.664 .741 .907 r
.45087 .21188 .45197 .21319 .45836 .21083 .45725 .20952 Metetra
.664 .741 .907 r
.45725 .20952 .45836 .21083 .46476 .20847 .46366 .20715 Metetra
.664 .741 .907 r
.46366 .20715 .46476 .20847 .47117 .2061 .47007 .20478 Metetra
.664 .741 .907 r
.47007 .20478 .47117 .2061 .4776 .20373 .47651 .2024 Metetra
.664 .741 .907 r
.47651 .2024 .4776 .20373 .48404 .20135 .48295 .20002 Metetra
.664 .741 .907 r
.48295 .20002 .48404 .20135 .4905 .19896 .48942 .19763 Metetra
.664 .741 .907 r
.48942 .19763 .4905 .19896 .49698 .19657 .49589 .19523 Metetra
.664 .741 .907 r
.49589 .19523 .49698 .19657 .50347 .19417 .50239 .19283 Metetra
.664 .741 .907 r
.50239 .19283 .50347 .19417 .50998 .19177 .5089 .19042 Metetra
.664 .741 .907 r
.5089 .19042 .50998 .19177 .5165 .18936 .51542 .18801 Metetra
.664 .741 .907 r
.51542 .18801 .5165 .18936 .52304 .18694 .52196 .18559 Metetra
.664 .741 .907 r
.52196 .18559 .52304 .18694 .52959 .18452 .52852 .18317 Metetra
.664 .741 .907 r
.52852 .18317 .52959 .18452 .53616 .1821 .53509 .18074 Metetra
.664 .741 .907 r
.53509 .18074 .53616 .1821 .54287 .20054 .54168 .17831 Metetra
.537 .327 .543 r
.54168 .17831 .54287 .20054 .54934 .17723 .54828 .17587 Metetra
.664 .741 .907 r
.54828 .17587 .54934 .17723 .55596 .17478 .5549 .17342 Metetra
.664 .741 .907 r
.5549 .17342 .55596 .17478 .56259 .17233 .56153 .17097 Metetra
.664 .741 .907 r
.56153 .17097 .56259 .17233 .56924 .16988 .56818 .16851 Metetra
.664 .741 .907 r
.56818 .16851 .56924 .16988 .5759 .16742 .57485 .16604 Metetra
.664 .741 .907 r
.57485 .16604 .5759 .16742 .58258 .16495 .58153 .16357 Metetra
.664 .741 .907 r
.58153 .16357 .58258 .16495 .58927 .16248 .58823 .1611 Metetra
.664 .741 .907 r
.58823 .1611 .58927 .16248 .59599 .16 .59495 .15861 Metetra
.664 .741 .907 r
.59495 .15861 .59599 .16 .60271 .15751 .60168 .15613 Metetra
.664 .741 .907 r
.60168 .15613 .60271 .15751 .60946 .15502 .60843 .15363 Metetra
.664 .741 .907 r
.60843 .15363 .60946 .15502 .61622 .15253 .61519 .15113 Metetra
.664 .741 .907 r
.61519 .15113 .61622 .15253 .62299 .15002 .62197 .14862 Metetra
.664 .741 .907 r
.62197 .14862 .62299 .15002 .62979 .14751 .62877 .14611 Metetra
.664 .741 .907 r
.62877 .14611 .62979 .14751 .6366 .145 .63558 .14359 Metetra
.664 .741 .907 r
.63558 .14359 .6366 .145 .64342 .14248 .64241 .14107 Metetra
.664 .741 .907 r
.64241 .14107 .64342 .14248 .65027 .13995 .64926 .13854 Metetra
.664 .741 .907 r
.64926 .13854 .65027 .13995 .65713 .13742 .65612 .136 Metetra
.664 .741 .907 r
.65612 .136 .65713 .13742 .664 .13488 .663 .13346 Metetra
.664 .741 .907 r
.663 .13346 .664 .13488 .6709 .13233 .66989 .13091 Metetra
.664 .741 .907 r
.66989 .13091 .6709 .13233 .67781 .12978 .67681 .12835 Metetra
.664 .741 .907 r
.67681 .12835 .67781 .12978 .68473 .12722 .68374 .12579 Metetra
.664 .741 .907 r
.68374 .12579 .68473 .12722 .69168 .12465 .69069 .12322 Metetra
.664 .741 .907 r
.69069 .12322 .69168 .12465 .69864 .12208 .69765 .12065 Metetra
.664 .741 .907 r
.69765 .12065 .69864 .12208 .70562 .1195 .70463 .11806 Metetra
.664 .741 .907 r
.70463 .11806 .70562 .1195 .71261 .11692 .71163 .11548 Metetra
.664 .741 .907 r
.71163 .11548 .71261 .11692 .71962 .11433 .71865 .11288 Metetra
.664 .741 .907 r
.71865 .11288 .71962 .11433 .72665 .11173 .72568 .11028 Metetra
.664 .741 .907 r
.72568 .11028 .72665 .11173 .7337 .10913 .73273 .10768 Metetra
.664 .741 .907 r
.73273 .10768 .7337 .10913 .74077 .10652 .7398 .10506 Metetra
.664 .741 .907 r
.7398 .10506 .74077 .10652 .74785 .10391 .74689 .10244 Metetra
.664 .741 .907 r
.74689 .10244 .74785 .10391 .75495 .10128 .75399 .09982 Metetra
.664 .741 .907 r
.12005 .33255 .1213 .33372 .12693 .33163 .12569 .33047 Metetra
.664 .741 .907 r
.12569 .33047 .12693 .33163 .13258 .32954 .13134 .32838 Metetra
.664 .741 .907 r
.13134 .32838 .13258 .32954 .13824 .32745 .137 .32628 Metetra
.664 .741 .907 r
.137 .32628 .13824 .32745 .14391 .32536 .14267 .32418 Metetra
.664 .741 .907 r
.14267 .32418 .14391 .32536 .14959 .32325 .14836 .32208 Metetra
.664 .741 .907 r
.14836 .32208 .14959 .32325 .15529 .32115 .15406 .31997 Metetra
.664 .741 .907 r
.15406 .31997 .15529 .32115 .161 .31904 .15977 .31786 Metetra
.664 .741 .907 r
.15977 .31786 .161 .31904 .16672 .31692 .1655 .31574 Metetra
.947 .623 .385 r
.1655 .31574 .16672 .31692 .17071 .33037 .16784 .34371 Metetra
0 0 .176 r
.16784 .34371 .17071 .33037 .17692 .32431 .17698 .31149 Metetra
.549 .353 .568 r
.17698 .31149 .17692 .32431 .18397 .31055 .18275 .30936 Metetra
.664 .741 .907 r
.18275 .30936 .18397 .31055 .18974 .30841 .18852 .30722 Metetra
.664 .741 .907 r
.18852 .30722 .18974 .30841 .19553 .30627 .19431 .30508 Metetra
.664 .741 .907 r
.19431 .30508 .19553 .30627 .20133 .30413 .20012 .30293 Metetra
.664 .741 .907 r
.20012 .30293 .20133 .30413 .20714 .30198 .20593 .30078 Metetra
.664 .741 .907 r
.20593 .30078 .20714 .30198 .21297 .29983 .21176 .29862 Metetra
.664 .741 .907 r
.21176 .29862 .21297 .29983 .21881 .29767 .2176 .29646 Metetra
.664 .741 .907 r
.2176 .29646 .21881 .29767 .22466 .2955 .22345 .29429 Metetra
.664 .741 .907 r
.22345 .29429 .22466 .2955 .23052 .29334 .22932 .29212 Metetra
.664 .741 .907 r
.22932 .29212 .23052 .29334 .2364 .29116 .2352 .28995 Metetra
.664 .741 .907 r
.2352 .28995 .2364 .29116 .24229 .28898 .2411 .28777 Metetra
.664 .741 .907 r
.2411 .28777 .24229 .28898 .2482 .2868 .24701 .28558 Metetra
.664 .741 .907 r
.24701 .28558 .2482 .2868 .25412 .28461 .25293 .28339 Metetra
.664 .741 .907 r
.25293 .28339 .25412 .28461 .26005 .28242 .25886 .28119 Metetra
.664 .741 .907 r
.25886 .28119 .26005 .28242 .266 .28022 .26481 .27899 Metetra
.664 .741 .907 r
.26481 .27899 .266 .28022 .27196 .27802 .27077 .27679 Metetra
.664 .741 .907 r
.27077 .27679 .27196 .27802 .27793 .27581 .27675 .27458 Metetra
.664 .741 .907 r
.27675 .27458 .27793 .27581 .28391 .2736 .28273 .27236 Metetra
.664 .741 .907 r
.28273 .27236 .28391 .2736 .28585 .32488 .28874 .27014 Metetra
.525 .303 .52 r
.28874 .27014 .28585 .32488 .29271 .31267 .29475 .26791 Metetra
.527 .307 .523 r
.29475 .26791 .29271 .31267 .30196 .26693 .30078 .26568 Metetra
.664 .741 .907 r
.30078 .26568 .30196 .26693 .308 .26469 .30683 .26345 Metetra
.664 .741 .907 r
.30683 .26345 .308 .26469 .31405 .26246 .31288 .26121 Metetra
.664 .741 .907 r
.31288 .26121 .31405 .26246 .32012 .26021 .31896 .25896 Metetra
.664 .741 .907 r
.31896 .25896 .32012 .26021 .3262 .25796 .32504 .25671 Metetra
.664 .741 .907 r
.32504 .25671 .3262 .25796 .3323 .25571 .33114 .25445 Metetra
.664 .741 .907 r
.33114 .25445 .3323 .25571 .33841 .25345 .33725 .25219 Metetra
.664 .741 .907 r
.33725 .25219 .33841 .25345 .34454 .25119 .34338 .24992 Metetra
.664 .741 .907 r
.34338 .24992 .34454 .25119 .35068 .24892 .34952 .24765 Metetra
.664 .741 .907 r
.34952 .24765 .35068 .24892 .35683 .24664 .35568 .24537 Metetra
.664 .741 .907 r
.35568 .24537 .35683 .24664 .363 .24436 .36185 .24309 Metetra
.664 .741 .907 r
.36185 .24309 .363 .24436 .36918 .24208 .36804 .2408 Metetra
.664 .741 .907 r
.36804 .2408 .36918 .24208 .37538 .23979 .37423 .23851 Metetra
.664 .741 .907 r
.37423 .23851 .37538 .23979 .38159 .23749 .38045 .23621 Metetra
.664 .741 .907 r
.38045 .23621 .38159 .23749 .38781 .23519 .38668 .2339 Metetra
.664 .741 .907 r
.38668 .2339 .38781 .23519 .39405 .23288 .39292 .23159 Metetra
.664 .741 .907 r
.39292 .23159 .39405 .23288 .40027 .23145 .39917 .22928 Metetra
.643 .616 .808 r
.39917 .22928 .40027 .23145 .40657 .22825 .40545 .22696 Metetra
.664 .741 .907 r
.40545 .22696 .40657 .22825 .41286 .22593 .41173 .22463 Metetra
.664 .741 .907 r
.41173 .22463 .41286 .22593 .41915 .2236 .41803 .2223 Metetra
.664 .741 .907 r
.41803 .2223 .41915 .2236 .42547 .22127 .42435 .21996 Metetra
.664 .741 .907 r
.42435 .21996 .42547 .22127 .43179 .21893 .43068 .21762 Metetra
.664 .741 .907 r
.43068 .21762 .43179 .21893 .43814 .21658 .43702 .21527 Metetra
.664 .741 .907 r
.43702 .21527 .43814 .21658 .44449 .21423 .44338 .21292 Metetra
.664 .741 .907 r
.44338 .21292 .44449 .21423 .45087 .21188 .44976 .21056 Metetra
.664 .741 .907 r
.44976 .21056 .45087 .21188 .45725 .20952 .45615 .2082 Metetra
.664 .741 .907 r
.45615 .2082 .45725 .20952 .46366 .20715 .46255 .20583 Metetra
.664 .741 .907 r
.46255 .20583 .46366 .20715 .47007 .20478 .46897 .20345 Metetra
.664 .741 .907 r
.46897 .20345 .47007 .20478 .47651 .2024 .47541 .20107 Metetra
.664 .741 .907 r
.47541 .20107 .47651 .2024 .48295 .20002 .48186 .19868 Metetra
.664 .741 .907 r
.48186 .19868 .48295 .20002 .48942 .19763 .48833 .19629 Metetra
.664 .741 .907 r
.48833 .19629 .48942 .19763 .49589 .19523 .49481 .19389 Metetra
.664 .741 .907 r
.49481 .19389 .49589 .19523 .50239 .19283 .5013 .19149 Metetra
.664 .741 .907 r
.5013 .19149 .50239 .19283 .5089 .19042 .50782 .18908 Metetra
.664 .741 .907 r
.50782 .18908 .5089 .19042 .51542 .18801 .51434 .18666 Metetra
.664 .741 .907 r
.51434 .18666 .51542 .18801 .52196 .18559 .52089 .18424 Metetra
.664 .741 .907 r
.52089 .18424 .52196 .18559 .52852 .18317 .52745 .18182 Metetra
.664 .741 .907 r
.52745 .18182 .52852 .18317 .53509 .18074 .53402 .17938 Metetra
.664 .741 .907 r
.53402 .17938 .53509 .18074 .54168 .17831 .54061 .17695 Metetra
.664 .741 .907 r
.54061 .17695 .54168 .17831 .54828 .17587 .54722 .1745 Metetra
.664 .741 .907 r
.54722 .1745 .54828 .17587 .5549 .17342 .55384 .17205 Metetra
.664 .741 .907 r
.55384 .17205 .5549 .17342 .56153 .17097 .56048 .1696 Metetra
.664 .741 .907 r
.56048 .1696 .56153 .17097 .56818 .16851 .56713 .16713 Metetra
.664 .741 .907 r
.56713 .16713 .56818 .16851 .57485 .16604 .5738 .16467 Metetra
.664 .741 .907 r
.5738 .16467 .57485 .16604 .58153 .16357 .58049 .16219 Metetra
.664 .741 .907 r
.58049 .16219 .58153 .16357 .58823 .1611 .58719 .15971 Metetra
.664 .741 .907 r
.58719 .15971 .58823 .1611 .59495 .15861 .59391 .15723 Metetra
.664 .741 .907 r
.59391 .15723 .59495 .15861 .60168 .15613 .60064 .15473 Metetra
.664 .741 .907 r
.60064 .15473 .60168 .15613 .60843 .15363 .60739 .15224 Metetra
.664 .741 .907 r
.60739 .15224 .60843 .15363 .61519 .15113 .61416 .14973 Metetra
.664 .741 .907 r
.61416 .14973 .61519 .15113 .62197 .14862 .62094 .14722 Metetra
.664 .741 .907 r
.62094 .14722 .62197 .14862 .62877 .14611 .62774 .14471 Metetra
.664 .741 .907 r
.62774 .14471 .62877 .14611 .63558 .14359 .63456 .14218 Metetra
.664 .741 .907 r
.63456 .14218 .63558 .14359 .64241 .14107 .64139 .13966 Metetra
.664 .741 .907 r
.64139 .13966 .64241 .14107 .64926 .13854 .64824 .13712 Metetra
.664 .741 .907 r
.64824 .13712 .64926 .13854 .65612 .136 .65511 .13458 Metetra
.664 .741 .907 r
.65511 .13458 .65612 .136 .663 .13346 .66199 .13203 Metetra
.664 .741 .907 r
.66199 .13203 .663 .13346 .66989 .13091 .66889 .12948 Metetra
.664 .741 .907 r
.66889 .12948 .66989 .13091 .67681 .12835 .67581 .12692 Metetra
.664 .741 .907 r
.67581 .12692 .67681 .12835 .68374 .12579 .68274 .12436 Metetra
.664 .741 .907 r
.68274 .12436 .68374 .12579 .69069 .12322 .68969 .12178 Metetra
.664 .741 .907 r
.68969 .12178 .69069 .12322 .69765 .12065 .69666 .11921 Metetra
.664 .741 .907 r
.69666 .11921 .69765 .12065 .70463 .11806 .70365 .11662 Metetra
.664 .741 .907 r
.70365 .11662 .70463 .11806 .71163 .11548 .71065 .11403 Metetra
.664 .741 .907 r
.71065 .11403 .71163 .11548 .71865 .11288 .71767 .11143 Metetra
.664 .741 .907 r
.71767 .11143 .71865 .11288 .72568 .11028 .72471 .10883 Metetra
.664 .741 .907 r
.72471 .10883 .72568 .11028 .73273 .10768 .73176 .10622 Metetra
.664 .741 .907 r
.73176 .10622 .73273 .10768 .7398 .10506 .73883 .1036 Metetra
.664 .741 .907 r
.73883 .1036 .7398 .10506 .74689 .10244 .74592 .10098 Metetra
.664 .741 .907 r
.74592 .10098 .74689 .10244 .75399 .09982 .75303 .09835 Metetra
.664 .741 .907 r
.11881 .33139 .12005 .33255 .12569 .33047 .12445 .3293 Metetra
.664 .741 .907 r
.12445 .3293 .12569 .33047 .13134 .32838 .1301 .32721 Metetra
.664 .741 .907 r
.1301 .32721 .13134 .32838 .137 .32628 .13576 .32511 Metetra
.664 .741 .907 r
.13576 .32511 .137 .32628 .14267 .32418 .14144 .32301 Metetra
.664 .741 .907 r
.14144 .32301 .14267 .32418 .14836 .32208 .14713 .3209 Metetra
.664 .741 .907 r
.14713 .3209 .14836 .32208 .15406 .31997 .15283 .31879 Metetra
.664 .741 .907 r
.15283 .31879 .15406 .31997 .15977 .31786 .15854 .31668 Metetra
.664 .741 .907 r
.15854 .31668 .15977 .31786 .1655 .31574 .16427 .31456 Metetra
.084 .462 .887 r
.16427 .31456 .1655 .31574 .16784 .34371 .16953 .31663 Metetra
.554 .336 .539 r
.16953 .31663 .16784 .34371 .17698 .31149 .17576 .3103 Metetra
.664 .741 .907 r
.17576 .3103 .17698 .31149 .18275 .30936 .18153 .30817 Metetra
.664 .741 .907 r
.18153 .30817 .18275 .30936 .18852 .30722 .18731 .30603 Metetra
.664 .741 .907 r
.18731 .30603 .18852 .30722 .19431 .30508 .1931 .30388 Metetra
.664 .741 .907 r
.1931 .30388 .19431 .30508 .20012 .30293 .1989 .30173 Metetra
.664 .741 .907 r
.1989 .30173 .20012 .30293 .20593 .30078 .20472 .29958 Metetra
.664 .741 .907 r
.20472 .29958 .20593 .30078 .21176 .29862 .21055 .29742 Metetra
.664 .741 .907 r
.21055 .29742 .21176 .29862 .2176 .29646 .21639 .29525 Metetra
.664 .741 .907 r
.21639 .29525 .2176 .29646 .22345 .29429 .22225 .29308 Metetra
.664 .741 .907 r
.22225 .29308 .22345 .29429 .22932 .29212 .22812 .29091 Metetra
.664 .741 .907 r
.22812 .29091 .22932 .29212 .2352 .28995 .234 .28873 Metetra
.664 .741 .907 r
.234 .28873 .2352 .28995 .2411 .28777 .2399 .28655 Metetra
.664 .741 .907 r
.2399 .28655 .2411 .28777 .24701 .28558 .24581 .28436 Metetra
.664 .741 .907 r
.24581 .28436 .24701 .28558 .25293 .28339 .25173 .28217 Metetra
.664 .741 .907 r
.25173 .28217 .25293 .28339 .25886 .28119 .25767 .27997 Metetra
.664 .741 .907 r
.25767 .27997 .25886 .28119 .26481 .27899 .26362 .27776 Metetra
.664 .741 .907 r
.26362 .27776 .26481 .27899 .27077 .27679 .26959 .27556 Metetra
.664 .741 .907 r
.26959 .27556 .27077 .27679 .27675 .27458 .27556 .27334 Metetra
.664 .741 .907 r
.27556 .27334 .27675 .27458 .28273 .27236 .28155 .27112 Metetra
.664 .741 .907 r
.28155 .27112 .28273 .27236 .28874 .27014 .28756 .2689 Metetra
.664 .741 .907 r
.28756 .2689 .28874 .27014 .29475 .26791 .29358 .26667 Metetra
.664 .741 .907 r
.29358 .26667 .29475 .26791 .30078 .26568 .29961 .26444 Metetra
.664 .741 .907 r
.29961 .26444 .30078 .26568 .30683 .26345 .30566 .2622 Metetra
.664 .741 .907 r
.30566 .2622 .30683 .26345 .31288 .26121 .31172 .25995 Metetra
.664 .741 .907 r
.31172 .25995 .31288 .26121 .31896 .25896 .31779 .2577 Metetra
.664 .741 .907 r
.31779 .2577 .31896 .25896 .32504 .25671 .32388 .25545 Metetra
.664 .741 .907 r
.32388 .25545 .32504 .25671 .33114 .25445 .32998 .25319 Metetra
.664 .741 .907 r
.32998 .25319 .33114 .25445 .33725 .25219 .3361 .25092 Metetra
.664 .741 .907 r
.3361 .25092 .33725 .25219 .34338 .24992 .34223 .24865 Metetra
.664 .741 .907 r
.34223 .24865 .34338 .24992 .34952 .24765 .34837 .24638 Metetra
.962 .673 .44 r
.34837 .24638 .34952 .24765 .35568 .24537 .34666 .38585 Metetra
.343 .142 .457 r
.34666 .38585 .35568 .24537 .36185 .24309 .3607 .24181 Metetra
.664 .741 .907 r
.3607 .24181 .36185 .24309 .36804 .2408 .36689 .23952 Metetra
.664 .741 .907 r
.36689 .23952 .36804 .2408 .37423 .23851 .37309 .23722 Metetra
.664 .741 .907 r
.37309 .23722 .37423 .23851 .38045 .23621 .37931 .23492 Metetra
.664 .741 .907 r
.37931 .23492 .38045 .23621 .38668 .2339 .38554 .23262 Metetra
.664 .741 .907 r
.38554 .23262 .38668 .2339 .39292 .23159 .39178 .2303 Metetra
.664 .741 .907 r
.39178 .2303 .39292 .23159 .39917 .22928 .39804 .22798 Metetra
.664 .741 .907 r
.39804 .22798 .39917 .22928 .40545 .22696 .40432 .22566 Metetra
.664 .741 .907 r
.40432 .22566 .40545 .22696 .41173 .22463 .41061 .22333 Metetra
.664 .741 .907 r
.41061 .22333 .41173 .22463 .41803 .2223 .41691 .221 Metetra
.664 .741 .907 r
.41691 .221 .41803 .2223 .42435 .21996 .42323 .21866 Metetra
.664 .741 .907 r
.42323 .21866 .42435 .21996 .43068 .21762 .42956 .21631 Metetra
.664 .741 .907 r
.42956 .21631 .43068 .21762 .43702 .21527 .43591 .21396 Metetra
.664 .741 .907 r
.43591 .21396 .43702 .21527 .44338 .21292 .44227 .21161 Metetra
.664 .741 .907 r
.44227 .21161 .44338 .21292 .44976 .21056 .44865 .20924 Metetra
.664 .741 .907 r
.44865 .20924 .44976 .21056 .45615 .2082 .45504 .20688 Metetra
.664 .741 .907 r
.45504 .20688 .45615 .2082 .46255 .20583 .46145 .2045 Metetra
.664 .741 .907 r
.46145 .2045 .46255 .20583 .46897 .20345 .46787 .20212 Metetra
.664 .741 .907 r
.46787 .20212 .46897 .20345 .47541 .20107 .47431 .19974 Metetra
.664 .741 .907 r
.47431 .19974 .47541 .20107 .48186 .19868 .48077 .19735 Metetra
.664 .741 .907 r
.48077 .19735 .48186 .19868 .48833 .19629 .48724 .19495 Metetra
.664 .741 .907 r
.48724 .19495 .48833 .19629 .49481 .19389 .49372 .19255 Metetra
.664 .741 .907 r
.49372 .19255 .49481 .19389 .5013 .19149 .50022 .19015 Metetra
.664 .741 .907 r
.50022 .19015 .5013 .19149 .50782 .18908 .50673 .18773 Metetra
.664 .741 .907 r
.50673 .18773 .50782 .18908 .51434 .18666 .51327 .18532 Metetra
.664 .741 .907 r
.51327 .18532 .51434 .18666 .52089 .18424 .51981 .18289 Metetra
.664 .741 .907 r
.51981 .18289 .52089 .18424 .52745 .18182 .52637 .18046 Metetra
.664 .741 .907 r
.52637 .18046 .52745 .18182 .53402 .17938 .53295 .17802 Metetra
.664 .741 .907 r
.53295 .17802 .53402 .17938 .54061 .17695 .53954 .17558 Metetra
.664 .741 .907 r
.53954 .17558 .54061 .17695 .54722 .1745 .54615 .17314 Metetra
.664 .741 .907 r
.54615 .17314 .54722 .1745 .55384 .17205 .55278 .17068 Metetra
.664 .741 .907 r
.55278 .17068 .55384 .17205 .56048 .1696 .55942 .16822 Metetra
.664 .741 .907 r
.55942 .16822 .56048 .1696 .56713 .16713 .56608 .16576 Metetra
.664 .741 .907 r
.56608 .16576 .56713 .16713 .5738 .16467 .57275 .16329 Metetra
.664 .741 .907 r
.57275 .16329 .5738 .16467 .58049 .16219 .57944 .16081 Metetra
.664 .741 .907 r
.57944 .16081 .58049 .16219 .58719 .15971 .58614 .15833 Metetra
.664 .741 .907 r
.58614 .15833 .58719 .15971 .59391 .15723 .59287 .15584 Metetra
.664 .741 .907 r
.59287 .15584 .59391 .15723 .60064 .15473 .5996 .15334 Metetra
.664 .741 .907 r
.5996 .15334 .60064 .15473 .60739 .15224 .60636 .15084 Metetra
.664 .741 .907 r
.60636 .15084 .60739 .15224 .61416 .14973 .61313 .14833 Metetra
.664 .741 .907 r
.61313 .14833 .61416 .14973 .62094 .14722 .61991 .14582 Metetra
.664 .741 .907 r
.61991 .14582 .62094 .14722 .62774 .14471 .62672 .1433 Metetra
.664 .741 .907 r
.62672 .1433 .62774 .14471 .63456 .14218 .63354 .14078 Metetra
.664 .741 .907 r
.63354 .14078 .63456 .14218 .64139 .13966 .64037 .13824 Metetra
.664 .741 .907 r
.64037 .13824 .64139 .13966 .64824 .13712 .64723 .13571 Metetra
.664 .741 .907 r
.64723 .13571 .64824 .13712 .65511 .13458 .6541 .13316 Metetra
.664 .741 .907 r
.6541 .13316 .65511 .13458 .66199 .13203 .66098 .13061 Metetra
.664 .741 .907 r
.66098 .13061 .66199 .13203 .66889 .12948 .66789 .12805 Metetra
.664 .741 .907 r
.66789 .12805 .66889 .12948 .67581 .12692 .67481 .12549 Metetra
.853 .45 0 r
.67481 .12549 .67581 .12692 .68274 .12436 .68309 .14819 Metetra
.557 .293 .471 r
.68309 .14819 .68274 .12436 .68969 .12178 .6908 .15798 Metetra
.359 .153 .458 r
.6908 .15798 .68969 .12178 .69666 .11921 .69567 .11777 Metetra
.664 .741 .907 r
.69567 .11777 .69666 .11921 .70365 .11662 .70266 .11518 Metetra
.664 .741 .907 r
.70266 .11518 .70365 .11662 .71065 .11403 .70967 .11258 Metetra
.664 .741 .907 r
.70967 .11258 .71065 .11403 .71767 .11143 .71669 .10998 Metetra
.664 .741 .907 r
.71669 .10998 .71767 .11143 .72471 .10883 .72373 .10737 Metetra
.664 .741 .907 r
.72373 .10737 .72471 .10883 .73176 .10622 .73079 .10476 Metetra
.664 .741 .907 r
.73079 .10476 .73176 .10622 .73883 .1036 .73787 .10214 Metetra
.664 .741 .907 r
.73787 .10214 .73883 .1036 .74592 .10098 .74496 .09951 Metetra
.664 .741 .907 r
.74496 .09951 .74592 .10098 .75303 .09835 .75207 .09688 Metetra
.664 .741 .907 r
.11756 .33023 .11881 .33139 .12445 .3293 .1232 .32814 Metetra
.664 .741 .907 r
.1232 .32814 .12445 .3293 .1301 .32721 .12886 .32604 Metetra
.664 .741 .907 r
.12886 .32604 .1301 .32721 .13576 .32511 .13452 .32394 Metetra
.664 .741 .907 r
.13452 .32394 .13576 .32511 .14144 .32301 .1402 .32184 Metetra
.664 .741 .907 r
.1402 .32184 .14144 .32301 .14713 .3209 .14589 .31973 Metetra
.664 .741 .907 r
.14589 .31973 .14713 .3209 .15283 .31879 .15159 .31761 Metetra
.664 .741 .907 r
.15159 .31761 .15283 .31879 .15854 .31668 .15731 .31549 Metetra
.664 .741 .907 r
.15731 .31549 .15854 .31668 .16427 .31456 .16304 .31337 Metetra
.664 .741 .907 r
.16304 .31337 .16427 .31456 .16953 .31663 .16878 .31124 Metetra
.584 .437 .647 r
.16878 .31124 .16953 .31663 .17576 .3103 .17454 .30911 Metetra
.664 .741 .907 r
.17454 .30911 .17576 .3103 .18153 .30817 .1803 .30697 Metetra
.664 .741 .907 r
.1803 .30697 .18153 .30817 .18731 .30603 .18609 .30483 Metetra
.664 .741 .907 r
.18609 .30483 .18731 .30603 .1931 .30388 .19188 .30268 Metetra
.664 .741 .907 r
.19188 .30268 .1931 .30388 .1989 .30173 .19769 .30053 Metetra
.664 .741 .907 r
.19769 .30053 .1989 .30173 .20472 .29958 .20351 .29837 Metetra
.664 .741 .907 r
.20351 .29837 .20472 .29958 .21055 .29742 .20934 .29621 Metetra
.664 .741 .907 r
.20934 .29621 .21055 .29742 .21639 .29525 .21518 .29404 Metetra
.664 .741 .907 r
.21518 .29404 .21639 .29525 .22225 .29308 .22104 .29187 Metetra
.664 .741 .907 r
.22104 .29187 .22225 .29308 .22812 .29091 .22692 .2897 Metetra
.664 .741 .907 r
.22692 .2897 .22812 .29091 .234 .28873 .2328 .28751 Metetra
.664 .741 .907 r
.2328 .28751 .234 .28873 .2399 .28655 .2387 .28533 Metetra
.664 .741 .907 r
.2387 .28533 .2399 .28655 .24581 .28436 .24461 .28314 Metetra
.664 .741 .907 r
.24461 .28314 .24581 .28436 .25173 .28217 .25054 .28094 Metetra
.664 .741 .907 r
.25054 .28094 .25173 .28217 .25767 .27997 .25648 .27874 Metetra
.664 .741 .907 r
.25648 .27874 .25767 .27997 .26362 .27776 .26243 .27653 Metetra
.664 .741 .907 r
.26243 .27653 .26362 .27776 .26959 .27556 .2684 .27432 Metetra
.664 .741 .907 r
.2684 .27432 .26959 .27556 .27556 .27334 .27438 .2721 Metetra
.664 .741 .907 r
.27438 .2721 .27556 .27334 .28155 .27112 .28037 .26988 Metetra
.664 .741 .907 r
.28037 .26988 .28155 .27112 .28756 .2689 .28638 .26766 Metetra
.664 .741 .907 r
.28638 .26766 .28756 .2689 .29358 .26667 .2924 .26543 Metetra
.664 .741 .907 r
.2924 .26543 .29358 .26667 .29961 .26444 .29843 .26319 Metetra
.664 .741 .907 r
.29843 .26319 .29961 .26444 .30566 .2622 .30448 .26095 Metetra
.664 .741 .907 r
.30448 .26095 .30566 .2622 .31172 .25995 .31055 .2587 Metetra
.664 .741 .907 r
.31055 .2587 .31172 .25995 .31779 .2577 .31662 .25645 Metetra
.664 .741 .907 r
.31662 .25645 .31779 .2577 .32388 .25545 .32271 .25419 Metetra
.664 .741 .907 r
.32271 .25419 .32388 .25545 .32998 .25319 .32882 .25193 Metetra
.664 .741 .907 r
.32882 .25193 .32998 .25319 .3361 .25092 .33494 .24966 Metetra
.664 .741 .907 r
.33494 .24966 .3361 .25092 .34223 .24865 .34107 .24739 Metetra
.959 .64 .371 r
.34107 .24739 .34223 .24865 .34837 .24638 .34443 .29324 Metetra
.774 .498 .518 r
.34443 .29324 .34837 .24638 .34666 .38585 .34022 .47796 Metetra
0 0 .288 r
.34022 .47796 .34666 .38585 .3607 .24181 .35955 .24054 Metetra
.664 .741 .907 r
.35955 .24054 .3607 .24181 .36689 .23952 .36574 .23824 Metetra
.664 .741 .907 r
.36574 .23824 .36689 .23952 .37309 .23722 .37195 .23594 Metetra
.664 .741 .907 r
.37195 .23594 .37309 .23722 .37931 .23492 .37817 .23364 Metetra
.664 .741 .907 r
.37817 .23364 .37931 .23492 .38554 .23262 .3844 .23133 Metetra
.664 .741 .907 r
.3844 .23133 .38554 .23262 .39178 .2303 .39065 .22901 Metetra
.664 .741 .907 r
.39065 .22901 .39178 .2303 .39804 .22798 .39691 .22669 Metetra
.664 .741 .907 r
.39691 .22669 .39804 .22798 .40432 .22566 .40319 .22436 Metetra
.664 .741 .907 r
.40319 .22436 .40432 .22566 .41061 .22333 .40948 .22203 Metetra
.664 .741 .907 r
.40948 .22203 .41061 .22333 .41691 .221 .41578 .21969 Metetra
.664 .741 .907 r
.41578 .21969 .41691 .221 .42323 .21866 .42211 .21735 Metetra
.664 .741 .907 r
.42211 .21735 .42323 .21866 .42956 .21631 .42844 .215 Metetra
.664 .741 .907 r
.42844 .215 .42956 .21631 .43591 .21396 .43479 .21265 Metetra
.664 .741 .907 r
.43479 .21265 .43591 .21396 .44227 .21161 .44116 .21029 Metetra
.664 .741 .907 r
.44116 .21029 .44227 .21161 .44865 .20924 .44754 .20792 Metetra
.664 .741 .907 r
.44754 .20792 .44865 .20924 .45504 .20688 .45394 .20555 Metetra
.664 .741 .907 r
.45394 .20555 .45504 .20688 .46145 .2045 .46035 .20318 Metetra
.664 .741 .907 r
.46035 .20318 .46145 .2045 .46787 .20212 .46677 .2008 Metetra
.664 .741 .907 r
.46677 .2008 .46787 .20212 .47431 .19974 .47321 .19841 Metetra
.664 .741 .907 r
.47321 .19841 .47431 .19974 .48077 .19735 .47967 .19601 Metetra
.664 .741 .907 r
.47967 .19601 .48077 .19735 .48724 .19495 .48614 .19362 Metetra
.664 .741 .907 r
.48614 .19362 .48724 .19495 .49372 .19255 .49263 .19121 Metetra
.664 .741 .907 r
.49263 .19121 .49372 .19255 .50022 .19015 .49913 .1888 Metetra
.664 .741 .907 r
.49913 .1888 .50022 .19015 .50673 .18773 .50565 .18639 Metetra
.664 .741 .907 r
.50565 .18639 .50673 .18773 .51327 .18532 .51218 .18396 Metetra
.664 .741 .907 r
.51218 .18396 .51327 .18532 .51981 .18289 .51873 .18154 Metetra
.664 .741 .907 r
.51873 .18154 .51981 .18289 .52637 .18046 .5253 .1791 Metetra
.664 .741 .907 r
.5253 .1791 .52637 .18046 .53295 .17802 .53188 .17666 Metetra
.664 .741 .907 r
.53188 .17666 .53295 .17802 .53954 .17558 .53848 .17422 Metetra
.664 .741 .907 r
.53848 .17422 .53954 .17558 .54615 .17314 .54509 .17177 Metetra
.664 .741 .907 r
.54509 .17177 .54615 .17314 .55278 .17068 .55172 .16931 Metetra
.664 .741 .907 r
.55172 .16931 .55278 .17068 .55942 .16822 .55836 .16685 Metetra
.664 .741 .907 r
.55836 .16685 .55942 .16822 .56608 .16576 .56502 .16438 Metetra
.664 .741 .907 r
.56502 .16438 .56608 .16576 .57275 .16329 .5717 .16191 Metetra
.664 .741 .907 r
.5717 .16191 .57275 .16329 .57944 .16081 .57839 .15943 Metetra
.664 .741 .907 r
.57839 .15943 .57944 .16081 .58614 .15833 .5851 .15694 Metetra
.664 .741 .907 r
.5851 .15694 .58614 .15833 .59287 .15584 .59182 .15445 Metetra
.664 .741 .907 r
.59182 .15445 .59287 .15584 .5996 .15334 .59856 .15195 Metetra
.664 .741 .907 r
.59856 .15195 .5996 .15334 .60636 .15084 .60532 .14944 Metetra
.664 .741 .907 r
.60532 .14944 .60636 .15084 .61313 .14833 .61209 .14693 Metetra
.664 .741 .907 r
.61209 .14693 .61313 .14833 .61991 .14582 .61889 .14442 Metetra
.664 .741 .907 r
.61889 .14442 .61991 .14582 .62672 .1433 .62569 .14189 Metetra
.664 .741 .907 r
.62569 .14189 .62672 .1433 .63354 .14078 .63252 .13936 Metetra
.664 .741 .907 r
.63252 .13936 .63354 .14078 .64037 .13824 .63936 .13683 Metetra
.664 .741 .907 r
.63936 .13683 .64037 .13824 .64723 .13571 .64621 .13429 Metetra
.664 .741 .907 r
.64621 .13429 .64723 .13571 .6541 .13316 .65309 .13174 Metetra
.664 .741 .907 r
.65309 .13174 .6541 .13316 .66098 .13061 .65998 .12919 Metetra
.114 .43 .872 r
.65998 .12919 .66098 .13061 .66789 .12805 .66716 .13246 Metetra
.2 0 .234 r
.66716 .13246 .66789 .12805 .67481 .12549 .67381 .12406 Metetra
.664 .741 .907 r
.67381 .12406 .67481 .12549 .68309 .14819 .68075 .12149 Metetra
.402 .226 .524 r
.68075 .12149 .68309 .14819 .6908 .15798 .68913 .14466 Metetra
.718 .475 .557 r
.68913 .14466 .6908 .15798 .69567 .11777 .69468 .11632 Metetra
.664 .741 .907 r
.69468 .11632 .69567 .11777 .70266 .11518 .70167 .11373 Metetra
.664 .741 .907 r
.70167 .11373 .70266 .11518 .70967 .11258 .70868 .11113 Metetra
.664 .741 .907 r
.70868 .11113 .70967 .11258 .71669 .10998 .71571 .10853 Metetra
.664 .741 .907 r
.71571 .10853 .71669 .10998 .72373 .10737 .72276 .10592 Metetra
.664 .741 .907 r
.72276 .10592 .72373 .10737 .73079 .10476 .72982 .1033 Metetra
.664 .741 .907 r
.72982 .1033 .73079 .10476 .73787 .10214 .7369 .10068 Metetra
.664 .741 .907 r
.7369 .10068 .73787 .10214 .74496 .09951 .74399 .09805 Metetra
.664 .741 .907 r
.74399 .09805 .74496 .09951 .75207 .09688 .75111 .09541 Metetra
.664 .741 .907 r
.11631 .32906 .11756 .33023 .1232 .32814 .12196 .32697 Metetra
.664 .741 .907 r
.12196 .32697 .1232 .32814 .12886 .32604 .12761 .32487 Metetra
.664 .741 .907 r
.12761 .32487 .12886 .32604 .13452 .32394 .13328 .32277 Metetra
.664 .741 .907 r
.13328 .32277 .13452 .32394 .1402 .32184 .13896 .32066 Metetra
.664 .741 .907 r
.13896 .32066 .1402 .32184 .14589 .31973 .14465 .31855 Metetra
.664 .741 .907 r
.14465 .31855 .14589 .31973 .15159 .31761 .15036 .31643 Metetra
.664 .741 .907 r
.15036 .31643 .15159 .31761 .15731 .31549 .15608 .31431 Metetra
.664 .741 .907 r
.15608 .31431 .15731 .31549 .16304 .31337 .16181 .31218 Metetra
.664 .741 .907 r
.16181 .31218 .16304 .31337 .16878 .31124 .16755 .31005 Metetra
.664 .741 .907 r
.16755 .31005 .16878 .31124 .17454 .30911 .17331 .30792 Metetra
.664 .741 .907 r
.17331 .30792 .17454 .30911 .1803 .30697 .17908 .30578 Metetra
.664 .741 .907 r
.17908 .30578 .1803 .30697 .18609 .30483 .18486 .30363 Metetra
.664 .741 .907 r
.18486 .30363 .18609 .30483 .19188 .30268 .19066 .30148 Metetra
.664 .741 .907 r
.19066 .30148 .19188 .30268 .19769 .30053 .19647 .29933 Metetra
.929 .547 .236 r
.19647 .29933 .19769 .30053 .20351 .29837 .20042 .31529 Metetra
.277 .049 .377 r
.20042 .31529 .20351 .29837 .20934 .29621 .20813 .295 Metetra
.664 .741 .907 r
.20813 .295 .20934 .29621 .21518 .29404 .21397 .29283 Metetra
.664 .741 .907 r
.21397 .29283 .21518 .29404 .22104 .29187 .21984 .29066 Metetra
.664 .741 .907 r
.21984 .29066 .22104 .29187 .22692 .2897 .22571 .28848 Metetra
.664 .741 .907 r
.22571 .28848 .22692 .2897 .2328 .28751 .2316 .2863 Metetra
.664 .741 .907 r
.2316 .2863 .2328 .28751 .2387 .28533 .2375 .28411 Metetra
.664 .741 .907 r
.2375 .28411 .2387 .28533 .24461 .28314 .24341 .28191 Metetra
.664 .741 .907 r
.24341 .28191 .24461 .28314 .25054 .28094 .24934 .27971 Metetra
.664 .741 .907 r
.24934 .27971 .25054 .28094 .25648 .27874 .25528 .27751 Metetra
.664 .741 .907 r
.25528 .27751 .25648 .27874 .26243 .27653 .26124 .2753 Metetra
.664 .741 .907 r
.26124 .2753 .26243 .27653 .2684 .27432 .26721 .27309 Metetra
.664 .741 .907 r
.26721 .27309 .2684 .27432 .27438 .2721 .27319 .27087 Metetra
.664 .741 .907 r
.27319 .27087 .27438 .2721 .28037 .26988 .27919 .26864 Metetra
.664 .741 .907 r
.27919 .26864 .28037 .26988 .28638 .26766 .2852 .26641 Metetra
.664 .741 .907 r
.2852 .26641 .28638 .26766 .2924 .26543 .29122 .26418 Metetra
.664 .741 .907 r
.29122 .26418 .2924 .26543 .29843 .26319 .29726 .26194 Metetra
.664 .741 .907 r
.29726 .26194 .29843 .26319 .30448 .26095 .30331 .25969 Metetra
.664 .741 .907 r
.30331 .25969 .30448 .26095 .31055 .2587 .30937 .25744 Metetra
.664 .741 .907 r
.30937 .25744 .31055 .2587 .31662 .25645 .31545 .25519 Metetra
.664 .741 .907 r
.31545 .25519 .31662 .25645 .32271 .25419 .32155 .25293 Metetra
.664 .741 .907 r
.32155 .25293 .32271 .25419 .32882 .25193 .32765 .25066 Metetra
.664 .741 .907 r
.32765 .25066 .32882 .25193 .33494 .24966 .33378 .24839 Metetra
.664 .741 .907 r
.33378 .24839 .33494 .24966 .34107 .24739 .33991 .24612 Metetra
.961 .663 .419 r
.33991 .24612 .34107 .24739 .34443 .29324 .34117 .32763 Metetra
.732 .457 .512 r
.34117 .32763 .34443 .29324 .34022 .47796 .34201 .42278 Metetra
.776 .512 .537 r
.34201 .42278 .34022 .47796 .35955 .24054 .3584 .23926 Metetra
.664 .741 .907 r
.3584 .23926 .35955 .24054 .36574 .23824 .3646 .23696 Metetra
.664 .741 .907 r
.3646 .23696 .36574 .23824 .37195 .23594 .3708 .23466 Metetra
.664 .741 .907 r
.3708 .23466 .37195 .23594 .37817 .23364 .37702 .23235 Metetra
.664 .741 .907 r
.37702 .23235 .37817 .23364 .3844 .23133 .38326 .23004 Metetra
.664 .741 .907 r
.38326 .23004 .3844 .23133 .39065 .22901 .38951 .22772 Metetra
.664 .741 .907 r
.38951 .22772 .39065 .22901 .39691 .22669 .39578 .22539 Metetra
.664 .741 .907 r
.39578 .22539 .39691 .22669 .40319 .22436 .40205 .22306 Metetra
.664 .741 .907 r
.40205 .22306 .40319 .22436 .40948 .22203 .40835 .22073 Metetra
.664 .741 .907 r
.40835 .22073 .40948 .22203 .41578 .21969 .41466 .21839 Metetra
.664 .741 .907 r
.41466 .21839 .41578 .21969 .42211 .21735 .42098 .21604 Metetra
.664 .741 .907 r
.42098 .21604 .42211 .21735 .42844 .215 .42732 .21369 Metetra
.664 .741 .907 r
.42732 .21369 .42844 .215 .43479 .21265 .43368 .21133 Metetra
.664 .741 .907 r
.43368 .21133 .43479 .21265 .44116 .21029 .44004 .20897 Metetra
.664 .741 .907 r
.44004 .20897 .44116 .21029 .44754 .20792 .44643 .2066 Metetra
.664 .741 .907 r
.44643 .2066 .44754 .20792 .45394 .20555 .45283 .20423 Metetra
.664 .741 .907 r
.45283 .20423 .45394 .20555 .46035 .20318 .45924 .20185 Metetra
.664 .741 .907 r
.45924 .20185 .46035 .20318 .46677 .2008 .46567 .19946 Metetra
.664 .741 .907 r
.46567 .19946 .46677 .2008 .47321 .19841 .47211 .19707 Metetra
.664 .741 .907 r
.47211 .19707 .47321 .19841 .47967 .19601 .47857 .19468 Metetra
.664 .741 .907 r
.47857 .19468 .47967 .19601 .48614 .19362 .48505 .19228 Metetra
.664 .741 .907 r
.48505 .19228 .48614 .19362 .49263 .19121 .49154 .18987 Metetra
.664 .741 .907 r
.49154 .18987 .49263 .19121 .49913 .1888 .49804 .18745 Metetra
.664 .741 .907 r
.49804 .18745 .49913 .1888 .50565 .18639 .50457 .18504 Metetra
.664 .741 .907 r
.50457 .18504 .50565 .18639 .51218 .18396 .5111 .18261 Metetra
.664 .741 .907 r
.5111 .18261 .51218 .18396 .51873 .18154 .51765 .18018 Metetra
.664 .741 .907 r
.51765 .18018 .51873 .18154 .5253 .1791 .52422 .17774 Metetra
.664 .741 .907 r
.52422 .17774 .5253 .1791 .53188 .17666 .53081 .1753 Metetra
.664 .741 .907 r
.53081 .1753 .53188 .17666 .53848 .17422 .53741 .17285 Metetra
.664 .741 .907 r
.53741 .17285 .53848 .17422 .54509 .17177 .54402 .1704 Metetra
.664 .741 .907 r
.54402 .1704 .54509 .17177 .55172 .16931 .55065 .16794 Metetra
.664 .741 .907 r
.55065 .16794 .55172 .16931 .55836 .16685 .5573 .16547 Metetra
.664 .741 .907 r
.5573 .16547 .55836 .16685 .56502 .16438 .56396 .163 Metetra
.664 .741 .907 r
.56396 .163 .56502 .16438 .5717 .16191 .57064 .16052 Metetra
.664 .741 .907 r
.57064 .16052 .5717 .16191 .57839 .15943 .57734 .15804 Metetra
.664 .741 .907 r
.57734 .15804 .57839 .15943 .5851 .15694 .58405 .15555 Metetra
.664 .741 .907 r
.58405 .15555 .5851 .15694 .59182 .15445 .59078 .15305 Metetra
.664 .741 .907 r
.59078 .15305 .59182 .15445 .59856 .15195 .59752 .15055 Metetra
.664 .741 .907 r
.59752 .15055 .59856 .15195 .60532 .14944 .60428 .14804 Metetra
.664 .741 .907 r
.60428 .14804 .60532 .14944 .61209 .14693 .61106 .14553 Metetra
.664 .741 .907 r
.61106 .14553 .61209 .14693 .61889 .14442 .61785 .14301 Metetra
.664 .741 .907 r
.61785 .14301 .61889 .14442 .62569 .14189 .62466 .14048 Metetra
.664 .741 .907 r
.62466 .14048 .62569 .14189 .63252 .13936 .63149 .13795 Metetra
.664 .741 .907 r
.63149 .13795 .63252 .13936 .63936 .13683 .63833 .13541 Metetra
.664 .741 .907 r
.63833 .13541 .63936 .13683 .64621 .13429 .64519 .13287 Metetra
.664 .741 .907 r
.64519 .13287 .64621 .13429 .65309 .13174 .65207 .13032 Metetra
.664 .741 .907 r
.65207 .13032 .65309 .13174 .65998 .12919 .65897 .12776 Metetra
.212 .495 .902 r
.65897 .12776 .65998 .12919 .66716 .13246 .66612 .13022 Metetra
.756 .677 .774 r
.66612 .13022 .66716 .13246 .67381 .12406 .67289 .12432 Metetra
.528 .91 .762 r
.67289 .12432 .67381 .12406 .68075 .12149 .67975 .12005 Metetra
.664 .741 .907 r
.67975 .12005 .68075 .12149 .68913 .14466 .68671 .11747 Metetra
.533 .319 .536 r
.68671 .11747 .68913 .14466 .69468 .11632 .69369 .11488 Metetra
.664 .741 .907 r
.69369 .11488 .69468 .11632 .70167 .11373 .70068 .11228 Metetra
.664 .741 .907 r
.70068 .11228 .70167 .11373 .70868 .11113 .7077 .10968 Metetra
.664 .741 .907 r
.7077 .10968 .70868 .11113 .71571 .10853 .71473 .10707 Metetra
.664 .741 .907 r
.71473 .10707 .71571 .10853 .72276 .10592 .72178 .10446 Metetra
.664 .741 .907 r
.72178 .10446 .72276 .10592 .72982 .1033 .72884 .10184 Metetra
.664 .741 .907 r
.72884 .10184 .72982 .1033 .7369 .10068 .73593 .09921 Metetra
.664 .741 .907 r
.73593 .09921 .7369 .10068 .74399 .09805 .74303 .09658 Metetra
.664 .741 .907 r
.74303 .09658 .74399 .09805 .75111 .09541 .75015 .09393 Metetra
.664 .741 .907 r
.11506 .32789 .11631 .32906 .12196 .32697 .12071 .3258 Metetra
.664 .741 .907 r
.12071 .3258 .12196 .32697 .12761 .32487 .12637 .3237 Metetra
.664 .741 .907 r
.12637 .3237 .12761 .32487 .13328 .32277 .13204 .32159 Metetra
.664 .741 .907 r
.13204 .32159 .13328 .32277 .13896 .32066 .13772 .31948 Metetra
.664 .741 .907 r
.13772 .31948 .13896 .32066 .14465 .31855 .14341 .31737 Metetra
.664 .741 .907 r
.14341 .31737 .14465 .31855 .15036 .31643 .14912 .31525 Metetra
.664 .741 .907 r
.14912 .31525 .15036 .31643 .15608 .31431 .15484 .31313 Metetra
.664 .741 .907 r
.15484 .31313 .15608 .31431 .16181 .31218 .16058 .311 Metetra
.664 .741 .907 r
.16058 .311 .16181 .31218 .16755 .31005 .16632 .30886 Metetra
.664 .741 .907 r
.16632 .30886 .16755 .31005 .17331 .30792 .17208 .30672 Metetra
.664 .741 .907 r
.17208 .30672 .17331 .30792 .17908 .30578 .17785 .30458 Metetra
.664 .741 .907 r
.17785 .30458 .17908 .30578 .18486 .30363 .18364 .30243 Metetra
.664 .741 .907 r
.18364 .30243 .18486 .30363 .19066 .30148 .18944 .30028 Metetra
.933 .559 .258 r
.18944 .30028 .19066 .30148 .19647 .29933 .19323 .3172 Metetra
.278 .051 .379 r
.19323 .3172 .19647 .29933 .20042 .31529 .20107 .29596 Metetra
.538 .33 .547 r
.20107 .29596 .20042 .31529 .20813 .295 .20691 .29379 Metetra
.664 .741 .907 r
.20691 .29379 .20813 .295 .21397 .29283 .21276 .29162 Metetra
.664 .741 .907 r
.21276 .29162 .21397 .29283 .21984 .29066 .21863 .28944 Metetra
.664 .741 .907 r
.21863 .28944 .21984 .29066 .22571 .28848 .2245 .28726 Metetra
.664 .741 .907 r
.2245 .28726 .22571 .28848 .2316 .2863 .23039 .28508 Metetra
.664 .741 .907 r
.23039 .28508 .2316 .2863 .2375 .28411 .2363 .28288 Metetra
.664 .741 .907 r
.2363 .28288 .2375 .28411 .24341 .28191 .24221 .28069 Metetra
.664 .741 .907 r
.24221 .28069 .24341 .28191 .24934 .27971 .24814 .27848 Metetra
.664 .741 .907 r
.24814 .27848 .24934 .27971 .25528 .27751 .25409 .27628 Metetra
.664 .741 .907 r
.25409 .27628 .25528 .27751 .26124 .2753 .26005 .27407 Metetra
.664 .741 .907 r
.26005 .27407 .26124 .2753 .26721 .27309 .26602 .27185 Metetra
.664 .741 .907 r
.26602 .27185 .26721 .27309 .27319 .27087 .272 .26963 Metetra
.664 .741 .907 r
.272 .26963 .27319 .27087 .27919 .26864 .278 .2674 Metetra
.664 .741 .907 r
.278 .2674 .27919 .26864 .2852 .26641 .28401 .26517 Metetra
.664 .741 .907 r
.28401 .26517 .2852 .26641 .29122 .26418 .29004 .26293 Metetra
.664 .741 .907 r
.29004 .26293 .29122 .26418 .29726 .26194 .29608 .26069 Metetra
.664 .741 .907 r
.29608 .26069 .29726 .26194 .30331 .25969 .30213 .25844 Metetra
.664 .741 .907 r
.30213 .25844 .30331 .25969 .30937 .25744 .3082 .25619 Metetra
.664 .741 .907 r
.3082 .25619 .30937 .25744 .31545 .25519 .31428 .25393 Metetra
.664 .741 .907 r
.31428 .25393 .31545 .25519 .32155 .25293 .32038 .25167 Metetra
.664 .741 .907 r
.32038 .25167 .32155 .25293 .32765 .25066 .32649 .2494 Metetra
.664 .741 .907 r
.32649 .2494 .32765 .25066 .33378 .24839 .33261 .24712 Metetra
.664 .741 .907 r
.33261 .24712 .33378 .24839 .33991 .24612 .33875 .24484 Metetra
.664 .741 .907 r
.33875 .24484 .33991 .24612 .34117 .32763 .3449 .24256 Metetra
.316 .132 .466 r
.3449 .24256 .34117 .32763 .34201 .42278 .34537 .34068 Metetra
.656 .407 .531 r
.34537 .34068 .34201 .42278 .3584 .23926 .35725 .23798 Metetra
.664 .741 .907 r
.35725 .23798 .3584 .23926 .3646 .23696 .36345 .23568 Metetra
.664 .741 .907 r
.36345 .23568 .3646 .23696 .3708 .23466 .36966 .23337 Metetra
.664 .741 .907 r
.36966 .23337 .3708 .23466 .37702 .23235 .37588 .23106 Metetra
.664 .741 .907 r
.37588 .23106 .37702 .23235 .38326 .23004 .38212 .22874 Metetra
.664 .741 .907 r
.38212 .22874 .38326 .23004 .38951 .22772 .38837 .22642 Metetra
.664 .741 .907 r
.38837 .22642 .38951 .22772 .39578 .22539 .39464 .22409 Metetra
.664 .741 .907 r
.39464 .22409 .39578 .22539 .40205 .22306 .40092 .22176 Metetra
.664 .741 .907 r
.40092 .22176 .40205 .22306 .40835 .22073 .40722 .21942 Metetra
.664 .741 .907 r
.40722 .21942 .40835 .22073 .41466 .21839 .41353 .21708 Metetra
.664 .741 .907 r
.41353 .21708 .41466 .21839 .42098 .21604 .41986 .21473 Metetra
.664 .741 .907 r
.41986 .21473 .42098 .21604 .42732 .21369 .4262 .21238 Metetra
.664 .741 .907 r
.4262 .21238 .42732 .21369 .43368 .21133 .43256 .21002 Metetra
.664 .741 .907 r
.43256 .21002 .43368 .21133 .44004 .20897 .43893 .20765 Metetra
.664 .741 .907 r
.43893 .20765 .44004 .20897 .44643 .2066 .44531 .20528 Metetra
.664 .741 .907 r
.44531 .20528 .44643 .2066 .45283 .20423 .45172 .2029 Metetra
.664 .741 .907 r
.45172 .2029 .45283 .20423 .45924 .20185 .45813 .20052 Metetra
.664 .741 .907 r
.45813 .20052 .45924 .20185 .46567 .19946 .46456 .19813 Metetra
.664 .741 .907 r
.46456 .19813 .46567 .19946 .47211 .19707 .47101 .19574 Metetra
.664 .741 .907 r
.47101 .19574 .47211 .19707 .47857 .19468 .47747 .19334 Metetra
.664 .741 .907 r
.47747 .19334 .47857 .19468 .48505 .19228 .48395 .19093 Metetra
.664 .741 .907 r
.48395 .19093 .48505 .19228 .49154 .18987 .49045 .18852 Metetra
.664 .741 .907 r
.49045 .18852 .49154 .18987 .49804 .18745 .49695 .18611 Metetra
.664 .741 .907 r
.49695 .18611 .49804 .18745 .50457 .18504 .50348 .18368 Metetra
.664 .741 .907 r
.50348 .18368 .50457 .18504 .5111 .18261 .51002 .18126 Metetra
.664 .741 .907 r
.51002 .18126 .5111 .18261 .51765 .18018 .51657 .17882 Metetra
.664 .741 .907 r
.51657 .17882 .51765 .18018 .52422 .17774 .52315 .17638 Metetra
.664 .741 .907 r
.52315 .17638 .52422 .17774 .53081 .1753 .52973 .17394 Metetra
.664 .741 .907 r
.52973 .17394 .53081 .1753 .53741 .17285 .53634 .17148 Metetra
.664 .741 .907 r
.53634 .17148 .53741 .17285 .54402 .1704 .54295 .16903 Metetra
.664 .741 .907 r
.54295 .16903 .54402 .1704 .55065 .16794 .54959 .16656 Metetra
.664 .741 .907 r
.54959 .16656 .55065 .16794 .5573 .16547 .55624 .16409 Metetra
.664 .741 .907 r
.55624 .16409 .5573 .16547 .56396 .163 .56291 .16162 Metetra
.664 .741 .907 r
.56291 .16162 .56396 .163 .57064 .16052 .56959 .15914 Metetra
.664 .741 .907 r
.56959 .15914 .57064 .16052 .57734 .15804 .57629 .15665 Metetra
.664 .741 .907 r
.57629 .15665 .57734 .15804 .58405 .15555 .583 .15416 Metetra
.664 .741 .907 r
.583 .15416 .58405 .15555 .59078 .15305 .58973 .15166 Metetra
.664 .741 .907 r
.58973 .15166 .59078 .15305 .59752 .15055 .59648 .14915 Metetra
.664 .741 .907 r
.59648 .14915 .59752 .15055 .60428 .14804 .60324 .14664 Metetra
.664 .741 .907 r
.60324 .14664 .60428 .14804 .61106 .14553 .61003 .14412 Metetra
.664 .741 .907 r
.61003 .14412 .61106 .14553 .61785 .14301 .61682 .1416 Metetra
.664 .741 .907 r
.61682 .1416 .61785 .14301 .62466 .14048 .62364 .13907 Metetra
.664 .741 .907 r
.62364 .13907 .62466 .14048 .63149 .13795 .63047 .13654 Metetra
.664 .741 .907 r
.63047 .13654 .63149 .13795 .63833 .13541 .63731 .13399 Metetra
.664 .741 .907 r
.63731 .13399 .63833 .13541 .64519 .13287 .64418 .13145 Metetra
.664 .741 .907 r
.64418 .13145 .64519 .13287 .65207 .13032 .65106 .12889 Metetra
.664 .741 .907 r
.65106 .12889 .65207 .13032 .65897 .12776 .65795 .12633 Metetra
.664 .741 .907 r
.65795 .12633 .65897 .12776 .66612 .13022 .66487 .12376 Metetra
.577 .421 .633 r
.66487 .12376 .66612 .13022 .67289 .12432 .6718 .12119 Metetra
.623 .546 .747 r
.6718 .12119 .67289 .12432 .67975 .12005 .67875 .11861 Metetra
.664 .741 .907 r
.67875 .11861 .67975 .12005 .68671 .11747 .68571 .11602 Metetra
.664 .741 .907 r
.68571 .11602 .68671 .11747 .69369 .11488 .69269 .11343 Metetra
.664 .741 .907 r
.69269 .11343 .69369 .11488 .70068 .11228 .69969 .11083 Metetra
.664 .741 .907 r
.69969 .11083 .70068 .11228 .7077 .10968 .70671 .10823 Metetra
.664 .741 .907 r
.70671 .10823 .7077 .10968 .71473 .10707 .71375 .10562 Metetra
.664 .741 .907 r
.71375 .10562 .71473 .10707 .72178 .10446 .7208 .103 Metetra
.664 .741 .907 r
.7208 .103 .72178 .10446 .72884 .10184 .72787 .10037 Metetra
.664 .741 .907 r
.72787 .10037 .72884 .10184 .73593 .09921 .73495 .09774 Metetra
.664 .741 .907 r
.73495 .09774 .73593 .09921 .74303 .09658 .74206 .0951 Metetra
.664 .741 .907 r
.74206 .0951 .74303 .09658 .75015 .09393 .74918 .09246 Metetra
.664 .741 .907 r
.11381 .32673 .11506 .32789 .12071 .3258 .11946 .32463 Metetra
.664 .741 .907 r
.11946 .32463 .12071 .3258 .12637 .3237 .12512 .32252 Metetra
.664 .741 .907 r
.12512 .32252 .12637 .3237 .13204 .32159 .13079 .32042 Metetra
.664 .741 .907 r
.13079 .32042 .13204 .32159 .13772 .31948 .13648 .3183 Metetra
.664 .741 .907 r
.13648 .3183 .13772 .31948 .14341 .31737 .14217 .31619 Metetra
.664 .741 .907 r
.14217 .31619 .14341 .31737 .14912 .31525 .14788 .31407 Metetra
.664 .741 .907 r
.14788 .31407 .14912 .31525 .15484 .31313 .15361 .31194 Metetra
.664 .741 .907 r
.15361 .31194 .15484 .31313 .16058 .311 .15934 .30981 Metetra
.664 .741 .907 r
.15934 .30981 .16058 .311 .16632 .30886 .16509 .30767 Metetra
.664 .741 .907 r
.16509 .30767 .16632 .30886 .17208 .30672 .17085 .30553 Metetra
.664 .741 .907 r
.17085 .30553 .17208 .30672 .17785 .30458 .17663 .30338 Metetra
.664 .741 .907 r
.17663 .30338 .17785 .30458 .18364 .30243 .18241 .30123 Metetra
.664 .741 .907 r
.18241 .30123 .18364 .30243 .18944 .30028 .18822 .29908 Metetra
.906 .495 .15 r
.18822 .29908 .18944 .30028 .19323 .3172 .19245 .31176 Metetra
.768 .566 .624 r
.19245 .31176 .19323 .3172 .20107 .29596 .19986 .29475 Metetra
.664 .741 .907 r
.19986 .29475 .20107 .29596 .20691 .29379 .2057 .29258 Metetra
.664 .741 .907 r
.2057 .29258 .20691 .29379 .21276 .29162 .21155 .29041 Metetra
.664 .741 .907 r
.21155 .29041 .21276 .29162 .21863 .28944 .21741 .28823 Metetra
.664 .741 .907 r
.21741 .28823 .21863 .28944 .2245 .28726 .22329 .28604 Metetra
.664 .741 .907 r
.22329 .28604 .2245 .28726 .23039 .28508 .22919 .28385 Metetra
.664 .741 .907 r
.22919 .28385 .23039 .28508 .2363 .28288 .23509 .28166 Metetra
.664 .741 .907 r
.23509 .28166 .2363 .28288 .24221 .28069 .24101 .27946 Metetra
.664 .741 .907 r
.24101 .27946 .24221 .28069 .24814 .27848 .24695 .27725 Metetra
.664 .741 .907 r
.24695 .27725 .24814 .27848 .25409 .27628 .25289 .27504 Metetra
.664 .741 .907 r
.25289 .27504 .25409 .27628 .26005 .27407 .25885 .27283 Metetra
.664 .741 .907 r
.25885 .27283 .26005 .27407 .26602 .27185 .26483 .27061 Metetra
.664 .741 .907 r
.26483 .27061 .26602 .27185 .272 .26963 .27081 .26838 Metetra
.664 .741 .907 r
.27081 .26838 .272 .26963 .278 .2674 .27681 .26615 Metetra
.664 .741 .907 r
.27681 .26615 .278 .2674 .28401 .26517 .28283 .26392 Metetra
.664 .741 .907 r
.28283 .26392 .28401 .26517 .29004 .26293 .28886 .26168 Metetra
.664 .741 .907 r
.28886 .26168 .29004 .26293 .29608 .26069 .2949 .25943 Metetra
.664 .741 .907 r
.2949 .25943 .29608 .26069 .30213 .25844 .30096 .25718 Metetra
.664 .741 .907 r
.30096 .25718 .30213 .25844 .3082 .25619 .30703 .25493 Metetra
.664 .741 .907 r
.30703 .25493 .3082 .25619 .31428 .25393 .31311 .25267 Metetra
.664 .741 .907 r
.31311 .25267 .31428 .25393 .32038 .25167 .31921 .2504 Metetra
.664 .741 .907 r
.31921 .2504 .32038 .25167 .32649 .2494 .32532 .24813 Metetra
.664 .741 .907 r
.32532 .24813 .32649 .2494 .33261 .24712 .33145 .24585 Metetra
.664 .741 .907 r
.33145 .24585 .33261 .24712 .33875 .24484 .33759 .24357 Metetra
.664 .741 .907 r
.33759 .24357 .33875 .24484 .3449 .24256 .34374 .24128 Metetra
.664 .741 .907 r
.34374 .24128 .3449 .24256 .34537 .34068 .34991 .23899 Metetra
.521 .294 .511 r
.34991 .23899 .34537 .34068 .35725 .23798 .3561 .23669 Metetra
.664 .741 .907 r
.3561 .23669 .35725 .23798 .36345 .23568 .36229 .23439 Metetra
.664 .741 .907 r
.36229 .23439 .36345 .23568 .36966 .23337 .36851 .23208 Metetra
.664 .741 .907 r
.36851 .23208 .36966 .23337 .37588 .23106 .37473 .22977 Metetra
.664 .741 .907 r
.37473 .22977 .37588 .23106 .38212 .22874 .38098 .22745 Metetra
.664 .741 .907 r
.38098 .22745 .38212 .22874 .38837 .22642 .38723 .22512 Metetra
.664 .741 .907 r
.38723 .22512 .38837 .22642 .39464 .22409 .3935 .22279 Metetra
.664 .741 .907 r
.3935 .22279 .39464 .22409 .40092 .22176 .39979 .22046 Metetra
.664 .741 .907 r
.39979 .22046 .40092 .22176 .40722 .21942 .40609 .21812 Metetra
.664 .741 .907 r
.40609 .21812 .40722 .21942 .41353 .21708 .4124 .21577 Metetra
.664 .741 .907 r
.4124 .21577 .41353 .21708 .41986 .21473 .41873 .21342 Metetra
.664 .741 .907 r
.41873 .21342 .41986 .21473 .4262 .21238 .42508 .21106 Metetra
.664 .741 .907 r
.42508 .21106 .4262 .21238 .43256 .21002 .43144 .2087 Metetra
.664 .741 .907 r
.43144 .2087 .43256 .21002 .43893 .20765 .43781 .20633 Metetra
.664 .741 .907 r
.43781 .20633 .43893 .20765 .44531 .20528 .4442 .20395 Metetra
.664 .741 .907 r
.4442 .20395 .44531 .20528 .45172 .2029 .4506 .20157 Metetra
.854 .426 0 r
.4506 .20157 .45172 .2029 .45813 .20052 .45664 .21609 Metetra
.304 .078 .396 r
.45664 .21609 .45813 .20052 .46456 .19813 .46346 .1968 Metetra
.664 .741 .907 r
.46346 .1968 .46456 .19813 .47101 .19574 .46991 .1944 Metetra
.664 .741 .907 r
.46991 .1944 .47101 .19574 .47747 .19334 .47637 .192 Metetra
.664 .741 .907 r
.47637 .192 .47747 .19334 .48395 .19093 .48286 .18959 Metetra
.664 .741 .907 r
.48286 .18959 .48395 .19093 .49045 .18852 .48935 .18718 Metetra
.664 .741 .907 r
.48935 .18718 .49045 .18852 .49695 .18611 .49586 .18476 Metetra
.664 .741 .907 r
.49586 .18476 .49695 .18611 .50348 .18368 .50239 .18233 Metetra
.664 .741 .907 r
.50239 .18233 .50348 .18368 .51002 .18126 .50893 .1799 Metetra
.664 .741 .907 r
.50893 .1799 .51002 .18126 .51657 .17882 .51549 .17746 Metetra
.664 .741 .907 r
.51549 .17746 .51657 .17882 .52315 .17638 .52207 .17502 Metetra
.664 .741 .907 r
.52207 .17502 .52315 .17638 .52973 .17394 .52866 .17257 Metetra
.664 .741 .907 r
.52866 .17257 .52973 .17394 .53634 .17148 .53526 .17011 Metetra
.664 .741 .907 r
.53526 .17011 .53634 .17148 .54295 .16903 .54188 .16765 Metetra
.664 .741 .907 r
.54188 .16765 .54295 .16903 .54959 .16656 .54852 .16519 Metetra
.664 .741 .907 r
.54852 .16519 .54959 .16656 .55624 .16409 .55518 .16271 Metetra
.664 .741 .907 r
.55518 .16271 .55624 .16409 .56291 .16162 .56185 .16024 Metetra
.664 .741 .907 r
.56185 .16024 .56291 .16162 .56959 .15914 .56853 .15775 Metetra
.664 .741 .907 r
.56853 .15775 .56959 .15914 .57629 .15665 .57523 .15526 Metetra
.664 .741 .907 r
.57523 .15526 .57629 .15665 .583 .15416 .58195 .15277 Metetra
.664 .741 .907 r
.58195 .15277 .583 .15416 .58973 .15166 .58869 .15026 Metetra
.664 .741 .907 r
.58869 .15026 .58973 .15166 .59648 .14915 .59544 .14775 Metetra
.664 .741 .907 r
.59544 .14775 .59648 .14915 .60324 .14664 .6022 .14524 Metetra
.664 .741 .907 r
.6022 .14524 .60324 .14664 .61003 .14412 .60899 .14272 Metetra
.664 .741 .907 r
.60899 .14272 .61003 .14412 .61682 .1416 .61579 .14019 Metetra
.664 .741 .907 r
.61579 .14019 .61682 .1416 .62364 .13907 .62261 .13766 Metetra
.664 .741 .907 r
.62261 .13766 .62364 .13907 .63047 .13654 .62944 .13512 Metetra
.664 .741 .907 r
.62944 .13512 .63047 .13654 .63731 .13399 .63629 .13257 Metetra
.664 .741 .907 r
.63629 .13257 .63731 .13399 .64418 .13145 .64316 .13002 Metetra
.664 .741 .907 r
.64316 .13002 .64418 .13145 .65106 .12889 .65004 .12746 Metetra
.664 .741 .907 r
.65004 .12746 .65106 .12889 .65795 .12633 .65694 .1249 Metetra
.664 .741 .907 r
.65694 .1249 .65795 .12633 .66487 .12376 .66386 .12233 Metetra
.664 .741 .907 r
.66386 .12233 .66487 .12376 .6718 .12119 .67079 .11975 Metetra
.664 .741 .907 r
.67079 .11975 .6718 .12119 .67875 .11861 .67774 .11717 Metetra
.664 .741 .907 r
.67774 .11717 .67875 .11861 .68571 .11602 .68471 .11458 Metetra
.664 .741 .907 r
.68471 .11458 .68571 .11602 .69269 .11343 .6917 .11198 Metetra
.664 .741 .907 r
.6917 .11198 .69269 .11343 .69969 .11083 .6987 .10938 Metetra
.664 .741 .907 r
.6987 .10938 .69969 .11083 .70671 .10823 .70572 .10677 Metetra
.664 .741 .907 r
.70572 .10677 .70671 .10823 .71375 .10562 .71276 .10416 Metetra
.664 .741 .907 r
.71276 .10416 .71375 .10562 .7208 .103 .71982 .10153 Metetra
.664 .741 .907 r
.71982 .10153 .7208 .103 .72787 .10037 .72689 .09891 Metetra
.664 .741 .907 r
.72689 .09891 .72787 .10037 .73495 .09774 .73398 .09627 Metetra
.664 .741 .907 r
.73398 .09627 .73495 .09774 .74206 .0951 .74109 .09363 Metetra
.664 .741 .907 r
.74109 .09363 .74206 .0951 .74918 .09246 .74821 .09098 Metetra
.664 .741 .907 r
.11256 .32556 .11381 .32673 .11946 .32463 .11821 .32346 Metetra
.664 .741 .907 r
.11821 .32346 .11946 .32463 .12512 .32252 .12387 .32135 Metetra
.664 .741 .907 r
.12387 .32135 .12512 .32252 .13079 .32042 .12955 .31924 Metetra
.664 .741 .907 r
.12955 .31924 .13079 .32042 .13648 .3183 .13523 .31712 Metetra
.664 .741 .907 r
.13523 .31712 .13648 .3183 .14217 .31619 .14093 .315 Metetra
.664 .741 .907 r
.14093 .315 .14217 .31619 .14788 .31407 .14664 .31288 Metetra
.664 .741 .907 r
.14664 .31288 .14788 .31407 .15361 .31194 .15237 .31075 Metetra
.664 .741 .907 r
.15237 .31075 .15361 .31194 .15934 .30981 .15811 .30862 Metetra
.664 .741 .907 r
.15811 .30862 .15934 .30981 .16509 .30767 .16386 .30648 Metetra
.664 .741 .907 r
.16386 .30648 .16509 .30767 .17085 .30553 .16962 .30433 Metetra
.664 .741 .907 r
.16962 .30433 .17085 .30553 .17663 .30338 .1754 .30219 Metetra
.664 .741 .907 r
.1754 .30219 .17663 .30338 .18241 .30123 .18119 .30003 Metetra
.664 .741 .907 r
.18119 .30003 .18241 .30123 .18822 .29908 .18699 .29787 Metetra
.664 .741 .907 r
.18699 .29787 .18822 .29908 .19245 .31176 .19281 .29571 Metetra
.541 .339 .555 r
.19281 .29571 .19245 .31176 .19986 .29475 .19864 .29354 Metetra
.664 .741 .907 r
.19864 .29354 .19986 .29475 .2057 .29258 .20448 .29137 Metetra
.664 .741 .907 r
.20448 .29137 .2057 .29258 .21155 .29041 .21033 .28919 Metetra
.664 .741 .907 r
.21033 .28919 .21155 .29041 .21741 .28823 .2162 .28701 Metetra
.664 .741 .907 r
.2162 .28701 .21741 .28823 .22329 .28604 .22208 .28482 Metetra
.664 .741 .907 r
.22208 .28482 .22329 .28604 .22919 .28385 .22798 .28263 Metetra
.664 .741 .907 r
.22798 .28263 .22919 .28385 .23509 .28166 .23389 .28043 Metetra
.664 .741 .907 r
.23389 .28043 .23509 .28166 .24101 .27946 .23981 .27823 Metetra
.664 .741 .907 r
.23981 .27823 .24101 .27946 .24695 .27725 .24574 .27602 Metetra
.664 .741 .907 r
.24574 .27602 .24695 .27725 .25289 .27504 .25169 .27381 Metetra
.664 .741 .907 r
.25169 .27381 .25289 .27504 .25885 .27283 .25766 .27159 Metetra
.664 .741 .907 r
.25766 .27159 .25885 .27283 .26483 .27061 .26363 .26937 Metetra
.664 .741 .907 r
.26363 .26937 .26483 .27061 .27081 .26838 .26962 .26714 Metetra
.664 .741 .907 r
.26962 .26714 .27081 .26838 .27681 .26615 .27563 .26491 Metetra
.664 .741 .907 r
.27563 .26491 .27681 .26615 .28283 .26392 .28164 .26267 Metetra
.664 .741 .907 r
.28164 .26267 .28283 .26392 .28886 .26168 .28767 .26043 Metetra
.664 .741 .907 r
.28767 .26043 .28886 .26168 .2949 .25943 .29372 .25818 Metetra
.664 .741 .907 r
.29372 .25818 .2949 .25943 .30096 .25718 .29978 .25593 Metetra
.664 .741 .907 r
.29978 .25593 .30096 .25718 .30703 .25493 .30585 .25367 Metetra
.664 .741 .907 r
.30585 .25367 .30703 .25493 .31311 .25267 .31194 .2514 Metetra
.664 .741 .907 r
.31194 .2514 .31311 .25267 .31921 .2504 .31804 .24913 Metetra
.664 .741 .907 r
.31804 .24913 .31921 .2504 .32532 .24813 .32415 .24686 Metetra
.664 .741 .907 r
.32415 .24686 .32532 .24813 .33145 .24585 .33028 .24458 Metetra
.664 .741 .907 r
.33028 .24458 .33145 .24585 .33759 .24357 .33643 .2423 Metetra
.664 .741 .907 r
.33643 .2423 .33759 .24357 .34374 .24128 .34258 .24001 Metetra
.664 .741 .907 r
.34258 .24001 .34374 .24128 .34991 .23899 .34876 .23771 Metetra
.664 .741 .907 r
.34876 .23771 .34991 .23899 .3561 .23669 .35494 .23541 Metetra
.664 .741 .907 r
.35494 .23541 .3561 .23669 .36229 .23439 .36114 .2331 Metetra
.664 .741 .907 r
.36114 .2331 .36229 .23439 .36851 .23208 .36736 .23079 Metetra
.664 .741 .907 r
.36736 .23079 .36851 .23208 .37473 .22977 .37359 .22847 Metetra
.664 .741 .907 r
.37359 .22847 .37473 .22977 .38098 .22745 .37983 .22615 Metetra
.664 .741 .907 r
.37983 .22615 .38098 .22745 .38723 .22512 .38609 .22382 Metetra
.664 .741 .907 r
.38609 .22382 .38723 .22512 .3935 .22279 .39236 .22149 Metetra
.664 .741 .907 r
.39236 .22149 .3935 .22279 .39979 .22046 .39865 .21915 Metetra
.664 .741 .907 r
.39865 .21915 .39979 .22046 .40609 .21812 .40495 .21681 Metetra
.664 .741 .907 r
.40495 .21681 .40609 .21812 .4124 .21577 .41127 .21446 Metetra
.664 .741 .907 r
.41127 .21446 .4124 .21577 .41873 .21342 .4176 .2121 Metetra
.664 .741 .907 r
.4176 .2121 .41873 .21342 .42508 .21106 .42395 .20974 Metetra
.664 .741 .907 r
.42395 .20974 .42508 .21106 .43144 .2087 .43031 .20738 Metetra
.664 .741 .907 r
.43031 .20738 .43144 .2087 .43781 .20633 .43669 .205 Metetra
.664 .741 .907 r
.43669 .205 .43781 .20633 .4442 .20395 .44308 .20263 Metetra
.664 .741 .907 r
.44308 .20263 .4442 .20395 .4506 .20157 .44949 .20024 Metetra
.969 .67 .403 r
.44949 .20024 .4506 .20157 .45664 .21609 .45232 .35525 Metetra
.326 .131 .456 r
.45232 .35525 .45664 .21609 .46346 .1968 .46235 .19546 Metetra
.664 .741 .907 r
.46235 .19546 .46346 .1968 .46991 .1944 .4688 .19306 Metetra
.664 .741 .907 r
.4688 .19306 .46991 .1944 .47637 .192 .47527 .19066 Metetra
.664 .741 .907 r
.47527 .19066 .47637 .192 .48286 .18959 .48176 .18824 Metetra
.664 .741 .907 r
.48176 .18824 .48286 .18959 .48935 .18718 .48826 .18583 Metetra
.664 .741 .907 r
.48826 .18583 .48935 .18718 .49586 .18476 .49477 .1834 Metetra
.664 .741 .907 r
.49477 .1834 .49586 .18476 .50239 .18233 .5013 .18097 Metetra
.664 .741 .907 r
.5013 .18097 .50239 .18233 .50893 .1799 .50785 .17854 Metetra
.664 .741 .907 r
.50785 .17854 .50893 .1799 .51549 .17746 .51441 .1761 Metetra
.664 .741 .907 r
.51441 .1761 .51549 .17746 .52207 .17502 .52099 .17365 Metetra
.664 .741 .907 r
.52099 .17365 .52207 .17502 .52866 .17257 .52758 .1712 Metetra
.664 .741 .907 r
.52758 .1712 .52866 .17257 .53526 .17011 .53419 .16874 Metetra
.664 .741 .907 r
.53419 .16874 .53526 .17011 .54188 .16765 .54081 .16628 Metetra
.664 .741 .907 r
.54081 .16628 .54188 .16765 .54852 .16519 .54745 .16381 Metetra
.664 .741 .907 r
.54745 .16381 .54852 .16519 .55518 .16271 .55411 .16133 Metetra
.664 .741 .907 r
.55411 .16133 .55518 .16271 .56185 .16024 .56078 .15885 Metetra
.664 .741 .907 r
.56078 .15885 .56185 .16024 .56853 .15775 .56747 .15636 Metetra
.664 .741 .907 r
.56747 .15636 .56853 .15775 .57523 .15526 .57418 .15387 Metetra
.664 .741 .907 r
.57418 .15387 .57523 .15526 .58195 .15277 .5809 .15137 Metetra
.664 .741 .907 r
.5809 .15137 .58195 .15277 .58869 .15026 .58764 .14886 Metetra
.664 .741 .907 r
.58764 .14886 .58869 .15026 .59544 .14775 .59439 .14635 Metetra
.664 .741 .907 r
.59439 .14635 .59544 .14775 .6022 .14524 .60116 .14383 Metetra
.664 .741 .907 r
.60116 .14383 .6022 .14524 .60899 .14272 .60795 .14131 Metetra
.664 .741 .907 r
.60795 .14131 .60899 .14272 .61579 .14019 .61475 .13878 Metetra
.664 .741 .907 r
.61475 .13878 .61579 .14019 .62261 .13766 .62157 .13624 Metetra
.664 .741 .907 r
.62157 .13624 .62261 .13766 .62944 .13512 .62841 .1337 Metetra
.664 .741 .907 r
.62841 .1337 .62944 .13512 .63629 .13257 .63526 .13115 Metetra
.664 .741 .907 r
.63526 .13115 .63629 .13257 .64316 .13002 .64213 .1286 Metetra
.664 .741 .907 r
.64213 .1286 .64316 .13002 .65004 .12746 .64902 .12603 Metetra
.664 .741 .907 r
.64902 .12603 .65004 .12746 .65694 .1249 .65593 .12347 Metetra
.664 .741 .907 r
.65593 .12347 .65694 .1249 .66386 .12233 .66285 .12089 Metetra
.664 .741 .907 r
.66285 .12089 .66386 .12233 .67079 .11975 .66979 .11831 Metetra
.664 .741 .907 r
.66979 .11831 .67079 .11975 .67774 .11717 .67674 .11572 Metetra
.664 .741 .907 r
.67674 .11572 .67774 .11717 .68471 .11458 .68371 .11313 Metetra
.664 .741 .907 r
.68371 .11313 .68471 .11458 .6917 .11198 .6907 .11053 Metetra
.664 .741 .907 r
.6907 .11053 .6917 .11198 .6987 .10938 .69771 .10793 Metetra
.664 .741 .907 r
.69771 .10793 .6987 .10938 .70572 .10677 .70473 .10531 Metetra
.664 .741 .907 r
.70473 .10531 .70572 .10677 .71276 .10416 .71178 .10269 Metetra
.664 .741 .907 r
.71178 .10269 .71276 .10416 .71982 .10153 .71883 .10007 Metetra
.664 .741 .907 r
.71883 .10007 .71982 .10153 .72689 .09891 .72591 .09744 Metetra
.664 .741 .907 r
.72591 .09744 .72689 .09891 .73398 .09627 .73301 .0948 Metetra
.664 .741 .907 r
.73301 .0948 .73398 .09627 .74109 .09363 .74012 .09215 Metetra
.664 .741 .907 r
.74012 .09215 .74109 .09363 .74821 .09098 .74725 .0895 Metetra
.664 .741 .907 r
.11131 .32439 .11256 .32556 .11821 .32346 .11696 .32228 Metetra
.664 .741 .907 r
.11696 .32228 .11821 .32346 .12387 .32135 .12262 .32017 Metetra
.664 .741 .907 r
.12262 .32017 .12387 .32135 .12955 .31924 .1283 .31806 Metetra
.664 .741 .907 r
.1283 .31806 .12955 .31924 .13523 .31712 .13399 .31594 Metetra
.664 .741 .907 r
.13399 .31594 .13523 .31712 .14093 .315 .13969 .31382 Metetra
.664 .741 .907 r
.13969 .31382 .14093 .315 .14664 .31288 .1454 .31169 Metetra
.664 .741 .907 r
.1454 .31169 .14664 .31288 .15237 .31075 .15113 .30956 Metetra
.664 .741 .907 r
.15113 .30956 .15237 .31075 .15811 .30862 .15687 .30742 Metetra
.664 .741 .907 r
.15687 .30742 .15811 .30862 .16386 .30648 .16262 .30528 Metetra
.664 .741 .907 r
.16262 .30528 .16386 .30648 .16962 .30433 .16839 .30314 Metetra
.664 .741 .907 r
.16839 .30314 .16962 .30433 .1754 .30219 .17417 .30099 Metetra
.664 .741 .907 r
.17417 .30099 .1754 .30219 .18119 .30003 .17996 .29883 Metetra
.664 .741 .907 r
.17996 .29883 .18119 .30003 .18699 .29787 .18577 .29667 Metetra
.664 .741 .907 r
.18577 .29667 .18699 .29787 .19281 .29571 .19158 .2945 Metetra
.664 .741 .907 r
.19158 .2945 .19281 .29571 .19864 .29354 .19741 .29233 Metetra
.664 .741 .907 r
.19741 .29233 .19864 .29354 .20448 .29137 .20326 .29016 Metetra
.664 .741 .907 r
.20326 .29016 .20448 .29137 .21033 .28919 .20912 .28798 Metetra
.664 .741 .907 r
.20912 .28798 .21033 .28919 .2162 .28701 .21499 .28579 Metetra
.664 .741 .907 r
.21499 .28579 .2162 .28701 .22208 .28482 .22087 .2836 Metetra
.664 .741 .907 r
.22087 .2836 .22208 .28482 .22798 .28263 .22677 .2814 Metetra
.664 .741 .907 r
.22677 .2814 .22798 .28263 .23389 .28043 .23268 .2792 Metetra
.664 .741 .907 r
.23268 .2792 .23389 .28043 .23981 .27823 .2386 .277 Metetra
.664 .741 .907 r
.2386 .277 .23981 .27823 .24574 .27602 .24454 .27479 Metetra
.664 .741 .907 r
.24454 .27479 .24574 .27602 .25169 .27381 .25049 .27257 Metetra
.664 .741 .907 r
.25049 .27257 .25169 .27381 .25766 .27159 .25646 .27035 Metetra
.664 .741 .907 r
.25646 .27035 .25766 .27159 .26363 .26937 .26244 .26813 Metetra
.664 .741 .907 r
.26244 .26813 .26363 .26937 .26962 .26714 .26843 .2659 Metetra
.664 .741 .907 r
.26843 .2659 .26962 .26714 .27563 .26491 .27444 .26366 Metetra
.664 .741 .907 r
.27444 .26366 .27563 .26491 .28164 .26267 .28046 .26142 Metetra
.664 .741 .907 r
.28046 .26142 .28164 .26267 .28767 .26043 .28649 .25917 Metetra
.664 .741 .907 r
.28649 .25917 .28767 .26043 .29372 .25818 .29254 .25692 Metetra
.664 .741 .907 r
.29254 .25692 .29372 .25818 .29978 .25593 .2986 .25467 Metetra
.664 .741 .907 r
.2986 .25467 .29978 .25593 .30585 .25367 .30467 .25241 Metetra
.664 .741 .907 r
.30467 .25241 .30585 .25367 .31194 .2514 .31076 .25014 Metetra
.664 .741 .907 r
.31076 .25014 .31194 .2514 .31804 .24913 .31687 .24787 Metetra
.664 .741 .907 r
.31687 .24787 .31804 .24913 .32415 .24686 .32298 .24559 Metetra
.664 .741 .907 r
.32298 .24559 .32415 .24686 .33028 .24458 .32912 .24331 Metetra
.664 .741 .907 r
.32912 .24331 .33028 .24458 .33643 .2423 .33526 .24102 Metetra
.664 .741 .907 r
.33526 .24102 .33643 .2423 .34258 .24001 .34142 .23873 Metetra
.664 .741 .907 r
.34142 .23873 .34258 .24001 .34876 .23771 .3476 .23643 Metetra
.664 .741 .907 r
.3476 .23643 .34876 .23771 .35494 .23541 .35378 .23412 Metetra
.664 .741 .907 r
.35378 .23412 .35494 .23541 .36114 .2331 .35999 .23181 Metetra
.664 .741 .907 r
.35999 .23181 .36114 .2331 .36736 .23079 .36621 .2295 Metetra
.664 .741 .907 r
.36621 .2295 .36736 .23079 .37359 .22847 .37244 .22718 Metetra
.664 .741 .907 r
.37244 .22718 .37359 .22847 .37983 .22615 .37868 .22485 Metetra
.664 .741 .907 r
.37868 .22485 .37983 .22615 .38609 .22382 .38495 .22252 Metetra
.664 .741 .907 r
.38495 .22252 .38609 .22382 .39236 .22149 .39122 .22019 Metetra
.664 .741 .907 r
.39122 .22019 .39236 .22149 .39865 .21915 .39751 .21785 Metetra
.664 .741 .907 r
.39751 .21785 .39865 .21915 .40495 .21681 .40382 .2155 Metetra
.664 .741 .907 r
.40382 .2155 .40495 .21681 .41127 .21446 .41014 .21315 Metetra
.664 .741 .907 r
.41014 .21315 .41127 .21446 .4176 .2121 .41647 .21079 Metetra
.664 .741 .907 r
.41647 .21079 .4176 .2121 .42395 .20974 .42282 .20842 Metetra
.664 .741 .907 r
.42282 .20842 .42395 .20974 .43031 .20738 .42919 .20605 Metetra
.664 .741 .907 r
.42919 .20605 .43031 .20738 .43669 .205 .43557 .20368 Metetra
.664 .741 .907 r
.43557 .20368 .43669 .205 .44308 .20263 .44197 .2013 Metetra
.967 .66 .383 r
.44197 .2013 .44308 .20263 .44949 .20024 .44591 .29618 Metetra
.582 .332 .503 r
.44591 .29618 .44949 .20024 .45232 .35525 .45115 .35373 Metetra
.968 .699 .468 r
.45115 .35373 .45232 .35525 .46235 .19546 .46124 .19412 Metetra
.664 .741 .907 r
.46124 .19412 .46235 .19546 .4688 .19306 .4677 .19172 Metetra
.664 .741 .907 r
.4677 .19172 .4688 .19306 .47527 .19066 .47417 .18931 Metetra
.664 .741 .907 r
.47417 .18931 .47527 .19066 .48176 .18824 .48066 .1869 Metetra
.664 .741 .907 r
.48066 .1869 .48176 .18824 .48826 .18583 .48716 .18448 Metetra
.664 .741 .907 r
.48716 .18448 .48826 .18583 .49477 .1834 .49368 .18205 Metetra
.664 .741 .907 r
.49368 .18205 .49477 .1834 .5013 .18097 .50021 .17962 Metetra
.664 .741 .907 r
.50021 .17962 .5013 .18097 .50785 .17854 .50676 .17718 Metetra
.664 .741 .907 r
.50676 .17718 .50785 .17854 .51441 .1761 .51332 .17474 Metetra
.664 .741 .907 r
.51332 .17474 .51441 .1761 .52099 .17365 .5199 .17229 Metetra
.664 .741 .907 r
.5199 .17229 .52099 .17365 .52758 .1712 .5265 .16983 Metetra
.664 .741 .907 r
.5265 .16983 .52758 .1712 .53419 .16874 .53311 .16737 Metetra
.664 .741 .907 r
.53311 .16737 .53419 .16874 .54081 .16628 .53974 .1649 Metetra
.664 .741 .907 r
.53974 .1649 .54081 .16628 .54745 .16381 .54639 .16243 Metetra
.664 .741 .907 r
.54639 .16243 .54745 .16381 .55411 .16133 .55305 .15995 Metetra
.664 .741 .907 r
.55305 .15995 .55411 .16133 .56078 .15885 .55972 .15746 Metetra
.664 .741 .907 r
.55972 .15746 .56078 .15885 .56747 .15636 .56641 .15497 Metetra
.664 .741 .907 r
.56641 .15497 .56747 .15636 .57418 .15387 .57312 .15248 Metetra
.664 .741 .907 r
.57312 .15248 .57418 .15387 .5809 .15137 .57985 .14997 Metetra
.664 .741 .907 r
.57985 .14997 .5809 .15137 .58764 .14886 .58659 .14746 Metetra
.664 .741 .907 r
.58659 .14746 .58764 .14886 .59439 .14635 .59335 .14495 Metetra
.664 .741 .907 r
.59335 .14495 .59439 .14635 .60116 .14383 .60012 .14243 Metetra
.664 .741 .907 r
.60012 .14243 .60116 .14383 .60795 .14131 .60691 .1399 Metetra
.664 .741 .907 r
.60691 .1399 .60795 .14131 .61475 .13878 .61372 .13737 Metetra
.664 .741 .907 r
.61372 .13737 .61475 .13878 .62157 .13624 .62054 .13483 Metetra
.664 .741 .907 r
.62054 .13483 .62157 .13624 .62841 .1337 .62738 .13228 Metetra
.664 .741 .907 r
.62738 .13228 .62841 .1337 .63526 .13115 .63424 .12973 Metetra
.664 .741 .907 r
.63424 .12973 .63526 .13115 .64213 .1286 .64111 .12717 Metetra
.664 .741 .907 r
.64111 .12717 .64213 .1286 .64902 .12603 .648 .1246 Metetra
.664 .741 .907 r
.648 .1246 .64902 .12603 .65593 .12347 .65491 .12203 Metetra
.664 .741 .907 r
.65491 .12203 .65593 .12347 .66285 .12089 .66183 .11945 Metetra
.664 .741 .907 r
.66183 .11945 .66285 .12089 .66979 .11831 .66878 .11687 Metetra
.664 .741 .907 r
.66878 .11687 .66979 .11831 .67674 .11572 .67574 .11428 Metetra
.664 .741 .907 r
.67574 .11428 .67674 .11572 .68371 .11313 .68271 .11168 Metetra
.664 .741 .907 r
.68271 .11168 .68371 .11313 .6907 .11053 .6897 .10908 Metetra
.664 .741 .907 r
.6897 .10908 .6907 .11053 .69771 .10793 .69671 .10647 Metetra
.664 .741 .907 r
.69671 .10647 .69771 .10793 .70473 .10531 .70374 .10385 Metetra
.664 .741 .907 r
.70374 .10385 .70473 .10531 .71178 .10269 .71079 .10123 Metetra
.664 .741 .907 r
.71079 .10123 .71178 .10269 .71883 .10007 .71785 .0986 Metetra
.664 .741 .907 r
.71785 .0986 .71883 .10007 .72591 .09744 .72493 .09597 Metetra
.664 .741 .907 r
.72493 .09597 .72591 .09744 .73301 .0948 .73203 .09332 Metetra
.664 .741 .907 r
.73203 .09332 .73301 .0948 .74012 .09215 .73915 .09067 Metetra
.664 .741 .907 r
.73915 .09067 .74012 .09215 .74725 .0895 .74628 .08802 Metetra
.664 .741 .907 r
.11005 .32321 .11131 .32439 .11696 .32228 .1157 .32111 Metetra
.664 .741 .907 r
.1157 .32111 .11696 .32228 .12262 .32017 .12137 .319 Metetra
.664 .741 .907 r
.12137 .319 .12262 .32017 .1283 .31806 .12705 .31688 Metetra
.664 .741 .907 r
.12705 .31688 .1283 .31806 .13399 .31594 .13274 .31476 Metetra
.664 .741 .907 r
.13274 .31476 .13399 .31594 .13969 .31382 .13844 .31263 Metetra
.664 .741 .907 r
.13844 .31263 .13969 .31382 .1454 .31169 .14416 .3105 Metetra
.664 .741 .907 r
.14416 .3105 .1454 .31169 .15113 .30956 .14989 .30837 Metetra
.664 .741 .907 r
.14989 .30837 .15113 .30956 .15687 .30742 .15563 .30623 Metetra
.664 .741 .907 r
.15563 .30623 .15687 .30742 .16262 .30528 .16139 .30409 Metetra
.664 .741 .907 r
.16139 .30409 .16262 .30528 .16839 .30314 .16716 .30194 Metetra
.664 .741 .907 r
.16716 .30194 .16839 .30314 .17417 .30099 .17294 .29978 Metetra
.664 .741 .907 r
.17294 .29978 .17417 .30099 .17996 .29883 .17873 .29762 Metetra
.664 .741 .907 r
.17873 .29762 .17996 .29883 .18577 .29667 .18454 .29546 Metetra
.664 .741 .907 r
.18454 .29546 .18577 .29667 .19158 .2945 .19036 .29329 Metetra
.664 .741 .907 r
.19036 .29329 .19158 .2945 .19741 .29233 .19619 .29112 Metetra
.664 .741 .907 r
.19619 .29112 .19741 .29233 .20326 .29016 .20204 .28894 Metetra
.664 .741 .907 r
.20204 .28894 .20326 .29016 .20912 .28798 .2079 .28676 Metetra
.664 .741 .907 r
.2079 .28676 .20912 .28798 .21499 .28579 .21377 .28457 Metetra
.664 .741 .907 r
.21377 .28457 .21499 .28579 .22087 .2836 .21966 .28238 Metetra
.664 .741 .907 r
.21966 .28238 .22087 .2836 .22677 .2814 .22556 .28018 Metetra
.664 .741 .907 r
.22556 .28018 .22677 .2814 .23268 .2792 .23147 .27798 Metetra
.664 .741 .907 r
.23147 .27798 .23268 .2792 .2386 .277 .2374 .27577 Metetra
.656 .16 0 r
.2374 .27577 .2386 .277 .24454 .27479 .24253 .28242 Metetra
.208 0 .282 r
.24253 .28242 .24454 .27479 .25049 .27257 .24929 .27134 Metetra
.664 .741 .907 r
.24929 .27134 .25049 .27257 .25646 .27035 .25526 .26911 Metetra
.664 .741 .907 r
.25526 .26911 .25646 .27035 .26244 .26813 .26124 .26688 Metetra
.664 .741 .907 r
.26124 .26688 .26244 .26813 .26843 .2659 .26724 .26465 Metetra
.664 .741 .907 r
.26724 .26465 .26843 .2659 .27444 .26366 .27324 .26241 Metetra
.664 .741 .907 r
.27324 .26241 .27444 .26366 .28046 .26142 .27927 .26017 Metetra
.664 .741 .907 r
.27927 .26017 .28046 .26142 .28649 .25917 .2853 .25792 Metetra
.664 .741 .907 r
.2853 .25792 .28649 .25917 .29254 .25692 .29135 .25567 Metetra
.664 .741 .907 r
.29135 .25567 .29254 .25692 .2986 .25467 .29742 .25341 Metetra
.664 .741 .907 r
.29742 .25341 .2986 .25467 .30467 .25241 .30349 .25114 Metetra
.664 .741 .907 r
.30349 .25114 .30467 .25241 .31076 .25014 .30959 .24887 Metetra
.664 .741 .907 r
.30959 .24887 .31076 .25014 .31687 .24787 .31569 .2466 Metetra
.664 .741 .907 r
.31569 .2466 .31687 .24787 .32298 .24559 .32181 .24432 Metetra
.664 .741 .907 r
.32181 .24432 .32298 .24559 .32912 .24331 .32795 .24203 Metetra
.664 .741 .907 r
.32795 .24203 .32912 .24331 .33526 .24102 .3341 .23974 Metetra
.664 .741 .907 r
.3341 .23974 .33526 .24102 .34142 .23873 .34026 .23744 Metetra
.664 .741 .907 r
.34026 .23744 .34142 .23873 .3476 .23643 .34644 .23514 Metetra
.664 .741 .907 r
.34644 .23514 .3476 .23643 .35378 .23412 .35263 .23284 Metetra
.664 .741 .907 r
.35263 .23284 .35378 .23412 .35999 .23181 .35883 .23052 Metetra
.664 .741 .907 r
.35883 .23052 .35999 .23181 .36621 .2295 .36505 .22821 Metetra
.664 .741 .907 r
.36505 .22821 .36621 .2295 .37244 .22718 .37129 .22588 Metetra
.664 .741 .907 r
.37129 .22588 .37244 .22718 .37868 .22485 .37754 .22356 Metetra
.664 .741 .907 r
.37754 .22356 .37868 .22485 .38495 .22252 .3838 .22122 Metetra
.664 .741 .907 r
.3838 .22122 .38495 .22252 .39122 .22019 .39008 .21888 Metetra
.664 .741 .907 r
.39008 .21888 .39122 .22019 .39751 .21785 .39637 .21654 Metetra
.664 .741 .907 r
.39637 .21654 .39751 .21785 .40382 .2155 .40268 .21419 Metetra
.664 .741 .907 r
.40268 .21419 .40382 .2155 .41014 .21315 .40901 .21183 Metetra
.664 .741 .907 r
.40901 .21183 .41014 .21315 .41647 .21079 .41534 .20947 Metetra
.664 .741 .907 r
.41534 .20947 .41647 .21079 .42282 .20842 .4217 .2071 Metetra
.664 .741 .907 r
.4217 .2071 .42282 .20842 .42919 .20605 .42806 .20473 Metetra
.664 .741 .907 r
.42806 .20473 .42919 .20605 .43557 .20368 .43445 .20235 Metetra
.664 .741 .907 r
.43445 .20235 .43557 .20368 .44197 .2013 .44085 .19997 Metetra
.969 .675 .415 r
.44085 .19997 .44197 .2013 .44591 .29618 .44173 .41266 Metetra
.215 .045 .422 r
.44173 .41266 .44591 .29618 .45115 .35373 .45301 .22409 Metetra
.548 .314 .513 r
.45301 .22409 .45115 .35373 .46124 .19412 .46013 .19278 Metetra
.664 .741 .907 r
.46013 .19278 .46124 .19412 .4677 .19172 .46659 .19038 Metetra
.664 .741 .907 r
.46659 .19038 .4677 .19172 .47417 .18931 .47307 .18796 Metetra
.664 .741 .907 r
.47307 .18796 .47417 .18931 .48066 .1869 .47956 .18555 Metetra
.664 .741 .907 r
.47956 .18555 .48066 .1869 .48716 .18448 .48606 .18312 Metetra
.664 .741 .907 r
.48606 .18312 .48716 .18448 .49368 .18205 .49258 .18069 Metetra
.664 .741 .907 r
.49258 .18069 .49368 .18205 .50021 .17962 .49912 .17826 Metetra
.664 .741 .907 r
.49912 .17826 .50021 .17962 .50676 .17718 .50567 .17582 Metetra
.664 .741 .907 r
.50567 .17582 .50676 .17718 .51332 .17474 .51224 .17337 Metetra
.664 .741 .907 r
.51224 .17337 .51332 .17474 .5199 .17229 .51882 .17092 Metetra
.664 .741 .907 r
.51882 .17092 .5199 .17229 .5265 .16983 .52542 .16846 Metetra
.664 .741 .907 r
.52542 .16846 .5265 .16983 .53311 .16737 .53204 .16599 Metetra
.664 .741 .907 r
.53204 .16599 .53311 .16737 .53974 .1649 .53867 .16352 Metetra
.664 .741 .907 r
.53867 .16352 .53974 .1649 .54639 .16243 .54531 .16105 Metetra
.664 .741 .907 r
.54531 .16105 .54639 .16243 .55305 .15995 .55198 .15856 Metetra
.664 .741 .907 r
.55198 .15856 .55305 .15995 .55972 .15746 .55866 .15608 Metetra
.664 .741 .907 r
.55866 .15608 .55972 .15746 .56641 .15497 .56535 .15358 Metetra
.664 .741 .907 r
.56535 .15358 .56641 .15497 .57312 .15248 .57206 .15108 Metetra
.664 .741 .907 r
.57206 .15108 .57312 .15248 .57985 .14997 .57879 .14857 Metetra
.664 .741 .907 r
.57879 .14857 .57985 .14997 .58659 .14746 .58554 .14606 Metetra
.664 .741 .907 r
.58554 .14606 .58659 .14746 .59335 .14495 .5923 .14354 Metetra
.664 .741 .907 r
.5923 .14354 .59335 .14495 .60012 .14243 .59907 .14102 Metetra
.664 .741 .907 r
.59907 .14102 .60012 .14243 .60691 .1399 .60587 .13849 Metetra
.664 .741 .907 r
.60587 .13849 .60691 .1399 .61372 .13737 .61268 .13595 Metetra
.664 .741 .907 r
.61268 .13595 .61372 .13737 .62054 .13483 .61951 .13341 Metetra
.664 .741 .907 r
.61951 .13341 .62054 .13483 .62738 .13228 .62635 .13086 Metetra
.664 .741 .907 r
.62635 .13086 .62738 .13228 .63424 .12973 .63321 .1283 Metetra
.664 .741 .907 r
.63321 .1283 .63424 .12973 .64111 .12717 .64009 .12574 Metetra
.664 .741 .907 r
.64009 .12574 .64111 .12717 .648 .1246 .64698 .12317 Metetra
.664 .741 .907 r
.64698 .12317 .648 .1246 .65491 .12203 .65389 .12059 Metetra
.664 .741 .907 r
.65389 .12059 .65491 .12203 .66183 .11945 .66082 .11801 Metetra
.664 .741 .907 r
.66082 .11801 .66183 .11945 .66878 .11687 .66777 .11543 Metetra
.664 .741 .907 r
.66777 .11543 .66878 .11687 .67574 .11428 .67473 .11283 Metetra
.664 .741 .907 r
.67473 .11283 .67574 .11428 .68271 .11168 .68171 .11023 Metetra
.664 .741 .907 r
.68171 .11023 .68271 .11168 .6897 .10908 .6887 .10762 Metetra
.664 .741 .907 r
.6887 .10762 .6897 .10908 .69671 .10647 .69572 .10501 Metetra
.664 .741 .907 r
.69572 .10501 .69671 .10647 .70374 .10385 .70275 .10239 Metetra
.664 .741 .907 r
.70275 .10239 .70374 .10385 .71079 .10123 .7098 .09977 Metetra
.664 .741 .907 r
.7098 .09977 .71079 .10123 .71785 .0986 .71687 .09713 Metetra
.664 .741 .907 r
.71687 .09713 .71785 .0986 .72493 .09597 .72395 .09449 Metetra
.664 .741 .907 r
.72395 .09449 .72493 .09597 .73203 .09332 .73105 .09185 Metetra
.664 .741 .907 r
.73105 .09185 .73203 .09332 .73915 .09067 .73817 .08919 Metetra
.664 .741 .907 r
.73817 .08919 .73915 .09067 .74628 .08802 .74531 .08654 Metetra
.664 .741 .907 r
.10879 .32204 .11005 .32321 .1157 .32111 .11445 .31993 Metetra
.664 .741 .907 r
.11445 .31993 .1157 .32111 .12137 .319 .12012 .31782 Metetra
.664 .741 .907 r
.12012 .31782 .12137 .319 .12705 .31688 .1258 .3157 Metetra
.664 .741 .907 r
.1258 .3157 .12705 .31688 .13274 .31476 .13149 .31357 Metetra
.664 .741 .907 r
.13149 .31357 .13274 .31476 .13844 .31263 .1372 .31145 Metetra
.664 .741 .907 r
.1372 .31145 .13844 .31263 .14416 .3105 .14292 .30931 Metetra
.664 .741 .907 r
.14292 .30931 .14416 .3105 .14989 .30837 .14865 .30718 Metetra
.664 .741 .907 r
.14865 .30718 .14989 .30837 .15563 .30623 .15439 .30504 Metetra
.664 .741 .907 r
.15439 .30504 .15563 .30623 .16139 .30409 .16015 .30289 Metetra
.664 .741 .907 r
.16015 .30289 .16139 .30409 .16716 .30194 .16592 .30074 Metetra
.664 .741 .907 r
.16592 .30074 .16716 .30194 .17294 .29978 .1717 .29858 Metetra
.664 .741 .907 r
.1717 .29858 .17294 .29978 .17873 .29762 .1775 .29642 Metetra
.664 .741 .907 r
.1775 .29642 .17873 .29762 .18454 .29546 .18331 .29425 Metetra
.664 .741 .907 r
.18331 .29425 .18454 .29546 .19036 .29329 .18913 .29208 Metetra
.664 .741 .907 r
.18913 .29208 .19036 .29329 .19619 .29112 .19497 .2899 Metetra
.664 .741 .907 r
.19497 .2899 .19619 .29112 .20204 .28894 .20082 .28772 Metetra
.664 .741 .907 r
.20082 .28772 .20204 .28894 .2079 .28676 .20668 .28554 Metetra
.664 .741 .907 r
.20668 .28554 .2079 .28676 .21377 .28457 .21255 .28335 Metetra
.664 .741 .907 r
.21255 .28335 .21377 .28457 .21966 .28238 .21844 .28115 Metetra
.664 .741 .907 r
.21844 .28115 .21966 .28238 .22556 .28018 .22435 .27895 Metetra
.664 .741 .907 r
.22435 .27895 .22556 .28018 .23147 .27798 .23026 .27674 Metetra
.049 .431 .871 r
.23026 .27674 .23147 .27798 .2374 .27577 .23576 .27914 Metetra
.036 0 .046 r
.23576 .27914 .2374 .27577 .24253 .28242 .24213 .27232 Metetra
.555 .369 .584 r
.24213 .27232 .24253 .28242 .24929 .27134 .24809 .2701 Metetra
.664 .741 .907 r
.24809 .2701 .24929 .27134 .25526 .26911 .25406 .26787 Metetra
.664 .741 .907 r
.25406 .26787 .25526 .26911 .26124 .26688 .26004 .26564 Metetra
.664 .741 .907 r
.26004 .26564 .26124 .26688 .26724 .26465 .26604 .2634 Metetra
.664 .741 .907 r
.26604 .2634 .26724 .26465 .27324 .26241 .27205 .26116 Metetra
.664 .741 .907 r
.27205 .26116 .27324 .26241 .27927 .26017 .27808 .25891 Metetra
.664 .741 .907 r
.27808 .25891 .27927 .26017 .2853 .25792 .28411 .25666 Metetra
.664 .741 .907 r
.28411 .25666 .2853 .25792 .29135 .25567 .29017 .25441 Metetra
.664 .741 .907 r
.29017 .25441 .29135 .25567 .29742 .25341 .29623 .25214 Metetra
.664 .741 .907 r
.29623 .25214 .29742 .25341 .30349 .25114 .30231 .24988 Metetra
.664 .741 .907 r
.30231 .24988 .30349 .25114 .30959 .24887 .30841 .2476 Metetra
.664 .741 .907 r
.30841 .2476 .30959 .24887 .31569 .2466 .31452 .24533 Metetra
.664 .741 .907 r
.31452 .24533 .31569 .2466 .32181 .24432 .32064 .24304 Metetra
.664 .741 .907 r
.32064 .24304 .32181 .24432 .32795 .24203 .32678 .24075 Metetra
.664 .741 .907 r
.32678 .24075 .32795 .24203 .3341 .23974 .33293 .23846 Metetra
.664 .741 .907 r
.33293 .23846 .3341 .23974 .34026 .23744 .33909 .23616 Metetra
.664 .741 .907 r
.33909 .23616 .34026 .23744 .34644 .23514 .34527 .23386 Metetra
.664 .741 .907 r
.34527 .23386 .34644 .23514 .35263 .23284 .35147 .23155 Metetra
.664 .741 .907 r
.35147 .23155 .35263 .23284 .35883 .23052 .35768 .22923 Metetra
.664 .741 .907 r
.35768 .22923 .35883 .23052 .36505 .22821 .3639 .22691 Metetra
.664 .741 .907 r
.3639 .22691 .36505 .22821 .37129 .22588 .37014 .22459 Metetra
.664 .741 .907 r
.37014 .22459 .37129 .22588 .37754 .22356 .37639 .22225 Metetra
.664 .741 .907 r
.37639 .22225 .37754 .22356 .3838 .22122 .38266 .21992 Metetra
.664 .741 .907 r
.38266 .21992 .3838 .22122 .39008 .21888 .38894 .21758 Metetra
.664 .741 .907 r
.38894 .21758 .39008 .21888 .39637 .21654 .39523 .21523 Metetra
.664 .741 .907 r
.39523 .21523 .39637 .21654 .40268 .21419 .40154 .21287 Metetra
.664 .741 .907 r
.40154 .21287 .40268 .21419 .40901 .21183 .40787 .21052 Metetra
.664 .741 .907 r
.40787 .21052 .40901 .21183 .41534 .20947 .41421 .20815 Metetra
.664 .741 .907 r
.41421 .20815 .41534 .20947 .4217 .2071 .42057 .20578 Metetra
.664 .741 .907 r
.42057 .20578 .4217 .2071 .42806 .20473 .42694 .2034 Metetra
.664 .741 .907 r
.42694 .2034 .42806 .20473 .43445 .20235 .43332 .20102 Metetra
.664 .741 .907 r
.43332 .20102 .43445 .20235 .44085 .19997 .43973 .19864 Metetra
.96 .627 .317 r
.43973 .19864 .44085 .19997 .44173 .41266 .44489 .24429 Metetra
.554 .318 .512 r
.44489 .24429 .44173 .41266 .45301 .22409 .45251 .19644 Metetra
.543 .325 .535 r
.45251 .19644 .45301 .22409 .46013 .19278 .45902 .19144 Metetra
.664 .741 .907 r
.45902 .19144 .46013 .19278 .46659 .19038 .46548 .18903 Metetra
.664 .741 .907 r
.46548 .18903 .46659 .19038 .47307 .18796 .47196 .18662 Metetra
.664 .741 .907 r
.47196 .18662 .47307 .18796 .47956 .18555 .47845 .1842 Metetra
.664 .741 .907 r
.47845 .1842 .47956 .18555 .48606 .18312 .48496 .18177 Metetra
.664 .741 .907 r
.48496 .18177 .48606 .18312 .49258 .18069 .49148 .17934 Metetra
.664 .741 .907 r
.49148 .17934 .49258 .18069 .49912 .17826 .49802 .1769 Metetra
.664 .741 .907 r
.49802 .1769 .49912 .17826 .50567 .17582 .50458 .17445 Metetra
.664 .741 .907 r
.50458 .17445 .50567 .17582 .51224 .17337 .51115 .172 Metetra
.664 .741 .907 r
.51115 .172 .51224 .17337 .51882 .17092 .51774 .16955 Metetra
.664 .741 .907 r
.51774 .16955 .51882 .17092 .52542 .16846 .52434 .16708 Metetra
.664 .741 .907 r
.52434 .16708 .52542 .16846 .53204 .16599 .53096 .16462 Metetra
.664 .741 .907 r
.53096 .16462 .53204 .16599 .53867 .16352 .53759 .16214 Metetra
.664 .741 .907 r
.53759 .16214 .53867 .16352 .54531 .16105 .54424 .15966 Metetra
.664 .741 .907 r
.54424 .15966 .54531 .16105 .55198 .15856 .55091 .15718 Metetra
.664 .741 .907 r
.55091 .15718 .55198 .15856 .55866 .15608 .55759 .15469 Metetra
.664 .741 .907 r
.55759 .15469 .55866 .15608 .56535 .15358 .56429 .15219 Metetra
.664 .741 .907 r
.56429 .15219 .56535 .15358 .57206 .15108 .57101 .14968 Metetra
.664 .741 .907 r
.57101 .14968 .57206 .15108 .57879 .14857 .57774 .14717 Metetra
.664 .741 .907 r
.57774 .14717 .57879 .14857 .58554 .14606 .58448 .14466 Metetra
.664 .741 .907 r
.58448 .14466 .58554 .14606 .5923 .14354 .59125 .14214 Metetra
.664 .741 .907 r
.59125 .14214 .5923 .14354 .59907 .14102 .59803 .13961 Metetra
.664 .741 .907 r
.59803 .13961 .59907 .14102 .60587 .13849 .60483 .13707 Metetra
.664 .741 .907 r
.60483 .13707 .60587 .13849 .61268 .13595 .61164 .13453 Metetra
.664 .741 .907 r
.61164 .13453 .61268 .13595 .61951 .13341 .61847 .13198 Metetra
.664 .741 .907 r
.61847 .13198 .61951 .13341 .62635 .13086 .62532 .12943 Metetra
.664 .741 .907 r
.62532 .12943 .62635 .13086 .63321 .1283 .63218 .12687 Metetra
.664 .741 .907 r
.63218 .12687 .63321 .1283 .64009 .12574 .63906 .12431 Metetra
.664 .741 .907 r
.63906 .12431 .64009 .12574 .64698 .12317 .64596 .12173 Metetra
.664 .741 .907 r
.64596 .12173 .64698 .12317 .65389 .12059 .65287 .11916 Metetra
.664 .741 .907 r
.65287 .11916 .65389 .12059 .66082 .11801 .65981 .11657 Metetra
.664 .741 .907 r
.65981 .11657 .66082 .11801 .66777 .11543 .66675 .11398 Metetra
.664 .741 .907 r
.66675 .11398 .66777 .11543 .67473 .11283 .67372 .11138 Metetra
.664 .741 .907 r
.67372 .11138 .67473 .11283 .68171 .11023 .6807 .10878 Metetra
.664 .741 .907 r
.6807 .10878 .68171 .11023 .6887 .10762 .6877 .10617 Metetra
.664 .741 .907 r
.6877 .10617 .6887 .10762 .69572 .10501 .69472 .10355 Metetra
.664 .741 .907 r
.69472 .10355 .69572 .10501 .70275 .10239 .70176 .10093 Metetra
.664 .741 .907 r
.70176 .10093 .70275 .10239 .7098 .09977 .70881 .0983 Metetra
.664 .741 .907 r
.70881 .0983 .7098 .09977 .71687 .09713 .71588 .09566 Metetra
.664 .741 .907 r
.71588 .09566 .71687 .09713 .72395 .09449 .72297 .09302 Metetra
.664 .741 .907 r
.72297 .09302 .72395 .09449 .73105 .09185 .73007 .09037 Metetra
.664 .741 .907 r
.73007 .09037 .73105 .09185 .73817 .08919 .7372 .08771 Metetra
.664 .741 .907 r
.7372 .08771 .73817 .08919 .74531 .08654 .74434 .08505 Metetra
.664 .741 .907 r
.10753 .32086 .10879 .32204 .11445 .31993 .11319 .31875 Metetra
.664 .741 .907 r
.11319 .31875 .11445 .31993 .12012 .31782 .11886 .31664 Metetra
.664 .741 .907 r
.11886 .31664 .12012 .31782 .1258 .3157 .12455 .31451 Metetra
.664 .741 .907 r
.12455 .31451 .1258 .3157 .13149 .31357 .13024 .31239 Metetra
.664 .741 .907 r
.13024 .31239 .13149 .31357 .1372 .31145 .13595 .31026 Metetra
.664 .741 .907 r
.13595 .31026 .1372 .31145 .14292 .30931 .14167 .30812 Metetra
.664 .741 .907 r
.14167 .30812 .14292 .30931 .14865 .30718 .1474 .30598 Metetra
.664 .741 .907 r
.1474 .30598 .14865 .30718 .15439 .30504 .15315 .30384 Metetra
.664 .741 .907 r
.15315 .30384 .15439 .30504 .16015 .30289 .15891 .30169 Metetra
.664 .741 .907 r
.15891 .30169 .16015 .30289 .16592 .30074 .16468 .29953 Metetra
.664 .741 .907 r
.16468 .29953 .16592 .30074 .1717 .29858 .17047 .29737 Metetra
.664 .741 .907 r
.17047 .29737 .1717 .29858 .1775 .29642 .17627 .29521 Metetra
.664 .741 .907 r
.17627 .29521 .1775 .29642 .18331 .29425 .18208 .29304 Metetra
.664 .741 .907 r
.18208 .29304 .18331 .29425 .18913 .29208 .1879 .29087 Metetra
.664 .741 .907 r
.1879 .29087 .18913 .29208 .19497 .2899 .19374 .28869 Metetra
.664 .741 .907 r
.19374 .28869 .19497 .2899 .20082 .28772 .19959 .28651 Metetra
.664 .741 .907 r
.19959 .28651 .20082 .28772 .20668 .28554 .20546 .28432 Metetra
.664 .741 .907 r
.20546 .28432 .20668 .28554 .21255 .28335 .21134 .28212 Metetra
.664 .741 .907 r
.21134 .28212 .21255 .28335 .21844 .28115 .21723 .27992 Metetra
.664 .741 .907 r
.21723 .27992 .21844 .28115 .22435 .27895 .22313 .27772 Metetra
.664 .741 .907 r
.22313 .27772 .22435 .27895 .23026 .27674 .22905 .27551 Metetra
.664 .741 .907 r
.22905 .27551 .23026 .27674 .23576 .27914 .23498 .2733 Metetra
.579 .426 .638 r
.23498 .2733 .23576 .27914 .24213 .27232 .24093 .27108 Metetra
.664 .741 .907 r
.24093 .27108 .24213 .27232 .24809 .2701 .24688 .26886 Metetra
.664 .741 .907 r
.24688 .26886 .24809 .2701 .25406 .26787 .25286 .26663 Metetra
.664 .741 .907 r
.25286 .26663 .25406 .26787 .26004 .26564 .25884 .26439 Metetra
.664 .741 .907 r
.25884 .26439 .26004 .26564 .26604 .2634 .26484 .26215 Metetra
.664 .741 .907 r
.26484 .26215 .26604 .2634 .27205 .26116 .27086 .25991 Metetra
.664 .741 .907 r
.27086 .25991 .27205 .26116 .27808 .25891 .27688 .25766 Metetra
.664 .741 .907 r
.27688 .25766 .27808 .25891 .28411 .25666 .28292 .2554 Metetra
.664 .741 .907 r
.28292 .2554 .28411 .25666 .29017 .25441 .28898 .25314 Metetra
.664 .741 .907 r
.28898 .25314 .29017 .25441 .29623 .25214 .29505 .25088 Metetra
.664 .741 .907 r
.29505 .25088 .29623 .25214 .30231 .24988 .30113 .24861 Metetra
.664 .741 .907 r
.30113 .24861 .30231 .24988 .30841 .2476 .30723 .24633 Metetra
.664 .741 .907 r
.30723 .24633 .30841 .2476 .31452 .24533 .31334 .24405 Metetra
.664 .741 .907 r
.31334 .24405 .31452 .24533 .32064 .24304 .31946 .24177 Metetra
.664 .741 .907 r
.31946 .24177 .32064 .24304 .32678 .24075 .3256 .23948 Metetra
.664 .741 .907 r
.3256 .23948 .32678 .24075 .33293 .23846 .33176 .23718 Metetra
.664 .741 .907 r
.33176 .23718 .33293 .23846 .33909 .23616 .33793 .23488 Metetra
.467 .662 .947 r
.33793 .23488 .33909 .23616 .34527 .23386 .34397 .23483 Metetra
.34397 .23483 .34527 .23386 .35147 .23155 .35031 .23026 Metetra
.664 .741 .907 r
.35031 .23026 .35147 .23155 .35768 .22923 .35652 .22794 Metetra
.664 .741 .907 r
.35652 .22794 .35768 .22923 .3639 .22691 .36274 .22562 Metetra
.664 .741 .907 r
.36274 .22562 .3639 .22691 .37014 .22459 .36898 .22329 Metetra
.664 .741 .907 r
.36898 .22329 .37014 .22459 .37639 .22225 .37524 .22095 Metetra
.664 .741 .907 r
.37524 .22095 .37639 .22225 .38266 .21992 .38151 .21861 Metetra
.664 .741 .907 r
.38151 .21861 .38266 .21992 .38894 .21758 .38779 .21627 Metetra
.664 .741 .907 r
.38779 .21627 .38894 .21758 .39523 .21523 .39409 .21392 Metetra
.664 .741 .907 r
.39409 .21392 .39523 .21523 .40154 .21287 .40041 .21156 Metetra
.664 .741 .907 r
.40041 .21156 .40154 .21287 .40787 .21052 .40673 .2092 Metetra
.664 .741 .907 r
.40673 .2092 .40787 .21052 .41421 .20815 .41308 .20683 Metetra
.664 .741 .907 r
.41308 .20683 .41421 .20815 .42057 .20578 .41944 .20446 Metetra
.664 .741 .907 r
.41944 .20446 .42057 .20578 .42694 .2034 .42581 .20208 Metetra
.664 .741 .907 r
.42581 .20208 .42694 .2034 .43332 .20102 .4322 .19969 Metetra
.664 .741 .907 r
.4322 .19969 .43332 .20102 .43973 .19864 .4386 .1973 Metetra
.664 .741 .907 r
.4386 .1973 .43973 .19864 .44489 .24429 .44502 .19491 Metetra
.524 .301 .519 r
.44502 .19491 .44489 .24429 .45251 .19644 .45146 .19251 Metetra
.605 .493 .7 r
.45146 .19251 .45251 .19644 .45902 .19144 .45791 .1901 Metetra
.664 .741 .907 r
.45791 .1901 .45902 .19144 .46548 .18903 .46437 .18769 Metetra
.664 .741 .907 r
.46437 .18769 .46548 .18903 .47196 .18662 .47085 .18527 Metetra
.664 .741 .907 r
.47085 .18527 .47196 .18662 .47845 .1842 .47735 .18284 Metetra
.664 .741 .907 r
.47735 .18284 .47845 .1842 .48496 .18177 .48386 .18041 Metetra
.664 .741 .907 r
.48386 .18041 .48496 .18177 .49148 .17934 .49039 .17798 Metetra
.664 .741 .907 r
.49039 .17798 .49148 .17934 .49802 .1769 .49693 .17554 Metetra
.664 .741 .907 r
.49693 .17554 .49802 .1769 .50458 .17445 .50349 .17309 Metetra
.664 .741 .907 r
.50349 .17309 .50458 .17445 .51115 .172 .51006 .17063 Metetra
.664 .741 .907 r
.51006 .17063 .51115 .172 .51774 .16955 .51665 .16817 Metetra
.664 .741 .907 r
.51665 .16817 .51774 .16955 .52434 .16708 .52326 .16571 Metetra
.664 .741 .907 r
.52326 .16571 .52434 .16708 .53096 .16462 .52988 .16324 Metetra
.664 .741 .907 r
.52988 .16324 .53096 .16462 .53759 .16214 .53652 .16076 Metetra
.664 .741 .907 r
.53652 .16076 .53759 .16214 .54424 .15966 .54317 .15828 Metetra
.664 .741 .907 r
.54317 .15828 .54424 .15966 .55091 .15718 .54984 .15579 Metetra
.664 .741 .907 r
.54984 .15579 .55091 .15718 .55759 .15469 .55652 .15329 Metetra
.664 .741 .907 r
.55652 .15329 .55759 .15469 .56429 .15219 .56323 .15079 Metetra
.664 .741 .907 r
.56323 .15079 .56429 .15219 .57101 .14968 .56994 .14828 Metetra
.664 .741 .907 r
.56994 .14828 .57101 .14968 .57774 .14717 .57668 .14577 Metetra
.664 .741 .907 r
.57668 .14577 .57774 .14717 .58448 .14466 .58343 .14325 Metetra
.664 .741 .907 r
.58343 .14325 .58448 .14466 .59125 .14214 .5902 .14073 Metetra
.664 .741 .907 r
.5902 .14073 .59125 .14214 .59803 .13961 .59698 .13819 Metetra
.664 .741 .907 r
.59698 .13819 .59803 .13961 .60483 .13707 .60378 .13566 Metetra
.664 .741 .907 r
.60378 .13566 .60483 .13707 .61164 .13453 .6106 .13311 Metetra
.664 .741 .907 r
.6106 .13311 .61164 .13453 .61847 .13198 .61743 .13056 Metetra
.664 .741 .907 r
.61743 .13056 .61847 .13198 .62532 .12943 .62428 .128 Metetra
.664 .741 .907 r
.62428 .128 .62532 .12943 .63218 .12687 .63115 .12544 Metetra
.664 .741 .907 r
.63115 .12544 .63218 .12687 .63906 .12431 .63803 .12287 Metetra
.664 .741 .907 r
.63803 .12287 .63906 .12431 .64596 .12173 .64494 .1203 Metetra
.664 .741 .907 r
.64494 .1203 .64596 .12173 .65287 .11916 .65185 .11771 Metetra
.664 .741 .907 r
.65185 .11771 .65287 .11916 .65981 .11657 .65879 .11513 Metetra
.664 .741 .907 r
.65879 .11513 .65981 .11657 .66675 .11398 .66574 .11253 Metetra
.664 .741 .907 r
.66574 .11253 .66675 .11398 .67372 .11138 .67271 .10993 Metetra
.664 .741 .907 r
.67271 .10993 .67372 .11138 .6807 .10878 .6797 .10732 Metetra
.664 .741 .907 r
.6797 .10732 .6807 .10878 .6877 .10617 .6867 .10471 Metetra
.664 .741 .907 r
.6867 .10471 .6877 .10617 .69472 .10355 .69372 .10209 Metetra
.664 .741 .907 r
.69372 .10209 .69472 .10355 .70176 .10093 .70076 .09946 Metetra
.664 .741 .907 r
.70076 .09946 .70176 .10093 .70881 .0983 .70782 .09683 Metetra
.664 .741 .907 r
.70782 .09683 .70881 .0983 .71588 .09566 .71489 .09419 Metetra
.664 .741 .907 r
.71489 .09419 .71588 .09566 .72297 .09302 .72198 .09154 Metetra
.664 .741 .907 r
.72198 .09154 .72297 .09302 .73007 .09037 .72909 .08889 Metetra
.664 .741 .907 r
.72909 .08889 .73007 .09037 .7372 .08771 .73622 .08623 Metetra
.664 .741 .907 r
.73622 .08623 .7372 .08771 .74434 .08505 .74336 .08356 Metetra
.664 .741 .907 r
.10627 .31969 .10753 .32086 .11319 .31875 .11193 .31757 Metetra
.664 .741 .907 r
.11193 .31757 .11319 .31875 .11886 .31664 .11761 .31545 Metetra
.664 .741 .907 r
.11761 .31545 .11886 .31664 .12455 .31451 .12329 .31333 Metetra
.664 .741 .907 r
.12329 .31333 .12455 .31451 .13024 .31239 .12899 .3112 Metetra
.664 .741 .907 r
.12899 .3112 .13024 .31239 .13595 .31026 .1347 .30907 Metetra
.664 .741 .907 r
.1347 .30907 .13595 .31026 .14167 .30812 .14042 .30693 Metetra
.664 .741 .907 r
.14042 .30693 .14167 .30812 .1474 .30598 .14616 .30479 Metetra
.664 .741 .907 r
.14616 .30479 .1474 .30598 .15315 .30384 .15191 .30264 Metetra
.664 .741 .907 r
.15191 .30264 .15315 .30384 .15891 .30169 .15767 .30049 Metetra
.664 .741 .907 r
.15767 .30049 .15891 .30169 .16468 .29953 .16344 .29833 Metetra
.664 .741 .907 r
.16344 .29833 .16468 .29953 .17047 .29737 .16923 .29617 Metetra
.664 .741 .907 r
.16923 .29617 .17047 .29737 .17627 .29521 .17503 .294 Metetra
.664 .741 .907 r
.17503 .294 .17627 .29521 .18208 .29304 .18085 .29183 Metetra
.664 .741 .907 r
.18085 .29183 .18208 .29304 .1879 .29087 .18667 .28965 Metetra
.664 .741 .907 r
.18667 .28965 .1879 .29087 .19374 .28869 .19251 .28747 Metetra
.664 .741 .907 r
.19251 .28747 .19374 .28869 .19959 .28651 .19837 .28528 Metetra
.664 .741 .907 r
.19837 .28528 .19959 .28651 .20546 .28432 .20423 .28309 Metetra
.664 .741 .907 r
.20423 .28309 .20546 .28432 .21134 .28212 .21012 .2809 Metetra
.664 .741 .907 r
.21012 .2809 .21134 .28212 .21723 .27992 .21601 .2787 Metetra
.664 .741 .907 r
.21601 .2787 .21723 .27992 .22313 .27772 .22192 .27649 Metetra
.664 .741 .907 r
.22192 .27649 .22313 .27772 .22905 .27551 .22784 .27428 Metetra
.664 .741 .907 r
.22784 .27428 .22905 .27551 .23498 .2733 .23377 .27206 Metetra
.664 .741 .907 r
.23377 .27206 .23498 .2733 .24093 .27108 .23972 .26984 Metetra
.664 .741 .907 r
.23972 .26984 .24093 .27108 .24688 .26886 .24568 .26761 Metetra
.664 .741 .907 r
.24568 .26761 .24688 .26886 .25286 .26663 .25165 .26538 Metetra
.664 .741 .907 r
.25165 .26538 .25286 .26663 .25884 .26439 .25764 .26314 Metetra
.664 .741 .907 r
.25764 .26314 .25884 .26439 .26484 .26215 .26364 .2609 Metetra
.664 .741 .907 r
.26364 .2609 .26484 .26215 .27086 .25991 .26966 .25865 Metetra
.664 .741 .907 r
.26966 .25865 .27086 .25991 .27688 .25766 .27569 .2564 Metetra
.664 .741 .907 r
.27569 .2564 .27688 .25766 .28292 .2554 .28173 .25414 Metetra
.664 .741 .907 r
.28173 .25414 .28292 .2554 .28898 .25314 .28779 .25188 Metetra
.664 .741 .907 r
.28779 .25188 .28898 .25314 .29505 .25088 .29386 .24961 Metetra
.664 .741 .907 r
.29386 .24961 .29505 .25088 .30113 .24861 .29995 .24734 Metetra
.664 .741 .907 r
.29995 .24734 .30113 .24861 .30723 .24633 .30605 .24506 Metetra
.664 .741 .907 r
.30605 .24506 .30723 .24633 .31334 .24405 .31216 .24278 Metetra
.664 .741 .907 r
.31216 .24278 .31334 .24405 .31946 .24177 .31829 .24049 Metetra
.664 .741 .907 r
.31829 .24049 .31946 .24177 .3256 .23948 .32443 .2382 Metetra
.664 .741 .907 r
.32443 .2382 .3256 .23948 .33176 .23718 .33059 .2359 Metetra
.664 .741 .907 r
.33059 .2359 .33176 .23718 .33793 .23488 .33676 .23359 Metetra
.962 .675 .443 r
.33676 .23359 .33793 .23488 .34397 .23483 .33366 .38708 Metetra
.339 .137 .453 r
.33366 .38708 .34397 .23483 .35031 .23026 .34894 .23243 Metetra
.34894 .23243 .35031 .23026 .35652 .22794 .35536 .22664 Metetra
.664 .741 .907 r
.35536 .22664 .35652 .22794 .36274 .22562 .36159 .22432 Metetra
.664 .741 .907 r
.36159 .22432 .36274 .22562 .36898 .22329 .36783 .22198 Metetra
.664 .741 .907 r
.36783 .22198 .36898 .22329 .37524 .22095 .37409 .21965 Metetra
.664 .741 .907 r
.37409 .21965 .37524 .22095 .38151 .21861 .38036 .2173 Metetra
.664 .741 .907 r
.38036 .2173 .38151 .21861 .38779 .21627 .38665 .21496 Metetra
.664 .741 .907 r
.38665 .21496 .38779 .21627 .39409 .21392 .39295 .2126 Metetra
.664 .741 .907 r
.39295 .2126 .39409 .21392 .40041 .21156 .39926 .21024 Metetra
.664 .741 .907 r
.39926 .21024 .40041 .21156 .40673 .2092 .4056 .20788 Metetra
.664 .741 .907 r
.4056 .20788 .40673 .2092 .41308 .20683 .41194 .20551 Metetra
.664 .741 .907 r
.41194 .20551 .41308 .20683 .41944 .20446 .4183 .20313 Metetra
.664 .741 .907 r
.4183 .20313 .41944 .20446 .42581 .20208 .42468 .20075 Metetra
.664 .741 .907 r
.42468 .20075 .42581 .20208 .4322 .19969 .43107 .19836 Metetra
.664 .741 .907 r
.43107 .19836 .4322 .19969 .4386 .1973 .43748 .19597 Metetra
.664 .741 .907 r
.43748 .19597 .4386 .1973 .44502 .19491 .4439 .19357 Metetra
.664 .741 .907 r
.4439 .19357 .44502 .19491 .45146 .19251 .45034 .19116 Metetra
.664 .741 .907 r
.45034 .19116 .45146 .19251 .45791 .1901 .45679 .18875 Metetra
.664 .741 .907 r
.45679 .18875 .45791 .1901 .46437 .18769 .46326 .18634 Metetra
.664 .741 .907 r
.46326 .18634 .46437 .18769 .47085 .18527 .46974 .18392 Metetra
.664 .741 .907 r
.46974 .18392 .47085 .18527 .47735 .18284 .47624 .18149 Metetra
.664 .741 .907 r
.47624 .18149 .47735 .18284 .48386 .18041 .48276 .17905 Metetra
.664 .741 .907 r
.48276 .17905 .48386 .18041 .49039 .17798 .48929 .17662 Metetra
.664 .741 .907 r
.48929 .17662 .49039 .17798 .49693 .17554 .49583 .17417 Metetra
.664 .741 .907 r
.49583 .17417 .49693 .17554 .50349 .17309 .50239 .17172 Metetra
.664 .741 .907 r
.50239 .17172 .50349 .17309 .51006 .17063 .50897 .16926 Metetra
.664 .741 .907 r
.50897 .16926 .51006 .17063 .51665 .16817 .51556 .1668 Metetra
.664 .741 .907 r
.51556 .1668 .51665 .16817 .52326 .16571 .52217 .16433 Metetra
.664 .741 .907 r
.52217 .16433 .52326 .16571 .52988 .16324 .5288 .16186 Metetra
.664 .741 .907 r
.5288 .16186 .52988 .16324 .53652 .16076 .53544 .15938 Metetra
.664 .741 .907 r
.53544 .15938 .53652 .16076 .54317 .15828 .54209 .15689 Metetra
.664 .741 .907 r
.54209 .15689 .54317 .15828 .54984 .15579 .54877 .1544 Metetra
.664 .741 .907 r
.54877 .1544 .54984 .15579 .55652 .15329 .55546 .1519 Metetra
.664 .741 .907 r
.55546 .1519 .55652 .15329 .56323 .15079 .56216 .14939 Metetra
.664 .741 .907 r
.56216 .14939 .56323 .15079 .56994 .14828 .56888 .14688 Metetra
.664 .741 .907 r
.56888 .14688 .56994 .14828 .57668 .14577 .57562 .14437 Metetra
.664 .741 .907 r
.57562 .14437 .57668 .14577 .58343 .14325 .58237 .14184 Metetra
.664 .741 .907 r
.58237 .14184 .58343 .14325 .5902 .14073 .58915 .13931 Metetra
.664 .741 .907 r
.58915 .13931 .5902 .14073 .59698 .13819 .59593 .13678 Metetra
.664 .741 .907 r
.59593 .13678 .59698 .13819 .60378 .13566 .60274 .13424 Metetra
.664 .741 .907 r
.60274 .13424 .60378 .13566 .6106 .13311 .60956 .13169 Metetra
.664 .741 .907 r
.60956 .13169 .6106 .13311 .61743 .13056 .61639 .12914 Metetra
.664 .741 .907 r
.61639 .12914 .61743 .13056 .62428 .128 .62325 .12658 Metetra
.664 .741 .907 r
.62325 .12658 .62428 .128 .63115 .12544 .63012 .12401 Metetra
.664 .741 .907 r
.63012 .12401 .63115 .12544 .63803 .12287 .63701 .12144 Metetra
.664 .741 .907 r
.63701 .12144 .63803 .12287 .64494 .1203 .64391 .11886 Metetra
.664 .741 .907 r
.64391 .11886 .64494 .1203 .65185 .11771 .65083 .11627 Metetra
.664 .741 .907 r
.65083 .11627 .65185 .11771 .65879 .11513 .65777 .11368 Metetra
.664 .741 .907 r
.65777 .11368 .65879 .11513 .66574 .11253 .66473 .11108 Metetra
.664 .741 .907 r
.66473 .11108 .66574 .11253 .67271 .10993 .6717 .10848 Metetra
.906 .527 .087 r
.6717 .10848 .67271 .10993 .6797 .10732 .68054 .14112 Metetra
.351 .143 .451 r
.68054 .14112 .6797 .10732 .6867 .10471 .6857 .10325 Metetra
.664 .741 .907 r
.6857 .10325 .6867 .10471 .69372 .10209 .69272 .10062 Metetra
.664 .741 .907 r
.69272 .10062 .69372 .10209 .70076 .09946 .69977 .09799 Metetra
.664 .741 .907 r
.69977 .09799 .70076 .09946 .70782 .09683 .70683 .09536 Metetra
.664 .741 .907 r
.70683 .09536 .70782 .09683 .71489 .09419 .7139 .09271 Metetra
.664 .741 .907 r
.7139 .09271 .71489 .09419 .72198 .09154 .721 .09006 Metetra
.664 .741 .907 r
.721 .09006 .72198 .09154 .72909 .08889 .72811 .08741 Metetra
.664 .741 .907 r
.72811 .08741 .72909 .08889 .73622 .08623 .73524 .08474 Metetra
.664 .741 .907 r
.73524 .08474 .73622 .08623 .74336 .08356 .74239 .08207 Metetra
.664 .741 .907 r
.10501 .31851 .10627 .31969 .11193 .31757 .11067 .31639 Metetra
.664 .741 .907 r
.11067 .31639 .11193 .31757 .11761 .31545 .11635 .31427 Metetra
.664 .741 .907 r
.11635 .31427 .11761 .31545 .12329 .31333 .12204 .31214 Metetra
.664 .741 .907 r
.12204 .31214 .12329 .31333 .12899 .3112 .12774 .31001 Metetra
.664 .741 .907 r
.12774 .31001 .12899 .3112 .1347 .30907 .13345 .30788 Metetra
.664 .741 .907 r
.13345 .30788 .1347 .30907 .14042 .30693 .13917 .30574 Metetra
.664 .741 .907 r
.13917 .30574 .14042 .30693 .14616 .30479 .14491 .30359 Metetra
.664 .741 .907 r
.14491 .30359 .14616 .30479 .15191 .30264 .15066 .30144 Metetra
.664 .741 .907 r
.15066 .30144 .15191 .30264 .15767 .30049 .15643 .29928 Metetra
.664 .741 .907 r
.15643 .29928 .15767 .30049 .16344 .29833 .1622 .29713 Metetra
.664 .741 .907 r
.1622 .29713 .16344 .29833 .16923 .29617 .16799 .29496 Metetra
.664 .741 .907 r
.16799 .29496 .16923 .29617 .17503 .294 .1738 .29279 Metetra
.664 .741 .907 r
.1738 .29279 .17503 .294 .18085 .29183 .17961 .29062 Metetra
.664 .741 .907 r
.17961 .29062 .18085 .29183 .18667 .28965 .18544 .28844 Metetra
.664 .741 .907 r
.18544 .28844 .18667 .28965 .19251 .28747 .19129 .28625 Metetra
.664 .741 .907 r
.19129 .28625 .19251 .28747 .19837 .28528 .19714 .28406 Metetra
.664 .741 .907 r
.19714 .28406 .19837 .28528 .20423 .28309 .20301 .28187 Metetra
.664 .741 .907 r
.20301 .28187 .20423 .28309 .21012 .2809 .20889 .27967 Metetra
.664 .741 .907 r
.20889 .27967 .21012 .2809 .21601 .2787 .21479 .27747 Metetra
.664 .741 .907 r
.21479 .27747 .21601 .2787 .22192 .27649 .2207 .27526 Metetra
.664 .741 .907 r
.2207 .27526 .22192 .27649 .22784 .27428 .22662 .27304 Metetra
.664 .741 .907 r
.22662 .27304 .22784 .27428 .23377 .27206 .23256 .27082 Metetra
.664 .741 .907 r
.23256 .27082 .23377 .27206 .23972 .26984 .23851 .2686 Metetra
.664 .741 .907 r
.23851 .2686 .23972 .26984 .24568 .26761 .24447 .26637 Metetra
.664 .741 .907 r
.24447 .26637 .24568 .26761 .25165 .26538 .25045 .26413 Metetra
.664 .741 .907 r
.25045 .26413 .25165 .26538 .25764 .26314 .25644 .26189 Metetra
.664 .741 .907 r
.25644 .26189 .25764 .26314 .26364 .2609 .26244 .25965 Metetra
.664 .741 .907 r
.26244 .25965 .26364 .2609 .26966 .25865 .26846 .2574 Metetra
.664 .741 .907 r
.26846 .2574 .26966 .25865 .27569 .2564 .27449 .25514 Metetra
.664 .741 .907 r
.27449 .25514 .27569 .2564 .28173 .25414 .28054 .25288 Metetra
.664 .741 .907 r
.28054 .25288 .28173 .25414 .28779 .25188 .2866 .25062 Metetra
.664 .741 .907 r
.2866 .25062 .28779 .25188 .29386 .24961 .29267 .24835 Metetra
.664 .741 .907 r
.29267 .24835 .29386 .24961 .29995 .24734 .29876 .24607 Metetra
.664 .741 .907 r
.29876 .24607 .29995 .24734 .30605 .24506 .30486 .24379 Metetra
.664 .741 .907 r
.30486 .24379 .30605 .24506 .31216 .24278 .31098 .2415 Metetra
.664 .741 .907 r
.31098 .2415 .31216 .24278 .31829 .24049 .31711 .23921 Metetra
.664 .741 .907 r
.31711 .23921 .31829 .24049 .32443 .2382 .32326 .23691 Metetra
.664 .741 .907 r
.32326 .23691 .32443 .2382 .33059 .2359 .32942 .23461 Metetra
.958 .634 .361 r
.32942 .23461 .33059 .2359 .33676 .23359 .33285 .2765 Metetra
.788 .509 .515 r
.33285 .2765 .33676 .23359 .33366 .38708 .32763 .46578 Metetra
0 0 .202 r
.32763 .46578 .33366 .38708 .34894 .23243 .34798 .22767 Metetra
.591 .458 .668 r
.34798 .22767 .34894 .23243 .35536 .22664 .3542 .22535 Metetra
.664 .741 .907 r
.3542 .22535 .35536 .22664 .36159 .22432 .36043 .22302 Metetra
.664 .741 .907 r
.36043 .22302 .36159 .22432 .36783 .22198 .36667 .22068 Metetra
.664 .741 .907 r
.36667 .22068 .36783 .22198 .37409 .21965 .37293 .21834 Metetra
.664 .741 .907 r
.37293 .21834 .37409 .21965 .38036 .2173 .37921 .216 Metetra
.664 .741 .907 r
.37921 .216 .38036 .2173 .38665 .21496 .3855 .21364 Metetra
.664 .741 .907 r
.3855 .21364 .38665 .21496 .39295 .2126 .3918 .21129 Metetra
.664 .741 .907 r
.3918 .21129 .39295 .2126 .39926 .21024 .39812 .20892 Metetra
.664 .741 .907 r
.39812 .20892 .39926 .21024 .4056 .20788 .40446 .20656 Metetra
.664 .741 .907 r
.40446 .20656 .4056 .20788 .41194 .20551 .41081 .20418 Metetra
.664 .741 .907 r
.41081 .20418 .41194 .20551 .4183 .20313 .41717 .2018 Metetra
.664 .741 .907 r
.41717 .2018 .4183 .20313 .42468 .20075 .42355 .19942 Metetra
.664 .741 .907 r
.42355 .19942 .42468 .20075 .43107 .19836 .42994 .19703 Metetra
.664 .741 .907 r
.42994 .19703 .43107 .19836 .43748 .19597 .43635 .19463 Metetra
.664 .741 .907 r
.43635 .19463 .43748 .19597 .4439 .19357 .44278 .19223 Metetra
.664 .741 .907 r
.44278 .19223 .4439 .19357 .45034 .19116 .44922 .18982 Metetra
.664 .741 .907 r
.44922 .18982 .45034 .19116 .45679 .18875 .45567 .18741 Metetra
.664 .741 .907 r
.45567 .18741 .45679 .18875 .46326 .18634 .46215 .18499 Metetra
.664 .741 .907 r
.46215 .18499 .46326 .18634 .46974 .18392 .46863 .18256 Metetra
.664 .741 .907 r
.46863 .18256 .46974 .18392 .47624 .18149 .47513 .18013 Metetra
.664 .741 .907 r
.47513 .18013 .47624 .18149 .48276 .17905 .48165 .1777 Metetra
.664 .741 .907 r
.48165 .1777 .48276 .17905 .48929 .17662 .48818 .17525 Metetra
.664 .741 .907 r
.48818 .17525 .48929 .17662 .49583 .17417 .49473 .1728 Metetra
.664 .741 .907 r
.49473 .1728 .49583 .17417 .50239 .17172 .5013 .17035 Metetra
.664 .741 .907 r
.5013 .17035 .50239 .17172 .50897 .16926 .50788 .16789 Metetra
.664 .741 .907 r
.50788 .16789 .50897 .16926 .51556 .1668 .51447 .16542 Metetra
.664 .741 .907 r
.51447 .16542 .51556 .1668 .52217 .16433 .52109 .16295 Metetra
.664 .741 .907 r
.52109 .16295 .52217 .16433 .5288 .16186 .52771 .16047 Metetra
.664 .741 .907 r
.52771 .16047 .5288 .16186 .53544 .15938 .53436 .15799 Metetra
.664 .741 .907 r
.53436 .15799 .53544 .15938 .54209 .15689 .54102 .1555 Metetra
.664 .741 .907 r
.54102 .1555 .54209 .15689 .54877 .1544 .54769 .153 Metetra
.664 .741 .907 r
.54769 .153 .54877 .1544 .55546 .1519 .55439 .1505 Metetra
.664 .741 .907 r
.55439 .1505 .55546 .1519 .56216 .14939 .56109 .14799 Metetra
.664 .741 .907 r
.56109 .14799 .56216 .14939 .56888 .14688 .56782 .14548 Metetra
.664 .741 .907 r
.56782 .14548 .56888 .14688 .57562 .14437 .57456 .14296 Metetra
.664 .741 .907 r
.57456 .14296 .57562 .14437 .58237 .14184 .58132 .14043 Metetra
.664 .741 .907 r
.58132 .14043 .58237 .14184 .58915 .13931 .58809 .1379 Metetra
.664 .741 .907 r
.58809 .1379 .58915 .13931 .59593 .13678 .59488 .13536 Metetra
.664 .741 .907 r
.59488 .13536 .59593 .13678 .60274 .13424 .60169 .13282 Metetra
.664 .741 .907 r
.60169 .13282 .60274 .13424 .60956 .13169 .60851 .13027 Metetra
.664 .741 .907 r
.60851 .13027 .60956 .13169 .61639 .12914 .61535 .12771 Metetra
.664 .741 .907 r
.61535 .12771 .61639 .12914 .62325 .12658 .62221 .12514 Metetra
.664 .741 .907 r
.62221 .12514 .62325 .12658 .63012 .12401 .62909 .12257 Metetra
.664 .741 .907 r
.62909 .12257 .63012 .12401 .63701 .12144 .63598 .12 Metetra
.664 .741 .907 r
.63598 .12 .63701 .12144 .64391 .11886 .64288 .11742 Metetra
.664 .741 .907 r
.64288 .11742 .64391 .11886 .65083 .11627 .64981 .11483 Metetra
.664 .741 .907 r
.64981 .11483 .65083 .11627 .65777 .11368 .65675 .11223 Metetra
.664 .741 .907 r
.65675 .11223 .65777 .11368 .66473 .11108 .66371 .10963 Metetra
.664 .741 .907 r
.66371 .10963 .66473 .11108 .6717 .10848 .67069 .10702 Metetra
.866 .469 0 r
.67069 .10702 .6717 .10848 .68054 .14112 .67911 .13177 Metetra
.78 .533 .562 r
.67911 .13177 .68054 .14112 .6857 .10325 .68469 .10179 Metetra
.664 .741 .907 r
.68469 .10179 .6857 .10325 .69272 .10062 .69172 .09916 Metetra
.664 .741 .907 r
.69172 .09916 .69272 .10062 .69977 .09799 .69877 .09652 Metetra
.664 .741 .907 r
.69877 .09652 .69977 .09799 .70683 .09536 .70583 .09388 Metetra
.664 .741 .907 r
.70583 .09388 .70683 .09536 .7139 .09271 .71291 .09123 Metetra
.664 .741 .907 r
.71291 .09123 .7139 .09271 .721 .09006 .72001 .08858 Metetra
.664 .741 .907 r
.72001 .08858 .721 .09006 .72811 .08741 .72713 .08592 Metetra
.664 .741 .907 r
.72713 .08592 .72811 .08741 .73524 .08474 .73426 .08325 Metetra
.664 .741 .907 r
.73426 .08325 .73524 .08474 .74239 .08207 .74141 .08058 Metetra
.664 .741 .907 r
.10375 .31733 .10501 .31851 .11067 .31639 .10941 .31521 Metetra
.664 .741 .907 r
.10941 .31521 .11067 .31639 .11635 .31427 .11509 .31308 Metetra
.664 .741 .907 r
.11509 .31308 .11635 .31427 .12204 .31214 .12078 .31095 Metetra
.664 .741 .907 r
.12078 .31095 .12204 .31214 .12774 .31001 .12648 .30882 Metetra
.664 .741 .907 r
.12648 .30882 .12774 .31001 .13345 .30788 .1322 .30668 Metetra
.664 .741 .907 r
.1322 .30668 .13345 .30788 .13917 .30574 .13792 .30454 Metetra
.664 .741 .907 r
.13792 .30454 .13917 .30574 .14491 .30359 .14366 .30239 Metetra
.664 .741 .907 r
.14366 .30239 .14491 .30359 .15066 .30144 .14942 .30024 Metetra
.664 .741 .907 r
.14942 .30024 .15066 .30144 .15643 .29928 .15518 .29808 Metetra
.664 .741 .907 r
.15518 .29808 .15643 .29928 .1622 .29713 .16096 .29592 Metetra
.664 .741 .907 r
.16096 .29592 .1622 .29713 .16799 .29496 .16675 .29375 Metetra
.664 .741 .907 r
.16675 .29375 .16799 .29496 .1738 .29279 .17256 .29158 Metetra
.664 .741 .907 r
.17256 .29158 .1738 .29279 .17961 .29062 .17838 .2894 Metetra
.703 .207 0 r
.17838 .2894 .17961 .29062 .18544 .28844 .18323 .29613 Metetra
.615 .315 .438 r
.18323 .29613 .18544 .28844 .19129 .28625 .18799 .3042 Metetra
.271 .044 .374 r
.18799 .3042 .19129 .28625 .19714 .28406 .19591 .28284 Metetra
.664 .741 .907 r
.19591 .28284 .19714 .28406 .20301 .28187 .20178 .28064 Metetra
.664 .741 .907 r
.20178 .28064 .20301 .28187 .20889 .27967 .20767 .27844 Metetra
.664 .741 .907 r
.20767 .27844 .20889 .27967 .21479 .27747 .21357 .27623 Metetra
.664 .741 .907 r
.21357 .27623 .21479 .27747 .2207 .27526 .21948 .27402 Metetra
.664 .741 .907 r
.21948 .27402 .2207 .27526 .22662 .27304 .2254 .2718 Metetra
.664 .741 .907 r
.2254 .2718 .22662 .27304 .23256 .27082 .23134 .26958 Metetra
.664 .741 .907 r
.23134 .26958 .23256 .27082 .23851 .2686 .2373 .26736 Metetra
.664 .741 .907 r
.2373 .26736 .23851 .2686 .24447 .26637 .24326 .26512 Metetra
.664 .741 .907 r
.24326 .26512 .24447 .26637 .25045 .26413 .24924 .26289 Metetra
.664 .741 .907 r
.24924 .26289 .25045 .26413 .25644 .26189 .25523 .26064 Metetra
.664 .741 .907 r
.25523 .26064 .25644 .26189 .26244 .25965 .26124 .25839 Metetra
.664 .741 .907 r
.26124 .25839 .26244 .25965 .26846 .2574 .26726 .25614 Metetra
.664 .741 .907 r
.26726 .25614 .26846 .2574 .27449 .25514 .2733 .25388 Metetra
.664 .741 .907 r
.2733 .25388 .27449 .25514 .28054 .25288 .27935 .25162 Metetra
.664 .741 .907 r
.27935 .25162 .28054 .25288 .2866 .25062 .28541 .24935 Metetra
.664 .741 .907 r
.28541 .24935 .2866 .25062 .29267 .24835 .29149 .24708 Metetra
.664 .741 .907 r
.29149 .24708 .29267 .24835 .29876 .24607 .29758 .2448 Metetra
.664 .741 .907 r
.29758 .2448 .29876 .24607 .30486 .24379 .30368 .24251 Metetra
.664 .741 .907 r
.30368 .24251 .30486 .24379 .31098 .2415 .3098 .24023 Metetra
.664 .741 .907 r
.3098 .24023 .31098 .2415 .31711 .23921 .31593 .23793 Metetra
.664 .741 .907 r
.31593 .23793 .31711 .23921 .32326 .23691 .32208 .23563 Metetra
.664 .741 .907 r
.32208 .23563 .32326 .23691 .32942 .23461 .32824 .23332 Metetra
.961 .66 .412 r
.32824 .23332 .32942 .23461 .33285 .2765 .32969 .30682 Metetra
.752 .473 .509 r
.32969 .30682 .33285 .2765 .32763 .46578 .32997 .40486 Metetra
.76 .496 .535 r
.32997 .40486 .32763 .46578 .34798 .22767 .34681 .22637 Metetra
.664 .741 .907 r
.34681 .22637 .34798 .22767 .3542 .22535 .35303 .22405 Metetra
.664 .741 .907 r
.35303 .22405 .3542 .22535 .36043 .22302 .35927 .22172 Metetra
.664 .741 .907 r
.35927 .22172 .36043 .22302 .36667 .22068 .36551 .21938 Metetra
.664 .741 .907 r
.36551 .21938 .36667 .22068 .37293 .21834 .37178 .21703 Metetra
.664 .741 .907 r
.37178 .21703 .37293 .21834 .37921 .216 .37806 .21468 Metetra
.664 .741 .907 r
.37806 .21468 .37921 .216 .3855 .21364 .38435 .21233 Metetra
.664 .741 .907 r
.38435 .21233 .3855 .21364 .3918 .21129 .39066 .20997 Metetra
.664 .741 .907 r
.39066 .20997 .3918 .21129 .39812 .20892 .39698 .2076 Metetra
.664 .741 .907 r
.39698 .2076 .39812 .20892 .40446 .20656 .40332 .20523 Metetra
.664 .741 .907 r
.40332 .20523 .40446 .20656 .41081 .20418 .40967 .20286 Metetra
.664 .741 .907 r
.40967 .20286 .41081 .20418 .41717 .2018 .41604 .20047 Metetra
.664 .741 .907 r
.41604 .20047 .41717 .2018 .42355 .19942 .42242 .19808 Metetra
.664 .741 .907 r
.42242 .19808 .42355 .19942 .42994 .19703 .42881 .19569 Metetra
.664 .741 .907 r
.42881 .19569 .42994 .19703 .43635 .19463 .43523 .19329 Metetra
.664 .741 .907 r
.43523 .19329 .43635 .19463 .44278 .19223 .44166 .19089 Metetra
.664 .741 .907 r
.44166 .19089 .44278 .19223 .44922 .18982 .4481 .18847 Metetra
.664 .741 .907 r
.4481 .18847 .44922 .18982 .45567 .18741 .45456 .18606 Metetra
.664 .741 .907 r
.45456 .18606 .45567 .18741 .46215 .18499 .46103 .18364 Metetra
.664 .741 .907 r
.46103 .18364 .46215 .18499 .46863 .18256 .46752 .18121 Metetra
.664 .741 .907 r
.46752 .18121 .46863 .18256 .47513 .18013 .47403 .17877 Metetra
.664 .741 .907 r
.47403 .17877 .47513 .18013 .48165 .1777 .48055 .17633 Metetra
.664 .741 .907 r
.48055 .17633 .48165 .1777 .48818 .17525 .48708 .17389 Metetra
.664 .741 .907 r
.48708 .17389 .48818 .17525 .49473 .1728 .49363 .17144 Metetra
.664 .741 .907 r
.49363 .17144 .49473 .1728 .5013 .17035 .5002 .16898 Metetra
.664 .741 .907 r
.5002 .16898 .5013 .17035 .50788 .16789 .50678 .16652 Metetra
.664 .741 .907 r
.50678 .16652 .50788 .16789 .51447 .16542 .51338 .16405 Metetra
.664 .741 .907 r
.51338 .16405 .51447 .16542 .52109 .16295 .52 .16157 Metetra
.664 .741 .907 r
.52 .16157 .52109 .16295 .52771 .16047 .52663 .15909 Metetra
.664 .741 .907 r
.52663 .15909 .52771 .16047 .53436 .15799 .53328 .1566 Metetra
.664 .741 .907 r
.53328 .1566 .53436 .15799 .54102 .1555 .53994 .15411 Metetra
.664 .741 .907 r
.53994 .15411 .54102 .1555 .54769 .153 .54662 .15161 Metetra
.664 .741 .907 r
.54662 .15161 .54769 .153 .55439 .1505 .55331 .1491 Metetra
.664 .741 .907 r
.55331 .1491 .55439 .1505 .56109 .14799 .56003 .14659 Metetra
.664 .741 .907 r
.56003 .14659 .56109 .14799 .56782 .14548 .56675 .14408 Metetra
.664 .741 .907 r
.56675 .14408 .56782 .14548 .57456 .14296 .5735 .14155 Metetra
.664 .741 .907 r
.5735 .14155 .57456 .14296 .58132 .14043 .58026 .13902 Metetra
.664 .741 .907 r
.58026 .13902 .58132 .14043 .58809 .1379 .58704 .13649 Metetra
.664 .741 .907 r
.58704 .13649 .58809 .1379 .59488 .13536 .59383 .13394 Metetra
.664 .741 .907 r
.59383 .13394 .59488 .13536 .60169 .13282 .60064 .13139 Metetra
.664 .741 .907 r
.60064 .13139 .60169 .13282 .60851 .13027 .60747 .12884 Metetra
.664 .741 .907 r
.60747 .12884 .60851 .13027 .61535 .12771 .61431 .12628 Metetra
.664 .741 .907 r
.61431 .12628 .61535 .12771 .62221 .12514 .62117 .12371 Metetra
.664 .741 .907 r
.62117 .12371 .62221 .12514 .62909 .12257 .62805 .12114 Metetra
.664 .741 .907 r
.62805 .12114 .62909 .12257 .63598 .12 .63495 .11856 Metetra
.664 .741 .907 r
.63495 .11856 .63598 .12 .64288 .11742 .64186 .11597 Metetra
.664 .741 .907 r
.64186 .11597 .64288 .11742 .64981 .11483 .64879 .11338 Metetra
.664 .741 .907 r
.64879 .11338 .64981 .11483 .65675 .11223 .65573 .11078 Metetra
.638 .73 .915 r
.65573 .11078 .65675 .11223 .66371 .10963 .66271 .1086 Metetra
.691 .831 .95 r
.66271 .1086 .66371 .10963 .67069 .10702 .66967 .10556 Metetra
.664 .741 .907 r
.66967 .10556 .67069 .10702 .67911 .13177 .67667 .10295 Metetra
.529 .314 .531 r
.67667 .10295 .67911 .13177 .68469 .10179 .68369 .10032 Metetra
.664 .741 .907 r
.68369 .10032 .68469 .10179 .69172 .09916 .69072 .09769 Metetra
.664 .741 .907 r
.69072 .09769 .69172 .09916 .69877 .09652 .69777 .09505 Metetra
.664 .741 .907 r
.69777 .09505 .69877 .09652 .70583 .09388 .70484 .09241 Metetra
.664 .741 .907 r
.70484 .09241 .70583 .09388 .71291 .09123 .71192 .08976 Metetra
.664 .741 .907 r
.71192 .08976 .71291 .09123 .72001 .08858 .71902 .0871 Metetra
.664 .741 .907 r
.71902 .0871 .72001 .08858 .72713 .08592 .72614 .08443 Metetra
.664 .741 .907 r
.72614 .08443 .72713 .08592 .73426 .08325 .73328 .08176 Metetra
.664 .741 .907 r
.73328 .08176 .73426 .08325 .74141 .08058 .74044 .07908 Metetra
.664 .741 .907 r
.10248 .31615 .10375 .31733 .10941 .31521 .10815 .31402 Metetra
.664 .741 .907 r
.10815 .31402 .10941 .31521 .11509 .31308 .11383 .3119 Metetra
.664 .741 .907 r
.11383 .3119 .11509 .31308 .12078 .31095 .11952 .30977 Metetra
.664 .741 .907 r
.11952 .30977 .12078 .31095 .12648 .30882 .12522 .30763 Metetra
.664 .741 .907 r
.12522 .30763 .12648 .30882 .1322 .30668 .13094 .30549 Metetra
.664 .741 .907 r
.13094 .30549 .1322 .30668 .13792 .30454 .13667 .30334 Metetra
.664 .741 .907 r
.13667 .30334 .13792 .30454 .14366 .30239 .14241 .30119 Metetra
.664 .741 .907 r
.14241 .30119 .14366 .30239 .14942 .30024 .14817 .29904 Metetra
.664 .741 .907 r
.14817 .29904 .14942 .30024 .15518 .29808 .15394 .29688 Metetra
.664 .741 .907 r
.15394 .29688 .15518 .29808 .16096 .29592 .15972 .29471 Metetra
.664 .741 .907 r
.15972 .29471 .16096 .29592 .16675 .29375 .16551 .29254 Metetra
.664 .741 .907 r
.16551 .29254 .16675 .29375 .17256 .29158 .17132 .29036 Metetra
.664 .741 .907 r
.17132 .29036 .17256 .29158 .17838 .2894 .17714 .28818 Metetra
.945 .602 .337 r
.17714 .28818 .17838 .2894 .18323 .29613 .1802 .31127 Metetra
.082 0 .285 r
.1802 .31127 .18323 .29613 .18799 .3042 .18882 .28381 Metetra
.534 .325 .542 r
.18882 .28381 .18799 .3042 .19591 .28284 .19468 .28162 Metetra
.664 .741 .907 r
.19468 .28162 .19591 .28284 .20178 .28064 .20056 .27942 Metetra
.664 .741 .907 r
.20056 .27942 .20178 .28064 .20767 .27844 .20644 .27721 Metetra
.664 .741 .907 r
.20644 .27721 .20767 .27844 .21357 .27623 .21235 .275 Metetra
.664 .741 .907 r
.21235 .275 .21357 .27623 .21948 .27402 .21826 .27279 Metetra
.664 .741 .907 r
.21826 .27279 .21948 .27402 .2254 .2718 .22419 .27057 Metetra
.664 .741 .907 r
.22419 .27057 .2254 .2718 .23134 .26958 .23013 .26834 Metetra
.664 .741 .907 r
.23013 .26834 .23134 .26958 .2373 .26736 .23608 .26611 Metetra
.664 .741 .907 r
.23608 .26611 .2373 .26736 .24326 .26512 .24205 .26388 Metetra
.664 .741 .907 r
.24205 .26388 .24326 .26512 .24924 .26289 .24803 .26164 Metetra
.664 .741 .907 r
.24803 .26164 .24924 .26289 .25523 .26064 .25403 .25939 Metetra
.664 .741 .907 r
.25403 .25939 .25523 .26064 .26124 .25839 .26004 .25714 Metetra
.664 .741 .907 r
.26004 .25714 .26124 .25839 .26726 .25614 .26606 .25488 Metetra
.664 .741 .907 r
.26606 .25488 .26726 .25614 .2733 .25388 .2721 .25262 Metetra
.664 .741 .907 r
.2721 .25262 .2733 .25388 .27935 .25162 .27815 .25036 Metetra
.664 .741 .907 r
.27815 .25036 .27935 .25162 .28541 .24935 .28422 .24808 Metetra
.664 .741 .907 r
.28422 .24808 .28541 .24935 .29149 .24708 .29029 .24581 Metetra
.664 .741 .907 r
.29029 .24581 .29149 .24708 .29758 .2448 .29639 .24353 Metetra
.664 .741 .907 r
.29639 .24353 .29758 .2448 .30368 .24251 .30249 .24124 Metetra
.664 .741 .907 r
.30249 .24124 .30368 .24251 .3098 .24023 .30862 .23895 Metetra
.664 .741 .907 r
.30862 .23895 .3098 .24023 .31593 .23793 .31475 .23665 Metetra
.664 .741 .907 r
.31475 .23665 .31593 .23793 .32208 .23563 .3209 .23434 Metetra
.664 .741 .907 r
.3209 .23434 .32208 .23563 .32824 .23332 .32707 .23204 Metetra
.639 .733 .916 r
.32707 .23204 .32824 .23332 .32969 .30682 .33322 .2301 Metetra
.339 .149 .47 r
.33322 .2301 .32969 .30682 .32997 .40486 .33456 .30765 Metetra
.618 .373 .524 r
.33456 .30765 .32997 .40486 .34681 .22637 .34565 .22508 Metetra
.664 .741 .907 r
.34565 .22508 .34681 .22637 .35303 .22405 .35187 .22275 Metetra
.664 .741 .907 r
.35187 .22275 .35303 .22405 .35927 .22172 .3581 .22041 Metetra
.664 .741 .907 r
.3581 .22041 .35927 .22172 .36551 .21938 .36436 .21807 Metetra
.664 .741 .907 r
.36436 .21807 .36551 .21938 .37178 .21703 .37062 .21572 Metetra
.664 .741 .907 r
.37062 .21572 .37178 .21703 .37806 .21468 .3769 .21337 Metetra
.664 .741 .907 r
.3769 .21337 .37806 .21468 .38435 .21233 .3832 .21101 Metetra
.664 .741 .907 r
.3832 .21101 .38435 .21233 .39066 .20997 .38951 .20865 Metetra
.664 .741 .907 r
.38951 .20865 .39066 .20997 .39698 .2076 .39583 .20628 Metetra
.664 .741 .907 r
.39583 .20628 .39698 .2076 .40332 .20523 .40217 .20391 Metetra
.664 .741 .907 r
.40217 .20391 .40332 .20523 .40967 .20286 .40853 .20153 Metetra
.664 .741 .907 r
.40853 .20153 .40967 .20286 .41604 .20047 .4149 .19914 Metetra
.664 .741 .907 r
.4149 .19914 .41604 .20047 .42242 .19808 .42128 .19675 Metetra
.664 .741 .907 r
.42128 .19675 .42242 .19808 .42881 .19569 .42768 .19435 Metetra
.664 .741 .907 r
.42768 .19435 .42881 .19569 .43523 .19329 .4341 .19195 Metetra
.664 .741 .907 r
.4341 .19195 .43523 .19329 .44166 .19089 .44053 .18954 Metetra
.664 .741 .907 r
.44053 .18954 .44166 .19089 .4481 .18847 .44698 .18713 Metetra
.664 .741 .907 r
.44698 .18713 .4481 .18847 .45456 .18606 .45344 .18471 Metetra
.664 .741 .907 r
.45344 .18471 .45456 .18606 .46103 .18364 .45991 .18228 Metetra
.664 .741 .907 r
.45991 .18228 .46103 .18364 .46752 .18121 .46641 .17985 Metetra
.664 .741 .907 r
.46641 .17985 .46752 .18121 .47403 .17877 .47291 .17741 Metetra
.664 .741 .907 r
.47291 .17741 .47403 .17877 .48055 .17633 .47944 .17497 Metetra
.664 .741 .907 r
.47944 .17497 .48055 .17633 .48708 .17389 .48598 .17252 Metetra
.664 .741 .907 r
.48598 .17252 .48708 .17389 .49363 .17144 .49253 .17007 Metetra
.664 .741 .907 r
.49253 .17007 .49363 .17144 .5002 .16898 .4991 .16761 Metetra
.664 .741 .907 r
.4991 .16761 .5002 .16898 .50678 .16652 .50569 .16514 Metetra
.664 .741 .907 r
.50569 .16514 .50678 .16652 .51338 .16405 .51229 .16267 Metetra
.664 .741 .907 r
.51229 .16267 .51338 .16405 .52 .16157 .51891 .16019 Metetra
.664 .741 .907 r
.51891 .16019 .52 .16157 .52663 .15909 .52554 .1577 Metetra
.664 .741 .907 r
.52554 .1577 .52663 .15909 .53328 .1566 .53219 .15521 Metetra
.664 .741 .907 r
.53219 .15521 .53328 .1566 .53994 .15411 .53886 .15272 Metetra
.664 .741 .907 r
.53886 .15272 .53994 .15411 .54662 .15161 .54554 .15021 Metetra
.664 .741 .907 r
.54554 .15021 .54662 .15161 .55331 .1491 .55224 .1477 Metetra
.664 .741 .907 r
.55224 .1477 .55331 .1491 .56003 .14659 .55896 .14519 Metetra
.664 .741 .907 r
.55896 .14519 .56003 .14659 .56675 .14408 .56569 .14267 Metetra
.664 .741 .907 r
.56569 .14267 .56675 .14408 .5735 .14155 .57244 .14014 Metetra
.664 .741 .907 r
.57244 .14014 .5735 .14155 .58026 .13902 .5792 .13761 Metetra
.664 .741 .907 r
.5792 .13761 .58026 .13902 .58704 .13649 .58598 .13507 Metetra
.664 .741 .907 r
.58598 .13507 .58704 .13649 .59383 .13394 .59278 .13252 Metetra
.664 .741 .907 r
.59278 .13252 .59383 .13394 .60064 .13139 .59959 .12997 Metetra
.664 .741 .907 r
.59959 .12997 .60064 .13139 .60747 .12884 .60642 .12741 Metetra
.664 .741 .907 r
.60642 .12741 .60747 .12884 .61431 .12628 .61327 .12485 Metetra
.664 .741 .907 r
.61327 .12485 .61431 .12628 .62117 .12371 .62013 .12228 Metetra
.664 .741 .907 r
.62013 .12228 .62117 .12371 .62805 .12114 .62701 .1197 Metetra
.664 .741 .907 r
.62701 .1197 .62805 .12114 .63495 .11856 .63391 .11712 Metetra
.664 .741 .907 r
.63391 .11712 .63495 .11856 .64186 .11597 .64083 .11453 Metetra
.664 .741 .907 r
.64083 .11453 .64186 .11597 .64879 .11338 .64776 .11193 Metetra
.664 .741 .907 r
.64776 .11193 .64879 .11338 .65573 .11078 .65471 .10933 Metetra
.664 .741 .907 r
.65471 .10933 .65573 .11078 .66271 .1086 .66168 .10672 Metetra
.655 .674 .856 r
.66168 .10672 .66271 .1086 .66967 .10556 .66866 .1041 Metetra
.664 .741 .907 r
.66866 .1041 .66967 .10556 .67667 .10295 .67566 .10148 Metetra
.664 .741 .907 r
.67566 .10148 .67667 .10295 .68369 .10032 .68268 .09885 Metetra
.664 .741 .907 r
.68268 .09885 .68369 .10032 .69072 .09769 .68971 .09622 Metetra
.664 .741 .907 r
.68971 .09622 .69072 .09769 .69777 .09505 .69677 .09358 Metetra
.664 .741 .907 r
.69677 .09358 .69777 .09505 .70484 .09241 .70384 .09093 Metetra
.664 .741 .907 r
.70384 .09093 .70484 .09241 .71192 .08976 .71093 .08827 Metetra
.664 .741 .907 r
.71093 .08827 .71192 .08976 .71902 .0871 .71803 .08561 Metetra
.664 .741 .907 r
.71803 .08561 .71902 .0871 .72614 .08443 .72516 .08294 Metetra
.664 .741 .907 r
.72516 .08294 .72614 .08443 .73328 .08176 .7323 .08027 Metetra
.664 .741 .907 r
.7323 .08027 .73328 .08176 .74044 .07908 .73946 .07759 Metetra
.664 .741 .907 r
.10122 .31496 .10248 .31615 .10815 .31402 .10689 .31284 Metetra
.664 .741 .907 r
.10689 .31284 .10815 .31402 .11383 .3119 .11257 .31071 Metetra
.664 .741 .907 r
.11257 .31071 .11383 .3119 .11952 .30977 .11826 .30857 Metetra
.664 .741 .907 r
.11826 .30857 .11952 .30977 .12522 .30763 .12397 .30644 Metetra
.664 .741 .907 r
.12397 .30644 .12522 .30763 .13094 .30549 .12968 .30429 Metetra
.664 .741 .907 r
.12968 .30429 .13094 .30549 .13667 .30334 .13542 .30214 Metetra
.664 .741 .907 r
.13542 .30214 .13667 .30334 .14241 .30119 .14116 .29999 Metetra
.664 .741 .907 r
.14116 .29999 .14241 .30119 .14817 .29904 .14692 .29783 Metetra
.664 .741 .907 r
.14692 .29783 .14817 .29904 .15394 .29688 .15269 .29567 Metetra
.664 .741 .907 r
.15269 .29567 .15394 .29688 .15972 .29471 .15847 .2935 Metetra
.664 .741 .907 r
.15847 .2935 .15972 .29471 .16551 .29254 .16427 .29133 Metetra
.664 .741 .907 r
.16427 .29133 .16551 .29254 .17132 .29036 .17008 .28915 Metetra
.664 .741 .907 r
.17008 .28915 .17132 .29036 .17714 .28818 .1759 .28697 Metetra
.919 .523 .196 r
.1759 .28697 .17714 .28818 .1802 .31127 .17993 .30115 Metetra
.702 .484 .59 r
.17993 .30115 .1802 .31127 .18882 .28381 .18759 .28259 Metetra
.664 .741 .907 r
.18759 .28259 .18882 .28381 .19468 .28162 .19345 .28039 Metetra
.664 .741 .907 r
.19345 .28039 .19468 .28162 .20056 .27942 .19933 .27819 Metetra
.664 .741 .907 r
.19933 .27819 .20056 .27942 .20644 .27721 .20522 .27598 Metetra
.664 .741 .907 r
.20522 .27598 .20644 .27721 .21235 .275 .21112 .27377 Metetra
.664 .741 .907 r
.21112 .27377 .21235 .275 .21826 .27279 .21704 .27155 Metetra
.664 .741 .907 r
.21704 .27155 .21826 .27279 .22419 .27057 .22297 .26933 Metetra
.664 .741 .907 r
.22297 .26933 .22419 .27057 .23013 .26834 .22891 .2671 Metetra
.664 .741 .907 r
.22891 .2671 .23013 .26834 .23608 .26611 .23487 .26486 Metetra
.664 .741 .907 r
.23487 .26486 .23608 .26611 .24205 .26388 .24084 .26263 Metetra
.664 .741 .907 r
.24084 .26263 .24205 .26388 .24803 .26164 .24682 .26038 Metetra
.664 .741 .907 r
.24682 .26038 .24803 .26164 .25403 .25939 .25282 .25813 Metetra
.664 .741 .907 r
.25282 .25813 .25403 .25939 .26004 .25714 .25883 .25588 Metetra
.664 .741 .907 r
.25883 .25588 .26004 .25714 .26606 .25488 .26486 .25362 Metetra
.664 .741 .907 r
.26486 .25362 .26606 .25488 .2721 .25262 .2709 .25136 Metetra
.664 .741 .907 r
.2709 .25136 .2721 .25262 .27815 .25036 .27695 .24909 Metetra
.664 .741 .907 r
.27695 .24909 .27815 .25036 .28422 .24808 .28302 .24682 Metetra
.664 .741 .907 r
.28302 .24682 .28422 .24808 .29029 .24581 .2891 .24454 Metetra
.664 .741 .907 r
.2891 .24454 .29029 .24581 .29639 .24353 .2952 .24225 Metetra
.664 .741 .907 r
.2952 .24225 .29639 .24353 .30249 .24124 .30131 .23996 Metetra
.938 .566 .238 r
.30131 .23996 .30249 .24124 .30862 .23895 .30579 .26074 Metetra
.295 .074 .399 r
.30579 .26074 .30862 .23895 .31475 .23665 .31357 .23536 Metetra
.664 .741 .907 r
.31357 .23536 .31475 .23665 .3209 .23434 .31972 .23306 Metetra
.664 .741 .907 r
.31972 .23306 .3209 .23434 .32707 .23204 .32589 .23075 Metetra
.664 .741 .907 r
.32589 .23075 .32707 .23204 .33322 .2301 .33207 .22843 Metetra
.656 .68 .861 r
.33207 .22843 .33322 .2301 .33456 .30765 .33827 .22611 Metetra
.519 .292 .51 r
.33827 .22611 .33456 .30765 .34565 .22508 .34448 .22378 Metetra
.664 .741 .907 r
.34448 .22378 .34565 .22508 .35187 .22275 .3507 .22145 Metetra
.664 .741 .907 r
.3507 .22145 .35187 .22275 .3581 .22041 .35694 .21911 Metetra
.664 .741 .907 r
.35694 .21911 .3581 .22041 .36436 .21807 .36319 .21676 Metetra
.664 .741 .907 r
.36319 .21676 .36436 .21807 .37062 .21572 .36946 .21441 Metetra
.664 .741 .907 r
.36946 .21441 .37062 .21572 .3769 .21337 .37575 .21206 Metetra
.664 .741 .907 r
.37575 .21206 .3769 .21337 .3832 .21101 .38205 .2097 Metetra
.664 .741 .907 r
.38205 .2097 .3832 .21101 .38951 .20865 .38836 .20733 Metetra
.664 .741 .907 r
.38836 .20733 .38951 .20865 .39583 .20628 .39469 .20496 Metetra
.664 .741 .907 r
.39469 .20496 .39583 .20628 .40217 .20391 .40103 .20258 Metetra
.664 .741 .907 r
.40103 .20258 .40217 .20391 .40853 .20153 .40739 .2002 Metetra
.664 .741 .907 r
.40739 .2002 .40853 .20153 .4149 .19914 .41376 .19781 Metetra
.664 .741 .907 r
.41376 .19781 .4149 .19914 .42128 .19675 .42015 .19541 Metetra
.664 .741 .907 r
.42015 .19541 .42128 .19675 .42768 .19435 .42655 .19301 Metetra
.664 .741 .907 r
.42655 .19301 .42768 .19435 .4341 .19195 .43297 .19061 Metetra
.664 .741 .907 r
.43297 .19061 .4341 .19195 .44053 .18954 .4394 .1882 Metetra
.664 .741 .907 r
.4394 .1882 .44053 .18954 .44698 .18713 .44585 .18578 Metetra
.664 .741 .907 r
.44585 .18578 .44698 .18713 .45344 .18471 .45232 .18336 Metetra
.664 .741 .907 r
.45232 .18336 .45344 .18471 .45991 .18228 .4588 .18093 Metetra
.664 .741 .907 r
.4588 .18093 .45991 .18228 .46641 .17985 .46529 .17849 Metetra
.664 .741 .907 r
.46529 .17849 .46641 .17985 .47291 .17741 .4718 .17605 Metetra
.664 .741 .907 r
.4718 .17605 .47291 .17741 .47944 .17497 .47833 .1736 Metetra
.664 .741 .907 r
.47833 .1736 .47944 .17497 .48598 .17252 .48487 .17115 Metetra
.664 .741 .907 r
.48487 .17115 .48598 .17252 .49253 .17007 .49143 .16869 Metetra
.664 .741 .907 r
.49143 .16869 .49253 .17007 .4991 .16761 .498 .16623 Metetra
.664 .741 .907 r
.498 .16623 .4991 .16761 .50569 .16514 .50459 .16376 Metetra
.664 .741 .907 r
.50459 .16376 .50569 .16514 .51229 .16267 .5112 .16128 Metetra
.664 .741 .907 r
.5112 .16128 .51229 .16267 .51891 .16019 .51782 .1588 Metetra
.664 .741 .907 r
.51782 .1588 .51891 .16019 .52554 .1577 .52446 .15631 Metetra
.664 .741 .907 r
.52446 .15631 .52554 .1577 .53219 .15521 .53111 .15382 Metetra
.664 .741 .907 r
.53111 .15382 .53219 .15521 .53886 .15272 .53778 .15132 Metetra
.664 .741 .907 r
.53778 .15132 .53886 .15272 .54554 .15021 .54447 .14881 Metetra
.664 .741 .907 r
.54447 .14881 .54554 .15021 .55224 .1477 .55117 .1463 Metetra
.664 .741 .907 r
.55117 .1463 .55224 .1477 .55896 .14519 .55789 .14378 Metetra
.664 .741 .907 r
.55789 .14378 .55896 .14519 .56569 .14267 .56462 .14126 Metetra
.664 .741 .907 r
.56462 .14126 .56569 .14267 .57244 .14014 .57137 .13873 Metetra
.664 .741 .907 r
.57137 .13873 .57244 .14014 .5792 .13761 .57814 .13619 Metetra
.664 .741 .907 r
.57814 .13619 .5792 .13761 .58598 .13507 .58492 .13365 Metetra
.664 .741 .907 r
.58492 .13365 .58598 .13507 .59278 .13252 .59172 .1311 Metetra
.664 .741 .907 r
.59172 .1311 .59278 .13252 .59959 .12997 .59854 .12854 Metetra
.664 .741 .907 r
.59854 .12854 .59959 .12997 .60642 .12741 .60537 .12598 Metetra
.664 .741 .907 r
.60537 .12598 .60642 .12741 .61327 .12485 .61223 .12342 Metetra
.664 .741 .907 r
.61223 .12342 .61327 .12485 .62013 .12228 .61909 .12084 Metetra
.664 .741 .907 r
.61909 .12084 .62013 .12228 .62701 .1197 .62598 .11826 Metetra
.664 .741 .907 r
.62598 .11826 .62701 .1197 .63391 .11712 .63288 .11567 Metetra
.664 .741 .907 r
.63288 .11567 .63391 .11712 .64083 .11453 .6398 .11308 Metetra
.664 .741 .907 r
.6398 .11308 .64083 .11453 .64776 .11193 .64673 .11048 Metetra
.664 .741 .907 r
.64673 .11048 .64776 .11193 .65471 .10933 .65369 .10787 Metetra
.664 .741 .907 r
.65369 .10787 .65471 .10933 .66168 .10672 .66066 .10526 Metetra
.664 .741 .907 r
.66066 .10526 .66168 .10672 .66866 .1041 .66764 .10264 Metetra
.664 .741 .907 r
.66764 .10264 .66866 .1041 .67566 .10148 .67465 .10002 Metetra
.664 .741 .907 r
.67465 .10002 .67566 .10148 .68268 .09885 .68167 .09738 Metetra
.664 .741 .907 r
.68167 .09738 .68268 .09885 .68971 .09622 .68871 .09475 Metetra
.664 .741 .907 r
.68871 .09475 .68971 .09622 .69677 .09358 .69577 .0921 Metetra
.664 .741 .907 r
.69577 .0921 .69677 .09358 .70384 .09093 .70284 .08945 Metetra
.664 .741 .907 r
.70284 .08945 .70384 .09093 .71093 .08827 .70993 .08679 Metetra
.664 .741 .907 r
.70993 .08679 .71093 .08827 .71803 .08561 .71704 .08413 Metetra
.664 .741 .907 r
.71704 .08413 .71803 .08561 .72516 .08294 .72417 .08145 Metetra
.664 .741 .907 r
.72417 .08145 .72516 .08294 .7323 .08027 .73132 .07877 Metetra
.664 .741 .907 r
.73132 .07877 .7323 .08027 .73946 .07759 .73848 .07609 Metetra
.664 .741 .907 r
.09995 .31378 .10122 .31496 .10689 .31284 .10562 .31165 Metetra
.664 .741 .907 r
.10562 .31165 .10689 .31284 .11257 .31071 .1113 .30952 Metetra
.664 .741 .907 r
.1113 .30952 .11257 .31071 .11826 .30857 .117 .30738 Metetra
.664 .741 .907 r
.117 .30738 .11826 .30857 .12397 .30644 .12271 .30524 Metetra
.664 .741 .907 r
.12271 .30524 .12397 .30644 .12968 .30429 .12843 .30309 Metetra
.664 .741 .907 r
.12843 .30309 .12968 .30429 .13542 .30214 .13416 .30094 Metetra
.664 .741 .907 r
.13416 .30094 .13542 .30214 .14116 .29999 .13991 .29879 Metetra
.664 .741 .907 r
.13991 .29879 .14116 .29999 .14692 .29783 .14567 .29663 Metetra
.664 .741 .907 r
.14567 .29663 .14692 .29783 .15269 .29567 .15144 .29446 Metetra
.664 .741 .907 r
.15144 .29446 .15269 .29567 .15847 .2935 .15723 .29229 Metetra
.664 .741 .907 r
.15723 .29229 .15847 .2935 .16427 .29133 .16303 .29011 Metetra
.664 .741 .907 r
.16303 .29011 .16427 .29133 .17008 .28915 .16884 .28793 Metetra
0 .078 .577 r
.16884 .28793 .17008 .28915 .1759 .28697 .17391 .2924 Metetra
.131 0 .186 r
.17391 .2924 .1759 .28697 .17993 .30115 .1805 .28356 Metetra
.537 .331 .548 r
.1805 .28356 .17993 .30115 .18759 .28259 .18635 .28136 Metetra
.664 .741 .907 r
.18635 .28136 .18759 .28259 .19345 .28039 .19222 .27916 Metetra
.664 .741 .907 r
.19222 .27916 .19345 .28039 .19933 .27819 .1981 .27696 Metetra
.664 .741 .907 r
.1981 .27696 .19933 .27819 .20522 .27598 .20399 .27475 Metetra
.664 .741 .907 r
.20399 .27475 .20522 .27598 .21112 .27377 .2099 .27253 Metetra
.664 .741 .907 r
.2099 .27253 .21112 .27377 .21704 .27155 .21581 .27031 Metetra
.664 .741 .907 r
.21581 .27031 .21704 .27155 .22297 .26933 .22175 .26808 Metetra
.664 .741 .907 r
.22175 .26808 .22297 .26933 .22891 .2671 .22769 .26585 Metetra
.664 .741 .907 r
.22769 .26585 .22891 .2671 .23487 .26486 .23365 .26362 Metetra
.664 .741 .907 r
.23365 .26362 .23487 .26486 .24084 .26263 .23962 .26138 Metetra
.664 .741 .907 r
.23962 .26138 .24084 .26263 .24682 .26038 .24561 .25913 Metetra
.664 .741 .907 r
.24561 .25913 .24682 .26038 .25282 .25813 .25161 .25688 Metetra
.664 .741 .907 r
.25161 .25688 .25282 .25813 .25883 .25588 .25763 .25462 Metetra
.664 .741 .907 r
.25763 .25462 .25883 .25588 .26486 .25362 .26366 .25236 Metetra
.664 .741 .907 r
.26366 .25236 .26486 .25362 .2709 .25136 .2697 .25009 Metetra
.664 .741 .907 r
.2697 .25009 .2709 .25136 .27695 .24909 .27575 .24782 Metetra
.664 .741 .907 r
.27575 .24782 .27695 .24909 .28302 .24682 .28182 .24554 Metetra
.664 .741 .907 r
.28182 .24554 .28302 .24682 .2891 .24454 .28791 .24326 Metetra
.664 .741 .907 r
.28791 .24326 .2891 .24454 .2952 .24225 .29401 .24097 Metetra
.664 .741 .907 r
.29401 .24097 .2952 .24225 .30131 .23996 .30012 .23868 Metetra
.959 .676 .456 r
.30012 .23868 .30131 .23996 .30579 .26074 .29418 .40513 Metetra
.292 .097 .435 r
.29418 .40513 .30579 .26074 .31357 .23536 .31239 .23408 Metetra
.664 .741 .907 r
.31239 .23408 .31357 .23536 .31972 .23306 .31854 .23177 Metetra
.664 .741 .907 r
.31854 .23177 .31972 .23306 .32589 .23075 .32471 .22945 Metetra
.664 .741 .907 r
.32471 .22945 .32589 .23075 .33207 .22843 .3309 .22713 Metetra
.664 .741 .907 r
.3309 .22713 .33207 .22843 .33827 .22611 .33709 .22481 Metetra
.664 .741 .907 r
.33709 .22481 .33827 .22611 .34448 .22378 .34331 .22248 Metetra
.664 .741 .907 r
.34331 .22248 .34448 .22378 .3507 .22145 .34953 .22014 Metetra
.664 .741 .907 r
.34953 .22014 .3507 .22145 .35694 .21911 .35578 .2178 Metetra
.664 .741 .907 r
.35578 .2178 .35694 .21911 .36319 .21676 .36203 .21545 Metetra
.664 .741 .907 r
.36203 .21545 .36319 .21676 .36946 .21441 .3683 .2131 Metetra
.664 .741 .907 r
.3683 .2131 .36946 .21441 .37575 .21206 .37459 .21074 Metetra
.664 .741 .907 r
.37459 .21074 .37575 .21206 .38205 .2097 .38089 .20838 Metetra
.664 .741 .907 r
.38089 .20838 .38205 .2097 .38836 .20733 .38721 .20601 Metetra
.664 .741 .907 r
.38721 .20601 .38836 .20733 .39469 .20496 .39354 .20363 Metetra
.664 .741 .907 r
.39354 .20363 .39469 .20496 .40103 .20258 .39988 .20125 Metetra
.664 .741 .907 r
.39988 .20125 .40103 .20258 .40739 .2002 .40624 .19887 Metetra
.664 .741 .907 r
.40624 .19887 .40739 .2002 .41376 .19781 .41262 .19647 Metetra
.664 .741 .907 r
.41262 .19647 .41376 .19781 .42015 .19541 .41901 .19408 Metetra
.664 .741 .907 r
.41901 .19408 .42015 .19541 .42655 .19301 .42542 .19167 Metetra
.664 .741 .907 r
.42542 .19167 .42655 .19301 .43297 .19061 .43184 .18926 Metetra
.664 .741 .907 r
.43184 .18926 .43297 .19061 .4394 .1882 .43828 .18685 Metetra
.664 .741 .907 r
.43828 .18685 .4394 .1882 .44585 .18578 .44473 .18443 Metetra
.664 .741 .907 r
.44473 .18443 .44585 .18578 .45232 .18336 .45119 .182 Metetra
.664 .741 .907 r
.45119 .182 .45232 .18336 .4588 .18093 .45768 .17957 Metetra
.664 .741 .907 r
.45768 .17957 .4588 .18093 .46529 .17849 .46418 .17713 Metetra
.664 .741 .907 r
.46418 .17713 .46529 .17849 .4718 .17605 .47069 .17469 Metetra
.664 .741 .907 r
.47069 .17469 .4718 .17605 .47833 .1736 .47722 .17224 Metetra
.664 .741 .907 r
.47722 .17224 .47833 .1736 .48487 .17115 .48376 .16978 Metetra
.664 .741 .907 r
.48376 .16978 .48487 .17115 .49143 .16869 .49033 .16732 Metetra
.664 .741 .907 r
.49033 .16732 .49143 .16869 .498 .16623 .4969 .16485 Metetra
.664 .741 .907 r
.4969 .16485 .498 .16623 .50459 .16376 .50349 .16238 Metetra
.664 .741 .907 r
.50349 .16238 .50459 .16376 .5112 .16128 .5101 .1599 Metetra
.664 .741 .907 r
.5101 .1599 .5112 .16128 .51782 .1588 .51673 .15742 Metetra
.664 .741 .907 r
.51673 .15742 .51782 .1588 .52446 .15631 .52337 .15492 Metetra
.664 .741 .907 r
.52337 .15492 .52446 .15631 .53111 .15382 .53002 .15243 Metetra
.664 .741 .907 r
.53002 .15243 .53111 .15382 .53778 .15132 .5367 .14992 Metetra
.664 .741 .907 r
.5367 .14992 .53778 .15132 .54447 .14881 .54339 .14741 Metetra
.664 .741 .907 r
.54339 .14741 .54447 .14881 .55117 .1463 .55009 .1449 Metetra
.664 .741 .907 r
.55009 .1449 .55117 .1463 .55789 .14378 .55681 .14238 Metetra
.664 .741 .907 r
.55681 .14238 .55789 .14378 .56462 .14126 .56355 .13985 Metetra
.664 .741 .907 r
.56355 .13985 .56462 .14126 .57137 .13873 .57031 .13731 Metetra
.664 .741 .907 r
.57031 .13731 .57137 .13873 .57814 .13619 .57708 .13477 Metetra
.664 .741 .907 r
.57708 .13477 .57814 .13619 .58492 .13365 .58386 .13223 Metetra
.862 .453 0 r
.58386 .13223 .58492 .13365 .59172 .1311 .59117 .15217 Metetra
.617 .337 .469 r
.59117 .15217 .59172 .1311 .59854 .12854 .59865 .1745 Metetra
.347 .141 .452 r
.59865 .1745 .59854 .12854 .60537 .12598 .60433 .12455 Metetra
.664 .741 .907 r
.60433 .12455 .60537 .12598 .61223 .12342 .61118 .12198 Metetra
.664 .741 .907 r
.61118 .12198 .61223 .12342 .61909 .12084 .61805 .1194 Metetra
.664 .741 .907 r
.61805 .1194 .61909 .12084 .62598 .11826 .62494 .11682 Metetra
.664 .741 .907 r
.62494 .11682 .62598 .11826 .63288 .11567 .63184 .11423 Metetra
.664 .741 .907 r
.63184 .11423 .63288 .11567 .6398 .11308 .63877 .11163 Metetra
.664 .741 .907 r
.63877 .11163 .6398 .11308 .64673 .11048 .6457 .10903 Metetra
.664 .741 .907 r
.6457 .10903 .64673 .11048 .65369 .10787 .65266 .10642 Metetra
.664 .741 .907 r
.65266 .10642 .65369 .10787 .66066 .10526 .65963 .1038 Metetra
.664 .741 .907 r
.65963 .1038 .66066 .10526 .66764 .10264 .66662 .10118 Metetra
.664 .741 .907 r
.66662 .10118 .66764 .10264 .67465 .10002 .67363 .09855 Metetra
.664 .741 .907 r
.67363 .09855 .67465 .10002 .68167 .09738 .68066 .09591 Metetra
.664 .741 .907 r
.68066 .09591 .68167 .09738 .68871 .09475 .6877 .09327 Metetra
.664 .741 .907 r
.6877 .09327 .68871 .09475 .69577 .0921 .69476 .09062 Metetra
.664 .741 .907 r
.69476 .09062 .69577 .0921 .70284 .08945 .70184 .08797 Metetra
.664 .741 .907 r
.70184 .08797 .70284 .08945 .70993 .08679 .70894 .0853 Metetra
.664 .741 .907 r
.70894 .0853 .70993 .08679 .71704 .08413 .71605 .08264 Metetra
.664 .741 .907 r
.71605 .08264 .71704 .08413 .72417 .08145 .72318 .07996 Metetra
.664 .741 .907 r
.72318 .07996 .72417 .08145 .73132 .07877 .73033 .07728 Metetra
.664 .741 .907 r
.73033 .07728 .73132 .07877 .73848 .07609 .7375 .07459 Metetra
.664 .741 .907 r
.09868 .31259 .09995 .31378 .10562 .31165 .10435 .31046 Metetra
.664 .741 .907 r
.10435 .31046 .10562 .31165 .1113 .30952 .11004 .30833 Metetra
.664 .741 .907 r
.11004 .30833 .1113 .30952 .117 .30738 .11573 .30619 Metetra
.664 .741 .907 r
.11573 .30619 .117 .30738 .12271 .30524 .12144 .30404 Metetra
.664 .741 .907 r
.12144 .30404 .12271 .30524 .12843 .30309 .12717 .30189 Metetra
.664 .741 .907 r
.12717 .30189 .12843 .30309 .13416 .30094 .1329 .29974 Metetra
.664 .741 .907 r
.1329 .29974 .13416 .30094 .13991 .29879 .13865 .29758 Metetra
.664 .741 .907 r
.13865 .29758 .13991 .29879 .14567 .29663 .14442 .29542 Metetra
.664 .741 .907 r
.14442 .29542 .14567 .29663 .15144 .29446 .15019 .29325 Metetra
.664 .741 .907 r
.15019 .29325 .15144 .29446 .15723 .29229 .15598 .29108 Metetra
.664 .741 .907 r
.15598 .29108 .15723 .29229 .16303 .29011 .16178 .2889 Metetra
.664 .741 .907 r
.16178 .2889 .16303 .29011 .16884 .28793 .1676 .28671 Metetra
.664 .741 .907 r
.1676 .28671 .16884 .28793 .17391 .2924 .17342 .28453 Metetra
.563 .39 .605 r
.17342 .28453 .17391 .2924 .1805 .28356 .17926 .28233 Metetra
.664 .741 .907 r
.17926 .28233 .1805 .28356 .18635 .28136 .18512 .28013 Metetra
.664 .741 .907 r
.18512 .28013 .18635 .28136 .19222 .27916 .19099 .27793 Metetra
.664 .741 .907 r
.19099 .27793 .19222 .27916 .1981 .27696 .19687 .27572 Metetra
.664 .741 .907 r
.19687 .27572 .1981 .27696 .20399 .27475 .20276 .27351 Metetra
.664 .741 .907 r
.20276 .27351 .20399 .27475 .2099 .27253 .20867 .27129 Metetra
.664 .741 .907 r
.20867 .27129 .2099 .27253 .21581 .27031 .21459 .26907 Metetra
.664 .741 .907 r
.21459 .26907 .21581 .27031 .22175 .26808 .22052 .26684 Metetra
.664 .741 .907 r
.22052 .26684 .22175 .26808 .22769 .26585 .22647 .26461 Metetra
.664 .741 .907 r
.22647 .26461 .22769 .26585 .23365 .26362 .23243 .26237 Metetra
.664 .741 .907 r
.23243 .26237 .23365 .26362 .23962 .26138 .23841 .26012 Metetra
.664 .741 .907 r
.23841 .26012 .23962 .26138 .24561 .25913 .2444 .25787 Metetra
.664 .741 .907 r
.2444 .25787 .24561 .25913 .25161 .25688 .2504 .25562 Metetra
.664 .741 .907 r
.2504 .25562 .25161 .25688 .25763 .25462 .25642 .25336 Metetra
.664 .741 .907 r
.25642 .25336 .25763 .25462 .26366 .25236 .26245 .2511 Metetra
.664 .741 .907 r
.26245 .2511 .26366 .25236 .2697 .25009 .26849 .24883 Metetra
.664 .741 .907 r
.26849 .24883 .2697 .25009 .27575 .24782 .27455 .24655 Metetra
.664 .741 .907 r
.27455 .24655 .27575 .24782 .28182 .24554 .28063 .24427 Metetra
.664 .741 .907 r
.28063 .24427 .28182 .24554 .28791 .24326 .28671 .24199 Metetra
.664 .741 .907 r
.28671 .24199 .28791 .24326 .29401 .24097 .29281 .2397 Metetra
.959 .673 .45 r
.29281 .2397 .29401 .24097 .30012 .23868 .28933 .36744 Metetra
.601 .35 .509 r
.28933 .36744 .30012 .23868 .29418 .40513 .28812 .47062 Metetra
0 0 .062 r
.28812 .47062 .29418 .40513 .31239 .23408 .3112 .23279 Metetra
.664 .741 .907 r
.3112 .23279 .31239 .23408 .31854 .23177 .31736 .23048 Metetra
.664 .741 .907 r
.31736 .23048 .31854 .23177 .32471 .22945 .32353 .22816 Metetra
.664 .741 .907 r
.32353 .22816 .32471 .22945 .3309 .22713 .32972 .22584 Metetra
.664 .741 .907 r
.32972 .22584 .3309 .22713 .33709 .22481 .33592 .22351 Metetra
.664 .741 .907 r
.33592 .22351 .33709 .22481 .34331 .22248 .34213 .22118 Metetra
.664 .741 .907 r
.34213 .22118 .34331 .22248 .34953 .22014 .34836 .21884 Metetra
.664 .741 .907 r
.34836 .21884 .34953 .22014 .35578 .2178 .35461 .21649 Metetra
.664 .741 .907 r
.35461 .21649 .35578 .2178 .36203 .21545 .36087 .21414 Metetra
.664 .741 .907 r
.36087 .21414 .36203 .21545 .3683 .2131 .36714 .21178 Metetra
.664 .741 .907 r
.36714 .21178 .3683 .2131 .37459 .21074 .37343 .20942 Metetra
.664 .741 .907 r
.37343 .20942 .37459 .21074 .38089 .20838 .37974 .20706 Metetra
.664 .741 .907 r
.37974 .20706 .38089 .20838 .38721 .20601 .38605 .20468 Metetra
.664 .741 .907 r
.38605 .20468 .38721 .20601 .39354 .20363 .39239 .20231 Metetra
.664 .741 .907 r
.39239 .20231 .39354 .20363 .39988 .20125 .39874 .19992 Metetra
.664 .741 .907 r
.39874 .19992 .39988 .20125 .40624 .19887 .4051 .19753 Metetra
.664 .741 .907 r
.4051 .19753 .40624 .19887 .41262 .19647 .41148 .19514 Metetra
.664 .741 .907 r
.41148 .19514 .41262 .19647 .41901 .19408 .41787 .19274 Metetra
.664 .741 .907 r
.41787 .19274 .41901 .19408 .42542 .19167 .42428 .19033 Metetra
.664 .741 .907 r
.42428 .19033 .42542 .19167 .43184 .18926 .43071 .18792 Metetra
.664 .741 .907 r
.43071 .18792 .43184 .18926 .43828 .18685 .43715 .1855 Metetra
.664 .741 .907 r
.43715 .1855 .43828 .18685 .44473 .18443 .4436 .18308 Metetra
.664 .741 .907 r
.4436 .18308 .44473 .18443 .45119 .182 .45007 .18065 Metetra
.664 .741 .907 r
.45007 .18065 .45119 .182 .45768 .17957 .45656 .17821 Metetra
.664 .741 .907 r
.45656 .17821 .45768 .17957 .46418 .17713 .46306 .17577 Metetra
.664 .741 .907 r
.46306 .17577 .46418 .17713 .47069 .17469 .46957 .17332 Metetra
.664 .741 .907 r
.46957 .17332 .47069 .17469 .47722 .17224 .47611 .17087 Metetra
.664 .741 .907 r
.47611 .17087 .47722 .17224 .48376 .16978 .48266 .16841 Metetra
.664 .741 .907 r
.48266 .16841 .48376 .16978 .49033 .16732 .48922 .16595 Metetra
.664 .741 .907 r
.48922 .16595 .49033 .16732 .4969 .16485 .4958 .16347 Metetra
.664 .741 .907 r
.4958 .16347 .4969 .16485 .50349 .16238 .5024 .161 Metetra
.664 .741 .907 r
.5024 .161 .50349 .16238 .5101 .1599 .50901 .15852 Metetra
.664 .741 .907 r
.50901 .15852 .5101 .1599 .51673 .15742 .51563 .15603 Metetra
.664 .741 .907 r
.51563 .15603 .51673 .15742 .52337 .15492 .52228 .15353 Metetra
.664 .741 .907 r
.52228 .15353 .52337 .15492 .53002 .15243 .52894 .15103 Metetra
.664 .741 .907 r
.52894 .15103 .53002 .15243 .5367 .14992 .53561 .14852 Metetra
.664 .741 .907 r
.53561 .14852 .5367 .14992 .54339 .14741 .54231 .14601 Metetra
.664 .741 .907 r
.54231 .14601 .54339 .14741 .55009 .1449 .54901 .14349 Metetra
.664 .741 .907 r
.54901 .14349 .55009 .1449 .55681 .14238 .55574 .14097 Metetra
.664 .741 .907 r
.55574 .14097 .55681 .14238 .56355 .13985 .56248 .13844 Metetra
.664 .741 .907 r
.56248 .13844 .56355 .13985 .57031 .13731 .56924 .1359 Metetra
.664 .741 .907 r
.56924 .1359 .57031 .13731 .57708 .13477 .57601 .13336 Metetra
.664 .741 .907 r
.57601 .13336 .57708 .13477 .58386 .13223 .5828 .13081 Metetra
.664 .741 .907 r
.5828 .13081 .58386 .13223 .59117 .15217 .58961 .12825 Metetra
.202 .079 .48 r
.58961 .12825 .59117 .15217 .59865 .1745 .59758 .17293 Metetra
.976 .726 .492 r
.59758 .17293 .59865 .1745 .60433 .12455 .60327 .12312 Metetra
.664 .741 .907 r
.60327 .12312 .60433 .12455 .61118 .12198 .61013 .12054 Metetra
.664 .741 .907 r
.61013 .12054 .61118 .12198 .61805 .1194 .61701 .11796 Metetra
.664 .741 .907 r
.61701 .11796 .61805 .1194 .62494 .11682 .6239 .11537 Metetra
.664 .741 .907 r
.6239 .11537 .62494 .11682 .63184 .11423 .63081 .11278 Metetra
.664 .741 .907 r
.63081 .11278 .63184 .11423 .63877 .11163 .63773 .11018 Metetra
.664 .741 .907 r
.63773 .11018 .63877 .11163 .6457 .10903 .64467 .10757 Metetra
.664 .741 .907 r
.64467 .10757 .6457 .10903 .65266 .10642 .65163 .10496 Metetra
.664 .741 .907 r
.65163 .10496 .65266 .10642 .65963 .1038 .65861 .10234 Metetra
.664 .741 .907 r
.65861 .10234 .65963 .1038 .66662 .10118 .66561 .09971 Metetra
.664 .741 .907 r
.66561 .09971 .66662 .10118 .67363 .09855 .67262 .09708 Metetra
.664 .741 .907 r
.67262 .09708 .67363 .09855 .68066 .09591 .67965 .09444 Metetra
.664 .741 .907 r
.67965 .09444 .68066 .09591 .6877 .09327 .68669 .09179 Metetra
.664 .741 .907 r
.68669 .09179 .6877 .09327 .69476 .09062 .69376 .08914 Metetra
.664 .741 .907 r
.69376 .08914 .69476 .09062 .70184 .08797 .70084 .08648 Metetra
.664 .741 .907 r
.70084 .08648 .70184 .08797 .70894 .0853 .70794 .08382 Metetra
.664 .741 .907 r
.70794 .08382 .70894 .0853 .71605 .08264 .71506 .08114 Metetra
.664 .741 .907 r
.71506 .08114 .71605 .08264 .72318 .07996 .72219 .07847 Metetra
.664 .741 .907 r
.72219 .07847 .72318 .07996 .73033 .07728 .72935 .07578 Metetra
.664 .741 .907 r
.72935 .07578 .73033 .07728 .7375 .07459 .73652 .07309 Metetra
.664 .741 .907 r
.09741 .3114 .09868 .31259 .10435 .31046 .10308 .30927 Metetra
.664 .741 .907 r
.10308 .30927 .10435 .31046 .11004 .30833 .10877 .30713 Metetra
.664 .741 .907 r
.10877 .30713 .11004 .30833 .11573 .30619 .11447 .30499 Metetra
.664 .741 .907 r
.11447 .30499 .11573 .30619 .12144 .30404 .12018 .30285 Metetra
.664 .741 .907 r
.12018 .30285 .12144 .30404 .12717 .30189 .12591 .30069 Metetra
.664 .741 .907 r
.12591 .30069 .12717 .30189 .1329 .29974 .13165 .29854 Metetra
.664 .741 .907 r
.13165 .29854 .1329 .29974 .13865 .29758 .1374 .29638 Metetra
.664 .741 .907 r
.1374 .29638 .13865 .29758 .14442 .29542 .14316 .29421 Metetra
.664 .741 .907 r
.14316 .29421 .14442 .29542 .15019 .29325 .14894 .29204 Metetra
.664 .741 .907 r
.14894 .29204 .15019 .29325 .15598 .29108 .15473 .28986 Metetra
.664 .741 .907 r
.15473 .28986 .15598 .29108 .16178 .2889 .16053 .28768 Metetra
.818 .351 0 r
.16053 .28768 .16178 .2889 .1676 .28671 .16511 .29622 Metetra
.213 0 .298 r
.16511 .29622 .1676 .28671 .17342 .28453 .17218 .2833 Metetra
.664 .741 .907 r
.17218 .2833 .17342 .28453 .17926 .28233 .17802 .28111 Metetra
.664 .741 .907 r
.17802 .28111 .17926 .28233 .18512 .28013 .18388 .27891 Metetra
.664 .741 .907 r
.18388 .27891 .18512 .28013 .19099 .27793 .18975 .2767 Metetra
.664 .741 .907 r
.18975 .2767 .19099 .27793 .19687 .27572 .19563 .27449 Metetra
.664 .741 .907 r
.19563 .27449 .19687 .27572 .20276 .27351 .20153 .27227 Metetra
.664 .741 .907 r
.20153 .27227 .20276 .27351 .20867 .27129 .20744 .27005 Metetra
.664 .741 .907 r
.20744 .27005 .20867 .27129 .21459 .26907 .21336 .26783 Metetra
.664 .741 .907 r
.21336 .26783 .21459 .26907 .22052 .26684 .2193 .26559 Metetra
.664 .741 .907 r
.2193 .26559 .22052 .26684 .22647 .26461 .22525 .26336 Metetra
.664 .741 .907 r
.22525 .26336 .22647 .26461 .23243 .26237 .23121 .26112 Metetra
.664 .741 .907 r
.23121 .26112 .23243 .26237 .23841 .26012 .23719 .25887 Metetra
.664 .741 .907 r
.23719 .25887 .23841 .26012 .2444 .25787 .24318 .25662 Metetra
.664 .741 .907 r
.24318 .25662 .2444 .25787 .2504 .25562 .24919 .25436 Metetra
.664 .741 .907 r
.24919 .25436 .2504 .25562 .25642 .25336 .25521 .2521 Metetra
.664 .741 .907 r
.25521 .2521 .25642 .25336 .26245 .2511 .26124 .24983 Metetra
.664 .741 .907 r
.26124 .24983 .26245 .2511 .26849 .24883 .26729 .24756 Metetra
.664 .741 .907 r
.26729 .24756 .26849 .24883 .27455 .24655 .27335 .24528 Metetra
.664 .741 .907 r
.27335 .24528 .27455 .24655 .28063 .24427 .27943 .243 Metetra
.664 .741 .907 r
.27943 .243 .28063 .24427 .28671 .24199 .28552 .24071 Metetra
.664 .741 .907 r
.28552 .24071 .28671 .24199 .29281 .2397 .29162 .23842 Metetra
.958 .678 .46 r
.29162 .23842 .29281 .2397 .28933 .36744 .28368 .42542 Metetra
.18 0 .385 r
.28368 .42542 .28933 .36744 .28812 .47062 .29673 .33256 Metetra
.607 .362 .52 r
.29673 .33256 .28812 .47062 .3112 .23279 .31001 .2315 Metetra
.664 .741 .907 r
.31001 .2315 .3112 .23279 .31736 .23048 .31617 .22919 Metetra
.664 .741 .907 r
.31617 .22919 .31736 .23048 .32353 .22816 .32235 .22687 Metetra
.664 .741 .907 r
.32235 .22687 .32353 .22816 .32972 .22584 .32854 .22454 Metetra
.664 .741 .907 r
.32854 .22454 .32972 .22584 .33592 .22351 .33474 .22221 Metetra
.664 .741 .907 r
.33474 .22221 .33592 .22351 .34213 .22118 .34096 .21987 Metetra
.664 .741 .907 r
.34096 .21987 .34213 .22118 .34836 .21884 .34719 .21753 Metetra
.664 .741 .907 r
.34719 .21753 .34836 .21884 .35461 .21649 .35344 .21518 Metetra
.664 .741 .907 r
.35344 .21518 .35461 .21649 .36087 .21414 .3597 .21283 Metetra
.664 .741 .907 r
.3597 .21283 .36087 .21414 .36714 .21178 .36598 .21047 Metetra
.664 .741 .907 r
.36598 .21047 .36714 .21178 .37343 .20942 .37227 .2081 Metetra
.664 .741 .907 r
.37227 .2081 .37343 .20942 .37974 .20706 .37858 .20573 Metetra
.664 .741 .907 r
.37858 .20573 .37974 .20706 .38605 .20468 .3849 .20336 Metetra
.664 .741 .907 r
.3849 .20336 .38605 .20468 .39239 .20231 .39124 .20098 Metetra
.664 .741 .907 r
.39124 .20098 .39239 .20231 .39874 .19992 .39759 .19859 Metetra
.664 .741 .907 r
.39759 .19859 .39874 .19992 .4051 .19753 .40395 .1962 Metetra
.664 .741 .907 r
.40395 .1962 .4051 .19753 .41148 .19514 .41034 .1938 Metetra
.664 .741 .907 r
.41034 .1938 .41148 .19514 .41787 .19274 .41673 .19139 Metetra
.664 .741 .907 r
.41673 .19139 .41787 .19274 .42428 .19033 .42314 .18898 Metetra
.664 .741 .907 r
.42314 .18898 .42428 .19033 .43071 .18792 .42957 .18657 Metetra
.664 .741 .907 r
.42957 .18657 .43071 .18792 .43715 .1855 .43601 .18415 Metetra
.664 .741 .907 r
.43601 .18415 .43715 .1855 .4436 .18308 .44247 .18172 Metetra
.664 .741 .907 r
.44247 .18172 .4436 .18308 .45007 .18065 .44895 .17929 Metetra
.664 .741 .907 r
.44895 .17929 .45007 .18065 .45656 .17821 .45543 .17685 Metetra
.664 .741 .907 r
.45543 .17685 .45656 .17821 .46306 .17577 .46194 .1744 Metetra
.664 .741 .907 r
.46194 .1744 .46306 .17577 .46957 .17332 .46846 .17195 Metetra
.664 .741 .907 r
.46846 .17195 .46957 .17332 .47611 .17087 .47499 .1695 Metetra
.664 .741 .907 r
.47499 .1695 .47611 .17087 .48266 .16841 .48155 .16704 Metetra
.664 .741 .907 r
.48155 .16704 .48266 .16841 .48922 .16595 .48811 .16457 Metetra
.664 .741 .907 r
.48811 .16457 .48922 .16595 .4958 .16347 .4947 .16209 Metetra
.664 .741 .907 r
.4947 .16209 .4958 .16347 .5024 .161 .50129 .15961 Metetra
.664 .741 .907 r
.50129 .15961 .5024 .161 .50901 .15852 .50791 .15713 Metetra
.664 .741 .907 r
.50791 .15713 .50901 .15852 .51563 .15603 .51454 .15464 Metetra
.664 .741 .907 r
.51454 .15464 .51563 .15603 .52228 .15353 .52119 .15214 Metetra
.664 .741 .907 r
.52119 .15214 .52228 .15353 .52894 .15103 .52785 .14963 Metetra
.664 .741 .907 r
.52785 .14963 .52894 .15103 .53561 .14852 .53453 .14712 Metetra
.664 .741 .907 r
.53453 .14712 .53561 .14852 .54231 .14601 .54122 .14461 Metetra
.664 .741 .907 r
.54122 .14461 .54231 .14601 .54901 .14349 .54794 .14209 Metetra
.664 .741 .907 r
.54794 .14209 .54901 .14349 .55574 .14097 .55466 .13956 Metetra
.664 .741 .907 r
.55466 .13956 .55574 .14097 .56248 .13844 .56141 .13702 Metetra
.664 .741 .907 r
.56141 .13702 .56248 .13844 .56924 .1359 .56817 .13448 Metetra
.664 .741 .907 r
.56817 .13448 .56924 .1359 .57601 .13336 .57495 .13193 Metetra
.482 .658 .939 r
.57495 .13193 .57601 .13336 .5828 .13081 .58179 .13177 Metetra
.58179 .13177 .5828 .13081 .58961 .12825 .58855 .12682 Metetra
.606 .717 .923 r
.58855 .12682 .58961 .12825 .59758 .17293 .5954 .12515 Metetra
.524 .301 .518 r
.5954 .12515 .59758 .17293 .60327 .12312 .60222 .12168 Metetra
.664 .741 .907 r
.60222 .12168 .60327 .12312 .61013 .12054 .60908 .1191 Metetra
.664 .741 .907 r
.60908 .1191 .61013 .12054 .61701 .11796 .61596 .11652 Metetra
.664 .741 .907 r
.61596 .11652 .61701 .11796 .6239 .11537 .62286 .11393 Metetra
.664 .741 .907 r
.62286 .11393 .6239 .11537 .63081 .11278 .62977 .11133 Metetra
.664 .741 .907 r
.62977 .11133 .63081 .11278 .63773 .11018 .6367 .10873 Metetra
.664 .741 .907 r
.6367 .10873 .63773 .11018 .64467 .10757 .64364 .10612 Metetra
.664 .741 .907 r
.64364 .10612 .64467 .10757 .65163 .10496 .65061 .1035 Metetra
.664 .741 .907 r
.65061 .1035 .65163 .10496 .65861 .10234 .65759 .10088 Metetra
.664 .741 .907 r
.65759 .10088 .65861 .10234 .66561 .09971 .66458 .09825 Metetra
.664 .741 .907 r
.66458 .09825 .66561 .09971 .67262 .09708 .6716 .09561 Metetra
.664 .741 .907 r
.6716 .09561 .67262 .09708 .67965 .09444 .67863 .09297 Metetra
.664 .741 .907 r
.67863 .09297 .67965 .09444 .68669 .09179 .68568 .09032 Metetra
.664 .741 .907 r
.68568 .09032 .68669 .09179 .69376 .08914 .69275 .08766 Metetra
.664 .741 .907 r
.69275 .08766 .69376 .08914 .70084 .08648 .69984 .085 Metetra
.664 .741 .907 r
.69984 .085 .70084 .08648 .70794 .08382 .70694 .08233 Metetra
.664 .741 .907 r
.70694 .08233 .70794 .08382 .71506 .08114 .71406 .07965 Metetra
.664 .741 .907 r
.71406 .07965 .71506 .08114 .72219 .07847 .7212 .07697 Metetra
.664 .741 .907 r
.7212 .07697 .72219 .07847 .72935 .07578 .72836 .07428 Metetra
.664 .741 .907 r
.72836 .07428 .72935 .07578 .73652 .07309 .73553 .07158 Metetra
.664 .741 .907 r
.09613 .31022 .09741 .3114 .10308 .30927 .10181 .30808 Metetra
.664 .741 .907 r
.10181 .30808 .10308 .30927 .10877 .30713 .1075 .30594 Metetra
.664 .741 .907 r
.1075 .30594 .10877 .30713 .11447 .30499 .1132 .3038 Metetra
.664 .741 .907 r
.1132 .3038 .11447 .30499 .12018 .30285 .11892 .30165 Metetra
.664 .741 .907 r
.11892 .30165 .12018 .30285 .12591 .30069 .12465 .29949 Metetra
.664 .741 .907 r
.12465 .29949 .12591 .30069 .13165 .29854 .13039 .29733 Metetra
.664 .741 .907 r
.13039 .29733 .13165 .29854 .1374 .29638 .13614 .29517 Metetra
.664 .741 .907 r
.13614 .29517 .1374 .29638 .14316 .29421 .14191 .293 Metetra
.664 .741 .907 r
.14191 .293 .14316 .29421 .14894 .29204 .14769 .29082 Metetra
.664 .741 .907 r
.14769 .29082 .14894 .29204 .15473 .28986 .15348 .28865 Metetra
.664 .741 .907 r
.15348 .28865 .15473 .28986 .16053 .28768 .15928 .28646 Metetra
.593 .72 .932 r
.15928 .28646 .16053 .28768 .16511 .29622 .165 .2852 Metetra
.561 .368 .577 r
.165 .2852 .16511 .29622 .17218 .2833 .17094 .28208 Metetra
.664 .741 .907 r
.17094 .28208 .17218 .2833 .17802 .28111 .17678 .27988 Metetra
.664 .741 .907 r
.17678 .27988 .17802 .28111 .18388 .27891 .18264 .27768 Metetra
.664 .741 .907 r
.18264 .27768 .18388 .27891 .18975 .2767 .18851 .27547 Metetra
.664 .741 .907 r
.18851 .27547 .18975 .2767 .19563 .27449 .1944 .27325 Metetra
.664 .741 .907 r
.1944 .27325 .19563 .27449 .20153 .27227 .2003 .27104 Metetra
.664 .741 .907 r
.2003 .27104 .20153 .27227 .20744 .27005 .20621 .26881 Metetra
.664 .741 .907 r
.20621 .26881 .20744 .27005 .21336 .26783 .21213 .26658 Metetra
.664 .741 .907 r
.21213 .26658 .21336 .26783 .2193 .26559 .21807 .26435 Metetra
.664 .741 .907 r
.21807 .26435 .2193 .26559 .22525 .26336 .22403 .26211 Metetra
.664 .741 .907 r
.22403 .26211 .22525 .26336 .23121 .26112 .22999 .25986 Metetra
.664 .741 .907 r
.22999 .25986 .23121 .26112 .23719 .25887 .23597 .25761 Metetra
.664 .741 .907 r
.23597 .25761 .23719 .25887 .24318 .25662 .24197 .25536 Metetra
.664 .741 .907 r
.24197 .25536 .24318 .25662 .24919 .25436 .24798 .2531 Metetra
.664 .741 .907 r
.24798 .2531 .24919 .25436 .25521 .2521 .254 .25083 Metetra
.664 .741 .907 r
.254 .25083 .25521 .2521 .26124 .24983 .26003 .24856 Metetra
.664 .741 .907 r
.26003 .24856 .26124 .24983 .26729 .24756 .26608 .24629 Metetra
.664 .741 .907 r
.26608 .24629 .26729 .24756 .27335 .24528 .27215 .24401 Metetra
.664 .741 .907 r
.27215 .24401 .27335 .24528 .27943 .243 .27823 .24172 Metetra
.664 .741 .907 r
.27823 .24172 .27943 .243 .28552 .24071 .28432 .23943 Metetra
.664 .741 .907 r
.28432 .23943 .28552 .24071 .29162 .23842 .29042 .23713 Metetra
.959 .667 .437 r
.29042 .23713 .29162 .23842 .28368 .42542 .28947 .3296 Metetra
.583 .344 .519 r
.28947 .3296 .28368 .42542 .29673 .33256 .29933 .2786 Metetra
.622 .38 .53 r
.29933 .2786 .29673 .33256 .31001 .2315 .30883 .23021 Metetra
.664 .741 .907 r
.30883 .23021 .31001 .2315 .31617 .22919 .31499 .22789 Metetra
.664 .741 .907 r
.31499 .22789 .31617 .22919 .32235 .22687 .32117 .22557 Metetra
.664 .741 .907 r
.32117 .22557 .32235 .22687 .32854 .22454 .32736 .22324 Metetra
.664 .741 .907 r
.32736 .22324 .32854 .22454 .33474 .22221 .33357 .22091 Metetra
.664 .741 .907 r
.33357 .22091 .33474 .22221 .34096 .21987 .33979 .21857 Metetra
.664 .741 .907 r
.33979 .21857 .34096 .21987 .34719 .21753 .34602 .21622 Metetra
.664 .741 .907 r
.34602 .21622 .34719 .21753 .35344 .21518 .35227 .21387 Metetra
.664 .741 .907 r
.35227 .21387 .35344 .21518 .3597 .21283 .35854 .21151 Metetra
.664 .741 .907 r
.35854 .21151 .3597 .21283 .36598 .21047 .36482 .20915 Metetra
.664 .741 .907 r
.36482 .20915 .36598 .21047 .37227 .2081 .37111 .20678 Metetra
.664 .741 .907 r
.37111 .20678 .37227 .2081 .37858 .20573 .37742 .20441 Metetra
.664 .741 .907 r
.37742 .20441 .37858 .20573 .3849 .20336 .38374 .20203 Metetra
.664 .741 .907 r
.38374 .20203 .3849 .20336 .39124 .20098 .39008 .19965 Metetra
.664 .741 .907 r
.39008 .19965 .39124 .20098 .39759 .19859 .39644 .19726 Metetra
.664 .741 .907 r
.39644 .19726 .39759 .19859 .40395 .1962 .40281 .19486 Metetra
.664 .741 .907 r
.40281 .19486 .40395 .1962 .41034 .1938 .40919 .19246 Metetra
.664 .741 .907 r
.40919 .19246 .41034 .1938 .41673 .19139 .41559 .19005 Metetra
.664 .741 .907 r
.41559 .19005 .41673 .19139 .42314 .18898 .42201 .18764 Metetra
.664 .741 .907 r
.42201 .18764 .42314 .18898 .42957 .18657 .42844 .18522 Metetra
.664 .741 .907 r
.42844 .18522 .42957 .18657 .43601 .18415 .43488 .18279 Metetra
.664 .741 .907 r
.43488 .18279 .43601 .18415 .44247 .18172 .44134 .18036 Metetra
.664 .741 .907 r
.44134 .18036 .44247 .18172 .44895 .17929 .44782 .17793 Metetra
.664 .741 .907 r
.44782 .17793 .44895 .17929 .45543 .17685 .45431 .17549 Metetra
.664 .741 .907 r
.45431 .17549 .45543 .17685 .46194 .1744 .46082 .17304 Metetra
.664 .741 .907 r
.46082 .17304 .46194 .1744 .46846 .17195 .46734 .17059 Metetra
.664 .741 .907 r
.46734 .17059 .46846 .17195 .47499 .1695 .47388 .16813 Metetra
.664 .741 .907 r
.47388 .16813 .47499 .1695 .48155 .16704 .48043 .16566 Metetra
.664 .741 .907 r
.48043 .16566 .48155 .16704 .48811 .16457 .487 .16319 Metetra
.664 .741 .907 r
.487 .16319 .48811 .16457 .4947 .16209 .49359 .16071 Metetra
.664 .741 .907 r
.49359 .16071 .4947 .16209 .50129 .15961 .50019 .15823 Metetra
.664 .741 .907 r
.50019 .15823 .50129 .15961 .50791 .15713 .50681 .15574 Metetra
.664 .741 .907 r
.50681 .15574 .50791 .15713 .51454 .15464 .51344 .15324 Metetra
.664 .741 .907 r
.51344 .15324 .51454 .15464 .52119 .15214 .52009 .15074 Metetra
.664 .741 .907 r
.52009 .15074 .52119 .15214 .52785 .14963 .52676 .14823 Metetra
.664 .741 .907 r
.52676 .14823 .52785 .14963 .53453 .14712 .53344 .14572 Metetra
.664 .741 .907 r
.53344 .14572 .53453 .14712 .54122 .14461 .54014 .1432 Metetra
.664 .741 .907 r
.54014 .1432 .54122 .14461 .54794 .14209 .54686 .14068 Metetra
.664 .741 .907 r
.54686 .14068 .54794 .14209 .55466 .13956 .55359 .13814 Metetra
.664 .741 .907 r
.55359 .13814 .55466 .13956 .56141 .13702 .56033 .13561 Metetra
.664 .741 .907 r
.56033 .13561 .56141 .13702 .56817 .13448 .5671 .13306 Metetra
.664 .741 .907 r
.5671 .13306 .56817 .13448 .57495 .13193 .57388 .13051 Metetra
.664 .741 .907 r
.57388 .13051 .57495 .13193 .58179 .13177 .58068 .12795 Metetra
.608 .504 .71 r
.58068 .12795 .58179 .13177 .58855 .12682 .58749 .12539 Metetra
.664 .741 .907 r
.58749 .12539 .58855 .12682 .5954 .12515 .59432 .12282 Metetra
.642 .616 .809 r
.59432 .12282 .5954 .12515 .60222 .12168 .60117 .12025 Metetra
.664 .741 .907 r
.60117 .12025 .60222 .12168 .60908 .1191 .60803 .11766 Metetra
.664 .741 .907 r
.60803 .11766 .60908 .1191 .61596 .11652 .61491 .11507 Metetra
.664 .741 .907 r
.61491 .11507 .61596 .11652 .62286 .11393 .62181 .11248 Metetra
.664 .741 .907 r
.62181 .11248 .62286 .11393 .62977 .11133 .62873 .10988 Metetra
.664 .741 .907 r
.62873 .10988 .62977 .11133 .6367 .10873 .63566 .10727 Metetra
.664 .741 .907 r
.63566 .10727 .6367 .10873 .64364 .10612 .64261 .10466 Metetra
.664 .741 .907 r
.64261 .10466 .64364 .10612 .65061 .1035 .64958 .10204 Metetra
.664 .741 .907 r
.64958 .10204 .65061 .1035 .65759 .10088 .65656 .09941 Metetra
.664 .741 .907 r
.65656 .09941 .65759 .10088 .66458 .09825 .66356 .09678 Metetra
.664 .741 .907 r
.66356 .09678 .66458 .09825 .6716 .09561 .67058 .09414 Metetra
.664 .741 .907 r
.67058 .09414 .6716 .09561 .67863 .09297 .67762 .09149 Metetra
.664 .741 .907 r
.67762 .09149 .67863 .09297 .68568 .09032 .68467 .08884 Metetra
.664 .741 .907 r
.68467 .08884 .68568 .09032 .69275 .08766 .69174 .08618 Metetra
.664 .741 .907 r
.69174 .08618 .69275 .08766 .69984 .085 .69883 .08351 Metetra
.664 .741 .907 r
.69883 .08351 .69984 .085 .70694 .08233 .70594 .08084 Metetra
.664 .741 .907 r
.70594 .08084 .70694 .08233 .71406 .07965 .71306 .07816 Metetra
.664 .741 .907 r
.71306 .07816 .71406 .07965 .7212 .07697 .72021 .07547 Metetra
.664 .741 .907 r
.72021 .07547 .7212 .07697 .72836 .07428 .72737 .07277 Metetra
.664 .741 .907 r
.72737 .07277 .72836 .07428 .73553 .07158 .73455 .07007 Metetra
.664 .741 .907 r
.09486 .30903 .09613 .31022 .10181 .30808 .10054 .30689 Metetra
.664 .741 .907 r
.10054 .30689 .10181 .30808 .1075 .30594 .10623 .30474 Metetra
.664 .741 .907 r
.10623 .30474 .1075 .30594 .1132 .3038 .11193 .3026 Metetra
.664 .741 .907 r
.11193 .3026 .1132 .3038 .11892 .30165 .11765 .30044 Metetra
.664 .741 .907 r
.11765 .30044 .11892 .30165 .12465 .29949 .12338 .29829 Metetra
.664 .741 .907 r
.12338 .29829 .12465 .29949 .13039 .29733 .12912 .29613 Metetra
.664 .741 .907 r
.12912 .29613 .13039 .29733 .13614 .29517 .13488 .29396 Metetra
.664 .741 .907 r
.13488 .29396 .13614 .29517 .14191 .293 .14065 .29179 Metetra
.664 .741 .907 r
.14065 .29179 .14191 .293 .14769 .29082 .14643 .28961 Metetra
.664 .741 .907 r
.14643 .28961 .14769 .29082 .15348 .28865 .15223 .28743 Metetra
.94 .585 .31 r
.15223 .28743 .15348 .28865 .15928 .28646 .15545 .30711 Metetra
.269 .043 .376 r
.15545 .30711 .15928 .28646 .165 .2852 .16386 .28305 Metetra
.641 .61 .804 r
.16386 .28305 .165 .2852 .17094 .28208 .16969 .28085 Metetra
.664 .741 .907 r
.16969 .28085 .17094 .28208 .17678 .27988 .17554 .27865 Metetra
.664 .741 .907 r
.17554 .27865 .17678 .27988 .18264 .27768 .1814 .27645 Metetra
.664 .741 .907 r
.1814 .27645 .18264 .27768 .18851 .27547 .18727 .27423 Metetra
.664 .741 .907 r
.18727 .27423 .18851 .27547 .1944 .27325 .19316 .27202 Metetra
.664 .741 .907 r
.19316 .27202 .1944 .27325 .2003 .27104 .19906 .2698 Metetra
.664 .741 .907 r
.19906 .2698 .2003 .27104 .20621 .26881 .20498 .26757 Metetra
.664 .741 .907 r
.20498 .26757 .20621 .26881 .21213 .26658 .2109 .26534 Metetra
.664 .741 .907 r
.2109 .26534 .21213 .26658 .21807 .26435 .21685 .2631 Metetra
.664 .741 .907 r
.21685 .2631 .21807 .26435 .22403 .26211 .2228 .26086 Metetra
.664 .741 .907 r
.2228 .26086 .22403 .26211 .22999 .25986 .22877 .25861 Metetra
.664 .741 .907 r
.22877 .25861 .22999 .25986 .23597 .25761 .23475 .25636 Metetra
.664 .741 .907 r
.23475 .25636 .23597 .25761 .24197 .25536 .24075 .2541 Metetra
.664 .741 .907 r
.24075 .2541 .24197 .25536 .24798 .2531 .24676 .25184 Metetra
.664 .741 .907 r
.24676 .25184 .24798 .2531 .254 .25083 .25279 .24957 Metetra
.664 .741 .907 r
.25279 .24957 .254 .25083 .26003 .24856 .25882 .2473 Metetra
.664 .741 .907 r
.25882 .2473 .26003 .24856 .26608 .24629 .26488 .24502 Metetra
.664 .741 .907 r
.26488 .24502 .26608 .24629 .27215 .24401 .27094 .24273 Metetra
.664 .741 .907 r
.27094 .24273 .27215 .24401 .27823 .24172 .27702 .24044 Metetra
.664 .741 .907 r
.27702 .24044 .27823 .24172 .28432 .23943 .28312 .23815 Metetra
.664 .741 .907 r
.28312 .23815 .28432 .23943 .29042 .23713 .28923 .23585 Metetra
.664 .741 .907 r
.28923 .23585 .29042 .23713 .28947 .3296 .29535 .23355 Metetra
.51 .283 .506 r
.29535 .23355 .28947 .3296 .29933 .2786 .30116 .23571 Metetra
.536 .312 .521 r
.30116 .23571 .29933 .2786 .30883 .23021 .30764 .22892 Metetra
.664 .741 .907 r
.30764 .22892 .30883 .23021 .31499 .22789 .3138 .2266 Metetra
.664 .741 .907 r
.3138 .2266 .31499 .22789 .32117 .22557 .31998 .22427 Metetra
.664 .741 .907 r
.31998 .22427 .32117 .22557 .32736 .22324 .32618 .22194 Metetra
0 .163 .672 r
.32618 .22194 .32736 .22324 .33357 .22091 .33195 .22655 Metetra
.167 0 .223 r
.33195 .22655 .33357 .22091 .33979 .21857 .33861 .21726 Metetra
.664 .741 .907 r
.33861 .21726 .33979 .21857 .34602 .21622 .34485 .21491 Metetra
.664 .741 .907 r
.34485 .21491 .34602 .21622 .35227 .21387 .3511 .21256 Metetra
.664 .741 .907 r
.3511 .21256 .35227 .21387 .35854 .21151 .35737 .2102 Metetra
.664 .741 .907 r
.35737 .2102 .35854 .21151 .36482 .20915 .36365 .20783 Metetra
.664 .741 .907 r
.36365 .20783 .36482 .20915 .37111 .20678 .36995 .20546 Metetra
.664 .741 .907 r
.36995 .20546 .37111 .20678 .37742 .20441 .37626 .20308 Metetra
.664 .741 .907 r
.37626 .20308 .37742 .20441 .38374 .20203 .38259 .2007 Metetra
.664 .741 .907 r
.38259 .2007 .38374 .20203 .39008 .19965 .38893 .19831 Metetra
.664 .741 .907 r
.38893 .19831 .39008 .19965 .39644 .19726 .39529 .19592 Metetra
.664 .741 .907 r
.39529 .19592 .39644 .19726 .40281 .19486 .40166 .19352 Metetra
.664 .741 .907 r
.40166 .19352 .40281 .19486 .40919 .19246 .40805 .19112 Metetra
.664 .741 .907 r
.40805 .19112 .40919 .19246 .41559 .19005 .41445 .18871 Metetra
.664 .741 .907 r
.41445 .18871 .41559 .19005 .42201 .18764 .42087 .18629 Metetra
.664 .741 .907 r
.42087 .18629 .42201 .18764 .42844 .18522 .4273 .18387 Metetra
.664 .741 .907 r
.4273 .18387 .42844 .18522 .43488 .18279 .43375 .18144 Metetra
.664 .741 .907 r
.43375 .18144 .43488 .18279 .44134 .18036 .44021 .17901 Metetra
.664 .741 .907 r
.44021 .17901 .44134 .18036 .44782 .17793 .44669 .17657 Metetra
.664 .741 .907 r
.44669 .17657 .44782 .17793 .45431 .17549 .45319 .17412 Metetra
.664 .741 .907 r
.45319 .17412 .45431 .17549 .46082 .17304 .4597 .17167 Metetra
.664 .741 .907 r
.4597 .17167 .46082 .17304 .46734 .17059 .46622 .16921 Metetra
.664 .741 .907 r
.46622 .16921 .46734 .17059 .47388 .16813 .47276 .16675 Metetra
.664 .741 .907 r
.47276 .16675 .47388 .16813 .48043 .16566 .47932 .16428 Metetra
.664 .741 .907 r
.47932 .16428 .48043 .16566 .487 .16319 .48589 .16181 Metetra
.664 .741 .907 r
.48589 .16181 .487 .16319 .49359 .16071 .49248 .15933 Metetra
.664 .741 .907 r
.49248 .15933 .49359 .16071 .50019 .15823 .49909 .15684 Metetra
.664 .741 .907 r
.49909 .15684 .50019 .15823 .50681 .15574 .50571 .15435 Metetra
.664 .741 .907 r
.50571 .15435 .50681 .15574 .51344 .15324 .51235 .15185 Metetra
.664 .741 .907 r
.51235 .15185 .51344 .15324 .52009 .15074 .519 .14934 Metetra
.664 .741 .907 r
.519 .14934 .52009 .15074 .52676 .14823 .52567 .14683 Metetra
.664 .741 .907 r
.52567 .14683 .52676 .14823 .53344 .14572 .53235 .14432 Metetra
.664 .741 .907 r
.53235 .14432 .53344 .14572 .54014 .1432 .53906 .14179 Metetra
.664 .741 .907 r
.53906 .14179 .54014 .1432 .54686 .14068 .54577 .13926 Metetra
.664 .741 .907 r
.54577 .13926 .54686 .14068 .55359 .13814 .55251 .13673 Metetra
.664 .741 .907 r
.55251 .13673 .55359 .13814 .56033 .13561 .55926 .13419 Metetra
.664 .741 .907 r
.55926 .13419 .56033 .13561 .5671 .13306 .56603 .13164 Metetra
.664 .741 .907 r
.56603 .13164 .5671 .13306 .57388 .13051 .57281 .12909 Metetra
.664 .741 .907 r
.57281 .12909 .57388 .13051 .58068 .12795 .57961 .12652 Metetra
.664 .741 .907 r
.57961 .12652 .58068 .12795 .58749 .12539 .58643 .12396 Metetra
.664 .741 .907 r
.58643 .12396 .58749 .12539 .59432 .12282 .59326 .12139 Metetra
.664 .741 .907 r
.59326 .12139 .59432 .12282 .60117 .12025 .60011 .11881 Metetra
.664 .741 .907 r
.60011 .11881 .60117 .12025 .60803 .11766 .60698 .11622 Metetra
.664 .741 .907 r
.60698 .11622 .60803 .11766 .61491 .11507 .61387 .11363 Metetra
.664 .741 .907 r
.61387 .11363 .61491 .11507 .62181 .11248 .62077 .11103 Metetra
.664 .741 .907 r
.62077 .11103 .62181 .11248 .62873 .10988 .62769 .10843 Metetra
.664 .741 .907 r
.62769 .10843 .62873 .10988 .63566 .10727 .63462 .10581 Metetra
.664 .741 .907 r
.63462 .10581 .63566 .10727 .64261 .10466 .64158 .1032 Metetra
.664 .741 .907 r
.64158 .1032 .64261 .10466 .64958 .10204 .64855 .10057 Metetra
.664 .741 .907 r
.64855 .10057 .64958 .10204 .65656 .09941 .65553 .09794 Metetra
.664 .741 .907 r
.65553 .09794 .65656 .09941 .66356 .09678 .66254 .0953 Metetra
.664 .741 .907 r
.66254 .0953 .66356 .09678 .67058 .09414 .66956 .09266 Metetra
.664 .741 .907 r
.66956 .09266 .67058 .09414 .67762 .09149 .6766 .09001 Metetra
.664 .741 .907 r
.6766 .09001 .67762 .09149 .68467 .08884 .68366 .08735 Metetra
.664 .741 .907 r
.68366 .08735 .68467 .08884 .69174 .08618 .69073 .08469 Metetra
.664 .741 .907 r
.69073 .08469 .69174 .08618 .69883 .08351 .69783 .08202 Metetra
.664 .741 .907 r
.69783 .08202 .69883 .08351 .70594 .08084 .70494 .07934 Metetra
.664 .741 .907 r
.70494 .07934 .70594 .08084 .71306 .07816 .71207 .07666 Metetra
.664 .741 .907 r
.71207 .07666 .71306 .07816 .72021 .07547 .71921 .07397 Metetra
.664 .741 .907 r
.71921 .07397 .72021 .07547 .72737 .07277 .72638 .07127 Metetra
.664 .741 .907 r
.72638 .07127 .72737 .07277 .73455 .07007 .73356 .06857 Metetra
.664 .741 .907 r
.09358 .30783 .09486 .30903 .10054 .30689 .09926 .30569 Metetra
.664 .741 .907 r
.09926 .30569 .10054 .30689 .10623 .30474 .10496 .30355 Metetra
.664 .741 .907 r
.10496 .30355 .10623 .30474 .11193 .3026 .11066 .3014 Metetra
.664 .741 .907 r
.11066 .3014 .11193 .3026 .11765 .30044 .11638 .29924 Metetra
.664 .741 .907 r
.11638 .29924 .11765 .30044 .12338 .29829 .12212 .29708 Metetra
.664 .741 .907 r
.12212 .29708 .12338 .29829 .12912 .29613 .12786 .29492 Metetra
.664 .741 .907 r
.12786 .29492 .12912 .29613 .13488 .29396 .13362 .29275 Metetra
.664 .741 .907 r
.13362 .29275 .13488 .29396 .14065 .29179 .13939 .29057 Metetra
.664 .741 .907 r
.13939 .29057 .14065 .29179 .14643 .28961 .14517 .28839 Metetra
.664 .741 .907 r
.14517 .28839 .14643 .28961 .15223 .28743 .15097 .28621 Metetra
.664 .741 .907 r
.15097 .28621 .15223 .28743 .15545 .30711 .15678 .28402 Metetra
.53 .317 .536 r
.15678 .28402 .15545 .30711 .16386 .28305 .16261 .28183 Metetra
.664 .741 .907 r
.16261 .28183 .16386 .28305 .16969 .28085 .16844 .27963 Metetra
.664 .741 .907 r
.16844 .27963 .16969 .28085 .17554 .27865 .17429 .27742 Metetra
.878 .444 .067 r
.17429 .27742 .17554 .27865 .1814 .27645 .1787 .28828 Metetra
.234 0 .328 r
.1787 .28828 .1814 .27645 .18727 .27423 .18603 .273 Metetra
.664 .741 .907 r
.18603 .273 .18727 .27423 .19316 .27202 .19192 .27078 Metetra
.664 .741 .907 r
.19192 .27078 .19316 .27202 .19906 .2698 .19783 .26855 Metetra
.664 .741 .907 r
.19783 .26855 .19906 .2698 .20498 .26757 .20374 .26632 Metetra
.664 .741 .907 r
.20374 .26632 .20498 .26757 .2109 .26534 .20967 .26409 Metetra
.664 .741 .907 r
.20967 .26409 .2109 .26534 .21685 .2631 .21562 .26185 Metetra
.664 .741 .907 r
.21562 .26185 .21685 .2631 .2228 .26086 .22158 .2596 Metetra
.664 .741 .907 r
.22158 .2596 .2228 .26086 .22877 .25861 .22755 .25735 Metetra
.664 .741 .907 r
.22755 .25735 .22877 .25861 .23475 .25636 .23353 .2551 Metetra
.664 .741 .907 r
.23353 .2551 .23475 .25636 .24075 .2541 .23953 .25284 Metetra
.664 .741 .907 r
.23953 .25284 .24075 .2541 .24676 .25184 .24554 .25057 Metetra
.664 .741 .907 r
.24554 .25057 .24676 .25184 .25279 .24957 .25157 .2483 Metetra
.664 .741 .907 r
.25157 .2483 .25279 .24957 .25882 .2473 .25761 .24603 Metetra
.664 .741 .907 r
.25761 .24603 .25882 .2473 .26488 .24502 .26367 .24374 Metetra
.664 .741 .907 r
.26367 .24374 .26488 .24502 .27094 .24273 .26974 .24146 Metetra
.664 .741 .907 r
.26974 .24146 .27094 .24273 .27702 .24044 .27582 .23917 Metetra
.664 .741 .907 r
.27582 .23917 .27702 .24044 .28312 .23815 .28192 .23687 Metetra
.664 .741 .907 r
.28192 .23687 .28312 .23815 .28923 .23585 .28803 .23457 Metetra
.664 .741 .907 r
.28803 .23457 .28923 .23585 .29535 .23355 .29415 .23226 Metetra
.664 .741 .907 r
.29415 .23226 .29535 .23355 .30116 .23571 .30029 .22994 Metetra
.579 .428 .641 r
.30029 .22994 .30116 .23571 .30764 .22892 .30645 .22762 Metetra
.664 .741 .907 r
.30645 .22762 .30764 .22892 .3138 .2266 .31261 .2253 Metetra
.664 .741 .907 r
.31261 .2253 .3138 .2266 .31998 .22427 .3188 .22297 Metetra
.664 .741 .907 r
.3188 .22297 .31998 .22427 .32618 .22194 .32499 .22064 Metetra
.962 .672 .438 r
.32499 .22064 .32618 .22194 .33195 .22655 .3228 .35031 Metetra
.406 .187 .466 r
.3228 .35031 .33195 .22655 .33861 .21726 .33415 .2691 Metetra
.32 .111 .432 r
.33415 .2691 .33861 .21726 .34485 .21491 .34367 .2136 Metetra
.664 .741 .907 r
.34367 .2136 .34485 .21491 .3511 .21256 .34993 .21124 Metetra
.664 .741 .907 r
.34993 .21124 .3511 .21256 .35737 .2102 .3562 .20888 Metetra
.664 .741 .907 r
.3562 .20888 .35737 .2102 .36365 .20783 .36248 .20651 Metetra
.664 .741 .907 r
.36248 .20651 .36365 .20783 .36995 .20546 .36878 .20413 Metetra
.664 .741 .907 r
.36878 .20413 .36995 .20546 .37626 .20308 .3751 .20176 Metetra
.664 .741 .907 r
.3751 .20176 .37626 .20308 .38259 .2007 .38143 .19937 Metetra
.664 .741 .907 r
.38143 .19937 .38259 .2007 .38893 .19831 .38777 .19698 Metetra
.664 .741 .907 r
.38777 .19698 .38893 .19831 .39529 .19592 .39413 .19458 Metetra
.664 .741 .907 r
.39413 .19458 .39529 .19592 .40166 .19352 .40051 .19218 Metetra
.664 .741 .907 r
.40051 .19218 .40166 .19352 .40805 .19112 .4069 .18977 Metetra
.664 .741 .907 r
.4069 .18977 .40805 .19112 .41445 .18871 .4133 .18736 Metetra
.664 .741 .907 r
.4133 .18736 .41445 .18871 .42087 .18629 .41972 .18494 Metetra
.664 .741 .907 r
.41972 .18494 .42087 .18629 .4273 .18387 .42616 .18251 Metetra
.664 .741 .907 r
.42616 .18251 .4273 .18387 .43375 .18144 .43261 .18008 Metetra
.664 .741 .907 r
.43261 .18008 .43375 .18144 .44021 .17901 .43908 .17765 Metetra
.664 .741 .907 r
.43908 .17765 .44021 .17901 .44669 .17657 .44556 .1752 Metetra
.664 .741 .907 r
.44556 .1752 .44669 .17657 .45319 .17412 .45206 .17276 Metetra
.664 .741 .907 r
.45206 .17276 .45319 .17412 .4597 .17167 .45857 .1703 Metetra
.664 .741 .907 r
.45857 .1703 .4597 .17167 .46622 .16921 .4651 .16784 Metetra
.664 .741 .907 r
.4651 .16784 .46622 .16921 .47276 .16675 .47165 .16538 Metetra
.664 .741 .907 r
.47165 .16538 .47276 .16675 .47932 .16428 .47821 .1629 Metetra
.664 .741 .907 r
.47821 .1629 .47932 .16428 .48589 .16181 .48478 .16043 Metetra
.664 .741 .907 r
.48478 .16043 .48589 .16181 .49248 .15933 .49137 .15794 Metetra
.664 .741 .907 r
.49137 .15794 .49248 .15933 .49909 .15684 .49798 .15545 Metetra
.664 .741 .907 r
.49798 .15545 .49909 .15684 .50571 .15435 .50461 .15295 Metetra
.664 .741 .907 r
.50461 .15295 .50571 .15435 .51235 .15185 .51125 .15045 Metetra
.664 .741 .907 r
.51125 .15045 .51235 .15185 .519 .14934 .5179 .14794 Metetra
.664 .741 .907 r
.5179 .14794 .519 .14934 .52567 .14683 .52458 .14543 Metetra
.664 .741 .907 r
.52458 .14543 .52567 .14683 .53235 .14432 .53126 .14291 Metetra
.664 .741 .907 r
.53126 .14291 .53235 .14432 .53906 .14179 .53797 .14038 Metetra
.664 .741 .907 r
.53797 .14038 .53906 .14179 .54577 .13926 .54469 .13785 Metetra
.664 .741 .907 r
.54469 .13785 .54577 .13926 .55251 .13673 .55143 .13531 Metetra
.664 .741 .907 r
.55143 .13531 .55251 .13673 .55926 .13419 .55818 .13277 Metetra
.664 .741 .907 r
.55818 .13277 .55926 .13419 .56603 .13164 .56495 .13022 Metetra
.664 .741 .907 r
.56495 .13022 .56603 .13164 .57281 .12909 .57174 .12766 Metetra
.664 .741 .907 r
.57174 .12766 .57281 .12909 .57961 .12652 .57854 .12509 Metetra
.664 .741 .907 r
.57854 .12509 .57961 .12652 .58643 .12396 .58537 .12252 Metetra
.664 .741 .907 r
.58537 .12252 .58643 .12396 .59326 .12139 .5922 .11995 Metetra
.664 .741 .907 r
.5922 .11995 .59326 .12139 .60011 .11881 .59906 .11736 Metetra
.664 .741 .907 r
.59906 .11736 .60011 .11881 .60698 .11622 .60593 .11478 Metetra
.664 .741 .907 r
.60593 .11478 .60698 .11622 .61387 .11363 .61282 .11218 Metetra
.664 .741 .907 r
.61282 .11218 .61387 .11363 .62077 .11103 .61972 .10958 Metetra
.664 .741 .907 r
.61972 .10958 .62077 .11103 .62769 .10843 .62664 .10697 Metetra
.664 .741 .907 r
.62664 .10697 .62769 .10843 .63462 .10581 .63358 .10435 Metetra
.664 .741 .907 r
.63358 .10435 .63462 .10581 .64158 .1032 .64054 .10173 Metetra
.664 .741 .907 r
.64054 .10173 .64158 .1032 .64855 .10057 .64751 .09911 Metetra
.664 .741 .907 r
.64751 .09911 .64855 .10057 .65553 .09794 .65451 .09647 Metetra
.664 .741 .907 r
.65451 .09647 .65553 .09794 .66254 .0953 .66151 .09383 Metetra
.945 .594 .197 r
.66151 .09383 .66254 .0953 .66956 .09266 .67144 .15006 Metetra
.355 .151 .46 r
.67144 .15006 .66956 .09266 .6766 .09001 .67558 .08853 Metetra
.664 .741 .907 r
.67558 .08853 .6766 .09001 .68366 .08735 .68265 .08587 Metetra
.664 .741 .907 r
.68265 .08587 .68366 .08735 .69073 .08469 .68972 .0832 Metetra
.664 .741 .907 r
.68972 .0832 .69073 .08469 .69783 .08202 .69682 .08053 Metetra
.664 .741 .907 r
.69682 .08053 .69783 .08202 .70494 .07934 .70394 .07785 Metetra
.664 .741 .907 r
.70394 .07785 .70494 .07934 .71207 .07666 .71107 .07516 Metetra
.664 .741 .907 r
.71107 .07516 .71207 .07666 .71921 .07397 .71822 .07246 Metetra
.664 .741 .907 r
.71822 .07246 .71921 .07397 .72638 .07127 .72539 .06976 Metetra
.664 .741 .907 r
.72539 .06976 .72638 .07127 .73356 .06857 .73257 .06705 Metetra
.664 .741 .907 r
.09231 .30664 .09358 .30783 .09926 .30569 .09799 .3045 Metetra
.664 .741 .907 r
.09799 .3045 .09926 .30569 .10496 .30355 .10368 .30235 Metetra
.664 .741 .907 r
.10368 .30235 .10496 .30355 .11066 .3014 .10939 .3002 Metetra
.664 .741 .907 r
.10939 .3002 .11066 .3014 .11638 .29924 .11511 .29804 Metetra
.664 .741 .907 r
.11511 .29804 .11638 .29924 .12212 .29708 .12085 .29588 Metetra
.664 .741 .907 r
.12085 .29588 .12212 .29708 .12786 .29492 .1266 .29371 Metetra
.664 .741 .907 r
.1266 .29371 .12786 .29492 .13362 .29275 .13236 .29154 Metetra
.664 .741 .907 r
.13236 .29154 .13362 .29275 .13939 .29057 .13813 .28936 Metetra
.664 .741 .907 r
.13813 .28936 .13939 .29057 .14517 .28839 .14392 .28718 Metetra
.664 .741 .907 r
.14392 .28718 .14517 .28839 .15097 .28621 .14972 .28499 Metetra
.664 .741 .907 r
.14972 .28499 .15097 .28621 .15678 .28402 .15553 .2828 Metetra
.664 .741 .907 r
.15553 .2828 .15678 .28402 .16261 .28183 .16135 .2806 Metetra
.664 .741 .907 r
.16135 .2806 .16261 .28183 .16844 .27963 .16719 .2784 Metetra
.664 .741 .907 r
.16719 .2784 .16844 .27963 .17429 .27742 .17305 .27619 Metetra
.664 .741 .907 r
.17305 .27619 .17429 .27742 .1787 .28828 .17891 .27398 Metetra
.541 .341 .558 r
.17891 .27398 .1787 .28828 .18603 .273 .18479 .27176 Metetra
.664 .741 .907 r
.18479 .27176 .18603 .273 .19192 .27078 .19068 .26954 Metetra
.664 .741 .907 r
.19068 .26954 .19192 .27078 .19783 .26855 .19659 .26731 Metetra
.664 .741 .907 r
.19659 .26731 .19783 .26855 .20374 .26632 .20251 .26508 Metetra
.664 .741 .907 r
.20251 .26508 .20374 .26632 .20967 .26409 .20844 .26284 Metetra
.664 .741 .907 r
.20844 .26284 .20967 .26409 .21562 .26185 .21439 .2606 Metetra
.664 .741 .907 r
.21439 .2606 .21562 .26185 .22158 .2596 .22035 .25835 Metetra
.664 .741 .907 r
.22035 .25835 .22158 .2596 .22755 .25735 .22632 .2561 Metetra
.664 .741 .907 r
.22632 .2561 .22755 .25735 .23353 .2551 .23231 .25384 Metetra
.664 .741 .907 r
.23231 .25384 .23353 .2551 .23953 .25284 .23831 .25158 Metetra
.664 .741 .907 r
.23831 .25158 .23953 .25284 .24554 .25057 .24433 .24931 Metetra
.664 .741 .907 r
.24433 .24931 .24554 .25057 .25157 .2483 .25036 .24703 Metetra
.664 .741 .907 r
.25036 .24703 .25157 .2483 .25761 .24603 .2564 .24475 Metetra
.664 .741 .907 r
.2564 .24475 .25761 .24603 .26367 .24374 .26246 .24247 Metetra
.664 .741 .907 r
.26246 .24247 .26367 .24374 .26974 .24146 .26853 .24018 Metetra
.664 .741 .907 r
.26853 .24018 .26974 .24146 .27582 .23917 .27461 .23788 Metetra
.664 .741 .907 r
.27461 .23788 .27582 .23917 .28192 .23687 .28071 .23558 Metetra
.664 .741 .907 r
.28071 .23558 .28192 .23687 .28803 .23457 .28683 .23328 Metetra
.664 .741 .907 r
.28683 .23328 .28803 .23457 .29415 .23226 .29295 .23097 Metetra
.664 .741 .907 r
.29295 .23097 .29415 .23226 .30029 .22994 .2991 .22865 Metetra
.664 .741 .907 r
.2991 .22865 .30029 .22994 .30645 .22762 .30525 .22633 Metetra
.664 .741 .907 r
.30525 .22633 .30645 .22762 .31261 .2253 .31142 .224 Metetra
.664 .741 .907 r
.31142 .224 .31261 .2253 .3188 .22297 .31761 .22167 Metetra
.664 .741 .907 r
.31761 .22167 .3188 .22297 .32499 .22064 .32381 .21933 Metetra
.961 .679 .453 r
.32381 .21933 .32499 .22064 .3228 .35031 .31487 .45342 Metetra
.103 0 .368 r
.31487 .45342 .3228 .35031 .33415 .2691 .33335 .26134 Metetra
.852 .605 .565 r
.33335 .26134 .33415 .2691 .34367 .2136 .3425 .21228 Metetra
.664 .741 .907 r
.3425 .21228 .34367 .2136 .34993 .21124 .34875 .20992 Metetra
.664 .741 .907 r
.34875 .20992 .34993 .21124 .3562 .20888 .35503 .20756 Metetra
.664 .741 .907 r
.35503 .20756 .3562 .20888 .36248 .20651 .36132 .20519 Metetra
.664 .741 .907 r
.36132 .20519 .36248 .20651 .36878 .20413 .36762 .20281 Metetra
.664 .741 .907 r
.36762 .20281 .36878 .20413 .3751 .20176 .37394 .20043 Metetra
.664 .741 .907 r
.37394 .20043 .3751 .20176 .38143 .19937 .38027 .19804 Metetra
.664 .741 .907 r
.38027 .19804 .38143 .19937 .38777 .19698 .38662 .19564 Metetra
.664 .741 .907 r
.38662 .19564 .38777 .19698 .39413 .19458 .39298 .19324 Metetra
.664 .741 .907 r
.39298 .19324 .39413 .19458 .40051 .19218 .39936 .19084 Metetra
.664 .741 .907 r
.39936 .19084 .40051 .19218 .4069 .18977 .40575 .18843 Metetra
.664 .741 .907 r
.40575 .18843 .4069 .18977 .4133 .18736 .41216 .18601 Metetra
.664 .741 .907 r
.41216 .18601 .4133 .18736 .41972 .18494 .41858 .18359 Metetra
.664 .741 .907 r
.41858 .18359 .41972 .18494 .42616 .18251 .42502 .18116 Metetra
.664 .741 .907 r
.42502 .18116 .42616 .18251 .43261 .18008 .43147 .17873 Metetra
.664 .741 .907 r
.43147 .17873 .43261 .18008 .43908 .17765 .43794 .17629 Metetra
.664 .741 .907 r
.43794 .17629 .43908 .17765 .44556 .1752 .44443 .17384 Metetra
.664 .741 .907 r
.44443 .17384 .44556 .1752 .45206 .17276 .45093 .17139 Metetra
.664 .741 .907 r
.45093 .17139 .45206 .17276 .45857 .1703 .45745 .16893 Metetra
.664 .741 .907 r
.45745 .16893 .45857 .1703 .4651 .16784 .46398 .16647 Metetra
.664 .741 .907 r
.46398 .16647 .4651 .16784 .47165 .16538 .47053 .164 Metetra
.664 .741 .907 r
.47053 .164 .47165 .16538 .47821 .1629 .47709 .16152 Metetra
.664 .741 .907 r
.47709 .16152 .47821 .1629 .48478 .16043 .48367 .15904 Metetra
.664 .741 .907 r
.48367 .15904 .48478 .16043 .49137 .15794 .49026 .15655 Metetra
.664 .741 .907 r
.49026 .15655 .49137 .15794 .49798 .15545 .49688 .15406 Metetra
.664 .741 .907 r
.49688 .15406 .49798 .15545 .50461 .15295 .5035 .15156 Metetra
.664 .741 .907 r
.5035 .15156 .50461 .15295 .51125 .15045 .51015 .14905 Metetra
.664 .741 .907 r
.51015 .14905 .51125 .15045 .5179 .14794 .51681 .14654 Metetra
.664 .741 .907 r
.51681 .14654 .5179 .14794 .52458 .14543 .52348 .14403 Metetra
.664 .741 .907 r
.52348 .14403 .52458 .14543 .53126 .14291 .53017 .1415 Metetra
.664 .741 .907 r
.53017 .1415 .53126 .14291 .53797 .14038 .53688 .13897 Metetra
.664 .741 .907 r
.53688 .13897 .53797 .14038 .54469 .13785 .54361 .13644 Metetra
.664 .741 .907 r
.54361 .13644 .54469 .13785 .55143 .13531 .55035 .13389 Metetra
.664 .741 .907 r
.55035 .13389 .55143 .13531 .55818 .13277 .5571 .13134 Metetra
.664 .741 .907 r
.5571 .13134 .55818 .13277 .56495 .13022 .56388 .12879 Metetra
.664 .741 .907 r
.56388 .12879 .56495 .13022 .57174 .12766 .57067 .12623 Metetra
.664 .741 .907 r
.57067 .12623 .57174 .12766 .57854 .12509 .57748 .12366 Metetra
.664 .741 .907 r
.57748 .12366 .57854 .12509 .58537 .12252 .5843 .12109 Metetra
.664 .741 .907 r
.5843 .12109 .58537 .12252 .5922 .11995 .59114 .11851 Metetra
.664 .741 .907 r
.59114 .11851 .5922 .11995 .59906 .11736 .598 .11592 Metetra
.664 .741 .907 r
.598 .11592 .59906 .11736 .60593 .11478 .60487 .11333 Metetra
.664 .741 .907 r
.60487 .11333 .60593 .11478 .61282 .11218 .61177 .11073 Metetra
.664 .741 .907 r
.61177 .11073 .61282 .11218 .61972 .10958 .61867 .10812 Metetra
.664 .741 .907 r
.61867 .10812 .61972 .10958 .62664 .10697 .6256 .10551 Metetra
.664 .741 .907 r
.6256 .10551 .62664 .10697 .63358 .10435 .63254 .10289 Metetra
.664 .741 .907 r
.63254 .10289 .63358 .10435 .64054 .10173 .6395 .10027 Metetra
.664 .741 .907 r
.6395 .10027 .64054 .10173 .64751 .09911 .64648 .09764 Metetra
.664 .741 .907 r
.64648 .09764 .64751 .09911 .65451 .09647 .65348 .095 Metetra
.941 .586 .184 r
.65348 .095 .65451 .09647 .66151 .09383 .66294 .14512 Metetra
.723 .432 .483 r
.66294 .14512 .66151 .09383 .67144 .15006 .67686 .28042 Metetra
.278 .102 .454 r
.67686 .28042 .67144 .15006 .67558 .08853 .67456 .08705 Metetra
.664 .741 .907 r
.67456 .08705 .67558 .08853 .68265 .08587 .68163 .08438 Metetra
.664 .741 .907 r
.68163 .08438 .68265 .08587 .68972 .0832 .68871 .08171 Metetra
.664 .741 .907 r
.68871 .08171 .68972 .0832 .69682 .08053 .69581 .07903 Metetra
.664 .741 .907 r
.69581 .07903 .69682 .08053 .70394 .07785 .70293 .07635 Metetra
.664 .741 .907 r
.70293 .07635 .70394 .07785 .71107 .07516 .71007 .07366 Metetra
.664 .741 .907 r
.71007 .07366 .71107 .07516 .71822 .07246 .71722 .07096 Metetra
.664 .741 .907 r
.71722 .07096 .71822 .07246 .72539 .06976 .72439 .06825 Metetra
.664 .741 .907 r
.72439 .06825 .72539 .06976 .73257 .06705 .73158 .06554 Metetra
.664 .741 .907 r
.09103 .30545 .09231 .30664 .09799 .3045 .09671 .3033 Metetra
.664 .741 .907 r
.09671 .3033 .09799 .3045 .10368 .30235 .10241 .30115 Metetra
.664 .741 .907 r
.10241 .30115 .10368 .30235 .10939 .3002 .10812 .29899 Metetra
.664 .741 .907 r
.10812 .29899 .10939 .3002 .11511 .29804 .11384 .29683 Metetra
.664 .741 .907 r
.11384 .29683 .11511 .29804 .12085 .29588 .11958 .29467 Metetra
.664 .741 .907 r
.11958 .29467 .12085 .29588 .1266 .29371 .12533 .2925 Metetra
.664 .741 .907 r
.12533 .2925 .1266 .29371 .13236 .29154 .13109 .29032 Metetra
.664 .741 .907 r
.13109 .29032 .13236 .29154 .13813 .28936 .13687 .28814 Metetra
.664 .741 .907 r
.13687 .28814 .13813 .28936 .14392 .28718 .14266 .28596 Metetra
.664 .741 .907 r
.14266 .28596 .14392 .28718 .14972 .28499 .14846 .28377 Metetra
.664 .741 .907 r
.14846 .28377 .14972 .28499 .15553 .2828 .15427 .28157 Metetra
.664 .741 .907 r
.15427 .28157 .15553 .2828 .16135 .2806 .1601 .27937 Metetra
.664 .741 .907 r
.1601 .27937 .16135 .2806 .16719 .2784 .16594 .27717 Metetra
.664 .741 .907 r
.16594 .27717 .16719 .2784 .17305 .27619 .1718 .27496 Metetra
.936 .569 .274 r
.1718 .27496 .17305 .27619 .17891 .27398 .17539 .29306 Metetra
.265 .038 .371 r
.17539 .29306 .17891 .27398 .18479 .27176 .18355 .27052 Metetra
.664 .741 .907 r
.18355 .27052 .18479 .27176 .19068 .26954 .18944 .2683 Metetra
.664 .741 .907 r
.18944 .2683 .19068 .26954 .19659 .26731 .19535 .26607 Metetra
.664 .741 .907 r
.19535 .26607 .19659 .26731 .20251 .26508 .20127 .26383 Metetra
.664 .741 .907 r
.20127 .26383 .20251 .26508 .20844 .26284 .20721 .26159 Metetra
.664 .741 .907 r
.20721 .26159 .20844 .26284 .21439 .2606 .21316 .25935 Metetra
.664 .741 .907 r
.21316 .25935 .21439 .2606 .22035 .25835 .21912 .25709 Metetra
.664 .741 .907 r
.21912 .25709 .22035 .25835 .22632 .2561 .22509 .25484 Metetra
.664 .741 .907 r
.22509 .25484 .22632 .2561 .23231 .25384 .23108 .25258 Metetra
.664 .741 .907 r
.23108 .25258 .23231 .25384 .23831 .25158 .23709 .25031 Metetra
.664 .741 .907 r
.23709 .25031 .23831 .25158 .24433 .24931 .24311 .24804 Metetra
.664 .741 .907 r
.24311 .24804 .24433 .24931 .25036 .24703 .24914 .24576 Metetra
.664 .741 .907 r
.24914 .24576 .25036 .24703 .2564 .24475 .25518 .24348 Metetra
.664 .741 .907 r
.25518 .24348 .2564 .24475 .26246 .24247 .26124 .24119 Metetra
.664 .741 .907 r
.26124 .24119 .26246 .24247 .26853 .24018 .26732 .2389 Metetra
.664 .741 .907 r
.26732 .2389 .26853 .24018 .27461 .23788 .27341 .2366 Metetra
.664 .741 .907 r
.27341 .2366 .27461 .23788 .28071 .23558 .27951 .2343 Metetra
.664 .741 .907 r
.27951 .2343 .28071 .23558 .28683 .23328 .28562 .23199 Metetra
.664 .741 .907 r
.28562 .23199 .28683 .23328 .29295 .23097 .29175 .22968 Metetra
.664 .741 .907 r
.29175 .22968 .29295 .23097 .2991 .22865 .2979 .22736 Metetra
.664 .741 .907 r
.2979 .22736 .2991 .22865 .30525 .22633 .30406 .22503 Metetra
.664 .741 .907 r
.30406 .22503 .30525 .22633 .31142 .224 .31023 .2227 Metetra
.664 .741 .907 r
.31023 .2227 .31142 .224 .31761 .22167 .31642 .22037 Metetra
.53 .691 .941 r
.31642 .22037 .31761 .22167 .32381 .21933 .32251 .21971 Metetra
.956 .672 .459 r
.32251 .21971 .32381 .21933 .31487 .45342 .31358 .45218 Metetra
.957 .712 .525 r
.31358 .45218 .31487 .45342 .33335 .26134 .32506 .37346 Metetra
.224 .043 .412 r
.32506 .37346 .33335 .26134 .3425 .21228 .34132 .21097 Metetra
.664 .741 .907 r
.34132 .21097 .3425 .21228 .34875 .20992 .34758 .2086 Metetra
.664 .741 .907 r
.34758 .2086 .34875 .20992 .35503 .20756 .35385 .20623 Metetra
.664 .741 .907 r
.35385 .20623 .35503 .20756 .36132 .20519 .36015 .20386 Metetra
.664 .741 .907 r
.36015 .20386 .36132 .20519 .36762 .20281 .36645 .20148 Metetra
.664 .741 .907 r
.36645 .20148 .36762 .20281 .37394 .20043 .37277 .19909 Metetra
.664 .741 .907 r
.37277 .19909 .37394 .20043 .38027 .19804 .37911 .1967 Metetra
.664 .741 .907 r
.37911 .1967 .38027 .19804 .38662 .19564 .38546 .19431 Metetra
.664 .741 .907 r
.38546 .19431 .38662 .19564 .39298 .19324 .39182 .1919 Metetra
.664 .741 .907 r
.39182 .1919 .39298 .19324 .39936 .19084 .3982 .18949 Metetra
.664 .741 .907 r
.3982 .18949 .39936 .19084 .40575 .18843 .4046 .18708 Metetra
.664 .741 .907 r
.4046 .18708 .40575 .18843 .41216 .18601 .41101 .18466 Metetra
.664 .741 .907 r
.41101 .18466 .41216 .18601 .41858 .18359 .41744 .18223 Metetra
.664 .741 .907 r
.41744 .18223 .41858 .18359 .42502 .18116 .42388 .1798 Metetra
.664 .741 .907 r
.42388 .1798 .42502 .18116 .43147 .17873 .43034 .17737 Metetra
.664 .741 .907 r
.43034 .17737 .43147 .17873 .43794 .17629 .43681 .17492 Metetra
.664 .741 .907 r
.43681 .17492 .43794 .17629 .44443 .17384 .4433 .17247 Metetra
.664 .741 .907 r
.4433 .17247 .44443 .17384 .45093 .17139 .4498 .17002 Metetra
.664 .741 .907 r
.4498 .17002 .45093 .17139 .45745 .16893 .45632 .16756 Metetra
.664 .741 .907 r
.45632 .16756 .45745 .16893 .46398 .16647 .46285 .16509 Metetra
.664 .741 .907 r
.46285 .16509 .46398 .16647 .47053 .164 .46941 .16262 Metetra
.664 .741 .907 r
.46941 .16262 .47053 .164 .47709 .16152 .47597 .16014 Metetra
.664 .741 .907 r
.47597 .16014 .47709 .16152 .48367 .15904 .48255 .15765 Metetra
.759 .309 0 r
.48255 .15765 .48367 .15904 .49026 .15655 .48898 .16951 Metetra
.285 .051 .374 r
.48898 .16951 .49026 .15655 .49688 .15406 .49577 .15267 Metetra
.664 .741 .907 r
.49577 .15267 .49688 .15406 .5035 .15156 .5024 .15016 Metetra
.664 .741 .907 r
.5024 .15016 .5035 .15156 .51015 .14905 .50904 .14765 Metetra
.664 .741 .907 r
.50904 .14765 .51015 .14905 .51681 .14654 .51571 .14514 Metetra
.664 .741 .907 r
.51571 .14514 .51681 .14654 .52348 .14403 .52239 .14262 Metetra
.664 .741 .907 r
.52239 .14262 .52348 .14403 .53017 .1415 .52908 .14009 Metetra
.664 .741 .907 r
.52908 .14009 .53017 .1415 .53688 .13897 .53579 .13756 Metetra
.664 .741 .907 r
.53579 .13756 .53688 .13897 .54361 .13644 .54252 .13502 Metetra
.664 .741 .907 r
.54252 .13502 .54361 .13644 .55035 .13389 .54926 .13247 Metetra
.664 .741 .907 r
.54926 .13247 .55035 .13389 .5571 .13134 .55603 .12992 Metetra
.664 .741 .907 r
.55603 .12992 .5571 .13134 .56388 .12879 .5628 .12736 Metetra
.664 .741 .907 r
.5628 .12736 .56388 .12879 .57067 .12623 .5696 .1248 Metetra
.664 .741 .907 r
.5696 .1248 .57067 .12623 .57748 .12366 .57641 .12223 Metetra
.664 .741 .907 r
.57641 .12223 .57748 .12366 .5843 .12109 .58323 .11965 Metetra
.664 .741 .907 r
.58323 .11965 .5843 .12109 .59114 .11851 .59008 .11707 Metetra
.664 .741 .907 r
.59008 .11707 .59114 .11851 .598 .11592 .59694 .11448 Metetra
.664 .741 .907 r
.59694 .11448 .598 .11592 .60487 .11333 .60382 .11188 Metetra
.664 .741 .907 r
.60382 .11188 .60487 .11333 .61177 .11073 .61071 .10928 Metetra
.664 .741 .907 r
.61071 .10928 .61177 .11073 .61867 .10812 .61763 .10667 Metetra
.664 .741 .907 r
.61763 .10667 .61867 .10812 .6256 .10551 .62455 .10405 Metetra
.664 .741 .907 r
.62455 .10405 .6256 .10551 .63254 .10289 .6315 .10143 Metetra
.664 .741 .907 r
.6315 .10143 .63254 .10289 .6395 .10027 .63846 .0988 Metetra
.664 .741 .907 r
.63846 .0988 .6395 .10027 .64648 .09764 .64545 .09617 Metetra
.664 .741 .907 r
.64545 .09617 .64648 .09764 .65348 .095 .65244 .09352 Metetra
.96 .625 .254 r
.65244 .09352 .65348 .095 .66294 .14512 .66361 .18079 Metetra
.783 .477 .47 r
.66361 .18079 .66294 .14512 .67686 .28042 .67791 .32295 Metetra
0 0 .119 r
.67791 .32295 .67686 .28042 .67456 .08705 .67354 .08556 Metetra
.664 .741 .907 r
.67354 .08556 .67456 .08705 .68163 .08438 .68061 .08289 Metetra
.664 .741 .907 r
.68061 .08289 .68163 .08438 .68871 .08171 .6877 .08022 Metetra
.664 .741 .907 r
.6877 .08022 .68871 .08171 .69581 .07903 .6948 .07754 Metetra
.664 .741 .907 r
.6948 .07754 .69581 .07903 .70293 .07635 .70193 .07485 Metetra
.664 .741 .907 r
.70193 .07485 .70293 .07635 .71007 .07366 .70907 .07215 Metetra
.664 .741 .907 r
.70907 .07215 .71007 .07366 .71722 .07096 .71622 .06945 Metetra
.664 .741 .907 r
.71622 .06945 .71722 .07096 .72439 .06825 .7234 .06674 Metetra
.664 .741 .907 r
.7234 .06674 .72439 .06825 .73158 .06554 .73059 .06403 Metetra
.664 .741 .907 r
.08975 .30425 .09103 .30545 .09671 .3033 .09543 .3021 Metetra
.664 .741 .907 r
.09543 .3021 .09671 .3033 .10241 .30115 .10113 .29995 Metetra
.664 .741 .907 r
.10113 .29995 .10241 .30115 .10812 .29899 .10685 .29779 Metetra
.664 .741 .907 r
.10685 .29779 .10812 .29899 .11384 .29683 .11257 .29563 Metetra
.664 .741 .907 r
.11257 .29563 .11384 .29683 .11958 .29467 .11831 .29346 Metetra
.664 .741 .907 r
.11831 .29346 .11958 .29467 .12533 .2925 .12406 .29128 Metetra
.664 .741 .907 r
.12406 .29128 .12533 .2925 .13109 .29032 .12983 .28911 Metetra
.664 .741 .907 r
.12983 .28911 .13109 .29032 .13687 .28814 .1356 .28692 Metetra
.664 .741 .907 r
.1356 .28692 .13687 .28814 .14266 .28596 .14139 .28474 Metetra
.664 .741 .907 r
.14139 .28474 .14266 .28596 .14846 .28377 .1472 .28254 Metetra
.664 .741 .907 r
.1472 .28254 .14846 .28377 .15427 .28157 .15302 .28035 Metetra
.664 .741 .907 r
.15302 .28035 .15427 .28157 .1601 .27937 .15885 .27814 Metetra
.664 .741 .907 r
.15885 .27814 .1601 .27937 .16594 .27717 .16469 .27593 Metetra
.664 .741 .907 r
.16469 .27593 .16594 .27717 .1718 .27496 .17055 .27372 Metetra
.87 .431 .047 r
.17055 .27372 .1718 .27496 .17539 .29306 .17499 .2842 Metetra
.693 .482 .597 r
.17499 .2842 .17539 .29306 .18355 .27052 .1823 .26928 Metetra
.664 .741 .907 r
.1823 .26928 .18355 .27052 .18944 .2683 .1882 .26705 Metetra
.664 .741 .907 r
.1882 .26705 .18944 .2683 .19535 .26607 .19411 .26482 Metetra
.664 .741 .907 r
.19411 .26482 .19535 .26607 .20127 .26383 .20003 .26258 Metetra
.664 .741 .907 r
.20003 .26258 .20127 .26383 .20721 .26159 .20597 .26034 Metetra
.664 .741 .907 r
.20597 .26034 .20721 .26159 .21316 .25935 .21192 .25809 Metetra
.664 .741 .907 r
.21192 .25809 .21316 .25935 .21912 .25709 .21789 .25584 Metetra
.664 .741 .907 r
.21789 .25584 .21912 .25709 .22509 .25484 .22387 .25358 Metetra
.664 .741 .907 r
.22387 .25358 .22509 .25484 .23108 .25258 .22986 .25131 Metetra
.664 .741 .907 r
.22986 .25131 .23108 .25258 .23709 .25031 .23586 .24904 Metetra
.664 .741 .907 r
.23586 .24904 .23709 .25031 .24311 .24804 .24188 .24677 Metetra
.664 .741 .907 r
.24188 .24677 .24311 .24804 .24914 .24576 .24792 .24449 Metetra
.664 .741 .907 r
.24792 .24449 .24914 .24576 .25518 .24348 .25397 .24221 Metetra
.664 .741 .907 r
.25397 .24221 .25518 .24348 .26124 .24119 .26003 .23991 Metetra
.664 .741 .907 r
.26003 .23991 .26124 .24119 .26732 .2389 .26611 .23762 Metetra
.664 .741 .907 r
.26611 .23762 .26732 .2389 .27341 .2366 .2722 .23532 Metetra
.664 .741 .907 r
.2722 .23532 .27341 .2366 .27951 .2343 .2783 .23301 Metetra
.664 .741 .907 r
.2783 .23301 .27951 .2343 .28562 .23199 .28442 .2307 Metetra
.664 .741 .907 r
.28442 .2307 .28562 .23199 .29175 .22968 .29055 .22838 Metetra
.664 .741 .907 r
.29055 .22838 .29175 .22968 .2979 .22736 .2967 .22606 Metetra
.664 .741 .907 r
.2967 .22606 .2979 .22736 .30406 .22503 .30286 .22373 Metetra
.664 .741 .907 r
.30286 .22373 .30406 .22503 .31023 .2227 .30904 .2214 Metetra
.664 .741 .907 r
.30904 .2214 .31023 .2227 .31642 .22037 .31523 .21906 Metetra
.664 .741 .907 r
.31523 .21906 .31642 .22037 .32251 .21971 .32143 .21672 Metetra
.967 .686 .447 r
.32143 .21672 .32251 .21971 .31358 .45218 .31229 .45093 Metetra
.958 .709 .518 r
.31229 .45093 .31358 .45218 .32506 .37346 .32465 .35882 Metetra
.891 .624 .526 r
.32465 .35882 .32506 .37346 .34132 .21097 .34014 .20965 Metetra
.664 .741 .907 r
.34014 .20965 .34132 .21097 .34758 .2086 .3464 .20728 Metetra
.664 .741 .907 r
.3464 .20728 .34758 .2086 .35385 .20623 .35268 .20491 Metetra
.664 .741 .907 r
.35268 .20491 .35385 .20623 .36015 .20386 .35897 .20253 Metetra
.664 .741 .907 r
.35897 .20253 .36015 .20386 .36645 .20148 .36528 .20015 Metetra
.664 .741 .907 r
.36528 .20015 .36645 .20148 .37277 .19909 .3716 .19776 Metetra
.664 .741 .907 r
.3716 .19776 .37277 .19909 .37911 .1967 .37794 .19537 Metetra
.664 .741 .907 r
.37794 .19537 .37911 .1967 .38546 .19431 .3843 .19297 Metetra
.664 .741 .907 r
.3843 .19297 .38546 .19431 .39182 .1919 .39066 .19056 Metetra
.664 .741 .907 r
.39066 .19056 .39182 .1919 .3982 .18949 .39705 .18815 Metetra
.664 .741 .907 r
.39705 .18815 .3982 .18949 .4046 .18708 .40345 .18573 Metetra
.664 .741 .907 r
.40345 .18573 .4046 .18708 .41101 .18466 .40986 .18331 Metetra
.664 .741 .907 r
.40986 .18331 .41101 .18466 .41744 .18223 .41629 .18088 Metetra
.664 .741 .907 r
.41629 .18088 .41744 .18223 .42388 .1798 .42274 .17844 Metetra
.664 .741 .907 r
.42274 .17844 .42388 .1798 .43034 .17737 .4292 .176 Metetra
.664 .741 .907 r
.4292 .176 .43034 .17737 .43681 .17492 .43567 .17356 Metetra
.664 .741 .907 r
.43567 .17356 .43681 .17492 .4433 .17247 .44216 .1711 Metetra
.664 .741 .907 r
.44216 .1711 .4433 .17247 .4498 .17002 .44867 .16865 Metetra
.664 .741 .907 r
.44867 .16865 .4498 .17002 .45632 .16756 .45519 .16618 Metetra
.664 .741 .907 r
.45519 .16618 .45632 .16756 .46285 .16509 .46173 .16371 Metetra
.664 .741 .907 r
.46173 .16371 .46285 .16509 .46941 .16262 .46828 .16124 Metetra
.664 .741 .907 r
.46828 .16124 .46941 .16262 .47597 .16014 .47485 .15875 Metetra
.664 .741 .907 r
.47485 .15875 .47597 .16014 .48255 .15765 .48144 .15627 Metetra
.911 .518 .112 r
.48144 .15627 .48255 .15765 .48898 .16951 .48774 .17814 Metetra
0 0 .174 r
.48774 .17814 .48898 .16951 .49577 .15267 .49466 .15127 Metetra
.664 .741 .907 r
.49466 .15127 .49577 .15267 .5024 .15016 .50129 .14876 Metetra
.664 .741 .907 r
.50129 .14876 .5024 .15016 .50904 .14765 .50794 .14625 Metetra
.664 .741 .907 r
.50794 .14625 .50904 .14765 .51571 .14514 .51461 .14373 Metetra
.664 .741 .907 r
.51461 .14373 .51571 .14514 .52239 .14262 .52129 .14121 Metetra
.664 .741 .907 r
.52129 .14121 .52239 .14262 .52908 .14009 .52799 .13868 Metetra
.664 .741 .907 r
.52799 .13868 .52908 .14009 .53579 .13756 .5347 .13614 Metetra
.664 .741 .907 r
.5347 .13614 .53579 .13756 .54252 .13502 .54143 .1336 Metetra
.664 .741 .907 r
.54143 .1336 .54252 .13502 .54926 .13247 .54818 .13105 Metetra
.664 .741 .907 r
.54818 .13105 .54926 .13247 .55603 .12992 .55494 .12849 Metetra
.664 .741 .907 r
.55494 .12849 .55603 .12992 .5628 .12736 .56172 .12593 Metetra
.664 .741 .907 r
.56172 .12593 .5628 .12736 .5696 .1248 .56852 .12336 Metetra
.664 .741 .907 r
.56852 .12336 .5696 .1248 .57641 .12223 .57534 .12079 Metetra
.664 .741 .907 r
.57534 .12079 .57641 .12223 .58323 .11965 .58217 .11821 Metetra
.664 .741 .907 r
.58217 .11821 .58323 .11965 .59008 .11707 .58901 .11562 Metetra
.664 .741 .907 r
.58901 .11562 .59008 .11707 .59694 .11448 .59588 .11303 Metetra
.664 .741 .907 r
.59588 .11303 .59694 .11448 .60382 .11188 .60276 .11043 Metetra
.664 .741 .907 r
.60276 .11043 .60382 .11188 .61071 .10928 .60966 .10782 Metetra
.664 .741 .907 r
.60966 .10782 .61071 .10928 .61763 .10667 .61657 .10521 Metetra
.664 .741 .907 r
.61657 .10521 .61763 .10667 .62455 .10405 .62351 .10259 Metetra
.664 .741 .907 r
.62351 .10259 .62455 .10405 .6315 .10143 .63046 .09996 Metetra
.664 .741 .907 r
.63046 .09996 .6315 .10143 .63846 .0988 .63742 .09733 Metetra
.664 .741 .907 r
.63742 .09733 .63846 .0988 .64545 .09617 .64441 .09469 Metetra
.664 .741 .907 r
.64441 .09469 .64545 .09617 .65244 .09352 .65141 .09205 Metetra
.964 .636 .274 r
.65141 .09205 .65244 .09352 .66361 .18079 .66371 .20444 Metetra
.822 .505 .453 r
.66371 .20444 .66361 .18079 .67791 .32295 .67717 .329 Metetra
.979 .697 .312 r
.67717 .329 .67791 .32295 .67354 .08556 .67252 .08407 Metetra
.664 .741 .907 r
.67252 .08407 .67354 .08556 .68061 .08289 .67959 .0814 Metetra
.664 .741 .907 r
.67959 .0814 .68061 .08289 .6877 .08022 .68668 .07872 Metetra
.664 .741 .907 r
.68668 .07872 .6877 .08022 .6948 .07754 .69379 .07604 Metetra
.664 .741 .907 r
.69379 .07604 .6948 .07754 .70193 .07485 .70092 .07334 Metetra
.664 .741 .907 r
.70092 .07334 .70193 .07485 .70907 .07215 .70806 .07065 Metetra
.664 .741 .907 r
.70806 .07065 .70907 .07215 .71622 .06945 .71522 .06794 Metetra
.664 .741 .907 r
.71522 .06794 .71622 .06945 .7234 .06674 .7224 .06523 Metetra
.664 .741 .907 r
.7224 .06523 .7234 .06674 .73059 .06403 .7296 .06251 Metetra
.664 .741 .907 r
.08846 .30305 .08975 .30425 .09543 .3021 .09415 .3009 Metetra
.664 .741 .907 r
.09415 .3009 .09543 .3021 .10113 .29995 .09985 .29874 Metetra
.664 .741 .907 r
.09985 .29874 .10113 .29995 .10685 .29779 .10557 .29658 Metetra
.664 .741 .907 r
.10557 .29658 .10685 .29779 .11257 .29563 .1113 .29442 Metetra
.664 .741 .907 r
.1113 .29442 .11257 .29563 .11831 .29346 .11704 .29225 Metetra
.664 .741 .907 r
.11704 .29225 .11831 .29346 .12406 .29128 .12279 .29007 Metetra
.664 .741 .907 r
.12279 .29007 .12406 .29128 .12983 .28911 .12856 .28789 Metetra
.664 .741 .907 r
.12856 .28789 .12983 .28911 .1356 .28692 .13434 .2857 Metetra
.664 .741 .907 r
.13434 .2857 .1356 .28692 .14139 .28474 .14013 .28351 Metetra
.664 .741 .907 r
.14013 .28351 .14139 .28474 .1472 .28254 .14594 .28132 Metetra
.664 .741 .907 r
.14594 .28132 .1472 .28254 .15302 .28035 .15176 .27912 Metetra
.664 .741 .907 r
.15176 .27912 .15302 .28035 .15885 .27814 .15759 .27691 Metetra
.664 .741 .907 r
.15759 .27691 .15885 .27814 .16469 .27593 .16344 .2747 Metetra
.664 .741 .907 r
.16344 .2747 .16469 .27593 .17055 .27372 .16929 .27249 Metetra
.941 .585 .303 r
.16929 .27249 .17055 .27372 .17499 .2842 .17263 .2927 Metetra
0 0 .02 r
.17263 .2927 .17499 .2842 .1823 .26928 .18105 .26804 Metetra
.664 .741 .907 r
.18105 .26804 .1823 .26928 .1882 .26705 .18695 .26581 Metetra
.664 .741 .907 r
.18695 .26581 .1882 .26705 .19411 .26482 .19287 .26357 Metetra
.664 .741 .907 r
.19287 .26357 .19411 .26482 .20003 .26258 .19879 .26133 Metetra
.664 .741 .907 r
.19879 .26133 .20003 .26258 .20597 .26034 .20473 .25909 Metetra
.664 .741 .907 r
.20473 .25909 .20597 .26034 .21192 .25809 .21069 .25683 Metetra
.664 .741 .907 r
.21069 .25683 .21192 .25809 .21789 .25584 .21665 .25458 Metetra
.664 .741 .907 r
.21665 .25458 .21789 .25584 .22387 .25358 .22264 .25232 Metetra
.664 .741 .907 r
.22264 .25232 .22387 .25358 .22986 .25131 .22863 .25005 Metetra
.664 .741 .907 r
.22863 .25005 .22986 .25131 .23586 .24904 .23464 .24778 Metetra
.664 .741 .907 r
.23464 .24778 .23586 .24904 .24188 .24677 .24066 .2455 Metetra
.664 .741 .907 r
.24066 .2455 .24188 .24677 .24792 .24449 .2467 .24322 Metetra
.664 .741 .907 r
.2467 .24322 .24792 .24449 .25397 .24221 .25275 .24093 Metetra
.664 .741 .907 r
.25275 .24093 .25397 .24221 .26003 .23991 .25881 .23864 Metetra
.664 .741 .907 r
.25881 .23864 .26003 .23991 .26611 .23762 .26489 .23634 Metetra
.664 .741 .907 r
.26489 .23634 .26611 .23762 .2722 .23532 .27099 .23403 Metetra
.664 .741 .907 r
.27099 .23403 .2722 .23532 .2783 .23301 .27709 .23172 Metetra
.664 .741 .907 r
.27709 .23172 .2783 .23301 .28442 .2307 .28321 .22941 Metetra
.664 .741 .907 r
.28321 .22941 .28442 .2307 .29055 .22838 .28935 .22709 Metetra
.664 .741 .907 r
.28935 .22709 .29055 .22838 .2967 .22606 .2955 .22476 Metetra
.664 .741 .907 r
.2955 .22476 .2967 .22606 .30286 .22373 .30166 .22243 Metetra
.664 .741 .907 r
.30166 .22243 .30286 .22373 .30904 .2214 .30784 .2201 Metetra
.664 .741 .907 r
.30784 .2201 .30904 .2214 .31523 .21906 .31404 .21775 Metetra
.664 .741 .907 r
.31404 .21775 .31523 .21906 .32143 .21672 .32024 .21541 Metetra
.961 .679 .453 r
.32024 .21541 .32143 .21672 .31229 .45093 .311 .44968 Metetra
.957 .712 .526 r
.311 .44968 .31229 .45093 .32465 .35882 .32245 .3726 Metetra
.994 .768 .404 r
.32245 .3726 .32465 .35882 .34014 .20965 .33896 .20833 Metetra
.664 .741 .907 r
.33896 .20833 .34014 .20965 .3464 .20728 .34522 .20596 Metetra
.664 .741 .907 r
.34522 .20596 .3464 .20728 .35268 .20491 .3515 .20359 Metetra
.664 .741 .907 r
.3515 .20359 .35268 .20491 .35897 .20253 .3578 .2012 Metetra
.664 .741 .907 r
.3578 .2012 .35897 .20253 .36528 .20015 .36411 .19882 Metetra
.664 .741 .907 r
.36411 .19882 .36528 .20015 .3716 .19776 .37044 .19643 Metetra
.664 .741 .907 r
.37044 .19643 .3716 .19776 .37794 .19537 .37678 .19403 Metetra
.664 .741 .907 r
.37678 .19403 .37794 .19537 .3843 .19297 .38313 .19162 Metetra
.664 .741 .907 r
.38313 .19162 .3843 .19297 .39066 .19056 .38951 .18922 Metetra
.664 .741 .907 r
.38951 .18922 .39066 .19056 .39705 .18815 .39589 .1868 Metetra
.664 .741 .907 r
.39589 .1868 .39705 .18815 .40345 .18573 .40229 .18438 Metetra
.664 .741 .907 r
.40229 .18438 .40345 .18573 .40986 .18331 .40871 .18195 Metetra
.664 .741 .907 r
.40871 .18195 .40986 .18331 .41629 .18088 .41514 .17952 Metetra
.664 .741 .907 r
.41514 .17952 .41629 .18088 .42274 .17844 .42159 .17708 Metetra
.664 .741 .907 r
.42159 .17708 .42274 .17844 .4292 .176 .42805 .17464 Metetra
.664 .741 .907 r
.42805 .17464 .4292 .176 .43567 .17356 .43453 .17219 Metetra
.664 .741 .907 r
.43453 .17219 .43567 .17356 .44216 .1711 .44103 .16973 Metetra
.664 .741 .907 r
.44103 .16973 .44216 .1711 .44867 .16865 .44754 .16727 Metetra
.664 .741 .907 r
.44754 .16727 .44867 .16865 .45519 .16618 .45406 .1648 Metetra
.664 .741 .907 r
.45406 .1648 .45519 .16618 .46173 .16371 .4606 .16233 Metetra
.664 .741 .907 r
.4606 .16233 .46173 .16371 .46828 .16124 .46716 .15985 Metetra
.664 .741 .907 r
.46716 .15985 .46828 .16124 .47485 .15875 .47373 .15737 Metetra
.664 .741 .907 r
.47373 .15737 .47485 .15875 .48144 .15627 .48032 .15487 Metetra
.733 .278 0 r
.48032 .15487 .48144 .15627 .48774 .17814 .48675 .16602 Metetra
.662 .439 .571 r
.48675 .16602 .48774 .17814 .49466 .15127 .49355 .14987 Metetra
.664 .741 .907 r
.49355 .14987 .49466 .15127 .50129 .14876 .50018 .14736 Metetra
.664 .741 .907 r
.50018 .14736 .50129 .14876 .50794 .14625 .50684 .14485 Metetra
.664 .741 .907 r
.50684 .14485 .50794 .14625 .51461 .14373 .5135 .14233 Metetra
.664 .741 .907 r
.5135 .14233 .51461 .14373 .52129 .14121 .52019 .1398 Metetra
.664 .741 .907 r
.52019 .1398 .52129 .14121 .52799 .13868 .52689 .13726 Metetra
.664 .741 .907 r
.52689 .13726 .52799 .13868 .5347 .13614 .53361 .13472 Metetra
.664 .741 .907 r
.53361 .13472 .5347 .13614 .54143 .1336 .54034 .13218 Metetra
.664 .741 .907 r
.54034 .13218 .54143 .1336 .54818 .13105 .54709 .12963 Metetra
.664 .741 .907 r
.54709 .12963 .54818 .13105 .55494 .12849 .55386 .12707 Metetra
.664 .741 .907 r
.55386 .12707 .55494 .12849 .56172 .12593 .56065 .1245 Metetra
.664 .741 .907 r
.56065 .1245 .56172 .12593 .56852 .12336 .56745 .12193 Metetra
.664 .741 .907 r
.56745 .12193 .56852 .12336 .57534 .12079 .57426 .11935 Metetra
.664 .741 .907 r
.57426 .11935 .57534 .12079 .58217 .11821 .5811 .11677 Metetra
.664 .741 .907 r
.5811 .11677 .58217 .11821 .58901 .11562 .58795 .11418 Metetra
.664 .741 .907 r
.58795 .11418 .58901 .11562 .59588 .11303 .59482 .11158 Metetra
.664 .741 .907 r
.59482 .11158 .59588 .11303 .60276 .11043 .6017 .10898 Metetra
.664 .741 .907 r
.6017 .10898 .60276 .11043 .60966 .10782 .6086 .10637 Metetra
.664 .741 .907 r
.6086 .10637 .60966 .10782 .61657 .10521 .61552 .10375 Metetra
.664 .741 .907 r
.61552 .10375 .61657 .10521 .62351 .10259 .62246 .10113 Metetra
.664 .741 .907 r
.62246 .10113 .62351 .10259 .63046 .09996 .62941 .0985 Metetra
.664 .741 .907 r
.62941 .0985 .63046 .09996 .63742 .09733 .63638 .09586 Metetra
.664 .741 .907 r
.63638 .09586 .63742 .09733 .64441 .09469 .64337 .09322 Metetra
.664 .741 .907 r
.64337 .09322 .64441 .09469 .65141 .09205 .65038 .09057 Metetra
.961 .63 .262 r
.65038 .09057 .65141 .09205 .66371 .20444 .6619 .18676 Metetra
.719 .526 0 r
.6619 .18676 .66371 .20444 .67717 .329 .67607 .32758 Metetra
.979 .685 .364 r
.67607 .32758 .67717 .329 .67252 .08407 .6715 .08258 Metetra
.664 .741 .907 r
.6715 .08258 .67252 .08407 .67959 .0814 .67857 .07991 Metetra
.664 .741 .907 r
.67857 .07991 .67959 .0814 .68668 .07872 .68567 .07723 Metetra
.664 .741 .907 r
.68567 .07723 .68668 .07872 .69379 .07604 .69278 .07454 Metetra
.664 .741 .907 r
.69278 .07454 .69379 .07604 .70092 .07334 .69991 .07184 Metetra
.664 .741 .907 r
.69991 .07184 .70092 .07334 .70806 .07065 .70706 .06914 Metetra
.664 .741 .907 r
.70706 .06914 .70806 .07065 .71522 .06794 .71422 .06643 Metetra
.664 .741 .907 r
.71422 .06643 .71522 .06794 .7224 .06523 .72141 .06371 Metetra
.664 .741 .907 r
.72141 .06371 .7224 .06523 .7296 .06251 .72861 .06099 Metetra
.664 .741 .907 r
.08718 .30185 .08846 .30305 .09415 .3009 .09287 .2997 Metetra
.664 .741 .907 r
.09287 .2997 .09415 .3009 .09985 .29874 .09857 .29754 Metetra
.664 .741 .907 r
.09857 .29754 .09985 .29874 .10557 .29658 .10429 .29538 Metetra
.664 .741 .907 r
.10429 .29538 .10557 .29658 .1113 .29442 .11002 .29321 Metetra
.664 .741 .907 r
.11002 .29321 .1113 .29442 .11704 .29225 .11577 .29103 Metetra
.664 .741 .907 r
.11577 .29103 .11704 .29225 .12279 .29007 .12152 .28885 Metetra
.664 .741 .907 r
.12152 .28885 .12279 .29007 .12856 .28789 .12729 .28667 Metetra
.664 .741 .907 r
.12729 .28667 .12856 .28789 .13434 .2857 .13307 .28448 Metetra
.664 .741 .907 r
.13307 .28448 .13434 .2857 .14013 .28351 .13887 .28229 Metetra
.664 .741 .907 r
.13887 .28229 .14013 .28351 .14594 .28132 .14468 .28009 Metetra
.664 .741 .907 r
.14468 .28009 .14594 .28132 .15176 .27912 .1505 .27789 Metetra
.664 .741 .907 r
.1505 .27789 .15176 .27912 .15759 .27691 .15633 .27568 Metetra
.664 .741 .907 r
.15633 .27568 .15759 .27691 .16344 .2747 .16218 .27347 Metetra
.664 .741 .907 r
.16218 .27347 .16344 .2747 .16929 .27249 .16804 .27125 Metetra
.389 .633 .952 r
.16804 .27125 .16929 .27249 .17263 .2927 .17361 .2717 Metetra
.548 .334 .541 r
.17361 .2717 .17263 .2927 .18105 .26804 .1798 .2668 Metetra
.664 .741 .907 r
.1798 .2668 .18105 .26804 .18695 .26581 .18571 .26456 Metetra
.664 .741 .907 r
.18571 .26456 .18695 .26581 .19287 .26357 .19162 .26232 Metetra
.664 .741 .907 r
.19162 .26232 .19287 .26357 .19879 .26133 .19755 .26008 Metetra
.664 .741 .907 r
.19755 .26008 .19879 .26133 .20473 .25909 .20349 .25783 Metetra
.664 .741 .907 r
.20349 .25783 .20473 .25909 .21069 .25683 .20945 .25558 Metetra
.664 .741 .907 r
.20945 .25558 .21069 .25683 .21665 .25458 .21542 .25332 Metetra
.664 .741 .907 r
.21542 .25332 .21665 .25458 .22264 .25232 .2214 .25105 Metetra
.664 .741 .907 r
.2214 .25105 .22264 .25232 .22863 .25005 .2274 .24878 Metetra
.664 .741 .907 r
.2274 .24878 .22863 .25005 .23464 .24778 .23341 .24651 Metetra
.664 .741 .907 r
.23341 .24651 .23464 .24778 .24066 .2455 .23944 .24423 Metetra
.664 .741 .907 r
.23944 .24423 .24066 .2455 .2467 .24322 .24548 .24194 Metetra
.664 .741 .907 r
.24548 .24194 .2467 .24322 .25275 .24093 .25153 .23965 Metetra
.664 .741 .907 r
.25153 .23965 .25275 .24093 .25881 .23864 .2576 .23735 Metetra
.664 .741 .907 r
.2576 .23735 .25881 .23864 .26489 .23634 .26368 .23505 Metetra
.664 .741 .907 r
.26368 .23505 .26489 .23634 .27099 .23403 .26977 .23275 Metetra
.664 .741 .907 r
.26977 .23275 .27099 .23403 .27709 .23172 .27588 .23043 Metetra
.664 .741 .907 r
.27588 .23043 .27709 .23172 .28321 .22941 .28201 .22812 Metetra
.664 .741 .907 r
.28201 .22812 .28321 .22941 .28935 .22709 .28815 .22579 Metetra
.664 .741 .907 r
.28815 .22579 .28935 .22709 .2955 .22476 .2943 .22346 Metetra
.664 .741 .907 r
.2943 .22346 .2955 .22476 .30166 .22243 .30047 .22113 Metetra
.664 .741 .907 r
.30047 .22113 .30166 .22243 .30784 .2201 .30665 .21879 Metetra
.664 .741 .907 r
.30665 .21879 .30784 .2201 .31404 .21775 .31284 .21644 Metetra
.664 .741 .907 r
.31284 .21644 .31404 .21775 .32024 .21541 .31905 .21409 Metetra
.961 .679 .453 r
.31905 .21409 .32024 .21541 .311 .44968 .30971 .44843 Metetra
.96 .7 .497 r
.30971 .44843 .311 .44968 .32245 .3726 .32669 .28505 Metetra
.62 .374 .522 r
.32669 .28505 .32245 .3726 .33896 .20833 .33777 .20701 Metetra
.664 .741 .907 r
.33777 .20701 .33896 .20833 .34522 .20596 .34404 .20464 Metetra
.664 .741 .907 r
.34404 .20464 .34522 .20596 .3515 .20359 .35033 .20226 Metetra
.664 .741 .907 r
.35033 .20226 .3515 .20359 .3578 .2012 .35663 .19987 Metetra
.664 .741 .907 r
.35663 .19987 .3578 .2012 .36411 .19882 .36294 .19748 Metetra
.664 .741 .907 r
.36294 .19748 .36411 .19882 .37044 .19643 .36927 .19509 Metetra
.664 .741 .907 r
.36927 .19509 .37044 .19643 .37678 .19403 .37561 .19269 Metetra
.664 .741 .907 r
.37561 .19269 .37678 .19403 .38313 .19162 .38197 .19028 Metetra
.664 .741 .907 r
.38197 .19028 .38313 .19162 .38951 .18922 .38834 .18787 Metetra
.664 .741 .907 r
.38834 .18787 .38951 .18922 .39589 .1868 .39473 .18545 Metetra
.664 .741 .907 r
.39473 .18545 .39589 .1868 .40229 .18438 .40114 .18303 Metetra
.664 .741 .907 r
.40114 .18303 .40229 .18438 .40871 .18195 .40756 .1806 Metetra
.664 .741 .907 r
.40756 .1806 .40871 .18195 .41514 .17952 .41399 .17816 Metetra
.664 .741 .907 r
.41399 .17816 .41514 .17952 .42159 .17708 .42044 .17572 Metetra
.664 .741 .907 r
.42044 .17572 .42159 .17708 .42805 .17464 .42691 .17327 Metetra
.664 .741 .907 r
.42691 .17327 .42805 .17464 .43453 .17219 .43339 .17082 Metetra
.664 .741 .907 r
.43339 .17082 .43453 .17219 .44103 .16973 .43989 .16836 Metetra
.664 .741 .907 r
.43989 .16836 .44103 .16973 .44754 .16727 .4464 .1659 Metetra
.664 .741 .907 r
.4464 .1659 .44754 .16727 .45406 .1648 .45293 .16343 Metetra
.664 .741 .907 r
.45293 .16343 .45406 .1648 .4606 .16233 .45947 .16095 Metetra
.664 .741 .907 r
.45947 .16095 .4606 .16233 .46716 .15985 .46603 .15847 Metetra
.664 .741 .907 r
.46603 .15847 .46716 .15985 .47373 .15737 .47261 .15598 Metetra
.664 .741 .907 r
.47261 .15598 .47373 .15737 .48032 .15487 .4792 .15348 Metetra
.664 .741 .907 r
.4792 .15348 .48032 .15487 .48675 .16602 .48581 .15098 Metetra
.539 .338 .556 r
.48581 .15098 .48675 .16602 .49355 .14987 .49243 .14847 Metetra
.664 .741 .907 r
.49243 .14847 .49355 .14987 .50018 .14736 .49907 .14596 Metetra
.664 .741 .907 r
.49907 .14596 .50018 .14736 .50684 .14485 .50573 .14344 Metetra
.664 .741 .907 r
.50573 .14344 .50684 .14485 .5135 .14233 .5124 .14092 Metetra
.664 .741 .907 r
.5124 .14092 .5135 .14233 .52019 .1398 .51909 .13839 Metetra
.664 .741 .907 r
.51909 .13839 .52019 .1398 .52689 .13726 .52579 .13585 Metetra
.664 .741 .907 r
.52579 .13585 .52689 .13726 .53361 .13472 .53252 .1333 Metetra
.664 .741 .907 r
.53252 .1333 .53361 .13472 .54034 .13218 .53925 .13075 Metetra
.664 .741 .907 r
.53925 .13075 .54034 .13218 .54709 .12963 .54601 .1282 Metetra
.664 .741 .907 r
.54601 .1282 .54709 .12963 .55386 .12707 .55278 .12564 Metetra
.664 .741 .907 r
.55278 .12564 .55386 .12707 .56065 .1245 .55957 .12307 Metetra
.664 .741 .907 r
.55957 .12307 .56065 .1245 .56745 .12193 .56637 .12049 Metetra
.664 .741 .907 r
.56637 .12049 .56745 .12193 .57426 .11935 .57319 .11791 Metetra
.664 .741 .907 r
.57319 .11791 .57426 .11935 .5811 .11677 .58003 .11532 Metetra
.664 .741 .907 r
.58003 .11532 .5811 .11677 .58795 .11418 .58688 .11273 Metetra
.664 .741 .907 r
.58688 .11273 .58795 .11418 .59482 .11158 .59375 .11013 Metetra
.664 .741 .907 r
.59375 .11013 .59482 .11158 .6017 .10898 .60064 .10752 Metetra
.664 .741 .907 r
.60064 .10752 .6017 .10898 .6086 .10637 .60755 .10491 Metetra
.664 .741 .907 r
.60755 .10491 .6086 .10637 .61552 .10375 .61447 .10229 Metetra
.664 .741 .907 r
.61447 .10229 .61552 .10375 .62246 .10113 .62141 .09966 Metetra
.664 .741 .907 r
.62141 .09966 .62246 .10113 .62941 .0985 .62837 .09703 Metetra
.664 .741 .907 r
.62837 .09703 .62941 .0985 .63638 .09586 .63534 .09439 Metetra
.664 .741 .907 r
.63534 .09439 .63638 .09586 .64337 .09322 .64233 .09174 Metetra
.664 .741 .907 r
.64233 .09174 .64337 .09322 .65038 .09057 .64934 .08909 Metetra
.934 .574 .164 r
.64934 .08909 .65038 .09057 .6619 .18676 .65851 .13387 Metetra
.179 .05 .456 r
.65851 .13387 .6619 .18676 .67607 .32758 .67098 .24253 Metetra
.703 .429 .507 r
.67098 .24253 .67607 .32758 .6715 .08258 .67047 .08109 Metetra
.664 .741 .907 r
.67047 .08109 .6715 .08258 .67857 .07991 .67755 .07841 Metetra
.664 .741 .907 r
.67755 .07841 .67857 .07991 .68567 .07723 .68465 .07573 Metetra
.664 .741 .907 r
.68465 .07573 .68567 .07723 .69278 .07454 .69177 .07303 Metetra
.664 .741 .907 r
.69177 .07303 .69278 .07454 .69991 .07184 .6989 .07033 Metetra
.664 .741 .907 r
.6989 .07033 .69991 .07184 .70706 .06914 .70605 .06763 Metetra
.664 .741 .907 r
.70605 .06763 .70706 .06914 .71422 .06643 .71322 .06491 Metetra
.664 .741 .907 r
.71322 .06491 .71422 .06643 .72141 .06371 .72041 .06219 Metetra
.664 .741 .907 r
.72041 .06219 .72141 .06371 .72861 .06099 .72761 .05947 Metetra
.664 .741 .907 r
.08589 .30065 .08718 .30185 .09287 .2997 .09159 .29849 Metetra
.664 .741 .907 r
.09159 .29849 .09287 .2997 .09857 .29754 .09729 .29633 Metetra
.664 .741 .907 r
.09729 .29633 .09857 .29754 .10429 .29538 .10301 .29417 Metetra
.664 .741 .907 r
.10301 .29417 .10429 .29538 .11002 .29321 .10874 .29199 Metetra
.664 .741 .907 r
.10874 .29199 .11002 .29321 .11577 .29103 .11449 .28982 Metetra
.664 .741 .907 r
.11449 .28982 .11577 .29103 .12152 .28885 .12025 .28764 Metetra
.664 .741 .907 r
.12025 .28764 .12152 .28885 .12729 .28667 .12602 .28545 Metetra
.664 .741 .907 r
.12602 .28545 .12729 .28667 .13307 .28448 .1318 .28326 Metetra
.664 .741 .907 r
.1318 .28326 .13307 .28448 .13887 .28229 .1376 .28106 Metetra
.664 .741 .907 r
.1376 .28106 .13887 .28229 .14468 .28009 .14341 .27886 Metetra
.664 .741 .907 r
.14341 .27886 .14468 .28009 .1505 .27789 .14924 .27666 Metetra
.664 .741 .907 r
.14924 .27666 .1505 .27789 .15633 .27568 .15507 .27445 Metetra
.664 .741 .907 r
.15507 .27445 .15633 .27568 .16218 .27347 .16092 .27223 Metetra
.664 .741 .907 r
.16092 .27223 .16218 .27347 .16804 .27125 .16679 .27001 Metetra
.664 .741 .907 r
.16679 .27001 .16804 .27125 .17361 .2717 .17266 .26778 Metetra
.601 .487 .695 r
.17266 .26778 .17361 .2717 .1798 .2668 .17855 .26555 Metetra
.664 .741 .907 r
.17855 .26555 .1798 .2668 .18571 .26456 .18446 .26331 Metetra
.664 .741 .907 r
.18446 .26331 .18571 .26456 .19162 .26232 .19038 .26107 Metetra
.664 .741 .907 r
.19038 .26107 .19162 .26232 .19755 .26008 .19631 .25883 Metetra
.664 .741 .907 r
.19631 .25883 .19755 .26008 .20349 .25783 .20225 .25657 Metetra
.664 .741 .907 r
.20225 .25657 .20349 .25783 .20945 .25558 .20821 .25432 Metetra
.664 .741 .907 r
.20821 .25432 .20945 .25558 .21542 .25332 .21418 .25205 Metetra
.664 .741 .907 r
.21418 .25205 .21542 .25332 .2214 .25105 .22017 .24979 Metetra
.664 .741 .907 r
.22017 .24979 .2214 .25105 .2274 .24878 .22617 .24751 Metetra
.664 .741 .907 r
.22617 .24751 .2274 .24878 .23341 .24651 .23218 .24524 Metetra
.664 .741 .907 r
.23218 .24524 .23341 .24651 .23944 .24423 .23821 .24295 Metetra
.664 .741 .907 r
.23821 .24295 .23944 .24423 .24548 .24194 .24425 .24066 Metetra
.664 .741 .907 r
.24425 .24066 .24548 .24194 .25153 .23965 .25031 .23837 Metetra
.664 .741 .907 r
.25031 .23837 .25153 .23965 .2576 .23735 .25638 .23607 Metetra
.664 .741 .907 r
.25638 .23607 .2576 .23735 .26368 .23505 .26246 .23377 Metetra
.664 .741 .907 r
.26246 .23377 .26368 .23505 .26977 .23275 .26856 .23146 Metetra
.664 .741 .907 r
.26856 .23146 .26977 .23275 .27588 .23043 .27467 .22914 Metetra
.664 .741 .907 r
.27467 .22914 .27588 .23043 .28201 .22812 .2808 .22682 Metetra
.664 .741 .907 r
.2808 .22682 .28201 .22812 .28815 .22579 .28694 .22449 Metetra
.664 .741 .907 r
.28694 .22449 .28815 .22579 .2943 .22346 .2931 .22216 Metetra
.664 .741 .907 r
.2931 .22216 .2943 .22346 .30047 .22113 .29926 .21983 Metetra
.664 .741 .907 r
.29926 .21983 .30047 .22113 .30665 .21879 .30545 .21748 Metetra
.664 .741 .907 r
.30545 .21748 .30665 .21879 .31284 .21644 .31165 .21513 Metetra
.664 .741 .907 r
.31165 .21513 .31284 .21644 .31905 .21409 .31786 .21278 Metetra
.961 .679 .453 r
.31786 .21278 .31905 .21409 .30971 .44843 .30841 .44718 Metetra
.959 .702 .502 r
.30841 .44718 .30971 .44843 .32669 .28505 .32404 .30611 Metetra
.717 .654 .099 r
.32404 .30611 .32669 .28505 .33777 .20701 .33659 .20569 Metetra
.664 .741 .907 r
.33659 .20569 .33777 .20701 .34404 .20464 .34286 .20331 Metetra
.664 .741 .907 r
.34286 .20331 .34404 .20464 .35033 .20226 .34915 .20093 Metetra
.664 .741 .907 r
.34915 .20093 .35033 .20226 .35663 .19987 .35545 .19854 Metetra
.664 .741 .907 r
.35545 .19854 .35663 .19987 .36294 .19748 .36177 .19615 Metetra
.664 .741 .907 r
.36177 .19615 .36294 .19748 .36927 .19509 .3681 .19375 Metetra
.664 .741 .907 r
.3681 .19375 .36927 .19509 .37561 .19269 .37444 .19135 Metetra
.664 .741 .907 r
.37444 .19135 .37561 .19269 .38197 .19028 .38081 .18894 Metetra
.664 .741 .907 r
.38081 .18894 .38197 .19028 .38834 .18787 .38718 .18652 Metetra
.664 .741 .907 r
.38718 .18652 .38834 .18787 .39473 .18545 .39357 .1841 Metetra
.664 .741 .907 r
.39357 .1841 .39473 .18545 .40114 .18303 .39998 .18167 Metetra
.664 .741 .907 r
.39998 .18167 .40114 .18303 .40756 .1806 .4064 .17924 Metetra
.664 .741 .907 r
.4064 .17924 .40756 .1806 .41399 .17816 .41284 .1768 Metetra
.664 .741 .907 r
.41284 .1768 .41399 .17816 .42044 .17572 .4193 .17436 Metetra
.664 .741 .907 r
.4193 .17436 .42044 .17572 .42691 .17327 .42577 .17191 Metetra
.664 .741 .907 r
.42577 .17191 .42691 .17327 .43339 .17082 .43225 .16945 Metetra
.664 .741 .907 r
.43225 .16945 .43339 .17082 .43989 .16836 .43875 .16699 Metetra
.664 .741 .907 r
.43875 .16699 .43989 .16836 .4464 .1659 .44527 .16452 Metetra
.664 .741 .907 r
.44527 .16452 .4464 .1659 .45293 .16343 .4518 .16205 Metetra
.664 .741 .907 r
.4518 .16205 .45293 .16343 .45947 .16095 .45834 .15957 Metetra
.664 .741 .907 r
.45834 .15957 .45947 .16095 .46603 .15847 .46491 .15708 Metetra
.664 .741 .907 r
.46491 .15708 .46603 .15847 .47261 .15598 .47149 .15459 Metetra
.664 .741 .907 r
.47149 .15459 .47261 .15598 .4792 .15348 .47808 .15209 Metetra
.664 .741 .907 r
.47808 .15209 .4792 .15348 .48581 .15098 .48469 .14958 Metetra
.664 .741 .907 r
.48469 .14958 .48581 .15098 .49243 .14847 .49132 .14707 Metetra
.664 .741 .907 r
.49132 .14707 .49243 .14847 .49907 .14596 .49796 .14456 Metetra
.664 .741 .907 r
.49796 .14456 .49907 .14596 .50573 .14344 .50462 .14204 Metetra
.664 .741 .907 r
.50462 .14204 .50573 .14344 .5124 .14092 .5113 .13951 Metetra
.664 .741 .907 r
.5113 .13951 .5124 .14092 .51909 .13839 .51799 .13697 Metetra
.664 .741 .907 r
.51799 .13697 .51909 .13839 .52579 .13585 .5247 .13443 Metetra
.664 .741 .907 r
.5247 .13443 .52579 .13585 .53252 .1333 .53142 .13188 Metetra
.664 .741 .907 r
.53142 .13188 .53252 .1333 .53925 .13075 .53816 .12933 Metetra
.664 .741 .907 r
.53816 .12933 .53925 .13075 .54601 .1282 .54492 .12677 Metetra
.664 .741 .907 r
.54492 .12677 .54601 .1282 .55278 .12564 .55169 .1242 Metetra
.664 .741 .907 r
.55169 .1242 .55278 .12564 .55957 .12307 .55848 .12163 Metetra
.664 .741 .907 r
.55848 .12163 .55957 .12307 .56637 .12049 .56529 .11905 Metetra
.664 .741 .907 r
.56529 .11905 .56637 .12049 .57319 .11791 .57211 .11647 Metetra
.664 .741 .907 r
.57211 .11647 .57319 .11791 .58003 .11532 .57896 .11388 Metetra
.664 .741 .907 r
.57896 .11388 .58003 .11532 .58688 .11273 .58581 .11128 Metetra
.664 .741 .907 r
.58581 .11128 .58688 .11273 .59375 .11013 .59269 .10867 Metetra
.664 .741 .907 r
.59269 .10867 .59375 .11013 .60064 .10752 .59958 .10606 Metetra
.664 .741 .907 r
.59958 .10606 .60064 .10752 .60755 .10491 .60649 .10345 Metetra
.664 .741 .907 r
.60649 .10345 .60755 .10491 .61447 .10229 .61341 .10082 Metetra
.664 .741 .907 r
.61341 .10082 .61447 .10229 .62141 .09966 .62036 .09819 Metetra
.664 .741 .907 r
.62036 .09819 .62141 .09966 .62837 .09703 .62732 .09556 Metetra
.664 .741 .907 r
.62732 .09556 .62837 .09703 .63534 .09439 .6343 .09291 Metetra
.664 .741 .907 r
.6343 .09291 .63534 .09439 .64233 .09174 .64129 .09026 Metetra
.664 .741 .907 r
.64129 .09026 .64233 .09174 .64934 .08909 .6483 .08761 Metetra
.938 .581 .177 r
.6483 .08761 .64934 .08909 .65851 .13387 .65761 .1357 Metetra
.96 .628 .325 r
.65761 .1357 .65851 .13387 .67098 .24253 .67126 .26984 Metetra
0 0 .015 r
.67126 .26984 .67098 .24253 .67047 .08109 .66945 .0796 Metetra
.664 .741 .907 r
.66945 .0796 .67047 .08109 .67755 .07841 .67653 .07691 Metetra
.664 .741 .907 r
.67653 .07691 .67755 .07841 .68465 .07573 .68363 .07422 Metetra
.664 .741 .907 r
.68363 .07422 .68465 .07573 .69177 .07303 .69075 .07153 Metetra
.664 .741 .907 r
.69075 .07153 .69177 .07303 .6989 .07033 .69789 .06882 Metetra
.664 .741 .907 r
.69789 .06882 .6989 .07033 .70605 .06763 .70504 .06611 Metetra
.664 .741 .907 r
.70504 .06611 .70605 .06763 .71322 .06491 .71222 .0634 Metetra
.664 .741 .907 r
.71222 .0634 .71322 .06491 .72041 .06219 .71941 .06067 Metetra
.664 .741 .907 r
.71941 .06067 .72041 .06219 .72761 .05947 .72662 .05794 Metetra
.664 .741 .907 r
.08461 .29945 .08589 .30065 .09159 .29849 .0903 .29729 Metetra
.664 .741 .907 r
.0903 .29729 .09159 .29849 .09729 .29633 .09601 .29513 Metetra
.664 .741 .907 r
.09601 .29513 .09729 .29633 .10301 .29417 .10173 .29296 Metetra
.664 .741 .907 r
.10173 .29296 .10301 .29417 .10874 .29199 .10747 .29078 Metetra
.664 .741 .907 r
.10747 .29078 .10874 .29199 .11449 .28982 .11321 .2886 Metetra
.664 .741 .907 r
.11321 .2886 .11449 .28982 .12025 .28764 .11897 .28642 Metetra
.664 .741 .907 r
.11897 .28642 .12025 .28764 .12602 .28545 .12475 .28423 Metetra
.664 .741 .907 r
.12475 .28423 .12602 .28545 .1318 .28326 .13053 .28204 Metetra
.664 .741 .907 r
.13053 .28204 .1318 .28326 .1376 .28106 .13633 .27984 Metetra
.664 .741 .907 r
.13633 .27984 .1376 .28106 .14341 .27886 .14215 .27763 Metetra
.664 .741 .907 r
.14215 .27763 .14341 .27886 .14924 .27666 .14797 .27542 Metetra
.664 .741 .907 r
.14797 .27542 .14924 .27666 .15507 .27445 .15381 .27321 Metetra
.664 .741 .907 r
.15381 .27321 .15507 .27445 .16092 .27223 .15966 .27099 Metetra
.664 .741 .907 r
.15966 .27099 .16092 .27223 .16679 .27001 .16553 .26877 Metetra
.664 .741 .907 r
.16553 .26877 .16679 .27001 .17266 .26778 .17141 .26654 Metetra
.664 .741 .907 r
.17141 .26654 .17266 .26778 .17855 .26555 .1773 .2643 Metetra
.664 .741 .907 r
.1773 .2643 .17855 .26555 .18446 .26331 .18321 .26206 Metetra
.664 .741 .907 r
.18321 .26206 .18446 .26331 .19038 .26107 .18913 .25982 Metetra
.664 .741 .907 r
.18913 .25982 .19038 .26107 .19631 .25883 .19506 .25757 Metetra
.664 .741 .907 r
.19506 .25757 .19631 .25883 .20225 .25657 .20101 .25532 Metetra
.664 .741 .907 r
.20101 .25532 .20225 .25657 .20821 .25432 .20697 .25306 Metetra
.664 .741 .907 r
.20697 .25306 .20821 .25432 .21418 .25205 .21295 .25079 Metetra
.664 .741 .907 r
.21295 .25079 .21418 .25205 .22017 .24979 .21893 .24852 Metetra
.664 .741 .907 r
.21893 .24852 .22017 .24979 .22617 .24751 .22494 .24624 Metetra
.664 .741 .907 r
.22494 .24624 .22617 .24751 .23218 .24524 .23095 .24396 Metetra
.664 .741 .907 r
.23095 .24396 .23218 .24524 .23821 .24295 .23698 .24168 Metetra
.664 .741 .907 r
.23698 .24168 .23821 .24295 .24425 .24066 .24303 .23939 Metetra
.664 .741 .907 r
.24303 .23939 .24425 .24066 .25031 .23837 .24909 .23709 Metetra
.664 .741 .907 r
.24909 .23709 .25031 .23837 .25638 .23607 .25516 .23479 Metetra
.664 .741 .907 r
.25516 .23479 .25638 .23607 .26246 .23377 .26124 .23248 Metetra
.664 .741 .907 r
.26124 .23248 .26246 .23377 .26856 .23146 .26735 .23017 Metetra
.664 .741 .907 r
.26735 .23017 .26856 .23146 .27467 .22914 .27346 .22785 Metetra
.664 .741 .907 r
.27346 .22785 .27467 .22914 .2808 .22682 .27959 .22552 Metetra
.664 .741 .907 r
.27959 .22552 .2808 .22682 .28694 .22449 .28573 .22319 Metetra
.664 .741 .907 r
.28573 .22319 .28694 .22449 .2931 .22216 .29189 .22086 Metetra
.664 .741 .907 r
.29189 .22086 .2931 .22216 .29926 .21983 .29806 .21852 Metetra
.664 .741 .907 r
.29806 .21852 .29926 .21983 .30545 .21748 .30425 .21617 Metetra
.664 .741 .907 r
.30425 .21617 .30545 .21748 .31165 .21513 .31045 .21382 Metetra
.664 .741 .907 r
.31045 .21382 .31165 .21513 .31786 .21278 .31667 .21147 Metetra
.961 .679 .453 r
.31667 .21147 .31786 .21278 .30841 .44718 .30712 .44593 Metetra
.96 .698 .494 r
.30712 .44593 .30841 .44718 .32404 .30611 .32597 .2559 Metetra
.632 .387 .529 r
.32597 .2559 .32404 .30611 .33659 .20569 .3354 .20436 Metetra
.664 .741 .907 r
.3354 .20436 .33659 .20569 .34286 .20331 .34168 .20198 Metetra
.664 .741 .907 r
.34168 .20198 .34286 .20331 .34915 .20093 .34797 .1996 Metetra
.664 .741 .907 r
.34797 .1996 .34915 .20093 .35545 .19854 .35427 .19721 Metetra
.664 .741 .907 r
.35427 .19721 .35545 .19854 .36177 .19615 .36059 .19481 Metetra
.664 .741 .907 r
.36059 .19481 .36177 .19615 .3681 .19375 .36692 .19241 Metetra
.664 .741 .907 r
.36692 .19241 .3681 .19375 .37444 .19135 .37327 .19 Metetra
.664 .741 .907 r
.37327 .19 .37444 .19135 .38081 .18894 .37964 .18759 Metetra
.664 .741 .907 r
.37964 .18759 .38081 .18894 .38718 .18652 .38602 .18517 Metetra
.664 .741 .907 r
.38602 .18517 .38718 .18652 .39357 .1841 .39241 .18275 Metetra
.664 .741 .907 r
.39241 .18275 .39357 .1841 .39998 .18167 .39882 .18032 Metetra
.664 .741 .907 r
.39882 .18032 .39998 .18167 .4064 .17924 .40525 .17788 Metetra
.664 .741 .907 r
.40525 .17788 .4064 .17924 .41284 .1768 .41169 .17544 Metetra
.664 .741 .907 r
.41169 .17544 .41284 .1768 .4193 .17436 .41815 .17299 Metetra
.664 .741 .907 r
.41815 .17299 .4193 .17436 .42577 .17191 .42462 .17054 Metetra
.664 .741 .907 r
.42462 .17054 .42577 .17191 .43225 .16945 .43111 .16808 Metetra
.664 .741 .907 r
.43111 .16808 .43225 .16945 .43875 .16699 .43761 .16561 Metetra
.664 .741 .907 r
.43761 .16561 .43875 .16699 .44527 .16452 .44413 .16314 Metetra
.664 .741 .907 r
.44413 .16314 .44527 .16452 .4518 .16205 .45066 .16066 Metetra
.664 .741 .907 r
.45066 .16066 .4518 .16205 .45834 .15957 .45721 .15818 Metetra
.664 .741 .907 r
.45721 .15818 .45834 .15957 .46491 .15708 .46378 .15569 Metetra
.664 .741 .907 r
.46378 .15569 .46491 .15708 .47149 .15459 .47036 .15319 Metetra
.664 .741 .907 r
.47036 .15319 .47149 .15459 .47808 .15209 .47696 .15069 Metetra
.298 .562 .929 r
.47696 .15069 .47808 .15209 .48469 .14958 .48352 .15209 Metetra
.48352 .15209 .48469 .14958 .49132 .14707 .4902 .14567 Metetra
.664 .741 .907 r
.4902 .14567 .49132 .14707 .49796 .14456 .49685 .14315 Metetra
.664 .741 .907 r
.49685 .14315 .49796 .14456 .50462 .14204 .50351 .14063 Metetra
.664 .741 .907 r
.50351 .14063 .50462 .14204 .5113 .13951 .51019 .13809 Metetra
.664 .741 .907 r
.51019 .13809 .5113 .13951 .51799 .13697 .51688 .13556 Metetra
.664 .741 .907 r
.51688 .13556 .51799 .13697 .5247 .13443 .5236 .13301 Metetra
.664 .741 .907 r
.5236 .13301 .5247 .13443 .53142 .13188 .53032 .13046 Metetra
.664 .741 .907 r
.53032 .13046 .53142 .13188 .53816 .12933 .53707 .1279 Metetra
.664 .741 .907 r
.53707 .1279 .53816 .12933 .54492 .12677 .54383 .12534 Metetra
.664 .741 .907 r
.54383 .12534 .54492 .12677 .55169 .1242 .55061 .12277 Metetra
.664 .741 .907 r
.55061 .12277 .55169 .1242 .55848 .12163 .5574 .12019 Metetra
.664 .741 .907 r
.5574 .12019 .55848 .12163 .56529 .11905 .56421 .11761 Metetra
.664 .741 .907 r
.56421 .11761 .56529 .11905 .57211 .11647 .57104 .11502 Metetra
.664 .741 .907 r
.57104 .11502 .57211 .11647 .57896 .11388 .57788 .11243 Metetra
.664 .741 .907 r
.57788 .11243 .57896 .11388 .58581 .11128 .58474 .10983 Metetra
.664 .741 .907 r
.58474 .10983 .58581 .11128 .59269 .10867 .59162 .10722 Metetra
.664 .741 .907 r
.59162 .10722 .59269 .10867 .59958 .10606 .59852 .10461 Metetra
.664 .741 .907 r
.59852 .10461 .59958 .10606 .60649 .10345 .60543 .10198 Metetra
.664 .741 .907 r
.60543 .10198 .60649 .10345 .61341 .10082 .61236 .09936 Metetra
.664 .741 .907 r
.61236 .09936 .61341 .10082 .62036 .09819 .61931 .09672 Metetra
.664 .741 .907 r
.61931 .09672 .62036 .09819 .62732 .09556 .62627 .09408 Metetra
.664 .741 .907 r
.62627 .09408 .62732 .09556 .6343 .09291 .63325 .09144 Metetra
.664 .741 .907 r
.63325 .09144 .6343 .09291 .64129 .09026 .64025 .08878 Metetra
.664 .741 .907 r
.64025 .08878 .64129 .09026 .6483 .08761 .64727 .08612 Metetra
.938 .581 .177 r
.64727 .08612 .6483 .08761 .65761 .1357 .65656 .13411 Metetra
.952 .61 .222 r
.65656 .13411 .65761 .1357 .67126 .26984 .66717 .20458 Metetra
.704 .431 .509 r
.66717 .20458 .67126 .26984 .66945 .0796 .66842 .0781 Metetra
.664 .741 .907 r
.66842 .0781 .66945 .0796 .67653 .07691 .67551 .07542 Metetra
.664 .741 .907 r
.67551 .07542 .67653 .07691 .68363 .07422 .68261 .07272 Metetra
.664 .741 .907 r
.68261 .07272 .68363 .07422 .69075 .07153 .68973 .07002 Metetra
.664 .741 .907 r
.68973 .07002 .69075 .07153 .69789 .06882 .69688 .06731 Metetra
.664 .741 .907 r
.69688 .06731 .69789 .06882 .70504 .06611 .70403 .0646 Metetra
.664 .741 .907 r
.70403 .0646 .70504 .06611 .71222 .0634 .71121 .06188 Metetra
.664 .741 .907 r
.71121 .06188 .71222 .0634 .71941 .06067 .71841 .05915 Metetra
.664 .741 .907 r
.71841 .05915 .71941 .06067 .72662 .05794 .72562 .05642 Metetra
.664 .741 .907 r
.08332 .29825 .08461 .29945 .0903 .29729 .08901 .29608 Metetra
.664 .741 .907 r
.08901 .29608 .0903 .29729 .09601 .29513 .09473 .29392 Metetra
.664 .741 .907 r
.09473 .29392 .09601 .29513 .10173 .29296 .10045 .29174 Metetra
.664 .741 .907 r
.10045 .29174 .10173 .29296 .10747 .29078 .10619 .28957 Metetra
.664 .741 .907 r
.10619 .28957 .10747 .29078 .11321 .2886 .11194 .28739 Metetra
.664 .741 .907 r
.11194 .28739 .11321 .2886 .11897 .28642 .1177 .2852 Metetra
.664 .741 .907 r
.1177 .2852 .11897 .28642 .12475 .28423 .12347 .28301 Metetra
.664 .741 .907 r
.12347 .28301 .12475 .28423 .13053 .28204 .12926 .28081 Metetra
.664 .741 .907 r
.12926 .28081 .13053 .28204 .13633 .27984 .13506 .27861 Metetra
.664 .741 .907 r
.13506 .27861 .13633 .27984 .14215 .27763 .14088 .2764 Metetra
.664 .741 .907 r
.14088 .2764 .14215 .27763 .14797 .27542 .14671 .27419 Metetra
.664 .741 .907 r
.14671 .27419 .14797 .27542 .15381 .27321 .15255 .27197 Metetra
.664 .741 .907 r
.15255 .27197 .15381 .27321 .15966 .27099 .1584 .26975 Metetra
.664 .741 .907 r
.1584 .26975 .15966 .27099 .16553 .26877 .16427 .26752 Metetra
.664 .741 .907 r
.16427 .26752 .16553 .26877 .17141 .26654 .17015 .26529 Metetra
.664 .741 .907 r
.17015 .26529 .17141 .26654 .1773 .2643 .17605 .26306 Metetra
.664 .741 .907 r
.17605 .26306 .1773 .2643 .18321 .26206 .18196 .26081 Metetra
.664 .741 .907 r
.18196 .26081 .18321 .26206 .18913 .25982 .18788 .25857 Metetra
.664 .741 .907 r
.18788 .25857 .18913 .25982 .19506 .25757 .19382 .25631 Metetra
.664 .741 .907 r
.19382 .25631 .19506 .25757 .20101 .25532 .19977 .25406 Metetra
.664 .741 .907 r
.19977 .25406 .20101 .25532 .20697 .25306 .20573 .25179 Metetra
.664 .741 .907 r
.20573 .25179 .20697 .25306 .21295 .25079 .21171 .24952 Metetra
.664 .741 .907 r
.21171 .24952 .21295 .25079 .21893 .24852 .2177 .24725 Metetra
.664 .741 .907 r
.2177 .24725 .21893 .24852 .22494 .24624 .2237 .24497 Metetra
.664 .741 .907 r
.2237 .24497 .22494 .24624 .23095 .24396 .22972 .24269 Metetra
.664 .741 .907 r
.22972 .24269 .23095 .24396 .23698 .24168 .23575 .2404 Metetra
.664 .741 .907 r
.23575 .2404 .23698 .24168 .24303 .23939 .2418 .2381 Metetra
.664 .741 .907 r
.2418 .2381 .24303 .23939 .24909 .23709 .24786 .2358 Metetra
.664 .741 .907 r
.24786 .2358 .24909 .23709 .25516 .23479 .25394 .2335 Metetra
.664 .741 .907 r
.25394 .2335 .25516 .23479 .26124 .23248 .26003 .23119 Metetra
.664 .741 .907 r
.26003 .23119 .26124 .23248 .26735 .23017 .26613 .22887 Metetra
.664 .741 .907 r
.26613 .22887 .26735 .23017 .27346 .22785 .27225 .22655 Metetra
.664 .741 .907 r
.27225 .22655 .27346 .22785 .27959 .22552 .27838 .22422 Metetra
.664 .741 .907 r
.27838 .22422 .27959 .22552 .28573 .22319 .28452 .22189 Metetra
.664 .741 .907 r
.28452 .22189 .28573 .22319 .29189 .22086 .29068 .21955 Metetra
.664 .741 .907 r
.29068 .21955 .29189 .22086 .29806 .21852 .29686 .21721 Metetra
.664 .741 .907 r
.29686 .21721 .29806 .21852 .30425 .21617 .30305 .21486 Metetra
.664 .741 .907 r
.30305 .21486 .30425 .21617 .31045 .21382 .30925 .21251 Metetra
.664 .741 .907 r
.30925 .21251 .31045 .21382 .31667 .21147 .31547 .21015 Metetra
.961 .679 .453 r
.31547 .21015 .31667 .21147 .30712 .44593 .30582 .44467 Metetra
.96 .698 .493 r
.30582 .44467 .30712 .44593 .32597 .2559 .32494 .25165 Metetra
.904 .662 .563 r
.32494 .25165 .32597 .2559 .3354 .20436 .33421 .20304 Metetra
.664 .741 .907 r
.33421 .20304 .3354 .20436 .34168 .20198 .34049 .20065 Metetra
.664 .741 .907 r
.34049 .20065 .34168 .20198 .34797 .1996 .34678 .19827 Metetra
.664 .741 .907 r
.34678 .19827 .34797 .1996 .35427 .19721 .35309 .19587 Metetra
.664 .741 .907 r
.35309 .19587 .35427 .19721 .36059 .19481 .35941 .19347 Metetra
.664 .741 .907 r
.35941 .19347 .36059 .19481 .36692 .19241 .36575 .19107 Metetra
.664 .741 .907 r
.36575 .19107 .36692 .19241 .37327 .19 .3721 .18866 Metetra
.664 .741 .907 r
.3721 .18866 .37327 .19 .37964 .18759 .37847 .18624 Metetra
.664 .741 .907 r
.37847 .18624 .37964 .18759 .38602 .18517 .38485 .18382 Metetra
.664 .741 .907 r
.38485 .18382 .38602 .18517 .39241 .18275 .39125 .18139 Metetra
.664 .741 .907 r
.39125 .18139 .39241 .18275 .39882 .18032 .39766 .17896 Metetra
.664 .741 .907 r
.39766 .17896 .39882 .18032 .40525 .17788 .40409 .17652 Metetra
.664 .741 .907 r
.40409 .17652 .40525 .17788 .41169 .17544 .41054 .17407 Metetra
.664 .741 .907 r
.41054 .17407 .41169 .17544 .41815 .17299 .417 .17162 Metetra
.664 .741 .907 r
.417 .17162 .41815 .17299 .42462 .17054 .42347 .16917 Metetra
.664 .741 .907 r
.42347 .16917 .42462 .17054 .43111 .16808 .42996 .1667 Metetra
.664 .741 .907 r
.42996 .1667 .43111 .16808 .43761 .16561 .43647 .16423 Metetra
.664 .741 .907 r
.43647 .16423 .43761 .16561 .44413 .16314 .44299 .16176 Metetra
.664 .741 .907 r
.44299 .16176 .44413 .16314 .45066 .16066 .44953 .15928 Metetra
.664 .741 .907 r
.44953 .15928 .45066 .16066 .45721 .15818 .45608 .15679 Metetra
.664 .741 .907 r
.45608 .15679 .45721 .15818 .46378 .15569 .46265 .1543 Metetra
.664 .741 .907 r
.46265 .1543 .46378 .15569 .47036 .15319 .46923 .1518 Metetra
.664 .741 .907 r
.46923 .1518 .47036 .15319 .47696 .15069 .47584 .14929 Metetra
.664 .741 .907 r
.47584 .14929 .47696 .15069 .48352 .15209 .48245 .14678 Metetra
.584 .444 .656 r
.48245 .14678 .48352 .15209 .4902 .14567 .48909 .14427 Metetra
.664 .741 .907 r
.48909 .14427 .4902 .14567 .49685 .14315 .49573 .14174 Metetra
.664 .741 .907 r
.49573 .14174 .49685 .14315 .50351 .14063 .5024 .13921 Metetra
.664 .741 .907 r
.5024 .13921 .50351 .14063 .51019 .13809 .50908 .13668 Metetra
.664 .741 .907 r
.50908 .13668 .51019 .13809 .51688 .13556 .51578 .13414 Metetra
.664 .741 .907 r
.51578 .13414 .51688 .13556 .5236 .13301 .52249 .13159 Metetra
.664 .741 .907 r
.52249 .13159 .5236 .13301 .53032 .13046 .52923 .12903 Metetra
.664 .741 .907 r
.52923 .12903 .53032 .13046 .53707 .1279 .53597 .12647 Metetra
.664 .741 .907 r
.53597 .12647 .53707 .1279 .54383 .12534 .54274 .12391 Metetra
.664 .741 .907 r
.54274 .12391 .54383 .12534 .55061 .12277 .54952 .12133 Metetra
.664 .741 .907 r
.54952 .12133 .55061 .12277 .5574 .12019 .55631 .11876 Metetra
.664 .741 .907 r
.55631 .11876 .5574 .12019 .56421 .11761 .56313 .11617 Metetra
.664 .741 .907 r
.56313 .11617 .56421 .11761 .57104 .11502 .56996 .11358 Metetra
.664 .741 .907 r
.56996 .11358 .57104 .11502 .57788 .11243 .57681 .11098 Metetra
.664 .741 .907 r
.57681 .11098 .57788 .11243 .58474 .10983 .58367 .10837 Metetra
.664 .741 .907 r
.58367 .10837 .58474 .10983 .59162 .10722 .59055 .10576 Metetra
.664 .741 .907 r
.59055 .10576 .59162 .10722 .59852 .10461 .59745 .10314 Metetra
.664 .741 .907 r
.59745 .10314 .59852 .10461 .60543 .10198 .60437 .10052 Metetra
.664 .741 .907 r
.60437 .10052 .60543 .10198 .61236 .09936 .6113 .09789 Metetra
.664 .741 .907 r
.6113 .09789 .61236 .09936 .61931 .09672 .61825 .09525 Metetra
.664 .741 .907 r
.61825 .09525 .61931 .09672 .62627 .09408 .62522 .09261 Metetra
.664 .741 .907 r
.62522 .09261 .62627 .09408 .63325 .09144 .6322 .08996 Metetra
.664 .741 .907 r
.6322 .08996 .63325 .09144 .64025 .08878 .63921 .0873 Metetra
.664 .741 .907 r
.63921 .0873 .64025 .08878 .64727 .08612 .64623 .08464 Metetra
.934 .574 .165 r
.64623 .08464 .64727 .08612 .65656 .13411 .65537 .12956 Metetra
.878 .569 .055 r
.65537 .12956 .65656 .13411 .66717 .20458 .66539 .18792 Metetra
.879 .586 .488 r
.66539 .18792 .66717 .20458 .66842 .0781 .66739 .0766 Metetra
.664 .741 .907 r
.66739 .0766 .66842 .0781 .67551 .07542 .67448 .07391 Metetra
.664 .741 .907 r
.67448 .07391 .67551 .07542 .68261 .07272 .68159 .07122 Metetra
.664 .741 .907 r
.68159 .07122 .68261 .07272 .68973 .07002 .68872 .06851 Metetra
.664 .741 .907 r
.68872 .06851 .68973 .07002 .69688 .06731 .69586 .0658 Metetra
.664 .741 .907 r
.69586 .0658 .69688 .06731 .70403 .0646 .70302 .06308 Metetra
.664 .741 .907 r
.70302 .06308 .70403 .0646 .71121 .06188 .7102 .06036 Metetra
.664 .741 .907 r
.7102 .06036 .71121 .06188 .71841 .05915 .7174 .05763 Metetra
.664 .741 .907 r
.7174 .05763 .71841 .05915 .72562 .05642 .72462 .05489 Metetra
.664 .741 .907 r
.08203 .29704 .08332 .29825 .08901 .29608 .08773 .29487 Metetra
.664 .741 .907 r
.08773 .29487 .08901 .29608 .09473 .29392 .09344 .29271 Metetra
.664 .741 .907 r
.09344 .29271 .09473 .29392 .10045 .29174 .09916 .29053 Metetra
.664 .741 .907 r
.09916 .29053 .10045 .29174 .10619 .28957 .1049 .28835 Metetra
.664 .741 .907 r
.1049 .28835 .10619 .28957 .11194 .28739 .11066 .28617 Metetra
.664 .741 .907 r
.11066 .28617 .11194 .28739 .1177 .2852 .11642 .28398 Metetra
.664 .741 .907 r
.11642 .28398 .1177 .2852 .12347 .28301 .1222 .28178 Metetra
.664 .741 .907 r
.1222 .28178 .12347 .28301 .12926 .28081 .12799 .27958 Metetra
.664 .741 .907 r
.12799 .27958 .12926 .28081 .13506 .27861 .13379 .27738 Metetra
.664 .741 .907 r
.13379 .27738 .13506 .27861 .14088 .2764 .13961 .27517 Metetra
.664 .741 .907 r
.13961 .27517 .14088 .2764 .14671 .27419 .14544 .27295 Metetra
.664 .741 .907 r
.14544 .27295 .14671 .27419 .15255 .27197 .15128 .27073 Metetra
.664 .741 .907 r
.15128 .27073 .15255 .27197 .1584 .26975 .15714 .26851 Metetra
.664 .741 .907 r
.15714 .26851 .1584 .26975 .16427 .26752 .16301 .26628 Metetra
.664 .741 .907 r
.16301 .26628 .16427 .26752 .17015 .26529 .1689 .26405 Metetra
.664 .741 .907 r
.1689 .26405 .17015 .26529 .17605 .26306 .17479 .26181 Metetra
.664 .741 .907 r
.17479 .26181 .17605 .26306 .18196 .26081 .18071 .25956 Metetra
.664 .741 .907 r
.18071 .25956 .18196 .26081 .18788 .25857 .18663 .25731 Metetra
.664 .741 .907 r
.18663 .25731 .18788 .25857 .19382 .25631 .19257 .25505 Metetra
.664 .741 .907 r
.19257 .25505 .19382 .25631 .19977 .25406 .19852 .25279 Metetra
.664 .741 .907 r
.19852 .25279 .19977 .25406 .20573 .25179 .20449 .25053 Metetra
.664 .741 .907 r
.20449 .25053 .20573 .25179 .21171 .24952 .21047 .24826 Metetra
.664 .741 .907 r
.21047 .24826 .21171 .24952 .2177 .24725 .21646 .24598 Metetra
.664 .741 .907 r
.21646 .24598 .2177 .24725 .2237 .24497 .22247 .2437 Metetra
.664 .741 .907 r
.22247 .2437 .2237 .24497 .22972 .24269 .22849 .24141 Metetra
.664 .741 .907 r
.22849 .24141 .22972 .24269 .23575 .2404 .23452 .23912 Metetra
.664 .741 .907 r
.23452 .23912 .23575 .2404 .2418 .2381 .24057 .23682 Metetra
.664 .741 .907 r
.24057 .23682 .2418 .2381 .24786 .2358 .24664 .23452 Metetra
.664 .741 .907 r
.24664 .23452 .24786 .2358 .25394 .2335 .25271 .23221 Metetra
.664 .741 .907 r
.25271 .23221 .25394 .2335 .26003 .23119 .2588 .2299 Metetra
.664 .741 .907 r
.2588 .2299 .26003 .23119 .26613 .22887 .26491 .22758 Metetra
.664 .741 .907 r
.26491 .22758 .26613 .22887 .27225 .22655 .27103 .22525 Metetra
.664 .741 .907 r
.27103 .22525 .27225 .22655 .27838 .22422 .27716 .22292 Metetra
.664 .741 .907 r
.27716 .22292 .27838 .22422 .28452 .22189 .28331 .22059 Metetra
.664 .741 .907 r
.28331 .22059 .28452 .22189 .29068 .21955 .28948 .21825 Metetra
.664 .741 .907 r
.28948 .21825 .29068 .21955 .29686 .21721 .29565 .2159 Metetra
.664 .741 .907 r
.29565 .2159 .29686 .21721 .30305 .21486 .30185 .21355 Metetra
.664 .741 .907 r
.30185 .21355 .30305 .21486 .30925 .21251 .30805 .21119 Metetra
.664 .741 .907 r
.30805 .21119 .30925 .21251 .31547 .21015 .31427 .20883 Metetra
.961 .679 .453 r
.31427 .20883 .31547 .21015 .30582 .44467 .30452 .44342 Metetra
.96 .699 .496 r
.30452 .44342 .30582 .44467 .32494 .25165 .32243 .27028 Metetra
0 0 .051 r
.32243 .27028 .32494 .25165 .33421 .20304 .33303 .20171 Metetra
.664 .741 .907 r
.33303 .20171 .33421 .20304 .34049 .20065 .33931 .19932 Metetra
.664 .741 .907 r
.33931 .19932 .34049 .20065 .34678 .19827 .3456 .19693 Metetra
.664 .741 .907 r
.3456 .19693 .34678 .19827 .35309 .19587 .35191 .19454 Metetra
.664 .741 .907 r
.35191 .19454 .35309 .19587 .35941 .19347 .35824 .19213 Metetra
.664 .741 .907 r
.35824 .19213 .35941 .19347 .36575 .19107 .36458 .18973 Metetra
.664 .741 .907 r
.36458 .18973 .36575 .19107 .3721 .18866 .37093 .18731 Metetra
.664 .741 .907 r
.37093 .18731 .3721 .18866 .37847 .18624 .3773 .18489 Metetra
.664 .741 .907 r
.3773 .18489 .37847 .18624 .38485 .18382 .38369 .18247 Metetra
.664 .741 .907 r
.38369 .18247 .38485 .18382 .39125 .18139 .39009 .18004 Metetra
.664 .741 .907 r
.39009 .18004 .39125 .18139 .39766 .17896 .3965 .1776 Metetra
.664 .741 .907 r
.3965 .1776 .39766 .17896 .40409 .17652 .40293 .17516 Metetra
.664 .741 .907 r
.40293 .17516 .40409 .17652 .41054 .17407 .40938 .17271 Metetra
.664 .741 .907 r
.40938 .17271 .41054 .17407 .417 .17162 .41584 .17025 Metetra
.664 .741 .907 r
.41584 .17025 .417 .17162 .42347 .16917 .42232 .16779 Metetra
.664 .741 .907 r
.42232 .16779 .42347 .16917 .42996 .1667 .42881 .16533 Metetra
.664 .741 .907 r
.42881 .16533 .42996 .1667 .43647 .16423 .43532 .16285 Metetra
.664 .741 .907 r
.43532 .16285 .43647 .16423 .44299 .16176 .44185 .16038 Metetra
.664 .741 .907 r
.44185 .16038 .44299 .16176 .44953 .15928 .44839 .15789 Metetra
.664 .741 .907 r
.44839 .15789 .44953 .15928 .45608 .15679 .45495 .1554 Metetra
.664 .741 .907 r
.45495 .1554 .45608 .15679 .46265 .1543 .46152 .15291 Metetra
.664 .741 .907 r
.46152 .15291 .46265 .1543 .46923 .1518 .46811 .1504 Metetra
.664 .741 .907 r
.46811 .1504 .46923 .1518 .47584 .14929 .47471 .1479 Metetra
.65 .736 .912 r
.47471 .1479 .47584 .14929 .48245 .14678 .48133 .14561 Metetra
.68 .787 .931 r
.48133 .14561 .48245 .14678 .48909 .14427 .48797 .14286 Metetra
.664 .741 .907 r
.48797 .14286 .48909 .14427 .49573 .14174 .49462 .14033 Metetra
.664 .741 .907 r
.49462 .14033 .49573 .14174 .5024 .13921 .50129 .1378 Metetra
.664 .741 .907 r
.50129 .1378 .5024 .13921 .50908 .13668 .50797 .13526 Metetra
.664 .741 .907 r
.50797 .13526 .50908 .13668 .51578 .13414 .51467 .13272 Metetra
.664 .741 .907 r
.51467 .13272 .51578 .13414 .52249 .13159 .52139 .13017 Metetra
.664 .741 .907 r
.52139 .13017 .52249 .13159 .52923 .12903 .52813 .12761 Metetra
.664 .741 .907 r
.52813 .12761 .52923 .12903 .53597 .12647 .53488 .12504 Metetra
.664 .741 .907 r
.53488 .12504 .53597 .12647 .54274 .12391 .54164 .12247 Metetra
.664 .741 .907 r
.54164 .12247 .54274 .12391 .54952 .12133 .54843 .1199 Metetra
.664 .741 .907 r
.54843 .1199 .54952 .12133 .55631 .11876 .55523 .11731 Metetra
.664 .741 .907 r
.55523 .11731 .55631 .11876 .56313 .11617 .56205 .11472 Metetra
.664 .741 .907 r
.56205 .11472 .56313 .11617 .56996 .11358 .56888 .11213 Metetra
.664 .741 .907 r
.56888 .11213 .56996 .11358 .57681 .11098 .57573 .10953 Metetra
.664 .741 .907 r
.57573 .10953 .57681 .11098 .58367 .10837 .5826 .10692 Metetra
.664 .741 .907 r
.5826 .10692 .58367 .10837 .59055 .10576 .58948 .1043 Metetra
.664 .741 .907 r
.58948 .1043 .59055 .10576 .59745 .10314 .59639 .10168 Metetra
.664 .741 .907 r
.59639 .10168 .59745 .10314 .60437 .10052 .6033 .09905 Metetra
.664 .741 .907 r
.6033 .09905 .60437 .10052 .6113 .09789 .61024 .09642 Metetra
.664 .741 .907 r
.61024 .09642 .6113 .09789 .61825 .09525 .6172 .09378 Metetra
.664 .741 .907 r
.6172 .09378 .61825 .09525 .62522 .09261 .62417 .09113 Metetra
.664 .741 .907 r
.62417 .09113 .62522 .09261 .6322 .08996 .63115 .08848 Metetra
.664 .741 .907 r
.63115 .08848 .6322 .08996 .63921 .0873 .63816 .08582 Metetra
.664 .741 .907 r
.63816 .08582 .63921 .0873 .64623 .08464 .64518 .08315 Metetra
.953 .611 .228 r
.64518 .08315 .64623 .08464 .65537 .12956 .65533 .15119 Metetra
.682 .384 .462 r
.65533 .15119 .65537 .12956 .66539 .18792 .66464 .19336 Metetra
.967 .719 .286 r
.66464 .19336 .66539 .18792 .66739 .0766 .66636 .0751 Metetra
.664 .741 .907 r
.66636 .0751 .66739 .0766 .67448 .07391 .67345 .07241 Metetra
.664 .741 .907 r
.67345 .07241 .67448 .07391 .68159 .07122 .68057 .06971 Metetra
.664 .741 .907 r
.68057 .06971 .68159 .07122 .68872 .06851 .6877 .067 Metetra
.664 .741 .907 r
.6877 .067 .68872 .06851 .69586 .0658 .69484 .06429 Metetra
.664 .741 .907 r
.69484 .06429 .69586 .0658 .70302 .06308 .70201 .06156 Metetra
.664 .741 .907 r
.70201 .06156 .70302 .06308 .7102 .06036 .7092 .05884 Metetra
.664 .741 .907 r
.7092 .05884 .7102 .06036 .7174 .05763 .7164 .0561 Metetra
.664 .741 .907 r
.7164 .0561 .7174 .05763 .72462 .05489 .72362 .05336 Metetra
.664 .741 .907 r
.08073 .29583 .08203 .29704 .08773 .29487 .08644 .29367 Metetra
.664 .741 .907 r
.08644 .29367 .08773 .29487 .09344 .29271 .09215 .29149 Metetra
.664 .741 .907 r
.09215 .29149 .09344 .29271 .09916 .29053 .09788 .28932 Metetra
.664 .741 .907 r
.09788 .28932 .09916 .29053 .1049 .28835 .10362 .28713 Metetra
.664 .741 .907 r
.10362 .28713 .1049 .28835 .11066 .28617 .10937 .28495 Metetra
.664 .741 .907 r
.10937 .28495 .11066 .28617 .11642 .28398 .11514 .28275 Metetra
.664 .741 .907 r
.11514 .28275 .11642 .28398 .1222 .28178 .12092 .28056 Metetra
.664 .741 .907 r
.12092 .28056 .1222 .28178 .12799 .27958 .12671 .27835 Metetra
.664 .741 .907 r
.12671 .27835 .12799 .27958 .13379 .27738 .13252 .27615 Metetra
.664 .741 .907 r
.13252 .27615 .13379 .27738 .13961 .27517 .13834 .27393 Metetra
.664 .741 .907 r
.13834 .27393 .13961 .27517 .14544 .27295 .14417 .27172 Metetra
.664 .741 .907 r
.14417 .27172 .14544 .27295 .15128 .27073 .15002 .26949 Metetra
.664 .741 .907 r
.15002 .26949 .15128 .27073 .15714 .26851 .15588 .26727 Metetra
.664 .741 .907 r
.15588 .26727 .15714 .26851 .16301 .26628 .16175 .26503 Metetra
.664 .741 .907 r
.16175 .26503 .16301 .26628 .1689 .26405 .16764 .2628 Metetra
.664 .741 .907 r
.16764 .2628 .1689 .26405 .17479 .26181 .17354 .26055 Metetra
.664 .741 .907 r
.17354 .26055 .17479 .26181 .18071 .25956 .17945 .25831 Metetra
.664 .741 .907 r
.17945 .25831 .18071 .25956 .18663 .25731 .18538 .25605 Metetra
.664 .741 .907 r
.18538 .25605 .18663 .25731 .19257 .25505 .19132 .25379 Metetra
.664 .741 .907 r
.19132 .25379 .19257 .25505 .19852 .25279 .19727 .25153 Metetra
.664 .741 .907 r
.19727 .25153 .19852 .25279 .20449 .25053 .20324 .24926 Metetra
.664 .741 .907 r
.20324 .24926 .20449 .25053 .21047 .24826 .20922 .24699 Metetra
.664 .741 .907 r
.20922 .24699 .21047 .24826 .21646 .24598 .21522 .24471 Metetra
.664 .741 .907 r
.21522 .24471 .21646 .24598 .22247 .2437 .22123 .24242 Metetra
.664 .741 .907 r
.22123 .24242 .22247 .2437 .22849 .24141 .22725 .24013 Metetra
.664 .741 .907 r
.22725 .24013 .22849 .24141 .23452 .23912 .23329 .23784 Metetra
.664 .741 .907 r
.23329 .23784 .23452 .23912 .24057 .23682 .23934 .23554 Metetra
.664 .741 .907 r
.23934 .23554 .24057 .23682 .24664 .23452 .24541 .23323 Metetra
.664 .741 .907 r
.24541 .23323 .24664 .23452 .25271 .23221 .25149 .23092 Metetra
.664 .741 .907 r
.25149 .23092 .25271 .23221 .2588 .2299 .25758 .22861 Metetra
.664 .741 .907 r
.25758 .22861 .2588 .2299 .26491 .22758 .26369 .22628 Metetra
.664 .741 .907 r
.26369 .22628 .26491 .22758 .27103 .22525 .26981 .22396 Metetra
.664 .741 .907 r
.26981 .22396 .27103 .22525 .27716 .22292 .27595 .22162 Metetra
.664 .741 .907 r
.27595 .22162 .27716 .22292 .28331 .22059 .2821 .21928 Metetra
.664 .741 .907 r
.2821 .21928 .28331 .22059 .28948 .21825 .28827 .21694 Metetra
.664 .741 .907 r
.28827 .21694 .28948 .21825 .29565 .2159 .29445 .21459 Metetra
.664 .741 .907 r
.29445 .21459 .29565 .2159 .30185 .21355 .30064 .21224 Metetra
.664 .741 .907 r
.30064 .21224 .30185 .21355 .30805 .21119 .30685 .20988 Metetra
.664 .741 .907 r
.30685 .20988 .30805 .21119 .31427 .20883 .31307 .20751 Metetra
.961 .679 .453 r
.31307 .20751 .31427 .20883 .30452 .44342 .30322 .44216 Metetra
.96 .7 .498 r
.30322 .44216 .30452 .44342 .32243 .27028 .32054 .27899 Metetra
.977 .797 .38 r
.32054 .27899 .32243 .27028 .33303 .20171 .33183 .20038 Metetra
.664 .741 .907 r
.33183 .20038 .33303 .20171 .33931 .19932 .33812 .19799 Metetra
.664 .741 .907 r
.33812 .19799 .33931 .19932 .3456 .19693 .34442 .1956 Metetra
.664 .741 .907 r
.34442 .1956 .3456 .19693 .35191 .19454 .35073 .1932 Metetra
.664 .741 .907 r
.35073 .1932 .35191 .19454 .35824 .19213 .35706 .19079 Metetra
.664 .741 .907 r
.35706 .19079 .35824 .19213 .36458 .18973 .3634 .18838 Metetra
.664 .741 .907 r
.3634 .18838 .36458 .18973 .37093 .18731 .36976 .18596 Metetra
.664 .741 .907 r
.36976 .18596 .37093 .18731 .3773 .18489 .37613 .18354 Metetra
.664 .741 .907 r
.37613 .18354 .3773 .18489 .38369 .18247 .38252 .18111 Metetra
.664 .741 .907 r
.38252 .18111 .38369 .18247 .39009 .18004 .38892 .17868 Metetra
.664 .741 .907 r
.38892 .17868 .39009 .18004 .3965 .1776 .39534 .17624 Metetra
.664 .741 .907 r
.39534 .17624 .3965 .1776 .40293 .17516 .40177 .17379 Metetra
.664 .741 .907 r
.40177 .17379 .40293 .17516 .40938 .17271 .40822 .17134 Metetra
.664 .741 .907 r
.40822 .17134 .40938 .17271 .41584 .17025 .41469 .16888 Metetra
.664 .741 .907 r
.41469 .16888 .41584 .17025 .42232 .16779 .42117 .16642 Metetra
.664 .741 .907 r
.42117 .16642 .42232 .16779 .42881 .16533 .42767 .16395 Metetra
.664 .741 .907 r
.42767 .16395 .42881 .16533 .43532 .16285 .43418 .16147 Metetra
.664 .741 .907 r
.43418 .16147 .43532 .16285 .44185 .16038 .44071 .15899 Metetra
.664 .741 .907 r
.44071 .15899 .44185 .16038 .44839 .15789 .44725 .1565 Metetra
.664 .741 .907 r
.44725 .1565 .44839 .15789 .45495 .1554 .45381 .15401 Metetra
.664 .741 .907 r
.45381 .15401 .45495 .1554 .46152 .15291 .46038 .15151 Metetra
.664 .741 .907 r
.46038 .15151 .46152 .15291 .46811 .1504 .46698 .14901 Metetra
.664 .741 .907 r
.46698 .14901 .46811 .1504 .47471 .1479 .47358 .14649 Metetra
.664 .741 .907 r
.47358 .14649 .47471 .1479 .48133 .14561 .48021 .14398 Metetra
.66 .703 .879 r
.48021 .14398 .48133 .14561 .48797 .14286 .48685 .14145 Metetra
.664 .741 .907 r
.48685 .14145 .48797 .14286 .49462 .14033 .4935 .13892 Metetra
.664 .741 .907 r
.4935 .13892 .49462 .14033 .50129 .1378 .50017 .13639 Metetra
.664 .741 .907 r
.50017 .13639 .50129 .1378 .50797 .13526 .50686 .13384 Metetra
.664 .741 .907 r
.50686 .13384 .50797 .13526 .51467 .13272 .51357 .13129 Metetra
.664 .741 .907 r
.51357 .13129 .51467 .13272 .52139 .13017 .52029 .12874 Metetra
.664 .741 .907 r
.52029 .12874 .52139 .13017 .52813 .12761 .52702 .12618 Metetra
.664 .741 .907 r
.52702 .12618 .52813 .12761 .53488 .12504 .53378 .12361 Metetra
.664 .741 .907 r
.53378 .12361 .53488 .12504 .54164 .12247 .54055 .12104 Metetra
.664 .741 .907 r
.54055 .12104 .54164 .12247 .54843 .1199 .54734 .11846 Metetra
.664 .741 .907 r
.54734 .11846 .54843 .1199 .55523 .11731 .55414 .11587 Metetra
.664 .741 .907 r
.55414 .11587 .55523 .11731 .56205 .11472 .56096 .11328 Metetra
.664 .741 .907 r
.56096 .11328 .56205 .11472 .56888 .11213 .5678 .11068 Metetra
.664 .741 .907 r
.5678 .11068 .56888 .11213 .57573 .10953 .57465 .10807 Metetra
.664 .741 .907 r
.57465 .10807 .57573 .10953 .5826 .10692 .58152 .10546 Metetra
.664 .741 .907 r
.58152 .10546 .5826 .10692 .58948 .1043 .58841 .10284 Metetra
.664 .741 .907 r
.58841 .10284 .58948 .1043 .59639 .10168 .59532 .10022 Metetra
.664 .741 .907 r
.59532 .10022 .59639 .10168 .6033 .09905 .60224 .09758 Metetra
.664 .741 .907 r
.60224 .09758 .6033 .09905 .61024 .09642 .60918 .09495 Metetra
.664 .741 .907 r
.60918 .09495 .61024 .09642 .6172 .09378 .61614 .0923 Metetra
.664 .741 .907 r
.61614 .0923 .6172 .09378 .62417 .09113 .62311 .08965 Metetra
.664 .741 .907 r
.62311 .08965 .62417 .09113 .63115 .08848 .6301 .08699 Metetra
.664 .741 .907 r
.6301 .08699 .63115 .08848 .63816 .08582 .63711 .08433 Metetra
.664 .741 .907 r
.63711 .08433 .63816 .08582 .64518 .08315 .64414 .08166 Metetra
.952 .608 .224 r
.64414 .08166 .64518 .08315 .65533 .15119 .65417 .14763 Metetra
.85 .524 0 r
.65417 .14763 .65533 .15119 .66464 .19336 .66345 .1893 Metetra
.971 .682 .421 r
.66345 .1893 .66464 .19336 .66636 .0751 .66533 .0736 Metetra
.664 .741 .907 r
.66533 .0736 .66636 .0751 .67345 .07241 .67243 .0709 Metetra
.664 .741 .907 r
.67243 .0709 .67345 .07241 .68057 .06971 .67954 .0682 Metetra
.664 .741 .907 r
.67954 .0682 .68057 .06971 .6877 .067 .68668 .06549 Metetra
.664 .741 .907 r
.68668 .06549 .6877 .067 .69484 .06429 .69383 .06277 Metetra
.664 .741 .907 r
.69383 .06277 .69484 .06429 .70201 .06156 .701 .06004 Metetra
.664 .741 .907 r
.701 .06004 .70201 .06156 .7092 .05884 .70819 .05731 Metetra
.664 .741 .907 r
.70819 .05731 .7092 .05884 .7164 .0561 .71539 .05457 Metetra
.664 .741 .907 r
.71539 .05457 .7164 .0561 .72362 .05336 .72262 .05182 Metetra
.664 .741 .907 r
.07944 .29462 .08073 .29583 .08644 .29367 .08514 .29245 Metetra
.664 .741 .907 r
.08514 .29245 .08644 .29367 .09215 .29149 .09086 .29028 Metetra
.664 .741 .907 r
.09086 .29028 .09215 .29149 .09788 .28932 .09659 .2881 Metetra
.664 .741 .907 r
.09659 .2881 .09788 .28932 .10362 .28713 .10233 .28591 Metetra
.664 .741 .907 r
.10233 .28591 .10362 .28713 .10937 .28495 .10809 .28372 Metetra
.664 .741 .907 r
.10809 .28372 .10937 .28495 .11514 .28275 .11386 .28153 Metetra
.664 .741 .907 r
.11386 .28153 .11514 .28275 .12092 .28056 .11964 .27933 Metetra
.664 .741 .907 r
.11964 .27933 .12092 .28056 .12671 .27835 .12544 .27712 Metetra
.664 .741 .907 r
.12544 .27712 .12671 .27835 .13252 .27615 .13125 .27491 Metetra
.664 .741 .907 r
.13125 .27491 .13252 .27615 .13834 .27393 .13707 .2727 Metetra
.664 .741 .907 r
.13707 .2727 .13834 .27393 .14417 .27172 .1429 .27048 Metetra
.664 .741 .907 r
.1429 .27048 .14417 .27172 .15002 .26949 .14875 .26825 Metetra
.664 .741 .907 r
.14875 .26825 .15002 .26949 .15588 .26727 .15461 .26602 Metetra
.664 .741 .907 r
.15461 .26602 .15588 .26727 .16175 .26503 .16049 .26379 Metetra
.664 .741 .907 r
.16049 .26379 .16175 .26503 .16764 .2628 .16638 .26155 Metetra
.664 .741 .907 r
.16638 .26155 .16764 .2628 .17354 .26055 .17228 .2593 Metetra
.664 .741 .907 r
.17228 .2593 .17354 .26055 .17945 .25831 .1782 .25705 Metetra
.664 .741 .907 r
.1782 .25705 .17945 .25831 .18538 .25605 .18413 .25479 Metetra
.664 .741 .907 r
.18413 .25479 .18538 .25605 .19132 .25379 .19007 .25253 Metetra
.664 .741 .907 r
.19007 .25253 .19132 .25379 .19727 .25153 .19602 .25027 Metetra
.664 .741 .907 r
.19602 .25027 .19727 .25153 .20324 .24926 .202 .24799 Metetra
.664 .741 .907 r
.202 .24799 .20324 .24926 .20922 .24699 .20798 .24572 Metetra
.664 .741 .907 r
.20798 .24572 .20922 .24699 .21522 .24471 .21398 .24344 Metetra
.664 .741 .907 r
.21398 .24344 .21522 .24471 .22123 .24242 .21999 .24115 Metetra
.664 .741 .907 r
.21999 .24115 .22123 .24242 .22725 .24013 .22602 .23886 Metetra
.664 .741 .907 r
.22602 .23886 .22725 .24013 .23329 .23784 .23206 .23656 Metetra
.664 .741 .907 r
.23206 .23656 .23329 .23784 .23934 .23554 .23811 .23425 Metetra
.664 .741 .907 r
.23811 .23425 .23934 .23554 .24541 .23323 .24418 .23194 Metetra
.664 .741 .907 r
.24418 .23194 .24541 .23323 .25149 .23092 .25026 .22963 Metetra
.664 .741 .907 r
.25026 .22963 .25149 .23092 .25758 .22861 .25636 .22731 Metetra
.664 .741 .907 r
.25636 .22731 .25758 .22861 .26369 .22628 .26247 .22499 Metetra
.664 .741 .907 r
.26247 .22499 .26369 .22628 .26981 .22396 .26859 .22266 Metetra
.664 .741 .907 r
.26859 .22266 .26981 .22396 .27595 .22162 .27473 .22032 Metetra
.664 .741 .907 r
.27473 .22032 .27595 .22162 .2821 .21928 .28089 .21798 Metetra
.664 .741 .907 r
.28089 .21798 .2821 .21928 .28827 .21694 .28706 .21563 Metetra
.664 .741 .907 r
.28706 .21563 .28827 .21694 .29445 .21459 .29324 .21328 Metetra
.664 .741 .907 r
.29324 .21328 .29445 .21459 .30064 .21224 .29944 .21092 Metetra
.664 .741 .907 r
.29944 .21092 .30064 .21224 .30685 .20988 .30565 .20856 Metetra
.664 .741 .907 r
.30565 .20856 .30685 .20988 .31307 .20751 .31187 .20619 Metetra
.961 .679 .453 r
.31187 .20619 .31307 .20751 .30322 .44216 .30192 .4409 Metetra
.96 .699 .497 r
.30192 .4409 .30322 .44216 .32054 .27899 .3197 .27185 Metetra
.893 .638 .545 r
.3197 .27185 .32054 .27899 .33183 .20038 .33064 .19905 Metetra
.664 .741 .907 r
.33064 .19905 .33183 .20038 .33812 .19799 .33693 .19666 Metetra
.664 .741 .907 r
.33693 .19666 .33812 .19799 .34442 .1956 .34323 .19426 Metetra
.664 .741 .907 r
.34323 .19426 .34442 .1956 .35073 .1932 .34954 .19186 Metetra
.664 .741 .907 r
.34954 .19186 .35073 .1932 .35706 .19079 .35587 .18945 Metetra
.664 .741 .907 r
.35587 .18945 .35706 .19079 .3634 .18838 .36222 .18703 Metetra
.664 .741 .907 r
.36222 .18703 .3634 .18838 .36976 .18596 .36858 .18461 Metetra
.664 .741 .907 r
.36858 .18461 .36976 .18596 .37613 .18354 .37496 .18219 Metetra
.664 .741 .907 r
.37496 .18219 .37613 .18354 .38252 .18111 .38135 .17975 Metetra
.664 .741 .907 r
.38135 .17975 .38252 .18111 .38892 .17868 .38775 .17732 Metetra
.664 .741 .907 r
.38775 .17732 .38892 .17868 .39534 .17624 .39418 .17487 Metetra
.664 .741 .907 r
.39418 .17487 .39534 .17624 .40177 .17379 .40061 .17242 Metetra
.664 .741 .907 r
.40061 .17242 .40177 .17379 .40822 .17134 .40707 .16997 Metetra
.664 .741 .907 r
.40707 .16997 .40822 .17134 .41469 .16888 .41353 .16751 Metetra
.664 .741 .907 r
.41353 .16751 .41469 .16888 .42117 .16642 .42002 .16504 Metetra
.664 .741 .907 r
.42002 .16504 .42117 .16642 .42767 .16395 .42652 .16257 Metetra
.664 .741 .907 r
.42652 .16257 .42767 .16395 .43418 .16147 .43303 .16009 Metetra
.664 .741 .907 r
.43303 .16009 .43418 .16147 .44071 .15899 .43956 .1576 Metetra
.664 .741 .907 r
.43956 .1576 .44071 .15899 .44725 .1565 .44611 .15511 Metetra
.664 .741 .907 r
.44611 .15511 .44725 .1565 .45381 .15401 .45267 .15262 Metetra
.664 .741 .907 r
.45267 .15262 .45381 .15401 .46038 .15151 .45925 .15011 Metetra
.664 .741 .907 r
.45925 .15011 .46038 .15151 .46698 .14901 .46584 .1476 Metetra
.664 .741 .907 r
.46584 .1476 .46698 .14901 .47358 .14649 .47245 .14509 Metetra
.137 .462 .889 r
.47245 .14509 .47358 .14649 .48021 .14398 .479 .14764 Metetra
.093 0 .114 r
.479 .14764 .48021 .14398 .48685 .14145 .48572 .14004 Metetra
.664 .741 .907 r
.48572 .14004 .48685 .14145 .4935 .13892 .49238 .13751 Metetra
.664 .741 .907 r
.49238 .13751 .4935 .13892 .50017 .13639 .49906 .13497 Metetra
.664 .741 .907 r
.49906 .13497 .50017 .13639 .50686 .13384 .50575 .13242 Metetra
.664 .741 .907 r
.50575 .13242 .50686 .13384 .51357 .13129 .51246 .12987 Metetra
.664 .741 .907 r
.51246 .12987 .51357 .13129 .52029 .12874 .51918 .12731 Metetra
.664 .741 .907 r
.51918 .12731 .52029 .12874 .52702 .12618 .52592 .12475 Metetra
.664 .741 .907 r
.52592 .12475 .52702 .12618 .53378 .12361 .53268 .12218 Metetra
.664 .741 .907 r
.53268 .12218 .53378 .12361 .54055 .12104 .53945 .1196 Metetra
.664 .741 .907 r
.53945 .1196 .54055 .12104 .54734 .11846 .54624 .11701 Metetra
.664 .741 .907 r
.54624 .11701 .54734 .11846 .55414 .11587 .55305 .11442 Metetra
.664 .741 .907 r
.55305 .11442 .55414 .11587 .56096 .11328 .55987 .11183 Metetra
.664 .741 .907 r
.55987 .11183 .56096 .11328 .5678 .11068 .56672 .10923 Metetra
.664 .741 .907 r
.56672 .10923 .5678 .11068 .57465 .10807 .57357 .10662 Metetra
.664 .741 .907 r
.57357 .10662 .57465 .10807 .58152 .10546 .58045 .104 Metetra
.664 .741 .907 r
.58045 .104 .58152 .10546 .58841 .10284 .58734 .10138 Metetra
.664 .741 .907 r
.58734 .10138 .58841 .10284 .59532 .10022 .59425 .09875 Metetra
.664 .741 .907 r
.59425 .09875 .59532 .10022 .60224 .09758 .60117 .09611 Metetra
.664 .741 .907 r
.60117 .09611 .60224 .09758 .60918 .09495 .60812 .09347 Metetra
.664 .741 .907 r
.60812 .09347 .60918 .09495 .61614 .0923 .61508 .09082 Metetra
.664 .741 .907 r
.61508 .09082 .61614 .0923 .62311 .08965 .62206 .08817 Metetra
.664 .741 .907 r
.62206 .08817 .62311 .08965 .6301 .08699 .62905 .08551 Metetra
.664 .741 .907 r
.62905 .08551 .6301 .08699 .63711 .08433 .63607 .08284 Metetra
.664 .741 .907 r
.63607 .08284 .63711 .08433 .64414 .08166 .6431 .08016 Metetra
.955 .616 .237 r
.6431 .08016 .64414 .08166 .65417 .14763 .65345 .1539 Metetra
.769 .415 .385 r
.65345 .1539 .65417 .14763 .66345 .1893 .66199 .17939 Metetra
.927 .633 .467 r
.66199 .17939 .66345 .1893 .66533 .0736 .66429 .0721 Metetra
.664 .741 .907 r
.66429 .0721 .66533 .0736 .67243 .0709 .6714 .0694 Metetra
.664 .741 .907 r
.6714 .0694 .67243 .0709 .67954 .0682 .67852 .06669 Metetra
.664 .741 .907 r
.67852 .06669 .67954 .0682 .68668 .06549 .68565 .06397 Metetra
.664 .741 .907 r
.68565 .06397 .68668 .06549 .69383 .06277 .69281 .06125 Metetra
.664 .741 .907 r
.69281 .06125 .69383 .06277 .701 .06004 .69998 .05852 Metetra
.664 .741 .907 r
.69998 .05852 .701 .06004 .70819 .05731 .70717 .05578 Metetra
.664 .741 .907 r
.70717 .05578 .70819 .05731 .71539 .05457 .71438 .05304 Metetra
.664 .741 .907 r
.71438 .05304 .71539 .05457 .72262 .05182 .72161 .05029 Metetra
.664 .741 .907 r
.07814 .29341 .07944 .29462 .08514 .29245 .08385 .29124 Metetra
.664 .741 .907 r
.08385 .29124 .08514 .29245 .09086 .29028 .08957 .28906 Metetra
.664 .741 .907 r
.08957 .28906 .09086 .29028 .09659 .2881 .0953 .28688 Metetra
.664 .741 .907 r
.0953 .28688 .09659 .2881 .10233 .28591 .10105 .28469 Metetra
.664 .741 .907 r
.10105 .28469 .10233 .28591 .10809 .28372 .10681 .2825 Metetra
.664 .741 .907 r
.10681 .2825 .10809 .28372 .11386 .28153 .11258 .2803 Metetra
.664 .741 .907 r
.11258 .2803 .11386 .28153 .11964 .27933 .11836 .2781 Metetra
.664 .741 .907 r
.11836 .2781 .11964 .27933 .12544 .27712 .12416 .27589 Metetra
.664 .741 .907 r
.12416 .27589 .12544 .27712 .13125 .27491 .12997 .27368 Metetra
.664 .741 .907 r
.12997 .27368 .13125 .27491 .13707 .2727 .13579 .27146 Metetra
.664 .741 .907 r
.13579 .27146 .13707 .2727 .1429 .27048 .14163 .26924 Metetra
.664 .741 .907 r
.14163 .26924 .1429 .27048 .14875 .26825 .14748 .26701 Metetra
.664 .741 .907 r
.14748 .26701 .14875 .26825 .15461 .26602 .15335 .26478 Metetra
.664 .741 .907 r
.15335 .26478 .15461 .26602 .16049 .26379 .15922 .26254 Metetra
.162 .508 .912 r
.15922 .26254 .16049 .26379 .16638 .26155 .16465 .26425 Metetra
.16465 .26425 .16638 .26155 .17228 .2593 .17102 .25805 Metetra
.664 .741 .907 r
.17102 .25805 .17228 .2593 .1782 .25705 .17694 .25579 Metetra
.664 .741 .907 r
.17694 .25579 .1782 .25705 .18413 .25479 .18287 .25353 Metetra
.664 .741 .907 r
.18287 .25353 .18413 .25479 .19007 .25253 .18882 .25127 Metetra
.664 .741 .907 r
.18882 .25127 .19007 .25253 .19602 .25027 .19477 .249 Metetra
.664 .741 .907 r
.19477 .249 .19602 .25027 .202 .24799 .20075 .24673 Metetra
.664 .741 .907 r
.20075 .24673 .202 .24799 .20798 .24572 .20673 .24445 Metetra
.664 .741 .907 r
.20673 .24445 .20798 .24572 .21398 .24344 .21274 .24216 Metetra
.664 .741 .907 r
.21274 .24216 .21398 .24344 .21999 .24115 .21875 .23987 Metetra
.664 .741 .907 r
.21875 .23987 .21999 .24115 .22602 .23886 .22478 .23757 Metetra
.664 .741 .907 r
.22478 .23757 .22602 .23886 .23206 .23656 .23082 .23527 Metetra
.664 .741 .907 r
.23082 .23527 .23206 .23656 .23811 .23425 .23688 .23297 Metetra
.664 .741 .907 r
.23688 .23297 .23811 .23425 .24418 .23194 .24295 .23065 Metetra
.664 .741 .907 r
.24295 .23065 .24418 .23194 .25026 .22963 .24903 .22834 Metetra
.664 .741 .907 r
.24903 .22834 .25026 .22963 .25636 .22731 .25513 .22601 Metetra
.664 .741 .907 r
.25513 .22601 .25636 .22731 .26247 .22499 .26125 .22369 Metetra
.664 .741 .907 r
.26125 .22369 .26247 .22499 .26859 .22266 .26737 .22135 Metetra
.664 .741 .907 r
.26737 .22135 .26859 .22266 .27473 .22032 .27352 .21901 Metetra
.664 .741 .907 r
.27352 .21901 .27473 .22032 .28089 .21798 .27967 .21667 Metetra
.664 .741 .907 r
.27967 .21667 .28089 .21798 .28706 .21563 .28584 .21432 Metetra
.664 .741 .907 r
.28584 .21432 .28706 .21563 .29324 .21328 .29203 .21196 Metetra
.664 .741 .907 r
.29203 .21196 .29324 .21328 .29944 .21092 .29823 .2096 Metetra
.664 .741 .907 r
.29823 .2096 .29944 .21092 .30565 .20856 .30444 .20724 Metetra
.664 .741 .907 r
.30444 .20724 .30565 .20856 .31187 .20619 .31067 .20486 Metetra
.961 .679 .453 r
.31067 .20486 .31187 .20619 .30192 .4409 .30061 .43963 Metetra
.96 .697 .492 r
.30061 .43963 .30192 .4409 .3197 .27185 .32077 .23613 Metetra
.637 .394 .534 r
.32077 .23613 .3197 .27185 .33064 .19905 .32945 .19771 Metetra
.664 .741 .907 r
.32945 .19771 .33064 .19905 .33693 .19666 .33574 .19532 Metetra
.664 .741 .907 r
.33574 .19532 .33693 .19666 .34323 .19426 .34204 .19292 Metetra
.664 .741 .907 r
.34204 .19292 .34323 .19426 .34954 .19186 .34836 .19051 Metetra
.664 .741 .907 r
.34836 .19051 .34954 .19186 .35587 .18945 .35469 .1881 Metetra
.664 .741 .907 r
.35469 .1881 .35587 .18945 .36222 .18703 .36104 .18568 Metetra
.664 .741 .907 r
.36104 .18568 .36222 .18703 .36858 .18461 .3674 .18326 Metetra
.664 .741 .907 r
.3674 .18326 .36858 .18461 .37496 .18219 .37378 .18083 Metetra
.664 .741 .907 r
.37378 .18083 .37496 .18219 .38135 .17975 .38018 .1784 Metetra
.664 .741 .907 r
.38018 .1784 .38135 .17975 .38775 .17732 .38659 .17595 Metetra
.664 .741 .907 r
.38659 .17595 .38775 .17732 .39418 .17487 .39301 .17351 Metetra
.664 .741 .907 r
.39301 .17351 .39418 .17487 .40061 .17242 .39945 .17106 Metetra
.664 .741 .907 r
.39945 .17106 .40061 .17242 .40707 .16997 .40591 .1686 Metetra
.664 .741 .907 r
.40591 .1686 .40707 .16997 .41353 .16751 .41238 .16613 Metetra
.664 .741 .907 r
.41238 .16613 .41353 .16751 .42002 .16504 .41886 .16366 Metetra
.664 .741 .907 r
.41886 .16366 .42002 .16504 .42652 .16257 .42537 .16119 Metetra
.664 .741 .907 r
.42537 .16119 .42652 .16257 .43303 .16009 .43188 .1587 Metetra
.664 .741 .907 r
.43188 .1587 .43303 .16009 .43956 .1576 .43842 .15622 Metetra
.664 .741 .907 r
.43842 .15622 .43956 .1576 .44611 .15511 .44497 .15372 Metetra
.664 .741 .907 r
.44497 .15372 .44611 .15511 .45267 .15262 .45153 .15122 Metetra
.664 .741 .907 r
.45153 .15122 .45267 .15262 .45925 .15011 .45811 .14872 Metetra
.664 .741 .907 r
.45811 .14872 .45925 .15011 .46584 .1476 .46471 .1462 Metetra
.664 .741 .907 r
.46471 .1462 .46584 .1476 .47245 .14509 .47133 .14368 Metetra
.664 .741 .907 r
.47133 .14368 .47245 .14509 .479 .14764 .47795 .14116 Metetra
.572 .415 .629 r
.47795 .14116 .479 .14764 .48572 .14004 .4846 .13863 Metetra
.664 .741 .907 r
.4846 .13863 .48572 .14004 .49238 .13751 .49126 .13609 Metetra
.664 .741 .907 r
.49126 .13609 .49238 .13751 .49906 .13497 .49794 .13355 Metetra
.664 .741 .907 r
.49794 .13355 .49906 .13497 .50575 .13242 .50464 .131 Metetra
.664 .741 .907 r
.50464 .131 .50575 .13242 .51246 .12987 .51135 .12844 Metetra
.664 .741 .907 r
.51135 .12844 .51246 .12987 .51918 .12731 .51807 .12588 Metetra
.664 .741 .907 r
.51807 .12588 .51918 .12731 .52592 .12475 .52482 .12331 Metetra
.664 .741 .907 r
.52482 .12331 .52592 .12475 .53268 .12218 .53158 .12074 Metetra
.664 .741 .907 r
.53158 .12074 .53268 .12218 .53945 .1196 .53835 .11816 Metetra
.664 .741 .907 r
.53835 .11816 .53945 .1196 .54624 .11701 .54515 .11557 Metetra
.664 .741 .907 r
.54515 .11557 .54624 .11701 .55305 .11442 .55196 .11298 Metetra
.664 .741 .907 r
.55196 .11298 .55305 .11442 .55987 .11183 .55879 .11038 Metetra
.664 .741 .907 r
.55879 .11038 .55987 .11183 .56672 .10923 .56563 .10777 Metetra
.664 .741 .907 r
.56563 .10777 .56672 .10923 .57357 .10662 .57249 .10516 Metetra
.664 .741 .907 r
.57249 .10516 .57357 .10662 .58045 .104 .57937 .10254 Metetra
.664 .741 .907 r
.57937 .10254 .58045 .104 .58734 .10138 .58627 .09991 Metetra
.664 .741 .907 r
.58627 .09991 .58734 .10138 .59425 .09875 .59318 .09728 Metetra
.664 .741 .907 r
.59318 .09728 .59425 .09875 .60117 .09611 .60011 .09464 Metetra
.664 .741 .907 r
.60011 .09464 .60117 .09611 .60812 .09347 .60705 .092 Metetra
.664 .741 .907 r
.60705 .092 .60812 .09347 .61508 .09082 .61402 .08934 Metetra
.664 .741 .907 r
.61402 .08934 .61508 .09082 .62206 .08817 .621 .08669 Metetra
.664 .741 .907 r
.621 .08669 .62206 .08817 .62905 .08551 .628 .08402 Metetra
.664 .741 .907 r
.628 .08402 .62905 .08551 .63607 .08284 .63502 .08135 Metetra
.664 .741 .907 r
.63502 .08135 .63607 .08284 .6431 .08016 .64205 .07867 Metetra
.94 .584 .182 r
.64205 .07867 .6431 .08016 .65345 .1539 .65134 .12811 Metetra
.108 .014 .455 r
.65134 .12811 .65345 .1539 .66199 .17939 .66141 .18886 Metetra
.909 .698 .196 r
.66141 .18886 .66199 .17939 .66429 .0721 .66326 .07059 Metetra
.664 .741 .907 r
.66326 .07059 .66429 .0721 .6714 .0694 .67037 .06789 Metetra
.664 .741 .907 r
.67037 .06789 .6714 .0694 .67852 .06669 .67749 .06517 Metetra
.664 .741 .907 r
.67749 .06517 .67852 .06669 .68565 .06397 .68463 .06245 Metetra
.664 .741 .907 r
.68463 .06245 .68565 .06397 .69281 .06125 .69179 .05973 Metetra
.664 .741 .907 r
.69179 .05973 .69281 .06125 .69998 .05852 .69897 .05699 Metetra
.664 .741 .907 r
.69897 .05699 .69998 .05852 .70717 .05578 .70616 .05425 Metetra
.664 .741 .907 r
.70616 .05425 .70717 .05578 .71438 .05304 .71338 .05151 Metetra
.664 .741 .907 r
.71338 .05151 .71438 .05304 .72161 .05029 .72061 .04875 Metetra
.664 .741 .907 r
.07685 .2922 .07814 .29341 .08385 .29124 .08256 .29003 Metetra
.664 .741 .907 r
.08256 .29003 .08385 .29124 .08957 .28906 .08828 .28785 Metetra
.664 .741 .907 r
.08828 .28785 .08957 .28906 .0953 .28688 .09401 .28566 Metetra
.664 .741 .907 r
.09401 .28566 .0953 .28688 .10105 .28469 .09976 .28347 Metetra
.664 .741 .907 r
.09976 .28347 .10105 .28469 .10681 .2825 .10552 .28127 Metetra
.664 .741 .907 r
.10552 .28127 .10681 .2825 .11258 .2803 .11129 .27907 Metetra
.664 .741 .907 r
.11129 .27907 .11258 .2803 .11836 .2781 .11708 .27687 Metetra
.664 .741 .907 r
.11708 .27687 .11836 .2781 .12416 .27589 .12288 .27466 Metetra
.664 .741 .907 r
.12288 .27466 .12416 .27589 .12997 .27368 .12869 .27244 Metetra
.664 .741 .907 r
.12869 .27244 .12997 .27368 .13579 .27146 .13452 .27022 Metetra
.664 .741 .907 r
.13452 .27022 .13579 .27146 .14163 .26924 .14036 .268 Metetra
.664 .741 .907 r
.14036 .268 .14163 .26924 .14748 .26701 .14621 .26576 Metetra
.664 .741 .907 r
.14621 .26576 .14748 .26701 .15335 .26478 .15208 .26353 Metetra
.664 .741 .907 r
.15208 .26353 .15335 .26478 .15922 .26254 .15796 .26129 Metetra
.664 .741 .907 r
.15796 .26129 .15922 .26254 .16465 .26425 .16385 .25904 Metetra
.582 .439 .652 r
.16385 .25904 .16465 .26425 .17102 .25805 .16976 .25679 Metetra
.664 .741 .907 r
.16976 .25679 .17102 .25805 .17694 .25579 .17568 .25453 Metetra
.664 .741 .907 r
.17568 .25453 .17694 .25579 .18287 .25353 .18161 .25227 Metetra
.664 .741 .907 r
.18161 .25227 .18287 .25353 .18882 .25127 .18756 .25 Metetra
.664 .741 .907 r
.18756 .25 .18882 .25127 .19477 .249 .19352 .24773 Metetra
.664 .741 .907 r
.19352 .24773 .19477 .249 .20075 .24673 .1995 .24545 Metetra
.664 .741 .907 r
.1995 .24545 .20075 .24673 .20673 .24445 .20549 .24317 Metetra
.664 .741 .907 r
.20549 .24317 .20673 .24445 .21274 .24216 .21149 .24088 Metetra
.664 .741 .907 r
.21149 .24088 .21274 .24216 .21875 .23987 .21751 .23859 Metetra
.664 .741 .907 r
.21751 .23859 .21875 .23987 .22478 .23757 .22354 .23629 Metetra
.664 .741 .907 r
.22354 .23629 .22478 .23757 .23082 .23527 .22958 .23399 Metetra
.664 .741 .907 r
.22958 .23399 .23082 .23527 .23688 .23297 .23564 .23168 Metetra
.664 .741 .907 r
.23564 .23168 .23688 .23297 .24295 .23065 .24172 .22936 Metetra
.664 .741 .907 r
.24172 .22936 .24295 .23065 .24903 .22834 .2478 .22704 Metetra
.664 .741 .907 r
.2478 .22704 .24903 .22834 .25513 .22601 .2539 .22472 Metetra
.664 .741 .907 r
.2539 .22472 .25513 .22601 .26125 .22369 .26002 .22239 Metetra
.664 .741 .907 r
.26002 .22239 .26125 .22369 .26737 .22135 .26615 .22005 Metetra
.664 .741 .907 r
.26615 .22005 .26737 .22135 .27352 .21901 .2723 .21771 Metetra
.664 .741 .907 r
.2723 .21771 .27352 .21901 .27967 .21667 .27845 .21536 Metetra
.664 .741 .907 r
.27845 .21536 .27967 .21667 .28584 .21432 .28463 .21301 Metetra
.664 .741 .907 r
.28463 .21301 .28584 .21432 .29203 .21196 .29082 .21065 Metetra
.664 .741 .907 r
.29082 .21065 .29203 .21196 .29823 .2096 .29702 .20828 Metetra
.664 .741 .907 r
.29702 .20828 .29823 .2096 .30444 .20724 .30324 .20591 Metetra
.664 .741 .907 r
.30324 .20591 .30444 .20724 .31067 .20486 .30947 .20354 Metetra
.961 .679 .453 r
.30947 .20354 .31067 .20486 .30061 .43963 .2993 .43837 Metetra
.96 .696 .49 r
.2993 .43837 .30061 .43963 .32077 .23613 .32105 .21263 Metetra
.599 .371 .541 r
.32105 .21263 .32077 .23613 .32945 .19771 .32825 .19638 Metetra
.664 .741 .907 r
.32825 .19638 .32945 .19771 .33574 .19532 .33454 .19398 Metetra
.664 .741 .907 r
.33454 .19398 .33574 .19532 .34204 .19292 .34085 .19158 Metetra
.664 .741 .907 r
.34085 .19158 .34204 .19292 .34836 .19051 .34717 .18917 Metetra
.664 .741 .907 r
.34717 .18917 .34836 .19051 .35469 .1881 .35351 .18675 Metetra
.664 .741 .907 r
.35351 .18675 .35469 .1881 .36104 .18568 .35986 .18433 Metetra
.664 .741 .907 r
.35986 .18433 .36104 .18568 .3674 .18326 .36622 .18191 Metetra
.664 .741 .907 r
.36622 .18191 .3674 .18326 .37378 .18083 .37261 .17947 Metetra
.664 .741 .907 r
.37261 .17947 .37378 .18083 .38018 .1784 .379 .17703 Metetra
.664 .741 .907 r
.379 .17703 .38018 .1784 .38659 .17595 .38542 .17459 Metetra
.664 .741 .907 r
.38542 .17459 .38659 .17595 .39301 .17351 .39184 .17214 Metetra
.664 .741 .907 r
.39184 .17214 .39301 .17351 .39945 .17106 .39829 .16969 Metetra
.664 .741 .907 r
.39829 .16969 .39945 .17106 .40591 .1686 .40474 .16722 Metetra
.664 .741 .907 r
.40474 .16722 .40591 .1686 .41238 .16613 .41122 .16476 Metetra
.664 .741 .907 r
.41122 .16476 .41238 .16613 .41886 .16366 .41771 .16228 Metetra
.664 .741 .907 r
.41771 .16228 .41886 .16366 .42537 .16119 .42421 .1598 Metetra
.664 .741 .907 r
.42421 .1598 .42537 .16119 .43188 .1587 .43073 .15732 Metetra
.664 .741 .907 r
.43073 .15732 .43188 .1587 .43842 .15622 .43727 .15483 Metetra
.664 .741 .907 r
.43727 .15483 .43842 .15622 .44497 .15372 .44382 .15233 Metetra
.664 .741 .907 r
.44382 .15233 .44497 .15372 .45153 .15122 .45039 .14982 Metetra
.664 .741 .907 r
.45039 .14982 .45153 .15122 .45811 .14872 .45698 .14731 Metetra
.664 .741 .907 r
.45698 .14731 .45811 .14872 .46471 .1462 .46358 .1448 Metetra
.664 .741 .907 r
.46358 .1448 .46471 .1462 .47133 .14368 .47019 .14228 Metetra
.664 .741 .907 r
.47019 .14228 .47133 .14368 .47795 .14116 .47683 .13975 Metetra
.664 .741 .907 r
.47683 .13975 .47795 .14116 .4846 .13863 .48348 .13721 Metetra
.664 .741 .907 r
.48348 .13721 .4846 .13863 .49126 .13609 .49014 .13467 Metetra
.664 .741 .907 r
.49014 .13467 .49126 .13609 .49794 .13355 .49682 .13213 Metetra
.664 .741 .907 r
.49682 .13213 .49794 .13355 .50464 .131 .50352 .12957 Metetra
.664 .741 .907 r
.50352 .12957 .50464 .131 .51135 .12844 .51023 .12702 Metetra
.664 .741 .907 r
.51023 .12702 .51135 .12844 .51807 .12588 .51696 .12445 Metetra
.664 .741 .907 r
.51696 .12445 .51807 .12588 .52482 .12331 .52371 .12188 Metetra
.664 .741 .907 r
.52371 .12188 .52482 .12331 .53158 .12074 .53048 .1193 Metetra
.664 .741 .907 r
.53048 .1193 .53158 .12074 .53835 .11816 .53726 .11672 Metetra
.664 .741 .907 r
.53726 .11672 .53835 .11816 .54515 .11557 .54405 .11413 Metetra
.664 .741 .907 r
.54405 .11413 .54515 .11557 .55196 .11298 .55087 .11153 Metetra
.664 .741 .907 r
.55087 .11153 .55196 .11298 .55879 .11038 .5577 .10892 Metetra
.664 .741 .907 r
.5577 .10892 .55879 .11038 .56563 .10777 .56455 .10631 Metetra
.664 .741 .907 r
.56455 .10631 .56563 .10777 .57249 .10516 .57141 .1037 Metetra
.664 .741 .907 r
.57141 .1037 .57249 .10516 .57937 .10254 .57829 .10108 Metetra
.664 .741 .907 r
.57829 .10108 .57937 .10254 .58627 .09991 .58519 .09845 Metetra
.664 .741 .907 r
.58519 .09845 .58627 .09991 .59318 .09728 .59211 .09581 Metetra
.664 .741 .907 r
.59211 .09581 .59318 .09728 .60011 .09464 .59904 .09317 Metetra
.664 .741 .907 r
.59904 .09317 .60011 .09464 .60705 .092 .60599 .09052 Metetra
.664 .741 .907 r
.60599 .09052 .60705 .092 .61402 .08934 .61296 .08786 Metetra
.664 .741 .907 r
.61296 .08786 .61402 .08934 .621 .08669 .61994 .0852 Metetra
.664 .741 .907 r
.61994 .0852 .621 .08669 .628 .08402 .62695 .08253 Metetra
.664 .741 .907 r
.62695 .08253 .628 .08402 .63502 .08135 .63397 .07985 Metetra
.664 .741 .907 r
.63397 .07985 .63502 .08135 .64205 .07867 .641 .07717 Metetra
.878 .484 .024 r
.641 .07717 .64205 .07867 .65134 .12811 .64928 .10324 Metetra
0 0 .319 r
.64928 .10324 .65134 .12811 .66141 .18886 .66124 .20746 Metetra
.73 .595 .023 r
.66124 .20746 .66141 .18886 .66326 .07059 .66222 .06908 Metetra
.664 .741 .907 r
.66222 .06908 .66326 .07059 .67037 .06789 .66933 .06637 Metetra
.664 .741 .907 r
.66933 .06637 .67037 .06789 .67749 .06517 .67646 .06366 Metetra
.664 .741 .907 r
.67646 .06366 .67749 .06517 .68463 .06245 .6836 .06093 Metetra
.664 .741 .907 r
.6836 .06093 .68463 .06245 .69179 .05973 .69077 .0582 Metetra
.664 .741 .907 r
.69077 .0582 .69179 .05973 .69897 .05699 .69795 .05547 Metetra
.664 .741 .907 r
.69795 .05547 .69897 .05699 .70616 .05425 .70515 .05272 Metetra
.664 .741 .907 r
.70515 .05272 .70616 .05425 .71338 .05151 .71237 .04997 Metetra
.664 .741 .907 r
.71237 .04997 .71338 .05151 .72061 .04875 .7196 .04721 Metetra
.664 .741 .907 r
.07555 .29099 .07685 .2922 .08256 .29003 .08126 .28881 Metetra
.664 .741 .907 r
.08126 .28881 .08256 .29003 .08828 .28785 .08698 .28663 Metetra
.664 .741 .907 r
.08698 .28663 .08828 .28785 .09401 .28566 .09272 .28444 Metetra
.664 .741 .907 r
.09272 .28444 .09401 .28566 .09976 .28347 .09847 .28225 Metetra
.664 .741 .907 r
.09847 .28225 .09976 .28347 .10552 .28127 .10423 .28005 Metetra
.664 .741 .907 r
.10423 .28005 .10552 .28127 .11129 .27907 .11001 .27784 Metetra
.664 .741 .907 r
.11001 .27784 .11129 .27907 .11708 .27687 .1158 .27564 Metetra
.664 .741 .907 r
.1158 .27564 .11708 .27687 .12288 .27466 .1216 .27342 Metetra
.664 .741 .907 r
.1216 .27342 .12288 .27466 .12869 .27244 .12741 .2712 Metetra
.664 .741 .907 r
.12741 .2712 .12869 .27244 .13452 .27022 .13324 .26898 Metetra
.664 .741 .907 r
.13324 .26898 .13452 .27022 .14036 .268 .13908 .26675 Metetra
.664 .741 .907 r
.13908 .26675 .14036 .268 .14621 .26576 .14494 .26452 Metetra
.664 .741 .907 r
.14494 .26452 .14621 .26576 .15208 .26353 .15081 .26228 Metetra
.664 .741 .907 r
.15081 .26228 .15208 .26353 .15796 .26129 .15669 .26004 Metetra
.664 .741 .907 r
.15669 .26004 .15796 .26129 .16385 .25904 .16259 .25779 Metetra
.664 .741 .907 r
.16259 .25779 .16385 .25904 .16976 .25679 .1685 .25553 Metetra
.664 .741 .907 r
.1685 .25553 .16976 .25679 .17568 .25453 .17442 .25327 Metetra
.664 .741 .907 r
.17442 .25327 .17568 .25453 .18161 .25227 .18035 .25101 Metetra
.664 .741 .907 r
.18035 .25101 .18161 .25227 .18756 .25 .18631 .24874 Metetra
.664 .741 .907 r
.18631 .24874 .18756 .25 .19352 .24773 .19227 .24646 Metetra
.664 .741 .907 r
.19227 .24646 .19352 .24773 .1995 .24545 .19825 .24418 Metetra
.664 .741 .907 r
.19825 .24418 .1995 .24545 .20549 .24317 .20424 .2419 Metetra
.664 .741 .907 r
.20424 .2419 .20549 .24317 .21149 .24088 .21024 .2396 Metetra
.664 .741 .907 r
.21024 .2396 .21149 .24088 .21751 .23859 .21626 .23731 Metetra
.664 .741 .907 r
.21626 .23731 .21751 .23859 .22354 .23629 .2223 .23501 Metetra
.664 .741 .907 r
.2223 .23501 .22354 .23629 .22958 .23399 .22834 .2327 Metetra
.664 .741 .907 r
.22834 .2327 .22958 .23399 .23564 .23168 .23441 .23039 Metetra
.664 .741 .907 r
.23441 .23039 .23564 .23168 .24172 .22936 .24048 .22807 Metetra
.664 .741 .907 r
.24048 .22807 .24172 .22936 .2478 .22704 .24657 .22575 Metetra
.664 .741 .907 r
.24657 .22575 .2478 .22704 .2539 .22472 .25268 .22342 Metetra
.664 .741 .907 r
.25268 .22342 .2539 .22472 .26002 .22239 .25879 .22108 Metetra
.664 .741 .907 r
.25879 .22108 .26002 .22239 .26615 .22005 .26493 .21874 Metetra
.664 .741 .907 r
.26493 .21874 .26615 .22005 .2723 .21771 .27107 .2164 Metetra
.664 .741 .907 r
.27107 .2164 .2723 .21771 .27845 .21536 .27724 .21405 Metetra
.664 .741 .907 r
.27724 .21405 .27845 .21536 .28463 .21301 .28341 .21169 Metetra
.664 .741 .907 r
.28341 .21169 .28463 .21301 .29082 .21065 .2896 .20933 Metetra
.664 .741 .907 r
.2896 .20933 .29082 .21065 .29702 .20828 .29581 .20696 Metetra
.664 .741 .907 r
.29581 .20696 .29702 .20828 .30324 .20591 .30203 .20459 Metetra
.664 .741 .907 r
.30203 .20459 .30324 .20591 .30947 .20354 .30826 .20221 Metetra
.961 .679 .453 r
.30826 .20221 .30947 .20354 .2993 .43837 .298 .4371 Metetra
.96 .697 .491 r
.298 .4371 .2993 .43837 .32105 .21263 .31908 .22258 Metetra
0 0 .143 r
.31908 .22258 .32105 .21263 .32825 .19638 .32706 .19504 Metetra
.664 .741 .907 r
.32706 .19504 .32825 .19638 .33454 .19398 .33335 .19264 Metetra
.664 .741 .907 r
.33335 .19264 .33454 .19398 .34085 .19158 .33966 .19023 Metetra
.664 .741 .907 r
.33966 .19023 .34085 .19158 .34717 .18917 .34598 .18782 Metetra
.664 .741 .907 r
.34598 .18782 .34717 .18917 .35351 .18675 .35232 .1854 Metetra
.664 .741 .907 r
.35232 .1854 .35351 .18675 .35986 .18433 .35867 .18298 Metetra
.664 .741 .907 r
.35867 .18298 .35986 .18433 .36622 .18191 .36504 .18055 Metetra
.664 .741 .907 r
.36504 .18055 .36622 .18191 .37261 .17947 .37143 .17811 Metetra
.664 .741 .907 r
.37143 .17811 .37261 .17947 .379 .17703 .37783 .17567 Metetra
.664 .741 .907 r
.37783 .17567 .379 .17703 .38542 .17459 .38424 .17323 Metetra
.664 .741 .907 r
.38424 .17323 .38542 .17459 .39184 .17214 .39067 .17077 Metetra
.664 .741 .907 r
.39067 .17077 .39184 .17214 .39829 .16969 .39712 .16831 Metetra
.664 .741 .907 r
.39712 .16831 .39829 .16969 .40474 .16722 .40358 .16585 Metetra
.664 .741 .907 r
.40358 .16585 .40474 .16722 .41122 .16476 .41006 .16338 Metetra
.664 .741 .907 r
.41006 .16338 .41122 .16476 .41771 .16228 .41655 .1609 Metetra
.664 .741 .907 r
.41655 .1609 .41771 .16228 .42421 .1598 .42306 .15842 Metetra
.664 .741 .907 r
.42306 .15842 .42421 .1598 .43073 .15732 .42958 .15593 Metetra
.664 .741 .907 r
.42958 .15593 .43073 .15732 .43727 .15483 .43612 .15343 Metetra
.664 .741 .907 r
.43612 .15343 .43727 .15483 .44382 .15233 .44268 .15093 Metetra
.664 .741 .907 r
.44268 .15093 .44382 .15233 .45039 .14982 .44925 .14843 Metetra
.664 .741 .907 r
.44925 .14843 .45039 .14982 .45698 .14731 .45584 .14591 Metetra
.664 .741 .907 r
.45584 .14591 .45698 .14731 .46358 .1448 .46244 .14339 Metetra
.664 .741 .907 r
.46244 .14339 .46358 .1448 .47019 .14228 .46906 .14087 Metetra
.664 .741 .907 r
.46906 .14087 .47019 .14228 .47683 .13975 .4757 .13834 Metetra
.664 .741 .907 r
.4757 .13834 .47683 .13975 .48348 .13721 .48235 .1358 Metetra
.664 .741 .907 r
.48235 .1358 .48348 .13721 .49014 .13467 .48902 .13325 Metetra
.664 .741 .907 r
.48902 .13325 .49014 .13467 .49682 .13213 .4957 .1307 Metetra
.664 .741 .907 r
.4957 .1307 .49682 .13213 .50352 .12957 .5024 .12815 Metetra
.664 .741 .907 r
.5024 .12815 .50352 .12957 .51023 .12702 .50912 .12559 Metetra
.664 .741 .907 r
.50912 .12559 .51023 .12702 .51696 .12445 .51585 .12302 Metetra
.664 .741 .907 r
.51585 .12302 .51696 .12445 .52371 .12188 .5226 .12044 Metetra
.664 .741 .907 r
.5226 .12044 .52371 .12188 .53048 .1193 .52937 .11786 Metetra
.664 .741 .907 r
.52937 .11786 .53048 .1193 .53726 .11672 .53615 .11527 Metetra
.664 .741 .907 r
.53615 .11527 .53726 .11672 .54405 .11413 .54296 .11268 Metetra
.664 .741 .907 r
.54296 .11268 .54405 .11413 .55087 .11153 .54977 .11008 Metetra
.664 .741 .907 r
.54977 .11008 .55087 .11153 .5577 .10892 .55661 .10747 Metetra
.664 .741 .907 r
.55661 .10747 .5577 .10892 .56455 .10631 .56346 .10486 Metetra
.664 .741 .907 r
.56346 .10486 .56455 .10631 .57141 .1037 .57033 .10224 Metetra
.664 .741 .907 r
.57033 .10224 .57141 .1037 .57829 .10108 .57721 .09961 Metetra
.664 .741 .907 r
.57721 .09961 .57829 .10108 .58519 .09845 .58411 .09698 Metetra
.664 .741 .907 r
.58411 .09698 .58519 .09845 .59211 .09581 .59103 .09434 Metetra
.664 .741 .907 r
.59103 .09434 .59211 .09581 .59904 .09317 .59797 .09169 Metetra
.664 .741 .907 r
.59797 .09169 .59904 .09317 .60599 .09052 .60492 .08904 Metetra
.664 .741 .907 r
.60492 .08904 .60599 .09052 .61296 .08786 .61189 .08638 Metetra
.664 .741 .907 r
.61189 .08638 .61296 .08786 .61994 .0852 .61888 .08371 Metetra
.664 .741 .907 r
.61888 .08371 .61994 .0852 .62695 .08253 .62589 .08104 Metetra
.664 .741 .907 r
.62589 .08104 .62695 .08253 .63397 .07985 .63291 .07836 Metetra
.664 .741 .907 r
.63291 .07836 .63397 .07985 .641 .07717 .63995 .07567 Metetra
.919 .547 .121 r
.63995 .07567 .641 .07717 .64928 .10324 .64867 .11226 Metetra
.795 .456 .414 r
.64867 .11226 .64928 .10324 .66124 .20746 .65781 .15346 Metetra
.676 .41 .512 r
.65781 .15346 .66124 .20746 .66222 .06908 .66119 .06757 Metetra
.664 .741 .907 r
.66119 .06757 .66222 .06908 .66933 .06637 .6683 .06486 Metetra
.664 .741 .907 r
.6683 .06486 .66933 .06637 .67646 .06366 .67543 .06214 Metetra
.664 .741 .907 r
.67543 .06214 .67646 .06366 .6836 .06093 .68258 .05941 Metetra
.664 .741 .907 r
.68258 .05941 .6836 .06093 .69077 .0582 .68974 .05668 Metetra
.664 .741 .907 r
.68974 .05668 .69077 .0582 .69795 .05547 .69693 .05394 Metetra
.664 .741 .907 r
.69693 .05394 .69795 .05547 .70515 .05272 .70413 .05119 Metetra
.664 .741 .907 r
.70413 .05119 .70515 .05272 .71237 .04997 .71135 .04843 Metetra
.664 .741 .907 r
.71135 .04843 .71237 .04997 .7196 .04721 .71859 .04567 Metetra
.664 .741 .907 r
.07425 .28978 .07555 .29099 .08126 .28881 .07996 .28759 Metetra
.664 .741 .907 r
.07996 .28759 .08126 .28881 .08698 .28663 .08569 .28541 Metetra
.664 .741 .907 r
.08569 .28541 .08698 .28663 .09272 .28444 .09143 .28322 Metetra
.664 .741 .907 r
.09143 .28322 .09272 .28444 .09847 .28225 .09718 .28102 Metetra
.664 .741 .907 r
.09718 .28102 .09847 .28225 .10423 .28005 .10294 .27882 Metetra
.664 .741 .907 r
.10294 .27882 .10423 .28005 .11001 .27784 .10872 .27661 Metetra
.664 .741 .907 r
.10872 .27661 .11001 .27784 .1158 .27564 .11451 .2744 Metetra
.664 .741 .907 r
.11451 .2744 .1158 .27564 .1216 .27342 .12032 .27219 Metetra
.664 .741 .907 r
.12032 .27219 .1216 .27342 .12741 .2712 .12613 .26996 Metetra
.664 .741 .907 r
.12613 .26996 .12741 .2712 .13324 .26898 .13196 .26774 Metetra
.664 .741 .907 r
.13196 .26774 .13324 .26898 .13908 .26675 .13781 .26551 Metetra
.664 .741 .907 r
.13781 .26551 .13908 .26675 .14494 .26452 .14367 .26327 Metetra
.664 .741 .907 r
.14367 .26327 .14494 .26452 .15081 .26228 .14954 .26103 Metetra
.664 .741 .907 r
.14954 .26103 .15081 .26228 .15669 .26004 .15542 .25878 Metetra
.912 .509 .171 r
.15542 .25878 .15669 .26004 .16259 .25779 .15946 .27225 Metetra
.235 0 .337 r
.15946 .27225 .16259 .25779 .1685 .25553 .16723 .25427 Metetra
.664 .741 .907 r
.16723 .25427 .1685 .25553 .17442 .25327 .17316 .25201 Metetra
.664 .741 .907 r
.17316 .25201 .17442 .25327 .18035 .25101 .17909 .24974 Metetra
.664 .741 .907 r
.17909 .24974 .18035 .25101 .18631 .24874 .18505 .24747 Metetra
.664 .741 .907 r
.18505 .24747 .18631 .24874 .19227 .24646 .19101 .24519 Metetra
.664 .741 .907 r
.19101 .24519 .19227 .24646 .19825 .24418 .19699 .24291 Metetra
.664 .741 .907 r
.19699 .24291 .19825 .24418 .20424 .2419 .20299 .24062 Metetra
.664 .741 .907 r
.20299 .24062 .20424 .2419 .21024 .2396 .209 .23832 Metetra
.664 .741 .907 r
.209 .23832 .21024 .2396 .21626 .23731 .21502 .23603 Metetra
.664 .741 .907 r
.21502 .23603 .21626 .23731 .2223 .23501 .22105 .23372 Metetra
.664 .741 .907 r
.22105 .23372 .2223 .23501 .22834 .2327 .2271 .23141 Metetra
.664 .741 .907 r
.2271 .23141 .22834 .2327 .23441 .23039 .23317 .22909 Metetra
.664 .741 .907 r
.23317 .22909 .23441 .23039 .24048 .22807 .23925 .22677 Metetra
.664 .741 .907 r
.23925 .22677 .24048 .22807 .24657 .22575 .24534 .22445 Metetra
.664 .741 .907 r
.24534 .22445 .24657 .22575 .25268 .22342 .25145 .22212 Metetra
.664 .741 .907 r
.25145 .22212 .25268 .22342 .25879 .22108 .25757 .21978 Metetra
.664 .741 .907 r
.25757 .21978 .25879 .22108 .26493 .21874 .2637 .21744 Metetra
.664 .741 .907 r
.2637 .21744 .26493 .21874 .27107 .2164 .26985 .21509 Metetra
.664 .741 .907 r
.26985 .21509 .27107 .2164 .27724 .21405 .27602 .21273 Metetra
.664 .741 .907 r
.27602 .21273 .27724 .21405 .28341 .21169 .28219 .21038 Metetra
.664 .741 .907 r
.28219 .21038 .28341 .21169 .2896 .20933 .28839 .20801 Metetra
.664 .741 .907 r
.28839 .20801 .2896 .20933 .29581 .20696 .2946 .20564 Metetra
.664 .741 .907 r
.2946 .20564 .29581 .20696 .30203 .20459 .30082 .20326 Metetra
.664 .741 .907 r
.30082 .20326 .30203 .20459 .30826 .20221 .30706 .20088 Metetra
.961 .679 .453 r
.30706 .20088 .30826 .20221 .298 .4371 .29669 .43584 Metetra
.96 .697 .492 r
.29669 .43584 .298 .4371 .31908 .22258 .31737 .22851 Metetra
.839 .792 .295 r
.31737 .22851 .31908 .22258 .32706 .19504 .32586 .1937 Metetra
.664 .741 .907 r
.32586 .1937 .32706 .19504 .33335 .19264 .33215 .1913 Metetra
.664 .741 .907 r
.33215 .1913 .33335 .19264 .33966 .19023 .33846 .18889 Metetra
.852 .416 0 r
.33846 .18889 .33966 .19023 .34598 .18782 .34389 .20158 Metetra
.26 .025 .355 r
.34389 .20158 .34598 .18782 .35232 .1854 .35113 .18405 Metetra
.664 .741 .907 r
.35113 .18405 .35232 .1854 .35867 .18298 .35749 .18162 Metetra
.664 .741 .907 r
.35749 .18162 .35867 .18298 .36504 .18055 .36386 .17919 Metetra
.664 .741 .907 r
.36386 .17919 .36504 .18055 .37143 .17811 .37025 .17675 Metetra
.664 .741 .907 r
.37025 .17675 .37143 .17811 .37783 .17567 .37665 .17431 Metetra
.664 .741 .907 r
.37665 .17431 .37783 .17567 .38424 .17323 .38307 .17186 Metetra
.664 .741 .907 r
.38307 .17186 .38424 .17323 .39067 .17077 .3895 .1694 Metetra
.664 .741 .907 r
.3895 .1694 .39067 .17077 .39712 .16831 .39595 .16694 Metetra
.664 .741 .907 r
.39595 .16694 .39712 .16831 .40358 .16585 .40242 .16447 Metetra
.664 .741 .907 r
.40242 .16447 .40358 .16585 .41006 .16338 .4089 .162 Metetra
.664 .741 .907 r
.4089 .162 .41006 .16338 .41655 .1609 .41539 .15952 Metetra
.664 .741 .907 r
.41539 .15952 .41655 .1609 .42306 .15842 .4219 .15703 Metetra
.664 .741 .907 r
.4219 .15703 .42306 .15842 .42958 .15593 .42843 .15454 Metetra
.664 .741 .907 r
.42843 .15454 .42958 .15593 .43612 .15343 .43497 .15204 Metetra
.664 .741 .907 r
.43497 .15204 .43612 .15343 .44268 .15093 .44153 .14953 Metetra
.664 .741 .907 r
.44153 .14953 .44268 .15093 .44925 .14843 .44811 .14702 Metetra
.664 .741 .907 r
.44811 .14702 .44925 .14843 .45584 .14591 .4547 .14451 Metetra
.664 .741 .907 r
.4547 .14451 .45584 .14591 .46244 .14339 .4613 .14199 Metetra
.664 .741 .907 r
.4613 .14199 .46244 .14339 .46906 .14087 .46793 .13946 Metetra
.258 .538 .921 r
.46793 .13946 .46906 .14087 .4757 .13834 .47449 .14113 Metetra
.011 0 .003 r
.47449 .14113 .4757 .13834 .48235 .1358 .48122 .13438 Metetra
.664 .741 .907 r
.48122 .13438 .48235 .1358 .48902 .13325 .48789 .13183 Metetra
.664 .741 .907 r
.48789 .13183 .48902 .13325 .4957 .1307 .49458 .12928 Metetra
.664 .741 .907 r
.49458 .12928 .4957 .1307 .5024 .12815 .50128 .12672 Metetra
.664 .741 .907 r
.50128 .12672 .5024 .12815 .50912 .12559 .508 .12415 Metetra
.664 .741 .907 r
.508 .12415 .50912 .12559 .51585 .12302 .51474 .12158 Metetra
.664 .741 .907 r
.51474 .12158 .51585 .12302 .5226 .12044 .5215 .119 Metetra
.664 .741 .907 r
.5215 .119 .5226 .12044 .52937 .11786 .52827 .11642 Metetra
.664 .741 .907 r
.52827 .11642 .52937 .11786 .53615 .11527 .53505 .11383 Metetra
.664 .741 .907 r
.53505 .11383 .53615 .11527 .54296 .11268 .54186 .11123 Metetra
.664 .741 .907 r
.54186 .11123 .54296 .11268 .54977 .11008 .54868 .10862 Metetra
.664 .741 .907 r
.54868 .10862 .54977 .11008 .55661 .10747 .55551 .10601 Metetra
.664 .741 .907 r
.55551 .10601 .55661 .10747 .56346 .10486 .56237 .1034 Metetra
.664 .741 .907 r
.56237 .1034 .56346 .10486 .57033 .10224 .56924 .10077 Metetra
.664 .741 .907 r
.56924 .10077 .57033 .10224 .57721 .09961 .57613 .09814 Metetra
.664 .741 .907 r
.57613 .09814 .57721 .09961 .58411 .09698 .58303 .0955 Metetra
.664 .741 .907 r
.58303 .0955 .58411 .09698 .59103 .09434 .58996 .09286 Metetra
.664 .741 .907 r
.58996 .09286 .59103 .09434 .59797 .09169 .5969 .09021 Metetra
.664 .741 .907 r
.5969 .09021 .59797 .09169 .60492 .08904 .60385 .08755 Metetra
.664 .741 .907 r
.60385 .08755 .60492 .08904 .61189 .08638 .61083 .08489 Metetra
.664 .741 .907 r
.61083 .08489 .61189 .08638 .61888 .08371 .61782 .08222 Metetra
.664 .741 .907 r
.61782 .08222 .61888 .08371 .62589 .08104 .62483 .07955 Metetra
.664 .741 .907 r
.62483 .07955 .62589 .08104 .63291 .07836 .63186 .07686 Metetra
.664 .741 .907 r
.63186 .07686 .63291 .07836 .63995 .07567 .6389 .07417 Metetra
.785 .364 0 r
.6389 .07417 .63995 .07567 .64867 .11226 .64681 .09162 Metetra
.439 .254 .531 r
.64681 .09162 .64867 .11226 .65781 .15346 .65454 .10244 Metetra
.593 .348 .515 r
.65454 .10244 .65781 .15346 .66119 .06757 .66015 .06606 Metetra
.664 .741 .907 r
.66015 .06606 .66119 .06757 .6683 .06486 .66726 .06334 Metetra
.664 .741 .907 r
.66726 .06334 .6683 .06486 .67543 .06214 .6744 .06062 Metetra
.664 .741 .907 r
.6744 .06062 .67543 .06214 .68258 .05941 .68155 .05789 Metetra
.664 .741 .907 r
.68155 .05789 .68258 .05941 .68974 .05668 .68872 .05515 Metetra
.664 .741 .907 r
.68872 .05515 .68974 .05668 .69693 .05394 .69591 .05241 Metetra
.664 .741 .907 r
.69591 .05241 .69693 .05394 .70413 .05119 .70312 .04965 Metetra
.664 .741 .907 r
.70312 .04965 .70413 .05119 .71135 .04843 .71034 .04689 Metetra
.664 .741 .907 r
.71034 .04689 .71135 .04843 .71859 .04567 .71759 .04413 Metetra
.664 .741 .907 r
.07295 .28856 .07425 .28978 .07996 .28759 .07866 .28638 Metetra
.664 .741 .907 r
.07866 .28638 .07996 .28759 .08569 .28541 .08439 .28419 Metetra
.664 .741 .907 r
.08439 .28419 .08569 .28541 .09143 .28322 .09013 .28199 Metetra
.664 .741 .907 r
.09013 .28199 .09143 .28322 .09718 .28102 .09588 .27979 Metetra
.664 .741 .907 r
.09588 .27979 .09718 .28102 .10294 .27882 .10165 .27759 Metetra
.664 .741 .907 r
.10165 .27759 .10294 .27882 .10872 .27661 .10743 .27538 Metetra
.664 .741 .907 r
.10743 .27538 .10872 .27661 .11451 .2744 .11322 .27317 Metetra
.664 .741 .907 r
.11322 .27317 .11451 .2744 .12032 .27219 .11903 .27095 Metetra
.664 .741 .907 r
.11903 .27095 .12032 .27219 .12613 .26996 .12485 .26872 Metetra
.664 .741 .907 r
.12485 .26872 .12613 .26996 .13196 .26774 .13068 .26649 Metetra
.664 .741 .907 r
.13068 .26649 .13196 .26774 .13781 .26551 .13653 .26426 Metetra
.664 .741 .907 r
.13653 .26426 .13781 .26551 .14367 .26327 .14239 .26202 Metetra
.664 .741 .907 r
.14239 .26202 .14367 .26327 .14954 .26103 .14826 .25978 Metetra
.664 .741 .907 r
.14826 .25978 .14954 .26103 .15542 .25878 .15415 .25753 Metetra
.664 .741 .907 r
.15415 .25753 .15542 .25878 .15946 .27225 .16005 .25527 Metetra
.533 .326 .545 r
.16005 .25527 .15946 .27225 .16723 .25427 .16596 .25301 Metetra
.664 .741 .907 r
.16596 .25301 .16723 .25427 .17316 .25201 .17189 .25075 Metetra
.664 .741 .907 r
.17189 .25075 .17316 .25201 .17909 .24974 .17783 .24847 Metetra
.664 .741 .907 r
.17783 .24847 .17909 .24974 .18505 .24747 .18379 .2462 Metetra
.664 .741 .907 r
.18379 .2462 .18505 .24747 .19101 .24519 .18976 .24392 Metetra
.664 .741 .907 r
.18976 .24392 .19101 .24519 .19699 .24291 .19574 .24163 Metetra
.664 .741 .907 r
.19574 .24163 .19699 .24291 .20299 .24062 .20174 .23934 Metetra
.664 .741 .907 r
.20174 .23934 .20299 .24062 .209 .23832 .20775 .23704 Metetra
.664 .741 .907 r
.20775 .23704 .209 .23832 .21502 .23603 .21377 .23474 Metetra
.664 .741 .907 r
.21377 .23474 .21502 .23603 .22105 .23372 .21981 .23243 Metetra
.664 .741 .907 r
.21981 .23243 .22105 .23372 .2271 .23141 .22586 .23012 Metetra
.664 .741 .907 r
.22586 .23012 .2271 .23141 .23317 .22909 .23193 .2278 Metetra
.664 .741 .907 r
.23193 .2278 .23317 .22909 .23925 .22677 .23801 .22548 Metetra
.664 .741 .907 r
.23801 .22548 .23925 .22677 .24534 .22445 .2441 .22315 Metetra
.664 .741 .907 r
.2441 .22315 .24534 .22445 .25145 .22212 .25021 .22081 Metetra
.664 .741 .907 r
.25021 .22081 .25145 .22212 .25757 .21978 .25634 .21847 Metetra
.664 .741 .907 r
.25634 .21847 .25757 .21978 .2637 .21744 .26247 .21613 Metetra
.664 .741 .907 r
.26247 .21613 .2637 .21744 .26985 .21509 .26863 .21378 Metetra
.664 .741 .907 r
.26863 .21378 .26985 .21509 .27602 .21273 .27479 .21142 Metetra
.664 .741 .907 r
.27479 .21142 .27602 .21273 .28219 .21038 .28098 .20906 Metetra
.664 .741 .907 r
.28098 .20906 .28219 .21038 .28839 .20801 .28717 .20669 Metetra
.664 .741 .907 r
.28717 .20669 .28839 .20801 .2946 .20564 .29338 .20432 Metetra
.664 .741 .907 r
.29338 .20432 .2946 .20564 .30082 .20326 .29961 .20194 Metetra
.664 .741 .907 r
.29961 .20194 .30082 .20326 .30706 .20088 .30585 .19955 Metetra
.961 .679 .453 r
.30585 .19955 .30706 .20088 .29669 .43584 .29537 .43457 Metetra
.96 .696 .49 r
.29537 .43457 .29669 .43584 .31737 .22851 .31786 .20219 Metetra
.561 .337 .533 r
.31786 .20219 .31737 .22851 .32586 .1937 .32466 .19236 Metetra
.664 .741 .907 r
.32466 .19236 .32586 .1937 .33215 .1913 .33096 .18996 Metetra
.664 .741 .907 r
.33096 .18996 .33215 .1913 .33846 .18889 .33727 .18754 Metetra
.664 .741 .907 r
.33727 .18754 .33846 .18889 .34389 .20158 .3436 .18512 Metetra
.534 .329 .548 r
.3436 .18512 .34389 .20158 .35113 .18405 .34994 .1827 Metetra
.664 .741 .907 r
.34994 .1827 .35113 .18405 .35749 .18162 .3563 .18027 Metetra
.664 .741 .907 r
.3563 .18027 .35749 .18162 .36386 .17919 .36268 .17783 Metetra
.664 .741 .907 r
.36268 .17783 .36386 .17919 .37025 .17675 .36907 .17539 Metetra
.664 .741 .907 r
.36907 .17539 .37025 .17675 .37665 .17431 .37547 .17294 Metetra
.664 .741 .907 r
.37547 .17294 .37665 .17431 .38307 .17186 .38189 .17049 Metetra
.664 .741 .907 r
.38189 .17049 .38307 .17186 .3895 .1694 .38833 .16803 Metetra
.664 .741 .907 r
.38833 .16803 .3895 .1694 .39595 .16694 .39478 .16556 Metetra
.664 .741 .907 r
.39478 .16556 .39595 .16694 .40242 .16447 .40125 .16309 Metetra
.664 .741 .907 r
.40125 .16309 .40242 .16447 .4089 .162 .40773 .16061 Metetra
.664 .741 .907 r
.40773 .16061 .4089 .162 .41539 .15952 .41423 .15813 Metetra
.664 .741 .907 r
.41423 .15813 .41539 .15952 .4219 .15703 .42075 .15564 Metetra
.664 .741 .907 r
.42075 .15564 .4219 .15703 .42843 .15454 .42728 .15314 Metetra
.664 .741 .907 r
.42728 .15314 .42843 .15454 .43497 .15204 .43382 .15064 Metetra
.664 .741 .907 r
.43382 .15064 .43497 .15204 .44153 .14953 .44038 .14814 Metetra
.664 .741 .907 r
.44038 .14814 .44153 .14953 .44811 .14702 .44696 .14562 Metetra
.664 .741 .907 r
.44696 .14562 .44811 .14702 .4547 .14451 .45356 .1431 Metetra
.664 .741 .907 r
.45356 .1431 .4547 .14451 .4613 .14199 .46016 .14058 Metetra
.664 .741 .907 r
.46016 .14058 .4613 .14199 .46793 .13946 .46679 .13804 Metetra
.664 .741 .907 r
.46679 .13804 .46793 .13946 .47449 .14113 .47343 .13551 Metetra
.58 .434 .648 r
.47343 .13551 .47449 .14113 .48122 .13438 .48009 .13296 Metetra
.664 .741 .907 r
.48009 .13296 .48122 .13438 .48789 .13183 .48677 .13041 Metetra
.664 .741 .907 r
.48677 .13041 .48789 .13183 .49458 .12928 .49346 .12785 Metetra
.664 .741 .907 r
.49346 .12785 .49458 .12928 .50128 .12672 .50016 .12529 Metetra
.664 .741 .907 r
.50016 .12529 .50128 .12672 .508 .12415 .50689 .12272 Metetra
.664 .741 .907 r
.50689 .12272 .508 .12415 .51474 .12158 .51363 .12014 Metetra
.664 .741 .907 r
.51363 .12014 .51474 .12158 .5215 .119 .52038 .11756 Metetra
.664 .741 .907 r
.52038 .11756 .5215 .119 .52827 .11642 .52716 .11497 Metetra
.664 .741 .907 r
.52716 .11497 .52827 .11642 .53505 .11383 .53395 .11238 Metetra
.664 .741 .907 r
.53395 .11238 .53505 .11383 .54186 .11123 .54076 .10978 Metetra
.664 .741 .907 r
.54076 .10978 .54186 .11123 .54868 .10862 .54758 .10717 Metetra
.664 .741 .907 r
.54758 .10717 .54868 .10862 .55551 .10601 .55442 .10455 Metetra
.664 .741 .907 r
.55442 .10455 .55551 .10601 .56237 .1034 .56128 .10193 Metetra
.664 .741 .907 r
.56128 .10193 .56237 .1034 .56924 .10077 .56815 .09931 Metetra
.664 .741 .907 r
.56815 .09931 .56924 .10077 .57613 .09814 .57505 .09667 Metetra
.664 .741 .907 r
.57505 .09667 .57613 .09814 .58303 .0955 .58195 .09403 Metetra
.664 .741 .907 r
.58195 .09403 .58303 .0955 .58996 .09286 .58888 .09138 Metetra
.664 .741 .907 r
.58888 .09138 .58996 .09286 .5969 .09021 .59582 .08873 Metetra
.664 .741 .907 r
.59582 .08873 .5969 .09021 .60385 .08755 .60279 .08607 Metetra
.664 .741 .907 r
.60279 .08607 .60385 .08755 .61083 .08489 .60976 .0834 Metetra
.664 .741 .907 r
.60976 .0834 .61083 .08489 .61782 .08222 .61676 .08073 Metetra
.664 .741 .907 r
.61676 .08073 .61782 .08222 .62483 .07955 .62377 .07805 Metetra
.664 .741 .907 r
.62377 .07805 .62483 .07955 .63186 .07686 .6308 .07536 Metetra
.664 .741 .907 r
.6308 .07536 .63186 .07686 .6389 .07417 .63785 .07267 Metetra
.881 .489 .031 r
.63785 .07267 .6389 .07417 .64681 .09162 .64613 .09926 Metetra
.908 .568 .388 r
.64613 .09926 .64681 .09162 .65454 .10244 .65754 .19314 Metetra
.281 .098 .445 r
.65754 .19314 .65454 .10244 .66015 .06606 .65911 .06455 Metetra
.664 .741 .907 r
.65911 .06455 .66015 .06606 .66726 .06334 .66623 .06182 Metetra
.664 .741 .907 r
.66623 .06182 .66726 .06334 .6744 .06062 .67336 .0591 Metetra
.664 .741 .907 r
.67336 .0591 .6744 .06062 .68155 .05789 .68052 .05636 Metetra
.664 .741 .907 r
.68052 .05636 .68155 .05789 .68872 .05515 .68769 .05362 Metetra
.664 .741 .907 r
.68769 .05362 .68872 .05515 .69591 .05241 .69489 .05087 Metetra
.664 .741 .907 r
.69489 .05087 .69591 .05241 .70312 .04965 .7021 .04812 Metetra
.664 .741 .907 r
.7021 .04812 .70312 .04965 .71034 .04689 .70933 .04535 Metetra
.664 .741 .907 r
.70933 .04535 .71034 .04689 .71759 .04413 .71657 .04258 Metetra
.664 .741 .907 r
.07164 .28734 .07295 .28856 .07866 .28638 .07736 .28516 Metetra
.664 .741 .907 r
.07736 .28516 .07866 .28638 .08439 .28419 .08309 .28296 Metetra
.664 .741 .907 r
.08309 .28296 .08439 .28419 .09013 .28199 .08883 .28077 Metetra
.664 .741 .907 r
.08883 .28077 .09013 .28199 .09588 .27979 .09459 .27856 Metetra
.664 .741 .907 r
.09459 .27856 .09588 .27979 .10165 .27759 .10036 .27636 Metetra
.664 .741 .907 r
.10036 .27636 .10165 .27759 .10743 .27538 .10614 .27415 Metetra
.664 .741 .907 r
.10614 .27415 .10743 .27538 .11322 .27317 .11194 .27193 Metetra
.664 .741 .907 r
.11194 .27193 .11322 .27317 .11903 .27095 .11774 .26971 Metetra
.664 .741 .907 r
.11774 .26971 .11903 .27095 .12485 .26872 .12357 .26748 Metetra
.664 .741 .907 r
.12357 .26748 .12485 .26872 .13068 .26649 .1294 .26525 Metetra
.664 .741 .907 r
.1294 .26525 .13068 .26649 .13653 .26426 .13525 .26301 Metetra
.664 .741 .907 r
.13525 .26301 .13653 .26426 .14239 .26202 .14111 .26077 Metetra
.664 .741 .907 r
.14111 .26077 .14239 .26202 .14826 .25978 .14699 .25852 Metetra
.664 .741 .907 r
.14699 .25852 .14826 .25978 .15415 .25753 .15288 .25627 Metetra
.664 .741 .907 r
.15288 .25627 .15415 .25753 .16005 .25527 .15878 .25401 Metetra
.664 .741 .907 r
.15878 .25401 .16005 .25527 .16596 .25301 .1647 .25175 Metetra
.664 .741 .907 r
.1647 .25175 .16596 .25301 .17189 .25075 .17063 .24948 Metetra
.664 .741 .907 r
.17063 .24948 .17189 .25075 .17783 .24847 .17657 .24721 Metetra
.664 .741 .907 r
.17657 .24721 .17783 .24847 .18379 .2462 .18253 .24493 Metetra
.664 .741 .907 r
.18253 .24493 .18379 .2462 .18976 .24392 .1885 .24264 Metetra
.664 .741 .907 r
.1885 .24264 .18976 .24392 .19574 .24163 .19448 .24035 Metetra
.664 .741 .907 r
.19448 .24035 .19574 .24163 .20174 .23934 .20048 .23806 Metetra
.664 .741 .907 r
.20048 .23806 .20174 .23934 .20775 .23704 .2065 .23576 Metetra
.664 .741 .907 r
.2065 .23576 .20775 .23704 .21377 .23474 .21252 .23345 Metetra
.664 .741 .907 r
.21252 .23345 .21377 .23474 .21981 .23243 .21856 .23114 Metetra
.664 .741 .907 r
.21856 .23114 .21981 .23243 .22586 .23012 .22462 .22883 Metetra
.664 .741 .907 r
.22462 .22883 .22586 .23012 .23193 .2278 .23069 .22651 Metetra
.664 .741 .907 r
.23069 .22651 .23193 .2278 .23801 .22548 .23677 .22418 Metetra
.664 .741 .907 r
.23677 .22418 .23801 .22548 .2441 .22315 .24287 .22185 Metetra
.664 .741 .907 r
.24287 .22185 .2441 .22315 .25021 .22081 .24898 .21951 Metetra
.664 .741 .907 r
.24898 .21951 .25021 .22081 .25634 .21847 .25511 .21717 Metetra
.664 .741 .907 r
.25511 .21717 .25634 .21847 .26247 .21613 .26125 .21482 Metetra
.664 .741 .907 r
.26125 .21482 .26247 .21613 .26863 .21378 .2674 .21246 Metetra
.664 .741 .907 r
.2674 .21246 .26863 .21378 .27479 .21142 .27357 .2101 Metetra
.664 .741 .907 r
.27357 .2101 .27479 .21142 .28098 .20906 .27975 .20774 Metetra
.664 .741 .907 r
.27975 .20774 .28098 .20906 .28717 .20669 .28595 .20537 Metetra
.664 .741 .907 r
.28595 .20537 .28717 .20669 .29338 .20432 .29217 .20299 Metetra
.664 .741 .907 r
.29217 .20299 .29338 .20432 .29961 .20194 .29839 .20061 Metetra
.664 .741 .907 r
.29839 .20061 .29961 .20194 .30585 .19955 .30464 .19822 Metetra
.961 .679 .453 r
.30464 .19822 .30585 .19955 .29537 .43457 .29444 .42787 Metetra
.938 .672 .507 r
.29444 .42787 .29537 .43457 .31786 .20219 .31368 .24404 Metetra
.26 .056 .402 r
.31368 .24404 .31786 .20219 .32466 .19236 .32345 .19102 Metetra
.664 .741 .907 r
.32345 .19102 .32466 .19236 .33096 .18996 .32976 .18861 Metetra
.664 .741 .907 r
.32976 .18861 .33096 .18996 .33727 .18754 .33607 .18619 Metetra
.664 .741 .907 r
.33607 .18619 .33727 .18754 .3436 .18512 .34241 .18377 Metetra
.664 .741 .907 r
.34241 .18377 .3436 .18512 .34994 .1827 .34875 .18134 Metetra
.664 .741 .907 r
.34875 .18134 .34994 .1827 .3563 .18027 .35512 .17891 Metetra
.664 .741 .907 r
.35512 .17891 .3563 .18027 .36268 .17783 .36149 .17647 Metetra
.664 .741 .907 r
.36149 .17647 .36268 .17783 .36907 .17539 .36789 .17403 Metetra
.664 .741 .907 r
.36789 .17403 .36907 .17539 .37547 .17294 .37429 .17157 Metetra
.664 .741 .907 r
.37429 .17157 .37547 .17294 .38189 .17049 .38072 .16912 Metetra
.664 .741 .907 r
.38072 .16912 .38189 .17049 .38833 .16803 .38716 .16665 Metetra
.664 .741 .907 r
.38716 .16665 .38833 .16803 .39478 .16556 .39361 .16418 Metetra
.664 .741 .907 r
.39361 .16418 .39478 .16556 .40125 .16309 .40008 .16171 Metetra
.664 .741 .907 r
.40008 .16171 .40125 .16309 .40773 .16061 .40657 .15923 Metetra
.664 .741 .907 r
.40657 .15923 .40773 .16061 .41423 .15813 .41307 .15674 Metetra
.664 .741 .907 r
.41307 .15674 .41423 .15813 .42075 .15564 .41959 .15425 Metetra
.664 .741 .907 r
.41959 .15425 .42075 .15564 .42728 .15314 .42612 .15175 Metetra
.664 .741 .907 r
.42612 .15175 .42728 .15314 .43382 .15064 .43267 .14925 Metetra
.664 .741 .907 r
.43267 .14925 .43382 .15064 .44038 .14814 .43923 .14673 Metetra
.664 .741 .907 r
.43923 .14673 .44038 .14814 .44696 .14562 .44581 .14422 Metetra
.664 .741 .907 r
.44581 .14422 .44696 .14562 .45356 .1431 .45241 .14169 Metetra
.664 .741 .907 r
.45241 .14169 .45356 .1431 .46016 .14058 .45902 .13916 Metetra
.664 .741 .907 r
.45902 .13916 .46016 .14058 .46679 .13804 .46565 .13663 Metetra
.664 .741 .907 r
.46565 .13663 .46679 .13804 .47343 .13551 .4723 .13409 Metetra
.664 .741 .907 r
.4723 .13409 .47343 .13551 .48009 .13296 .47896 .13154 Metetra
.664 .741 .907 r
.47896 .13154 .48009 .13296 .48677 .13041 .48564 .12898 Metetra
.664 .741 .907 r
.48564 .12898 .48677 .13041 .49346 .12785 .49233 .12642 Metetra
.664 .741 .907 r
.49233 .12642 .49346 .12785 .50016 .12529 .49904 .12386 Metetra
.664 .741 .907 r
.49904 .12386 .50016 .12529 .50689 .12272 .50577 .12128 Metetra
.664 .741 .907 r
.50577 .12128 .50689 .12272 .51363 .12014 .51251 .1187 Metetra
.664 .741 .907 r
.51251 .1187 .51363 .12014 .52038 .11756 .51927 .11612 Metetra
.664 .741 .907 r
.51927 .11612 .52038 .11756 .52716 .11497 .52605 .11353 Metetra
.664 .741 .907 r
.52605 .11353 .52716 .11497 .53395 .11238 .53284 .11093 Metetra
.664 .741 .907 r
.53284 .11093 .53395 .11238 .54076 .10978 .53965 .10832 Metetra
.664 .741 .907 r
.53965 .10832 .54076 .10978 .54758 .10717 .54648 .10571 Metetra
.664 .741 .907 r
.54648 .10571 .54758 .10717 .55442 .10455 .55333 .10309 Metetra
.664 .741 .907 r
.55333 .10309 .55442 .10455 .56128 .10193 .56019 .10047 Metetra
.664 .741 .907 r
.56019 .10047 .56128 .10193 .56815 .09931 .56706 .09784 Metetra
.664 .741 .907 r
.56706 .09784 .56815 .09931 .57505 .09667 .57396 .0952 Metetra
.664 .741 .907 r
.57396 .0952 .57505 .09667 .58195 .09403 .58087 .09256 Metetra
.664 .741 .907 r
.58087 .09256 .58195 .09403 .58888 .09138 .5878 .0899 Metetra
.664 .741 .907 r
.5878 .0899 .58888 .09138 .59582 .08873 .59475 .08725 Metetra
.664 .741 .907 r
.59475 .08725 .59582 .08873 .60279 .08607 .60171 .08458 Metetra
.664 .741 .907 r
.60171 .08458 .60279 .08607 .60976 .0834 .6087 .08191 Metetra
.664 .741 .907 r
.6087 .08191 .60976 .0834 .61676 .08073 .6157 .07924 Metetra
.664 .741 .907 r
.6157 .07924 .61676 .08073 .62377 .07805 .62271 .07655 Metetra
.664 .741 .907 r
.62271 .07655 .62377 .07805 .6308 .07536 .62975 .07386 Metetra
.664 .741 .907 r
.62975 .07386 .6308 .07536 .63785 .07267 .6368 .07116 Metetra
.836 .427 0 r
.6368 .07116 .63785 .07267 .64613 .09926 .64485 .09222 Metetra
.928 .632 .158 r
.64485 .09222 .64613 .09926 .65754 .19314 .65731 .21129 Metetra
.782 .624 .062 r
.65731 .21129 .65754 .19314 .65911 .06455 .65806 .06303 Metetra
.664 .741 .907 r
.65806 .06303 .65911 .06455 .66623 .06182 .66519 .0603 Metetra
.664 .741 .907 r
.66519 .0603 .66623 .06182 .67336 .0591 .67233 .05757 Metetra
.664 .741 .907 r
.67233 .05757 .67336 .0591 .68052 .05636 .67949 .05483 Metetra
.664 .741 .907 r
.67949 .05483 .68052 .05636 .68769 .05362 .68667 .05209 Metetra
.664 .741 .907 r
.68667 .05209 .68769 .05362 .69489 .05087 .69386 .04934 Metetra
.664 .741 .907 r
.69386 .04934 .69489 .05087 .7021 .04812 .70108 .04658 Metetra
.664 .741 .907 r
.70108 .04658 .7021 .04812 .70933 .04535 .70831 .04381 Metetra
.664 .741 .907 r
.70831 .04381 .70933 .04535 .71657 .04258 .71556 .04103 Metetra
.664 .741 .907 r
.07034 .28612 .07164 .28734 .07736 .28516 .07606 .28393 Metetra
.664 .741 .907 r
.07606 .28393 .07736 .28516 .08309 .28296 .08179 .28174 Metetra
.664 .741 .907 r
.08179 .28174 .08309 .28296 .08883 .28077 .08753 .27954 Metetra
.664 .741 .907 r
.08753 .27954 .08883 .28077 .09459 .27856 .09329 .27733 Metetra
.664 .741 .907 r
.09329 .27733 .09459 .27856 .10036 .27636 .09906 .27513 Metetra
.664 .741 .907 r
.09906 .27513 .10036 .27636 .10614 .27415 .10485 .27291 Metetra
.664 .741 .907 r
.10485 .27291 .10614 .27415 .11194 .27193 .11065 .27069 Metetra
.664 .741 .907 r
.11065 .27069 .11194 .27193 .11774 .26971 .11646 .26847 Metetra
.664 .741 .907 r
.11646 .26847 .11774 .26971 .12357 .26748 .12228 .26624 Metetra
.664 .741 .907 r
.12228 .26624 .12357 .26748 .1294 .26525 .12812 .264 Metetra
.664 .741 .907 r
.12812 .264 .1294 .26525 .13525 .26301 .13397 .26176 Metetra
.664 .741 .907 r
.13397 .26176 .13525 .26301 .14111 .26077 .13983 .25952 Metetra
.664 .741 .907 r
.13983 .25952 .14111 .26077 .14699 .25852 .14571 .25727 Metetra
.664 .741 .907 r
.14571 .25727 .14699 .25852 .15288 .25627 .1516 .25501 Metetra
.664 .741 .907 r
.1516 .25501 .15288 .25627 .15878 .25401 .15751 .25275 Metetra
.664 .741 .907 r
.15751 .25275 .15878 .25401 .1647 .25175 .16343 .25048 Metetra
.664 .741 .907 r
.16343 .25048 .1647 .25175 .17063 .24948 .16936 .24821 Metetra
.664 .741 .907 r
.16936 .24821 .17063 .24948 .17657 .24721 .17531 .24594 Metetra
.664 .741 .907 r
.17531 .24594 .17657 .24721 .18253 .24493 .18127 .24365 Metetra
.664 .741 .907 r
.18127 .24365 .18253 .24493 .1885 .24264 .18724 .24137 Metetra
.664 .741 .907 r
.18724 .24137 .1885 .24264 .19448 .24035 .19323 .23907 Metetra
.664 .741 .907 r
.19323 .23907 .19448 .24035 .20048 .23806 .19923 .23678 Metetra
.664 .741 .907 r
.19923 .23678 .20048 .23806 .2065 .23576 .20524 .23447 Metetra
.664 .741 .907 r
.20524 .23447 .2065 .23576 .21252 .23345 .21127 .23217 Metetra
.664 .741 .907 r
.21127 .23217 .21252 .23345 .21856 .23114 .21732 .22985 Metetra
.664 .741 .907 r
.21732 .22985 .21856 .23114 .22462 .22883 .22337 .22753 Metetra
.664 .741 .907 r
.22337 .22753 .22462 .22883 .23069 .22651 .22944 .22521 Metetra
.664 .741 .907 r
.22944 .22521 .23069 .22651 .23677 .22418 .23553 .22288 Metetra
.664 .741 .907 r
.23553 .22288 .23677 .22418 .24287 .22185 .24163 .22054 Metetra
.664 .741 .907 r
.24163 .22054 .24287 .22185 .24898 .21951 .24774 .2182 Metetra
.664 .741 .907 r
.24774 .2182 .24898 .21951 .25511 .21717 .25387 .21586 Metetra
.664 .741 .907 r
.25387 .21586 .25511 .21717 .26125 .21482 .26002 .2135 Metetra
.664 .741 .907 r
.26002 .2135 .26125 .21482 .2674 .21246 .26617 .21115 Metetra
.664 .741 .907 r
.26617 .21115 .2674 .21246 .27357 .2101 .27235 .20878 Metetra
.664 .741 .907 r
.27235 .20878 .27357 .2101 .27975 .20774 .27853 .20642 Metetra
.664 .741 .907 r
.27853 .20642 .27975 .20774 .28595 .20537 .28473 .20404 Metetra
.664 .741 .907 r
.28473 .20404 .28595 .20537 .29217 .20299 .29095 .20166 Metetra
.664 .741 .907 r
.29095 .20166 .29217 .20299 .29839 .20061 .29718 .19928 Metetra
.664 .741 .907 r
.29718 .19928 .29839 .20061 .30464 .19822 .30343 .19688 Metetra
.961 .679 .453 r
.30343 .19688 .30464 .19822 .29444 .42787 .29274 .43202 Metetra
.976 .718 .475 r
.29274 .43202 .29444 .42787 .31368 .24404 .31445 .21392 Metetra
.61 .374 .534 r
.31445 .21392 .31368 .24404 .32345 .19102 .32225 .18968 Metetra
.664 .741 .907 r
.32225 .18968 .32345 .19102 .32976 .18861 .32856 .18726 Metetra
.664 .741 .907 r
.32856 .18726 .32976 .18861 .33607 .18619 .33488 .18484 Metetra
.664 .741 .907 r
.33488 .18484 .33607 .18619 .34241 .18377 .34121 .18242 Metetra
.664 .741 .907 r
.34121 .18242 .34241 .18377 .34875 .18134 .34756 .17999 Metetra
.664 .741 .907 r
.34756 .17999 .34875 .18134 .35512 .17891 .35393 .17755 Metetra
.664 .741 .907 r
.35393 .17755 .35512 .17891 .36149 .17647 .36031 .17511 Metetra
.664 .741 .907 r
.36031 .17511 .36149 .17647 .36789 .17403 .3667 .17266 Metetra
.664 .741 .907 r
.3667 .17266 .36789 .17403 .37429 .17157 .37311 .1702 Metetra
.664 .741 .907 r
.37311 .1702 .37429 .17157 .38072 .16912 .37954 .16774 Metetra
.664 .741 .907 r
.37954 .16774 .38072 .16912 .38716 .16665 .38598 .16528 Metetra
.664 .741 .907 r
.38598 .16528 .38716 .16665 .39361 .16418 .39244 .16281 Metetra
.664 .741 .907 r
.39244 .16281 .39361 .16418 .40008 .16171 .39891 .16033 Metetra
.664 .741 .907 r
.39891 .16033 .40008 .16171 .40657 .15923 .4054 .15784 Metetra
.664 .741 .907 r
.4054 .15784 .40657 .15923 .41307 .15674 .41191 .15535 Metetra
.664 .741 .907 r
.41191 .15535 .41307 .15674 .41959 .15425 .41843 .15286 Metetra
.664 .741 .907 r
.41843 .15286 .41959 .15425 .42612 .15175 .42496 .15035 Metetra
.664 .741 .907 r
.42496 .15035 .42612 .15175 .43267 .14925 .43151 .14785 Metetra
.664 .741 .907 r
.43151 .14785 .43267 .14925 .43923 .14673 .43808 .14533 Metetra
.664 .741 .907 r
.43808 .14533 .43923 .14673 .44581 .14422 .44467 .14281 Metetra
.664 .741 .907 r
.44467 .14281 .44581 .14422 .45241 .14169 .45127 .14028 Metetra
.664 .741 .907 r
.45127 .14028 .45241 .14169 .45902 .13916 .45788 .13775 Metetra
.664 .741 .907 r
.45788 .13775 .45902 .13916 .46565 .13663 .46451 .13521 Metetra
.664 .741 .907 r
.46451 .13521 .46565 .13663 .4723 .13409 .47116 .13267 Metetra
.664 .741 .907 r
.47116 .13267 .4723 .13409 .47896 .13154 .47783 .13011 Metetra
.664 .741 .907 r
.47783 .13011 .47896 .13154 .48564 .12898 .48451 .12756 Metetra
.664 .741 .907 r
.48451 .12756 .48564 .12898 .49233 .12642 .49121 .12499 Metetra
.664 .741 .907 r
.49121 .12499 .49233 .12642 .49904 .12386 .49792 .12242 Metetra
.664 .741 .907 r
.49792 .12242 .49904 .12386 .50577 .12128 .50465 .11985 Metetra
.664 .741 .907 r
.50465 .11985 .50577 .12128 .51251 .1187 .5114 .11726 Metetra
.664 .741 .907 r
.5114 .11726 .51251 .1187 .51927 .11612 .51816 .11467 Metetra
.664 .741 .907 r
.51816 .11467 .51927 .11612 .52605 .11353 .52494 .11208 Metetra
.664 .741 .907 r
.52494 .11208 .52605 .11353 .53284 .11093 .53174 .10948 Metetra
.664 .741 .907 r
.53174 .10948 .53284 .11093 .53965 .10832 .53855 .10687 Metetra
.664 .741 .907 r
.53855 .10687 .53965 .10832 .54648 .10571 .54538 .10425 Metetra
.664 .741 .907 r
.54538 .10425 .54648 .10571 .55333 .10309 .55223 .10163 Metetra
.664 .741 .907 r
.55223 .10163 .55333 .10309 .56019 .10047 .55909 .099 Metetra
.664 .741 .907 r
.55909 .099 .56019 .10047 .56706 .09784 .56598 .09637 Metetra
.664 .741 .907 r
.56598 .09637 .56706 .09784 .57396 .0952 .57287 .09373 Metetra
.664 .741 .907 r
.57287 .09373 .57396 .0952 .58087 .09256 .57979 .09108 Metetra
.664 .741 .907 r
.57979 .09108 .58087 .09256 .5878 .0899 .58672 .08842 Metetra
.664 .741 .907 r
.58672 .08842 .5878 .0899 .59475 .08725 .59367 .08576 Metetra
.664 .741 .907 r
.59367 .08576 .59475 .08725 .60171 .08458 .60064 .08309 Metetra
.664 .741 .907 r
.60064 .08309 .60171 .08458 .6087 .08191 .60763 .08042 Metetra
.664 .741 .907 r
.60763 .08042 .6087 .08191 .6157 .07924 .61463 .07774 Metetra
.664 .741 .907 r
.61463 .07774 .6157 .07924 .62271 .07655 .62165 .07505 Metetra
.664 .741 .907 r
.62165 .07505 .62271 .07655 .62975 .07386 .62869 .07236 Metetra
.664 .741 .907 r
.62869 .07236 .62975 .07386 .6368 .07116 .63574 .06966 Metetra
.883 .491 .035 r
.63574 .06966 .6368 .07116 .64485 .09222 .64403 .09659 Metetra
.956 .626 .35 r
.64403 .09659 .64485 .09222 .65731 .21129 .65862 .26525 Metetra
0 0 .269 r
.65862 .26525 .65731 .21129 .65806 .06303 .65702 .06151 Metetra
.664 .741 .907 r
.65702 .06151 .65806 .06303 .66519 .0603 .66415 .05878 Metetra
.664 .741 .907 r
.66415 .05878 .66519 .0603 .67233 .05757 .67129 .05605 Metetra
.664 .741 .907 r
.67129 .05605 .67233 .05757 .67949 .05483 .67846 .0533 Metetra
.664 .741 .907 r
.67846 .0533 .67949 .05483 .68667 .05209 .68564 .05055 Metetra
.664 .741 .907 r
.68564 .05055 .68667 .05209 .69386 .04934 .69284 .0478 Metetra
.664 .741 .907 r
.69284 .0478 .69386 .04934 .70108 .04658 .70006 .04503 Metetra
.664 .741 .907 r
.70006 .04503 .70108 .04658 .70831 .04381 .70729 .04226 Metetra
.664 .741 .907 r
.70729 .04226 .70831 .04381 .71556 .04103 .71455 .03948 Metetra
.664 .741 .907 r
.06903 .2849 .07034 .28612 .07606 .28393 .07475 .28271 Metetra
.664 .741 .907 r
.07475 .28271 .07606 .28393 .08179 .28174 .08049 .28051 Metetra
.664 .741 .907 r
.08049 .28051 .08179 .28174 .08753 .27954 .08623 .27831 Metetra
.664 .741 .907 r
.08623 .27831 .08753 .27954 .09329 .27733 .09199 .2761 Metetra
.664 .741 .907 r
.09199 .2761 .09329 .27733 .09906 .27513 .09777 .27389 Metetra
.664 .741 .907 r
.09777 .27389 .09906 .27513 .10485 .27291 .10355 .27167 Metetra
.664 .741 .907 r
.10355 .27167 .10485 .27291 .11065 .27069 .10935 .26945 Metetra
.664 .741 .907 r
.10935 .26945 .11065 .27069 .11646 .26847 .11517 .26722 Metetra
.664 .741 .907 r
.11517 .26722 .11646 .26847 .12228 .26624 .12099 .26499 Metetra
.664 .741 .907 r
.12099 .26499 .12228 .26624 .12812 .264 .12683 .26275 Metetra
.664 .741 .907 r
.12683 .26275 .12812 .264 .13397 .26176 .13269 .26051 Metetra
.664 .741 .907 r
.13269 .26051 .13397 .26176 .13983 .25952 .13855 .25826 Metetra
.664 .741 .907 r
.13855 .25826 .13983 .25952 .14571 .25727 .14443 .25601 Metetra
.664 .741 .907 r
.14443 .25601 .14571 .25727 .1516 .25501 .15033 .25375 Metetra
.562 .708 .939 r
.15033 .25375 .1516 .25501 .15751 .25275 .15608 .25276 Metetra
.695 .965 .937 r
.15608 .25276 .15751 .25275 .16343 .25048 .16216 .24922 Metetra
.664 .741 .907 r
.16216 .24922 .16343 .25048 .16936 .24821 .16809 .24694 Metetra
.664 .741 .907 r
.16809 .24694 .16936 .24821 .17531 .24594 .17404 .24466 Metetra
.664 .741 .907 r
.17404 .24466 .17531 .24594 .18127 .24365 .18 .24238 Metetra
.664 .741 .907 r
.18 .24238 .18127 .24365 .18724 .24137 .18598 .24009 Metetra
.664 .741 .907 r
.18598 .24009 .18724 .24137 .19323 .23907 .19197 .23779 Metetra
.664 .741 .907 r
.19197 .23779 .19323 .23907 .19923 .23678 .19797 .23549 Metetra
.664 .741 .907 r
.19797 .23549 .19923 .23678 .20524 .23447 .20399 .23319 Metetra
.664 .741 .907 r
.20399 .23319 .20524 .23447 .21127 .23217 .21002 .23088 Metetra
.664 .741 .907 r
.21002 .23088 .21127 .23217 .21732 .22985 .21607 .22856 Metetra
.664 .741 .907 r
.21607 .22856 .21732 .22985 .22337 .22753 .22213 .22624 Metetra
.664 .741 .907 r
.22213 .22624 .22337 .22753 .22944 .22521 .2282 .22391 Metetra
.664 .741 .907 r
.2282 .22391 .22944 .22521 .23553 .22288 .23429 .22158 Metetra
.664 .741 .907 r
.23429 .22158 .23553 .22288 .24163 .22054 .24039 .21924 Metetra
.664 .741 .907 r
.24039 .21924 .24163 .22054 .24774 .2182 .24651 .21689 Metetra
.664 .741 .907 r
.24651 .21689 .24774 .2182 .25387 .21586 .25264 .21454 Metetra
.664 .741 .907 r
.25264 .21454 .25387 .21586 .26002 .2135 .25878 .21219 Metetra
.664 .741 .907 r
.25878 .21219 .26002 .2135 .26617 .21115 .26494 .20983 Metetra
.664 .741 .907 r
.26494 .20983 .26617 .21115 .27235 .20878 .27112 .20746 Metetra
.664 .741 .907 r
.27112 .20746 .27235 .20878 .27853 .20642 .27731 .20509 Metetra
.664 .741 .907 r
.27731 .20509 .27853 .20642 .28473 .20404 .28351 .20271 Metetra
.664 .741 .907 r
.28351 .20271 .28473 .20404 .29095 .20166 .28973 .20033 Metetra
.664 .741 .907 r
.28973 .20033 .29095 .20166 .29718 .19928 .29596 .19794 Metetra
.664 .741 .907 r
.29596 .19794 .29718 .19928 .30343 .19688 .30221 .19555 Metetra
.961 .679 .453 r
.30221 .19555 .30343 .19688 .29274 .43202 .29142 .43075 Metetra
.96 .697 .491 r
.29142 .43075 .29274 .43202 .31445 .21392 .31281 .21862 Metetra
.881 .829 .358 r
.31281 .21862 .31445 .21392 .32225 .18968 .32105 .18833 Metetra
.664 .741 .907 r
.32105 .18833 .32225 .18968 .32856 .18726 .32735 .18591 Metetra
.664 .741 .907 r
.32735 .18591 .32856 .18726 .33488 .18484 .33368 .18349 Metetra
.664 .741 .907 r
.33368 .18349 .33488 .18484 .34121 .18242 .34001 .18106 Metetra
.664 .741 .907 r
.34001 .18106 .34121 .18242 .34756 .17999 .34637 .17863 Metetra
.664 .741 .907 r
.34637 .17863 .34756 .17999 .35393 .17755 .35273 .17619 Metetra
.664 .741 .907 r
.35273 .17619 .35393 .17755 .36031 .17511 .35912 .17374 Metetra
.664 .741 .907 r
.35912 .17374 .36031 .17511 .3667 .17266 .36552 .17129 Metetra
.664 .741 .907 r
.36552 .17129 .3667 .17266 .37311 .1702 .37193 .16883 Metetra
.664 .741 .907 r
.37193 .16883 .37311 .1702 .37954 .16774 .37836 .16637 Metetra
.664 .741 .907 r
.37836 .16637 .37954 .16774 .38598 .16528 .38481 .1639 Metetra
.664 .741 .907 r
.38481 .1639 .38598 .16528 .39244 .16281 .39127 .16142 Metetra
.664 .741 .907 r
.39127 .16142 .39244 .16281 .39891 .16033 .39774 .15894 Metetra
.664 .741 .907 r
.39774 .15894 .39891 .16033 .4054 .15784 .40423 .15645 Metetra
.664 .741 .907 r
.40423 .15645 .4054 .15784 .41191 .15535 .41074 .15396 Metetra
.664 .741 .907 r
.41074 .15396 .41191 .15535 .41843 .15286 .41726 .15146 Metetra
.664 .741 .907 r
.41726 .15146 .41843 .15286 .42496 .15035 .4238 .14896 Metetra
.664 .741 .907 r
.4238 .14896 .42496 .15035 .43151 .14785 .43036 .14644 Metetra
.664 .741 .907 r
.43036 .14644 .43151 .14785 .43808 .14533 .43693 .14393 Metetra
.664 .741 .907 r
.43693 .14393 .43808 .14533 .44467 .14281 .44352 .1414 Metetra
.664 .741 .907 r
.44352 .1414 .44467 .14281 .45127 .14028 .45012 .13887 Metetra
.664 .741 .907 r
.45012 .13887 .45127 .14028 .45788 .13775 .45674 .13634 Metetra
.664 .741 .907 r
.45674 .13634 .45788 .13775 .46451 .13521 .46337 .13379 Metetra
.664 .741 .907 r
.46337 .13379 .46451 .13521 .47116 .13267 .47003 .13124 Metetra
.664 .741 .907 r
.47003 .13124 .47116 .13267 .47783 .13011 .47669 .12869 Metetra
.664 .741 .907 r
.47669 .12869 .47783 .13011 .48451 .12756 .48338 .12613 Metetra
.664 .741 .907 r
.48338 .12613 .48451 .12756 .49121 .12499 .49008 .12356 Metetra
.664 .741 .907 r
.49008 .12356 .49121 .12499 .49792 .12242 .49679 .12099 Metetra
.664 .741 .907 r
.49679 .12099 .49792 .12242 .50465 .11985 .50353 .11841 Metetra
.664 .741 .907 r
.50353 .11841 .50465 .11985 .5114 .11726 .51028 .11582 Metetra
.664 .741 .907 r
.51028 .11582 .5114 .11726 .51816 .11467 .51704 .11323 Metetra
.664 .741 .907 r
.51704 .11323 .51816 .11467 .52494 .11208 .52383 .11063 Metetra
.664 .741 .907 r
.52383 .11063 .52494 .11208 .53174 .10948 .53063 .10802 Metetra
.664 .741 .907 r
.53063 .10802 .53174 .10948 .53855 .10687 .53745 .10541 Metetra
.664 .741 .907 r
.53745 .10541 .53855 .10687 .54538 .10425 .54428 .10279 Metetra
.664 .741 .907 r
.54428 .10279 .54538 .10425 .55223 .10163 .55113 .10016 Metetra
.664 .741 .907 r
.55113 .10016 .55223 .10163 .55909 .099 .558 .09753 Metetra
.664 .741 .907 r
.558 .09753 .55909 .099 .56598 .09637 .56488 .09489 Metetra
.664 .741 .907 r
.56488 .09489 .56598 .09637 .57287 .09373 .57179 .09225 Metetra
.664 .741 .907 r
.57179 .09225 .57287 .09373 .57979 .09108 .57871 .0896 Metetra
.664 .741 .907 r
.57871 .0896 .57979 .09108 .58672 .08842 .58564 .08694 Metetra
.664 .741 .907 r
.58564 .08694 .58672 .08842 .59367 .08576 .5926 .08428 Metetra
.664 .741 .907 r
.5926 .08428 .59367 .08576 .60064 .08309 .59957 .0816 Metetra
.664 .741 .907 r
.59957 .0816 .60064 .08309 .60763 .08042 .60656 .07893 Metetra
.664 .741 .907 r
.60656 .07893 .60763 .08042 .61463 .07774 .61356 .07624 Metetra
.664 .741 .907 r
.61356 .07624 .61463 .07774 .62165 .07505 .62059 .07355 Metetra
.664 .741 .907 r
.62059 .07355 .62165 .07505 .62869 .07236 .62763 .07085 Metetra
.664 .741 .907 r
.62763 .07085 .62869 .07236 .63574 .06966 .63469 .06815 Metetra
.919 .547 .121 r
.63469 .06815 .63574 .06966 .64403 .09659 .64335 .10469 Metetra
.942 .612 .376 r
.64335 .10469 .64403 .09659 .65862 .26525 .65825 .28133 Metetra
.929 .69 .206 r
.65825 .28133 .65862 .26525 .65702 .06151 .65597 .05999 Metetra
.664 .741 .907 r
.65597 .05999 .65702 .06151 .66415 .05878 .66311 .05726 Metetra
.664 .741 .907 r
.66311 .05726 .66415 .05878 .67129 .05605 .67026 .05452 Metetra
.664 .741 .907 r
.67026 .05452 .67129 .05605 .67846 .0533 .67742 .05177 Metetra
.664 .741 .907 r
.67742 .05177 .67846 .0533 .68564 .05055 .68461 .04902 Metetra
.664 .741 .907 r
.68461 .04902 .68564 .05055 .69284 .0478 .69181 .04626 Metetra
.664 .741 .907 r
.69181 .04626 .69284 .0478 .70006 .04503 .69903 .04349 Metetra
.664 .741 .907 r
.69903 .04349 .70006 .04503 .70729 .04226 .70628 .04071 Metetra
.664 .741 .907 r
.70628 .04071 .70729 .04226 .71455 .03948 .71353 .03793 Metetra
.664 .741 .907 r
.06772 .28368 .06903 .2849 .07475 .28271 .07345 .28149 Metetra
.664 .741 .907 r
.07345 .28149 .07475 .28271 .08049 .28051 .07918 .27928 Metetra
.664 .741 .907 r
.07918 .27928 .08049 .28051 .08623 .27831 .08493 .27708 Metetra
.664 .741 .907 r
.08493 .27708 .08623 .27831 .09199 .2761 .09069 .27487 Metetra
.664 .741 .907 r
.09069 .27487 .09199 .2761 .09777 .27389 .09647 .27265 Metetra
.664 .741 .907 r
.09647 .27265 .09777 .27389 .10355 .27167 .10226 .27043 Metetra
.664 .741 .907 r
.10226 .27043 .10355 .27167 .10935 .26945 .10806 .26821 Metetra
.664 .741 .907 r
.10806 .26821 .10935 .26945 .11517 .26722 .11388 .26598 Metetra
.664 .741 .907 r
.11388 .26598 .11517 .26722 .12099 .26499 .1197 .26374 Metetra
.664 .741 .907 r
.1197 .26374 .12099 .26499 .12683 .26275 .12555 .2615 Metetra
.664 .741 .907 r
.12555 .2615 .12683 .26275 .13269 .26051 .1314 .25926 Metetra
.664 .741 .907 r
.1314 .25926 .13269 .26051 .13855 .25826 .13727 .25701 Metetra
.664 .741 .907 r
.13727 .25701 .13855 .25826 .14443 .25601 .14315 .25475 Metetra
.664 .741 .907 r
.14315 .25475 .14443 .25601 .15033 .25375 .14905 .25249 Metetra
.543 .701 .943 r
.14905 .25249 .15033 .25375 .15608 .25276 .15478 .25168 Metetra
.748 .789 .886 r
.15478 .25168 .15608 .25276 .16216 .24922 .16088 .24795 Metetra
.664 .741 .907 r
.16088 .24795 .16216 .24922 .16809 .24694 .16682 .24567 Metetra
.664 .741 .907 r
.16682 .24567 .16809 .24694 .17404 .24466 .17277 .24339 Metetra
.664 .741 .907 r
.17277 .24339 .17404 .24466 .18 .24238 .17874 .2411 Metetra
.664 .741 .907 r
.17874 .2411 .18 .24238 .18598 .24009 .18471 .23881 Metetra
.664 .741 .907 r
.18471 .23881 .18598 .24009 .19197 .23779 .19071 .23651 Metetra
.664 .741 .907 r
.19071 .23651 .19197 .23779 .19797 .23549 .19671 .23421 Metetra
.664 .741 .907 r
.19671 .23421 .19797 .23549 .20399 .23319 .20273 .2319 Metetra
.664 .741 .907 r
.20273 .2319 .20399 .23319 .21002 .23088 .20877 .22958 Metetra
.664 .741 .907 r
.20877 .22958 .21002 .23088 .21607 .22856 .21481 .22726 Metetra
.664 .741 .907 r
.21481 .22726 .21607 .22856 .22213 .22624 .22088 .22494 Metetra
.664 .741 .907 r
.22088 .22494 .22213 .22624 .2282 .22391 .22695 .22261 Metetra
.664 .741 .907 r
.22695 .22261 .2282 .22391 .23429 .22158 .23304 .22027 Metetra
.664 .741 .907 r
.23304 .22027 .23429 .22158 .24039 .21924 .23915 .21793 Metetra
.664 .741 .907 r
.23915 .21793 .24039 .21924 .24651 .21689 .24527 .21558 Metetra
.664 .741 .907 r
.24527 .21558 .24651 .21689 .25264 .21454 .2514 .21323 Metetra
.664 .741 .907 r
.2514 .21323 .25264 .21454 .25878 .21219 .25755 .21087 Metetra
.664 .741 .907 r
.25755 .21087 .25878 .21219 .26494 .20983 .26371 .20851 Metetra
.664 .741 .907 r
.26371 .20851 .26494 .20983 .27112 .20746 .26989 .20614 Metetra
.664 .741 .907 r
.26989 .20614 .27112 .20746 .27731 .20509 .27608 .20377 Metetra
.664 .741 .907 r
.27608 .20377 .27731 .20509 .28351 .20271 .28229 .20139 Metetra
.664 .741 .907 r
.28229 .20139 .28351 .20271 .28973 .20033 .28851 .199 Metetra
.664 .741 .907 r
.28851 .199 .28973 .20033 .29596 .19794 .29475 .19661 Metetra
.664 .741 .907 r
.29475 .19661 .29596 .19794 .30221 .19555 .301 .19421 Metetra
.961 .679 .453 r
.301 .19421 .30221 .19555 .29142 .43075 .2901 .42947 Metetra
.96 .698 .493 r
.2901 .42947 .29142 .43075 .31281 .21862 .31073 .22942 Metetra
.31073 .22942 .31281 .21862 .32105 .18833 .31984 .18698 Metetra
.664 .741 .907 r
.31984 .18698 .32105 .18833 .32735 .18591 .32615 .18456 Metetra
.664 .741 .907 r
.32615 .18456 .32735 .18591 .33368 .18349 .33247 .18214 Metetra
.664 .741 .907 r
.33247 .18214 .33368 .18349 .34001 .18106 .33882 .17971 Metetra
.664 .741 .907 r
.33882 .17971 .34001 .18106 .34637 .17863 .34517 .17727 Metetra
.664 .741 .907 r
.34517 .17727 .34637 .17863 .35273 .17619 .35154 .17483 Metetra
.664 .741 .907 r
.35154 .17483 .35273 .17619 .35912 .17374 .35793 .17238 Metetra
.664 .741 .907 r
.35793 .17238 .35912 .17374 .36552 .17129 .36433 .16992 Metetra
.664 .741 .907 r
.36433 .16992 .36552 .17129 .37193 .16883 .37075 .16746 Metetra
.664 .741 .907 r
.37075 .16746 .37193 .16883 .37836 .16637 .37718 .16499 Metetra
.664 .741 .907 r
.37718 .16499 .37836 .16637 .38481 .1639 .38363 .16252 Metetra
.664 .741 .907 r
.38363 .16252 .38481 .1639 .39127 .16142 .39009 .16004 Metetra
.664 .741 .907 r
.39009 .16004 .39127 .16142 .39774 .15894 .39657 .15756 Metetra
.664 .741 .907 r
.39657 .15756 .39774 .15894 .40423 .15645 .40306 .15506 Metetra
.664 .741 .907 r
.40306 .15506 .40423 .15645 .41074 .15396 .40957 .15257 Metetra
.664 .741 .907 r
.40957 .15257 .41074 .15396 .41726 .15146 .4161 .15006 Metetra
.664 .741 .907 r
.4161 .15006 .41726 .15146 .4238 .14896 .42264 .14756 Metetra
.664 .741 .907 r
.42264 .14756 .4238 .14896 .43036 .14644 .4292 .14504 Metetra
.664 .741 .907 r
.4292 .14504 .43036 .14644 .43693 .14393 .43577 .14252 Metetra
.664 .741 .907 r
.43577 .14252 .43693 .14393 .44352 .1414 .44236 .13999 Metetra
.664 .741 .907 r
.44236 .13999 .44352 .1414 .45012 .13887 .44897 .13746 Metetra
.664 .741 .907 r
.44897 .13746 .45012 .13887 .45674 .13634 .45559 .13492 Metetra
.664 .741 .907 r
.45559 .13492 .45674 .13634 .46337 .13379 .46223 .13237 Metetra
.664 .741 .907 r
.46223 .13237 .46337 .13379 .47003 .13124 .46889 .12982 Metetra
.664 .741 .907 r
.46889 .12982 .47003 .13124 .47669 .12869 .47556 .12726 Metetra
.664 .741 .907 r
.47556 .12726 .47669 .12869 .48338 .12613 .48224 .1247 Metetra
.664 .741 .907 r
.48224 .1247 .48338 .12613 .49008 .12356 .48895 .12213 Metetra
.664 .741 .907 r
.48895 .12213 .49008 .12356 .49679 .12099 .49567 .11955 Metetra
.664 .741 .907 r
.49567 .11955 .49679 .12099 .50353 .11841 .5024 .11696 Metetra
.664 .741 .907 r
.5024 .11696 .50353 .11841 .51028 .11582 .50916 .11437 Metetra
.664 .741 .907 r
.50916 .11437 .51028 .11582 .51704 .11323 .51593 .11178 Metetra
.664 .741 .907 r
.51593 .11178 .51704 .11323 .52383 .11063 .52272 .10917 Metetra
.664 .741 .907 r
.52272 .10917 .52383 .11063 .53063 .10802 .52952 .10656 Metetra
.664 .741 .907 r
.52952 .10656 .53063 .10802 .53745 .10541 .53634 .10395 Metetra
.664 .741 .907 r
.53634 .10395 .53745 .10541 .54428 .10279 .54318 .10133 Metetra
.664 .741 .907 r
.54318 .10133 .54428 .10279 .55113 .10016 .55003 .0987 Metetra
.664 .741 .907 r
.55003 .0987 .55113 .10016 .558 .09753 .5569 .09606 Metetra
.664 .741 .907 r
.5569 .09606 .558 .09753 .56488 .09489 .56379 .09342 Metetra
.664 .741 .907 r
.56379 .09342 .56488 .09489 .57179 .09225 .5707 .09077 Metetra
.664 .741 .907 r
.5707 .09077 .57179 .09225 .57871 .0896 .57762 .08812 Metetra
.664 .741 .907 r
.57762 .08812 .57871 .0896 .58564 .08694 .58456 .08545 Metetra
.664 .741 .907 r
.58456 .08545 .58564 .08694 .5926 .08428 .59152 .08279 Metetra
.664 .741 .907 r
.59152 .08279 .5926 .08428 .59957 .0816 .59849 .08011 Metetra
.664 .741 .907 r
.59849 .08011 .59957 .0816 .60656 .07893 .60548 .07743 Metetra
.664 .741 .907 r
.60548 .07743 .60656 .07893 .61356 .07624 .61249 .07474 Metetra
.664 .741 .907 r
.61249 .07474 .61356 .07624 .62059 .07355 .61952 .07205 Metetra
.664 .741 .907 r
.61952 .07205 .62059 .07355 .62763 .07085 .62657 .06934 Metetra
.664 .741 .907 r
.62657 .06934 .62763 .07085 .63469 .06815 .63363 .06663 Metetra
.925 .557 .137 r
.63363 .06663 .63469 .06815 .64335 .10469 .6424 .10592 Metetra
.966 .642 .324 r
.6424 .10592 .64335 .10469 .65825 .28133 .65802 .3008 Metetra
.915 .683 .184 r
.65802 .3008 .65825 .28133 .65597 .05999 .65493 .05847 Metetra
.664 .741 .907 r
.65493 .05847 .65597 .05999 .66311 .05726 .66206 .05573 Metetra
.664 .741 .907 r
.66206 .05573 .66311 .05726 .67026 .05452 .66922 .05299 Metetra
.664 .741 .907 r
.66922 .05299 .67026 .05452 .67742 .05177 .67639 .05024 Metetra
.664 .741 .907 r
.67639 .05024 .67742 .05177 .68461 .04902 .68358 .04748 Metetra
.664 .741 .907 r
.68358 .04748 .68461 .04902 .69181 .04626 .69078 .04471 Metetra
.664 .741 .907 r
.69078 .04471 .69181 .04626 .69903 .04349 .69801 .04194 Metetra
.664 .741 .907 r
.69801 .04194 .69903 .04349 .70628 .04071 .70526 .03916 Metetra
.664 .741 .907 r
.70526 .03916 .70628 .04071 .71353 .03793 .71252 .03638 Metetra
.664 .741 .907 r
.06641 .28246 .06772 .28368 .07345 .28149 .07214 .28026 Metetra
.664 .741 .907 r
.07214 .28026 .07345 .28149 .07918 .27928 .07788 .27806 Metetra
.664 .741 .907 r
.07788 .27806 .07918 .27928 .08493 .27708 .08363 .27585 Metetra
.664 .741 .907 r
.08363 .27585 .08493 .27708 .09069 .27487 .08939 .27363 Metetra
.664 .741 .907 r
.08939 .27363 .09069 .27487 .09647 .27265 .09517 .27142 Metetra
.664 .741 .907 r
.09517 .27142 .09647 .27265 .10226 .27043 .10096 .26919 Metetra
.664 .741 .907 r
.10096 .26919 .10226 .27043 .10806 .26821 .10677 .26697 Metetra
.664 .741 .907 r
.10677 .26697 .10806 .26821 .11388 .26598 .11258 .26473 Metetra
.664 .741 .907 r
.11258 .26473 .11388 .26598 .1197 .26374 .11841 .26249 Metetra
.664 .741 .907 r
.11841 .26249 .1197 .26374 .12555 .2615 .12426 .26025 Metetra
.664 .741 .907 r
.12426 .26025 .12555 .2615 .1314 .25926 .13012 .258 Metetra
.664 .741 .907 r
.13012 .258 .1314 .25926 .13727 .25701 .13599 .25575 Metetra
.664 .741 .907 r
.13599 .25575 .13727 .25701 .14315 .25475 .14187 .25349 Metetra
.664 .741 .907 r
.14187 .25349 .14315 .25475 .14905 .25249 .14777 .25122 Metetra
0 .078 .578 r
.14777 .25122 .14905 .25249 .15478 .25168 .15287 .25571 Metetra
.15287 .25571 .15478 .25168 .16088 .24795 .15961 .24668 Metetra
.664 .741 .907 r
.15961 .24668 .16088 .24795 .16682 .24567 .16555 .2444 Metetra
.664 .741 .907 r
.16555 .2444 .16682 .24567 .17277 .24339 .1715 .24211 Metetra
.664 .741 .907 r
.1715 .24211 .17277 .24339 .17874 .2411 .17747 .23982 Metetra
.664 .741 .907 r
.17747 .23982 .17874 .2411 .18471 .23881 .18345 .23753 Metetra
.664 .741 .907 r
.18345 .23753 .18471 .23881 .19071 .23651 .18944 .23523 Metetra
.664 .741 .907 r
.18944 .23523 .19071 .23651 .19671 .23421 .19545 .23292 Metetra
.664 .741 .907 r
.19545 .23292 .19671 .23421 .20273 .2319 .20147 .23061 Metetra
.664 .741 .907 r
.20147 .23061 .20273 .2319 .20877 .22958 .20751 .22829 Metetra
.664 .741 .907 r
.20751 .22829 .20877 .22958 .21481 .22726 .21356 .22597 Metetra
.664 .741 .907 r
.21356 .22597 .21481 .22726 .22088 .22494 .21963 .22364 Metetra
.664 .741 .907 r
.21963 .22364 .22088 .22494 .22695 .22261 .22571 .22131 Metetra
.664 .741 .907 r
.22571 .22131 .22695 .22261 .23304 .22027 .2318 .21897 Metetra
.664 .741 .907 r
.2318 .21897 .23304 .22027 .23915 .21793 .23791 .21662 Metetra
.664 .741 .907 r
.23791 .21662 .23915 .21793 .24527 .21558 .24403 .21427 Metetra
.664 .741 .907 r
.24403 .21427 .24527 .21558 .2514 .21323 .25017 .21192 Metetra
.664 .741 .907 r
.25017 .21192 .2514 .21323 .25755 .21087 .25632 .20956 Metetra
.664 .741 .907 r
.25632 .20956 .25755 .21087 .26371 .20851 .26248 .20719 Metetra
.664 .741 .907 r
.26248 .20719 .26371 .20851 .26989 .20614 .26866 .20482 Metetra
.664 .741 .907 r
.26866 .20482 .26989 .20614 .27608 .20377 .27486 .20244 Metetra
.664 .741 .907 r
.27486 .20244 .27608 .20377 .28229 .20139 .28106 .20006 Metetra
.664 .741 .907 r
.28106 .20006 .28229 .20139 .28851 .199 .28729 .19767 Metetra
.664 .741 .907 r
.28729 .19767 .28851 .199 .29475 .19661 .29353 .19527 Metetra
.664 .741 .907 r
.29353 .19527 .29475 .19661 .301 .19421 .29978 .19287 Metetra
.961 .679 .453 r
.29978 .19287 .301 .19421 .2901 .42947 .28878 .42819 Metetra
.959 .703 .504 r
.28878 .42819 .2901 .42947 .31073 .22942 .30478 .29497 Metetra
.146 0 .371 r
.30478 .29497 .31073 .22942 .31984 .18698 .31863 .18564 Metetra
.664 .741 .907 r
.31863 .18564 .31984 .18698 .32615 .18456 .32494 .18321 Metetra
.664 .741 .907 r
.32494 .18321 .32615 .18456 .33247 .18214 .33127 .18078 Metetra
.664 .741 .907 r
.33127 .18078 .33247 .18214 .33882 .17971 .33762 .17835 Metetra
.664 .741 .907 r
.33762 .17835 .33882 .17971 .34517 .17727 .34397 .17591 Metetra
.664 .741 .907 r
.34397 .17591 .34517 .17727 .35154 .17483 .35035 .17346 Metetra
.664 .741 .907 r
.35035 .17346 .35154 .17483 .35793 .17238 .35674 .17101 Metetra
.664 .741 .907 r
.35674 .17101 .35793 .17238 .36433 .16992 .36314 .16855 Metetra
.664 .741 .907 r
.36314 .16855 .36433 .16992 .37075 .16746 .36956 .16608 Metetra
.664 .741 .907 r
.36956 .16608 .37075 .16746 .37718 .16499 .376 .16361 Metetra
.664 .741 .907 r
.376 .16361 .37718 .16499 .38363 .16252 .38245 .16114 Metetra
.664 .741 .907 r
.38245 .16114 .38363 .16252 .39009 .16004 .38891 .15866 Metetra
.664 .741 .907 r
.38891 .15866 .39009 .16004 .39657 .15756 .3954 .15617 Metetra
.664 .741 .907 r
.3954 .15617 .39657 .15756 .40306 .15506 .40189 .15367 Metetra
.664 .741 .907 r
.40189 .15367 .40306 .15506 .40957 .15257 .40841 .15117 Metetra
.664 .741 .907 r
.40841 .15117 .40957 .15257 .4161 .15006 .41494 .14867 Metetra
.664 .741 .907 r
.41494 .14867 .4161 .15006 .42264 .14756 .42148 .14615 Metetra
.664 .741 .907 r
.42148 .14615 .42264 .14756 .4292 .14504 .42804 .14363 Metetra
.664 .741 .907 r
.42804 .14363 .4292 .14504 .43577 .14252 .43462 .14111 Metetra
.664 .741 .907 r
.43462 .14111 .43577 .14252 .44236 .13999 .44121 .13858 Metetra
.664 .741 .907 r
.44121 .13858 .44236 .13999 .44897 .13746 .44782 .13604 Metetra
.664 .741 .907 r
.44782 .13604 .44897 .13746 .45559 .13492 .45445 .1335 Metetra
.664 .741 .907 r
.45445 .1335 .45559 .13492 .46223 .13237 .46109 .13095 Metetra
.229 .52 .915 r
.46109 .13095 .46223 .13237 .46889 .12982 .46766 .13282 Metetra
.024 0 .025 r
.46766 .13282 .46889 .12982 .47556 .12726 .47442 .12583 Metetra
.664 .741 .907 r
.47442 .12583 .47556 .12726 .48224 .1247 .48111 .12326 Metetra
.664 .741 .907 r
.48111 .12326 .48224 .1247 .48895 .12213 .48782 .12069 Metetra
.664 .741 .907 r
.48782 .12069 .48895 .12213 .49567 .11955 .49454 .11811 Metetra
.664 .741 .907 r
.49454 .11811 .49567 .11955 .5024 .11696 .50128 .11552 Metetra
.664 .741 .907 r
.50128 .11552 .5024 .11696 .50916 .11437 .50804 .11293 Metetra
.664 .741 .907 r
.50804 .11293 .50916 .11437 .51593 .11178 .51481 .11033 Metetra
.664 .741 .907 r
.51481 .11033 .51593 .11178 .52272 .10917 .5216 .10772 Metetra
.664 .741 .907 r
.5216 .10772 .52272 .10917 .52952 .10656 .52841 .10511 Metetra
.664 .741 .907 r
.52841 .10511 .52952 .10656 .53634 .10395 .53523 .10249 Metetra
.664 .741 .907 r
.53523 .10249 .53634 .10395 .54318 .10133 .54207 .09986 Metetra
.664 .741 .907 r
.54207 .09986 .54318 .10133 .55003 .0987 .54893 .09723 Metetra
.664 .741 .907 r
.54893 .09723 .55003 .0987 .5569 .09606 .5558 .09459 Metetra
.664 .741 .907 r
.5558 .09459 .5569 .09606 .56379 .09342 .5627 .09194 Metetra
.664 .741 .907 r
.5627 .09194 .56379 .09342 .5707 .09077 .56961 .08929 Metetra
.664 .741 .907 r
.56961 .08929 .5707 .09077 .57762 .08812 .57653 .08663 Metetra
.664 .741 .907 r
.57653 .08663 .57762 .08812 .58456 .08545 .58348 .08397 Metetra
.664 .741 .907 r
.58348 .08397 .58456 .08545 .59152 .08279 .59044 .08129 Metetra
.664 .741 .907 r
.59044 .08129 .59152 .08279 .59849 .08011 .59741 .07862 Metetra
.664 .741 .907 r
.59741 .07862 .59849 .08011 .60548 .07743 .60441 .07593 Metetra
.664 .741 .907 r
.60441 .07593 .60548 .07743 .61249 .07474 .61142 .07324 Metetra
.664 .741 .907 r
.61142 .07324 .61249 .07474 .61952 .07205 .61846 .07054 Metetra
.664 .741 .907 r
.61846 .07054 .61952 .07205 .62657 .06934 .62551 .06783 Metetra
.664 .741 .907 r
.62551 .06783 .62657 .06934 .63363 .06663 .63257 .06512 Metetra
.908 .529 .093 r
.63257 .06512 .63363 .06663 .6424 .10592 .64107 .09787 Metetra
.957 .657 .228 r
.64107 .09787 .6424 .10592 .65802 .3008 .65705 .30299 Metetra
.982 .692 .341 r
.65705 .30299 .65802 .3008 .65493 .05847 .65388 .05694 Metetra
.664 .741 .907 r
.65388 .05694 .65493 .05847 .66206 .05573 .66102 .0542 Metetra
.664 .741 .907 r
.66102 .0542 .66206 .05573 .66922 .05299 .66818 .05145 Metetra
.664 .741 .907 r
.66818 .05145 .66922 .05299 .67639 .05024 .67535 .0487 Metetra
.664 .741 .907 r
.67535 .0487 .67639 .05024 .68358 .04748 .68254 .04594 Metetra
.664 .741 .907 r
.68254 .04594 .68358 .04748 .69078 .04471 .68976 .04317 Metetra
.664 .741 .907 r
.68976 .04317 .69078 .04471 .69801 .04194 .69699 .04039 Metetra
.664 .741 .907 r
.69699 .04039 .69801 .04194 .70526 .03916 .70423 .03761 Metetra
.664 .741 .907 r
.70423 .03761 .70526 .03916 .71252 .03638 .7115 .03482 Metetra
.664 .741 .907 r
.0651 .28123 .06641 .28246 .07214 .28026 .07083 .27903 Metetra
.664 .741 .907 r
.07083 .27903 .07214 .28026 .07788 .27806 .07657 .27682 Metetra
.664 .741 .907 r
.07657 .27682 .07788 .27806 .08363 .27585 .08232 .27461 Metetra
.664 .741 .907 r
.08232 .27461 .08363 .27585 .08939 .27363 .08809 .2724 Metetra
.664 .741 .907 r
.08809 .2724 .08939 .27363 .09517 .27142 .09387 .27018 Metetra
.664 .741 .907 r
.09387 .27018 .09517 .27142 .10096 .26919 .09966 .26795 Metetra
.664 .741 .907 r
.09966 .26795 .10096 .26919 .10677 .26697 .10547 .26572 Metetra
.664 .741 .907 r
.10547 .26572 .10677 .26697 .11258 .26473 .11129 .26348 Metetra
.664 .741 .907 r
.11129 .26348 .11258 .26473 .11841 .26249 .11712 .26124 Metetra
.664 .741 .907 r
.11712 .26124 .11841 .26249 .12426 .26025 .12297 .259 Metetra
.664 .741 .907 r
.12297 .259 .12426 .26025 .13012 .258 .12883 .25675 Metetra
.664 .741 .907 r
.12883 .25675 .13012 .258 .13599 .25575 .1347 .25449 Metetra
.664 .741 .907 r
.1347 .25449 .13599 .25575 .14187 .25349 .14059 .25223 Metetra
.664 .741 .907 r
.14059 .25223 .14187 .25349 .14777 .25122 .14649 .24996 Metetra
.348 .612 .949 r
.14649 .24996 .14777 .25122 .15287 .25571 .15205 .25063 Metetra
.645 .486 .653 r
.15205 .25063 .15287 .25571 .15961 .24668 .15833 .24541 Metetra
.664 .741 .907 r
.15833 .24541 .15961 .24668 .16555 .2444 .16427 .24313 Metetra
.664 .741 .907 r
.16427 .24313 .16555 .2444 .1715 .24211 .17023 .24084 Metetra
.664 .741 .907 r
.17023 .24084 .1715 .24211 .17747 .23982 .1762 .23854 Metetra
.664 .741 .907 r
.1762 .23854 .17747 .23982 .18345 .23753 .18218 .23625 Metetra
.664 .741 .907 r
.18218 .23625 .18345 .23753 .18944 .23523 .18818 .23394 Metetra
.664 .741 .907 r
.18818 .23394 .18944 .23523 .19545 .23292 .19419 .23163 Metetra
.664 .741 .907 r
.19419 .23163 .19545 .23292 .20147 .23061 .20022 .22932 Metetra
.664 .741 .907 r
.20022 .22932 .20147 .23061 .20751 .22829 .20625 .227 Metetra
.664 .741 .907 r
.20625 .227 .20751 .22829 .21356 .22597 .21231 .22467 Metetra
.664 .741 .907 r
.21231 .22467 .21356 .22597 .21963 .22364 .21838 .22234 Metetra
.664 .741 .907 r
.21838 .22234 .21963 .22364 .22571 .22131 .22446 .22 Metetra
.664 .741 .907 r
.22446 .22 .22571 .22131 .2318 .21897 .23055 .21766 Metetra
.664 .741 .907 r
.23055 .21766 .2318 .21897 .23791 .21662 .23666 .21531 Metetra
.664 .741 .907 r
.23666 .21531 .23791 .21662 .24403 .21427 .24279 .21296 Metetra
.664 .741 .907 r
.24279 .21296 .24403 .21427 .25017 .21192 .24893 .2106 Metetra
.664 .741 .907 r
.24893 .2106 .25017 .21192 .25632 .20956 .25508 .20824 Metetra
.664 .741 .907 r
.25508 .20824 .25632 .20956 .26248 .20719 .26125 .20587 Metetra
.664 .741 .907 r
.26125 .20587 .26248 .20719 .26866 .20482 .26743 .20349 Metetra
.664 .741 .907 r
.26743 .20349 .26866 .20482 .27486 .20244 .27363 .20111 Metetra
.664 .741 .907 r
.27363 .20111 .27486 .20244 .28106 .20006 .27984 .19872 Metetra
.664 .741 .907 r
.27984 .19872 .28106 .20006 .28729 .19767 .28607 .19633 Metetra
.664 .741 .907 r
.28607 .19633 .28729 .19767 .29353 .19527 .29231 .19393 Metetra
.664 .741 .907 r
.29231 .19393 .29353 .19527 .29978 .19287 .29856 .19153 Metetra
.961 .679 .453 r
.29856 .19153 .29978 .19287 .28878 .42819 .28746 .42691 Metetra
.96 .698 .495 r
.28746 .42691 .28878 .42819 .30478 .29497 .3071 .24322 Metetra
.641 .392 .526 r
.3071 .24322 .30478 .29497 .31863 .18564 .31742 .18428 Metetra
.664 .741 .907 r
.31742 .18428 .31863 .18564 .32494 .18321 .32374 .18186 Metetra
.664 .741 .907 r
.32374 .18186 .32494 .18321 .33127 .18078 .33007 .17943 Metetra
.664 .741 .907 r
.33007 .17943 .33127 .18078 .33762 .17835 .33641 .17699 Metetra
.664 .741 .907 r
.33641 .17699 .33762 .17835 .34397 .17591 .34277 .17454 Metetra
.664 .741 .907 r
.34277 .17454 .34397 .17591 .35035 .17346 .34915 .17209 Metetra
.664 .741 .907 r
.34915 .17209 .35035 .17346 .35674 .17101 .35554 .16964 Metetra
.664 .741 .907 r
.35554 .16964 .35674 .17101 .36314 .16855 .36195 .16717 Metetra
.664 .741 .907 r
.36195 .16717 .36314 .16855 .36956 .16608 .36837 .16471 Metetra
.664 .741 .907 r
.36837 .16471 .36956 .16608 .376 .16361 .37481 .16223 Metetra
.664 .741 .907 r
.37481 .16223 .376 .16361 .38245 .16114 .38127 .15975 Metetra
.664 .741 .907 r
.38127 .15975 .38245 .16114 .38891 .15866 .38773 .15727 Metetra
.664 .741 .907 r
.38773 .15727 .38891 .15866 .3954 .15617 .39422 .15478 Metetra
.664 .741 .907 r
.39422 .15478 .3954 .15617 .40189 .15367 .40072 .15228 Metetra
.664 .741 .907 r
.40072 .15228 .40189 .15367 .40841 .15117 .40724 .14977 Metetra
.664 .741 .907 r
.40724 .14977 .40841 .15117 .41494 .14867 .41377 .14727 Metetra
.664 .741 .907 r
.41377 .14727 .41494 .14867 .42148 .14615 .42032 .14475 Metetra
.664 .741 .907 r
.42032 .14475 .42148 .14615 .42804 .14363 .42688 .14223 Metetra
.664 .741 .907 r
.42688 .14223 .42804 .14363 .43462 .14111 .43346 .1397 Metetra
.664 .741 .907 r
.43346 .1397 .43462 .14111 .44121 .13858 .44006 .13716 Metetra
.664 .741 .907 r
.44006 .13716 .44121 .13858 .44782 .13604 .44667 .13462 Metetra
.664 .741 .907 r
.44667 .13462 .44782 .13604 .45445 .1335 .4533 .13208 Metetra
.664 .741 .907 r
.4533 .13208 .45445 .1335 .46109 .13095 .45994 .12952 Metetra
.664 .741 .907 r
.45994 .12952 .46109 .13095 .46766 .13282 .4666 .12697 Metetra
.577 .428 .642 r
.4666 .12697 .46766 .13282 .47442 .12583 .47328 .1244 Metetra
.664 .741 .907 r
.47328 .1244 .47442 .12583 .48111 .12326 .47997 .12183 Metetra
.664 .741 .907 r
.47997 .12183 .48111 .12326 .48782 .12069 .48668 .11925 Metetra
.664 .741 .907 r
.48668 .11925 .48782 .12069 .49454 .11811 .49341 .11666 Metetra
.664 .741 .907 r
.49341 .11666 .49454 .11811 .50128 .11552 .50015 .11407 Metetra
.664 .741 .907 r
.50015 .11407 .50128 .11552 .50804 .11293 .50691 .11148 Metetra
.664 .741 .907 r
.50691 .11148 .50804 .11293 .51481 .11033 .51369 .10887 Metetra
.664 .741 .907 r
.51369 .10887 .51481 .11033 .5216 .10772 .52048 .10626 Metetra
.664 .741 .907 r
.52048 .10626 .5216 .10772 .52841 .10511 .52729 .10365 Metetra
.664 .741 .907 r
.52729 .10365 .52841 .10511 .53523 .10249 .53412 .10102 Metetra
.664 .741 .907 r
.53412 .10102 .53523 .10249 .54207 .09986 .54097 .09839 Metetra
.664 .741 .907 r
.54097 .09839 .54207 .09986 .54893 .09723 .54783 .09576 Metetra
.664 .741 .907 r
.54783 .09576 .54893 .09723 .5558 .09459 .5547 .09311 Metetra
.664 .741 .907 r
.5547 .09311 .5558 .09459 .5627 .09194 .5616 .09047 Metetra
.664 .741 .907 r
.5616 .09047 .5627 .09194 .56961 .08929 .56851 .08781 Metetra
.664 .741 .907 r
.56851 .08781 .56961 .08929 .57653 .08663 .57544 .08515 Metetra
.664 .741 .907 r
.57544 .08515 .57653 .08663 .58348 .08397 .58239 .08248 Metetra
.664 .741 .907 r
.58239 .08248 .58348 .08397 .59044 .08129 .58935 .0798 Metetra
.664 .741 .907 r
.58935 .0798 .59044 .08129 .59741 .07862 .59634 .07712 Metetra
.664 .741 .907 r
.59634 .07712 .59741 .07862 .60441 .07593 .60334 .07443 Metetra
.664 .741 .907 r
.60334 .07443 .60441 .07593 .61142 .07324 .61035 .07173 Metetra
.664 .741 .907 r
.61035 .07173 .61142 .07324 .61846 .07054 .61739 .06903 Metetra
.664 .741 .907 r
.61739 .06903 .61846 .07054 .62551 .06783 .62444 .06632 Metetra
.664 .741 .907 r
.62444 .06632 .62551 .06783 .63257 .06512 .63151 .0636 Metetra
.928 .562 .145 r
.63151 .0636 .63257 .06512 .64107 .09787 .64032 .10442 Metetra
.947 .616 .366 r
.64032 .10442 .64107 .09787 .65705 .30299 .65465 .27144 Metetra
.883 .58 .468 r
.65465 .27144 .65705 .30299 .65388 .05694 .65283 .05541 Metetra
.664 .741 .907 r
.65283 .05541 .65388 .05694 .66102 .0542 .65997 .05267 Metetra
.664 .741 .907 r
.65997 .05267 .66102 .0542 .66818 .05145 .66713 .04992 Metetra
.664 .741 .907 r
.66713 .04992 .66818 .05145 .67535 .0487 .67431 .04716 Metetra
.664 .741 .907 r
.67431 .04716 .67535 .0487 .68254 .04594 .68151 .04439 Metetra
.664 .741 .907 r
.68151 .04439 .68254 .04594 .68976 .04317 .68872 .04162 Metetra
.664 .741 .907 r
.68872 .04162 .68976 .04317 .69699 .04039 .69596 .03884 Metetra
.664 .741 .907 r
.69596 .03884 .69699 .04039 .70423 .03761 .70321 .03606 Metetra
.664 .741 .907 r
.70321 .03606 .70423 .03761 .7115 .03482 .71048 .03326 Metetra
.664 .741 .907 r
.06379 .28 .0651 .28123 .07083 .27903 .06952 .2778 Metetra
.664 .741 .907 r
.06952 .2778 .07083 .27903 .07657 .27682 .07526 .27559 Metetra
.664 .741 .907 r
.07526 .27559 .07657 .27682 .08232 .27461 .08101 .27338 Metetra
.664 .741 .907 r
.08101 .27338 .08232 .27461 .08809 .2724 .08678 .27116 Metetra
.664 .741 .907 r
.08678 .27116 .08809 .2724 .09387 .27018 .09257 .26894 Metetra
.664 .741 .907 r
.09257 .26894 .09387 .27018 .09966 .26795 .09836 .26671 Metetra
.664 .741 .907 r
.09836 .26671 .09966 .26795 .10547 .26572 .10417 .26447 Metetra
.664 .741 .907 r
.10417 .26447 .10547 .26572 .11129 .26348 .10999 .26223 Metetra
.664 .741 .907 r
.10999 .26223 .11129 .26348 .11712 .26124 .11583 .25999 Metetra
.664 .741 .907 r
.11583 .25999 .11712 .26124 .12297 .259 .12168 .25774 Metetra
.664 .741 .907 r
.12168 .25774 .12297 .259 .12883 .25675 .12754 .25549 Metetra
.664 .741 .907 r
.12754 .25549 .12883 .25675 .1347 .25449 .13342 .25323 Metetra
.664 .741 .907 r
.13342 .25323 .1347 .25449 .14059 .25223 .1393 .25096 Metetra
.664 .741 .907 r
.1393 .25096 .14059 .25223 .14649 .24996 .14521 .24869 Metetra
.945 .599 .33 r
.14521 .24869 .14649 .24996 .15205 .25063 .14808 .27142 Metetra
.209 0 .345 r
.14808 .27142 .15205 .25063 .15833 .24541 .15705 .24414 Metetra
.664 .741 .907 r
.15705 .24414 .15833 .24541 .16427 .24313 .163 .24185 Metetra
.664 .741 .907 r
.163 .24185 .16427 .24313 .17023 .24084 .16896 .23956 Metetra
.664 .741 .907 r
.16896 .23956 .17023 .24084 .1762 .23854 .17493 .23726 Metetra
.664 .741 .907 r
.17493 .23726 .1762 .23854 .18218 .23625 .18091 .23496 Metetra
.664 .741 .907 r
.18091 .23496 .18218 .23625 .18818 .23394 .18691 .23265 Metetra
.664 .741 .907 r
.18691 .23265 .18818 .23394 .19419 .23163 .19293 .23034 Metetra
.664 .741 .907 r
.19293 .23034 .19419 .23163 .20022 .22932 .19895 .22802 Metetra
.664 .741 .907 r
.19895 .22802 .20022 .22932 .20625 .227 .205 .2257 Metetra
.664 .741 .907 r
.205 .2257 .20625 .227 .21231 .22467 .21105 .22337 Metetra
.664 .741 .907 r
.21105 .22337 .21231 .22467 .21838 .22234 .21712 .22104 Metetra
.664 .741 .907 r
.21712 .22104 .21838 .22234 .22446 .22 .22321 .2187 Metetra
.664 .741 .907 r
.22321 .2187 .22446 .22 .23055 .21766 .2293 .21635 Metetra
.664 .741 .907 r
.2293 .21635 .23055 .21766 .23666 .21531 .23542 .214 Metetra
.664 .741 .907 r
.23542 .214 .23666 .21531 .24279 .21296 .24154 .21165 Metetra
.664 .741 .907 r
.24154 .21165 .24279 .21296 .24893 .2106 .24769 .20928 Metetra
.664 .741 .907 r
.24769 .20928 .24893 .2106 .25508 .20824 .25384 .20692 Metetra
.664 .741 .907 r
.25384 .20692 .25508 .20824 .26125 .20587 .26001 .20454 Metetra
.664 .741 .907 r
.26001 .20454 .26125 .20587 .26743 .20349 .2662 .20216 Metetra
.664 .741 .907 r
.2662 .20216 .26743 .20349 .27363 .20111 .2724 .19978 Metetra
.664 .741 .907 r
.2724 .19978 .27363 .20111 .27984 .19872 .27861 .19739 Metetra
.664 .741 .907 r
.27861 .19739 .27984 .19872 .28607 .19633 .28484 .19499 Metetra
.664 .741 .907 r
.28484 .19499 .28607 .19633 .29231 .19393 .29108 .19259 Metetra
.664 .741 .907 r
.29108 .19259 .29231 .19393 .29856 .19153 .29734 .19019 Metetra
.961 .679 .453 r
.29734 .19019 .29856 .19153 .28746 .42691 .28613 .42563 Metetra
.957 .711 .524 r
.28613 .42563 .28746 .42691 .3071 .24322 .29855 .34421 Metetra
.171 0 .385 r
.29855 .34421 .3071 .24322 .31742 .18428 .31598 .18618 Metetra
.31598 .18618 .31742 .18428 .32374 .18186 .32253 .1805 Metetra
.664 .741 .907 r
.32253 .1805 .32374 .18186 .33007 .17943 .32886 .17807 Metetra
.664 .741 .907 r
.32886 .17807 .33007 .17943 .33641 .17699 .33521 .17562 Metetra
.664 .741 .907 r
.33521 .17562 .33641 .17699 .34277 .17454 .34157 .17318 Metetra
.664 .741 .907 r
.34157 .17318 .34277 .17454 .34915 .17209 .34795 .17072 Metetra
.664 .741 .907 r
.34795 .17072 .34915 .17209 .35554 .16964 .35435 .16826 Metetra
.664 .741 .907 r
.35435 .16826 .35554 .16964 .36195 .16717 .36076 .1658 Metetra
.664 .741 .907 r
.36076 .1658 .36195 .16717 .36837 .16471 .36718 .16333 Metetra
.664 .741 .907 r
.36718 .16333 .36837 .16471 .37481 .16223 .37363 .16085 Metetra
.664 .741 .907 r
.37363 .16085 .37481 .16223 .38127 .15975 .38008 .15837 Metetra
.664 .741 .907 r
.38008 .15837 .38127 .15975 .38773 .15727 .38655 .15588 Metetra
.664 .741 .907 r
.38655 .15588 .38773 .15727 .39422 .15478 .39304 .15338 Metetra
.664 .741 .907 r
.39304 .15338 .39422 .15478 .40072 .15228 .39955 .15088 Metetra
.664 .741 .907 r
.39955 .15088 .40072 .15228 .40724 .14977 .40607 .14838 Metetra
.664 .741 .907 r
.40607 .14838 .40724 .14977 .41377 .14727 .4126 .14586 Metetra
.664 .741 .907 r
.4126 .14586 .41377 .14727 .42032 .14475 .41915 .14334 Metetra
.664 .741 .907 r
.41915 .14334 .42032 .14475 .42688 .14223 .42572 .14082 Metetra
.664 .741 .907 r
.42572 .14082 .42688 .14223 .43346 .1397 .4323 .13829 Metetra
.664 .741 .907 r
.4323 .13829 .43346 .1397 .44006 .13716 .4389 .13575 Metetra
.664 .741 .907 r
.4389 .13575 .44006 .13716 .44667 .13462 .44552 .1332 Metetra
.664 .741 .907 r
.44552 .1332 .44667 .13462 .4533 .13208 .45215 .13065 Metetra
.664 .741 .907 r
.45215 .13065 .4533 .13208 .45994 .12952 .4588 .1281 Metetra
.795 .353 0 r
.4588 .1281 .45994 .12952 .4666 .12697 .46515 .14113 Metetra
.273 .04 .367 r
.46515 .14113 .4666 .12697 .47328 .1244 .47214 .12297 Metetra
.664 .741 .907 r
.47214 .12297 .47328 .1244 .47997 .12183 .47884 .12039 Metetra
.664 .741 .907 r
.47884 .12039 .47997 .12183 .48668 .11925 .48555 .11781 Metetra
.664 .741 .907 r
.48555 .11781 .48668 .11925 .49341 .11666 .49228 .11522 Metetra
.664 .741 .907 r
.49228 .11522 .49341 .11666 .50015 .11407 .49903 .11263 Metetra
.664 .741 .907 r
.49903 .11263 .50015 .11407 .50691 .11148 .50579 .11003 Metetra
.664 .741 .907 r
.50579 .11003 .50691 .11148 .51369 .10887 .51257 .10742 Metetra
.664 .741 .907 r
.51257 .10742 .51369 .10887 .52048 .10626 .51937 .1048 Metetra
.664 .741 .907 r
.51937 .1048 .52048 .10626 .52729 .10365 .52618 .10218 Metetra
.664 .741 .907 r
.52618 .10218 .52729 .10365 .53412 .10102 .53301 .09956 Metetra
.664 .741 .907 r
.53301 .09956 .53412 .10102 .54097 .09839 .53986 .09692 Metetra
.664 .741 .907 r
.53986 .09692 .54097 .09839 .54783 .09576 .54672 .09428 Metetra
.664 .741 .907 r
.54672 .09428 .54783 .09576 .5547 .09311 .5536 .09164 Metetra
.664 .741 .907 r
.5536 .09164 .5547 .09311 .5616 .09047 .5605 .08898 Metetra
.664 .741 .907 r
.5605 .08898 .5616 .09047 .56851 .08781 .56742 .08633 Metetra
.664 .741 .907 r
.56742 .08633 .56851 .08781 .57544 .08515 .57435 .08366 Metetra
.664 .741 .907 r
.57435 .08366 .57544 .08515 .58239 .08248 .5813 .08099 Metetra
.664 .741 .907 r
.5813 .08099 .58239 .08248 .58935 .0798 .58827 .07831 Metetra
.664 .741 .907 r
.58827 .07831 .58935 .0798 .59634 .07712 .59526 .07562 Metetra
.664 .741 .907 r
.59526 .07562 .59634 .07712 .60334 .07443 .60226 .07293 Metetra
.664 .741 .907 r
.60226 .07293 .60334 .07443 .61035 .07173 .60928 .07023 Metetra
.664 .741 .907 r
.60928 .07023 .61035 .07173 .61739 .06903 .61632 .06752 Metetra
.664 .741 .907 r
.61632 .06752 .61739 .06903 .62444 .06632 .62338 .06481 Metetra
.664 .741 .907 r
.62338 .06481 .62444 .06632 .63151 .0636 .63045 .06209 Metetra
.963 .633 .268 r
.63045 .06209 .63151 .0636 .64032 .10442 .6417 .16568 Metetra
.697 .408 .481 r
.6417 .16568 .64032 .10442 .65465 .27144 .65478 .30006 Metetra
.818 .634 .082 r
.65478 .30006 .65465 .27144 .65283 .05541 .65178 .05388 Metetra
.664 .741 .907 r
.65178 .05388 .65283 .05541 .65997 .05267 .65893 .05113 Metetra
.664 .741 .907 r
.65893 .05113 .65997 .05267 .66713 .04992 .66609 .04838 Metetra
.664 .741 .907 r
.66609 .04838 .66713 .04992 .67431 .04716 .67327 .04562 Metetra
.664 .741 .907 r
.67327 .04562 .67431 .04716 .68151 .04439 .68047 .04285 Metetra
.664 .741 .907 r
.68047 .04285 .68151 .04439 .68872 .04162 .68769 .04007 Metetra
.664 .741 .907 r
.68769 .04007 .68872 .04162 .69596 .03884 .69493 .03729 Metetra
.664 .741 .907 r
.69493 .03729 .69596 .03884 .70321 .03606 .70219 .0345 Metetra
.664 .741 .907 r
.70219 .0345 .70321 .03606 .71048 .03326 .70946 .0317 Metetra
.664 .741 .907 r
.06247 .27878 .06379 .28 .06952 .2778 .0682 .27657 Metetra
.664 .741 .907 r
.0682 .27657 .06952 .2778 .07526 .27559 .07395 .27436 Metetra
.664 .741 .907 r
.07395 .27436 .07526 .27559 .08101 .27338 .07971 .27214 Metetra
.664 .741 .907 r
.07971 .27214 .08101 .27338 .08678 .27116 .08548 .26992 Metetra
.664 .741 .907 r
.08548 .26992 .08678 .27116 .09257 .26894 .09126 .26769 Metetra
.664 .741 .907 r
.09126 .26769 .09257 .26894 .09836 .26671 .09706 .26546 Metetra
.664 .741 .907 r
.09706 .26546 .09836 .26671 .10417 .26447 .10287 .26323 Metetra
.664 .741 .907 r
.10287 .26323 .10417 .26447 .10999 .26223 .10869 .26098 Metetra
.664 .741 .907 r
.10869 .26098 .10999 .26223 .11583 .25999 .11453 .25874 Metetra
.664 .741 .907 r
.11453 .25874 .11583 .25999 .12168 .25774 .12038 .25648 Metetra
.664 .741 .907 r
.12038 .25648 .12168 .25774 .12754 .25549 .12625 .25423 Metetra
.664 .741 .907 r
.12625 .25423 .12754 .25549 .13342 .25323 .13213 .25196 Metetra
.664 .741 .907 r
.13213 .25196 .13342 .25323 .1393 .25096 .13802 .2497 Metetra
.664 .741 .907 r
.13802 .2497 .1393 .25096 .14521 .24869 .14392 .24742 Metetra
.916 .517 .184 r
.14392 .24742 .14521 .24869 .14808 .27142 .14786 .26135 Metetra
.702 .482 .587 r
.14786 .26135 .14808 .27142 .15705 .24414 .15578 .24286 Metetra
.664 .741 .907 r
.15578 .24286 .15705 .24414 .163 .24185 .16172 .24057 Metetra
.664 .741 .907 r
.16172 .24057 .163 .24185 .16896 .23956 .16768 .23828 Metetra
.664 .741 .907 r
.16768 .23828 .16896 .23956 .17493 .23726 .17366 .23598 Metetra
.664 .741 .907 r
.17366 .23598 .17493 .23726 .18091 .23496 .17964 .23367 Metetra
.664 .741 .907 r
.17964 .23367 .18091 .23496 .18691 .23265 .18565 .23136 Metetra
.664 .741 .907 r
.18565 .23136 .18691 .23265 .19293 .23034 .19166 .22905 Metetra
.664 .741 .907 r
.19166 .22905 .19293 .23034 .19895 .22802 .19769 .22673 Metetra
.664 .741 .907 r
.19769 .22673 .19895 .22802 .205 .2257 .20374 .2244 Metetra
.664 .741 .907 r
.20374 .2244 .205 .2257 .21105 .22337 .20979 .22207 Metetra
.664 .741 .907 r
.20979 .22207 .21105 .22337 .21712 .22104 .21587 .21973 Metetra
.664 .741 .907 r
.21587 .21973 .21712 .22104 .22321 .2187 .22195 .21739 Metetra
.664 .741 .907 r
.22195 .21739 .22321 .2187 .2293 .21635 .22805 .21504 Metetra
.664 .741 .907 r
.22805 .21504 .2293 .21635 .23542 .214 .23417 .21269 Metetra
.664 .741 .907 r
.23417 .21269 .23542 .214 .24154 .21165 .2403 .21033 Metetra
.664 .741 .907 r
.2403 .21033 .24154 .21165 .24769 .20928 .24644 .20796 Metetra
.664 .741 .907 r
.24644 .20796 .24769 .20928 .25384 .20692 .2526 .20559 Metetra
.664 .741 .907 r
.2526 .20559 .25384 .20692 .26001 .20454 .25877 .20322 Metetra
.664 .741 .907 r
.25877 .20322 .26001 .20454 .2662 .20216 .26496 .20084 Metetra
.664 .741 .907 r
.26496 .20084 .2662 .20216 .2724 .19978 .27116 .19845 Metetra
.664 .741 .907 r
.27116 .19845 .2724 .19978 .27861 .19739 .27738 .19605 Metetra
.664 .741 .907 r
.27738 .19605 .27861 .19739 .28484 .19499 .28361 .19366 Metetra
.664 .741 .907 r
.28361 .19366 .28484 .19499 .29108 .19259 .28986 .19125 Metetra
.664 .741 .907 r
.28986 .19125 .29108 .19259 .29734 .19019 .29612 .18884 Metetra
.961 .679 .453 r
.29612 .18884 .29734 .19019 .28613 .42563 .28481 .42434 Metetra
.958 .708 .516 r
.28481 .42434 .28613 .42563 .29855 .34421 .29826 .32908 Metetra
.889 .621 .525 r
.29826 .32908 .29855 .34421 .31598 .18618 .315 .18158 Metetra
.591 .463 .675 r
.315 .18158 .31598 .18618 .32253 .1805 .32132 .17914 Metetra
.664 .741 .907 r
.32132 .17914 .32253 .1805 .32886 .17807 .32765 .1767 Metetra
.664 .741 .907 r
.32765 .1767 .32886 .17807 .33521 .17562 .33401 .17426 Metetra
.664 .741 .907 r
.33401 .17426 .33521 .17562 .34157 .17318 .34037 .17181 Metetra
.664 .741 .907 r
.34037 .17181 .34157 .17318 .34795 .17072 .34675 .16935 Metetra
.664 .741 .907 r
.34675 .16935 .34795 .17072 .35435 .16826 .35315 .16689 Metetra
.664 .741 .907 r
.35315 .16689 .35435 .16826 .36076 .1658 .35957 .16442 Metetra
.664 .741 .907 r
.35957 .16442 .36076 .1658 .36718 .16333 .36599 .16195 Metetra
.664 .741 .907 r
.36599 .16195 .36718 .16333 .37363 .16085 .37244 .15947 Metetra
.664 .741 .907 r
.37244 .15947 .37363 .16085 .38008 .15837 .3789 .15698 Metetra
.664 .741 .907 r
.3789 .15698 .38008 .15837 .38655 .15588 .38537 .15449 Metetra
.664 .741 .907 r
.38537 .15449 .38655 .15588 .39304 .15338 .39186 .15199 Metetra
.664 .741 .907 r
.39186 .15199 .39304 .15338 .39955 .15088 .39837 .14949 Metetra
.664 .741 .907 r
.39837 .14949 .39955 .15088 .40607 .14838 .40489 .14697 Metetra
.664 .741 .907 r
.40489 .14697 .40607 .14838 .4126 .14586 .41143 .14446 Metetra
.664 .741 .907 r
.41143 .14446 .4126 .14586 .41915 .14334 .41798 .14194 Metetra
.664 .741 .907 r
.41798 .14194 .41915 .14334 .42572 .14082 .42456 .13941 Metetra
.664 .741 .907 r
.42456 .13941 .42572 .14082 .4323 .13829 .43114 .13687 Metetra
.664 .741 .907 r
.43114 .13687 .4323 .13829 .4389 .13575 .43774 .13433 Metetra
.664 .741 .907 r
.43774 .13433 .4389 .13575 .44552 .1332 .44436 .13178 Metetra
.664 .741 .907 r
.44436 .13178 .44552 .1332 .45215 .13065 .451 .12923 Metetra
.664 .741 .907 r
.451 .12923 .45215 .13065 .4588 .1281 .45765 .12667 Metetra
.825 .392 0 r
.45765 .12667 .4588 .1281 .46515 .14113 .46397 .14099 Metetra
.985 .844 .619 r
.46397 .14099 .46515 .14113 .47214 .12297 .471 .12153 Metetra
.664 .741 .907 r
.471 .12153 .47214 .12297 .47884 .12039 .4777 .11895 Metetra
.664 .741 .907 r
.4777 .11895 .47884 .12039 .48555 .11781 .48441 .11637 Metetra
.664 .741 .907 r
.48441 .11637 .48555 .11781 .49228 .11522 .49115 .11377 Metetra
.664 .741 .907 r
.49115 .11377 .49228 .11522 .49903 .11263 .4979 .11118 Metetra
.664 .741 .907 r
.4979 .11118 .49903 .11263 .50579 .11003 .50466 .10857 Metetra
.664 .741 .907 r
.50466 .10857 .50579 .11003 .51257 .10742 .51145 .10596 Metetra
.664 .741 .907 r
.51145 .10596 .51257 .10742 .51937 .1048 .51825 .10334 Metetra
.664 .741 .907 r
.51825 .10334 .51937 .1048 .52618 .10218 .52506 .10072 Metetra
.664 .741 .907 r
.52506 .10072 .52618 .10218 .53301 .09956 .5319 .09809 Metetra
.664 .741 .907 r
.5319 .09809 .53301 .09956 .53986 .09692 .53875 .09545 Metetra
.664 .741 .907 r
.53875 .09545 .53986 .09692 .54672 .09428 .54562 .09281 Metetra
.664 .741 .907 r
.54562 .09281 .54672 .09428 .5536 .09164 .5525 .09016 Metetra
.664 .741 .907 r
.5525 .09016 .5536 .09164 .5605 .08898 .5594 .0875 Metetra
.664 .741 .907 r
.5594 .0875 .5605 .08898 .56742 .08633 .56632 .08484 Metetra
.664 .741 .907 r
.56632 .08484 .56742 .08633 .57435 .08366 .57326 .08217 Metetra
.664 .741 .907 r
.57326 .08217 .57435 .08366 .5813 .08099 .58021 .07949 Metetra
.664 .741 .907 r
.58021 .07949 .5813 .08099 .58827 .07831 .58719 .07681 Metetra
.664 .741 .907 r
.58719 .07681 .58827 .07831 .59526 .07562 .59417 .07412 Metetra
.664 .741 .907 r
.59417 .07412 .59526 .07562 .60226 .07293 .60118 .07142 Metetra
.664 .741 .907 r
.60118 .07142 .60226 .07293 .60928 .07023 .60821 .06872 Metetra
.664 .741 .907 r
.60821 .06872 .60928 .07023 .61632 .06752 .61525 .06601 Metetra
.664 .741 .907 r
.61525 .06601 .61632 .06752 .62338 .06481 .62231 .06329 Metetra
.664 .741 .907 r
.62231 .06329 .62338 .06481 .63045 .06209 .62939 .06057 Metetra
.963 .635 .271 r
.62939 .06057 .63045 .06209 .6417 .16568 .6408 .16935 Metetra
.952 .616 .343 r
.6408 .16935 .6417 .16568 .65478 .30006 .65364 .29859 Metetra
.979 .685 .364 r
.65364 .29859 .65478 .30006 .65178 .05388 .65073 .05235 Metetra
.664 .741 .907 r
.65073 .05235 .65178 .05388 .65893 .05113 .65788 .0496 Metetra
.664 .741 .907 r
.65788 .0496 .65893 .05113 .66609 .04838 .66504 .04684 Metetra
.664 .741 .907 r
.66504 .04684 .66609 .04838 .67327 .04562 .67223 .04407 Metetra
.664 .741 .907 r
.67223 .04407 .67327 .04562 .68047 .04285 .67944 .0413 Metetra
.664 .741 .907 r
.67944 .0413 .68047 .04285 .68769 .04007 .68666 .03852 Metetra
.664 .741 .907 r
.68666 .03852 .68769 .04007 .69493 .03729 .6939 .03573 Metetra
.664 .741 .907 r
.6939 .03573 .69493 .03729 .70219 .0345 .70116 .03294 Metetra
.664 .741 .907 r
.70116 .03294 .70219 .0345 .70946 .0317 .70844 .03014 Metetra
.664 .741 .907 r
.06115 .27755 .06247 .27878 .0682 .27657 .06689 .27534 Metetra
.664 .741 .907 r
.06689 .27534 .0682 .27657 .07395 .27436 .07264 .27312 Metetra
.664 .741 .907 r
.07264 .27312 .07395 .27436 .07971 .27214 .0784 .2709 Metetra
.664 .741 .907 r
.0784 .2709 .07971 .27214 .08548 .26992 .08417 .26868 Metetra
.664 .741 .907 r
.08417 .26868 .08548 .26992 .09126 .26769 .08996 .26645 Metetra
.664 .741 .907 r
.08996 .26645 .09126 .26769 .09706 .26546 .09576 .26422 Metetra
.664 .741 .907 r
.09576 .26422 .09706 .26546 .10287 .26323 .10157 .26198 Metetra
.664 .741 .907 r
.10157 .26198 .10287 .26323 .10869 .26098 .1074 .25973 Metetra
.664 .741 .907 r
.1074 .25973 .10869 .26098 .11453 .25874 .11324 .25748 Metetra
.664 .741 .907 r
.11324 .25748 .11453 .25874 .12038 .25648 .11909 .25523 Metetra
.664 .741 .907 r
.11909 .25523 .12038 .25648 .12625 .25423 .12496 .25297 Metetra
.664 .741 .907 r
.12496 .25297 .12625 .25423 .13213 .25196 .13084 .2507 Metetra
.664 .741 .907 r
.13084 .2507 .13213 .25196 .13802 .2497 .13673 .24843 Metetra
.664 .741 .907 r
.13673 .24843 .13802 .2497 .14392 .24742 .14264 .24615 Metetra
.878 .444 .068 r
.14264 .24615 .14392 .24742 .14786 .26135 .14694 .25704 Metetra
.788 .595 .64 r
.14694 .25704 .14786 .26135 .15578 .24286 .15449 .24159 Metetra
.664 .741 .907 r
.15449 .24159 .15578 .24286 .16172 .24057 .16044 .23929 Metetra
.664 .741 .907 r
.16044 .23929 .16172 .24057 .16768 .23828 .16641 .237 Metetra
.664 .741 .907 r
.16641 .237 .16768 .23828 .17366 .23598 .17238 .23469 Metetra
.664 .741 .907 r
.17238 .23469 .17366 .23598 .17964 .23367 .17837 .23239 Metetra
.664 .741 .907 r
.17837 .23239 .17964 .23367 .18565 .23136 .18438 .23007 Metetra
.664 .741 .907 r
.18438 .23007 .18565 .23136 .19166 .22905 .1904 .22776 Metetra
.664 .741 .907 r
.1904 .22776 .19166 .22905 .19769 .22673 .19643 .22543 Metetra
.664 .741 .907 r
.19643 .22543 .19769 .22673 .20374 .2244 .20247 .2231 Metetra
.664 .741 .907 r
.20247 .2231 .20374 .2244 .20979 .22207 .20853 .22077 Metetra
.664 .741 .907 r
.20853 .22077 .20979 .22207 .21587 .21973 .21461 .21843 Metetra
.664 .741 .907 r
.21461 .21843 .21587 .21973 .22195 .21739 .2207 .21608 Metetra
.664 .741 .907 r
.2207 .21608 .22195 .21739 .22805 .21504 .2268 .21373 Metetra
.664 .741 .907 r
.2268 .21373 .22805 .21504 .23417 .21269 .23292 .21137 Metetra
.664 .741 .907 r
.23292 .21137 .23417 .21269 .2403 .21033 .23905 .20901 Metetra
.664 .741 .907 r
.23905 .20901 .2403 .21033 .24644 .20796 .2452 .20664 Metetra
.664 .741 .907 r
.2452 .20664 .24644 .20796 .2526 .20559 .25136 .20427 Metetra
.664 .741 .907 r
.25136 .20427 .2526 .20559 .25877 .20322 .25754 .20189 Metetra
.664 .741 .907 r
.25754 .20189 .25877 .20322 .26496 .20084 .26373 .1995 Metetra
.664 .741 .907 r
.26373 .1995 .26496 .20084 .27116 .19845 .26993 .19711 Metetra
.664 .741 .907 r
.26993 .19711 .27116 .19845 .27738 .19605 .27615 .19472 Metetra
.664 .741 .907 r
.27615 .19472 .27738 .19605 .28361 .19366 .28239 .19232 Metetra
.664 .741 .907 r
.28239 .19232 .28361 .19366 .28986 .19125 .28863 .18991 Metetra
.664 .741 .907 r
.28863 .18991 .28986 .19125 .29612 .18884 .2949 .18749 Metetra
.961 .679 .453 r
.2949 .18749 .29612 .18884 .28481 .42434 .28348 .42306 Metetra
.958 .708 .516 r
.28348 .42306 .28481 .42434 .29826 .32908 .29706 .32653 Metetra
.954 .693 .503 r
.29706 .32653 .29826 .32908 .315 .18158 .31378 .18022 Metetra
.664 .741 .907 r
.31378 .18022 .315 .18158 .32132 .17914 .32011 .17778 Metetra
.664 .741 .907 r
.32011 .17778 .32132 .17914 .32765 .1767 .32644 .17534 Metetra
.664 .741 .907 r
.32644 .17534 .32765 .1767 .33401 .17426 .3328 .17289 Metetra
.664 .741 .907 r
.3328 .17289 .33401 .17426 .34037 .17181 .33917 .17044 Metetra
.664 .741 .907 r
.33917 .17044 .34037 .17181 .34675 .16935 .34555 .16798 Metetra
.664 .741 .907 r
.34555 .16798 .34675 .16935 .35315 .16689 .35195 .16551 Metetra
.664 .741 .907 r
.35195 .16551 .35315 .16689 .35957 .16442 .35837 .16304 Metetra
.664 .741 .907 r
.35837 .16304 .35957 .16442 .36599 .16195 .3648 .16056 Metetra
.664 .741 .907 r
.3648 .16056 .36599 .16195 .37244 .15947 .37125 .15808 Metetra
.664 .741 .907 r
.37125 .15808 .37244 .15947 .3789 .15698 .37771 .15559 Metetra
.664 .741 .907 r
.37771 .15559 .3789 .15698 .38537 .15449 .38419 .1531 Metetra
.664 .741 .907 r
.38419 .1531 .38537 .15449 .39186 .15199 .39068 .15059 Metetra
.664 .741 .907 r
.39068 .15059 .39186 .15199 .39837 .14949 .39719 .14809 Metetra
.664 .741 .907 r
.39719 .14809 .39837 .14949 .40489 .14697 .40372 .14557 Metetra
.664 .741 .907 r
.40372 .14557 .40489 .14697 .41143 .14446 .41026 .14305 Metetra
.664 .741 .907 r
.41026 .14305 .41143 .14446 .41798 .14194 .41682 .14053 Metetra
.664 .741 .907 r
.41682 .14053 .41798 .14194 .42456 .13941 .42339 .13799 Metetra
.664 .741 .907 r
.42339 .13799 .42456 .13941 .43114 .13687 .42998 .13545 Metetra
.664 .741 .907 r
.42998 .13545 .43114 .13687 .43774 .13433 .43658 .13291 Metetra
.664 .741 .907 r
.43658 .13291 .43774 .13433 .44436 .13178 .44321 .13036 Metetra
.664 .741 .907 r
.44321 .13036 .44436 .13178 .451 .12923 .44984 .1278 Metetra
.664 .741 .907 r
.44984 .1278 .451 .12923 .45765 .12667 .4565 .12524 Metetra
0 .221 .731 r
.4565 .12524 .45765 .12667 .46397 .14099 .46301 .13005 Metetra
.622 .412 .576 r
.46301 .13005 .46397 .14099 .471 .12153 .46985 .12009 Metetra
.664 .741 .907 r
.46985 .12009 .471 .12153 .4777 .11895 .47656 .11751 Metetra
.664 .741 .907 r
.47656 .11751 .4777 .11895 .48441 .11637 .48328 .11492 Metetra
.664 .741 .907 r
.48328 .11492 .48441 .11637 .49115 .11377 .49001 .11233 Metetra
.664 .741 .907 r
.49001 .11233 .49115 .11377 .4979 .11118 .49677 .10972 Metetra
.664 .741 .907 r
.49677 .10972 .4979 .11118 .50466 .10857 .50354 .10712 Metetra
.664 .741 .907 r
.50354 .10712 .50466 .10857 .51145 .10596 .51032 .1045 Metetra
.664 .741 .907 r
.51032 .1045 .51145 .10596 .51825 .10334 .51713 .10188 Metetra
.664 .741 .907 r
.51713 .10188 .51825 .10334 .52506 .10072 .52395 .09925 Metetra
.664 .741 .907 r
.52395 .09925 .52506 .10072 .5319 .09809 .53078 .09662 Metetra
.664 .741 .907 r
.53078 .09662 .5319 .09809 .53875 .09545 .53764 .09398 Metetra
.664 .741 .907 r
.53764 .09398 .53875 .09545 .54562 .09281 .54451 .09133 Metetra
.664 .741 .907 r
.54451 .09133 .54562 .09281 .5525 .09016 .5514 .08868 Metetra
.664 .741 .907 r
.5514 .08868 .5525 .09016 .5594 .0875 .5583 .08602 Metetra
.664 .741 .907 r
.5583 .08602 .5594 .0875 .56632 .08484 .56523 .08335 Metetra
.664 .741 .907 r
.56523 .08335 .56632 .08484 .57326 .08217 .57217 .08068 Metetra
.664 .741 .907 r
.57217 .08068 .57326 .08217 .58021 .07949 .57912 .078 Metetra
.664 .741 .907 r
.57912 .078 .58021 .07949 .58719 .07681 .5861 .07531 Metetra
.664 .741 .907 r
.5861 .07531 .58719 .07681 .59417 .07412 .59309 .07262 Metetra
.664 .741 .907 r
.59309 .07262 .59417 .07412 .60118 .07142 .6001 .06991 Metetra
.664 .741 .907 r
.6001 .06991 .60118 .07142 .60821 .06872 .60713 .06721 Metetra
.664 .741 .907 r
.60713 .06721 .60821 .06872 .61525 .06601 .61418 .06449 Metetra
.664 .741 .907 r
.61418 .06449 .61525 .06601 .62231 .06329 .62124 .06177 Metetra
.664 .741 .907 r
.62124 .06177 .62231 .06329 .62939 .06057 .62832 .05904 Metetra
.961 .629 .26 r
.62832 .05904 .62939 .06057 .6408 .16935 .63915 .15342 Metetra
.792 .571 .005 r
.63915 .15342 .6408 .16935 .65364 .29859 .6525 .29711 Metetra
.979 .685 .364 r
.6525 .29711 .65364 .29859 .65073 .05235 .64967 .05082 Metetra
.664 .741 .907 r
.64967 .05082 .65073 .05235 .65788 .0496 .65683 .04806 Metetra
.664 .741 .907 r
.65683 .04806 .65788 .0496 .66504 .04684 .664 .0453 Metetra
.664 .741 .907 r
.664 .0453 .66504 .04684 .67223 .04407 .67119 .04253 Metetra
.664 .741 .907 r
.67119 .04253 .67223 .04407 .67944 .0413 .6784 .03975 Metetra
.664 .741 .907 r
.6784 .03975 .67944 .0413 .68666 .03852 .68562 .03697 Metetra
.664 .741 .907 r
.68562 .03697 .68666 .03852 .6939 .03573 .69287 .03418 Metetra
.664 .741 .907 r
.69287 .03418 .6939 .03573 .70116 .03294 .70013 .03138 Metetra
.664 .741 .907 r
.70013 .03138 .70116 .03294 .70844 .03014 .70742 .02857 Metetra
.664 .741 .907 r
.05984 .27631 .06115 .27755 .06689 .27534 .06557 .2741 Metetra
.664 .741 .907 r
.06557 .2741 .06689 .27534 .07264 .27312 .07132 .27189 Metetra
.664 .741 .907 r
.07132 .27189 .07264 .27312 .0784 .2709 .07708 .26966 Metetra
.664 .741 .907 r
.07708 .26966 .0784 .2709 .08417 .26868 .08286 .26744 Metetra
.664 .741 .907 r
.08286 .26744 .08417 .26868 .08996 .26645 .08865 .2652 Metetra
.664 .741 .907 r
.08865 .2652 .08996 .26645 .09576 .26422 .09445 .26297 Metetra
.664 .741 .907 r
.09445 .26297 .09576 .26422 .10157 .26198 .10027 .26072 Metetra
.664 .741 .907 r
.10027 .26072 .10157 .26198 .1074 .25973 .10609 .25848 Metetra
.664 .741 .907 r
.10609 .25848 .1074 .25973 .11324 .25748 .11194 .25622 Metetra
.664 .741 .907 r
.11194 .25622 .11324 .25748 .11909 .25523 .11779 .25397 Metetra
.664 .741 .907 r
.11779 .25397 .11909 .25523 .12496 .25297 .12366 .2517 Metetra
.664 .741 .907 r
.12366 .2517 .12496 .25297 .13084 .2507 .12954 .24943 Metetra
.664 .741 .907 r
.12954 .24943 .13084 .2507 .13673 .24843 .13544 .24716 Metetra
.664 .741 .907 r
.13544 .24716 .13673 .24843 .14264 .24615 .14135 .24488 Metetra
.56 .707 .939 r
.14135 .24488 .14264 .24615 .14694 .25704 .14711 .2439 Metetra
.552 .35 .561 r
.14711 .2439 .14694 .25704 .15449 .24159 .15321 .24031 Metetra
.664 .741 .907 r
.15321 .24031 .15449 .24159 .16044 .23929 .15916 .23801 Metetra
.664 .741 .907 r
.15916 .23801 .16044 .23929 .16641 .237 .16513 .23571 Metetra
.664 .741 .907 r
.16513 .23571 .16641 .237 .17238 .23469 .17111 .23341 Metetra
.664 .741 .907 r
.17111 .23341 .17238 .23469 .17837 .23239 .1771 .2311 Metetra
.664 .741 .907 r
.1771 .2311 .17837 .23239 .18438 .23007 .18311 .22878 Metetra
.664 .741 .907 r
.18311 .22878 .18438 .23007 .1904 .22776 .18913 .22646 Metetra
.664 .741 .907 r
.18913 .22646 .1904 .22776 .19643 .22543 .19516 .22413 Metetra
.664 .741 .907 r
.19516 .22413 .19643 .22543 .20247 .2231 .20121 .2218 Metetra
.664 .741 .907 r
.20121 .2218 .20247 .2231 .20853 .22077 .20727 .21946 Metetra
.664 .741 .907 r
.20727 .21946 .20853 .22077 .21461 .21843 .21335 .21712 Metetra
.664 .741 .907 r
.21335 .21712 .21461 .21843 .2207 .21608 .21944 .21477 Metetra
.664 .741 .907 r
.21944 .21477 .2207 .21608 .2268 .21373 .22555 .21242 Metetra
.664 .741 .907 r
.22555 .21242 .2268 .21373 .23292 .21137 .23167 .21006 Metetra
.664 .741 .907 r
.23167 .21006 .23292 .21137 .23905 .20901 .2378 .20769 Metetra
.664 .741 .907 r
.2378 .20769 .23905 .20901 .2452 .20664 .24395 .20532 Metetra
.664 .741 .907 r
.24395 .20532 .2452 .20664 .25136 .20427 .25012 .20294 Metetra
.664 .741 .907 r
.25012 .20294 .25136 .20427 .25754 .20189 .2563 .20056 Metetra
.664 .741 .907 r
.2563 .20056 .25754 .20189 .26373 .1995 .26249 .19817 Metetra
.664 .741 .907 r
.26249 .19817 .26373 .1995 .26993 .19711 .2687 .19578 Metetra
.664 .741 .907 r
.2687 .19578 .26993 .19711 .27615 .19472 .27492 .19338 Metetra
.664 .741 .907 r
.27492 .19338 .27615 .19472 .28239 .19232 .28116 .19097 Metetra
.664 .741 .907 r
.28116 .19097 .28239 .19232 .28863 .18991 .28741 .18856 Metetra
.664 .741 .907 r
.28741 .18856 .28863 .18991 .2949 .18749 .29367 .18615 Metetra
.961 .679 .453 r
.29367 .18615 .2949 .18749 .28348 .42306 .28215 .42177 Metetra
.96 .699 .495 r
.28215 .42177 .28348 .42306 .29706 .32653 .30203 .23935 Metetra
.596 .35 .514 r
.30203 .23935 .29706 .32653 .31378 .18022 .31256 .17886 Metetra
.664 .741 .907 r
.31256 .17886 .31378 .18022 .32011 .17778 .31889 .17642 Metetra
.664 .741 .907 r
.31889 .17642 .32011 .17778 .32644 .17534 .32523 .17398 Metetra
.664 .741 .907 r
.32523 .17398 .32644 .17534 .3328 .17289 .33159 .17153 Metetra
.664 .741 .907 r
.33159 .17153 .3328 .17289 .33917 .17044 .33796 .16907 Metetra
.664 .741 .907 r
.33796 .16907 .33917 .17044 .34555 .16798 .34435 .16661 Metetra
.664 .741 .907 r
.34435 .16661 .34555 .16798 .35195 .16551 .35075 .16414 Metetra
.664 .741 .907 r
.35075 .16414 .35195 .16551 .35837 .16304 .35717 .16166 Metetra
.664 .741 .907 r
.35717 .16166 .35837 .16304 .3648 .16056 .36361 .15918 Metetra
.664 .741 .907 r
.36361 .15918 .3648 .16056 .37125 .15808 .37006 .15669 Metetra
.664 .741 .907 r
.37006 .15669 .37125 .15808 .37771 .15559 .37652 .1542 Metetra
.664 .741 .907 r
.37652 .1542 .37771 .15559 .38419 .1531 .383 .1517 Metetra
.664 .741 .907 r
.383 .1517 .38419 .1531 .39068 .15059 .3895 .1492 Metetra
.664 .741 .907 r
.3895 .1492 .39068 .15059 .39719 .14809 .39601 .14668 Metetra
.664 .741 .907 r
.39601 .14668 .39719 .14809 .40372 .14557 .40254 .14417 Metetra
.664 .741 .907 r
.40254 .14417 .40372 .14557 .41026 .14305 .40909 .14164 Metetra
.664 .741 .907 r
.40909 .14164 .41026 .14305 .41682 .14053 .41565 .13911 Metetra
.664 .741 .907 r
.41565 .13911 .41682 .14053 .42339 .13799 .42222 .13658 Metetra
.664 .741 .907 r
.42222 .13658 .42339 .13799 .42998 .13545 .42881 .13404 Metetra
.664 .741 .907 r
.42881 .13404 .42998 .13545 .43658 .13291 .43542 .13149 Metetra
.664 .741 .907 r
.43542 .13149 .43658 .13291 .44321 .13036 .44205 .12893 Metetra
.664 .741 .907 r
.44205 .12893 .44321 .13036 .44984 .1278 .44869 .12637 Metetra
.664 .741 .907 r
.44869 .12637 .44984 .1278 .4565 .12524 .45535 .12381 Metetra
.664 .741 .907 r
.45535 .12381 .4565 .12524 .46301 .13005 .46202 .12123 Metetra
.554 .376 .594 r
.46202 .12123 .46301 .13005 .46985 .12009 .46871 .11865 Metetra
.664 .741 .907 r
.46871 .11865 .46985 .12009 .47656 .11751 .47542 .11607 Metetra
.664 .741 .907 r
.47542 .11607 .47656 .11751 .48328 .11492 .48214 .11347 Metetra
.664 .741 .907 r
.48214 .11347 .48328 .11492 .49001 .11233 .48888 .11088 Metetra
.664 .741 .907 r
.48888 .11088 .49001 .11233 .49677 .10972 .49563 .10827 Metetra
.664 .741 .907 r
.49563 .10827 .49677 .10972 .50354 .10712 .50241 .10566 Metetra
.664 .741 .907 r
.50241 .10566 .50354 .10712 .51032 .1045 .5092 .10304 Metetra
.664 .741 .907 r
.5092 .10304 .51032 .1045 .51713 .10188 .516 .10042 Metetra
.664 .741 .907 r
.516 .10042 .51713 .10188 .52395 .09925 .52283 .09779 Metetra
.664 .741 .907 r
.52283 .09779 .52395 .09925 .53078 .09662 .52967 .09515 Metetra
.664 .741 .907 r
.52967 .09515 .53078 .09662 .53764 .09398 .53653 .0925 Metetra
.664 .741 .907 r
.53653 .0925 .53764 .09398 .54451 .09133 .5434 .08985 Metetra
.664 .741 .907 r
.5434 .08985 .54451 .09133 .5514 .08868 .55029 .08719 Metetra
.664 .741 .907 r
.55029 .08719 .5514 .08868 .5583 .08602 .5572 .08453 Metetra
.664 .741 .907 r
.5572 .08453 .5583 .08602 .56523 .08335 .56413 .08186 Metetra
.664 .741 .907 r
.56413 .08186 .56523 .08335 .57217 .08068 .57107 .07918 Metetra
.664 .741 .907 r
.57107 .07918 .57217 .08068 .57912 .078 .57803 .0765 Metetra
.664 .741 .907 r
.57803 .0765 .57912 .078 .5861 .07531 .58501 .07381 Metetra
.664 .741 .907 r
.58501 .07381 .5861 .07531 .59309 .07262 .59201 .07111 Metetra
.664 .741 .907 r
.59201 .07111 .59309 .07262 .6001 .06991 .59902 .06841 Metetra
.664 .741 .907 r
.59902 .06841 .6001 .06991 .60713 .06721 .60605 .06569 Metetra
.664 .741 .907 r
.60605 .06569 .60713 .06721 .61418 .06449 .6131 .06298 Metetra
.664 .741 .907 r
.6131 .06298 .61418 .06449 .62124 .06177 .62017 .06025 Metetra
.664 .741 .907 r
.62017 .06025 .62124 .06177 .62832 .05904 .62725 .05752 Metetra
0 0 .531 r
.62725 .05752 .62832 .05904 .63915 .15342 .6348 .06631 Metetra
.192 .048 .444 r
.6348 .06631 .63915 .15342 .6525 .29711 .64878 .23218 Metetra
.76 .473 .498 r
.64878 .23218 .6525 .29711 .64967 .05082 .64862 .04928 Metetra
.664 .741 .907 r
.64862 .04928 .64967 .05082 .65683 .04806 .65577 .04652 Metetra
.664 .741 .907 r
.65577 .04652 .65683 .04806 .664 .0453 .66295 .04375 Metetra
.664 .741 .907 r
.66295 .04375 .664 .0453 .67119 .04253 .67014 .04098 Metetra
.664 .741 .907 r
.67014 .04098 .67119 .04253 .6784 .03975 .67736 .0382 Metetra
.664 .741 .907 r
.67736 .0382 .6784 .03975 .68562 .03697 .68459 .03541 Metetra
.664 .741 .907 r
.68459 .03541 .68562 .03697 .69287 .03418 .69184 .03262 Metetra
.664 .741 .907 r
.69184 .03262 .69287 .03418 .70013 .03138 .6991 .02981 Metetra
.664 .741 .907 r
.6991 .02981 .70013 .03138 .70742 .02857 .70639 .027 Metetra
.664 .741 .907 r
.05852 .27508 .05984 .27631 .06557 .2741 .06425 .27287 Metetra
.664 .741 .907 r
.06425 .27287 .06557 .2741 .07132 .27189 .07 .27065 Metetra
.664 .741 .907 r
.07 .27065 .07132 .27189 .07708 .26966 .07577 .26842 Metetra
.664 .741 .907 r
.07577 .26842 .07708 .26966 .08286 .26744 .08155 .26619 Metetra
.664 .741 .907 r
.08155 .26619 .08286 .26744 .08865 .2652 .08734 .26396 Metetra
.664 .741 .907 r
.08734 .26396 .08865 .2652 .09445 .26297 .09314 .26172 Metetra
.664 .741 .907 r
.09314 .26172 .09445 .26297 .10027 .26072 .09896 .25947 Metetra
.664 .741 .907 r
.09896 .25947 .10027 .26072 .10609 .25848 .10479 .25722 Metetra
.664 .741 .907 r
.10479 .25722 .10609 .25848 .11194 .25622 .11064 .25497 Metetra
.664 .741 .907 r
.11064 .25497 .11194 .25622 .11779 .25397 .11649 .2527 Metetra
.664 .741 .907 r
.11649 .2527 .11779 .25397 .12366 .2517 .12237 .25044 Metetra
.664 .741 .907 r
.12237 .25044 .12366 .2517 .12954 .24943 .12825 .24817 Metetra
.664 .741 .907 r
.12825 .24817 .12954 .24943 .13544 .24716 .13415 .24589 Metetra
.664 .741 .907 r
.13415 .24589 .13544 .24716 .14135 .24488 .14006 .24361 Metetra
.664 .741 .907 r
.14006 .24361 .14135 .24488 .14711 .2439 .14599 .24132 Metetra
.629 .575 .774 r
.14599 .24132 .14711 .2439 .15321 .24031 .15193 .23903 Metetra
.664 .741 .907 r
.15193 .23903 .15321 .24031 .15916 .23801 .15788 .23673 Metetra
.664 .741 .907 r
.15788 .23673 .15916 .23801 .16513 .23571 .16385 .23443 Metetra
.664 .741 .907 r
.16385 .23443 .16513 .23571 .17111 .23341 .16983 .23212 Metetra
.664 .741 .907 r
.16983 .23212 .17111 .23341 .1771 .2311 .17582 .22981 Metetra
.664 .741 .907 r
.17582 .22981 .1771 .2311 .18311 .22878 .18183 .22749 Metetra
.664 .741 .907 r
.18183 .22749 .18311 .22878 .18913 .22646 .18786 .22516 Metetra
.664 .741 .907 r
.18786 .22516 .18913 .22646 .19516 .22413 .19389 .22283 Metetra
.664 .741 .907 r
.19389 .22283 .19516 .22413 .20121 .2218 .19995 .2205 Metetra
.664 .741 .907 r
.19995 .2205 .20121 .2218 .20727 .21946 .20601 .21816 Metetra
.664 .741 .907 r
.20601 .21816 .20727 .21946 .21335 .21712 .21209 .21581 Metetra
.664 .741 .907 r
.21209 .21581 .21335 .21712 .21944 .21477 .21819 .21346 Metetra
.664 .741 .907 r
.21819 .21346 .21944 .21477 .22555 .21242 .22429 .2111 Metetra
.664 .741 .907 r
.22429 .2111 .22555 .21242 .23167 .21006 .23042 .20874 Metetra
.664 .741 .907 r
.23042 .20874 .23167 .21006 .2378 .20769 .23655 .20637 Metetra
.664 .741 .907 r
.23655 .20637 .2378 .20769 .24395 .20532 .24271 .20399 Metetra
.664 .741 .907 r
.24271 .20399 .24395 .20532 .25012 .20294 .24887 .20161 Metetra
.664 .741 .907 r
.24887 .20161 .25012 .20294 .2563 .20056 .25505 .19923 Metetra
.664 .741 .907 r
.25505 .19923 .2563 .20056 .26249 .19817 .26125 .19684 Metetra
.664 .741 .907 r
.26125 .19684 .26249 .19817 .2687 .19578 .26746 .19444 Metetra
.664 .741 .907 r
.26746 .19444 .2687 .19578 .27492 .19338 .27368 .19204 Metetra
.664 .741 .907 r
.27368 .19204 .27492 .19338 .28116 .19097 .27992 .18963 Metetra
.664 .741 .907 r
.27992 .18963 .28116 .19097 .28741 .18856 .28618 .18722 Metetra
.664 .741 .907 r
.28618 .18722 .28741 .18856 .29367 .18615 .29245 .1848 Metetra
.961 .679 .453 r
.29245 .1848 .29367 .18615 .28215 .42177 .28081 .42048 Metetra
.96 .699 .496 r
.28081 .42048 .28215 .42177 .30203 .23935 .30042 .24299 Metetra
.998 .785 .481 r
.30042 .24299 .30203 .23935 .31256 .17886 .31135 .1775 Metetra
.664 .741 .907 r
.31135 .1775 .31256 .17886 .31889 .17642 .31768 .17506 Metetra
.664 .741 .907 r
.31768 .17506 .31889 .17642 .32523 .17398 .32402 .17261 Metetra
.664 .741 .907 r
.32402 .17261 .32523 .17398 .33159 .17153 .33038 .17016 Metetra
.664 .741 .907 r
.33038 .17016 .33159 .17153 .33796 .16907 .33676 .1677 Metetra
.664 .741 .907 r
.33676 .1677 .33796 .16907 .34435 .16661 .34315 .16523 Metetra
.664 .741 .907 r
.34315 .16523 .34435 .16661 .35075 .16414 .34955 .16276 Metetra
.664 .741 .907 r
.34955 .16276 .35075 .16414 .35717 .16166 .35598 .16028 Metetra
.664 .741 .907 r
.35598 .16028 .35717 .16166 .36361 .15918 .36241 .15779 Metetra
.664 .741 .907 r
.36241 .15779 .36361 .15918 .37006 .15669 .36887 .1553 Metetra
.664 .741 .907 r
.36887 .1553 .37006 .15669 .37652 .1542 .37533 .15281 Metetra
.664 .741 .907 r
.37533 .15281 .37652 .1542 .383 .1517 .38182 .1503 Metetra
.664 .741 .907 r
.38182 .1503 .383 .1517 .3895 .1492 .38832 .1478 Metetra
.664 .741 .907 r
.38832 .1478 .3895 .1492 .39601 .14668 .39483 .14528 Metetra
.664 .741 .907 r
.39483 .14528 .39601 .14668 .40254 .14417 .40136 .14276 Metetra
.664 .741 .907 r
.40136 .14276 .40254 .14417 .40909 .14164 .40791 .14023 Metetra
.664 .741 .907 r
.40791 .14023 .40909 .14164 .41565 .13911 .41447 .1377 Metetra
.664 .741 .907 r
.41447 .1377 .41565 .13911 .42222 .13658 .42105 .13516 Metetra
.664 .741 .907 r
.42105 .13516 .42222 .13658 .42881 .13404 .42765 .13262 Metetra
.664 .741 .907 r
.42765 .13262 .42881 .13404 .43542 .13149 .43426 .13006 Metetra
.664 .741 .907 r
.43426 .13006 .43542 .13149 .44205 .12893 .44089 .12751 Metetra
.664 .741 .907 r
.44089 .12751 .44205 .12893 .44869 .12637 .44753 .12494 Metetra
.664 .741 .907 r
.44753 .12494 .44869 .12637 .45535 .12381 .45419 .12237 Metetra
.664 .741 .907 r
.45419 .12237 .45535 .12381 .46202 .12123 .46087 .11979 Metetra
.664 .741 .907 r
.46087 .11979 .46202 .12123 .46871 .11865 .46756 .11721 Metetra
.664 .741 .907 r
.46756 .11721 .46871 .11865 .47542 .11607 .47427 .11462 Metetra
.664 .741 .907 r
.47427 .11462 .47542 .11607 .48214 .11347 .481 .11203 Metetra
.664 .741 .907 r
.481 .11203 .48214 .11347 .48888 .11088 .48774 .10942 Metetra
.664 .741 .907 r
.48774 .10942 .48888 .11088 .49563 .10827 .4945 .10681 Metetra
.664 .741 .907 r
.4945 .10681 .49563 .10827 .50241 .10566 .50128 .1042 Metetra
.664 .741 .907 r
.50128 .1042 .50241 .10566 .5092 .10304 .50807 .10158 Metetra
.664 .741 .907 r
.50807 .10158 .5092 .10304 .516 .10042 .51488 .09895 Metetra
.664 .741 .907 r
.51488 .09895 .516 .10042 .52283 .09779 .52171 .09631 Metetra
.664 .741 .907 r
.52171 .09631 .52283 .09779 .52967 .09515 .52855 .09367 Metetra
.664 .741 .907 r
.52855 .09367 .52967 .09515 .53653 .0925 .53541 .09103 Metetra
.664 .741 .907 r
.53541 .09103 .53653 .0925 .5434 .08985 .54229 .08837 Metetra
.664 .741 .907 r
.54229 .08837 .5434 .08985 .55029 .08719 .54918 .08571 Metetra
.664 .741 .907 r
.54918 .08571 .55029 .08719 .5572 .08453 .5561 .08304 Metetra
.664 .741 .907 r
.5561 .08304 .5572 .08453 .56413 .08186 .56303 .08037 Metetra
.664 .741 .907 r
.56303 .08037 .56413 .08186 .57107 .07918 .56997 .07769 Metetra
.664 .741 .907 r
.56997 .07769 .57107 .07918 .57803 .0765 .57694 .075 Metetra
.664 .741 .907 r
.57694 .075 .57803 .0765 .58501 .07381 .58392 .0723 Metetra
.664 .741 .907 r
.58392 .0723 .58501 .07381 .59201 .07111 .59092 .0696 Metetra
.664 .741 .907 r
.59092 .0696 .59201 .07111 .59902 .06841 .59794 .06689 Metetra
.664 .741 .907 r
.59794 .06689 .59902 .06841 .60605 .06569 .60497 .06418 Metetra
.664 .741 .907 r
.60497 .06418 .60605 .06569 .6131 .06298 .61203 .06146 Metetra
.664 .741 .907 r
.61203 .06146 .6131 .06298 .62017 .06025 .6191 .05873 Metetra
.664 .741 .907 r
.6191 .05873 .62017 .06025 .62725 .05752 .62619 .05599 Metetra
.901 .518 .075 r
.62619 .05599 .62725 .05752 .6348 .06631 .63455 .08674 Metetra
.848 .524 .438 r
.63455 .08674 .6348 .06631 .64878 .23218 .64714 .2177 Metetra
.932 .63 .446 r
.64714 .2177 .64878 .23218 .64862 .04928 .64756 .04774 Metetra
.664 .741 .907 r
.64756 .04774 .64862 .04928 .65577 .04652 .65472 .04498 Metetra
.664 .741 .907 r
.65472 .04498 .65577 .04652 .66295 .04375 .6619 .04221 Metetra
.664 .741 .907 r
.6619 .04221 .66295 .04375 .67014 .04098 .6691 .03943 Metetra
.664 .741 .907 r
.6691 .03943 .67014 .04098 .67736 .0382 .67631 .03664 Metetra
.664 .741 .907 r
.67631 .03664 .67736 .0382 .68459 .03541 .68355 .03385 Metetra
.664 .741 .907 r
.68355 .03385 .68459 .03541 .69184 .03262 .6908 .03105 Metetra
.664 .741 .907 r
.6908 .03105 .69184 .03262 .6991 .02981 .69807 .02825 Metetra
.664 .741 .907 r
.69807 .02825 .6991 .02981 .70639 .027 .70536 .02543 Metetra
.664 .741 .907 r
.05719 .27385 .05852 .27508 .06425 .27287 .06293 .27163 Metetra
.664 .741 .907 r
.06293 .27163 .06425 .27287 .07 .27065 .06869 .26941 Metetra
.664 .741 .907 r
.06869 .26941 .07 .27065 .07577 .26842 .07445 .26718 Metetra
.664 .741 .907 r
.07445 .26718 .07577 .26842 .08155 .26619 .08023 .26495 Metetra
.664 .741 .907 r
.08023 .26495 .08155 .26619 .08734 .26396 .08603 .26271 Metetra
.664 .741 .907 r
.08603 .26271 .08734 .26396 .09314 .26172 .09183 .26047 Metetra
.664 .741 .907 r
.09183 .26047 .09314 .26172 .09896 .25947 .09765 .25822 Metetra
.664 .741 .907 r
.09765 .25822 .09896 .25947 .10479 .25722 .10349 .25596 Metetra
.664 .741 .907 r
.10349 .25596 .10479 .25722 .11064 .25497 .10933 .25371 Metetra
.664 .741 .907 r
.10933 .25371 .11064 .25497 .11649 .2527 .11519 .25144 Metetra
.664 .741 .907 r
.11519 .25144 .11649 .2527 .12237 .25044 .12107 .24917 Metetra
.664 .741 .907 r
.12107 .24917 .12237 .25044 .12825 .24817 .12696 .2469 Metetra
.664 .741 .907 r
.12696 .2469 .12825 .24817 .13415 .24589 .13286 .24462 Metetra
.664 .741 .907 r
.13286 .24462 .13415 .24589 .14006 .24361 .13877 .24233 Metetra
.258 .564 .935 r
.13877 .24233 .14006 .24361 .14599 .24132 .14427 .24351 Metetra
.14427 .24351 .14599 .24132 .15193 .23903 .15064 .23775 Metetra
.664 .741 .907 r
.15064 .23775 .15193 .23903 .15788 .23673 .1566 .23545 Metetra
.664 .741 .907 r
.1566 .23545 .15788 .23673 .16385 .23443 .16257 .23314 Metetra
.664 .741 .907 r
.16257 .23314 .16385 .23443 .16983 .23212 .16855 .23083 Metetra
.664 .741 .907 r
.16855 .23083 .16983 .23212 .17582 .22981 .17455 .22851 Metetra
.664 .741 .907 r
.17455 .22851 .17582 .22981 .18183 .22749 .18056 .22619 Metetra
.664 .741 .907 r
.18056 .22619 .18183 .22749 .18786 .22516 .18659 .22386 Metetra
.664 .741 .907 r
.18659 .22386 .18786 .22516 .19389 .22283 .19262 .22153 Metetra
.664 .741 .907 r
.19262 .22153 .19389 .22283 .19995 .2205 .19868 .21919 Metetra
.664 .741 .907 r
.19868 .21919 .19995 .2205 .20601 .21816 .20475 .21685 Metetra
.664 .741 .907 r
.20475 .21685 .20601 .21816 .21209 .21581 .21083 .2145 Metetra
.664 .741 .907 r
.21083 .2145 .21209 .21581 .21819 .21346 .21693 .21214 Metetra
.664 .741 .907 r
.21693 .21214 .21819 .21346 .22429 .2111 .22304 .20978 Metetra
.664 .741 .907 r
.22304 .20978 .22429 .2111 .23042 .20874 .22916 .20742 Metetra
.664 .741 .907 r
.22916 .20742 .23042 .20874 .23655 .20637 .2353 .20504 Metetra
.664 .741 .907 r
.2353 .20504 .23655 .20637 .24271 .20399 .24146 .20267 Metetra
.664 .741 .907 r
.24146 .20267 .24271 .20399 .24887 .20161 .24763 .20028 Metetra
.664 .741 .907 r
.24763 .20028 .24887 .20161 .25505 .19923 .25381 .1979 Metetra
.664 .741 .907 r
.25381 .1979 .25505 .19923 .26125 .19684 .26001 .1955 Metetra
.664 .741 .907 r
.26001 .1955 .26125 .19684 .26746 .19444 .26622 .1931 Metetra
.664 .741 .907 r
.26622 .1931 .26746 .19444 .27368 .19204 .27245 .1907 Metetra
.664 .741 .907 r
.27245 .1907 .27368 .19204 .27992 .18963 .27869 .18828 Metetra
.664 .741 .907 r
.27869 .18828 .27992 .18963 .28618 .18722 .28495 .18587 Metetra
.664 .741 .907 r
.28495 .18587 .28618 .18722 .29245 .1848 .29122 .18344 Metetra
.961 .679 .453 r
.29122 .18344 .29245 .1848 .28081 .42048 .27948 .41919 Metetra
.96 .697 .492 r
.27948 .41919 .28081 .42048 .30042 .24299 .30162 .20824 Metetra
.62 .379 .53 r
.30162 .20824 .30042 .24299 .31135 .1775 .31013 .17614 Metetra
.664 .741 .907 r
.31013 .17614 .31135 .1775 .31768 .17506 .31646 .17369 Metetra
.664 .741 .907 r
.31646 .17369 .31768 .17506 .32402 .17261 .32281 .17124 Metetra
.664 .741 .907 r
.32281 .17124 .32402 .17261 .33038 .17016 .32917 .16878 Metetra
.664 .741 .907 r
.32917 .16878 .33038 .17016 .33676 .1677 .33555 .16632 Metetra
.664 .741 .907 r
.33555 .16632 .33676 .1677 .34315 .16523 .34194 .16385 Metetra
.664 .741 .907 r
.34194 .16385 .34315 .16523 .34955 .16276 .34835 .16137 Metetra
.664 .741 .907 r
.34835 .16137 .34955 .16276 .35598 .16028 .35478 .15889 Metetra
.664 .741 .907 r
.35478 .15889 .35598 .16028 .36241 .15779 .36122 .15641 Metetra
.664 .741 .907 r
.36122 .15641 .36241 .15779 .36887 .1553 .36767 .15391 Metetra
.664 .741 .907 r
.36767 .15391 .36887 .1553 .37533 .15281 .37414 .15141 Metetra
.664 .741 .907 r
.37414 .15141 .37533 .15281 .38182 .1503 .38063 .14891 Metetra
.664 .741 .907 r
.38063 .14891 .38182 .1503 .38832 .1478 .38713 .14639 Metetra
.664 .741 .907 r
.38713 .14639 .38832 .1478 .39483 .14528 .39365 .14388 Metetra
.664 .741 .907 r
.39365 .14388 .39483 .14528 .40136 .14276 .40018 .14135 Metetra
.664 .741 .907 r
.40018 .14135 .40136 .14276 .40791 .14023 .40674 .13882 Metetra
.664 .741 .907 r
.40674 .13882 .40791 .14023 .41447 .1377 .4133 .13628 Metetra
.664 .741 .907 r
.4133 .13628 .41447 .1377 .42105 .13516 .41988 .13374 Metetra
.664 .741 .907 r
.41988 .13374 .42105 .13516 .42765 .13262 .42648 .13119 Metetra
.664 .741 .907 r
.42648 .13119 .42765 .13262 .43426 .13006 .4331 .12864 Metetra
.664 .741 .907 r
.4331 .12864 .43426 .13006 .44089 .12751 .43973 .12608 Metetra
.664 .741 .907 r
.43973 .12608 .44089 .12751 .44753 .12494 .44637 .12351 Metetra
.664 .741 .907 r
.44637 .12351 .44753 .12494 .45419 .12237 .45304 .12094 Metetra
.664 .741 .907 r
.45304 .12094 .45419 .12237 .46087 .11979 .45972 .11835 Metetra
.664 .741 .907 r
.45972 .11835 .46087 .11979 .46756 .11721 .46641 .11577 Metetra
.664 .741 .907 r
.46641 .11577 .46756 .11721 .47427 .11462 .47313 .11317 Metetra
.664 .741 .907 r
.47313 .11317 .47427 .11462 .481 .11203 .47986 .11058 Metetra
.664 .741 .907 r
.47986 .11058 .481 .11203 .48774 .10942 .4866 .10797 Metetra
.664 .741 .907 r
.4866 .10797 .48774 .10942 .4945 .10681 .49337 .10536 Metetra
.664 .741 .907 r
.49337 .10536 .4945 .10681 .50128 .1042 .50014 .10274 Metetra
.664 .741 .907 r
.50014 .10274 .50128 .1042 .50807 .10158 .50694 .10011 Metetra
.664 .741 .907 r
.50694 .10011 .50807 .10158 .51488 .09895 .51375 .09748 Metetra
.664 .741 .907 r
.51375 .09748 .51488 .09895 .52171 .09631 .52058 .09484 Metetra
.664 .741 .907 r
.52058 .09484 .52171 .09631 .52855 .09367 .52743 .0922 Metetra
.664 .741 .907 r
.52743 .0922 .52855 .09367 .53541 .09103 .5343 .08955 Metetra
.664 .741 .907 r
.5343 .08955 .53541 .09103 .54229 .08837 .54118 .08689 Metetra
.664 .741 .907 r
.54118 .08689 .54229 .08837 .54918 .08571 .54808 .08422 Metetra
.664 .741 .907 r
.54808 .08422 .54918 .08571 .5561 .08304 .55499 .08155 Metetra
.664 .741 .907 r
.55499 .08155 .5561 .08304 .56303 .08037 .56193 .07887 Metetra
.664 .741 .907 r
.56193 .07887 .56303 .08037 .56997 .07769 .56888 .07619 Metetra
.664 .741 .907 r
.56888 .07619 .56997 .07769 .57694 .075 .57584 .0735 Metetra
.664 .741 .907 r
.57584 .0735 .57694 .075 .58392 .0723 .58283 .0708 Metetra
.664 .741 .907 r
.58283 .0708 .58392 .0723 .59092 .0696 .58983 .06809 Metetra
.664 .741 .907 r
.58983 .06809 .59092 .0696 .59794 .06689 .59685 .06538 Metetra
.664 .741 .907 r
.59685 .06538 .59794 .06689 .60497 .06418 .60389 .06266 Metetra
.664 .741 .907 r
.60389 .06266 .60497 .06418 .61203 .06146 .61095 .05994 Metetra
.664 .741 .907 r
.61095 .05994 .61203 .06146 .6191 .05873 .61802 .0572 Metetra
.664 .741 .907 r
.61802 .0572 .6191 .05873 .62619 .05599 .62512 .05446 Metetra
.939 .582 .178 r
.62512 .05446 .62619 .05599 .63455 .08674 .63414 .1029 Metetra
.865 .536 .426 r
.63414 .1029 .63455 .08674 .64714 .2177 .64628 .22279 Metetra
.979 .707 .314 r
.64628 .22279 .64714 .2177 .64756 .04774 .6465 .0462 Metetra
.664 .741 .907 r
.6465 .0462 .64756 .04774 .65472 .04498 .65367 .04343 Metetra
.664 .741 .907 r
.65367 .04343 .65472 .04498 .6619 .04221 .66085 .04066 Metetra
.664 .741 .907 r
.66085 .04066 .6619 .04221 .6691 .03943 .66805 .03788 Metetra
.664 .741 .907 r
.66805 .03788 .6691 .03943 .67631 .03664 .67527 .03509 Metetra
.664 .741 .907 r
.67527 .03509 .67631 .03664 .68355 .03385 .68251 .03229 Metetra
.664 .741 .907 r
.68251 .03229 .68355 .03385 .6908 .03105 .68977 .02949 Metetra
.664 .741 .907 r
.68977 .02949 .6908 .03105 .69807 .02825 .69704 .02668 Metetra
.664 .741 .907 r
.69704 .02668 .69807 .02825 .70536 .02543 .70434 .02386 Metetra
.664 .741 .907 r
.05587 .27261 .05719 .27385 .06293 .27163 .06161 .27039 Metetra
.664 .741 .907 r
.06161 .27039 .06293 .27163 .06869 .26941 .06737 .26816 Metetra
.664 .741 .907 r
.06737 .26816 .06869 .26941 .07445 .26718 .07314 .26593 Metetra
.664 .741 .907 r
.07314 .26593 .07445 .26718 .08023 .26495 .07892 .2637 Metetra
.664 .741 .907 r
.07892 .2637 .08023 .26495 .08603 .26271 .08471 .26146 Metetra
.664 .741 .907 r
.08471 .26146 .08603 .26271 .09183 .26047 .09052 .25921 Metetra
.664 .741 .907 r
.09052 .25921 .09183 .26047 .09765 .25822 .09635 .25696 Metetra
.664 .741 .907 r
.09635 .25696 .09765 .25822 .10349 .25596 .10218 .2547 Metetra
.664 .741 .907 r
.10218 .2547 .10349 .25596 .10933 .25371 .10803 .25244 Metetra
.664 .741 .907 r
.10803 .25244 .10933 .25371 .11519 .25144 .11389 .25018 Metetra
.664 .741 .907 r
.11389 .25018 .11519 .25144 .12107 .24917 .11977 .2479 Metetra
.664 .741 .907 r
.11977 .2479 .12107 .24917 .12696 .2469 .12566 .24563 Metetra
.664 .741 .907 r
.12566 .24563 .12696 .2469 .13286 .24462 .13156 .24335 Metetra
.664 .741 .907 r
.13156 .24335 .13286 .24462 .13877 .24233 .13748 .24106 Metetra
.664 .741 .907 r
.13748 .24106 .13877 .24233 .14427 .24351 .14341 .23876 Metetra
.586 .453 .666 r
.14341 .23876 .14427 .24351 .15064 .23775 .14935 .23647 Metetra
.664 .741 .907 r
.14935 .23647 .15064 .23775 .1566 .23545 .15531 .23416 Metetra
.664 .741 .907 r
.15531 .23416 .1566 .23545 .16257 .23314 .16128 .23185 Metetra
.664 .741 .907 r
.16128 .23185 .16257 .23314 .16855 .23083 .16727 .22954 Metetra
.664 .741 .907 r
.16727 .22954 .16855 .23083 .17455 .22851 .17327 .22722 Metetra
.664 .741 .907 r
.17327 .22722 .17455 .22851 .18056 .22619 .17928 .22489 Metetra
.664 .741 .907 r
.17928 .22489 .18056 .22619 .18659 .22386 .18531 .22256 Metetra
.664 .741 .907 r
.18531 .22256 .18659 .22386 .19262 .22153 .19135 .22023 Metetra
.664 .741 .907 r
.19135 .22023 .19262 .22153 .19868 .21919 .19741 .21789 Metetra
.664 .741 .907 r
.19741 .21789 .19868 .21919 .20475 .21685 .20348 .21554 Metetra
.664 .741 .907 r
.20348 .21554 .20475 .21685 .21083 .2145 .20957 .21319 Metetra
.664 .741 .907 r
.20957 .21319 .21083 .2145 .21693 .21214 .21567 .21083 Metetra
.664 .741 .907 r
.21567 .21083 .21693 .21214 .22304 .20978 .22178 .20846 Metetra
.664 .741 .907 r
.22178 .20846 .22304 .20978 .22916 .20742 .22791 .20609 Metetra
.664 .741 .907 r
.22791 .20609 .22916 .20742 .2353 .20504 .23405 .20372 Metetra
.664 .741 .907 r
.23405 .20372 .2353 .20504 .24146 .20267 .24021 .20134 Metetra
.664 .741 .907 r
.24021 .20134 .24146 .20267 .24763 .20028 .24638 .19895 Metetra
.664 .741 .907 r
.24638 .19895 .24763 .20028 .25381 .1979 .25256 .19656 Metetra
.664 .741 .907 r
.25256 .19656 .25381 .1979 .26001 .1955 .25876 .19416 Metetra
.664 .741 .907 r
.25876 .19416 .26001 .1955 .26622 .1931 .26498 .19176 Metetra
.664 .741 .907 r
.26498 .19176 .26622 .1931 .27245 .1907 .27121 .18935 Metetra
.664 .741 .907 r
.27121 .18935 .27245 .1907 .27869 .18828 .27746 .18694 Metetra
.664 .741 .907 r
.27746 .18694 .27869 .18828 .28495 .18587 .28372 .18452 Metetra
.664 .741 .907 r
.28372 .18452 .28495 .18587 .29122 .18344 .28999 .18209 Metetra
.961 .679 .453 r
.28999 .18209 .29122 .18344 .27948 .41919 .27814 .41789 Metetra
.96 .698 .494 r
.27814 .41789 .27948 .41919 .30162 .20824 .29895 .22626 Metetra
0 0 .157 r
.29895 .22626 .30162 .20824 .31013 .17614 .30891 .17478 Metetra
.664 .741 .907 r
.30891 .17478 .31013 .17614 .31646 .17369 .31524 .17233 Metetra
.664 .741 .907 r
.31524 .17233 .31646 .17369 .32281 .17124 .32159 .16987 Metetra
.664 .741 .907 r
.32159 .16987 .32281 .17124 .32917 .16878 .32796 .16741 Metetra
.664 .741 .907 r
.32796 .16741 .32917 .16878 .33555 .16632 .33434 .16494 Metetra
.664 .741 .907 r
.33434 .16494 .33555 .16632 .34194 .16385 .34073 .16247 Metetra
.664 .741 .907 r
.34073 .16247 .34194 .16385 .34835 .16137 .34715 .15999 Metetra
.664 .741 .907 r
.34715 .15999 .34835 .16137 .35478 .15889 .35357 .15751 Metetra
.664 .741 .907 r
.35357 .15751 .35478 .15889 .36122 .15641 .36002 .15502 Metetra
.664 .741 .907 r
.36002 .15502 .36122 .15641 .36767 .15391 .36648 .15252 Metetra
.664 .741 .907 r
.36648 .15252 .36767 .15391 .37414 .15141 .37295 .15001 Metetra
.664 .741 .907 r
.37295 .15001 .37414 .15141 .38063 .14891 .37944 .14751 Metetra
.664 .741 .907 r
.37944 .14751 .38063 .14891 .38713 .14639 .38595 .14499 Metetra
.664 .741 .907 r
.38595 .14499 .38713 .14639 .39365 .14388 .39247 .14247 Metetra
.664 .741 .907 r
.39247 .14247 .39365 .14388 .40018 .14135 .399 .13994 Metetra
.664 .741 .907 r
.399 .13994 .40018 .14135 .40674 .13882 .40556 .13741 Metetra
.664 .741 .907 r
.40556 .13741 .40674 .13882 .4133 .13628 .41213 .13487 Metetra
.664 .741 .907 r
.41213 .13487 .4133 .13628 .41988 .13374 .41871 .13232 Metetra
.664 .741 .907 r
.41871 .13232 .41988 .13374 .42648 .13119 .42531 .12977 Metetra
.664 .741 .907 r
.42531 .12977 .42648 .13119 .4331 .12864 .43193 .12721 Metetra
.664 .741 .907 r
.43193 .12721 .4331 .12864 .43973 .12608 .43856 .12465 Metetra
.664 .741 .907 r
.43856 .12465 .43973 .12608 .44637 .12351 .44522 .12207 Metetra
.664 .741 .907 r
.44522 .12207 .44637 .12351 .45304 .12094 .45188 .1195 Metetra
.664 .741 .907 r
.45188 .1195 .45304 .12094 .45972 .11835 .45856 .11691 Metetra
.664 .741 .907 r
.45856 .11691 .45972 .11835 .46641 .11577 .46526 .11432 Metetra
.664 .741 .907 r
.46526 .11432 .46641 .11577 .47313 .11317 .47198 .11173 Metetra
.664 .741 .907 r
.47198 .11173 .47313 .11317 .47986 .11058 .47871 .10912 Metetra
.664 .741 .907 r
.47871 .10912 .47986 .11058 .4866 .10797 .48546 .10651 Metetra
.664 .741 .907 r
.48546 .10651 .4866 .10797 .49337 .10536 .49223 .1039 Metetra
.664 .741 .907 r
.49223 .1039 .49337 .10536 .50014 .10274 .49901 .10127 Metetra
.664 .741 .907 r
.49901 .10127 .50014 .10274 .50694 .10011 .50581 .09865 Metetra
.664 .741 .907 r
.50581 .09865 .50694 .10011 .51375 .09748 .51263 .09601 Metetra
.664 .741 .907 r
.51263 .09601 .51375 .09748 .52058 .09484 .51946 .09337 Metetra
.664 .741 .907 r
.51946 .09337 .52058 .09484 .52743 .0922 .52631 .09072 Metetra
.664 .741 .907 r
.52631 .09072 .52743 .0922 .5343 .08955 .53318 .08806 Metetra
.664 .741 .907 r
.53318 .08806 .5343 .08955 .54118 .08689 .54006 .0854 Metetra
.664 .741 .907 r
.54006 .0854 .54118 .08689 .54808 .08422 .54697 .08273 Metetra
.664 .741 .907 r
.54697 .08273 .54808 .08422 .55499 .08155 .55389 .08006 Metetra
.664 .741 .907 r
.55389 .08006 .55499 .08155 .56193 .07887 .56082 .07738 Metetra
.664 .741 .907 r
.56082 .07738 .56193 .07887 .56888 .07619 .56778 .07469 Metetra
.664 .741 .907 r
.56778 .07469 .56888 .07619 .57584 .0735 .57475 .07199 Metetra
.664 .741 .907 r
.57475 .07199 .57584 .0735 .58283 .0708 .58174 .06929 Metetra
.664 .741 .907 r
.58174 .06929 .58283 .0708 .58983 .06809 .58874 .06658 Metetra
.664 .741 .907 r
.58874 .06658 .58983 .06809 .59685 .06538 .59577 .06386 Metetra
.664 .741 .907 r
.59577 .06386 .59685 .06538 .60389 .06266 .60281 .06114 Metetra
.664 .741 .907 r
.60281 .06114 .60389 .06266 .61095 .05994 .60987 .05841 Metetra
.664 .741 .907 r
.60987 .05841 .61095 .05994 .61802 .0572 .61695 .05568 Metetra
.664 .741 .907 r
.61695 .05568 .61802 .0572 .62512 .05446 .62404 .05293 Metetra
.927 .56 .142 r
.62404 .05293 .62512 .05446 .63414 .1029 .63275 .09322 Metetra
0 0 .136 r
.63275 .09322 .63414 .1029 .64628 .22279 .6427 .15894 Metetra
.692 .419 .505 r
.6427 .15894 .64628 .22279 .6465 .0462 .64544 .04466 Metetra
.664 .741 .907 r
.64544 .04466 .6465 .0462 .65367 .04343 .65261 .04189 Metetra
.664 .741 .907 r
.65261 .04189 .65367 .04343 .66085 .04066 .6598 .03911 Metetra
.664 .741 .907 r
.6598 .03911 .66085 .04066 .66805 .03788 .667 .03632 Metetra
.664 .741 .907 r
.667 .03632 .66805 .03788 .67527 .03509 .67423 .03353 Metetra
.664 .741 .907 r
.67423 .03353 .67527 .03509 .68251 .03229 .68147 .03073 Metetra
.664 .741 .907 r
.68147 .03073 .68251 .03229 .68977 .02949 .68873 .02792 Metetra
.664 .741 .907 r
.68873 .02792 .68977 .02949 .69704 .02668 .69601 .02511 Metetra
.664 .741 .907 r
.69601 .02511 .69704 .02668 .70434 .02386 .70331 .02229 Metetra
.664 .741 .907 r
.05454 .27137 .05587 .27261 .06161 .27039 .06029 .26915 Metetra
.664 .741 .907 r
.06029 .26915 .06161 .27039 .06737 .26816 .06605 .26692 Metetra
.664 .741 .907 r
.06605 .26692 .06737 .26816 .07314 .26593 .07182 .26469 Metetra
.664 .741 .907 r
.07182 .26469 .07314 .26593 .07892 .2637 .0776 .26245 Metetra
.664 .741 .907 r
.0776 .26245 .07892 .2637 .08471 .26146 .0834 .26021 Metetra
.664 .741 .907 r
.0834 .26021 .08471 .26146 .09052 .25921 .08921 .25796 Metetra
.664 .741 .907 r
.08921 .25796 .09052 .25921 .09635 .25696 .09504 .2557 Metetra
.664 .741 .907 r
.09504 .2557 .09635 .25696 .10218 .2547 .10087 .25344 Metetra
.664 .741 .907 r
.10087 .25344 .10218 .2547 .10803 .25244 .10672 .25118 Metetra
.664 .741 .907 r
.10672 .25118 .10803 .25244 .11389 .25018 .11259 .24891 Metetra
.664 .741 .907 r
.11259 .24891 .11389 .25018 .11977 .2479 .11847 .24664 Metetra
.664 .741 .907 r
.11847 .24664 .11977 .2479 .12566 .24563 .12436 .24436 Metetra
.664 .741 .907 r
.12436 .24436 .12566 .24563 .13156 .24335 .13027 .24207 Metetra
.664 .741 .907 r
.13027 .24207 .13156 .24335 .13748 .24106 .13618 .23978 Metetra
.664 .741 .907 r
.13618 .23978 .13748 .24106 .14341 .23876 .14212 .23748 Metetra
.664 .741 .907 r
.14212 .23748 .14341 .23876 .14935 .23647 .14806 .23518 Metetra
.664 .741 .907 r
.14806 .23518 .14935 .23647 .15531 .23416 .15402 .23288 Metetra
.664 .741 .907 r
.15402 .23288 .15531 .23416 .16128 .23185 .16 .23056 Metetra
.664 .741 .907 r
.16 .23056 .16128 .23185 .16727 .22954 .16599 .22825 Metetra
.664 .741 .907 r
.16599 .22825 .16727 .22954 .17327 .22722 .17199 .22592 Metetra
.664 .741 .907 r
.17199 .22592 .17327 .22722 .17928 .22489 .17801 .22359 Metetra
.664 .741 .907 r
.17801 .22359 .17928 .22489 .18531 .22256 .18404 .22126 Metetra
.664 .741 .907 r
.18404 .22126 .18531 .22256 .19135 .22023 .19008 .21892 Metetra
.664 .741 .907 r
.19008 .21892 .19135 .22023 .19741 .21789 .19614 .21658 Metetra
.664 .741 .907 r
.19614 .21658 .19741 .21789 .20348 .21554 .20221 .21423 Metetra
.664 .741 .907 r
.20221 .21423 .20348 .21554 .20957 .21319 .2083 .21187 Metetra
.664 .741 .907 r
.2083 .21187 .20957 .21319 .21567 .21083 .2144 .20951 Metetra
.664 .741 .907 r
.2144 .20951 .21567 .21083 .22178 .20846 .22052 .20714 Metetra
.664 .741 .907 r
.22052 .20714 .22178 .20846 .22791 .20609 .22665 .20477 Metetra
.664 .741 .907 r
.22665 .20477 .22791 .20609 .23405 .20372 .23279 .20239 Metetra
.664 .741 .907 r
.23279 .20239 .23405 .20372 .24021 .20134 .23895 .20001 Metetra
.664 .741 .907 r
.23895 .20001 .24021 .20134 .24638 .19895 .24513 .19762 Metetra
.664 .741 .907 r
.24513 .19762 .24638 .19895 .25256 .19656 .25132 .19522 Metetra
.664 .741 .907 r
.25132 .19522 .25256 .19656 .25876 .19416 .25752 .19282 Metetra
.664 .741 .907 r
.25752 .19282 .25876 .19416 .26498 .19176 .26374 .19042 Metetra
.664 .741 .907 r
.26374 .19042 .26498 .19176 .27121 .18935 .26997 .18801 Metetra
.664 .741 .907 r
.26997 .18801 .27121 .18935 .27746 .18694 .27622 .18559 Metetra
.664 .741 .907 r
.27622 .18559 .27746 .18694 .28372 .18452 .28248 .18316 Metetra
.664 .741 .907 r
.28248 .18316 .28372 .18452 .28999 .18209 .28876 .18073 Metetra
.961 .679 .453 r
.28876 .18073 .28999 .18209 .27814 .41789 .2768 .4166 Metetra
.96 .699 .496 r
.2768 .4166 .27814 .41789 .29895 .22626 .29652 .2408 Metetra
.712 .673 .127 r
.29652 .2408 .29895 .22626 .30891 .17478 .30768 .17341 Metetra
.664 .741 .907 r
.30768 .17341 .30891 .17478 .31524 .17233 .31402 .17096 Metetra
.664 .741 .907 r
.31402 .17096 .31524 .17233 .32159 .16987 .32037 .1685 Metetra
.664 .741 .907 r
.32037 .1685 .32159 .16987 .32796 .16741 .32674 .16604 Metetra
.664 .741 .907 r
.32674 .16604 .32796 .16741 .33434 .16494 .33313 .16356 Metetra
.664 .741 .907 r
.33313 .16356 .33434 .16494 .34073 .16247 .33953 .16109 Metetra
.664 .741 .907 r
.33953 .16109 .34073 .16247 .34715 .15999 .34594 .15861 Metetra
.664 .741 .907 r
.34594 .15861 .34715 .15999 .35357 .15751 .35237 .15612 Metetra
.664 .741 .907 r
.35237 .15612 .35357 .15751 .36002 .15502 .35882 .15362 Metetra
.664 .741 .907 r
.35882 .15362 .36002 .15502 .36648 .15252 .36528 .15112 Metetra
.664 .741 .907 r
.36528 .15112 .36648 .15252 .37295 .15001 .37176 .14862 Metetra
.664 .741 .907 r
.37176 .14862 .37295 .15001 .37944 .14751 .37825 .1461 Metetra
.664 .741 .907 r
.37825 .1461 .37944 .14751 .38595 .14499 .38476 .14358 Metetra
.664 .741 .907 r
.38476 .14358 .38595 .14499 .39247 .14247 .39128 .14106 Metetra
.664 .741 .907 r
.39128 .14106 .39247 .14247 .399 .13994 .39782 .13853 Metetra
.664 .741 .907 r
.39782 .13853 .399 .13994 .40556 .13741 .40438 .13599 Metetra
.664 .741 .907 r
.40438 .13599 .40556 .13741 .41213 .13487 .41095 .13345 Metetra
.664 .741 .907 r
.41095 .13345 .41213 .13487 .41871 .13232 .41754 .1309 Metetra
.664 .741 .907 r
.41754 .1309 .41871 .13232 .42531 .12977 .42414 .12834 Metetra
.664 .741 .907 r
.42414 .12834 .42531 .12977 .43193 .12721 .43076 .12578 Metetra
.664 .741 .907 r
.43076 .12578 .43193 .12721 .43856 .12465 .4374 .12321 Metetra
.664 .741 .907 r
.4374 .12321 .43856 .12465 .44522 .12207 .44405 .12064 Metetra
.664 .741 .907 r
.44405 .12064 .44522 .12207 .45188 .1195 .45072 .11806 Metetra
.664 .741 .907 r
.45072 .11806 .45188 .1195 .45856 .11691 .45741 .11547 Metetra
.664 .741 .907 r
.45741 .11547 .45856 .11691 .46526 .11432 .46411 .11287 Metetra
.664 .741 .907 r
.46411 .11287 .46526 .11432 .47198 .11173 .47083 .11027 Metetra
.664 .741 .907 r
.47083 .11027 .47198 .11173 .47871 .10912 .47757 .10767 Metetra
.664 .741 .907 r
.47757 .10767 .47871 .10912 .48546 .10651 .48432 .10505 Metetra
.664 .741 .907 r
.48432 .10505 .48546 .10651 .49223 .1039 .49109 .10244 Metetra
.664 .741 .907 r
.49109 .10244 .49223 .1039 .49901 .10127 .49788 .09981 Metetra
.664 .741 .907 r
.49788 .09981 .49901 .10127 .50581 .09865 .50468 .09718 Metetra
.664 .741 .907 r
.50468 .09718 .50581 .09865 .51263 .09601 .5115 .09454 Metetra
.664 .741 .907 r
.5115 .09454 .51263 .09601 .51946 .09337 .51834 .09189 Metetra
.664 .741 .907 r
.51834 .09189 .51946 .09337 .52631 .09072 .52519 .08924 Metetra
.664 .741 .907 r
.52519 .08924 .52631 .09072 .53318 .08806 .53206 .08658 Metetra
.664 .741 .907 r
.53206 .08658 .53318 .08806 .54006 .0854 .53895 .08391 Metetra
.664 .741 .907 r
.53895 .08391 .54006 .0854 .54697 .08273 .54585 .08124 Metetra
.664 .741 .907 r
.54585 .08124 .54697 .08273 .55389 .08006 .55278 .07856 Metetra
.664 .741 .907 r
.55278 .07856 .55389 .08006 .56082 .07738 .55972 .07588 Metetra
.664 .741 .907 r
.55972 .07588 .56082 .07738 .56778 .07469 .56667 .07318 Metetra
.664 .741 .907 r
.56667 .07318 .56778 .07469 .57475 .07199 .57365 .07049 Metetra
.664 .741 .907 r
.57365 .07049 .57475 .07199 .58174 .06929 .58064 .06778 Metetra
.664 .741 .907 r
.58064 .06778 .58174 .06929 .58874 .06658 .58765 .06507 Metetra
.664 .741 .907 r
.58765 .06507 .58874 .06658 .59577 .06386 .59468 .06235 Metetra
.664 .741 .907 r
.59468 .06235 .59577 .06386 .60281 .06114 .60173 .05962 Metetra
.664 .741 .907 r
.60173 .05962 .60281 .06114 .60987 .05841 .60879 .05689 Metetra
.664 .741 .907 r
.60879 .05689 .60987 .05841 .61695 .05568 .61587 .05415 Metetra
.664 .741 .907 r
.61587 .05415 .61695 .05568 .62404 .05293 .62297 .0514 Metetra
.955 .615 .235 r
.62297 .0514 .62404 .05293 .63275 .09322 .63286 .12428 Metetra
.627 .342 .466 r
.63286 .12428 .63275 .09322 .6427 .15894 .6418 .16257 Metetra
.981 .72 .324 r
.6418 .16257 .6427 .15894 .64544 .04466 .64438 .04311 Metetra
.664 .741 .907 r
.64438 .04311 .64544 .04466 .65261 .04189 .65155 .04034 Metetra
.664 .741 .907 r
.65155 .04034 .65261 .04189 .6598 .03911 .65874 .03756 Metetra
.664 .741 .907 r
.65874 .03756 .6598 .03911 .667 .03632 .66595 .03477 Metetra
.664 .741 .907 r
.66595 .03477 .667 .03632 .67423 .03353 .67318 .03197 Metetra
.664 .741 .907 r
.67318 .03197 .67423 .03353 .68147 .03073 .68043 .02916 Metetra
.664 .741 .907 r
.68043 .02916 .68147 .03073 .68873 .02792 .68769 .02635 Metetra
.664 .741 .907 r
.68769 .02635 .68873 .02792 .69601 .02511 .69497 .02353 Metetra
.664 .741 .907 r
.69497 .02353 .69601 .02511 .70331 .02229 .70228 .02071 Metetra
.664 .741 .907 r
.05322 .27013 .05454 .27137 .06029 .26915 .05896 .26791 Metetra
.664 .741 .907 r
.05896 .26791 .06029 .26915 .06605 .26692 .06472 .26568 Metetra
.664 .741 .907 r
.06472 .26568 .06605 .26692 .07182 .26469 .0705 .26344 Metetra
.664 .741 .907 r
.0705 .26344 .07182 .26469 .0776 .26245 .07628 .2612 Metetra
.664 .741 .907 r
.07628 .2612 .0776 .26245 .0834 .26021 .08208 .25895 Metetra
.664 .741 .907 r
.08208 .25895 .0834 .26021 .08921 .25796 .0879 .2567 Metetra
.664 .741 .907 r
.0879 .2567 .08921 .25796 .09504 .2557 .09372 .25444 Metetra
.664 .741 .907 r
.09372 .25444 .09504 .2557 .10087 .25344 .09956 .25218 Metetra
.664 .741 .907 r
.09956 .25218 .10087 .25344 .10672 .25118 .10542 .24991 Metetra
.664 .741 .907 r
.10542 .24991 .10672 .25118 .11259 .24891 .11128 .24764 Metetra
.664 .741 .907 r
.11128 .24764 .11259 .24891 .11847 .24664 .11716 .24536 Metetra
.664 .741 .907 r
.11716 .24536 .11847 .24664 .12436 .24436 .12306 .24308 Metetra
.664 .741 .907 r
.12306 .24308 .12436 .24436 .13027 .24207 .12897 .24079 Metetra
.664 .741 .907 r
.12897 .24079 .13027 .24207 .13618 .23978 .13489 .2385 Metetra
.664 .741 .907 r
.13489 .2385 .13618 .23978 .14212 .23748 .14082 .2362 Metetra
.664 .741 .907 r
.14082 .2362 .14212 .23748 .14806 .23518 .14677 .2339 Metetra
.664 .741 .907 r
.14677 .2339 .14806 .23518 .15402 .23288 .15274 .23159 Metetra
.664 .741 .907 r
.15274 .23159 .15402 .23288 .16 .23056 .15871 .22927 Metetra
.664 .741 .907 r
.15871 .22927 .16 .23056 .16599 .22825 .1647 .22695 Metetra
.664 .741 .907 r
.1647 .22695 .16599 .22825 .17199 .22592 .17071 .22462 Metetra
.664 .741 .907 r
.17071 .22462 .17199 .22592 .17801 .22359 .17673 .22229 Metetra
.664 .741 .907 r
.17673 .22229 .17801 .22359 .18404 .22126 .18276 .21996 Metetra
.664 .741 .907 r
.18276 .21996 .18404 .22126 .19008 .21892 .18881 .21761 Metetra
.664 .741 .907 r
.18881 .21761 .19008 .21892 .19614 .21658 .19487 .21527 Metetra
.664 .741 .907 r
.19487 .21527 .19614 .21658 .20221 .21423 .20094 .21291 Metetra
.664 .741 .907 r
.20094 .21291 .20221 .21423 .2083 .21187 .20703 .21055 Metetra
.664 .741 .907 r
.20703 .21055 .2083 .21187 .2144 .20951 .21314 .20819 Metetra
.664 .741 .907 r
.21314 .20819 .2144 .20951 .22052 .20714 .21926 .20582 Metetra
.664 .741 .907 r
.21926 .20582 .22052 .20714 .22665 .20477 .22539 .20344 Metetra
.664 .741 .907 r
.22539 .20344 .22665 .20477 .23279 .20239 .23154 .20106 Metetra
.664 .741 .907 r
.23154 .20106 .23279 .20239 .23895 .20001 .2377 .19868 Metetra
.664 .741 .907 r
.2377 .19868 .23895 .20001 .24513 .19762 .24388 .19628 Metetra
.664 .741 .907 r
.24388 .19628 .24513 .19762 .25132 .19522 .25007 .19389 Metetra
.664 .741 .907 r
.25007 .19389 .25132 .19522 .25752 .19282 .25627 .19148 Metetra
.664 .741 .907 r
.25627 .19148 .25752 .19282 .26374 .19042 .26249 .18907 Metetra
.664 .741 .907 r
.26249 .18907 .26374 .19042 .26997 .18801 .26873 .18666 Metetra
.664 .741 .907 r
.26873 .18666 .26997 .18801 .27622 .18559 .27498 .18424 Metetra
.664 .741 .907 r
.27498 .18424 .27622 .18559 .28248 .18316 .28125 .18181 Metetra
.664 .741 .907 r
.28125 .18181 .28248 .18316 .28876 .18073 .28753 .17938 Metetra
.961 .679 .453 r
.28753 .17938 .28876 .18073 .2768 .4166 .27546 .4153 Metetra
.96 .7 .498 r
.27546 .4153 .2768 .4166 .29652 .2408 .29433 .25184 Metetra
.942 .791 .331 r
.29433 .25184 .29652 .2408 .30768 .17341 .30646 .17204 Metetra
.664 .741 .907 r
.30646 .17204 .30768 .17341 .31402 .17096 .3128 .16959 Metetra
.664 .741 .907 r
.3128 .16959 .31402 .17096 .32037 .1685 .31916 .16713 Metetra
.664 .741 .907 r
.31916 .16713 .32037 .1685 .32674 .16604 .32553 .16466 Metetra
.664 .741 .907 r
.32553 .16466 .32674 .16604 .33313 .16356 .33191 .16218 Metetra
.664 .741 .907 r
.33191 .16218 .33313 .16356 .33953 .16109 .33832 .1597 Metetra
.664 .741 .907 r
.33832 .1597 .33953 .16109 .34594 .15861 .34473 .15722 Metetra
.664 .741 .907 r
.34473 .15722 .34594 .15861 .35237 .15612 .35117 .15473 Metetra
.664 .741 .907 r
.35117 .15473 .35237 .15612 .35882 .15362 .35761 .15223 Metetra
.664 .741 .907 r
.35761 .15223 .35882 .15362 .36528 .15112 .36408 .14973 Metetra
.664 .741 .907 r
.36408 .14973 .36528 .15112 .37176 .14862 .37056 .14722 Metetra
.664 .741 .907 r
.37056 .14722 .37176 .14862 .37825 .1461 .37705 .1447 Metetra
.664 .741 .907 r
.37705 .1447 .37825 .1461 .38476 .14358 .38357 .14218 Metetra
.664 .741 .907 r
.38357 .14218 .38476 .14358 .39128 .14106 .39009 .13965 Metetra
.664 .741 .907 r
.39009 .13965 .39128 .14106 .39782 .13853 .39664 .13711 Metetra
.664 .741 .907 r
.39664 .13711 .39782 .13853 .40438 .13599 .4032 .13457 Metetra
.664 .741 .907 r
.4032 .13457 .40438 .13599 .41095 .13345 .40977 .13203 Metetra
.664 .741 .907 r
.40977 .13203 .41095 .13345 .41754 .1309 .41636 .12947 Metetra
.664 .741 .907 r
.41636 .12947 .41754 .1309 .42414 .12834 .42297 .12691 Metetra
.664 .741 .907 r
.42297 .12691 .42414 .12834 .43076 .12578 .42959 .12435 Metetra
.664 .741 .907 r
.42959 .12435 .43076 .12578 .4374 .12321 .43624 .12178 Metetra
.664 .741 .907 r
.43624 .12178 .4374 .12321 .44405 .12064 .44289 .1192 Metetra
.664 .741 .907 r
.44289 .1192 .44405 .12064 .45072 .11806 .44956 .11661 Metetra
.664 .741 .907 r
.44956 .11661 .45072 .11806 .45741 .11547 .45625 .11402 Metetra
.664 .741 .907 r
.45625 .11402 .45741 .11547 .46411 .11287 .46296 .11143 Metetra
.664 .741 .907 r
.46296 .11143 .46411 .11287 .47083 .11027 .46968 .10882 Metetra
.664 .741 .907 r
.46968 .10882 .47083 .11027 .47757 .10767 .47642 .10621 Metetra
.664 .741 .907 r
.47642 .10621 .47757 .10767 .48432 .10505 .48318 .10359 Metetra
.664 .741 .907 r
.48318 .10359 .48432 .10505 .49109 .10244 .48995 .10097 Metetra
.664 .741 .907 r
.48995 .10097 .49109 .10244 .49788 .09981 .49674 .09834 Metetra
.664 .741 .907 r
.49674 .09834 .49788 .09981 .50468 .09718 .50354 .09571 Metetra
.664 .741 .907 r
.50354 .09571 .50468 .09718 .5115 .09454 .51037 .09306 Metetra
.664 .741 .907 r
.51037 .09306 .5115 .09454 .51834 .09189 .51721 .09041 Metetra
.664 .741 .907 r
.51721 .09041 .51834 .09189 .52519 .08924 .52407 .08776 Metetra
.664 .741 .907 r
.52407 .08776 .52519 .08924 .53206 .08658 .53094 .08509 Metetra
.664 .741 .907 r
.53094 .08509 .53206 .08658 .53895 .08391 .53783 .08242 Metetra
.664 .741 .907 r
.53783 .08242 .53895 .08391 .54585 .08124 .54474 .07975 Metetra
.664 .741 .907 r
.54474 .07975 .54585 .08124 .55278 .07856 .55167 .07707 Metetra
.664 .741 .907 r
.55167 .07707 .55278 .07856 .55972 .07588 .55861 .07438 Metetra
.664 .741 .907 r
.55861 .07438 .55972 .07588 .56667 .07318 .56557 .07168 Metetra
.664 .741 .907 r
.56557 .07168 .56667 .07318 .57365 .07049 .57255 .06898 Metetra
.664 .741 .907 r
.57255 .06898 .57365 .07049 .58064 .06778 .57955 .06627 Metetra
.664 .741 .907 r
.57955 .06627 .58064 .06778 .58765 .06507 .58656 .06355 Metetra
.664 .741 .907 r
.58656 .06355 .58765 .06507 .59468 .06235 .59359 .06083 Metetra
.664 .741 .907 r
.59359 .06083 .59468 .06235 .60173 .05962 .60064 .0581 Metetra
.664 .741 .907 r
.60064 .0581 .60173 .05962 .60879 .05689 .60771 .05536 Metetra
.664 .741 .907 r
.60771 .05536 .60879 .05689 .61587 .05415 .61479 .05261 Metetra
.664 .741 .907 r
.61479 .05261 .61587 .05415 .62297 .0514 .6219 .04986 Metetra
.956 .616 .238 r
.6219 .04986 .62297 .0514 .63286 .12428 .63183 .12451 Metetra
.909 .503 .183 r
.63183 .12451 .63286 .12428 .6418 .16257 .64037 .15293 Metetra
.933 .638 .46 r
.64037 .15293 .6418 .16257 .64438 .04311 .64332 .04157 Metetra
.664 .741 .907 r
.64332 .04157 .64438 .04311 .65155 .04034 .65049 .03879 Metetra
.664 .741 .907 r
.65049 .03879 .65155 .04034 .65874 .03756 .65769 .036 Metetra
.664 .741 .907 r
.65769 .036 .65874 .03756 .66595 .03477 .6649 .03321 Metetra
.664 .741 .907 r
.6649 .03321 .66595 .03477 .67318 .03197 .67213 .03041 Metetra
.664 .741 .907 r
.67213 .03041 .67318 .03197 .68043 .02916 .67938 .0276 Metetra
.664 .741 .907 r
.67938 .0276 .68043 .02916 .68769 .02635 .68665 .02478 Metetra
.664 .741 .907 r
.68665 .02478 .68769 .02635 .69497 .02353 .69394 .02196 Metetra
.664 .741 .907 r
.69394 .02196 .69497 .02353 .70228 .02071 .70124 .01913 Metetra
.664 .741 .907 r
.05189 .26889 .05322 .27013 .05896 .26791 .05764 .26666 Metetra
.664 .741 .907 r
.05764 .26666 .05896 .26791 .06472 .26568 .0634 .26443 Metetra
.664 .741 .907 r
.0634 .26443 .06472 .26568 .0705 .26344 .06918 .26219 Metetra
.664 .741 .907 r
.06918 .26219 .0705 .26344 .07628 .2612 .07496 .25995 Metetra
.664 .741 .907 r
.07496 .25995 .07628 .2612 .08208 .25895 .08077 .2577 Metetra
.664 .741 .907 r
.08077 .2577 .08208 .25895 .0879 .2567 .08658 .25544 Metetra
.664 .741 .907 r
.08658 .25544 .0879 .2567 .09372 .25444 .09241 .25318 Metetra
.664 .741 .907 r
.09241 .25318 .09372 .25444 .09956 .25218 .09825 .25092 Metetra
.664 .741 .907 r
.09825 .25092 .09956 .25218 .10542 .24991 .10411 .24865 Metetra
.664 .741 .907 r
.10411 .24865 .10542 .24991 .11128 .24764 .10998 .24637 Metetra
.664 .741 .907 r
.10998 .24637 .11128 .24764 .11716 .24536 .11586 .24409 Metetra
.664 .741 .907 r
.11586 .24409 .11716 .24536 .12306 .24308 .12176 .24181 Metetra
.664 .741 .907 r
.12176 .24181 .12306 .24308 .12897 .24079 .12767 .23951 Metetra
.664 .741 .907 r
.12767 .23951 .12897 .24079 .13489 .2385 .13359 .23722 Metetra
.664 .741 .907 r
.13359 .23722 .13489 .2385 .14082 .2362 .13953 .23492 Metetra
.664 .741 .907 r
.13953 .23492 .14082 .2362 .14677 .2339 .14548 .23261 Metetra
.664 .741 .907 r
.14548 .23261 .14677 .2339 .15274 .23159 .15145 .2303 Metetra
.664 .741 .907 r
.15145 .2303 .15274 .23159 .15871 .22927 .15742 .22798 Metetra
.664 .741 .907 r
.15742 .22798 .15871 .22927 .1647 .22695 .16342 .22565 Metetra
.664 .741 .907 r
.16342 .22565 .1647 .22695 .17071 .22462 .16943 .22333 Metetra
.664 .741 .907 r
.16943 .22333 .17071 .22462 .17673 .22229 .17545 .22099 Metetra
.664 .741 .907 r
.17545 .22099 .17673 .22229 .18276 .21996 .18148 .21865 Metetra
.664 .741 .907 r
.18148 .21865 .18276 .21996 .18881 .21761 .18753 .21631 Metetra
.664 .741 .907 r
.18753 .21631 .18881 .21761 .19487 .21527 .1936 .21395 Metetra
.664 .741 .907 r
.1936 .21395 .19487 .21527 .20094 .21291 .19967 .2116 Metetra
.664 .741 .907 r
.19967 .2116 .20094 .21291 .20703 .21055 .20577 .20924 Metetra
.664 .741 .907 r
.20577 .20924 .20703 .21055 .21314 .20819 .21187 .20687 Metetra
.664 .741 .907 r
.21187 .20687 .21314 .20819 .21926 .20582 .21799 .2045 Metetra
.664 .741 .907 r
.21799 .2045 .21926 .20582 .22539 .20344 .22413 .20212 Metetra
.664 .741 .907 r
.22413 .20212 .22539 .20344 .23154 .20106 .23028 .19973 Metetra
.664 .741 .907 r
.23028 .19973 .23154 .20106 .2377 .19868 .23644 .19734 Metetra
.664 .741 .907 r
.23644 .19734 .2377 .19868 .24388 .19628 .24262 .19495 Metetra
.664 .741 .907 r
.24262 .19495 .24388 .19628 .25007 .19389 .24882 .19255 Metetra
.664 .741 .907 r
.24882 .19255 .25007 .19389 .25627 .19148 .25503 .19014 Metetra
.664 .741 .907 r
.25503 .19014 .25627 .19148 .26249 .18907 .26125 .18773 Metetra
.664 .741 .907 r
.26125 .18773 .26249 .18907 .26873 .18666 .26749 .18531 Metetra
.664 .741 .907 r
.26749 .18531 .26873 .18666 .27498 .18424 .27374 .18288 Metetra
.664 .741 .907 r
.27374 .18288 .27498 .18424 .28125 .18181 .28001 .18045 Metetra
.664 .741 .907 r
.28001 .18045 .28125 .18181 .28753 .17938 .28629 .17802 Metetra
.961 .679 .453 r
.28629 .17802 .28753 .17938 .27546 .4153 .27412 .414 Metetra
.96 .699 .496 r
.27412 .414 .27546 .4153 .29433 .25184 .2937 .24205 Metetra
.866 .609 .547 r
.2937 .24205 .29433 .25184 .30646 .17204 .30523 .17067 Metetra
.664 .741 .907 r
.30523 .17067 .30646 .17204 .3128 .16959 .31158 .16822 Metetra
.664 .741 .907 r
.31158 .16822 .3128 .16959 .31916 .16713 .31793 .16575 Metetra
.664 .741 .907 r
.31793 .16575 .31916 .16713 .32553 .16466 .32431 .16328 Metetra
.664 .741 .907 r
.32431 .16328 .32553 .16466 .33191 .16218 .3307 .1608 Metetra
.664 .741 .907 r
.3307 .1608 .33191 .16218 .33832 .1597 .3371 .15832 Metetra
.664 .741 .907 r
.3371 .15832 .33832 .1597 .34473 .15722 .34352 .15583 Metetra
.664 .741 .907 r
.34352 .15583 .34473 .15722 .35117 .15473 .34996 .15333 Metetra
.664 .741 .907 r
.34996 .15333 .35117 .15473 .35761 .15223 .35641 .15083 Metetra
.664 .741 .907 r
.35641 .15083 .35761 .15223 .36408 .14973 .36288 .14833 Metetra
.664 .741 .907 r
.36288 .14833 .36408 .14973 .37056 .14722 .36936 .14581 Metetra
.664 .741 .907 r
.36936 .14581 .37056 .14722 .37705 .1447 .37586 .14329 Metetra
.664 .741 .907 r
.37586 .14329 .37705 .1447 .38357 .14218 .38237 .14077 Metetra
.664 .741 .907 r
.38237 .14077 .38357 .14218 .39009 .13965 .38891 .13824 Metetra
.664 .741 .907 r
.38891 .13824 .39009 .13965 .39664 .13711 .39545 .1357 Metetra
.664 .741 .907 r
.39545 .1357 .39664 .13711 .4032 .13457 .40201 .13315 Metetra
.664 .741 .907 r
.40201 .13315 .4032 .13457 .40977 .13203 .40859 .1306 Metetra
.664 .741 .907 r
.40859 .1306 .40977 .13203 .41636 .12947 .41519 .12805 Metetra
.664 .741 .907 r
.41519 .12805 .41636 .12947 .42297 .12691 .4218 .12548 Metetra
.664 .741 .907 r
.4218 .12548 .42297 .12691 .42959 .12435 .42842 .12292 Metetra
.664 .741 .907 r
.42842 .12292 .42959 .12435 .43624 .12178 .43507 .12034 Metetra
.664 .741 .907 r
.43507 .12034 .43624 .12178 .44289 .1192 .44173 .11776 Metetra
.664 .741 .907 r
.44173 .11776 .44289 .1192 .44956 .11661 .4484 .11517 Metetra
.248 .532 .919 r
.4484 .11517 .44956 .11661 .45625 .11402 .45499 .11688 Metetra
.45499 .11688 .45625 .11402 .46296 .11143 .4618 .10997 Metetra
.664 .741 .907 r
.4618 .10997 .46296 .11143 .46968 .10882 .46853 .10737 Metetra
.664 .741 .907 r
.46853 .10737 .46968 .10882 .47642 .10621 .47527 .10475 Metetra
.664 .741 .907 r
.47527 .10475 .47642 .10621 .48318 .10359 .48203 .10213 Metetra
.664 .741 .907 r
.48203 .10213 .48318 .10359 .48995 .10097 .48881 .09951 Metetra
.664 .741 .907 r
.48881 .09951 .48995 .10097 .49674 .09834 .4956 .09687 Metetra
.664 .741 .907 r
.4956 .09687 .49674 .09834 .50354 .09571 .50241 .09423 Metetra
.664 .741 .907 r
.50241 .09423 .50354 .09571 .51037 .09306 .50924 .09159 Metetra
.664 .741 .907 r
.50924 .09159 .51037 .09306 .51721 .09041 .51608 .08893 Metetra
.664 .741 .907 r
.51608 .08893 .51721 .09041 .52407 .08776 .52294 .08627 Metetra
.664 .741 .907 r
.52294 .08627 .52407 .08776 .53094 .08509 .52982 .08361 Metetra
.664 .741 .907 r
.52982 .08361 .53094 .08509 .53783 .08242 .53671 .08093 Metetra
.664 .741 .907 r
.53671 .08093 .53783 .08242 .54474 .07975 .54363 .07825 Metetra
.664 .741 .907 r
.54363 .07825 .54474 .07975 .55167 .07707 .55056 .07557 Metetra
.664 .741 .907 r
.55056 .07557 .55167 .07707 .55861 .07438 .5575 .07287 Metetra
.664 .741 .907 r
.5575 .07287 .55861 .07438 .56557 .07168 .56447 .07017 Metetra
.664 .741 .907 r
.56447 .07017 .56557 .07168 .57255 .06898 .57145 .06747 Metetra
.664 .741 .907 r
.57145 .06747 .57255 .06898 .57955 .06627 .57845 .06475 Metetra
.664 .741 .907 r
.57845 .06475 .57955 .06627 .58656 .06355 .58547 .06203 Metetra
.664 .741 .907 r
.58547 .06203 .58656 .06355 .59359 .06083 .5925 .0593 Metetra
.664 .741 .907 r
.5925 .0593 .59359 .06083 .60064 .0581 .59956 .05657 Metetra
.664 .741 .907 r
.59956 .05657 .60064 .0581 .60771 .05536 .60663 .05383 Metetra
.664 .741 .907 r
.60663 .05383 .60771 .05536 .61479 .05261 .61372 .05108 Metetra
.664 .741 .907 r
.61372 .05108 .61479 .05261 .6219 .04986 .62082 .04833 Metetra
.944 .592 .195 r
.62082 .04833 .6219 .04986 .63183 .12451 .62997 .10192 Metetra
.198 .076 .479 r
.62997 .10192 .63183 .12451 .64037 .15293 .63894 .14299 Metetra
.925 .631 .468 r
.63894 .14299 .64037 .15293 .64332 .04157 .64225 .04002 Metetra
.664 .741 .907 r
.64225 .04002 .64332 .04157 .65049 .03879 .64943 .03723 Metetra
.664 .741 .907 r
.64943 .03723 .65049 .03879 .65769 .036 .65663 .03444 Metetra
.664 .741 .907 r
.65663 .03444 .65769 .036 .6649 .03321 .66385 .03165 Metetra
.664 .741 .907 r
.66385 .03165 .6649 .03321 .67213 .03041 .67108 .02884 Metetra
.664 .741 .907 r
.67108 .02884 .67213 .03041 .67938 .0276 .67834 .02603 Metetra
.664 .741 .907 r
.67834 .02603 .67938 .0276 .68665 .02478 .68561 .02321 Metetra
.664 .741 .907 r
.68561 .02321 .68665 .02478 .69394 .02196 .6929 .02038 Metetra
.664 .741 .907 r
.6929 .02038 .69394 .02196 .70124 .01913 .70021 .01755 Metetra
.664 .741 .907 r
.05056 .26765 .05189 .26889 .05764 .26666 .05631 .26542 Metetra
.664 .741 .907 r
.05631 .26542 .05764 .26666 .0634 .26443 .06207 .26318 Metetra
.664 .741 .907 r
.06207 .26318 .0634 .26443 .06918 .26219 .06785 .26094 Metetra
.664 .741 .907 r
.06785 .26094 .06918 .26219 .07496 .25995 .07364 .25869 Metetra
.664 .741 .907 r
.07364 .25869 .07496 .25995 .08077 .2577 .07945 .25644 Metetra
.664 .741 .907 r
.07945 .25644 .08077 .2577 .08658 .25544 .08526 .25418 Metetra
.664 .741 .907 r
.08526 .25418 .08658 .25544 .09241 .25318 .0911 .25192 Metetra
.664 .741 .907 r
.0911 .25192 .09241 .25318 .09825 .25092 .09694 .24965 Metetra
.664 .741 .907 r
.09694 .24965 .09825 .25092 .10411 .24865 .1028 .24738 Metetra
.664 .741 .907 r
.1028 .24738 .10411 .24865 .10998 .24637 .10867 .2451 Metetra
.664 .741 .907 r
.10867 .2451 .10998 .24637 .11586 .24409 .11455 .24282 Metetra
.664 .741 .907 r
.11455 .24282 .11586 .24409 .12176 .24181 .12045 .24053 Metetra
.664 .741 .907 r
.12045 .24053 .12176 .24181 .12767 .23951 .12637 .23823 Metetra
.664 .741 .907 r
.12637 .23823 .12767 .23951 .13359 .23722 .13229 .23593 Metetra
.887 .46 .093 r
.13229 .23593 .13359 .23722 .13953 .23492 .1365 .24733 Metetra
.203 0 .303 r
.1365 .24733 .13953 .23492 .14548 .23261 .14419 .23132 Metetra
.664 .741 .907 r
.14419 .23132 .14548 .23261 .15145 .2303 .15015 .229 Metetra
.664 .741 .907 r
.15015 .229 .15145 .2303 .15742 .22798 .15614 .22668 Metetra
.664 .741 .907 r
.15614 .22668 .15742 .22798 .16342 .22565 .16213 .22436 Metetra
.664 .741 .907 r
.16213 .22436 .16342 .22565 .16943 .22333 .16814 .22202 Metetra
.664 .741 .907 r
.16814 .22202 .16943 .22333 .17545 .22099 .17416 .21969 Metetra
.664 .741 .907 r
.17416 .21969 .17545 .22099 .18148 .21865 .1802 .21734 Metetra
.664 .741 .907 r
.1802 .21734 .18148 .21865 .18753 .21631 .18625 .215 Metetra
.664 .741 .907 r
.18625 .215 .18753 .21631 .1936 .21395 .19232 .21264 Metetra
.664 .741 .907 r
.19232 .21264 .1936 .21395 .19967 .2116 .1984 .21028 Metetra
.664 .741 .907 r
.1984 .21028 .19967 .2116 .20577 .20924 .2045 .20792 Metetra
.664 .741 .907 r
.2045 .20792 .20577 .20924 .21187 .20687 .21061 .20555 Metetra
.664 .741 .907 r
.21061 .20555 .21187 .20687 .21799 .2045 .21673 .20317 Metetra
.664 .741 .907 r
.21673 .20317 .21799 .2045 .22413 .20212 .22287 .20079 Metetra
.664 .741 .907 r
.22287 .20079 .22413 .20212 .23028 .19973 .22902 .1984 Metetra
.664 .741 .907 r
.22902 .1984 .23028 .19973 .23644 .19734 .23519 .19601 Metetra
.664 .741 .907 r
.23519 .19601 .23644 .19734 .24262 .19495 .24137 .19361 Metetra
.664 .741 .907 r
.24137 .19361 .24262 .19495 .24882 .19255 .24757 .1912 Metetra
.664 .741 .907 r
.24757 .1912 .24882 .19255 .25503 .19014 .25378 .18879 Metetra
.664 .741 .907 r
.25378 .18879 .25503 .19014 .26125 .18773 .26 .18638 Metetra
.664 .741 .907 r
.26 .18638 .26125 .18773 .26749 .18531 .26624 .18396 Metetra
.664 .741 .907 r
.26624 .18396 .26749 .18531 .27374 .18288 .2725 .18153 Metetra
.664 .741 .907 r
.2725 .18153 .27374 .18288 .28001 .18045 .27877 .1791 Metetra
.664 .741 .907 r
.27877 .1791 .28001 .18045 .28629 .17802 .28506 .17666 Metetra
.961 .679 .453 r
.28506 .17666 .28629 .17802 .27412 .414 .27277 .4127 Metetra
.96 .697 .492 r
.27277 .4127 .27412 .414 .2937 .24205 .2951 .20571 Metetra
.627 .383 .529 r
.2951 .20571 .2937 .24205 .30523 .17067 .304 .1693 Metetra
.664 .741 .907 r
.304 .1693 .30523 .17067 .31158 .16822 .31035 .16684 Metetra
.664 .741 .907 r
.31035 .16684 .31158 .16822 .31793 .16575 .31671 .16437 Metetra
.664 .741 .907 r
.31671 .16437 .31793 .16575 .32431 .16328 .32309 .1619 Metetra
.664 .741 .907 r
.32309 .1619 .32431 .16328 .3307 .1608 .32948 .15942 Metetra
.664 .741 .907 r
.32948 .15942 .3307 .1608 .3371 .15832 .33589 .15693 Metetra
.664 .741 .907 r
.33589 .15693 .3371 .15832 .34352 .15583 .34231 .15444 Metetra
.664 .741 .907 r
.34231 .15444 .34352 .15583 .34996 .15333 .34875 .15194 Metetra
.664 .741 .907 r
.34875 .15194 .34996 .15333 .35641 .15083 .35521 .14944 Metetra
.664 .741 .907 r
.35521 .14944 .35641 .15083 .36288 .14833 .36168 .14693 Metetra
.664 .741 .907 r
.36168 .14693 .36288 .14833 .36936 .14581 .36816 .14441 Metetra
.664 .741 .907 r
.36816 .14441 .36936 .14581 .37586 .14329 .37466 .14189 Metetra
.664 .741 .907 r
.37466 .14189 .37586 .14329 .38237 .14077 .38118 .13936 Metetra
.664 .741 .907 r
.38118 .13936 .38237 .14077 .38891 .13824 .38771 .13682 Metetra
.664 .741 .907 r
.38771 .13682 .38891 .13824 .39545 .1357 .39426 .13428 Metetra
.664 .741 .907 r
.39426 .13428 .39545 .1357 .40201 .13315 .40083 .13173 Metetra
.664 .741 .907 r
.40083 .13173 .40201 .13315 .40859 .1306 .40741 .12918 Metetra
.664 .741 .907 r
.40741 .12918 .40859 .1306 .41519 .12805 .41401 .12662 Metetra
.664 .741 .907 r
.41401 .12662 .41519 .12805 .4218 .12548 .42062 .12405 Metetra
.664 .741 .907 r
.42062 .12405 .4218 .12548 .42842 .12292 .42725 .12148 Metetra
.664 .741 .907 r
.42725 .12148 .42842 .12292 .43507 .12034 .4339 .1189 Metetra
.664 .741 .907 r
.4339 .1189 .43507 .12034 .44173 .11776 .44056 .11631 Metetra
.664 .741 .907 r
.44056 .11631 .44173 .11776 .4484 .11517 .44724 .11372 Metetra
.664 .741 .907 r
.44724 .11372 .4484 .11517 .45499 .11688 .45394 .11113 Metetra
.577 .429 .645 r
.45394 .11113 .45499 .11688 .4618 .10997 .46065 .10852 Metetra
.664 .741 .907 r
.46065 .10852 .4618 .10997 .46853 .10737 .46738 .10591 Metetra
.664 .741 .907 r
.46738 .10591 .46853 .10737 .47527 .10475 .47412 .10329 Metetra
.664 .741 .907 r
.47412 .10329 .47527 .10475 .48203 .10213 .48089 .10067 Metetra
.664 .741 .907 r
.48089 .10067 .48203 .10213 .48881 .09951 .48766 .09804 Metetra
.664 .741 .907 r
.48766 .09804 .48881 .09951 .4956 .09687 .49446 .0954 Metetra
.664 .741 .907 r
.49446 .0954 .4956 .09687 .50241 .09423 .50127 .09276 Metetra
.664 .741 .907 r
.50127 .09276 .50241 .09423 .50924 .09159 .5081 .09011 Metetra
.664 .741 .907 r
.5081 .09011 .50924 .09159 .51608 .08893 .51495 .08745 Metetra
.664 .741 .907 r
.51495 .08745 .51608 .08893 .52294 .08627 .52181 .08479 Metetra
.664 .741 .907 r
.52181 .08479 .52294 .08627 .52982 .08361 .5287 .08212 Metetra
.664 .741 .907 r
.5287 .08212 .52982 .08361 .53671 .08093 .53559 .07944 Metetra
.664 .741 .907 r
.53559 .07944 .53671 .08093 .54363 .07825 .54251 .07676 Metetra
.664 .741 .907 r
.54251 .07676 .54363 .07825 .55056 .07557 .54944 .07407 Metetra
.664 .741 .907 r
.54944 .07407 .55056 .07557 .5575 .07287 .55639 .07137 Metetra
.664 .741 .907 r
.55639 .07137 .5575 .07287 .56447 .07017 .56336 .06866 Metetra
.664 .741 .907 r
.56336 .06866 .56447 .07017 .57145 .06747 .57035 .06595 Metetra
.664 .741 .907 r
.57035 .06595 .57145 .06747 .57845 .06475 .57735 .06324 Metetra
.664 .741 .907 r
.57735 .06324 .57845 .06475 .58547 .06203 .58437 .06051 Metetra
.664 .741 .907 r
.58437 .06051 .58547 .06203 .5925 .0593 .59141 .05778 Metetra
.664 .741 .907 r
.59141 .05778 .5925 .0593 .59956 .05657 .59847 .05504 Metetra
.664 .741 .907 r
.59847 .05504 .59956 .05657 .60663 .05383 .60554 .0523 Metetra
.664 .741 .907 r
.60554 .0523 .60663 .05383 .61372 .05108 .61263 .04954 Metetra
.664 .741 .907 r
.61263 .04954 .61372 .05108 .62082 .04833 .61974 .04679 Metetra
.923 .555 .133 r
.61974 .04679 .62082 .04833 .62997 .10192 .62835 .0854 Metetra
0 0 .293 r
.62835 .0854 .62997 .10192 .63894 .14299 .63851 .15913 Metetra
.747 .614 .046 r
.63851 .15913 .63894 .14299 .64225 .04002 .64119 .03847 Metetra
.664 .741 .907 r
.64119 .03847 .64225 .04002 .64943 .03723 .64837 .03568 Metetra
.664 .741 .907 r
.64837 .03568 .64943 .03723 .65663 .03444 .65557 .03288 Metetra
.664 .741 .907 r
.65557 .03288 .65663 .03444 .66385 .03165 .66279 .03008 Metetra
.664 .741 .907 r
.66279 .03008 .66385 .03165 .67108 .02884 .67003 .02727 Metetra
.664 .741 .907 r
.67003 .02727 .67108 .02884 .67834 .02603 .67729 .02446 Metetra
.664 .741 .907 r
.67729 .02446 .67834 .02603 .68561 .02321 .68456 .02163 Metetra
.664 .741 .907 r
.68456 .02163 .68561 .02321 .6929 .02038 .69186 .0188 Metetra
.664 .741 .907 r
.69186 .0188 .6929 .02038 .70021 .01755 .69917 .01596 Metetra
.664 .741 .907 r
.04923 .26641 .05056 .26765 .05631 .26542 .05498 .26417 Metetra
.664 .741 .907 r
.05498 .26417 .05631 .26542 .06207 .26318 .06075 .26193 Metetra
.664 .741 .907 r
.06075 .26193 .06207 .26318 .06785 .26094 .06653 .25969 Metetra
.664 .741 .907 r
.06653 .25969 .06785 .26094 .07364 .25869 .07232 .25744 Metetra
.664 .741 .907 r
.07232 .25744 .07364 .25869 .07945 .25644 .07813 .25518 Metetra
.664 .741 .907 r
.07813 .25518 .07945 .25644 .08526 .25418 .08395 .25292 Metetra
.664 .741 .907 r
.08395 .25292 .08526 .25418 .0911 .25192 .08978 .25066 Metetra
.664 .741 .907 r
.08978 .25066 .0911 .25192 .09694 .24965 .09563 .24839 Metetra
.664 .741 .907 r
.09563 .24839 .09694 .24965 .1028 .24738 .10149 .24611 Metetra
.664 .741 .907 r
.10149 .24611 .1028 .24738 .10867 .2451 .10736 .24383 Metetra
.664 .741 .907 r
.10736 .24383 .10867 .2451 .11455 .24282 .11325 .24154 Metetra
.664 .741 .907 r
.11325 .24154 .11455 .24282 .12045 .24053 .11915 .23925 Metetra
.664 .741 .907 r
.11915 .23925 .12045 .24053 .12637 .23823 .12506 .23695 Metetra
.664 .741 .907 r
.12506 .23695 .12637 .23823 .13229 .23593 .13099 .23465 Metetra
.664 .741 .907 r
.13099 .23465 .13229 .23593 .1365 .24733 .13693 .23234 Metetra
.532 .327 .548 r
.13693 .23234 .1365 .24733 .14419 .23132 .14289 .23003 Metetra
.664 .741 .907 r
.14289 .23003 .14419 .23132 .15015 .229 .14886 .22771 Metetra
.664 .741 .907 r
.14886 .22771 .15015 .229 .15614 .22668 .15484 .22539 Metetra
.664 .741 .907 r
.15484 .22539 .15614 .22668 .16213 .22436 .16084 .22306 Metetra
.664 .741 .907 r
.16084 .22306 .16213 .22436 .16814 .22202 .16685 .22072 Metetra
.664 .741 .907 r
.16685 .22072 .16814 .22202 .17416 .21969 .17288 .21838 Metetra
.664 .741 .907 r
.17288 .21838 .17416 .21969 .1802 .21734 .17892 .21603 Metetra
.664 .741 .907 r
.17892 .21603 .1802 .21734 .18625 .215 .18497 .21368 Metetra
.664 .741 .907 r
.18497 .21368 .18625 .215 .19232 .21264 .19104 .21133 Metetra
.664 .741 .907 r
.19104 .21133 .19232 .21264 .1984 .21028 .19713 .20896 Metetra
.664 .741 .907 r
.19713 .20896 .1984 .21028 .2045 .20792 .20322 .2066 Metetra
.664 .741 .907 r
.20322 .2066 .2045 .20792 .21061 .20555 .20934 .20422 Metetra
.664 .741 .907 r
.20934 .20422 .21061 .20555 .21673 .20317 .21546 .20184 Metetra
.664 .741 .907 r
.21546 .20184 .21673 .20317 .22287 .20079 .2216 .19946 Metetra
.664 .741 .907 r
.2216 .19946 .22287 .20079 .22902 .1984 .22776 .19707 Metetra
.664 .741 .907 r
.22776 .19707 .22902 .1984 .23519 .19601 .23393 .19467 Metetra
.664 .741 .907 r
.23393 .19467 .23519 .19601 .24137 .19361 .24011 .19227 Metetra
.664 .741 .907 r
.24011 .19227 .24137 .19361 .24757 .1912 .24631 .18986 Metetra
.664 .741 .907 r
.24631 .18986 .24757 .1912 .25378 .18879 .25253 .18745 Metetra
.664 .741 .907 r
.25253 .18745 .25378 .18879 .26 .18638 .25875 .18503 Metetra
.664 .741 .907 r
.25875 .18503 .26 .18638 .26624 .18396 .265 .1826 Metetra
.664 .741 .907 r
.265 .1826 .26624 .18396 .2725 .18153 .27126 .18017 Metetra
.664 .741 .907 r
.27126 .18017 .2725 .18153 .27877 .1791 .27753 .17774 Metetra
.664 .741 .907 r
.27753 .17774 .27877 .1791 .28506 .17666 .28382 .17529 Metetra
.961 .679 .453 r
.28382 .17529 .28506 .17666 .27277 .4127 .27143 .4114 Metetra
.96 .696 .49 r
.27143 .4114 .27277 .4127 .2951 .20571 .29542 .18382 Metetra
.6 .37 .54 r
.29542 .18382 .2951 .20571 .304 .1693 .30277 .16793 Metetra
.664 .741 .907 r
.30277 .16793 .304 .1693 .31035 .16684 .30912 .16547 Metetra
.664 .741 .907 r
.30912 .16547 .31035 .16684 .31671 .16437 .31549 .16299 Metetra
.664 .741 .907 r
.31549 .16299 .31671 .16437 .32309 .1619 .32187 .16052 Metetra
.664 .741 .907 r
.32187 .16052 .32309 .1619 .32948 .15942 .32826 .15803 Metetra
.664 .741 .907 r
.32826 .15803 .32948 .15942 .33589 .15693 .33467 .15554 Metetra
.664 .741 .907 r
.33467 .15554 .33589 .15693 .34231 .15444 .3411 .15305 Metetra
.664 .741 .907 r
.3411 .15305 .34231 .15444 .34875 .15194 .34754 .15054 Metetra
.664 .741 .907 r
.34754 .15054 .34875 .15194 .35521 .14944 .354 .14804 Metetra
.664 .741 .907 r
.354 .14804 .35521 .14944 .36168 .14693 .36047 .14552 Metetra
.664 .741 .907 r
.36047 .14552 .36168 .14693 .36816 .14441 .36696 .143 Metetra
.664 .741 .907 r
.36696 .143 .36816 .14441 .37466 .14189 .37347 .14048 Metetra
.664 .741 .907 r
.37347 .14048 .37466 .14189 .38118 .13936 .37999 .13794 Metetra
.664 .741 .907 r
.37999 .13794 .38118 .13936 .38771 .13682 .38652 .1354 Metetra
.664 .741 .907 r
.38652 .1354 .38771 .13682 .39426 .13428 .39308 .13286 Metetra
.664 .741 .907 r
.39308 .13286 .39426 .13428 .40083 .13173 .39964 .13031 Metetra
.664 .741 .907 r
.39964 .13031 .40083 .13173 .40741 .12918 .40623 .12775 Metetra
.664 .741 .907 r
.40623 .12775 .40741 .12918 .41401 .12662 .41283 .12519 Metetra
.664 .741 .907 r
.41283 .12519 .41401 .12662 .42062 .12405 .41945 .12262 Metetra
.664 .741 .907 r
.41945 .12262 .42062 .12405 .42725 .12148 .42608 .12004 Metetra
.664 .741 .907 r
.42608 .12004 .42725 .12148 .4339 .1189 .43273 .11746 Metetra
.664 .741 .907 r
.43273 .11746 .4339 .1189 .44056 .11631 .43939 .11487 Metetra
.664 .741 .907 r
.43939 .11487 .44056 .11631 .44724 .11372 .44608 .11227 Metetra
.664 .741 .907 r
.44608 .11227 .44724 .11372 .45394 .11113 .45278 .10967 Metetra
.664 .741 .907 r
.45278 .10967 .45394 .11113 .46065 .10852 .45949 .10706 Metetra
.664 .741 .907 r
.45949 .10706 .46065 .10852 .46738 .10591 .46622 .10445 Metetra
.664 .741 .907 r
.46622 .10445 .46738 .10591 .47412 .10329 .47297 .10183 Metetra
.664 .741 .907 r
.47297 .10183 .47412 .10329 .48089 .10067 .47974 .0992 Metetra
.664 .741 .907 r
.47974 .0992 .48089 .10067 .48766 .09804 .48652 .09657 Metetra
.664 .741 .907 r
.48652 .09657 .48766 .09804 .49446 .0954 .49332 .09393 Metetra
.664 .741 .907 r
.49332 .09393 .49446 .0954 .50127 .09276 .50013 .09128 Metetra
.664 .741 .907 r
.50013 .09128 .50127 .09276 .5081 .09011 .50697 .08863 Metetra
.664 .741 .907 r
.50697 .08863 .5081 .09011 .51495 .08745 .51382 .08596 Metetra
.664 .741 .907 r
.51382 .08596 .51495 .08745 .52181 .08479 .52069 .0833 Metetra
.664 .741 .907 r
.52069 .0833 .52181 .08479 .5287 .08212 .52757 .08062 Metetra
.664 .741 .907 r
.52757 .08062 .5287 .08212 .53559 .07944 .53447 .07794 Metetra
.664 .741 .907 r
.53447 .07794 .53559 .07944 .54251 .07676 .54139 .07526 Metetra
.664 .741 .907 r
.54139 .07526 .54251 .07676 .54944 .07407 .54833 .07256 Metetra
.664 .741 .907 r
.54833 .07256 .54944 .07407 .55639 .07137 .55528 .06986 Metetra
.664 .741 .907 r
.55528 .06986 .55639 .07137 .56336 .06866 .56225 .06715 Metetra
.664 .741 .907 r
.56225 .06715 .56336 .06866 .57035 .06595 .56924 .06444 Metetra
.664 .741 .907 r
.56924 .06444 .57035 .06595 .57735 .06324 .57625 .06172 Metetra
.664 .741 .907 r
.57625 .06172 .57735 .06324 .58437 .06051 .58327 .05899 Metetra
.664 .741 .907 r
.58327 .05899 .58437 .06051 .59141 .05778 .59032 .05625 Metetra
.664 .741 .907 r
.59032 .05625 .59141 .05778 .59847 .05504 .59738 .05351 Metetra
.664 .741 .907 r
.59738 .05351 .59847 .05504 .60554 .0523 .60446 .05076 Metetra
.664 .741 .907 r
.60446 .05076 .60554 .0523 .61263 .04954 .61155 .04801 Metetra
.664 .741 .907 r
.61155 .04801 .61263 .04954 .61974 .04679 .61867 .04524 Metetra
.918 .547 .12 r
.61867 .04524 .61974 .04679 .62835 .0854 .62718 .08172 Metetra
.957 .638 .23 r
.62718 .08172 .62835 .0854 .63851 .15913 .63884 .1958 Metetra
0 0 .198 r
.63884 .1958 .63851 .15913 .64119 .03847 .64012 .03691 Metetra
.664 .741 .907 r
.64012 .03691 .64119 .03847 .64837 .03568 .64731 .03412 Metetra
.664 .741 .907 r
.64731 .03412 .64837 .03568 .65557 .03288 .65451 .03132 Metetra
.664 .741 .907 r
.65451 .03132 .65557 .03288 .66279 .03008 .66174 .02852 Metetra
.664 .741 .907 r
.66174 .02852 .66279 .03008 .67003 .02727 .66898 .0257 Metetra
.664 .741 .907 r
.66898 .0257 .67003 .02727 .67729 .02446 .67624 .02288 Metetra
.664 .741 .907 r
.67624 .02288 .67729 .02446 .68456 .02163 .68352 .02006 Metetra
.664 .741 .907 r
.68352 .02006 .68456 .02163 .69186 .0188 .69082 .01722 Metetra
.664 .741 .907 r
.69082 .01722 .69186 .0188 .69917 .01596 .69814 .01438 Metetra
.664 .741 .907 r
.04789 .26516 .04923 .26641 .05498 .26417 .05365 .26292 Metetra
.664 .741 .907 r
.05365 .26292 .05498 .26417 .06075 .26193 .05942 .26068 Metetra
.664 .741 .907 r
.05942 .26068 .06075 .26193 .06653 .25969 .0652 .25843 Metetra
.664 .741 .907 r
.0652 .25843 .06653 .25969 .07232 .25744 .07099 .25618 Metetra
.664 .741 .907 r
.07099 .25618 .07232 .25744 .07813 .25518 .0768 .25392 Metetra
.664 .741 .907 r
.0768 .25392 .07813 .25518 .08395 .25292 .08262 .25166 Metetra
.664 .741 .907 r
.08262 .25166 .08395 .25292 .08978 .25066 .08846 .24939 Metetra
.664 .741 .907 r
.08846 .24939 .08978 .25066 .09563 .24839 .09431 .24712 Metetra
.664 .741 .907 r
.09431 .24712 .09563 .24839 .10149 .24611 .10017 .24484 Metetra
.664 .741 .907 r
.10017 .24484 .10149 .24611 .10736 .24383 .10605 .24255 Metetra
.664 .741 .907 r
.10605 .24255 .10736 .24383 .11325 .24154 .11194 .24026 Metetra
.664 .741 .907 r
.11194 .24026 .11325 .24154 .11915 .23925 .11784 .23797 Metetra
.664 .741 .907 r
.11784 .23797 .11915 .23925 .12506 .23695 .12376 .23567 Metetra
.664 .741 .907 r
.12376 .23567 .12506 .23695 .13099 .23465 .12969 .23336 Metetra
.664 .741 .907 r
.12969 .23336 .13099 .23465 .13693 .23234 .13563 .23105 Metetra
.664 .741 .907 r
.13563 .23105 .13693 .23234 .14289 .23003 .14159 .22874 Metetra
.664 .741 .907 r
.14159 .22874 .14289 .23003 .14886 .22771 .14756 .22641 Metetra
.664 .741 .907 r
.14756 .22641 .14886 .22771 .15484 .22539 .15355 .22409 Metetra
.664 .741 .907 r
.15355 .22409 .15484 .22539 .16084 .22306 .15955 .22175 Metetra
.664 .741 .907 r
.15955 .22175 .16084 .22306 .16685 .22072 .16557 .21942 Metetra
.664 .741 .907 r
.16557 .21942 .16685 .22072 .17288 .21838 .17159 .21707 Metetra
.664 .741 .907 r
.17159 .21707 .17288 .21838 .17892 .21603 .17764 .21472 Metetra
.664 .741 .907 r
.17764 .21472 .17892 .21603 .18497 .21368 .18369 .21237 Metetra
.664 .741 .907 r
.18369 .21237 .18497 .21368 .19104 .21133 .18977 .21001 Metetra
.664 .741 .907 r
.18977 .21001 .19104 .21133 .19713 .20896 .19585 .20764 Metetra
.664 .741 .907 r
.19585 .20764 .19713 .20896 .20322 .2066 .20195 .20527 Metetra
.664 .741 .907 r
.20195 .20527 .20322 .2066 .20934 .20422 .20806 .2029 Metetra
.664 .741 .907 r
.20806 .2029 .20934 .20422 .21546 .20184 .21419 .20051 Metetra
.664 .741 .907 r
.21419 .20051 .21546 .20184 .2216 .19946 .22034 .19812 Metetra
.664 .741 .907 r
.22034 .19812 .2216 .19946 .22776 .19707 .22649 .19573 Metetra
.664 .741 .907 r
.22649 .19573 .22776 .19707 .23393 .19467 .23267 .19333 Metetra
.664 .741 .907 r
.23267 .19333 .23393 .19467 .24011 .19227 .23885 .19093 Metetra
.664 .741 .907 r
.23885 .19093 .24011 .19227 .24631 .18986 .24506 .18852 Metetra
.664 .741 .907 r
.24506 .18852 .24631 .18986 .25253 .18745 .25127 .1861 Metetra
.664 .741 .907 r
.25127 .1861 .25253 .18745 .25875 .18503 .2575 .18368 Metetra
.664 .741 .907 r
.2575 .18368 .25875 .18503 .265 .1826 .26375 .18125 Metetra
.664 .741 .907 r
.26375 .18125 .265 .1826 .27126 .18017 .27001 .17881 Metetra
.664 .741 .907 r
.27001 .17881 .27126 .18017 .27753 .17774 .27629 .17637 Metetra
.664 .741 .907 r
.27629 .17637 .27753 .17774 .28382 .17529 .28258 .17393 Metetra
.961 .679 .453 r
.28258 .17393 .28382 .17529 .27143 .4114 .27008 .41009 Metetra
.96 .697 .492 r
.27008 .41009 .27143 .4114 .29542 .18382 .29274 .20109 Metetra
.033 0 .273 r
.29274 .20109 .29542 .18382 .30277 .16793 .30154 .16656 Metetra
.664 .741 .907 r
.30154 .16656 .30277 .16793 .30912 .16547 .3079 .16409 Metetra
.664 .741 .907 r
.3079 .16409 .30912 .16547 .31549 .16299 .31426 .16161 Metetra
.664 .741 .907 r
.31426 .16161 .31549 .16299 .32187 .16052 .32065 .15913 Metetra
.664 .741 .907 r
.32065 .15913 .32187 .16052 .32826 .15803 .32704 .15664 Metetra
.664 .741 .907 r
.32704 .15664 .32826 .15803 .33467 .15554 .33346 .15415 Metetra
.664 .741 .907 r
.33346 .15415 .33467 .15554 .3411 .15305 .33989 .15165 Metetra
.664 .741 .907 r
.33989 .15165 .3411 .15305 .34754 .15054 .34633 .14915 Metetra
.664 .741 .907 r
.34633 .14915 .34754 .15054 .354 .14804 .35279 .14663 Metetra
.664 .741 .907 r
.35279 .14663 .354 .14804 .36047 .14552 .35927 .14412 Metetra
.664 .741 .907 r
.35927 .14412 .36047 .14552 .36696 .143 .36576 .14159 Metetra
.664 .741 .907 r
.36576 .14159 .36696 .143 .37347 .14048 .37227 .13906 Metetra
.664 .741 .907 r
.37227 .13906 .37347 .14048 .37999 .13794 .37879 .13653 Metetra
.664 .741 .907 r
.37879 .13653 .37999 .13794 .38652 .1354 .38533 .13399 Metetra
.664 .741 .907 r
.38533 .13399 .38652 .1354 .39308 .13286 .39188 .13144 Metetra
.664 .741 .907 r
.39188 .13144 .39308 .13286 .39964 .13031 .39846 .12888 Metetra
.664 .741 .907 r
.39846 .12888 .39964 .13031 .40623 .12775 .40504 .12632 Metetra
.664 .741 .907 r
.40504 .12632 .40623 .12775 .41283 .12519 .41165 .12376 Metetra
.664 .741 .907 r
.41165 .12376 .41283 .12519 .41945 .12262 .41827 .12118 Metetra
.664 .741 .907 r
.41827 .12118 .41945 .12262 .42608 .12004 .4249 .1186 Metetra
.664 .741 .907 r
.4249 .1186 .42608 .12004 .43273 .11746 .43156 .11602 Metetra
.664 .741 .907 r
.43156 .11602 .43273 .11746 .43939 .11487 .43823 .11342 Metetra
.664 .741 .907 r
.43823 .11342 .43939 .11487 .44608 .11227 .44491 .11082 Metetra
.664 .741 .907 r
.44491 .11082 .44608 .11227 .45278 .10967 .45161 .10822 Metetra
.664 .741 .907 r
.45161 .10822 .45278 .10967 .45949 .10706 .45833 .10561 Metetra
.664 .741 .907 r
.45833 .10561 .45949 .10706 .46622 .10445 .46507 .10299 Metetra
.664 .741 .907 r
.46507 .10299 .46622 .10445 .47297 .10183 .47182 .10036 Metetra
.664 .741 .907 r
.47182 .10036 .47297 .10183 .47974 .0992 .47859 .09773 Metetra
.664 .741 .907 r
.47859 .09773 .47974 .0992 .48652 .09657 .48537 .0951 Metetra
.664 .741 .907 r
.48537 .0951 .48652 .09657 .49332 .09393 .49218 .09245 Metetra
.664 .741 .907 r
.49218 .09245 .49332 .09393 .50013 .09128 .49899 .0898 Metetra
.664 .741 .907 r
.49899 .0898 .50013 .09128 .50697 .08863 .50583 .08714 Metetra
.664 .741 .907 r
.50583 .08714 .50697 .08863 .51382 .08596 .51269 .08448 Metetra
.664 .741 .907 r
.51269 .08448 .51382 .08596 .52069 .0833 .51956 .08181 Metetra
.664 .741 .907 r
.51956 .08181 .52069 .0833 .52757 .08062 .52644 .07913 Metetra
.664 .741 .907 r
.52644 .07913 .52757 .08062 .53447 .07794 .53335 .07645 Metetra
.664 .741 .907 r
.53335 .07645 .53447 .07794 .54139 .07526 .54027 .07375 Metetra
.664 .741 .907 r
.54027 .07375 .54139 .07526 .54833 .07256 .54721 .07106 Metetra
.664 .741 .907 r
.54721 .07106 .54833 .07256 .55528 .06986 .55417 .06835 Metetra
.664 .741 .907 r
.55417 .06835 .55528 .06986 .56225 .06715 .56114 .06564 Metetra
.664 .741 .907 r
.56114 .06564 .56225 .06715 .56924 .06444 .56814 .06292 Metetra
.664 .741 .907 r
.56814 .06292 .56924 .06444 .57625 .06172 .57515 .0602 Metetra
.664 .741 .907 r
.57515 .0602 .57625 .06172 .58327 .05899 .58218 .05746 Metetra
.664 .741 .907 r
.58218 .05746 .58327 .05899 .59032 .05625 .58922 .05473 Metetra
.664 .741 .907 r
.58922 .05473 .59032 .05625 .59738 .05351 .59629 .05198 Metetra
.664 .741 .907 r
.59629 .05198 .59738 .05351 .60446 .05076 .60337 .04923 Metetra
.664 .741 .907 r
.60337 .04923 .60446 .05076 .61155 .04801 .61047 .04647 Metetra
.664 .741 .907 r
.61047 .04647 .61155 .04801 .61867 .04524 .61759 .0437 Metetra
.82 .406 0 r
.61759 .0437 .61867 .04524 .62718 .08172 .62551 .0634 Metetra
.304 .158 .512 r
.62551 .0634 .62718 .08172 .63884 .1958 .63369 .08652 Metetra
.562 .314 .498 r
.63369 .08652 .63884 .1958 .64012 .03691 .63905 .03536 Metetra
.664 .741 .907 r
.63905 .03536 .64012 .03691 .64731 .03412 .64624 .03256 Metetra
.664 .741 .907 r
.64624 .03256 .64731 .03412 .65451 .03132 .65345 .02976 Metetra
.664 .741 .907 r
.65345 .02976 .65451 .03132 .66174 .02852 .66068 .02695 Metetra
.664 .741 .907 r
.66068 .02695 .66174 .02852 .66898 .0257 .66792 .02413 Metetra
.664 .741 .907 r
.66792 .02413 .66898 .0257 .67624 .02288 .67519 .02131 Metetra
.664 .741 .907 r
.67519 .02131 .67624 .02288 .68352 .02006 .68247 .01848 Metetra
.664 .741 .907 r
.68247 .01848 .68352 .02006 .69082 .01722 .68978 .01564 Metetra
.664 .741 .907 r
.68978 .01564 .69082 .01722 .69814 .01438 .6971 .01279 Metetra
.664 .741 .907 r
.04656 .26391 .04789 .26516 .05365 .26292 .05231 .26167 Metetra
.664 .741 .907 r
.05231 .26167 .05365 .26292 .05942 .26068 .05809 .25943 Metetra
.664 .741 .907 r
.05809 .25943 .05942 .26068 .0652 .25843 .06387 .25718 Metetra
.664 .741 .907 r
.06387 .25718 .0652 .25843 .07099 .25618 .06967 .25492 Metetra
.664 .741 .907 r
.06967 .25492 .07099 .25618 .0768 .25392 .07548 .25266 Metetra
.664 .741 .907 r
.07548 .25266 .0768 .25392 .08262 .25166 .0813 .25039 Metetra
.664 .741 .907 r
.0813 .25039 .08262 .25166 .08846 .24939 .08714 .24812 Metetra
.664 .741 .907 r
.08714 .24812 .08846 .24939 .09431 .24712 .09299 .24585 Metetra
.664 .741 .907 r
.09299 .24585 .09431 .24712 .10017 .24484 .09886 .24356 Metetra
.664 .741 .907 r
.09886 .24356 .10017 .24484 .10605 .24255 .10473 .24128 Metetra
.664 .741 .907 r
.10473 .24128 .10605 .24255 .11194 .24026 .11063 .23898 Metetra
.664 .741 .907 r
.11063 .23898 .11194 .24026 .11784 .23797 .11653 .23669 Metetra
.664 .741 .907 r
.11653 .23669 .11784 .23797 .12376 .23567 .12245 .23438 Metetra
.664 .741 .907 r
.12245 .23438 .12376 .23567 .12969 .23336 .12838 .23207 Metetra
.664 .741 .907 r
.12838 .23207 .12969 .23336 .13563 .23105 .13433 .22976 Metetra
.664 .741 .907 r
.13433 .22976 .13563 .23105 .14159 .22874 .14029 .22744 Metetra
.664 .741 .907 r
.14029 .22744 .14159 .22874 .14756 .22641 .14627 .22512 Metetra
.664 .741 .907 r
.14627 .22512 .14756 .22641 .15355 .22409 .15226 .22279 Metetra
.664 .741 .907 r
.15226 .22279 .15355 .22409 .15955 .22175 .15826 .22045 Metetra
.664 .741 .907 r
.15826 .22045 .15955 .22175 .16557 .21942 .16428 .21811 Metetra
.664 .741 .907 r
.16428 .21811 .16557 .21942 .17159 .21707 .17031 .21576 Metetra
.664 .741 .907 r
.17031 .21576 .17159 .21707 .17764 .21472 .17635 .21341 Metetra
.664 .741 .907 r
.17635 .21341 .17764 .21472 .18369 .21237 .18241 .21105 Metetra
.664 .741 .907 r
.18241 .21105 .18369 .21237 .18977 .21001 .18849 .20869 Metetra
.664 .741 .907 r
.18849 .20869 .18977 .21001 .19585 .20764 .19457 .20632 Metetra
.664 .741 .907 r
.19457 .20632 .19585 .20764 .20195 .20527 .20068 .20395 Metetra
.664 .741 .907 r
.20068 .20395 .20195 .20527 .20806 .2029 .20679 .20157 Metetra
.664 .741 .907 r
.20679 .20157 .20806 .2029 .21419 .20051 .21292 .19918 Metetra
.664 .741 .907 r
.21292 .19918 .21419 .20051 .22034 .19812 .21907 .19679 Metetra
.664 .741 .907 r
.21907 .19679 .22034 .19812 .22649 .19573 .22523 .19439 Metetra
.664 .741 .907 r
.22523 .19439 .22649 .19573 .23267 .19333 .2314 .19199 Metetra
.664 .741 .907 r
.2314 .19199 .23267 .19333 .23885 .19093 .23759 .18958 Metetra
.664 .741 .907 r
.23759 .18958 .23885 .19093 .24506 .18852 .2438 .18717 Metetra
.664 .741 .907 r
.2438 .18717 .24506 .18852 .25127 .1861 .25002 .18475 Metetra
.664 .741 .907 r
.25002 .18475 .25127 .1861 .2575 .18368 .25625 .18232 Metetra
.664 .741 .907 r
.25625 .18232 .2575 .18368 .26375 .18125 .2625 .17989 Metetra
.664 .741 .907 r
.2625 .17989 .26375 .18125 .27001 .17881 .26877 .17745 Metetra
.664 .741 .907 r
.26877 .17745 .27001 .17881 .27629 .17637 .27504 .17501 Metetra
.664 .741 .907 r
.27504 .17501 .27629 .17637 .28258 .17393 .28134 .17256 Metetra
.961 .679 .453 r
.28134 .17256 .28258 .17393 .27008 .41009 .26873 .40879 Metetra
.96 .696 .49 r
.26873 .40879 .27008 .41009 .29274 .20109 .29295 .18082 Metetra
.605 .376 .543 r
.29295 .18082 .29274 .20109 .30154 .16656 .30031 .16518 Metetra
.664 .741 .907 r
.30031 .16518 .30154 .16656 .3079 .16409 .30667 .16271 Metetra
.664 .741 .907 r
.30667 .16271 .3079 .16409 .31426 .16161 .31304 .16023 Metetra
.664 .741 .907 r
.31304 .16023 .31426 .16161 .32065 .15913 .31942 .15774 Metetra
.664 .741 .907 r
.31942 .15774 .32065 .15913 .32704 .15664 .32582 .15525 Metetra
.664 .741 .907 r
.32582 .15525 .32704 .15664 .33346 .15415 .33224 .15276 Metetra
.664 .741 .907 r
.33224 .15276 .33346 .15415 .33989 .15165 .33867 .15025 Metetra
.664 .741 .907 r
.33867 .15025 .33989 .15165 .34633 .14915 .34512 .14775 Metetra
.664 .741 .907 r
.34512 .14775 .34633 .14915 .35279 .14663 .35158 .14523 Metetra
.664 .741 .907 r
.35158 .14523 .35279 .14663 .35927 .14412 .35806 .14271 Metetra
.664 .741 .907 r
.35806 .14271 .35927 .14412 .36576 .14159 .36455 .14018 Metetra
.664 .741 .907 r
.36455 .14018 .36576 .14159 .37227 .13906 .37107 .13765 Metetra
.664 .741 .907 r
.37107 .13765 .37227 .13906 .37879 .13653 .37759 .13511 Metetra
.664 .741 .907 r
.37759 .13511 .37879 .13653 .38533 .13399 .38413 .13257 Metetra
.664 .741 .907 r
.38413 .13257 .38533 .13399 .39188 .13144 .39069 .13001 Metetra
.664 .741 .907 r
.39069 .13001 .39188 .13144 .39846 .12888 .39727 .12746 Metetra
.664 .741 .907 r
.39727 .12746 .39846 .12888 .40504 .12632 .40386 .12489 Metetra
.664 .741 .907 r
.40386 .12489 .40504 .12632 .41165 .12376 .41046 .12232 Metetra
.664 .741 .907 r
.41046 .12232 .41165 .12376 .41827 .12118 .41709 .11974 Metetra
.664 .741 .907 r
.41709 .11974 .41827 .12118 .4249 .1186 .42373 .11716 Metetra
.664 .741 .907 r
.42373 .11716 .4249 .1186 .43156 .11602 .43038 .11457 Metetra
.664 .741 .907 r
.43038 .11457 .43156 .11602 .43823 .11342 .43705 .11197 Metetra
.664 .741 .907 r
.43705 .11197 .43823 .11342 .44491 .11082 .44374 .10937 Metetra
.664 .741 .907 r
.44374 .10937 .44491 .11082 .45161 .10822 .45045 .10676 Metetra
.664 .741 .907 r
.45045 .10676 .45161 .10822 .45833 .10561 .45717 .10415 Metetra
.664 .741 .907 r
.45717 .10415 .45833 .10561 .46507 .10299 .46391 .10153 Metetra
.664 .741 .907 r
.46391 .10153 .46507 .10299 .47182 .10036 .47066 .0989 Metetra
.664 .741 .907 r
.47066 .0989 .47182 .10036 .47859 .09773 .47744 .09626 Metetra
.664 .741 .907 r
.47744 .09626 .47859 .09773 .48537 .0951 .48422 .09362 Metetra
.664 .741 .907 r
.48422 .09362 .48537 .0951 .49218 .09245 .49103 .09097 Metetra
.664 .741 .907 r
.49103 .09097 .49218 .09245 .49899 .0898 .49785 .08832 Metetra
.664 .741 .907 r
.49785 .08832 .49899 .0898 .50583 .08714 .50469 .08566 Metetra
.664 .741 .907 r
.50469 .08566 .50583 .08714 .51269 .08448 .51155 .08299 Metetra
.664 .741 .907 r
.51155 .08299 .51269 .08448 .51956 .08181 .51842 .08031 Metetra
.664 .741 .907 r
.51842 .08031 .51956 .08181 .52644 .07913 .52532 .07763 Metetra
.664 .741 .907 r
.52532 .07763 .52644 .07913 .53335 .07645 .53222 .07495 Metetra
.664 .741 .907 r
.53222 .07495 .53335 .07645 .54027 .07375 .53915 .07225 Metetra
.664 .741 .907 r
.53915 .07225 .54027 .07375 .54721 .07106 .54609 .06955 Metetra
.664 .741 .907 r
.54609 .06955 .54721 .07106 .55417 .06835 .55306 .06684 Metetra
.664 .741 .907 r
.55306 .06684 .55417 .06835 .56114 .06564 .56003 .06412 Metetra
.664 .741 .907 r
.56003 .06412 .56114 .06564 .56814 .06292 .56703 .0614 Metetra
.664 .741 .907 r
.56703 .0614 .56814 .06292 .57515 .0602 .57404 .05867 Metetra
.664 .741 .907 r
.57404 .05867 .57515 .0602 .58218 .05746 .58108 .05594 Metetra
.664 .741 .907 r
.58108 .05594 .58218 .05746 .58922 .05473 .58813 .05319 Metetra
.664 .741 .907 r
.58813 .05319 .58922 .05473 .59629 .05198 .59519 .05044 Metetra
.664 .741 .907 r
.59519 .05044 .59629 .05198 .60337 .04923 .60228 .04769 Metetra
.664 .741 .907 r
.60228 .04769 .60337 .04923 .61047 .04647 .60938 .04492 Metetra
.664 .741 .907 r
.60938 .04492 .61047 .04647 .61759 .0437 .6165 .04215 Metetra
.715 .283 0 r
.6165 .04215 .61759 .0437 .62551 .0634 .62424 .05652 Metetra
0 0 .38 r
.62424 .05652 .62551 .0634 .63369 .08652 .63263 .08604 Metetra
.993 .746 .44 r
.63263 .08604 .63369 .08652 .63905 .03536 .63798 .0338 Metetra
.664 .741 .907 r
.63798 .0338 .63905 .03536 .64624 .03256 .64517 .031 Metetra
.664 .741 .907 r
.64517 .031 .64624 .03256 .65345 .02976 .65239 .02819 Metetra
.664 .741 .907 r
.65239 .02819 .65345 .02976 .66068 .02695 .65962 .02538 Metetra
.664 .741 .907 r
.65962 .02538 .66068 .02695 .66792 .02413 .66687 .02256 Metetra
.664 .741 .907 r
.66687 .02256 .66792 .02413 .67519 .02131 .67414 .01973 Metetra
.664 .741 .907 r
.67414 .01973 .67519 .02131 .68247 .01848 .68143 .01689 Metetra
.664 .741 .907 r
.68143 .01689 .68247 .01848 .68978 .01564 .68873 .01405 Metetra
.664 .741 .907 r
.68873 .01405 .68978 .01564 .6971 .01279 .69606 .0112 Metetra
.664 .741 .907 r
.04522 .26266 .04656 .26391 .05231 .26167 .05098 .26042 Metetra
.664 .741 .907 r
.05098 .26042 .05231 .26167 .05809 .25943 .05675 .25817 Metetra
.664 .741 .907 r
.05675 .25817 .05809 .25943 .06387 .25718 .06254 .25592 Metetra
.664 .741 .907 r
.06254 .25592 .06387 .25718 .06967 .25492 .06834 .25366 Metetra
.664 .741 .907 r
.06834 .25366 .06967 .25492 .07548 .25266 .07415 .2514 Metetra
.664 .741 .907 r
.07415 .2514 .07548 .25266 .0813 .25039 .07998 .24913 Metetra
.664 .741 .907 r
.07998 .24913 .0813 .25039 .08714 .24812 .08582 .24685 Metetra
.664 .741 .907 r
.08582 .24685 .08714 .24812 .09299 .24585 .09167 .24457 Metetra
.664 .741 .907 r
.09167 .24457 .09299 .24585 .09886 .24356 .09754 .24229 Metetra
.664 .741 .907 r
.09754 .24229 .09886 .24356 .10473 .24128 .10342 .24 Metetra
.664 .741 .907 r
.10342 .24 .10473 .24128 .11063 .23898 .10931 .2377 Metetra
.664 .741 .907 r
.10931 .2377 .11063 .23898 .11653 .23669 .11522 .2354 Metetra
.664 .741 .907 r
.11522 .2354 .11653 .23669 .12245 .23438 .12114 .2331 Metetra
.664 .741 .907 r
.12114 .2331 .12245 .23438 .12838 .23207 .12708 .23078 Metetra
.664 .741 .907 r
.12708 .23078 .12838 .23207 .13433 .22976 .13303 .22847 Metetra
.664 .741 .907 r
.13303 .22847 .13433 .22976 .14029 .22744 .13899 .22615 Metetra
.664 .741 .907 r
.13899 .22615 .14029 .22744 .14627 .22512 .14497 .22382 Metetra
.664 .741 .907 r
.14497 .22382 .14627 .22512 .15226 .22279 .15096 .22148 Metetra
.664 .741 .907 r
.15096 .22148 .15226 .22279 .15826 .22045 .15697 .21915 Metetra
.664 .741 .907 r
.15697 .21915 .15826 .22045 .16428 .21811 .16298 .2168 Metetra
.664 .741 .907 r
.16298 .2168 .16428 .21811 .17031 .21576 .16902 .21445 Metetra
.664 .741 .907 r
.16902 .21445 .17031 .21576 .17635 .21341 .17507 .2121 Metetra
.664 .741 .907 r
.17507 .2121 .17635 .21341 .18241 .21105 .18113 .20974 Metetra
.664 .741 .907 r
.18113 .20974 .18241 .21105 .18849 .20869 .1872 .20737 Metetra
.664 .741 .907 r
.1872 .20737 .18849 .20869 .19457 .20632 .19329 .205 Metetra
.664 .741 .907 r
.19329 .205 .19457 .20632 .20068 .20395 .1994 .20262 Metetra
.664 .741 .907 r
.1994 .20262 .20068 .20395 .20679 .20157 .20552 .20024 Metetra
.664 .741 .907 r
.20552 .20024 .20679 .20157 .21292 .19918 .21165 .19785 Metetra
.664 .741 .907 r
.21165 .19785 .21292 .19918 .21907 .19679 .2178 .19545 Metetra
.664 .741 .907 r
.2178 .19545 .21907 .19679 .22523 .19439 .22396 .19305 Metetra
.664 .741 .907 r
.22396 .19305 .22523 .19439 .2314 .19199 .23014 .19065 Metetra
.664 .741 .907 r
.23014 .19065 .2314 .19199 .23759 .18958 .23633 .18824 Metetra
.664 .741 .907 r
.23633 .18824 .23759 .18958 .2438 .18717 .24254 .18582 Metetra
.664 .741 .907 r
.24254 .18582 .2438 .18717 .25002 .18475 .24876 .1834 Metetra
.664 .741 .907 r
.24876 .1834 .25002 .18475 .25625 .18232 .255 .18097 Metetra
.664 .741 .907 r
.255 .18097 .25625 .18232 .2625 .17989 .26125 .17853 Metetra
.664 .741 .907 r
.26125 .17853 .2625 .17989 .26877 .17745 .26752 .17609 Metetra
.664 .741 .907 r
.26752 .17609 .26877 .17745 .27504 .17501 .2738 .17365 Metetra
.938 .566 .234 r
.2738 .17365 .27504 .17501 .28134 .17256 .27812 .1954 Metetra
.868 .579 .497 r
.27812 .1954 .28134 .17256 .26873 .40879 .26737 .40748 Metetra
.96 .696 .489 r
.26737 .40748 .26873 .40879 .29295 .18082 .29273 .16627 Metetra
.532 .329 .551 r
.29273 .16627 .29295 .18082 .30031 .16518 .29908 .1638 Metetra
.664 .741 .907 r
.29908 .1638 .30031 .16518 .30667 .16271 .30543 .16133 Metetra
.664 .741 .907 r
.30543 .16133 .30667 .16271 .31304 .16023 .31181 .15884 Metetra
.664 .741 .907 r
.31181 .15884 .31304 .16023 .31942 .15774 .3182 .15636 Metetra
.664 .741 .907 r
.3182 .15636 .31942 .15774 .32582 .15525 .3246 .15386 Metetra
.664 .741 .907 r
.3246 .15386 .32582 .15525 .33224 .15276 .33102 .15136 Metetra
.664 .741 .907 r
.33102 .15136 .33224 .15276 .33867 .15025 .33745 .14886 Metetra
.664 .741 .907 r
.33745 .14886 .33867 .15025 .34512 .14775 .3439 .14634 Metetra
.664 .741 .907 r
.3439 .14634 .34512 .14775 .35158 .14523 .35037 .14383 Metetra
.664 .741 .907 r
.35037 .14383 .35158 .14523 .35806 .14271 .35685 .1413 Metetra
.664 .741 .907 r
.35685 .1413 .35806 .14271 .36455 .14018 .36335 .13877 Metetra
.664 .741 .907 r
.36335 .13877 .36455 .14018 .37107 .13765 .36986 .13623 Metetra
.664 .741 .907 r
.36986 .13623 .37107 .13765 .37759 .13511 .37639 .13369 Metetra
.664 .741 .907 r
.37639 .13369 .37759 .13511 .38413 .13257 .38294 .13114 Metetra
.664 .741 .907 r
.38294 .13114 .38413 .13257 .39069 .13001 .3895 .12859 Metetra
.664 .741 .907 r
.3895 .12859 .39069 .13001 .39727 .12746 .39608 .12603 Metetra
.664 .741 .907 r
.39608 .12603 .39727 .12746 .40386 .12489 .40267 .12346 Metetra
.664 .741 .907 r
.40267 .12346 .40386 .12489 .41046 .12232 .40928 .12088 Metetra
.664 .741 .907 r
.40928 .12088 .41046 .12232 .41709 .11974 .41591 .1183 Metetra
.664 .741 .907 r
.41591 .1183 .41709 .11974 .42373 .11716 .42255 .11572 Metetra
.664 .741 .907 r
.42255 .11572 .42373 .11716 .43038 .11457 .42921 .11312 Metetra
.664 .741 .907 r
.42921 .11312 .43038 .11457 .43705 .11197 .43588 .11052 Metetra
.664 .741 .907 r
.43588 .11052 .43705 .11197 .44374 .10937 .44257 .10792 Metetra
.664 .741 .907 r
.44257 .10792 .44374 .10937 .45045 .10676 .44928 .10531 Metetra
.664 .741 .907 r
.44928 .10531 .45045 .10676 .45717 .10415 .45601 .10269 Metetra
.664 .741 .907 r
.45601 .10269 .45717 .10415 .46391 .10153 .46275 .10006 Metetra
.664 .741 .907 r
.46275 .10006 .46391 .10153 .47066 .0989 .46951 .09743 Metetra
.664 .741 .907 r
.46951 .09743 .47066 .0989 .47744 .09626 .47628 .09479 Metetra
.664 .741 .907 r
.47628 .09479 .47744 .09626 .48422 .09362 .48308 .09215 Metetra
.664 .741 .907 r
.48308 .09215 .48422 .09362 .49103 .09097 .48988 .08949 Metetra
.664 .741 .907 r
.48988 .08949 .49103 .09097 .49785 .08832 .49671 .08683 Metetra
.664 .741 .907 r
.49671 .08683 .49785 .08832 .50469 .08566 .50355 .08417 Metetra
.664 .741 .907 r
.50355 .08417 .50469 .08566 .51155 .08299 .51041 .0815 Metetra
.664 .741 .907 r
.51041 .0815 .51155 .08299 .51842 .08031 .51729 .07882 Metetra
.664 .741 .907 r
.51729 .07882 .51842 .08031 .52532 .07763 .52419 .07613 Metetra
.664 .741 .907 r
.52419 .07613 .52532 .07763 .53222 .07495 .5311 .07344 Metetra
.664 .741 .907 r
.5311 .07344 .53222 .07495 .53915 .07225 .53803 .07074 Metetra
.664 .741 .907 r
.53803 .07074 .53915 .07225 .54609 .06955 .54498 .06804 Metetra
.664 .741 .907 r
.54498 .06804 .54609 .06955 .55306 .06684 .55194 .06533 Metetra
.664 .741 .907 r
.55194 .06533 .55306 .06684 .56003 .06412 .55892 .06261 Metetra
.664 .741 .907 r
.55892 .06261 .56003 .06412 .56703 .0614 .56592 .05988 Metetra
.664 .741 .907 r
.56592 .05988 .56703 .0614 .57404 .05867 .57294 .05715 Metetra
.664 .741 .907 r
.57294 .05715 .57404 .05867 .58108 .05594 .57997 .05441 Metetra
.664 .741 .907 r
.57997 .05441 .58108 .05594 .58813 .05319 .58703 .05166 Metetra
.664 .741 .907 r
.58703 .05166 .58813 .05319 .59519 .05044 .5941 .04891 Metetra
.664 .741 .907 r
.5941 .04891 .59519 .05044 .60228 .04769 .60119 .04615 Metetra
.664 .741 .907 r
.60119 .04615 .60228 .04769 .60938 .04492 .6083 .04338 Metetra
.664 .741 .907 r
.6083 .04338 .60938 .04492 .6165 .04215 .61542 .0406 Metetra
.664 .741 .907 r
.61542 .0406 .6165 .04215 .62424 .05652 .62256 .03782 Metetra
0 0 .401 r
.62256 .03782 .62424 .05652 .63263 .08604 .63196 .09579 Metetra
.63196 .09579 .63263 .08604 .63798 .0338 .63691 .03224 Metetra
.664 .741 .907 r
.63691 .03224 .63798 .0338 .64517 .031 .6441 .02943 Metetra
.664 .741 .907 r
.6441 .02943 .64517 .031 .65239 .02819 .65132 .02662 Metetra
.664 .741 .907 r
.65132 .02662 .65239 .02819 .65962 .02538 .65856 .02381 Metetra
.664 .741 .907 r
.65856 .02381 .65962 .02538 .66687 .02256 .66581 .02098 Metetra
.664 .741 .907 r
.66581 .02098 .66687 .02256 .67414 .01973 .67308 .01815 Metetra
.664 .741 .907 r
.67308 .01815 .67414 .01973 .68143 .01689 .68038 .01531 Metetra
.664 .741 .907 r
.68038 .01531 .68143 .01689 .68873 .01405 .68769 .01246 Metetra
.664 .741 .907 r
.68769 .01246 .68873 .01405 .69606 .0112 .69502 .00961 Metetra
.664 .741 .907 r
.04388 .26141 .04522 .26266 .05098 .26042 .04964 .25917 Metetra
.664 .741 .907 r
.04964 .25917 .05098 .26042 .05675 .25817 .05542 .25692 Metetra
.664 .741 .907 r
.05542 .25692 .05675 .25817 .06254 .25592 .06121 .25466 Metetra
.664 .741 .907 r
.06121 .25466 .06254 .25592 .06834 .25366 .06701 .2524 Metetra
.664 .741 .907 r
.06701 .2524 .06834 .25366 .07415 .2514 .07282 .25013 Metetra
.664 .741 .907 r
.07282 .25013 .07415 .2514 .07998 .24913 .07865 .24786 Metetra
.664 .741 .907 r
.07865 .24786 .07998 .24913 .08582 .24685 .08449 .24558 Metetra
.664 .741 .907 r
.08449 .24558 .08582 .24685 .09167 .24457 .09035 .2433 Metetra
.664 .741 .907 r
.09035 .2433 .09167 .24457 .09754 .24229 .09622 .24101 Metetra
.664 .741 .907 r
.09622 .24101 .09754 .24229 .10342 .24 .1021 .23872 Metetra
.664 .741 .907 r
.1021 .23872 .10342 .24 .10931 .2377 .108 .23642 Metetra
.664 .741 .907 r
.108 .23642 .10931 .2377 .11522 .2354 .11391 .23412 Metetra
.664 .741 .907 r
.11391 .23412 .11522 .2354 .12114 .2331 .11983 .23181 Metetra
.664 .741 .907 r
.11983 .23181 .12114 .2331 .12708 .23078 .12577 .22949 Metetra
.664 .741 .907 r
.12577 .22949 .12708 .23078 .13303 .22847 .13172 .22717 Metetra
.664 .741 .907 r
.13172 .22717 .13303 .22847 .13899 .22615 .13769 .22485 Metetra
.664 .741 .907 r
.13769 .22485 .13899 .22615 .14497 .22382 .14367 .22252 Metetra
.664 .741 .907 r
.14367 .22252 .14497 .22382 .15096 .22148 .14966 .22018 Metetra
.664 .741 .907 r
.14966 .22018 .15096 .22148 .15697 .21915 .15567 .21784 Metetra
.664 .741 .907 r
.15567 .21784 .15697 .21915 .16298 .2168 .16169 .21549 Metetra
.664 .741 .907 r
.16169 .21549 .16298 .2168 .16902 .21445 .16773 .21314 Metetra
.664 .741 .907 r
.16773 .21314 .16902 .21445 .17507 .2121 .17378 .21078 Metetra
.664 .741 .907 r
.17378 .21078 .17507 .2121 .18113 .20974 .17984 .20842 Metetra
.664 .741 .907 r
.17984 .20842 .18113 .20974 .1872 .20737 .18592 .20605 Metetra
.664 .741 .907 r
.18592 .20605 .1872 .20737 .19329 .205 .19201 .20367 Metetra
.664 .741 .907 r
.19201 .20367 .19329 .205 .1994 .20262 .19812 .20129 Metetra
.664 .741 .907 r
.19812 .20129 .1994 .20262 .20552 .20024 .20424 .19891 Metetra
.664 .741 .907 r
.20424 .19891 .20552 .20024 .21165 .19785 .21038 .19651 Metetra
.664 .741 .907 r
.21038 .19651 .21165 .19785 .2178 .19545 .21653 .19412 Metetra
.664 .741 .907 r
.21653 .19412 .2178 .19545 .22396 .19305 .2227 .19171 Metetra
.664 .741 .907 r
.2227 .19171 .22396 .19305 .23014 .19065 .22888 .1893 Metetra
.664 .741 .907 r
.22888 .1893 .23014 .19065 .23633 .18824 .23507 .18689 Metetra
.664 .741 .907 r
.23507 .18689 .23633 .18824 .24254 .18582 .24128 .18447 Metetra
.664 .741 .907 r
.24128 .18447 .24254 .18582 .24876 .1834 .2475 .18204 Metetra
.664 .741 .907 r
.2475 .18204 .24876 .1834 .255 .18097 .25374 .17961 Metetra
.664 .741 .907 r
.25374 .17961 .255 .18097 .26125 .17853 .26 .17717 Metetra
.664 .741 .907 r
.26 .17717 .26125 .17853 .26752 .17609 .26627 .17473 Metetra
.664 .741 .907 r
.26627 .17473 .26752 .17609 .2738 .17365 .27255 .17228 Metetra
.96 .647 .386 r
.27255 .17228 .2738 .17365 .27812 .1954 .27428 .22538 Metetra
.824 .536 .502 r
.27428 .22538 .27812 .1954 .26737 .40748 .26639 .40154 Metetra
.946 .679 .498 r
.26639 .40154 .26737 .40748 .29273 .16627 .2915 .16489 Metetra
.664 .741 .907 r
.2915 .16489 .29273 .16627 .29908 .1638 .29784 .16242 Metetra
.664 .741 .907 r
.29784 .16242 .29908 .1638 .30543 .16133 .3042 .15994 Metetra
.664 .741 .907 r
.3042 .15994 .30543 .16133 .31181 .15884 .31058 .15746 Metetra
.664 .741 .907 r
.31058 .15746 .31181 .15884 .3182 .15636 .31697 .15497 Metetra
.664 .741 .907 r
.31697 .15497 .3182 .15636 .3246 .15386 .32337 .15247 Metetra
.664 .741 .907 r
.32337 .15247 .3246 .15386 .33102 .15136 .3298 .14997 Metetra
.664 .741 .907 r
.3298 .14997 .33102 .15136 .33745 .14886 .33623 .14746 Metetra
.664 .741 .907 r
.33623 .14746 .33745 .14886 .3439 .14634 .34269 .14494 Metetra
.664 .741 .907 r
.34269 .14494 .3439 .14634 .35037 .14383 .34916 .14242 Metetra
.664 .741 .907 r
.34916 .14242 .35037 .14383 .35685 .1413 .35564 .13989 Metetra
.664 .741 .907 r
.35564 .13989 .35685 .1413 .36335 .13877 .36214 .13736 Metetra
.664 .741 .907 r
.36214 .13736 .36335 .13877 .36986 .13623 .36866 .13482 Metetra
.664 .741 .907 r
.36866 .13482 .36986 .13623 .37639 .13369 .37519 .13227 Metetra
.664 .741 .907 r
.37519 .13227 .37639 .13369 .38294 .13114 .38174 .12972 Metetra
.664 .741 .907 r
.38174 .12972 .38294 .13114 .3895 .12859 .3883 .12716 Metetra
.664 .741 .907 r
.3883 .12716 .3895 .12859 .39608 .12603 .39488 .12459 Metetra
.664 .741 .907 r
.39488 .12459 .39608 .12603 .40267 .12346 .40148 .12202 Metetra
.664 .741 .907 r
.40148 .12202 .40267 .12346 .40928 .12088 .40809 .11945 Metetra
.664 .741 .907 r
.40809 .11945 .40928 .12088 .41591 .1183 .41472 .11686 Metetra
.664 .741 .907 r
.41472 .11686 .41591 .1183 .42255 .11572 .42137 .11427 Metetra
.664 .741 .907 r
.42137 .11427 .42255 .11572 .42921 .11312 .42803 .11167 Metetra
.664 .741 .907 r
.42803 .11167 .42921 .11312 .43588 .11052 .43471 .10907 Metetra
.664 .741 .907 r
.43471 .10907 .43588 .11052 .44257 .10792 .4414 .10646 Metetra
.664 .741 .907 r
.4414 .10646 .44257 .10792 .44928 .10531 .44811 .10385 Metetra
.664 .741 .907 r
.44811 .10385 .44928 .10531 .45601 .10269 .45484 .10122 Metetra
.664 .741 .907 r
.45484 .10122 .45601 .10269 .46275 .10006 .46159 .09859 Metetra
.664 .741 .907 r
.46159 .09859 .46275 .10006 .46951 .09743 .46835 .09596 Metetra
.664 .741 .907 r
.46835 .09596 .46951 .09743 .47628 .09479 .47513 .09332 Metetra
.664 .741 .907 r
.47513 .09332 .47628 .09479 .48308 .09215 .48192 .09067 Metetra
.664 .741 .907 r
.48192 .09067 .48308 .09215 .48988 .08949 .48874 .08801 Metetra
.664 .741 .907 r
.48874 .08801 .48988 .08949 .49671 .08683 .49557 .08535 Metetra
.664 .741 .907 r
.49557 .08535 .49671 .08683 .50355 .08417 .50241 .08268 Metetra
.664 .741 .907 r
.50241 .08268 .50355 .08417 .51041 .0815 .50928 .08001 Metetra
.664 .741 .907 r
.50928 .08001 .51041 .0815 .51729 .07882 .51616 .07732 Metetra
.664 .741 .907 r
.51616 .07732 .51729 .07882 .52419 .07613 .52306 .07463 Metetra
.664 .741 .907 r
.52306 .07463 .52419 .07613 .5311 .07344 .52997 .07194 Metetra
.664 .741 .907 r
.52997 .07194 .5311 .07344 .53803 .07074 .5369 .06924 Metetra
.664 .741 .907 r
.5369 .06924 .53803 .07074 .54498 .06804 .54385 .06653 Metetra
.664 .741 .907 r
.54385 .06653 .54498 .06804 .55194 .06533 .55082 .06381 Metetra
.664 .741 .907 r
.55082 .06381 .55194 .06533 .55892 .06261 .55781 .06109 Metetra
.664 .741 .907 r
.55781 .06109 .55892 .06261 .56592 .05988 .56481 .05836 Metetra
.664 .741 .907 r
.56481 .05836 .56592 .05988 .57294 .05715 .57183 .05562 Metetra
.664 .741 .907 r
.57183 .05562 .57294 .05715 .57997 .05441 .57887 .05288 Metetra
.664 .741 .907 r
.57887 .05288 .57997 .05441 .58703 .05166 .58593 .05013 Metetra
.664 .741 .907 r
.58593 .05013 .58703 .05166 .5941 .04891 .593 .04737 Metetra
.664 .741 .907 r
.593 .04737 .5941 .04891 .60119 .04615 .6001 .0446 Metetra
.664 .741 .907 r
.6001 .0446 .60119 .04615 .6083 .04338 .60721 .04183 Metetra
.624 .724 .918 r
.60721 .04183 .6083 .04338 .61542 .0406 .61436 .0397 Metetra
.702 .873 .962 r
.61436 .0397 .61542 .0406 .62256 .03782 .62148 .03627 Metetra
0 .222 .739 r
.62148 .03627 .62256 .03782 .63196 .09579 .62896 .04192 Metetra
.529 .295 .504 r
.62896 .04192 .63196 .09579 .63691 .03224 .63583 .03067 Metetra
.664 .741 .907 r
.63583 .03067 .63691 .03224 .6441 .02943 .64303 .02787 Metetra
.664 .741 .907 r
.64303 .02787 .6441 .02943 .65132 .02662 .65026 .02505 Metetra
.664 .741 .907 r
.65026 .02505 .65132 .02662 .65856 .02381 .6575 .02223 Metetra
.664 .741 .907 r
.6575 .02223 .65856 .02381 .66581 .02098 .66475 .0194 Metetra
.664 .741 .907 r
.66475 .0194 .66581 .02098 .67308 .01815 .67203 .01656 Metetra
.664 .741 .907 r
.67203 .01656 .67308 .01815 .68038 .01531 .67933 .01372 Metetra
.664 .741 .907 r
.67933 .01372 .68038 .01531 .68769 .01246 .68664 .01087 Metetra
.664 .741 .907 r
.68664 .01087 .68769 .01246 .69502 .00961 .69397 .00801 Metetra
.664 .741 .907 r
.04254 .26016 .04388 .26141 .04964 .25917 .0483 .25791 Metetra
.664 .741 .907 r
.0483 .25791 .04964 .25917 .05542 .25692 .05408 .25566 Metetra
.664 .741 .907 r
.05408 .25566 .05542 .25692 .06121 .25466 .05987 .2534 Metetra
.664 .741 .907 r
.05987 .2534 .06121 .25466 .06701 .2524 .06568 .25113 Metetra
.664 .741 .907 r
.06568 .25113 .06701 .2524 .07282 .25013 .07149 .24887 Metetra
.664 .741 .907 r
.07149 .24887 .07282 .25013 .07865 .24786 .07732 .24659 Metetra
.664 .741 .907 r
.07732 .24659 .07865 .24786 .08449 .24558 .08317 .24431 Metetra
.664 .741 .907 r
.08317 .24431 .08449 .24558 .09035 .2433 .08903 .24202 Metetra
.664 .741 .907 r
.08903 .24202 .09035 .2433 .09622 .24101 .0949 .23973 Metetra
.664 .741 .907 r
.0949 .23973 .09622 .24101 .1021 .23872 .10078 .23744 Metetra
.664 .741 .907 r
.10078 .23744 .1021 .23872 .108 .23642 .10668 .23514 Metetra
.664 .741 .907 r
.10668 .23514 .108 .23642 .11391 .23412 .1126 .23283 Metetra
.664 .741 .907 r
.1126 .23283 .11391 .23412 .11983 .23181 .11852 .23052 Metetra
.87 .429 .047 r
.11852 .23052 .11983 .23181 .12577 .22949 .1228 .24089 Metetra
.404 .126 .375 r
.1228 .24089 .12577 .22949 .13172 .22717 .12913 .23579 Metetra
.154 0 .241 r
.12913 .23579 .13172 .22717 .13769 .22485 .13638 .22355 Metetra
.664 .741 .907 r
.13638 .22355 .13769 .22485 .14367 .22252 .14237 .22121 Metetra
.664 .741 .907 r
.14237 .22121 .14367 .22252 .14966 .22018 .14836 .21888 Metetra
.664 .741 .907 r
.14836 .21888 .14966 .22018 .15567 .21784 .15437 .21653 Metetra
.664 .741 .907 r
.15437 .21653 .15567 .21784 .16169 .21549 .1604 .21418 Metetra
.664 .741 .907 r
.1604 .21418 .16169 .21549 .16773 .21314 .16643 .21182 Metetra
.664 .741 .907 r
.16643 .21182 .16773 .21314 .17378 .21078 .17249 .20946 Metetra
.664 .741 .907 r
.17249 .20946 .17378 .21078 .17984 .20842 .17855 .2071 Metetra
.664 .741 .907 r
.17855 .2071 .17984 .20842 .18592 .20605 .18463 .20472 Metetra
.664 .741 .907 r
.18463 .20472 .18592 .20605 .19201 .20367 .19073 .20235 Metetra
.664 .741 .907 r
.19073 .20235 .19201 .20367 .19812 .20129 .19684 .19996 Metetra
.664 .741 .907 r
.19684 .19996 .19812 .20129 .20424 .19891 .20296 .19757 Metetra
.664 .741 .907 r
.20296 .19757 .20424 .19891 .21038 .19651 .2091 .19518 Metetra
.664 .741 .907 r
.2091 .19518 .21038 .19651 .21653 .19412 .21526 .19278 Metetra
.664 .741 .907 r
.21526 .19278 .21653 .19412 .2227 .19171 .22143 .19037 Metetra
.664 .741 .907 r
.22143 .19037 .2227 .19171 .22888 .1893 .22761 .18796 Metetra
.664 .741 .907 r
.22761 .18796 .22888 .1893 .23507 .18689 .23381 .18554 Metetra
.664 .741 .907 r
.23381 .18554 .23507 .18689 .24128 .18447 .24002 .18312 Metetra
.664 .741 .907 r
.24002 .18312 .24128 .18447 .2475 .18204 .24624 .18069 Metetra
.664 .741 .907 r
.24624 .18069 .2475 .18204 .25374 .17961 .25249 .17825 Metetra
.664 .741 .907 r
.25249 .17825 .25374 .17961 .26 .17717 .25874 .17581 Metetra
.664 .741 .907 r
.25874 .17581 .26 .17717 .26627 .17473 .26502 .17336 Metetra
.664 .741 .907 r
.26502 .17336 .26627 .17473 .27255 .17228 .2713 .17091 Metetra
.959 .637 .365 r
.2713 .17091 .27255 .17228 .27428 .22538 .27379 .21463 Metetra
.978 .72 .314 r
.27379 .21463 .27428 .22538 .26639 .40154 .27136 .32178 Metetra
.71 .446 .524 r
.27136 .32178 .26639 .40154 .2915 .16489 .29025 .16352 Metetra
.664 .741 .907 r
.29025 .16352 .2915 .16489 .29784 .16242 .2966 .16104 Metetra
.664 .741 .907 r
.2966 .16104 .29784 .16242 .3042 .15994 .30297 .15856 Metetra
.664 .741 .907 r
.30297 .15856 .3042 .15994 .31058 .15746 .30934 .15607 Metetra
.664 .741 .907 r
.30934 .15607 .31058 .15746 .31697 .15497 .31574 .15357 Metetra
.664 .741 .907 r
.31574 .15357 .31697 .15497 .32337 .15247 .32215 .15107 Metetra
.664 .741 .907 r
.32215 .15107 .32337 .15247 .3298 .14997 .32857 .14857 Metetra
.664 .741 .907 r
.32857 .14857 .3298 .14997 .33623 .14746 .33501 .14605 Metetra
.664 .741 .907 r
.33501 .14605 .33623 .14746 .34269 .14494 .34147 .14353 Metetra
.664 .741 .907 r
.34147 .14353 .34269 .14494 .34916 .14242 .34794 .14101 Metetra
.664 .741 .907 r
.34794 .14101 .34916 .14242 .35564 .13989 .35443 .13848 Metetra
.664 .741 .907 r
.35443 .13848 .35564 .13989 .36214 .13736 .36093 .13594 Metetra
.664 .741 .907 r
.36093 .13594 .36214 .13736 .36866 .13482 .36745 .1334 Metetra
.664 .741 .907 r
.36745 .1334 .36866 .13482 .37519 .13227 .37399 .13085 Metetra
.664 .741 .907 r
.37399 .13085 .37519 .13227 .38174 .12972 .38054 .12829 Metetra
.664 .741 .907 r
.38054 .12829 .38174 .12972 .3883 .12716 .38711 .12573 Metetra
.664 .741 .907 r
.38711 .12573 .3883 .12716 .39488 .12459 .39369 .12316 Metetra
.664 .741 .907 r
.39369 .12316 .39488 .12459 .40148 .12202 .40029 .12059 Metetra
.664 .741 .907 r
.40029 .12059 .40148 .12202 .40809 .11945 .40691 .11801 Metetra
.664 .741 .907 r
.40691 .11801 .40809 .11945 .41472 .11686 .41354 .11542 Metetra
.664 .741 .907 r
.41354 .11542 .41472 .11686 .42137 .11427 .42019 .11282 Metetra
.664 .741 .907 r
.42019 .11282 .42137 .11427 .42803 .11167 .42685 .11022 Metetra
.664 .741 .907 r
.42685 .11022 .42803 .11167 .43471 .10907 .43353 .10762 Metetra
.664 .741 .907 r
.43353 .10762 .43471 .10907 .4414 .10646 .44023 .105 Metetra
.664 .741 .907 r
.44023 .105 .4414 .10646 .44811 .10385 .44695 .10238 Metetra
.664 .741 .907 r
.44695 .10238 .44811 .10385 .45484 .10122 .45368 .09976 Metetra
.664 .741 .907 r
.45368 .09976 .45484 .10122 .46159 .09859 .46043 .09712 Metetra
.664 .741 .907 r
.46043 .09712 .46159 .09859 .46835 .09596 .46719 .09449 Metetra
.664 .741 .907 r
.46719 .09449 .46835 .09596 .47513 .09332 .47397 .09184 Metetra
.664 .741 .907 r
.47397 .09184 .47513 .09332 .48192 .09067 .48077 .08919 Metetra
.664 .741 .907 r
.48077 .08919 .48192 .09067 .48874 .08801 .48759 .08653 Metetra
.664 .741 .907 r
.48759 .08653 .48874 .08801 .49557 .08535 .49442 .08386 Metetra
.664 .741 .907 r
.49442 .08386 .49557 .08535 .50241 .08268 .50127 .08119 Metetra
.664 .741 .907 r
.50127 .08119 .50241 .08268 .50928 .08001 .50814 .07851 Metetra
.664 .741 .907 r
.50814 .07851 .50928 .08001 .51616 .07732 .51502 .07582 Metetra
.664 .741 .907 r
.51502 .07582 .51616 .07732 .52306 .07463 .52192 .07313 Metetra
.664 .741 .907 r
.52192 .07313 .52306 .07463 .52997 .07194 .52884 .07043 Metetra
.664 .741 .907 r
.52884 .07043 .52997 .07194 .5369 .06924 .53578 .06773 Metetra
.664 .741 .907 r
.53578 .06773 .5369 .06924 .54385 .06653 .54273 .06501 Metetra
.664 .741 .907 r
.54273 .06501 .54385 .06653 .55082 .06381 .5497 .06229 Metetra
.664 .741 .907 r
.5497 .06229 .55082 .06381 .55781 .06109 .55669 .05957 Metetra
.664 .741 .907 r
.55669 .05957 .55781 .06109 .56481 .05836 .5637 .05683 Metetra
.664 .741 .907 r
.5637 .05683 .56481 .05836 .57183 .05562 .57072 .05409 Metetra
.664 .741 .907 r
.57072 .05409 .57183 .05562 .57887 .05288 .57777 .05134 Metetra
.664 .741 .907 r
.57777 .05134 .57887 .05288 .58593 .05013 .58483 .04859 Metetra
.664 .741 .907 r
.58483 .04859 .58593 .05013 .593 .04737 .59191 .04583 Metetra
.664 .741 .907 r
.59191 .04583 .593 .04737 .6001 .0446 .599 .04306 Metetra
.664 .741 .907 r
.599 .04306 .6001 .0446 .60721 .04183 .60612 .04028 Metetra
.664 .741 .907 r
.60612 .04028 .60721 .04183 .61436 .0397 .61325 .0375 Metetra
.648 .646 .834 r
.61325 .0375 .61436 .0397 .62148 .03627 .6204 .03471 Metetra
.664 .741 .907 r
.6204 .03471 .62148 .03627 .62896 .04192 .62757 .03191 Metetra
.547 .362 .582 r
.62757 .03191 .62896 .04192 .63583 .03067 .63476 .02911 Metetra
.664 .741 .907 r
.63476 .02911 .63583 .03067 .64303 .02787 .64196 .0263 Metetra
.664 .741 .907 r
.64196 .0263 .64303 .02787 .65026 .02505 .64919 .02348 Metetra
.664 .741 .907 r
.64919 .02348 .65026 .02505 .6575 .02223 .65643 .02065 Metetra
.664 .741 .907 r
.65643 .02065 .6575 .02223 .66475 .0194 .66369 .01782 Metetra
.664 .741 .907 r
.66369 .01782 .66475 .0194 .67203 .01656 .67097 .01498 Metetra
.664 .741 .907 r
.67097 .01498 .67203 .01656 .67933 .01372 .67827 .01213 Metetra
.664 .741 .907 r
.67827 .01213 .67933 .01372 .68664 .01087 .68559 .00928 Metetra
.664 .741 .907 r
.68559 .00928 .68664 .01087 .69397 .00801 .69293 .00641 Metetra
.664 .741 .907 r
.0412 .25891 .04254 .26016 .0483 .25791 .04696 .25666 Metetra
.664 .741 .907 r
.04696 .25666 .0483 .25791 .05408 .25566 .05274 .2544 Metetra
.664 .741 .907 r
.05274 .2544 .05408 .25566 .05987 .2534 .05854 .25214 Metetra
.664 .741 .907 r
.05854 .25214 .05987 .2534 .06568 .25113 .06434 .24987 Metetra
.664 .741 .907 r
.06434 .24987 .06568 .25113 .07149 .24887 .07016 .2476 Metetra
.664 .741 .907 r
.07016 .2476 .07149 .24887 .07732 .24659 .076 .24532 Metetra
.664 .741 .907 r
.076 .24532 .07732 .24659 .08317 .24431 .08184 .24304 Metetra
.664 .741 .907 r
.08184 .24304 .08317 .24431 .08903 .24202 .0877 .24075 Metetra
.664 .741 .907 r
.0877 .24075 .08903 .24202 .0949 .23973 .09358 .23845 Metetra
.664 .741 .907 r
.09358 .23845 .0949 .23973 .10078 .23744 .09946 .23615 Metetra
.664 .741 .907 r
.09946 .23615 .10078 .23744 .10668 .23514 .10536 .23385 Metetra
.664 .741 .907 r
.10536 .23385 .10668 .23514 .1126 .23283 .11128 .23154 Metetra
.664 .741 .907 r
.11128 .23154 .1126 .23283 .11852 .23052 .11721 .22923 Metetra
.95 .639 .41 r
.11721 .22923 .11852 .23052 .1228 .24089 .11792 .26661 Metetra
.083 0 .294 r
.11792 .26661 .1228 .24089 .12913 .23579 .12911 .22458 Metetra
.54 .347 .568 r
.12911 .22458 .12913 .23579 .13638 .22355 .13508 .22225 Metetra
.664 .741 .907 r
.13508 .22225 .13638 .22355 .14237 .22121 .14106 .21991 Metetra
.664 .741 .907 r
.14106 .21991 .14237 .22121 .14836 .21888 .14706 .21757 Metetra
.664 .741 .907 r
.14706 .21757 .14836 .21888 .15437 .21653 .15307 .21522 Metetra
.664 .741 .907 r
.15307 .21522 .15437 .21653 .1604 .21418 .1591 .21287 Metetra
.664 .741 .907 r
.1591 .21287 .1604 .21418 .16643 .21182 .16514 .21051 Metetra
.664 .741 .907 r
.16514 .21051 .16643 .21182 .17249 .20946 .1712 .20814 Metetra
.664 .741 .907 r
.1712 .20814 .17249 .20946 .17855 .2071 .17726 .20577 Metetra
.664 .741 .907 r
.17726 .20577 .17855 .2071 .18463 .20472 .18335 .2034 Metetra
.664 .741 .907 r
.18335 .2034 .18463 .20472 .19073 .20235 .18945 .20102 Metetra
.664 .741 .907 r
.18945 .20102 .19073 .20235 .19684 .19996 .19556 .19863 Metetra
.664 .741 .907 r
.19556 .19863 .19684 .19996 .20296 .19757 .20169 .19624 Metetra
.664 .741 .907 r
.20169 .19624 .20296 .19757 .2091 .19518 .20783 .19384 Metetra
.664 .741 .907 r
.20783 .19384 .2091 .19518 .21526 .19278 .21398 .19143 Metetra
.664 .741 .907 r
.21398 .19143 .21526 .19278 .22143 .19037 .22015 .18903 Metetra
.664 .741 .907 r
.22015 .18903 .22143 .19037 .22761 .18796 .22634 .18661 Metetra
.664 .741 .907 r
.22634 .18661 .22761 .18796 .23381 .18554 .23254 .18419 Metetra
.664 .741 .907 r
.23254 .18419 .23381 .18554 .24002 .18312 .23875 .18176 Metetra
.664 .741 .907 r
.23875 .18176 .24002 .18312 .24624 .18069 .24498 .17933 Metetra
.664 .741 .907 r
.24498 .17933 .24624 .18069 .25249 .17825 .25123 .17689 Metetra
.664 .741 .907 r
.25123 .17689 .25249 .17825 .25874 .17581 .25749 .17445 Metetra
.664 .741 .907 r
.25749 .17445 .25874 .17581 .26502 .17336 .26376 .172 Metetra
.664 .741 .907 r
.26376 .172 .26502 .17336 .2713 .17091 .27005 .16954 Metetra
.664 .741 .907 r
.27005 .16954 .2713 .17091 .27379 .21463 .27636 .16708 Metetra
.353 .156 .468 r
.27636 .16708 .27379 .21463 .27136 .32178 .27938 .2053 Metetra
.553 .31 .502 r
.27938 .2053 .27136 .32178 .29025 .16352 .28901 .16214 Metetra
.664 .741 .907 r
.28901 .16214 .29025 .16352 .2966 .16104 .29536 .15966 Metetra
.664 .741 .907 r
.29536 .15966 .2966 .16104 .30297 .15856 .30173 .15717 Metetra
.664 .741 .907 r
.30173 .15717 .30297 .15856 .30934 .15607 .30811 .15468 Metetra
.664 .741 .907 r
.30811 .15468 .30934 .15607 .31574 .15357 .31451 .15218 Metetra
.664 .741 .907 r
.31451 .15218 .31574 .15357 .32215 .15107 .32092 .14968 Metetra
.664 .741 .907 r
.32092 .14968 .32215 .15107 .32857 .14857 .32735 .14717 Metetra
.664 .741 .907 r
.32735 .14717 .32857 .14857 .33501 .14605 .33379 .14465 Metetra
.664 .741 .907 r
.33379 .14465 .33501 .14605 .34147 .14353 .34025 .14213 Metetra
.664 .741 .907 r
.34025 .14213 .34147 .14353 .34794 .14101 .34672 .1396 Metetra
.664 .741 .907 r
.34672 .1396 .34794 .14101 .35443 .13848 .35322 .13706 Metetra
.664 .741 .907 r
.35322 .13706 .35443 .13848 .36093 .13594 .35972 .13452 Metetra
.664 .741 .907 r
.35972 .13452 .36093 .13594 .36745 .1334 .36624 .13198 Metetra
.664 .741 .907 r
.36624 .13198 .36745 .1334 .37399 .13085 .37278 .12942 Metetra
.664 .741 .907 r
.37278 .12942 .37399 .13085 .38054 .12829 .37934 .12686 Metetra
.664 .741 .907 r
.37934 .12686 .38054 .12829 .38711 .12573 .38591 .1243 Metetra
.664 .741 .907 r
.38591 .1243 .38711 .12573 .39369 .12316 .39249 .12173 Metetra
.664 .741 .907 r
.39249 .12173 .39369 .12316 .40029 .12059 .3991 .11915 Metetra
.664 .741 .907 r
.3991 .11915 .40029 .12059 .40691 .11801 .40572 .11656 Metetra
.664 .741 .907 r
.40572 .11656 .40691 .11801 .41354 .11542 .41235 .11397 Metetra
.664 .741 .907 r
.41235 .11397 .41354 .11542 .42019 .11282 .419 .11137 Metetra
.664 .741 .907 r
.419 .11137 .42019 .11282 .42685 .11022 .42567 .10877 Metetra
.664 .741 .907 r
.42567 .10877 .42685 .11022 .43353 .10762 .43236 .10616 Metetra
.664 .741 .907 r
.43236 .10616 .43353 .10762 .44023 .105 .43906 .10354 Metetra
.664 .741 .907 r
.43906 .10354 .44023 .105 .44695 .10238 .44578 .10092 Metetra
.664 .741 .907 r
.44578 .10092 .44695 .10238 .45368 .09976 .45251 .09829 Metetra
.664 .741 .907 r
.45251 .09829 .45368 .09976 .46043 .09712 .45926 .09565 Metetra
.664 .741 .907 r
.45926 .09565 .46043 .09712 .46719 .09449 .46603 .09301 Metetra
.664 .741 .907 r
.46603 .09301 .46719 .09449 .47397 .09184 .47281 .09036 Metetra
.664 .741 .907 r
.47281 .09036 .47397 .09184 .48077 .08919 .47962 .0877 Metetra
.664 .741 .907 r
.47962 .0877 .48077 .08919 .48759 .08653 .48644 .08504 Metetra
.664 .741 .907 r
.48644 .08504 .48759 .08653 .49442 .08386 .49327 .08237 Metetra
.664 .741 .907 r
.49327 .08237 .49442 .08386 .50127 .08119 .50012 .0797 Metetra
.664 .741 .907 r
.50012 .0797 .50127 .08119 .50814 .07851 .507 .07701 Metetra
.664 .741 .907 r
.507 .07701 .50814 .07851 .51502 .07582 .51388 .07432 Metetra
.664 .741 .907 r
.51388 .07432 .51502 .07582 .52192 .07313 .52079 .07163 Metetra
.664 .741 .907 r
.52079 .07163 .52192 .07313 .52884 .07043 .52771 .06892 Metetra
.664 .741 .907 r
.52771 .06892 .52884 .07043 .53578 .06773 .53465 .06621 Metetra
.664 .741 .907 r
.53465 .06621 .53578 .06773 .54273 .06501 .54161 .0635 Metetra
.664 .741 .907 r
.54161 .0635 .54273 .06501 .5497 .06229 .54858 .06077 Metetra
.664 .741 .907 r
.54858 .06077 .5497 .06229 .55669 .05957 .55558 .05804 Metetra
.664 .741 .907 r
.55558 .05804 .55669 .05957 .5637 .05683 .56259 .0553 Metetra
.664 .741 .907 r
.56259 .0553 .5637 .05683 .57072 .05409 .56961 .05256 Metetra
.664 .741 .907 r
.56961 .05256 .57072 .05409 .57777 .05134 .57666 .04981 Metetra
.664 .741 .907 r
.57666 .04981 .57777 .05134 .58483 .04859 .58372 .04705 Metetra
.664 .741 .907 r
.58372 .04705 .58483 .04859 .59191 .04583 .59081 .04428 Metetra
.664 .741 .907 r
.59081 .04428 .59191 .04583 .599 .04306 .59791 .04151 Metetra
.664 .741 .907 r
.59791 .04151 .599 .04306 .60612 .04028 .60502 .03873 Metetra
.664 .741 .907 r
.60502 .03873 .60612 .04028 .61325 .0375 .61216 .03595 Metetra
.664 .741 .907 r
.61216 .03595 .61325 .0375 .6204 .03471 .61932 .03315 Metetra
.664 .741 .907 r
.61932 .03315 .6204 .03471 .62757 .03191 .62649 .03035 Metetra
.664 .741 .907 r
.62649 .03035 .62757 .03191 .63476 .02911 .63368 .02754 Metetra
.664 .741 .907 r
.63368 .02754 .63476 .02911 .64196 .0263 .64089 .02473 Metetra
.664 .741 .907 r
.64089 .02473 .64196 .0263 .64919 .02348 .64812 .0219 Metetra
.664 .741 .907 r
.64812 .0219 .64919 .02348 .65643 .02065 .65537 .01907 Metetra
.664 .741 .907 r
.65537 .01907 .65643 .02065 .66369 .01782 .66263 .01624 Metetra
.664 .741 .907 r
.66263 .01624 .66369 .01782 .67097 .01498 .66992 .01339 Metetra
.664 .741 .907 r
.66992 .01339 .67097 .01498 .67827 .01213 .67722 .01054 Metetra
.664 .741 .907 r
.67722 .01054 .67827 .01213 .68559 .00928 .68454 .00768 Metetra
.664 .741 .907 r
.68454 .00768 .68559 .00928 .69293 .00641 .69188 .00481 Metetra
.664 .741 .907 r
.03985 .25765 .0412 .25891 .04696 .25666 .04562 .2554 Metetra
.664 .741 .907 r
.04562 .2554 .04696 .25666 .05274 .2544 .0514 .25314 Metetra
.664 .741 .907 r
.0514 .25314 .05274 .2544 .05854 .25214 .0572 .25087 Metetra
.664 .741 .907 r
.0572 .25087 .05854 .25214 .06434 .24987 .06301 .2486 Metetra
.664 .741 .907 r
.06301 .2486 .06434 .24987 .07016 .2476 .06883 .24633 Metetra
.664 .741 .907 r
.06883 .24633 .07016 .2476 .076 .24532 .07466 .24405 Metetra
.664 .741 .907 r
.07466 .24405 .076 .24532 .08184 .24304 .08051 .24176 Metetra
.664 .741 .907 r
.08051 .24176 .08184 .24304 .0877 .24075 .08638 .23947 Metetra
.664 .741 .907 r
.08638 .23947 .0877 .24075 .09358 .23845 .09225 .23717 Metetra
.664 .741 .907 r
.09225 .23717 .09358 .23845 .09946 .23615 .09814 .23487 Metetra
.664 .741 .907 r
.09814 .23487 .09946 .23615 .10536 .23385 .10405 .23256 Metetra
.664 .741 .907 r
.10405 .23256 .10536 .23385 .11128 .23154 .10996 .23025 Metetra
.664 .741 .907 r
.10996 .23025 .11128 .23154 .11721 .22923 .11589 .22793 Metetra
.95 .657 .449 r
.11589 .22793 .11721 .22923 .11792 .26661 .11394 .28537 Metetra
.11394 .28537 .11792 .26661 .12911 .22458 .1278 .22328 Metetra
.664 .741 .907 r
.1278 .22328 .12911 .22458 .13508 .22225 .13377 .22094 Metetra
.664 .741 .907 r
.13377 .22094 .13508 .22225 .14106 .21991 .13976 .2186 Metetra
.664 .741 .907 r
.13976 .2186 .14106 .21991 .14706 .21757 .14576 .21626 Metetra
.664 .741 .907 r
.14576 .21626 .14706 .21757 .15307 .21522 .15177 .21391 Metetra
.664 .741 .907 r
.15177 .21391 .15307 .21522 .1591 .21287 .1578 .21155 Metetra
.664 .741 .907 r
.1578 .21155 .1591 .21287 .16514 .21051 .16384 .20919 Metetra
.664 .741 .907 r
.16384 .20919 .16514 .21051 .1712 .20814 .1699 .20682 Metetra
.664 .741 .907 r
.1699 .20682 .1712 .20814 .17726 .20577 .17597 .20445 Metetra
.664 .741 .907 r
.17597 .20445 .17726 .20577 .18335 .2034 .18206 .20207 Metetra
.664 .741 .907 r
.18206 .20207 .18335 .2034 .18945 .20102 .18816 .19969 Metetra
.664 .741 .907 r
.18816 .19969 .18945 .20102 .19556 .19863 .19428 .1973 Metetra
.664 .741 .907 r
.19428 .1973 .19556 .19863 .20169 .19624 .2004 .1949 Metetra
.664 .741 .907 r
.2004 .1949 .20169 .19624 .20783 .19384 .20655 .1925 Metetra
.664 .741 .907 r
.20655 .1925 .20783 .19384 .21398 .19143 .21271 .19009 Metetra
.664 .741 .907 r
.21271 .19009 .21398 .19143 .22015 .18903 .21888 .18768 Metetra
.664 .741 .907 r
.21888 .18768 .22015 .18903 .22634 .18661 .22507 .18526 Metetra
.664 .741 .907 r
.22507 .18526 .22634 .18661 .23254 .18419 .23127 .18284 Metetra
.664 .741 .907 r
.23127 .18284 .23254 .18419 .23875 .18176 .23749 .18041 Metetra
.664 .741 .907 r
.23749 .18041 .23875 .18176 .24498 .17933 .24372 .17797 Metetra
.664 .741 .907 r
.24372 .17797 .24498 .17933 .25123 .17689 .24997 .17553 Metetra
.664 .741 .907 r
.24997 .17553 .25123 .17689 .25749 .17445 .25623 .17308 Metetra
.664 .741 .907 r
.25623 .17308 .25749 .17445 .26376 .172 .26251 .17063 Metetra
.664 .741 .907 r
.26251 .17063 .26376 .172 .27005 .16954 .2688 .16817 Metetra
.664 .741 .907 r
.2688 .16817 .27005 .16954 .27636 .16708 .27511 .1657 Metetra
.664 .741 .907 r
.27511 .1657 .27636 .16708 .27938 .2053 .28143 .16323 Metetra
.51 .283 .506 r
.28143 .16323 .27938 .2053 .28901 .16214 .28777 .16075 Metetra
.664 .741 .907 r
.28777 .16075 .28901 .16214 .29536 .15966 .29412 .15827 Metetra
.664 .741 .907 r
.29412 .15827 .29536 .15966 .30173 .15717 .30049 .15578 Metetra
.664 .741 .907 r
.30049 .15578 .30173 .15717 .30811 .15468 .30687 .15329 Metetra
.664 .741 .907 r
.30687 .15329 .30811 .15468 .31451 .15218 .31327 .15078 Metetra
.664 .741 .907 r
.31327 .15078 .31451 .15218 .32092 .14968 .31969 .14828 Metetra
.664 .741 .907 r
.31969 .14828 .32092 .14968 .32735 .14717 .32612 .14576 Metetra
.664 .741 .907 r
.32612 .14576 .32735 .14717 .33379 .14465 .33257 .14324 Metetra
.664 .741 .907 r
.33257 .14324 .33379 .14465 .34025 .14213 .33903 .14072 Metetra
.664 .741 .907 r
.33903 .14072 .34025 .14213 .34672 .1396 .34551 .13819 Metetra
.664 .741 .907 r
.34551 .13819 .34672 .1396 .35322 .13706 .352 .13565 Metetra
.664 .741 .907 r
.352 .13565 .35322 .13706 .35972 .13452 .35851 .1331 Metetra
.664 .741 .907 r
.35851 .1331 .35972 .13452 .36624 .13198 .36503 .13055 Metetra
.664 .741 .907 r
.36503 .13055 .36624 .13198 .37278 .12942 .37158 .128 Metetra
.664 .741 .907 r
.37158 .128 .37278 .12942 .37934 .12686 .37813 .12543 Metetra
.664 .741 .907 r
.37813 .12543 .37934 .12686 .38591 .1243 .38471 .12286 Metetra
.664 .741 .907 r
.38471 .12286 .38591 .1243 .39249 .12173 .3913 .12029 Metetra
.664 .741 .907 r
.3913 .12029 .39249 .12173 .3991 .11915 .3979 .11771 Metetra
.664 .741 .907 r
.3979 .11771 .3991 .11915 .40572 .11656 .40452 .11512 Metetra
.664 .741 .907 r
.40452 .11512 .40572 .11656 .41235 .11397 .41116 .11252 Metetra
.664 .741 .907 r
.41116 .11252 .41235 .11397 .419 .11137 .41782 .10992 Metetra
.664 .741 .907 r
.41782 .10992 .419 .11137 .42567 .10877 .42449 .10731 Metetra
.664 .741 .907 r
.42449 .10731 .42567 .10877 .43236 .10616 .43118 .1047 Metetra
.664 .741 .907 r
.43118 .1047 .43236 .10616 .43906 .10354 .43788 .10208 Metetra
.664 .741 .907 r
.43788 .10208 .43906 .10354 .44578 .10092 .4446 .09945 Metetra
.664 .741 .907 r
.4446 .09945 .44578 .10092 .45251 .09829 .45134 .09682 Metetra
.664 .741 .907 r
.45134 .09682 .45251 .09829 .45926 .09565 .4581 .09418 Metetra
.664 .741 .907 r
.4581 .09418 .45926 .09565 .46603 .09301 .46487 .09153 Metetra
.664 .741 .907 r
.46487 .09153 .46603 .09301 .47281 .09036 .47166 .08888 Metetra
.664 .741 .907 r
.47166 .08888 .47281 .09036 .47962 .0877 .47846 .08622 Metetra
.664 .741 .907 r
.47846 .08622 .47962 .0877 .48644 .08504 .48528 .08355 Metetra
.664 .741 .907 r
.48528 .08355 .48644 .08504 .49327 .08237 .49212 .08088 Metetra
.664 .741 .907 r
.49212 .08088 .49327 .08237 .50012 .0797 .49898 .0782 Metetra
.664 .741 .907 r
.49898 .0782 .50012 .0797 .507 .07701 .50585 .07551 Metetra
.664 .741 .907 r
.50585 .07551 .507 .07701 .51388 .07432 .51274 .07282 Metetra
.664 .741 .907 r
.51274 .07282 .51388 .07432 .52079 .07163 .51965 .07012 Metetra
.664 .741 .907 r
.51965 .07012 .52079 .07163 .52771 .06892 .52658 .06741 Metetra
.664 .741 .907 r
.52658 .06741 .52771 .06892 .53465 .06621 .53352 .0647 Metetra
.664 .741 .907 r
.53352 .0647 .53465 .06621 .54161 .0635 .54048 .06198 Metetra
.664 .741 .907 r
.54048 .06198 .54161 .0635 .54858 .06077 .54746 .05925 Metetra
.664 .741 .907 r
.54746 .05925 .54858 .06077 .55558 .05804 .55446 .05652 Metetra
.664 .741 .907 r
.55446 .05652 .55558 .05804 .56259 .0553 .56147 .05377 Metetra
.664 .741 .907 r
.56147 .05377 .56259 .0553 .56961 .05256 .5685 .05103 Metetra
.664 .741 .907 r
.5685 .05103 .56961 .05256 .57666 .04981 .57555 .04827 Metetra
.664 .741 .907 r
.57555 .04827 .57666 .04981 .58372 .04705 .58262 .04551 Metetra
.664 .741 .907 r
.58262 .04551 .58372 .04705 .59081 .04428 .58971 .04274 Metetra
.664 .741 .907 r
.58971 .04274 .59081 .04428 .59791 .04151 .59681 .03996 Metetra
.664 .741 .907 r
.59681 .03996 .59791 .04151 .60502 .03873 .60393 .03718 Metetra
.664 .741 .907 r
.60393 .03718 .60502 .03873 .61216 .03595 .61107 .03439 Metetra
.664 .741 .907 r
.61107 .03439 .61216 .03595 .61932 .03315 .61823 .03159 Metetra
.664 .741 .907 r
.61823 .03159 .61932 .03315 .62649 .03035 .62541 .02878 Metetra
.664 .741 .907 r
.62541 .02878 .62649 .03035 .63368 .02754 .6326 .02597 Metetra
.664 .741 .907 r
.6326 .02597 .63368 .02754 .64089 .02473 .63982 .02315 Metetra
.664 .741 .907 r
.63982 .02315 .64089 .02473 .64812 .0219 .64705 .02033 Metetra
.664 .741 .907 r
.64705 .02033 .64812 .0219 .65537 .01907 .6543 .01749 Metetra
.664 .741 .907 r
.6543 .01749 .65537 .01907 .66263 .01624 .66157 .01465 Metetra
.664 .741 .907 r
.66157 .01465 .66263 .01624 .66992 .01339 .66886 .0118 Metetra
.664 .741 .907 r
.66886 .0118 .66992 .01339 .67722 .01054 .67616 .00895 Metetra
.664 .741 .907 r
.67616 .00895 .67722 .01054 .68454 .00768 .68349 .00608 Metetra
.664 .741 .907 r
.68349 .00608 .68454 .00768 .69188 .00481 .69084 .00321 Metetra
.664 .741 .907 r
.03851 .2564 .03985 .25765 .04562 .2554 .04428 .25414 Metetra
.664 .741 .907 r
.04428 .25414 .04562 .2554 .0514 .25314 .05006 .25188 Metetra
.664 .741 .907 r
.05006 .25188 .0514 .25314 .0572 .25087 .05586 .24961 Metetra
.664 .741 .907 r
.05586 .24961 .0572 .25087 .06301 .2486 .06167 .24733 Metetra
.664 .741 .907 r
.06167 .24733 .06301 .2486 .06883 .24633 .06749 .24506 Metetra
.664 .741 .907 r
.06749 .24506 .06883 .24633 .07466 .24405 .07333 .24277 Metetra
.664 .741 .907 r
.07333 .24277 .07466 .24405 .08051 .24176 .07918 .24048 Metetra
.664 .741 .907 r
.07918 .24048 .08051 .24176 .08638 .23947 .08505 .23819 Metetra
.664 .741 .907 r
.08505 .23819 .08638 .23947 .09225 .23717 .09093 .23589 Metetra
.664 .741 .907 r
.09093 .23589 .09225 .23717 .09814 .23487 .09682 .23358 Metetra
.664 .741 .907 r
.09682 .23358 .09814 .23487 .10405 .23256 .10272 .23127 Metetra
.664 .741 .907 r
.10272 .23127 .10405 .23256 .10996 .23025 .10864 .22896 Metetra
.664 .741 .907 r
.10864 .22896 .10996 .23025 .11589 .22793 .11458 .22664 Metetra
.664 .741 .907 r
.11458 .22664 .11589 .22793 .11394 .28537 .12052 .22431 Metetra
.506 .275 .499 r
.12052 .22431 .11394 .28537 .1278 .22328 .12649 .22198 Metetra
.664 .741 .907 r
.12649 .22198 .1278 .22328 .13377 .22094 .13246 .21964 Metetra
.664 .741 .907 r
.13246 .21964 .13377 .22094 .13976 .2186 .13845 .2173 Metetra
.664 .741 .907 r
.13845 .2173 .13976 .2186 .14576 .21626 .14445 .21495 Metetra
.664 .741 .907 r
.14445 .21495 .14576 .21626 .15177 .21391 .15047 .21259 Metetra
.664 .741 .907 r
.15047 .21259 .15177 .21391 .1578 .21155 .1565 .21024 Metetra
.664 .741 .907 r
.1565 .21024 .1578 .21155 .16384 .20919 .16255 .20787 Metetra
.664 .741 .907 r
.16255 .20787 .16384 .20919 .1699 .20682 .16861 .2055 Metetra
.664 .741 .907 r
.16861 .2055 .1699 .20682 .17597 .20445 .17468 .20312 Metetra
.664 .741 .907 r
.17468 .20312 .17597 .20445 .18206 .20207 .18077 .20074 Metetra
.664 .741 .907 r
.18077 .20074 .18206 .20207 .18816 .19969 .18687 .19835 Metetra
.664 .741 .907 r
.18687 .19835 .18816 .19969 .19428 .1973 .19299 .19596 Metetra
.664 .741 .907 r
.19299 .19596 .19428 .1973 .2004 .1949 .19912 .19356 Metetra
.664 .741 .907 r
.19912 .19356 .2004 .1949 .20655 .1925 .20527 .19116 Metetra
.664 .741 .907 r
.20527 .19116 .20655 .1925 .21271 .19009 .21143 .18875 Metetra
.664 .741 .907 r
.21143 .18875 .21271 .19009 .21888 .18768 .21761 .18633 Metetra
.664 .741 .907 r
.21761 .18633 .21888 .18768 .22507 .18526 .2238 .18391 Metetra
.664 .741 .907 r
.2238 .18391 .22507 .18526 .23127 .18284 .23 .18148 Metetra
.664 .741 .907 r
.23 .18148 .23127 .18284 .23749 .18041 .23622 .17905 Metetra
.664 .741 .907 r
.23622 .17905 .23749 .18041 .24372 .17797 .24246 .17661 Metetra
.664 .741 .907 r
.24246 .17661 .24372 .17797 .24997 .17553 .24871 .17416 Metetra
.664 .741 .907 r
.24871 .17416 .24997 .17553 .25623 .17308 .25497 .17171 Metetra
.664 .741 .907 r
.25497 .17171 .25623 .17308 .26251 .17063 .26125 .16926 Metetra
.664 .741 .907 r
.26125 .16926 .26251 .17063 .2688 .16817 .26755 .16679 Metetra
.664 .741 .907 r
.26755 .16679 .2688 .16817 .27511 .1657 .27386 .16432 Metetra
.664 .741 .907 r
.27386 .16432 .27511 .1657 .28143 .16323 .28018 .16185 Metetra
.664 .741 .907 r
.28018 .16185 .28143 .16323 .28777 .16075 .28652 .15937 Metetra
.664 .741 .907 r
.28652 .15937 .28777 .16075 .29412 .15827 .29288 .15688 Metetra
.664 .741 .907 r
.29288 .15688 .29412 .15827 .30049 .15578 .29925 .15439 Metetra
.664 .741 .907 r
.29925 .15439 .30049 .15578 .30687 .15329 .30564 .15189 Metetra
.664 .741 .907 r
.30564 .15189 .30687 .15329 .31327 .15078 .31204 .14939 Metetra
.664 .741 .907 r
.31204 .14939 .31327 .15078 .31969 .14828 .31846 .14688 Metetra
.664 .741 .907 r
.31846 .14688 .31969 .14828 .32612 .14576 .32489 .14436 Metetra
.664 .741 .907 r
.32489 .14436 .32612 .14576 .33257 .14324 .33134 .14184 Metetra
.664 .741 .907 r
.33134 .14184 .33257 .14324 .33903 .14072 .33781 .13931 Metetra
.664 .741 .907 r
.33781 .13931 .33903 .14072 .34551 .13819 .34429 .13677 Metetra
.664 .741 .907 r
.34429 .13677 .34551 .13819 .352 .13565 .35078 .13423 Metetra
.664 .741 .907 r
.35078 .13423 .352 .13565 .35851 .1331 .3573 .13168 Metetra
.664 .741 .907 r
.3573 .13168 .35851 .1331 .36503 .13055 .36382 .12913 Metetra
.664 .741 .907 r
.36382 .12913 .36503 .13055 .37158 .128 .37037 .12657 Metetra
.664 .741 .907 r
.37037 .12657 .37158 .128 .37813 .12543 .37693 .124 Metetra
.664 .741 .907 r
.37693 .124 .37813 .12543 .38471 .12286 .3835 .12143 Metetra
.664 .741 .907 r
.3835 .12143 .38471 .12286 .3913 .12029 .3901 .11885 Metetra
.664 .741 .907 r
.3901 .11885 .3913 .12029 .3979 .11771 .39671 .11626 Metetra
.664 .741 .907 r
.39671 .11626 .3979 .11771 .40452 .11512 .40333 .11367 Metetra
.664 .741 .907 r
.40333 .11367 .40452 .11512 .41116 .11252 .40997 .11107 Metetra
.664 .741 .907 r
.40997 .11107 .41116 .11252 .41782 .10992 .41663 .10847 Metetra
.664 .741 .907 r
.41663 .10847 .41782 .10992 .42449 .10731 .42331 .10586 Metetra
.664 .741 .907 r
.42331 .10586 .42449 .10731 .43118 .1047 .43 .10324 Metetra
.664 .741 .907 r
.43 .10324 .43118 .1047 .43788 .10208 .4367 .10062 Metetra
.664 .741 .907 r
.4367 .10062 .43788 .10208 .4446 .09945 .44343 .09799 Metetra
.664 .741 .907 r
.44343 .09799 .4446 .09945 .45134 .09682 .45017 .09535 Metetra
.664 .741 .907 r
.45017 .09535 .45134 .09682 .4581 .09418 .45693 .0927 Metetra
.664 .741 .907 r
.45693 .0927 .4581 .09418 .46487 .09153 .4637 .09005 Metetra
.664 .741 .907 r
.4637 .09005 .46487 .09153 .47166 .08888 .47049 .0874 Metetra
.664 .741 .907 r
.47049 .0874 .47166 .08888 .47846 .08622 .4773 .08473 Metetra
.664 .741 .907 r
.4773 .08473 .47846 .08622 .48528 .08355 .48413 .08206 Metetra
.664 .741 .907 r
.48413 .08206 .48528 .08355 .49212 .08088 .49097 .07939 Metetra
.664 .741 .907 r
.49097 .07939 .49212 .08088 .49898 .0782 .49783 .0767 Metetra
.664 .741 .907 r
.49783 .0767 .49898 .0782 .50585 .07551 .50471 .07401 Metetra
.664 .741 .907 r
.50471 .07401 .50585 .07551 .51274 .07282 .5116 .07131 Metetra
.664 .741 .907 r
.5116 .07131 .51274 .07282 .51965 .07012 .51851 .06861 Metetra
.664 .741 .907 r
.51851 .06861 .51965 .07012 .52658 .06741 .52544 .0659 Metetra
.664 .741 .907 r
.52544 .0659 .52658 .06741 .53352 .0647 .53239 .06318 Metetra
.664 .741 .907 r
.53239 .06318 .53352 .0647 .54048 .06198 .53936 .06046 Metetra
.664 .741 .907 r
.53936 .06046 .54048 .06198 .54746 .05925 .54634 .05773 Metetra
.664 .741 .907 r
.54634 .05773 .54746 .05925 .55446 .05652 .55334 .05499 Metetra
.664 .741 .907 r
.55334 .05499 .55446 .05652 .56147 .05377 .56035 .05224 Metetra
.664 .741 .907 r
.56035 .05224 .56147 .05377 .5685 .05103 .56739 .04949 Metetra
.664 .741 .907 r
.56739 .04949 .5685 .05103 .57555 .04827 .57444 .04673 Metetra
.664 .741 .907 r
.57444 .04673 .57555 .04827 .58262 .04551 .58151 .04396 Metetra
.664 .741 .907 r
.58151 .04396 .58262 .04551 .58971 .04274 .5886 .04119 Metetra
.664 .741 .907 r
.5886 .04119 .58971 .04274 .59681 .03996 .59571 .03841 Metetra
.664 .741 .907 r
.59571 .03841 .59681 .03996 .60393 .03718 .60284 .03562 Metetra
.664 .741 .907 r
.60284 .03562 .60393 .03718 .61107 .03439 .60998 .03283 Metetra
.664 .741 .907 r
.60998 .03283 .61107 .03439 .61823 .03159 .61714 .03003 Metetra
.664 .741 .907 r
.61714 .03003 .61823 .03159 .62541 .02878 .62432 .02722 Metetra
.664 .741 .907 r
.62432 .02722 .62541 .02878 .6326 .02597 .63152 .0244 Metetra
.664 .741 .907 r
.63152 .0244 .6326 .02597 .63982 .02315 .63874 .02158 Metetra
.664 .741 .907 r
.63874 .02158 .63982 .02315 .64705 .02033 .64598 .01875 Metetra
.664 .741 .907 r
.64598 .01875 .64705 .02033 .6543 .01749 .65323 .01591 Metetra
.664 .741 .907 r
.65323 .01591 .6543 .01749 .66157 .01465 .6605 .01306 Metetra
.664 .741 .907 r
.6605 .01306 .66157 .01465 .66886 .0118 .6678 .01021 Metetra
.664 .741 .907 r
.6678 .01021 .66886 .0118 .67616 .00895 .67511 .00735 Metetra
.664 .741 .907 r
.67511 .00735 .67616 .00895 .68349 .00608 .68244 .00448 Metetra
.664 .741 .907 r
.68244 .00448 .68349 .00608 .69084 .00321 .68979 .00161 Metetra
.664 .741 .907 r
.03716 .25514 .03851 .2564 .04428 .25414 .04293 .25288 Metetra
.664 .741 .907 r
.04293 .25288 .04428 .25414 .05006 .25188 .04872 .25061 Metetra
.664 .741 .907 r
.04872 .25061 .05006 .25188 .05586 .24961 .05452 .24834 Metetra
.664 .741 .907 r
.05452 .24834 .05586 .24961 .06167 .24733 .06033 .24606 Metetra
.664 .741 .907 r
.06033 .24606 .06167 .24733 .06749 .24506 .06616 .24378 Metetra
.664 .741 .907 r
.06616 .24378 .06749 .24506 .07333 .24277 .072 .2415 Metetra
.664 .741 .907 r
.072 .2415 .07333 .24277 .07918 .24048 .07785 .2392 Metetra
.664 .741 .907 r
.07785 .2392 .07918 .24048 .08505 .23819 .08372 .23691 Metetra
.664 .741 .907 r
.08372 .23691 .08505 .23819 .09093 .23589 .0896 .2346 Metetra
.664 .741 .907 r
.0896 .2346 .09093 .23589 .09682 .23358 .09549 .2323 Metetra
.664 .741 .907 r
.09549 .2323 .09682 .23358 .10272 .23127 .1014 .22998 Metetra
.664 .741 .907 r
.1014 .22998 .10272 .23127 .10864 .22896 .10732 .22766 Metetra
.664 .741 .907 r
.10732 .22766 .10864 .22896 .11458 .22664 .11326 .22534 Metetra
.664 .741 .907 r
.11326 .22534 .11458 .22664 .12052 .22431 .11921 .22301 Metetra
.664 .741 .907 r
.11921 .22301 .12052 .22431 .12649 .22198 .12517 .22067 Metetra
.664 .741 .907 r
.12517 .22067 .12649 .22198 .13246 .21964 .13115 .21833 Metetra
.664 .741 .907 r
.13115 .21833 .13246 .21964 .13845 .2173 .13714 .21599 Metetra
.664 .741 .907 r
.13714 .21599 .13845 .2173 .14445 .21495 .14315 .21364 Metetra
.664 .741 .907 r
.14315 .21364 .14445 .21495 .15047 .21259 .14917 .21128 Metetra
.664 .741 .907 r
.14917 .21128 .15047 .21259 .1565 .21024 .1552 .20892 Metetra
.664 .741 .907 r
.1552 .20892 .1565 .21024 .16255 .20787 .16125 .20655 Metetra
.664 .741 .907 r
.16125 .20655 .16255 .20787 .16861 .2055 .16731 .20417 Metetra
.664 .741 .907 r
.16731 .20417 .16861 .2055 .17468 .20312 .17339 .2018 Metetra
.664 .741 .907 r
.17339 .2018 .17468 .20312 .18077 .20074 .17948 .19941 Metetra
.664 .741 .907 r
.17948 .19941 .18077 .20074 .18687 .19835 .18558 .19702 Metetra
.664 .741 .907 r
.18558 .19702 .18687 .19835 .19299 .19596 .1917 .19462 Metetra
.664 .741 .907 r
.1917 .19462 .19299 .19596 .19912 .19356 .19784 .19222 Metetra
.664 .741 .907 r
.19784 .19222 .19912 .19356 .20527 .19116 .20399 .18981 Metetra
.664 .741 .907 r
.20399 .18981 .20527 .19116 .21143 .18875 .21015 .1874 Metetra
.664 .741 .907 r
.21015 .1874 .21143 .18875 .21761 .18633 .21633 .18498 Metetra
.664 .741 .907 r
.21633 .18498 .21761 .18633 .2238 .18391 .22252 .18256 Metetra
.664 .741 .907 r
.22252 .18256 .2238 .18391 .23 .18148 .22873 .18012 Metetra
.664 .741 .907 r
.22873 .18012 .23 .18148 .23622 .17905 .23495 .17769 Metetra
.664 .741 .907 r
.23495 .17769 .23622 .17905 .24246 .17661 .24119 .17525 Metetra
.664 .741 .907 r
.24119 .17525 .24246 .17661 .24871 .17416 .24744 .1728 Metetra
.664 .741 .907 r
.24744 .1728 .24871 .17416 .25497 .17171 .25371 .17034 Metetra
.664 .741 .907 r
.25371 .17034 .25497 .17171 .26125 .16926 .25999 .16788 Metetra
.664 .741 .907 r
.25999 .16788 .26125 .16926 .26755 .16679 .26629 .16542 Metetra
.664 .741 .907 r
.26629 .16542 .26755 .16679 .27386 .16432 .2726 .16294 Metetra
.664 .741 .907 r
.2726 .16294 .27386 .16432 .28018 .16185 .27893 .16047 Metetra
.664 .741 .907 r
.27893 .16047 .28018 .16185 .28652 .15937 .28528 .15798 Metetra
.664 .741 .907 r
.28528 .15798 .28652 .15937 .29288 .15688 .29163 .15549 Metetra
.664 .741 .907 r
.29163 .15549 .29288 .15688 .29925 .15439 .29801 .153 Metetra
.664 .741 .907 r
.29801 .153 .29925 .15439 .30564 .15189 .3044 .15049 Metetra
.664 .741 .907 r
.3044 .15049 .30564 .15189 .31204 .14939 .3108 .14799 Metetra
.664 .741 .907 r
.3108 .14799 .31204 .14939 .31846 .14688 .31722 .14547 Metetra
.664 .741 .907 r
.31722 .14547 .31846 .14688 .32489 .14436 .32366 .14295 Metetra
.664 .741 .907 r
.32366 .14295 .32489 .14436 .33134 .14184 .33011 .14043 Metetra
.664 .741 .907 r
.33011 .14043 .33134 .14184 .33781 .13931 .33658 .13789 Metetra
.664 .741 .907 r
.33658 .13789 .33781 .13931 .34429 .13677 .34306 .13535 Metetra
.664 .741 .907 r
.34306 .13535 .34429 .13677 .35078 .13423 .34956 .13281 Metetra
.664 .741 .907 r
.34956 .13281 .35078 .13423 .3573 .13168 .35608 .13026 Metetra
.664 .741 .907 r
.35608 .13026 .3573 .13168 .36382 .12913 .36261 .1277 Metetra
.664 .741 .907 r
.36261 .1277 .36382 .12913 .37037 .12657 .36916 .12514 Metetra
.664 .741 .907 r
.36916 .12514 .37037 .12657 .37693 .124 .37572 .12257 Metetra
.664 .741 .907 r
.37572 .12257 .37693 .124 .3835 .12143 .3823 .11999 Metetra
.664 .741 .907 r
.3823 .11999 .3835 .12143 .3901 .11885 .3889 .11741 Metetra
.664 .741 .907 r
.3889 .11741 .3901 .11885 .39671 .11626 .39551 .11482 Metetra
.664 .741 .907 r
.39551 .11482 .39671 .11626 .40333 .11367 .40214 .11222 Metetra
.664 .741 .907 r
.40214 .11222 .40333 .11367 .40997 .11107 .40878 .10962 Metetra
.664 .741 .907 r
.40878 .10962 .40997 .11107 .41663 .10847 .41544 .10701 Metetra
.664 .741 .907 r
.41544 .10701 .41663 .10847 .42331 .10586 .42212 .1044 Metetra
.664 .741 .907 r
.42212 .1044 .42331 .10586 .43 .10324 .42881 .10178 Metetra
.664 .741 .907 r
.42881 .10178 .43 .10324 .4367 .10062 .43553 .09915 Metetra
.664 .741 .907 r
.43553 .09915 .4367 .10062 .44343 .09799 .44225 .09652 Metetra
.664 .741 .907 r
.44225 .09652 .44343 .09799 .45017 .09535 .449 .09387 Metetra
.664 .741 .907 r
.449 .09387 .45017 .09535 .45693 .0927 .45576 .09123 Metetra
.664 .741 .907 r
.45576 .09123 .45693 .0927 .4637 .09005 .46254 .08857 Metetra
.664 .741 .907 r
.46254 .08857 .4637 .09005 .47049 .0874 .46933 .08591 Metetra
.664 .741 .907 r
.46933 .08591 .47049 .0874 .4773 .08473 .47614 .08324 Metetra
.664 .741 .907 r
.47614 .08324 .4773 .08473 .48413 .08206 .48297 .08057 Metetra
.664 .741 .907 r
.48297 .08057 .48413 .08206 .49097 .07939 .48982 .07789 Metetra
.664 .741 .907 r
.48982 .07789 .49097 .07939 .49783 .0767 .49668 .0752 Metetra
.664 .741 .907 r
.49668 .0752 .49783 .0767 .50471 .07401 .50356 .07251 Metetra
.664 .741 .907 r
.50356 .07251 .50471 .07401 .5116 .07131 .51046 .06981 Metetra
.664 .741 .907 r
.51046 .06981 .5116 .07131 .51851 .06861 .51738 .0671 Metetra
.664 .741 .907 r
.51738 .0671 .51851 .06861 .52544 .0659 .52431 .06439 Metetra
.664 .741 .907 r
.52431 .06439 .52544 .0659 .53239 .06318 .53126 .06166 Metetra
.664 .741 .907 r
.53126 .06166 .53239 .06318 .53936 .06046 .53823 .05894 Metetra
.664 .741 .907 r
.53823 .05894 .53936 .06046 .54634 .05773 .54521 .0562 Metetra
.664 .741 .907 r
.54521 .0562 .54634 .05773 .55334 .05499 .55222 .05346 Metetra
.664 .741 .907 r
.55222 .05346 .55334 .05499 .56035 .05224 .55924 .05071 Metetra
.664 .741 .907 r
.55924 .05071 .56035 .05224 .56739 .04949 .56628 .04795 Metetra
.664 .741 .907 r
.56628 .04795 .56739 .04949 .57444 .04673 .57333 .04519 Metetra
.664 .741 .907 r
.57333 .04519 .57444 .04673 .58151 .04396 .58041 .04242 Metetra
.664 .741 .907 r
.58041 .04242 .58151 .04396 .5886 .04119 .5875 .03964 Metetra
.664 .741 .907 r
.5875 .03964 .5886 .04119 .59571 .03841 .59461 .03686 Metetra
.664 .741 .907 r
.59461 .03686 .59571 .03841 .60284 .03562 .60174 .03407 Metetra
.664 .741 .907 r
.60174 .03407 .60284 .03562 .60998 .03283 .60889 .03127 Metetra
.664 .741 .907 r
.60889 .03127 .60998 .03283 .61714 .03003 .61605 .02846 Metetra
.664 .741 .907 r
.61605 .02846 .61714 .03003 .62432 .02722 .62324 .02565 Metetra
.664 .741 .907 r
.62324 .02565 .62432 .02722 .63152 .0244 .63044 .02283 Metetra
.664 .741 .907 r
.63044 .02283 .63152 .0244 .63874 .02158 .63766 .02 Metetra
.664 .741 .907 r
.63766 .02 .63874 .02158 .64598 .01875 .6449 .01716 Metetra
.664 .741 .907 r
.6449 .01716 .64598 .01875 .65323 .01591 .65216 .01432 Metetra
.664 .741 .907 r
.65216 .01432 .65323 .01591 .6605 .01306 .65944 .01147 Metetra
.664 .741 .907 r
.65944 .01147 .6605 .01306 .6678 .01021 .66673 .00862 Metetra
.664 .741 .907 r
.66673 .00862 .6678 .01021 .67511 .00735 .67405 .00575 Metetra
.664 .741 .907 r
.67405 .00575 .67511 .00735 .68244 .00448 .68138 .00288 Metetra
.664 .741 .907 r
.68138 .00288 .68244 .00448 .68979 .00161 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14917 .21128 m
.15379 .21594 L
s
[(20)] .13993 .20196 .9915 1 Mshowa
.2726 .16294 m
.27702 .1678 L
s
[(40)] .26378 .15323 .9081 1 Mshowa
.40214 .11222 m
.40631 .11729 L
s
[(60)] .39379 .1021 .82471 1 Mshowa
.53823 .05894 m
.54213 .06421 L
s
[(80)] .53041 .04839 .74131 1 Mshowa
.68138 .00288 m
.68499 .00836 L
s
[(100)] .67417 -0.00808 .65791 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.0896 .2346 m
.09243 .23734 L
s
.11921 .22301 m
.12201 .22578 L
s
.17948 .19941 m
.18222 .20223 L
s
.21015 .1874 m
.21286 .19025 L
s
.24119 .17525 m
.24387 .17813 L
s
.3044 .15049 m
.30701 .15344 L
s
.33658 .13789 m
.33916 .14087 L
s
.36916 .12514 m
.3717 .12814 L
s
.43553 .09915 m
.43799 .10222 L
s
.46933 .08591 m
.47176 .08901 L
s
.50356 .07251 m
.50595 .07564 L
s
.57333 .04519 m
.57563 .04838 L
s
.60889 .03127 m
.61114 .03449 L
s
.6449 .01716 m
.64711 .02042 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{822, 666.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<f0002VQP00`40o`000?l0003ooooooooooooo
oooo>Oooo`00oooooooooooooooo>Oooo`00oooooooooolVoooo1@0000;oool00`000?ooooooo`02
oooo00<0003oooooool0ooooo`Coool00?oooooooooo:?ooo`070000oooooooooooo0000oooo0000
00;oool00`000?ooo`00003ooooo1Oooo`00oooooooooolXoooo00L0003oooooooooool0003oool0
00000_ooo`030000oooo00000?ooool5oooo003oooooooooobSoool01`000?ooooooooooo`000?oo
o`000002oooo00<0003oool00000ooooo`Goool00?oooooooooo:?ooo`070000oooooooooooo0000
oooo000000;oool00`000?ooo`00003ooooo1Oooo`00oooooooooolWoooo0P0000Coool00`000?oo
ooooo`02oooo00<0003oooooool0ooooo`Coool00?ooooooooooooooocWoool00?oooooooooooooo
ocWoool00?ooooooooooooooocWoool00?ooooooooooooooocWoool00?ooooooooooooooocWoool0
0?ooooooooooooooocWoool00?ooooooooooooooocWoool00?ooooooooooooooocWoool00?oooooo
oooo?Oooo`80003ioooo003ooooooooooc_oool50000n?ooo`00oooooooooolhoooo100000:Y_NP2
0000n?ooo`00oooooooooolfoooo10000003ZKgX0000000000@0003goooo003ooooooooooc?oool4
000000FY_NP000000000002Y_NP01P000?Koool00?oooooooooo<?ooo`@000001:Vmj00000000000
00:Y_NP500000ZVmj0030000oooooooo0?Coool00?oooooooooo;_ooo`<00002ZKgX0P0000>Y_NP4
00000ZVmj0<000000jVmj0000?ooo`3doooo003oooooooooob_oool300000jVmj08000000jVmj000
0:Vmj004000000>Y_NP0002Y_NP00P0000:Y_NP30000m?ooo`00oooooooooolYoooo0`000003ZKgX
0000ZKgX00800002ZKgX1@0000:Y_NP3000000FY_NP000000000002Y_NP00P000?Coool00?oooooo
oooo9_ooo`@00002ZKgX0`000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003
000000BY_NP0000000000002ZKgX00<0003oooooool0lOooo`00oooooooooolToooo10000005ZKgX
000000000000ZKgX00<000000jVmj00000000004000000BY_NP0000000000002ZKgX0`0000:Y_NP4
0000l_ooo`00oooooooooolQoooo10000005ZKgX000000000000ZKgX00<000001JVmj00000000000
0:Vmj00200000ZVmj0800003ZKgX0P000003ZKgX00000000008000001:Vmj000000000000?;oool0
0?oooooooooo7oooo`L000001JVmj000000000000:Vmj00300000ZVmj0800002ZKgX0P000003ZKgX
0000ZKgX00800002ZKgX0`000004ZKgX00000000ZKgX0`000?7oool00?oooooooooo7?ooo`L00000
1:Vmj0000000000000:Y_NP200000jVmj0<000000jVmj00000000002ZKgX0`000005ZKgX00000000
0000ZKgX00H000000jVmj0000000003aoooo003ooooooooooaWoool4000000>Y_NP0000000000ZVm
j0800003ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj003000000FY_NP00000
0000002Y_NP01P000004ZKgX0000000000000ZVmj0030000oooooooo0>koool00?oooooooooo5ooo
o`<00002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP3000000BY_NP00000002Y_NP3
000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`0000>Y_NP2000000>Y_NP0003o
ool0k_ooo`00oooooooooolDoooo0`0000>Y_NP3000000>Y_NP0000000000ZVmj0<000001JVmj000
000000000:Vmj006000000FY_NP000000000002Y_NP00`0000:Y_NP200000ZVmj08000000jVmj000
0:Vmj00200000ZVmj080003_oooo003ooooooooooa;oool3000000>Y_NP0002Y_NP00P000005ZKgX
000000000000ZKgX00<000001JVmj000000000000:Vmj006000000BY_NP0000000000002ZKgX0P00
00>Y_NP3000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P000>koool00?oooooo
oooo3oooo`@00002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00<00000
0jVmj00000000002ZKgX0P0000>Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX
00<000001JVmj000000000000:Vmj0060000kOooo`00ooooooooool=oooo10000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP200000ZVmj0800000
0jVmj0000:Vmj00200000ZVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003
000000>Y_NP0000000000ZVmj0030000oooooooo0>_oool00?oooooooooo2_ooo`@000001JVmj000
000000000:Vmj003000000>Y_NP000000000100000:Y_NP200000jVmj08000001:Vmj00000000000
00:Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00<00002ZKgX0P00
00:Y_NP2000000>Y_NP0003oool0joooo`00ooooooooool8oooo0`000005ZKgX000000000000ZKgX
00<000001JVmj000000000000:Vmj00200000jVmj08000000jVmj0000:Vmj00200000ZVmj0800000
1JVmj000000000000:Vmj003000000>Y_NP00000000010000004ZKgX0000000000000ZVmj0<00002
ZKgX0`000003ZKgX0000000000:Y_NP30000joooo`00ooooooooool5oooo0`000005ZKgX00000000
0000ZKgX00<00002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP3000000>Y_NP00000
000010000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000>Y_NP2000000>Y
_NP0000000000P000005ZKgX000000000000ZKgX00<000000jVmj0000000003[oooo003ooooooooo
o`;oool4000000>Y_NP0000000000ZVmj0800003ZKgX0P000004ZKgX0000000000000ZVmj0<00000
1JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP0000000000002ZKgX0P00
00:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000
0000002Y_NP00P000>[oool00?oooooooooo0`0000:Y_NP200000ZVmj08000000jVmj0000:Vmj002
00000ZVmj08000001JVmj000000000000:Vmj003000000FY_NP000000000002Y_NP01P0000:Y_NP2
00000jVmj08000001:Vmj0000000000000:Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX
000000000000ZKgX00<00002ZKgX00<0003oooooool0ioooo`00oooooocoool300000jVmj0<00000
0jVmj00000000002ZKgX0`000005ZKgX000000000000S5bD008000001JVmj000000000000:Vmj003
000000FY_NP000000000002Y_NP00P0000>Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP2000000FY
_NP000000000002Y_NP00`000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP200000jVm
j0<0003Yoooo003ooooon_ooo`<000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`00
0004ZKgX0000000000000haLU0050000Qd^100000000ZKgX00<00002ZKgX0P0000:Y_NP2000000>Y
_NP0002Y_NP00P0000:Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<00003ZKgX0P000003ZKgX0000ZKgX008000001:Vmj000000000000>Soool0
0?ooooogoooo100000:Y_NP3000000BY_NP00000002Y_NP3000000JY_NP000000000002Y_NP00004
S5bD00<00027Bh4000000P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP200000ZVmj0@00000
0jVmj00000000002ZKgX0`000004ZKgX00000000ZKgX0`000>Ooool00?oooooeoooo10000005ZKgX
000000000000ZKgX00<000001:Vmj00000000:Vmj0<00004ZKgX00D0002<G9B<G9B<G9@000000XM;
P@<000000jVmj00000000002ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00`000003ZKgX
0000000000@00002ZKgX0P0000>Y_NP3000000>Y_NP0000000000ZVmj0<000001JVmj00000000000
0:Vmj006000000>Y_NP000000000ioooo`00oooooo;oool4000000FY_NP000000000002Y_NP00`00
0003ZKgX0000000000@00002YJGE00<0002Y_NRY_NP00ZVmj0050000S5bDS5bDS5bD000000:7Bh44
000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00<000000jVmj00000000003
ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj007000000>Y_NP0000000001000
0004ZKgX0000000000000ZVmj0030000oooooooo0>Coool00?ooooo`oooo1`000005ZKgX00000000
0000ZKgX00<000000jVmj00000000003YJGE0P000003/mof0000ZKgX00>Y_NP00`0008aLU0000003
Qd^11@000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP200000ZVmj08000000jVmj000
0:Vmj00200000ZVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003000000>Y
_NP0000000000ZVmj0800003ZKgX0P000003ZKgX0000oooo0>Coool00?oooonhoooo00<0003ooooo
ool00_ooo`030000oooooooo02goool7000000BY_NP0000000000002ZKgX0P0000:Y_NP2000000>Y
_NP0002UYMD00P0000:cgoH300000jVmj0030000S5bD000000>7Bh46000000>Y_NP0000000000ZVm
j0800003ZKgX0P000004ZKgX0000000000000ZVmj0<000001JVmj000000000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP0000000000002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P00
00:Y_NP20000iOooo`00oooookOoool00`000?ooo`000002oooo00<0003oool00000:oooo`@00000
0jVmj00000000002ZKgX0P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000007/mof00000000
0000ZKgX000003Rm008000000jVmj00000000004Qd^11`0000:Y_NP2000000>Y_NP0002Y_NP00P00
00:Y_NP2000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX00H00002ZKgX0P00
0003ZKgX0000ZKgX00<000000jVmj00000000002ZKgX0`000003ZKgX0000000000@0003Toooo003o
oooo]oooo`030000oooo000000;oool00`000?ooo`00000Yoooo0`000004ZKgX0000000000000ZVm
j08000000jVmj0000:Vmj00200000ZVmj0800002ZKgX0P000004WkW[0000000000001:Vmj0040000
03Rm03Rm03Rm0`0000>7Bh42000000?n_W00000000000P000003ZKgX0000000000:Y_NP3000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00<000001JVmj000000000000:Vmj00200000jVm
j08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX
008000001:Vmj000000000000>?oool00?oooonhoooo00L0003oooooooooool0003oool000009_oo
o`<000001:Vmj0000000000000:Y_NP300000ZVmj0<000001JVmj000000000000:Vmj006000000>Y
_NP0000000001:Vmj003000003Rm03Rm0080>;d00`0008M;PHM;P@02Qd^10`000003Se1o00000000
008000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP0000000000002
ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP6000000FY_NP000000000002Y_NP00`00
0003ZKgX0000000000@00002ZKgX00<0003oooooool0hOooo`00oooookOoool00`000?ooo`000002
oooo00<0003oool000009?ooo`800002ZKgX0P0000BY_NP200000ZVmj08000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P0000>Y_NP200000`0h_@030000Qd^1Qd^100:7Bh43
000000>?D7l0000000000`000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX0P00
00>Y_NP2000000BY_NP0000000000002ZKgX0`000005ZKgX000000000000ZKgX00H000001JVmj000
000000000:Vmj003000000>Y_NP0000000000jVmj08000000jVmj0000?ooo`3Qoooo003ooooo^?oo
o`030000oooooooo00;oool00`000?ooooooo`0Poooo0`0000:Y_NP2000000>Y_NP0002Y_NP00`00
0003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`00
0003ZKgX0000ZKgX00:Y_NP200000`0h_@030000Qd^1Qd^100:7Bh43000000>?D7l0000000001000
0004ZKgX0000000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00800002ZKgX0P000005ZKgX
000000000000ZKgX00<000000jVmj00000000004000000BY_NP0000000000002ZKgX0P0000:Y_NP2
000000>Y_NP0002Y_NP00P0000:Y_NP30000hOooo`00ooooomkoool4000000>Y_NP0000000000ZVm
j0<000000jVmj00000000004000000FY_NP000000000002Y_NP00`000003ZKgX0000000000:Y_NP2
00001:Vmj0800002ZKgX0P0000<0>;d00`0008M;PHM;P@02Qd^10`000003Se1o0000000000D00003
ZKgX0`000003ZKgX0000000000:Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX
00<000000jVmj00000000002ZKgX0P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000005ZKgX
000000000000ZKgX0080003Qoooo003ooooofoooo`@000001JVmj000000000000:Vmj003000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00002ZKgX0P0000:Y_NP2000000>Y
_NP0002Y_NP00`000004ZKgX0000ZKgXZKgX0P0000<0>;d00`0008M;PHM;P@02Qd^10`000003Se1o
0000000000D000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003000000BY_NP00000
002Y_NP3000000BY_NP0000000000002ZKgX0P0000:Y_NP4000000>Y_NP0000000000ZVmj0800000
1JVmj000000000000:Vmj003000000>Y_NP00000000010000>3oool00?oooooIoooo10000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000>Y_NP2
000000BY_NP0000000000002ZKgX0`000003ZKgX0000000000<00002ZKgX00D00000>;d0>;d0>;d0
000018M;P@<000000hm@O`0000000006000000BY_NP00000002Y_NP3000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`0000>Y_NP3000000>Y_NP0000000000ZVmj0<000000jVmj000
00000004000000FY_NP000000000002Y_NP00`000003ZKgX0000000000:Y_NP00`000?ooooooo`3N
oooo003oooooe_ooo`@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`00
00:Y_NP200000ZVmj08000000jVmj0000:Vmj00200000ZVmj08000001JVmj000000000000:Vmj003
000000>Y_NP0000000000P0000:Y_NP01@00000h_@0h_@0h_@000004Qd^10`000003Se1o00000000
00L000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj00600000ZVmj0050000ZKgX0000
0000ZKgX00<000000jVmj00000000005000000BY_NP00000002Y_NP3000000FY_NP000000000002Y
_NP00`0000:Y_NP2000000>Y_NP0003oool0g_ooo`00ooooomCoool3000000FY_NP000000000002Y
_NP00`000003ZKgX0000000000:Y_NP200000jVmj08000001:Vmj0000000000000:Y_NP3000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00<000000jVmj00000000002000000>Y_NP00000
00000P0h_@030000Qd^1Qd^100:7Bh43000000>?D7l0000000002`000005ZKgX000000000000ZKgX
00<000000jVmj00000000004ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX
00<000001:Vmj00000000:Vmj0<000001jVmj000000000000:Vmj0000:Vmj00200000ZVmj0<0003N
oooo003ooooodOooo`<000001JVmj000000000000:Vmj00300000ZVmj0800002ZKgX0P000003ZKgX
0000ZKgX00800002ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<00000
1:Vmj0000000000000:Y_NP200000ZVmj08000000jVmj0000000000203Rm00<00027Bh67Bh400XM;
P@<000000hm@O`0000000008000000BY_NP0000000000002ZKgX0P0000:Y_NP2000000>Y_NP0002Y
_NP00`000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP00000
0000100000:Y_NP200000jVmj0<000001JVmj000000000000:Vmj0020000g_ooo`00ooooolkoool4
000000>Y_NP0000000000ZVmj0800003ZKgX0`000003ZKgX0000000000:Y_NP3000000>Y_NP00000
000010000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000>Y_NP2000000>Y
_NP0000000001P000080>;d00`0008M;PHM;P@02Qd^100@0003n_W00002?D7l;00000jVmj0800000
1:Vmj0000000000000:Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX
00<000000jVmj00000000003ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj003
000000>Y_NP000000000gOooo`00ooooolcoool3000000BY_NP0000000000002ZKgX0P000003ZKgX
0000ZKgX008000001JVmj000000000000:Vmj003000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00<00002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP2000000>Y
_NP00000000010000080>;d00`0008M;PHM;P@02Qd^10P0000:?D7l;000000>Y_NP0000000000ZVm
j08000001JVmj000000000000:Vmj003000000>Y_NP00000000010000004ZKgX0000000000000ZVm
j0<000001ZVmj00000000:Vmj0000:Vmj0800002ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX
0000000000@0003Loooo003ooooobOooo`<000001jVmj000000000000:Vmj0000:Vmj00200000ZVm
j0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3
00000jVmj08000001:Vmj0000000000000:Y_NP3000000>Y_NP00000000010000003ZKgX00000000
00<0000303Rm00@00027Bh67Bh67Bh4200000Xm@O``000000jVmj00000000004000000FY_NP00000
0000002Y_NP00`000003ZKgX0000000000:Y_NP200000jVmj08000001:Vmj0000000000000:Y_NP3
000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00800002ZKgX00<0003ooooo
ool0f_ooo`00ooooolOoool200000ZVmj0800003ZKgX0`000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj00600000ZVmj0040000ZKgX000000000ZVm
j08000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0000000000P00
00<0>;d00`0008M;PHM;P@0300000Xm@O`d000001:Vmj00000000:Vmj0<000001:Vmj00000000000
00:Y_NP200000ZVmj08000000jVmj0000:Vmj00200000ZVmj08000001JVmj000000000000:Vmj003
000000>Y_NP00000000010000004ZKgX0000000000000ZVmj0800002ZKgX0P000003ZKgX0000oooo
0=[oool00?ooooo4oooo0`0000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX
00<000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX00000000
00BY_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vm
j0@000000m5W00000000000303Rm00<00027Bh67Bh400`0000:?D7l>000000>Y_NP0000000000ZVm
j0800003ZKgX0`000003ZKgX0000000000:Y_NP3000000>Y_NP00000000020000005ZKgX00000000
0000ZKgX00800002ZKgX0P0000>Y_NP3000000>Y_NP0000000000ZVmj0<0003Joooo003ooooo`_oo
o`L00002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00<000000jVmj000
00000002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00`000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj003000000>Y_NP000000000100000:Y_NP00`000:Vmj000000300000P0h
_@030000Qd^1Qd^100<00002Se1o3`0000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX00000000
0000ZKgX00<000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`0000:Y_NP2
00000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX00000000
0=[oool00?oooonooooo10000005ZKgX000000000000ZKgX00<000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00`0000:Y_NP200000ZVmj08000001:Vmj0000000000000:Y_NP3
000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX
00800004ZKgX1`000080>;d00`0008M;PHM;P@0300000Xm@O`h000000jVmj00000000002ZKgX0`00
0004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00H000001:Vmj0000000000000>Y_NP3
000000>Y_NP0000000000ZVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj002
0000fOooo`00oooookgoool4000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP00`00
0003ZKgX0000000000:Y_NP200000jVmj0<000000jVmj00000000002ZKgX0P0000:Y_NP2000000FY
_NP000000000002Y_NP00`000003ZKgX0000000000@00002ZKgX0P0000:Y_NP2000000>Y_NP0002Y
_NP00`000005ZKgX000000000000dFL00080000203Rm00<00027Bh67Bh400`0000:?D7l?000000FY
_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000
000000000:Vmj002000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP00`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000@0003Hoooo003ooooo^_ooo`@000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00`0000:Y_NP200000ZVmj08000000jVmj0000:Vmj002
000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj003000000>Y_NP0000000000jVmj08000001:Vmj0000000000000:Y_NP3000000FY_NP00000
0000002Y_NP00P000003dFL0000000000080>;d00`0008M;PHM;P@0300000Xm@Oa0000001JVmj000
000000000:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP200001:Vmj0<000001:Vmj000
00000:Vmj0<000001JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP0
0`000?ooooooo`3Foooo003ooooo]oooo`@000001JVmj000000000000:Vmj003000000BY_NP00000
002Y_NP300000jVmj0<000000jVmj00000000002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX
000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P00
00:Y_NP200000ZVmj08000001JVmj000000000000:Vmj003000000>Y_NP0000000000P000080>;d0
0`0008M;PHM;P@0300000Xm@Oa4000000jVmj00000000004000000BY_NP0000000000002ZKgX0P00
00:Y_NP2000000>Y_NP0002Y_NP02P000005ZKgX000000000000ZKgX00H000001:Vmj00000000000
00:Y_NP200000jVmj0<0003Goooo003ooooo]Oooo`<000001JVmj000000000000:Vmj003000000FY
_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00<00002ZKgX0P000004ZKgX
0000000000000ZVmj0<000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000FY
_NP000000000002Y_NP00`000080>;d00`0008M;PHM;P@0300000Xm@Oa8000000jVmj00000000002
ZKgX0P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000003ZKgX0000000000@000001JVmj000
000000000:Vmj003000000>Y_NP0000000000ZVmj0800003ZKgX0`000005ZKgX000000000000ZKgX
00<0003Foooo003ooooo/_ooo`@000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP2
00000jVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003000000BY_NP00000
002Y_NP3000000NY_NP000000000002Y_NP0002Y_NP00P0000:Y_NP200000ZVmj08000001JVmj000
000000000:Vmj003000000>Y_NP00000000010000004ZKgX0000000000000ZVmj0H00000100h_@00
08M;PHM;P@800003Se1o4`0000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP2000000FY_NP00000
0000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX0000000000000ZVmj0800002ZKgX0P00
0003ZKgX0000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP000000000e_ooo`00oooo
ok3oool3000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<000001JVmj00000000000
0:Vmj003000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP01P0000:Y_NP200000jVm
j0<000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0004ZKgX0000000000000ZVmj0<00002ZKgX00H0003AI`0000000000>;d00002Qd^10P0000>?D7lE
00000ZVmj0<000000jVmj00000000004000000FY_NP000000000002Y_NP00`000003ZKgX00000000
00:Y_NP200000jVmj0<000000jVmj00000000002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX
000000000000ZKgX0080003Eoooo003ooooo[Oooo`<000001:Vmj0000000000000:Y_NP200000ZVm
j08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj003000000>Y_NP0000000000jVmj08000000jVmj0000:Vmj002
000000FY_NP000000000002Y_NP00`000003ZKgX0000000000@000001JVmj000000000000:Vmj002
00000ZVmj0800004ZKgX0P0000:Y_NP6000000@0>;d00027Bh67Bh4200000hm@Oa00000019MIP`00
00000:Vmj0<000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX
00000000008000001ZVmj00000000:Vmj0000:Vmj08000001JVmj000000000000:Vmj003000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj0000000003Doooo003o
ooooZoooo`800002ZKgX0P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000004ZKgX00000000
ZKgX0`000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000:Y_NP2000000>Y
_NP0002Y_NP00P0000:Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000004ZKgX
0000000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00<000000jVmj00000000007000000@0
>;d00027Bh67Bh4200000hm@O`8000000njSM@000000000;000000FGFH<000000000002Y_NP00`00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP0002Y_NP00P00
00:Y_NP3000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP01P000004ZKgX00000000
00000ZVmj08000000jVmj0000?ooo`3Coooo003oooooZ?ooo`<00002ZKgX0P000003ZKgX0000ZKgX
00800002ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<000001JVmj000
000000000:Vmj00300000ZVmj08000001:Vmj0000000000000:Y_NP3000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP200000jVmj08000001:Vmj000
0000000000:Y_NP3000000>Y_NP00000000010000003ZKgX0000000000<000000`0h_@0008M;P@03
00000hm@O`8000000njSM@000000000;000000>GFH<0000000000P000005ZKgX000000000000ZKgX
00H00002ZKgX0P0000>Y_NP7000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00H000001:Vmj0000000000000:Y_NP300000ZVmj0<0003Coooo003oooooYOooo`<00002ZKgX0`00
00:Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vm
j0<000001jVmj000000000000:Vmj0000:Vmj00200000ZVmj0800002ZKgX0P000005ZKgX00000000
0000ZKgX00<000000jVmj00000000004000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX
00800002ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00@000000`0h_@0008M;P@0300000hm@O`@000000k5[P@0000000009000000>GFH<0000000000`00
0005ZKgX000000000000ZKgX00800003ZKgX0P000003ZKgX0000ZKgX008000001JVmj00000000000
0:Vmj003000000>Y_NP00000000010000005ZKgX000000000000ZKgX00800002ZKgX0P0000BY_NP2
000000FY_NP000000000002Y_NP00`000=;oool00?oooonSoooo0`0000>Y_NP200000ZVmj0800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX
00800002ZKgX0P0000>Y_NP3000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000@000001:Vmj0000000000000:Y_NP300000ZVmj0<000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000`0h_@00
08M;P@0300000hm@O`@000000k5[P@0000000009000000>GFH<000000000100000:Y_NP2000000>Y
_NP0002Y_NP00P0000:Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000004ZKgX
0000000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00H000001JVmj000000000000:Vmj002
0000d_ooo`00oooooj3oool3000000>Y_NP0002Y_NP00`000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`0000:Y_NP200000ZVmj0800000
0jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj00200000ZVmj0800004ZKgX0P0000:Y_NP2000000FY_NP000000000002Y
_NP01P000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX00D0002Y_NP00000001=
:8<00P000004Qd^10000000000000hm@O`@000000k5[P@0000000009000000>GFH<0000000001P00
00:Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00800002ZKgX0P00
00>Y_NP3000000>Y_NP0000000000ZVmj0<000001:Vmj00000000:Vmj0<000001JVmj00000000000
0:Vmj0020000dOooo`00oooooikoool300000ZVmj0<000001JVmj000000000000:Vmj006000000FY
_NP000000000002Y_NP00P0000:Y_NP200000jVmj08000001:Vmj0000000000000:Y_NP3000000BY
_NP00000002Y_NP3000000FY_NP000000000002Y_NP01P0000:Y_NP200000ZVmj08000000jVmj000
0:Vmj003000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj00300000ZVmj0800003ZKgX1@000004CBR300000000Qd^10`0000>?D7l4000000>aJh400000
00002@000003UeV30000000000@00002ZKgX0P000005ZKgX000000000000ZKgX00H000000jVmj000
0000000500000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP0003oool0d?ooo`00oooo
oi_oool400000ZVmj08000001JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00`00
00:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP2000000FY_NP000000000002Y_NP00`000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00800003ZKgX0P000004ZKgX0000000000000ZVm
j0<000000jVmj00000000004000000FY_NP000000000002Y_NP00`000003ZKgX0000000000:Y_NP2
00000jVmj0<000001JVmj000000000000:Vmj007000000B7Bh40000000000003Se1o10000003/F^1
0000000000T000000iMIP`0000000009000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00D000000jVmj00000000002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX00000000
0000ZKgX00H000001:Vmj0000000000000:Y_NP2000000>Y_NP0003oool0coooo`00oooooiWoool4
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj00300000ZVmj0<00002ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj003
000000BY_NP00000002Y_NP300000ZVmj08000000jVmj0000:Vmj00200000ZVmj0800002ZKgX0P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00300000ZVmj0800002ZKgX0P00
0003ZKgX0000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP00000000010000003Qd^1
0000000000B?D7l4000000>aJh40000000002@000003UeV30000000000H000001JVmj00000000000
0:Vmj00600000ZVmj0800003ZKgX0`000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vm
j0<000000jVmj00000000004000000BY_NP0000000000002ZKgX0`0000:Y_NP30000coooo`00oooo
oiKoool4000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP200001:Vmj0800002ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj003000000>Y_NP000000000100000:Y_NP300000ZVmj0<000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000jVmj08000001:Vmj00000000000
00:Y_NP3000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP01@000003Qd^100000000
00B?D7l4000000>aJh40000000002@000003UeV30000000000L000001JVmj000000000000:Vmj002
00000jVmj08000000jVmj0000:Vmj006000000FY_NP000000000002Y_NP01P000005ZKgX00000000
0000ZKgX00800002ZKgX0P0000BY_NP2000000FY_NP000000000002Y_NP00P000<ooool00?oooonD
oooo0`000005ZKgX000000000000ZKgX00<000000jVmj0000000000400000ZVmj0800002ZKgX0P00
0003ZKgX0000ZKgX00<000000jVmj00000000004000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00<000000jVmj00000000004ZKgX0P0000:Y_NP2000000FY_NP000000000002Y
_NP01P000005ZKgX000000000000ZKgX00<000000jVmj00000000002ZKgX00@0002Y_NP000000002
ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<000000jVmj00000000006
000000>7Bh400000000018m@O`@000000k5[P@000000000:000000>]J8<0000000001`0000:Y_NP2
000000>Y_NP0002Y_NP00P0000:Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0004ZKgX0000000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00H000001JVmj00000000000
0:Vmj0020000c_ooo`00oooooi7oool4000000BY_NP00000002Y_NP3000000FY_NP000000000002Y
_NP00P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000003ZKgX0000000000@000001JVmj000
000000000:Vmj003000000>Y_NP0000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00<00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00<00002ZKgX0P0000>Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000100h_@000000000000B?D7l4000000>a
Jh40000000002P000003[FR30000000000T00002ZKgX0`000005ZKgX000000000000ZKgX00H00000
1JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000003ZKgX0000000000:Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP00000000010000<goool00?oooon?oooo0`000005ZKgX
000000000000ZKgX008000001:Vmj0000000000000:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP2
00000ZVmj08000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`000004ZKgX
0000000000000ZVmj08000001:Vmj0000000000000:Y_NP3000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP200000jVmj08000000jVmj0000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj00000000004
00000ZVmj0800002ZKgX0`000003CBR30000000000800004Se1o10000003/F^10000000000X00000
0jeXP`000000000700000ZVmj08000001JVmj000000000000:Vmj006000000FY_NP000000000002Y
_NP01P0000:Y_NP01@000:Vmj00000000:Vmj003000000FY_NP000000000002Y_NP01P000005ZKgX
000000000000ZKgX008000000jVmj0000000003=oooo003oooooS?ooo`<000001JVmj00000000000
0:Vmj003000000>Y_NP0000000000ZVmj0<00002ZKgX0`000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP300000ZVm
j0800002ZKgX0P000005ZKgX000000000000ZKgX00<000000jVmj00000000004000000BY_NP00000
00000002ZKgX0P000003ZKgX0000ZKgX00800002ZKgX1P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj003000000>Y_NP0000000000jVmj08000001JVmj000000000000:Vmj002
000000==:8<0000000000P0000B?D7l4000000>aJh40000000002P000003[FR30000000000`00000
1JVmj000000000000:Vmj002000000>Y_NP0000000001@000003ZKgX0000000000BY_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H00002ZKgX00<0
003oooooool0b_ooo`00ooooohWoool3000000FY_NP000000000002Y_NP00`0000:Y_NP200000jVm
j0800002ZKgX0P000005ZKgX000000000000ZKgX00<000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P0000:Y_NP200001:Vmj08000001JVmj000000000000:Vmj003000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000004ZKgX0000000000000ZVmj0<00002ZKgX0`00
0003ZKgX0000000000@000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP300000ZVm
j08000000jVmj0000:Vmj00200000ZVmj08000000jVmj00000000002000000==:8<0000000000P00
00B?D7l4000000>aJh40000000002P000003[FR30000000000T000001JVmj000000000000:Vmj003
000000>Y_NP0000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00<000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj000
00000004ZKgX0`000<_oool00?oooon7oooo0`000003ZKgX0000000000:Y_NP200000jVmj0800000
0jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00000
0jVmj0000000000400000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00H000001JVmj00000000000
0:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0800004ZKgX0P0000:Y_NP2
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj00000000004
00000ZVmj0<00002ZKgX0`000003ZKgX0000000000@000001JVmj0000000000004dXP`04000018m@
O`@000000k5[P@000000000:000000>]J8<0000000002P000005ZKgX000000000000ZKgX00<00002
ZKgX0P000004ZKgX0000000000000ZVmj0<000001JVmj000000000000:Vmj006000000FY_NP00000
0000002Y_NP00P0000:Y_NP200000ZVmj08000000jVmj0000:Vmj003000000>Y_NP000000000booo
o`00ooooohCoool3000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00800002ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@00003ZKgX0P00
0004ZKgX0000000000000ZVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003
000000>Y_NP0000000000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00<000000jVmj00000000004
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj00000000004
ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00L00004
Se1o10000003/F^10000000000X000000jeXP`000000000;000000NY_NP000000000002Y_NP0002Y
_NP00P0000:Y_NP200000ZVmj08000001JVmj000000000000:Vmj006000000FY_NP000000000002Y
_NP00`0000:Y_NP2000000BY_NP0000000000002ZKgX0`000005ZKgX000000000000ZKgX0080003:
oooo003oooooP_ooo`<000000jVmj00000000002ZKgX0`0000:Y_NP3000000FY_NP000000000002Y
_NP01P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0040000
ZKgX000000000ZVmj0800002ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj003000000BY_NP0000000000002ZKgX0P000004ZKgX0000000000000ZVmj0<000000jVmj000
00000004000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`0000:Y_NP2000000>Y
_NP0002Y_NP00`000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000>Y_NP00000
00000P000006lILa000000000000CBR3000018m@O`@000000k5[P@000000000:000000>]J8<00000
00002@000003ZKgX0000000000>Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP0002Y_NP00P0000:Y_NP200000ZVm
j08000001JVmj000000000000:Vmj0060000bOooo`00ooooodWoool200001?ooo`030000oooooooo
02goool300000ZVmj0800003ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP01P000005ZKgX
000000000000ZKgX00<000000jVmj00000000002ZKgX0P0000>Y_NP3000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX000000000000ZKgX
0000ZKgX00800002ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00<000000jVmj0000000000400000ZVmj0<00002ZKgX0`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj003000000BY_NP00000002Y_NP5000000A=:8<0001=:8<00004Se1o1000
0003/F^10000000000X000000jeXP`000000000:000000>Y_NP0002Y_NP00P000005ZKgX00000000
0000ZKgX00H000001JVmj000000000000:Vmj00600000ZVmj0800003ZKgX0`000005ZKgX00000000
0000ZKgX00H000001JVmj000000000000:Vmj002000000>Y_NP000000000bOooo`00ooooodWoool0
0`000?ooo`000002oooo00<0003oool00000:oooo`<00003ZKgX0`000005ZKgX000000000000ZKgX
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP2
00000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX00000000
00@000001JVmj000000000000:Vmj00200000ZVmj0800003ZKgX0`000005ZKgX000000000000ZKgX
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj002
00001:Vmj0800002ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003
000000>Y_NP000000000100000:Y_NP3000000A=:8<0001=:8<00004Se1o10000003/F^100000000
00X000000jeXP`0000000009000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00H000000jVmj0000000000400000jVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y
_NP01P000005ZKgX000000000000ZKgX00H00002ZKgX00<0003oooooool0a_ooo`00ooooodWoool0
0`000?ooo`000002oooo00<0003oool00000:Oooo`<000000jVmj0000:Vmj002000000FY_NP00000
0000002Y_NP00`000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000003ZKgX0P000004ZKgX0000000000000ZVmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000004000000BY_NP0000000000002ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P00
0005ZKgX000000000000ZKgX00<000000jVmj00000000004000000FY_NP000000000002Y_NP00P00
00:Y_NP200000ZVmj08000000jVmj0000:Vmj003000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP0000000001:Vmj0@00000
14dXP`0004dXP`0000B?D7l4000000>aJh40000000002P000003[FR30000000000X000000jVmj000
00000004000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX00@0
002Y_NP000000002ZKgX1P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj006
00000jVmj08000000jVmj0000?ooo`36oooo003oooooBOooo`800003oooo00<0003oool000009ooo
o`800003ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00<000001:Vmj000
00000:Vmj0<000000jVmj00000000002ZKgX00@0002Y_NP000000002ZKgX0P000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0P000004ZKgX
0000000000000ZVmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000FY_NP00000
0000002Y_NP00`0000:Y_NP2000000BY_NP0000000000002ZKgX0`000005ZKgX000000000000ZKgX
00H000001JVmj000000000000:Vmj00200000ZVmj0800002ZKgX0P000003ZKgX0000ZKgX00<00000
2:Vmj0000000000004dXP`0004dXP`0000B?D7l4000000>aJh40000000002P000003[FR300000000
00h000001JVmj000000000000:Vmj00600000ZVmj0800003ZKgX0`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP010000:Vmj0000000
00:Y_NP20000aoooo`00ooooodWoool00`000?ooooooo`02oooo00<0003oool000009?ooo`<00000
0jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00000
1JVmj000000000000:Vmj00200000ZVmj0800003ZKgX0`000003ZKgX0000000000@000001JVmj000
000000000:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0040000ZKgX0000
00000ZVmj08000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP0000000000002ZKgX0`0000:Y_NP200000ZVmj08000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00`0000:Y_NP2000000BY_NP0000000000002ZKgX0`00
0005ZKgX000000000000ZKgX00800003CBR300<0002?D7n?D7l00Xm@O`@000000k5[P@000000000:
000000>]J8<0000000002`000005ZKgX000000000000ZKgX00<000001ZVmj00000000:Vmj0000:Vm
j08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00H000001:Vmj0000000000000:Y_NP200000jVmj0<000000jVmj000000000040000a_ooo`00oooo
od[oool200000oooo`030000oooooooo023oool400000ZVmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj00300000ZVmj08000000jVmj0000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000001JVmj00000000000
0:Vmj00200000ZVmj0800003ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj003
000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0800004ZKgX0P000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000000
00:Y_NP300000ZVmj0800002ZKgX0P000005ZKgX000000000000ZKgX00D00003CBR300<0002?D7n?
D7l00Xm@O`@000000k5[P@000000000:000000>]J8<0000000002@000004ZKgX00000000ZKgX0`00
00:Y_NP2000000>Y_NP0002Y_NP00P0000:Y_NP6000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001:Vmj0000000000000>Y_NP3000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`000<Goool00?oooom`oooo10000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001jVmj000000000000:Vmj0000:Vmj002
00000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj00000000000
0:Vmj00300000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00<000000jVmj00000000004000000BY_NP0000000000002ZKgX0P000003ZKgX
0000ZKgX00H000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0800004ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002000014dXP`040000Se1oSe1oSe1o10000003/F^10000000000X000000jeXP`00
0>fRM`0=00000ZVmj0<00002ZKgX2P000005ZKgX000000000000ZKgX00H000001JVmj00000000000
0:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00<000001JVmj000000000000:Vmj006000000>Y
_NP000000000aOooo`00ooooofgoool4000000FY_NP000000000002Y_NP00`000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0800003ZKgX0`000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001jVmj00000000000
0:Vmj0000:Vmj00200000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000004000000BY_NP0000000000002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3
000000FY_NP000000000002Y_NP01P000004ZKgX0000000000000ZVmj08000000jVmj0000:Vmj006
000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00<00004CBR300@0002?D7n?
D7n?D7l4000000>aJh40000000002P000003[FR30000kJ9g00X00004ZKgX0P0000:Y_NP2000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00H000001:Vmj0000000000000:Y_NP200000jVm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000FY_NP000000000002Y_NP00P00
0<Coool00?oooom[oooo10000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00H00002
ZKgX0P0000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX00<000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<000001JVmj000
000000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0800004ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00H000001:Vmj0000000000000:Y_NP300000ZVmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000004000000FY_NP000000000002Y_NP00`0000:Y_NP200000ddXP`040000Se1oSe1o
Se1o10000003/F^10000000000X000000jeXP`000>fRM`08000000>Y_NP0002Y_NP00`0000:7D8L5
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX0P0000>Y_NP3
000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0005ZKgX000000000000ZKgX00800033oooo003oooooJ?ooo`@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP01P0000>Y_NP2000000BY_NP0000000000002ZKgX0`000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00H000001:Vmj0000000000000:Y_NP2000000>Y
_NP0002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj00000000004000000FY_NP00000
0000002Y_NP00P0000:Y_NP200000ZVmj08000000jVmj0000:Vmj003000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0800004ZKgX0P00
0005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1jVmj000000000000:Vmj0000:Vmj00400000ddXP`040000Se1oSe1oSe1o10000003/F^100000000
00X000000jeXP`000>fRM`0;00001HM@Q`8000001JVmj000000000000:Vmj006000000BY_NP00000
00000002ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP00000
000010000005ZKgX000000000000ZKgX008000001:Vmj0000000000000:Y_NP2000000>Y_NP0003o
ool0`_ooo`00ooooofKoool4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP0000000000ZVmj0040000ZKgX000000000ZVmj0800002ZKgX0P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj006000000BY_NP0000000000002ZKgX0`0000:Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<00002ZKgX0P00
0004ZKgX0000000000000ZVmj0<000000jVmj00000000004000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`0000:Y_NP2000000>Y_NP0002Y_NP01P000005ZKgX000000000000ZKgX
00<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX0P0000>Y_NP3000000BY_NP00000
00000003CBR300@0002?D7n?D7n?D7l4000000>aJh40000000002P000003[FR30000kJ9g00P00000
0jVmj00008M@Q`05Qe270`000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP300000ZVm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000FY_NP000000000002Y_NP01P00
00:Y_NP300000ZVmj0<00032oooo003oooooHoooo`@000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<000001JVmj000000000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0800004ZKgX0P00
00:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj00300000ZVmj0<00002ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00<000000jVmj0000000000400000ZVmj0<00002ZKgX0`000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00H000001:Vmj0000000000000:Y_NP2000000>Y
_NP0002Y_NP00P000005ZKgX000000000000ZKgX00800003CBR300@0002?D7n?D7n?D7l4000000>a
Jh40000000002P000003[FR30000kJ9g008000000n6FO00000000003000000>Y_NP00027D8L018M@
Q`D000001:Vmj00000000:Vmj0<00004ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj00200001:Vmj0800002
ZKgX0P000004ZKgX000000000000`Oooo`00ooooof7oool3000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`0000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX
00<000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX00000000
00000ZVmj08000000jVmj0000:Vmj003000000>Y_NP00000000010000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00200000ZVmj0800004ZKgX0P000005ZKgX000000000000ZKgX
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj002
00001:Vmj0800002ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj006
000000BY_NP0000000000002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP500000ddXP`040000
Se1oSe1oSe1o10000003/F^10000000000X000000jeXP`000>fRM`02000000?QUW`0000000000`00
0003ZKgX0000Qe2700B7D8L2000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00H00000
1JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVm
j08000000jVmj0000:Vmj003000000>Y_NP00000000010000003ZKgX000000000<7oool00?oooomN
oooo0`000005ZKgX000000000000ZKgX00<000001JVmj000000000000:Vmj00200000ZVmj0<00002
ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00H000001JVmj00000000000
0:Vmj00200000ZVmj0<00002ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj003
000000BY_NP00000002Y_NP300000ZVmj08000000jVmj0000:Vmj006000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP2000000>Y_NP0002Y
_NP00`000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P0000:Y_NP200001:Vmj08000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP4
00000ddXP`040000Se1oSe1oSe1o10000003/F^10000000000X000000jeXP`000>fRM`02000000?Q
UW`0000000000`000003ZKgX0000Qe2700B7D8L300000ZVmj0<000000jVmj00000000002000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H00002ZKgX0`00
00:Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@00030oooo003oooooFoooo`@00000
1:Vmj00000000:Vmj0<000001:Vmj0000000000000:Y_NP200000jVmj0800002ZKgX0P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj003000000BCKJD00000002Y_NP300000ZVm
j0800003ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00<000000jVmj0000000000400000ZVmj0<00002ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX
000000000000ZKgX00H000001JVmj000000000000:Vmj00200000ZVmj0<00002ZKgX0`000003ZKgX
0000000000@000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP300000ZVmj0800000
0jVmj0000:Vmj006000000FY_NP000000000002Y_NP01P000004ZKgX0000000000000ddXP`040000
Se1oSe1oSe1o10000003/F^10000000000X000000jeXP`000>fRM`02000000?QUW`0000000000`00
0003ZKgX0000Qe2700B7D8L010000:Vmj:Vmj:Vmj08000001JVmj000000000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP00P0000BY_NP2
000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P00
0<3oool00?oooomIoooo0`000005ZKgX000000000000ZKgX008000001:Vmj0000000000000>Y_NP3
000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>CKJD400000jVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj003000000>Y_NP0000000001:Vmj0800002
ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj006000000BY_NP00000
00000002ZKgX0P0000>Y_NP200000ZVmj08000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00`000003ZKgX0000000000@00002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000005ZKgX000000000000ZKgX00800003CBR300@0002?D7n?D7n?D7l4
000000>aJh40000000002@0000:]J8<01@000>fRM`0000000>6FO00500000ZVmj0030000Qe27Qe27
00:7D8L7000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX008000001:Vmj000
0000000000:Y_NP2000000>Y_NP0002Y_NP01P000005ZKgX000000000000ZKgX00H000001JVmj000
000000000:Vmj00200000ZVmj0030000oooooooo0;goool00?oooomFoooo10000004ZKgX00000000
ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000005ZKgX00000000ZKgX000000>CKJD200000ZVmj0040000
ZKgX000000000ZVmj0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0004ZKgX0000000000000ZVmj08000000jVmj0000:Vmj003000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000003
ZKgX0`000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001JVmj000000000000:Vmj00200001:Vmj0800002ZKgX0P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX0000CBR3
009=:8<0100008m@Ohm@Ohm@O`@000000k5[P@000000000900000ZeXP`050000kJ9g00000000hIIl
00D00002ZKgX00@00027D8N7D8N7D8L2000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX00H00002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00<00002ZKgX0P000003ZKgX0000oooo0;goool0
0?oooomDoooo0`000005ZKgX000000000000ZKgX00800002ZKgX0P0000>Y_NP3000000BY_NP00000
002Y_NP3000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`0000>Y_NP0100009=]
YI=]Y@0000>Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00<000001:Vmj000
00000:Vmj0<000000jVmj00000000002ZKgX0`0000:Y_NP3000000FY_NP000000000002Y_NP01P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0050000ZKgX0000
0000ZKgX00<000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP300000ZVmj08000000jVmj0000:Vmj003000000>Y_NP00000000010000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000002ZKgX0`0000==:8<0
100008m@Ohm@Ohm@O`@000001K5[P@00000000000<9iO`0700000ZeXP`050000kJ9g00000000hIIl
008000000k=]P@0000000002ZKgX00@00027D8N7D8N7D8L3000000BY_NP00000002Y_NP6000000FY
_NP000000000002Y_NP00`000003ZKgX0000000000BY_NP2000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX000000000000ZKgX0000ZKgX
00800002ZKgX0P000;koool00?oooomAoooo0`000005ZKgX000000000000ZKgX00<00002ZKgX0P00
0003ZKgX0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`00
0003ZKgX0000000000@000001:Vmj0000000000000>Y_NP0100009=]Y@000:Vmj08000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00`000003ZKgX0000000000@00002ZKgX0P00
00>Y_NP200000ZVmj08000001JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00`00
0003ZKgX0000000000:Y_NP200000jVmj0<000001:Vmj00000000:Vmj0<000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP300000ZVmj0<000000jVmj00000000004
000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00800002ZKgX0`0000:Y_NP2
00000TdXP`040000Se1oSe1oSe1o10000005/F^1000000000000`WUo00L00002[FR300D0003]XWL0
0000003QUW`00P000003/ff10000000000:Y_NP0100008M@QhM@QhM@Q`L000001JVmj00000000000
0:Vmj002000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00H000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<000001JVmj00000000000
0:Vmj0020000_Oooo`00ooooodooool2000000FY_NP000000000002Y_NP00`000003ZKgX00000000
00800002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00@000001:Vmj0000000000000:Y_NP3000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@00003ZKgX0P000003ZKgX0000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00<000001:Vmj0000000000000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00`0000>Y_NP200000ZVm
j08000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP01P000004ZKgX00000000
00000ZVmj0800003ZKgX0P0000:Y_NP400000TdXP`040000Se1oSe1oSe1o10000005/F^100000000
0000`WUo00L00002[FR300D0003]XWL00000003QUW`00P000003/ff10000000000:Y_NP0100008M@
QhM@QhM@Q`@000001:Vmj0000000000000:8DHT500000ZVmj0<00002ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj00300000ZVmj08000000jVmj000
0:Vmj002000000FY_NP000000000002Y_NP01P000;coool00?oooom<oooo0`000004ZKgX00000000
ZKgX0`0000BY_NP200000ZVmj08000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX00800002ZKgX0P0000BY_NP200000ZVmj08000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002
ZKgX00@0002Y_NP000000002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000007ZKgX000000000000ZKgX0000ZKgX00800002ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX00000000
0000ZKgX0000ZKgX00<000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001:Vmj0000000000000>Y_NP3000000FY_NP000000000002Y
_NP00`000004ZKgX0000000000000TdXP`030000Se1oSe1o00D000001K5[P@00000000000<9iO`07
00000ZeXP`050000kJ9g00000000hIIl008000000k=]P@0000000002ZKgX00D00027D8N7D8L00037
R8l0100000F8DHT200001:Vmj08000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000NY_NP000000000002Y_NP0002Y_NP00P0000:Y_NP6000000FY
_NP000000000002Y_NP00P000003ZKgX000000000;coool00?oooom:oooo0P000005ZKgX00000000
0000ZKgX00800002ZKgX00<0002Y_NP000000P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0800000
0jVmj0000:Vmj003000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000005ZKgX000000000000ZKgX
00H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVm
j0<000001JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00800002ZKgX0P0000>Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00<00000
1JVmj000000000000:Vmj00600000TdXP`030000Se1oSe1o00D000001K5[P@00000000000<9iO`07
00000ZeXP`050000kJ9g00000000hIIl008000000k=]P@0000000002ZKgX00<00027D8N7D8L00`00
0003ZKgX0000R56900F8DHT2000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H00000
1JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj006000000>Y_NP000000000^oooo`00ooooodOoool3000000>Y_NP00000
00000ZVmj0800003ZKgX0`000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P0000:Y_NP300000ZVmj0<000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP00P0000:=H9P2000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000000jVmj00000000004000000FY_NP000000000002Y_NP00`000004ZKgX00000000
ZKgX0`0000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX00H000001JVmj000
000000000:Vmj003000000BY_NP00000002Y_NP300000ZVmj08000000jVmj0000:Vmj002000000FY
_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00H00002ZKgX0P0000>Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX00000000009=:8<00`0008m@Ohm@O`05
000000FaJh40000000000032NGl01`0000:]J8<01@000>fRM`0000000>6FO002000000JcKH400000
0000002Y_NP00002Qe270P0000:Y_NP00`0008QARHQAR@03R56910000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000@000001JVmj000000000000:Vmj00600000ZVmj0050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000FY_NP000000000002Y_NP00P00
0;[oool00?oooom4oooo0`000004ZKgX0000000000000ZVmj08000000jVmj0000:Vmj002000000FY
_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<00003
ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00<00003
SF2H00@0002OJI<000000003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0005ZKgX000000000000ZKgX00H00002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000FY_NP000000000002Y_NP01P0000:Y_NP300000ZVmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj0000000000400000jVmj08000000jBMc`00
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001ZVmj000
000000000:Vmj000009=:8<00`0008m@Ohm@O`05000000FaJh40000000000032NGl01`0000:]J8<0
1@000>fRM`0000000>6FO002000000JcKH4000000000002Y_NP00002Qe270P0000:Y_NP00`0008QA
RHQAR@03R5691@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX00000000
0000ZKgX00800004ZKgX1P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00`000003ZKgX0000oooo0;Woool00?oooom2oooo0`000003ZKgX
0000000000:Y_NP300000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1JVmj000000000000:Vmj003000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001ZVmj000000000000:Vmj00000>=H9P0
0`0009mYTimYT`02000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP000000000100000BY_NP200000ZVmj08000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj00000000004
ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj00200000ZVmj0040000ZKgX000000000ZBMc`H000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000800002CBR300<0002?D7n?
D7l01@000005/F^1000000000000`WUo00L00002[FR300D0003]XWL00000003QUW`00P000006/ff1
000000000000ZKgX00000XM@Q`800002ZKgX00<00028DHV8DHT00hQAR@T000001JVmj00000000000
0:Vmj002000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00H000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000jVmj0<0002ioooo003o
oooo?oooo`<00002ZKgX0P0000>Y_NP200000ZVmj08000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00002ZKgX0P0000>Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300001:Vmj0080000
SF2HSF2HSF2H0000WfVC0000o=RN0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00<000000jVmj00000000004000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj0000000000000>Y_NP3000000FT
WLl0000000000026CH@00P000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj002
00000ZVmj0800002CBR300<0002?D7n?D7l01@000005/F^1000000000000`WUo00L00002[FR300D0
003]XWL00000003QUW`00P000003/ff10000000000<0000018M@Q`000<N8S`0000:Y_NP00`0008QA
RHQAR@03R5691P000005ZKgX000000000000ZKgX00H00002ZKgX0`0000:Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H00002ZKgX00D0002Y_NP0
0000002Y_NP00`000;Soool00?oooolloooo0`0000>Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0004ZKgX0000000000000jVmj0<000001JVmj000000000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200001:Vmj0040000SF2HSF2H00000YmY
T`030000o=RN0000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX0P0000>Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00200000ZVmj0<00002ZKgX0`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj0000000
0:Vmj003000018I=Q0<000000jVmj00000000004000000FY_NP000000000002Y_NP00`0000:Y_NP2
000000FY_NP0001=:8==:8<000000Xm@O`D000001K5[P@00000000000<9iO`0700000ZeXP`050000
kJ9g00000000hIIl008000000k=]P@0000000003000000B7D8L00037R8l00003ZKgX00@00028DHV8
DHV8DHT4000000FY_NP000000000002Y_NP01P0000BY_NP200000ZVmj08000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000jVmj000
00000004ZKgX1P000003ZKgX000000000;Soool00?ooooljoooo0`000003ZKgX0000ZKgX00800002
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000FY_NP000000000002Y_NP00`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01`000:Vm
j:Vmj:Vmj00008ePV0000002WfVC00<0003lf9h000000Y=]Y0D000001JVmj000000000000:Vmj002
000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP01P000004ZKgX0000000000000jVmj0800002ZKgX0P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj006000000BY_NP0000000000002ZKgX0P00
00>Y_NP3000000FY_NP00000002K]n`000001HI=Q0@000001:Vmj00000000:Vmj0<000001jVmj000
000000000:Vmj0000:Vmj00200000ZVmj0800002CBR300<0002?D7n?D7l00P000004kZ=e00000000
/F^10`000003`WUo0000000000D00002[FR300D0003]XWL00000003QUW`00P000003/ff100000000
008000001JVmj00000000<N8S`000003ZKgX00@00028DHV8DHV8DHT2000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0030000ZKgX0000008000000jVmj00000000004000000>Y_NP00000
000010000005ZKgX000000000000ZKgX008000001:Vmj0000000000000:Y_NP2000000>Y_NP0002Y
_NP01P000005ZKgX000000000000ZKgX0080002goooo003ooooo=oooo`<00003ZKgX0`000005ZKgX
000000000000ZKgX00H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0@000000jVmj00000000003WfVC00@0
003lf9h0002CKJ@3000000FY_NP000000000002Y_NP01P0000:Y_NP300000ZVmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000BY_NP0000000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP0000000000002Vh6e0P0000>K]n`00`0008I=
Q8I=Q003QTf41@000004ZKgX00000000ZKgX0`0000>Y_NP3000000FY_NP000000000002Y_NP00P00
009=:8<01@0008m@O`0000000>jSM@02000000FaJh40000000000032NGl01`0000:]J8<01@000>fR
M`0000000>6FO002000000>cKH40000000001`0000>Y_NP0100008QARHQARHQAR@H00002ZKgX0P00
00>Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@000001JVmj000000000000:Vmj006
00000ZVmj0<00002ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@0002foooo003o
oooo=Oooo`<000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP01P000005ZKgX00000000
0000ZKgX00<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj003
00000ZVmj08000000jVmj0000:Vmj002000000BY_NP00000>;/0>;/300000imYT`8000000i=]Y000
0:Vmj003000000>Y_NP000000000100000BY_NP200000ZVmj08000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX0P0000BY_NP6
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00<00003Vh6e100000>K]n`00`0008I=Q8I=Q003
QTf40P000005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000003ZKgX
0000000000<00002CBR300D0002?D7l00000003^XgD00P000005/F^1000000000000`WUo00L00002
[FR300D0003]XWL00000003QUW`00P000003/ff10000000000L00003ZKgX00@00028DHV8DHV8DHT4
00000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj00600001:Vmj08000001JVmj000000000000:Vmj003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP20000]_ooo`00oooooc;oool300000jVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003
000000>Y_NP0000000000ZVmj0800003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX0000000000000ZVmj0<00002ZKgX0`000005ZKgX
00000000ZKgX00000080>;/01P0009mYTimYTimYT`000?cHWP@000001JVmj000000000000:Vmj002
00000ZVmj0030000ZKgX0000008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000001:Vmj0000000000000:Y_NP2000000>Y_NP0002Y
_NP01P000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj002000000BY_NP00000
00000003ZKgX0`000005ZKgX00000000ZKgX000000>KPKD3000000>Y_NP0002K]n`00Y^gk0030000
QTf4QTf400:6CH@01@000?ViO@0000000:Vmj00300000jVmj0<000001:Vmj00000000:Vmj0<00000
1JVmj00000000:Vmj0000002CBR300D0002?D7l00000003^XgD00P000005/F^1000000000000`WUo
00L00002[FR300D0003]XWL00000003QUW`00P000003/ff10000000000@000001<N8S`0006HiQP00
00:Y_NP0100008QARHQARHQAR@H00002ZKgX1P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP00`000:Vmj0000005000000FY
_NP000000000002Y_NP01P000003ZKgX0000000000@000000jVmj0000000002eoooo003ooooo<?oo
o`<000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj003000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX
008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001:Vmj0000000000000BY_NP2000000FY_NP000000000002Y_NP00`000004ZKgX
0000000000000P0h^`040000WfVCWfVCWfVC10000003ZKgX0000000000:Y_NP200000jVmj0<00000
1JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00800002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX
000000000000ZKgX00H00002ZKgX00D0002Y_NP00000002Y_NP00`0000BY_NP300001:Vmj0050000
VkO/VkO/VkO/000000B6CH@500000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vm
j0<000001:Vmj00000000000009=:8<01P0008m@O`0000000>jSM@0000:aJh43000000?2NGl00000
00001@0000:]J8<01@000>fRM`0000000>6FO002000000>cKH400000000010000004ahR?0000ISV6
00000ZVmj0050000R569R5690000]gV>00<000001JVmj0000000000008QAR002000000FY_NP00000
0000002Y_NP01P000003ZKgX0000000000@00002ZKgX0P0000>Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP00`000?oo
ooooo`2boooo003ooooo;_ooo`800003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX0000000000000ZVmj0<00002ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP00`000:Vmj0000005000000FY_NP000000000002Y_NP00`000006ZKgX00000000000003Rk
00000imYT`D00002ZKgX0P000003ZKgX0000ZKgX008000001JVmj000000000000:Vmj006000000FY
_NP000000000002Y_NP01P000004ZKgX0000000000000jVmj0800002ZKgX0P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP01P0000BY_NP3
000000BY_NP00000002Y_NP900001:Vmj0800002VkO/00<00026CHB6CH@00XI=Q0800004ZKgX1P00
0003ZKgX0000000000@000001JVmj000000000000:Vmj00200000TdXP`060000Se1o00000000kZ=e
00000[5[P@<000000l9iO`000000000500000ZeXP`8000000oR^J`000>6FO002000000>cKH400000
000010000004ahR?0000ISV600000ZVmj0050000R569R5690000]gV>00@00004R5680`000003ZKgX
0000000000@000000jVmj0000000000400000jVmj08000000jVmj0000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000004ZKgX0P000;Coool00?ooool[oooo0`000003ZKgX0000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1:Vmj0000000000000BY_NP2000000FY_NP000000000002Y_NP00`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP3
000000FY_NP000000000002Y_NP01P00000703Rk0000WfVCWfVC0000o=RN000000:Y_NP300000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000BY
_NP0000000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000002
000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000000jVmj0000:Vmj003ZKgX0P00
00:K]n`00`0008I=Q8I=Q002QTf40P000003ZKgX0000000000@000000jVmj00000000004000000FY
_NP000000000002Y_NP01@00009=:8<00`0008m@O`00000300000[5[P@<000000l9iO`0000000005
00000ZeXP`8000000oR^J`000>6FO002000000>cKH400000000010000007ahR?0000ISV6ISV60000
ZKgX000000:8DHT3000000>Y_NP00028DHP018QAR0@000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX00@0002Y_NP000000002ZKgX1P000003ZKgX0000000000@000000jVmj00000000004
000000FY_NP000000000002Y_NP00P0000:Y_NP00`000:Vmj00000050000/oooo`00ooooobSoool4
00000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002ZKgX00<0002Y_NP000001@000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP0
0000002Y_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj00000000002
00000YmYT`800002ZKgX0P0000:Y_NP200000YA_Y@8000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00004ZKgX1P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<00000
0jVmj00000000004000000FY_NP000000000002Y_NP01P000003ZKgX0000ZKgX00:Y_NP200000Y^g
k0030000QTf4QTf400:6CH@3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000006ZKgX0000CBR3CBR30000Se1o100000:aJh43000000?2NGl0000000001@00
00:]J8<4000000CQUW`00000002cKH43000000FY_NP000000037R8l000000VHiQP030000ZKgX0000
00:8DHT200000ZVmj0030000R568R56800>8DHP5000000BY_NP00000002Y_NP300000jVmj0<00000
0jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000@000001JVmj00000000000
0:Vmj00300000jVmj0<000001:Vmj00000000:Vmj0<0002boooo003ooooo9_ooo`@00002ZKgX0P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vmj0<000001JVmj00000000000
0:Vmj006000000FY_NP000000000002Y_NP00P0000:Y_NP200000jVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj0000000000h^`800000
1OcHWP00000000000:Vmj00300000iA_Y@@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002ZKgX00<0002Y_NP000001@000005ZKgX000000000000ZKgX00H00000
1JVmj000000000000:Vmj002000000BY_NP0000000000002ZKgX0P000003ZKgX0000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP01P000003ZKgX0000000000800003
ZKgX0P0000:K]n`00`0008I=Q8I=Q002QTf410000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX1000009=:8<00`0008m@O`00000300000[5[P@<000000l9iO`00
0000000500000ZeXP`@000001>6FO00000000;=]P@@000001:Vmj0000<N8S`00009V>HH00`000:Vm
j0000002R5690P0000:Y_NP00`0008QAR8QAR002R56800@0002DF8D0002Y_NP600000ZVmj0050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001jVmj000000000000:Vmj0000:Vmj003000000>Y_NP00000000010000003ZKgX
000000000;;oool00?oooolSoooo1@000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX00D0
002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000
000000000:Vmj00300000ZVmj08000000jVmj0000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000002
ZKgX20000003ZKgX0000U6nU00:DKjD2000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001:Vmj0000000000000>Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
000010000005ZKgX000000000000ZKgX00H00002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P0000:Y_NP2
00000i^gk0040000QTf4QTf4QTf41@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP200000TdXP`030000Se1o000000<00002/F^10`000003`WUo00000000
00D00002[FR310000004hIIl00000000/ff10`000003ZKgX0000000000800003ISV60P000004R569
0000]gV>00000ZVmj0030000R568R56800:8DHP00`0009AHQ@00000400001:Vmj0H000000jVmj000
00000004000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX0P00
00>Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@0002aoooo003ooooo8Oooo`@00000
1JVmj000000000000:Vmj006000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00800002ZKgX0P0000>Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP0000000000002ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000
ZKgX000000D00005ZKgX00<0002DKjD000000`000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj0000000000400001:Vmj0800002ZKgX0P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX
0000000000000jVmj0030000ZKgXZKgX00800003VkO/00@00026CHB6CHB6CH@2000000>Y_NP00000
000010000003ZKgX0000000000@00002ZKgX0P0000>Y_NP300000TdXP`030000Se1o000000<00002
/F^10`000003`WUo0000000000D000000jeXP`0000000003000000CQUW`00000002cKH4800000fHi
QP060000ZKgX00000000]gV>00000ZVmj0030000R568R56800:8DHP0100009AHQ@00000000:Y_NP0
0`000:Vmj0000005000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H000001:Vmj000
0000000000:Y_NP2000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000>Y_NP0000000003_ooo`D00002oooo00<0003oooooool00_ooo`030000
oooooooo09Coool00?oooolNoooo10000005ZKgX000000000000ZKgX00H000001JVmj00000000000
0:Vmj003000000BY_NP00000002Y_NP300000ZVmj08000000jVmj0000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000004ZKgX0P000005ZKgX000000000000ZKgX00<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`000003ZKgX0000000000D00003
ZKgX0`000004ZKgX0000000000000Y9ZX@D00002ZKgX0P0000>Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000
ZKgX0000008000000jVmj00000000004000000>Y_NP00000000010000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00200000ZVmj0030000ZKgX000000800002ZKgX00<0000c57X0
00000Y^gk0040000QTf4QTf4QTf41P000003ZKgX0000000000@00003ZKgX0P000003ZKgX0000ZKgX
008000001jVmj0000000000004dXP`0008m@O`0400000[5[P@<000000l9iO`000000000400000ZeX
P`D000001>6FO00000000;=]P@@000001:Vmj0000000000000AV>HH3000000FgNHh0002Y_NRY_NP0
000018QAR0030000U5R5000000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000007ZKgX000000000000ZKgX0000ZKgX00800002ZKgX1P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000003oooo`070000
oooooooooooo0000oooo000000;oool00`000?ooo`00002Eoooo003ooooo7?ooo`@000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj003000000>Y_NP00000
00000ZVmj0<00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000005000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP0
1@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP:0000199ZX@<00003ZKgX0P000003ZKgX
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001:Vmj0000000000000>Y_NP3000000>Y_NP00000000010000003ZKgX
0000000000@000001JVmj000000000000:Vmj006000000BY_NP0000000000003ZKgX0`000004ZKgX
0000000000000ZVmj0800002VkO/00@00026CHB6CHB6CH@3000000FY_NP000000000002Y_NP00P00
00:Y_NP010000:Vmj000000000:Y_NP6000000JY_NP00000001=:8<0002?D7l400000[5[P@<00000
0l9iO`000000000400000ZeXP`D000001>6FO00000000;=]P@D000000jVmj00000000004ISV60`00
0004]gV>0000ZKgXZKgX0P0000>8DHP00`0009AHQ@000002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000003
ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj006000000>Y_NP0000000001000
0003ZKgX0000000000koool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool00000UOoo
o`00oooooaWoool4000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj003000000BY_NP0000000000003ZKgX0P0000:Y_NP2000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00H00000
1JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000005ZKgX00000000ZKgX000000BBJZ401@000:RchJRch@000:Vmj002
00000ZVmj0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP01@000:Vm
j00000000:Vmj003000000>Y_NP0000000000ZVmj0800002VkO/00D00026CHB6CH@0003i^Gd00`00
0004ZKgX0000000000000jVmj0<000000jVmj00000000004000000>Y_NP0000000000`000003CBR3
0000Se1o00@00002/F^10`000003`WUo0000000000@00002[FR31P000003]6j20000/ff100L00000
0jVmj00006HiQP02ISV60P0000:gNHh00`000:Vmj:Vmj00200000hQAR0030000U5R5000000<00000
0jVmj00000000004000000>Y_NP00000000010000005ZKgX000000000000ZKgX00800002ZKgX00D0
002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj000
00000004000000JY_NP000000000002Y_NP0000>oooo00L0003oooooooooool0003oool000000_oo
o`030000oooo000009Goool00>7oool300000_ooo`030000oooooooo02goool4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP0000000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H00002ZKgX00D0
002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP0
1@00099ZXI9ZXI9ZX@000002Z;?Q0`000003ZKgX0000000000@000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00004
ZKgX1P000003ZKgX0000000000<00002ZKgX0P0000:K]n`00`0008I=Q8I=Q003000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000002:Vmj00000000:Vm
j00004dXP`0008m@O`@00002/F^10`000003`WUo0000000000@00002[FR31P000003]6j20000/ff1
00<000000jVmj00000000003000016HiQP040000]gV>000000000ZVmj0800002R56800D0002DF8FD
F8D0002Y_NP01P000003ZKgX0000000000@000001JVmj000000000000:Vmj00300000jVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00003ZKgX0`0000goool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool0
0000UOooo`00h_ooo`060000oooooooo0000oooo0000:oooo`@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj00000000000
00BY_NP6000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX000000000000ZKgX00800004ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP0
1000099ZX@000:Rch@8000001Jk9kP00000000000:Vmj002000000FY_NP000000000002Y_NP01P00
0005ZKgX000000000000ZKgX00H00002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP0
0`000:Vmj0000005000000>Y_NP00000000010000004ZKgX00000000ZKgX0P0000:K]n`00`0008I=
Q8I=Q00400000jVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001jVmj000
0000000004dXP`0008m@O`0400000[5[P@<000000l9iO`000000000400000ZeXP`H000000kA^PP00
0;=]P@04000000>Y_NP0000000000P0000AV>HH010000;MiSP00000000>Y_NP0100008QAR8QAR000
00:DF8D2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000NY_NP000000000002Y
_NP0002Y_NP00`000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`0000_oool200001?oo
o`030000oooooooo00;oool00`000?ooooooo`2Doooo003Poooo10000004oooo0000oooo0000:?oo
o`D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00<0002Y_NP000001@000005ZKgX000000000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00:Y_NP2000000>Y_NP0002Y_NP00`000003ZKgX0000000000@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj00000000002000000>^
bNh0000000000YEaY`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
0000000400001:Vmj0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00800002ZKgX0P0000>Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0002Y_NP00P0000:K]n`00`0008I=Q8I=Q003000000FY_NP00000
0000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000006ZKgX00000000
CBR30000Se1o100000:aJh43000000?2NGl000000000100000:]J8<6000000>dKX80002cKH402@00
00AV>HH00`000;MiSP00000200000ZVmj0040000R568R56800000YAHQ@<000000jVmj00000000002
Qdj50P000004ZKgX00000000ZKgX0`0000>Y_NP3000000>Y_NP00000000010000003ZKgX00000000
00@000000jVmj00000000004000000FY_NP000000000002Y_NP00`0000>Y_NP3000000BY_NP00000
002Y_NP20000[Oooo`00h?ooo`030000oooo000000;oool00`000?ooo`00000Voooo10000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vmj0<000001JVmj000000000000:Vmj006
000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX0`00
00:Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H000001JVmj00000000000
0:Vmj00200000ZVmj0050000ZKgX00000000Y[cY00<00003UG6W10000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000005000000FY_NP00000
0000002Y_NP01P000003ZKgX0000000000@000001:Vmj0000000000000:Y_NP2000000>Y_NP0002Y
_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000004<aAj0000VkO/00000XI=Q0@000001JVmj000000000000:Vmj006000000>Y
_NP00000000010000003ZKgX0000000000<000000ddXP`0008m@O`0400000[5[P@<000000l9iO`00
0000000400000ZeXP`H000000kA^PP000;=]P@0500000ZVmj0800004ISV600<0002gNHh000000P00
00:Y_NP0100008QAR8QAR00000:DF8D4000018M>Q@H00002ZKgX00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX
000000000000ZKgX0000ZKgX00<000000jVmj00000000004000000>Y_NP000000000[?ooo`00hOoo
o`800002oooo00<0003oool000008oooo`D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj003000000>Y
_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0P0000:Y_NP2000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj00300000jVmj0<00000
1JJlj@0000000:Vmj0000003UG6W0P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00@000000jVmj00000000004000000BY_NP0000000000002ZKgX0`0000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000@c57X0002K]n`00002
QTf41@000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000000010000005ZKgX
0000CBR30000Se1o00@00002/F^10`000003`WUo0000000000@00002[FR31P000003]6j20000/ff1
00<00003ZKgX0`0000AV>HH00`000;MiSP00000200000ZVmj0040000R568R56800000YAHQ@030000
ZKgX000000F7CXD300001:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`000003ZKgX0000000000@00000
0jVmj000000000040000Zoooo`00h_ooo`050000oooooooooooo000002;oool4000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00<00003ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000NY_NP000000000002Y_NP0002Y_NP00`000004ZKgX0000000000001:Vmj0040000
UG6W0000ZKgX0P0000:9EXh2000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00004ZKgX0P000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000003ZKgX000000000080000013<DNP0009^gk00000:6CH@2
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000>Y_NP0000000000P000003CBR30000Se1o00@00002/F^10`000003`WUo00000000
00@00002[FR31P000003]6j20000/ff100<000001:Vmj00000000:Vmj0<00003ISV600P0002gNHh0
0000000003h0002Y_NP00002R56800H0002DF8FDF8D0002Y_NP00005Qdj500@0002Y_NP0002Y_NP3
000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000
0000100000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP20000Zoooo`00ooooo`Ooool5000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001jVmj000
000000000:Vmj0000:Vmj003000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>Y_NP3000000FY_NP000000000002Y_NP0100000:Y_NP4000018UFSP<000001:Vmj00000000:Vm
j0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000005000000>Y_NP00000000010000005ZKgX
000000000000ZKgX00H000000jVmj0000000000400000ZVmj080000013<DNP0009^gk00000:6CH@3
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj00200000ZVmj08000000ddXP`0008m@O`0400000[5[P@<000000l9iO`000000000400000ZeX
P`H000000kA^PP000;=]P@04000000BY_NP00000002Y_NP300000VHiQP080000]gV>00000000000n
0000ZKgX00000XQAR0060000U5R5U5R50000ZKgX00001HM>Q@@000000jVmj00000000004000000>Y
_NP00000000010000003ZKgX0000000000@000000jVmj0000000000400001:Vmj0H000000jVmj000
00000004000000FY_NP000000000002Y_NP00P000003ZKgX000000000:[oool00?ooool5oooo1000
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`000005ZKgX00000000
0000ZKgX00H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP0
1@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000000jVmj000
00000004000000JY_NP000000000002Y_NP00004REJ>00<0002YL98000001@0000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP300000jVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
00000004000000>Y_NP000000000100000BY_NP3000000@c57X0002K]n`00002QTf410000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX1@00
0003Se1o0000000000800002/F^10`000003`WUo0000000000@00002[FR31P000003]6j20000/ff1
00P000000jVmj00000000003ISV60`000006000n0000ZKgX0000R56800000iAHQ@030000ZKgX0000
00F7CXD00`000:Vmj0000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000ZKgX000000D000000jVmj00000000004
000000FY_NP000000000002Y_NP01P000003ZKgX000000000:Woool00?ooool2oooo1@000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<00000
0jVmj00000000004000000FY_NP000000000002Y_NP01P000004ZKgX0000000000000ZVmj0@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000BY_NP0
0`0008UFSXUFSP02REJ>0P000003000/0000000000BY_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002ZKgX00<0002Y_NP000001@000004<aAj0000VkO/00000XI=Q0D00000
0jVmj00000000004000000>Y_NP000000000100000:Y_NP01@000:Vmj00000000:Vmj004000000>?
D7l0000000000P0000:aJh43000000?2NGl000000000100000:]J8<00`000>fRM`000003000000>d
KX80002cKH401@000003ZKgX0000000000@00002ISV600<0002AI9X000000P000004ZKgX0000R568
00000iAHQ@030000ZKgX000000F7CXD2000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001ZVmj00000000000
0:Vmj0000:Woool00?ooool4000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX00@00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200001:Vmj0060000REJ>REJ>REJ>0000
ZG2B0P000003ZKgX0000ZKgX00<000000jVmj00000000004000000>Y_NP00000000010000005ZKgX
000000000000ZKgX008000001:Vmj0000000000000:Y_NP4000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0<00000
1:Vmj00000000:Vmj0<0000023<DNP00000008I=Q0000?ViO@000:Vmj0H000000jVmj00000000004
00001:Vmj0<000001:Vmj00000000:Vmj08000000ddXP`000000000300000[5[P@<000000l9iO`00
0000000400000ZeXP`030000kJ9g000000<000000kA^PP000;=]P@06000000RY_NP00000002Y_NP0
002AI9X0001V>HH2000000>Y_NP0000003h00P000003R5680000U5R500:DF8D00`000:Vmj0000005
Qdj50`000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP000000000100000:Y_NP0
1@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP300000jVmj0<0002Xoooo003loooo10000005ZKgX000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP0
0000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000NY_NP000000000002Y_NP0002Y
_NP00`000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000004ZKgX0000000000000jVmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0800003ZKgX00H00029EXj9EXj9EXh0002YL985000000>Y
_NP00000000010000003ZKgX0000000000@000001JVmj000000000000:Vmj006000000>Y_NP00000
00000P0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vm
j080000013<DNP00000008I=Q0@000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00<0
002Y_NP000000P000003ZKgX0000000000@000000jVmj00004dXP`0500000[5[P@<000000l9iO`00
0000000400000ZeXP`030000kJ9g000000<000000kA^PP000;=]P@03000000BY_NP0000000000003
ZKgX00<0002AI9ZAI9X01@000003000n0000000000800003U5R500@0002Y_NRY_NP00004Qdj51000
0004SenF00000000ZKgX1P000003ZKgX0000000000@00004ZKgX1P000003ZKgX0000000000@00000
0jVmj00000000004000000>Y_NP000000000100000:Y_NP01@000:Vmj00000000:Vmj0030000Yooo
o`00nOooo`@000001JVmj000000000000:Vmj003000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001:Vmj0000000000000>Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00003ZKgX0`000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000000jVmj0040000REJ>REJ>
00000ZU`TP8000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00H000001jVmj000000000000:Vmj0000:Vmj003000000>Y_NP0000000001000
0003ZKgX0000000000@000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`00
0004ZKgX00000000ZKgX0`000006ZKgX00000000ZKgX0000<aAj0P000003QTf40000000000<00000
1:Vmj00000000:Vmj0<00003ZKgX0`000003ZKgX0000000000@000000jVmj00000000002000000==
:8<0000000000`0000:aJh43000000?2NGl000000000100000:]J8<00`000>fRM`000003000000>d
KX80002cKH4010000003ZKgX0000000000>Y_NP00`00095TVY5TVP02000000BY_NP00000000003h4
00000iAHQ@040000ZKgXZKgX000018M>Q@040000SenFSenFSenF10000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP00`000:Vmj0000005000000>Y_NP00000000010000003ZKgX00000000
00@000000jVmj0000000000400000jVmj0L000000jVmj0000000002Woooo003goooo10000004ZKgX
00000000ZKgX0`000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj00200000ZVm
j0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000>Y_NP00000000010000005ZKgX000000000000ZKgX
00H000001:Vmj0000000000000>Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000000ZVmj0050000REJ>REJ>0000ZG2B
00@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001:Vmj0000000000000>Y_NP3000000>Y_NP00000000010000003ZKgX00000000
00@000001JVmj000000000000:Vmj00600000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<0000018I=Q00000000:Vmj0<000000jVmj00000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000005ZKgX000000000000CBR3
00D00002/F^10`000003`WUo0000000000@00002[FR300<0003]XWL000000`000003]6j20000/ff1
00P00003ZKgX00<0002AI9X000000P000004ZKgX0000000n000n0`0000>DF8D010000:Vmj:Vmj000
00B7CXD01@0008mOUXmOUXmOUP000002TFFK0P000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP5000000FY_NP000000000002Y_NP01P000:Koool00?Coool4000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX00H000001JVmj000000000000:Vmj00300000jVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000007ZKgX000000000000ZKgX0000ZKgX00<00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00300000ZVmj0030000REJ>000000:YL982000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVm
j0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj0000000000400001:Vmj0H000000jVmj00000000004000000>Y_NP0000000001`000005QTf4
000000000000ZKgX00<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000CBR31@0000:aJh43000000?2NGl000000000100000:]J8<00`000>fRM`000003
000000>dKX80002cKH401@000003ZKgX00000000008000001ZVmj00000000:Vmj0000:Vmj0800002
000n0P0000BDF8D010000:Vmj:Vmj00000B7CXD0100008mOUXmOUP0000:AII/00`0008aCQ`000004
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX0`000:Goool00?;oool4000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP0000000000002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000005ZKgX000000000000ZKgX00H000000jVmj00000000004000000FY_NP00000
0000002Y_NP00P000004ZKgX0000000000000ZVmj08000001:Vmj00008UFSP0000:YL983000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX00<0002Y_NP000001@000003ZKgX0000000000@000000jVmj00000000004000000>Y
_NP0000000000`000003QTf40000000000800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000CBR300D00002/F^10`000003`WUo
0000000000@00002[FR300T0003]XWL00000003QUW`0002dKX80002cKH400`000004ZKgX00000000
ZKgX2@000004ZKgX0000000n000n0P0000BDF8D010000:Vmj:Vmj00000B7CXD0100008mOUXmOUP00
00:AII/0100008aCQ`00000000BY_NP6000000>Y_NP00000000010000003ZKgX0000000000@00000
0jVmj00000000004000000BY_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0P000:Goool00>ooool4000000FY_NP000000000002Y_NP00P0000:2B842000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<000000jVmj00000000004000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00H00002ZKgX00<0002Y_NP000000P000003ZKgX
0000000000>YL984000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000D00003ZKgX1P000003ZKgX00000000
00@000000jVmj00000000004000000>Y_NP0000000000P000003CBR30000000000<00002/F^10`00
0003`WUo0000000000@00002[FR300L0003]XWL00000003QUW`0002dKX801P000004ZKgX00000000
ZKgX100000:Y_NP3000000>Y_NP0000003h00P0000BDF8D010000:Vmj:Vmj00000B7CXD00`0008mO
UP000002TFFK00<0002<DhN<DhL00P000003ZKgX0000000000@000000jVmj00000000004000000>Y
_NP00000000010000003ZKgX0000000000@000001jVmj000000000000:Vmj0000:Vmj003000000>Y
_NP00000000010000003ZKgX0000000000@000000jVmj0000000002Toooo003]oooo10000004ZKgX
00000000ZKgX0`0000B2B843000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP500000ZVm
j0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj0000000000400001:Vmj0T00002ZG2B0P000003ZKgX00000000
00@000001JVmj000000000000:Vmj002000000BY_NP0000000000003ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1000
00:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000002P000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000
00001@000006CBR3000000000000000R00000[5[P@<000000l9iO`0000000005000000>]J8<0003]
XWL00P000003hIIl0000]6j200X00002ZKgX00D0002Y_NP00000002Y_NP010000003000n00000000
00BDF8D010000:Vmj:Vmj00000>7CXD2000000B?GiH0002AII/00003S5>70`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj000000000040000Xooo
o`00j_ooo`@000001JVmj000000000000:Vmj002000000>Y_NP00022B8401898P@@000000jVmj000
00000002R5B=0P000003ZKgX0000000000:Y_NP00`000:Vmj0000005000000FY_NP000000000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
00000jVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000005000000>Y
_NP0000000000P0000>YL986000000FY_NP000000000002Y_NP01P0000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP7
000000@00280002aJh6aJh43000000?2NGl0000000001@000003[FR30000kJ9g008000000n6FO000
0;A^PP0700001:Vmj0H000001JVmj000000000000000?P02000019AHQ@040000ZKgXZKgX00000hM>
Q@@000000i5UV`0008aCQ`02S5>710000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP20000Xoooo`00j?oo
o`@000001:Vmj00000000:Vmj0<00003ZKgX00<00022B862B8400X98P@030000SDn0000000<00004
R5B=0`0000>Y_NP3000000BY_NP00000002Y_NP3000000FY_NP000000000002Y_NP01P000005ZKgX
000000000000ZKgX008000000jVmj0000000000200000ZVmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP0
0000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vm
j0<000001:Vmj0000;]7000000>YL983000000FY_NP000000000002Y_NP01P0000BY_NP6000000>Y
_NP00000000010000003ZKgX0000000000@000000jVmj00000000004000000BY_NP0000000000003
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000:Y_NP5000000@00280002aJh6aJh43000000?2NGl00000
00001@000003[FR30000kJ9g008000000n6FO0000;A^PP05000000>Y_NP0002Y_NP01P000003ZKgX
0000000000@000000`00?P0000000004U5R500@0002Y_NRY_NP00003Qdj51@0000B<DhL00`000:Vm
j0000005000000>Y_NP00000000010000003ZKgX0000000000@000001:Vmj0000000000000>Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP20000X_ooo`00iOooo`@000001JVmj000000000000:Vmj002000000BY_NP00000
00000002ZKgX00<00022B862B8400X98P@030000SDn0000000800004R5B=00D0002JH8/00000002Y
_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj006000000FY_NP00000
0000002Y_NP01P0000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZU`TP800000
1:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00<0002Y_NP000001@000003ZKgX00000000
00@000000jVmj00000000004000000>Y_NP00000000010000007ZKgX000000000000ZKgX0000ZKgX
00<000000jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj000
0000000400000ZVmj0050000ZKgX00000000nKUm00<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX1P000004000R0000/F^1/F^10`000003`WUo
0000000000D000000jeXP`000>fRM`02000000?QUW`0002dKX8020000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0P00008003h00`0009AHQIAHQ@02U5R500@0002Y_NRY_NP00003Qdj51@00
00B<DhL5000000>Y_NP00000000010000003ZKgX0000000000@000001jVmj000000000000:Vmj000
0:Vmj003000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj00000000004000000>Y
_NP000000000100000:Y_NP00`000?ooooooo`2Ooooo003Roooo1@000004ZKgX00000000ZKgX0`00
0005ZKgX00000000ZKgX000000>Y_NP00`000898PH98P@02PTR100<0002=Ch0000000P0000B8E8d2
000000@804D00000002Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00600001:Vmj0H000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0D00002ZG2B0`000004ZKgX00000000ZKgX0`0000:Y_NP4
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP300000jVmj0<000000jVmj00000000004000000>Y_NP00000000010000003ZKgX
0000000000@000000jVmj0000000000400001:Vmj0H000000jVmj00000000004000000>Y_NP00000
000010000003ZKgX0000000000@00002ZKgX00D0002Y_NP00000002Y_NP01@000004000R0000/F^1
/F^10`000003`WUo0000000000D000000jeXP`000>fRM`02000000?QUW`0002dKX801@000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP0000003h003h0000019AH
Q@040000ZKgXZKgX00000hM>Q@8000000`1Fd@0008aCQ`04S5>70P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj002000000BY_NP0000000000002ZKgX10000003ZKgX00000000
00@000000jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000@00004ZKgX0P00
0:7oool00=ooool400000ZVmj0<000001:Vmj00000000:Vmj0<00003ZKgX00D0002Y_NRY_NRY_NP0
00001898P@8000000kEbQP0000000003R5B=00D0002JH8/00000002IGXX00P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP0
0`000:Vmj0000005000000FY_NP000000000002Y_NP01P000003ZKgX0000000000@000001:Vmj000
0000000000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:YL984000000BY_NP00000002Y_NP400000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`000:Vmj0000005
000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj0000000000400000jVmj0L00000
0jVmj00000000003000000<00280002aJh400`000003`WUo0000000000D000000jeXP`000>fRM`02
000000?QUW`0002dKX801P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003
00000P00?P030000U5R5U5R500:DF8D010000:Vmj:Vmj00000>7CXD01000001Fd@1Fd@0000B<DhL0
1@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00<0002Y_NP000001@000:3oool00=goool3000000>Y_NP0002Y_NP00P00
0005ZKgX000000000000ZKgX008000000jVmj00000000003ZKgX00D0002Y_NRY_NRY_NP000001898
P@<000000o:]O`0008QDS@02R5B=00D0002JH8/00000002IGXX00`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000003ZKgX0000000000@000001JVmj000000000000:Vmj00400000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZU`TP030000ZKgX0000008000000jVmj000
00000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0<000001:Vmj000
00000:Vmj0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000<000001JVmj000000000000:Vmj008000000<00280002aJh400`000003`WUo00000000
00D000000jeXP`000>fRM`02000000?QUW`0002dKX801`000003ZKgX0000000000@000001:Vmj000
0000000000>Y_NP00`000000?P000004U5R500@0002Y_NRY_NP00003Qdj500@00000E]40E]400004
S5>71@000003ZKgX0000000000@000000jVmj0000000000400000ZVmj0050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000001:Vmj0000000000000:Y_NP4
000000BY_NP00000002Y_NP20000X?ooo`00f_ooo`<00003ZKgX0`000004ZKgX00000000ZKgX0`00
0005ZKgX00000000ZKgX000000>Y_NP01@000:Vmj:Vmj:Vmj0000003PTR100<0002=Ch0000000`00
00>8E8d00`0009YPR`000002VEj:10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000NY_NP000000000002Y_NP0002Y_NP00`00
0003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000000010000003ZKgX00000000
00@00002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP6000000BY_NP0000000000003ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1000
00:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0H00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj0000000
0:Vmj003000000>Y_NP0000000001@000003000R0000/F^100<000000l9iO`0000000005000000>]
J8<0003]XWL00P000003hIIl0000]6j200/000000jVmj0000000000300001:Vmj0040000000n0000
00000iAHQ@040000ZKgXZKgX00000hM>Q@04000005KA05KA000018aCQ`8000000jVmj00000000004
000000>Y_NP000000000100000BY_NP6000000>Y_NP00000000010000003ZKgX0000000000L00000
0jVmj0000000000600000ZVmj0H000000jVmj0000000002Ooooo003Hoooo0`000003ZKgX0000ZKgX
008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`0000>Y_NP200000ZVm
j0060000PTR1PTR1PTR10000SDn00`000005mK9m0000R5B=0000VV2;008000000iUNRP000:1RQ`04
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003
ZKgX0`000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000000010000003ZKgX
0000000000@00004ZKgX1P000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000
000010000003ZKgX0000000000800002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000003000R0000/F^100<000000l9iO`0000000005
000000>]J8<0003]XWL00P000003hIIl0000]6j200D000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0800003ZKgX00@0000003h000000003U5R500D0002Y_NRY_NRY_NP000000XM>Q@040000
05KA05KA000018aCQ`<000000jVmj00000000002R5270P000003ZKgX0000000000:Y_NP00`000:Vm
j0000005000000>Y_NP00000000010000003ZKgX0000000000@000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00<0002Y_NP000001@000003ZKgX0000000000@0002Noooo003Eoooo0`00
00:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000jVm
j0800002ZKgX00H00022B862B862B840002=Ch03000000Ke/Wd00028E8d0002JH8/00002VEj:00<0
002PHXL0000010000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00<0002Y_NP000001@000003ZKgX
0000000000@000000jVmj00000000004000000>Y_NP00000000010000007ZKgX000000000000ZKgX
0000ZKgX00<000000jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000P00002
ZKgX10000004ZKgX00000000ZKgX1P000003ZKgX0000000000@000000jVmj00000000004000000BY
_NP0000000000003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1P000003ZKgX0000000000800002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000003000R0000/F^100<00000
0l9iO`0000000005000000>]J8<0003]XWL00P000003hIIl0000]6j2008000001K=]P@0000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000ZKgX00:Y_NP010000000?P000000
00>DF8D01@000:Vmj:Vmj:Vmj0000002Qdj500@00000E]40E]400004S5>7100000B8D8L300000ZVm
j0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P00
09koool00=?oool700000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj0000:Vmj002ZKgX0P0000:Y_NP01P000898PH98PH98P@0008e?P0<000001_FbO@0008QDS@00
09YPR`0000:IGXX2000000?MVh`0000000000`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00003ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@000000jVmj00000000004000000>Y
_NP0000000001P0000:Y_NP9000000>Y_NP00000000010000003ZKgX0000000000@000001jVmj000
000000000:Vmj0000:Vmj003000000>Y_NP00000000010000003ZKgX0000000000@00002R5682000
0007ZKgX000000000000ZKgX0000ZKgX00<000000jVmj00000000004000000>Y_NP0000000001000
0003ZKgX0000000000@000001:Vmj0000000000000:Y_NP7000000>Y_NP00000000010000003ZKgX
0000000000@000001JVmj00000008P000;5[P@03000000?2NGl0000000001@000003[FR30000kJ9g
008000000n6FO0000;A^PP02000000>cKH40000000001@000003ZKgX0000000000@000001ZVmj000
0:Vmj:Vmj0000000?P800003U5R500D0002Y_NRY_NRY_NP000000XM>Q@04000005KA05KA000018aC
Q`030000ZKgX000000F8D8L500000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0H000000jVmj0000000000400000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj080002Moooo003@oooo0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000>Y_NP200000ZVm
j0060000PTR1PTR1PTR10000SDn00`000003mK9m0000000000:JH8/00`0009UNRYUNRP04000000>f
[200000000000P000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000NY
_NP000000000002Y_NP0002Y_NP01P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`0000:Y_NP4000000>Y_NP00000000010000005ZKgX000000000000RE>;
00800005R5680P000004ZKgX00000000ZKgX0`0000>Y_NP3000000>Y_NP00000000010000003ZKgX
0000000000@000000jVmj00000000004000000>Y_NP0000000001P000005ZKgX000000000000ZKgX
00H000000jVmj00000000004000000>Y_NP0000000000P000003000R0000/F^100<000000l9iO`00
00000005000000>]J8<0003]XWL00P000003hIIl0000]6j2008000000k=]P@0000000002000000>Y
_NP00000000010000003ZKgX0000000000800002ZKgX00@0000003h000000003U5R50P0000:Y_NP0
100008M>QHM>Q@0000<0E]401`0008aCQhaCQhaCQ`000:Vmj0000005R5270`000005ZKgX00000000
0000ZKgX00H000000jVmj00000000007000000>Y_NP000000000100000>Y_NP7000000>Y_NP00000
000010000003ZKgX0000000000@000000jVmj0000000002Loooo003>oooo1P0000>Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0800002
ZKgX00@00022B862B8400002SDn00`000005mK9m00000000VV2;000000:IGXX00`000:1RQ`000004
000000FNHHL000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVm
j0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVm
j0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`0000B9Dh/00`0008QAR8QAR004
R5680`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0L000000`008P00
0;5[P@03000000?2NGl0000000001@000003[FR30000kJ9g008000000n6FO0000;A^PP02000000>c
KH40000000000`000004ZKgX00000000ZKgX0`0000:Y_NP3000000>Y_NP0000003h00P0000>DF8D2
00000ZVmj0040000Qdj5Qdj500000`1Fd@070000S5>7S5>7S5>70000ZKgX000000F8D8L4000000>Y
_NP00000000010000003ZKgX0000000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0D000001JVmj000000000000:Vmj006000000>Y_NP00000000010000003ZKgX0000000000<0002L
oooo003;oooo0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000ZVmj0030000FRMg0000
00:Y_NP01`000898PH98P@0008e?P0000;EbQP02000000Ge/Wd0002JH8^JH8/000000YUNRP030000
X6:7000000@000000iiQQ`000000000200000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000FY_NP00000002Y_NP0000018UC
R`800005R5681@0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001I9VW00000008P000;5[P@03000000?2
NGl0000000001@000003[FR30000kJ9g008000000n6FO0000;A^PP02000000BcKH400000002Y_NP3
000000BY_NP00000002Y_NP400000ZVmj0030000ZKgXZKgX00<00002U5R50`0000:Y_NP0100008M>
QHM>Q@0000<0E]401`0008aCQhaCQhaCQ`000:Vmj0000005R5271@000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP20000Voooo`00bOooo`8000001:Vmj0000000000000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000000ZVm
j0030000FRMg000000:Y_NP01`000898PH98P@0008e?P0000;EbQP02000000Ge/Wd0002JH8^JH8/0
00000YUNRP030000X6:7000000D000000oo8N`000000000300000iMf[08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`0000>Y_NP3000000BY_NP00000002Y_NP300000jVmj0030000
RE>;RE>;00:9Dh/200001HQAR08000000jVmj0000000000200000ZVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0005TVJL000000000000/F^100<000000l9iO`0000000004000000C;M6T00000003]XWL2000000?Q
UW`0002dKX800P000005/ff1000000000000ZKgX00<000000jVmj00000000002ZKgX00L0002Y_NP0
0000002Y_NP0002Y_NP00`0000:DF8D300000ZVmj0030000Qdj5Qdj50080000205KA00L0002<DhN<
DhN<DhL0002Y_NP000001HQ@Q`8000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000003ZKgX0000000000@000001:Vmj0000000000000>Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP6000000>Y_NP00000000010000003ZKgX0000000009[oool00<Koool3
000000BY_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000002JVmj00000000:Vmj0000:Vmj00005XWM`000002ZKgX00L0
0022B862B840002=Ch00002eLXH00P000005mK9m0000VV2;VV2;000000:IGXX00`000:1RQ`000005
000000Cob7/0000000000004UgJ/10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00003ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0800003ZKgX00<00029Dh^9Dh/00XUCR`800005R5680`00
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<00000
1:Vmj00000000:Vmj0<000000jVmj00000000002SE^A0P0000>Y_NP3000000FBIY`000000000002a
Jh400`000003`WUo0000000000X000000n6FO0000;A^PP02000000>cKH40000000000P000004ZKgX
0000000000000jVmj0<000001JVmj000000000000:Vmj00300000YAHQ@<00002ZKgX00<00027CXF7
CXD00P000080E]401`0008aCQhaCQhaCQ`000:Vmj0000005R5270`000003ZKgX0000000000@00000
0jVmj00000000007000000NY_NP000000000002Y_NP0002Y_NP00`000003ZKgX0000000000@00000
0jVmj00000000007000000>Y_NP00000000010000006ZKgX000000000000ZKgX0000V_ooo`00a?oo
o`8000001JVmj000000000000:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000002:Vmj00000000000
0:Vmj00005XWM`0000:Y_NP00`000898P@000002SDn00P000006lZeo0000mK9m0000VV2;00000YUN
RP040000X6:70000gI^<0`000004WV6700000000V5V30`000005UgJ/000000000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002R5B<0P0000>Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<000001JVmj00000000:Vm
j0000003ZKgX00<00029Dh^9Dh/00XUCR`800005R5680P000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0H000000jVmj00000000004000000BY_NP0000000000003
ZKgX1P000003ZKgX0000000000@000001:Vmj0000000000000B=Fi400`000:Vmj:Vmj002ZKgX1`00
0005/F^1000000000000`WUo00`000000n6FO0000;A^PP02000000>cKH40000000000`000003ZKgX
0000ZKgX00<000000jVmj0000000000800000YAHQ@80000018iNU0000:Vmj00000:7CXD200000P1F
d@050000S5>7S5>7S5>7000000:Y_NP00`0008Q@QhQ@Q`02R5271`000003ZKgX0000000000@00000
1:Vmj00000000:Vmj0<00002ZKgX10000003ZKgX0000000000@000000jVmj00000000004000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@0002Ioooo0031oooo0`000004ZKgX
00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0070000ZKgX0000FRMg0000ZKgX0000
00:2B8400`0008e?P8e?P00300000_FbO@030000VV2;000000:IGXX010000:1RQ`000=fKS0<00000
19iQQ`00000009QIP`D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00004R5B<0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
00000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX1P000003ZKgX0000000000800002ZKgX0`000004ZKgX00000000
ZKgX0`0000>Y_NP200000ZVmj0070000RE>;RE>;RE>;0000E1a/000000B8DHP0100009EHQP000000
00:Y_NP6000000>Y_NP0000000001`000003ZKgX0000000000@000001jVmj000000000000:Vmj000
0:Vmj006000000>Y_NP00000000010000006ZKgX000000000000ZKgX000018eKT@@00003ZKgX1P00
0005/F^1000000000000`WUo00`000000n6FO0000;A^PP02000000>cKH40000000000ZVmj0@00000
0jVmj00000000004000000>Y_NP000000000100000:DF8D2000000B>GY@0002Y_NP00002Qdj50P00
0080E]401@0008aCQhaCQhaCQ`000002ZKgX00<00028D8N8D8L00XQ@Q`050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1000
00:Y_NP30000V?ooo`00_oooo`8000001JVmj000000000000:Vmj002000000>Y_NP0000000000P00
00:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0060000ZKgX00000000ZKgX00000UXWM`800002PTR100<0002=Ch2=
Ch000`0000;e/Wd00`0009YPR`000002VEj:00<0002PHXL0000010000005WV67000000000000m;60
00D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj00000000:Vmj0000004
R5B<10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000000jVmj0000000000200000ZVm
j0<000001:Vmj00000000:Vmj0H000000jVmj00000000007000000NY_NP000000000002Y_NP0002Y
_NP00`000003ZKgX0000000000H00004ZKgX0P0000:Y_NP01`0008UCRhUCRhUCR`0005@LK0000004
R56800<0002EF8H000001P000003ZKgX0000000000@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000BY_NP0
0`0008eKTHeKT@02SE^A00D0000n04X0001SF[8000000ZVmj08000001H]BQP00000000000;5[P@03
000000?2NGl0000000002P000003hIIl0000]6j2008000000k=]P@000000000200000ZVmj0<00000
1:Vmj00000000:Vmj0<000000jVmj0000000000300000YAHQ@80000018iNU0000:Vmj00000:7CXD2
00000P1Fd@050000S5>7S5>7S5>7000000:Y_NP00`0008Q@QhQ@Q`02R5270P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP6000000>Y_NP000000000100000:Y_NP0
1@000:Vmj00000000:Vmj0020000V?ooo`00_?ooo`<000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP0002Y_NP00002FRMg0P0000:2B840
0`0008e?P8e?P003000000Ge/Wd00000002JH8/000000YUNRP030000X6:7000000@000000iiQQ`00
00000002000000?SWXH0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00>Y_NP00`0008QDS8QDS002R5B<00<0002Y_NP000000P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0H000000jVmj00000000007
000000NY_NP000000000002Y_NP0002Y_NP00`000003ZKgX0000000000L000000jVmj00000000004
000000BY_NP00000002Y_NP300000ZVmj0@000000jVmj00000000004000000FY_NP00000002Y_NP0
00001:Vmj0800002ZKgX00L00029Dh^9Dh^9Dh/0001D76`0000018QAR0040000UER60000ZKgX0P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000003ZKgX0000000000800002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0P0000BY_NP0100008eKTHeKTHeKT@@00002HeZb10000005Re:6000000000000/F^100<00000
0l9iO`000000000:000000?QUW`0002dKX800P000005/ff1000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00`000005000n0000U5R50000ZKgX00800000
1:Vmj00008M>QHM>Q@<000000`1Fd@0008aCQ`02S5>700@0002Y_NRY_NP00004R5271P0000:;EH/5
000000BY_NP0000000000002ZKgX1`000003ZKgX0000000000@000000jVmj00000000007000000>Y
_NP000000000100000>Y_NP:0000Uoooo`00^_ooo`8000001JVmj000000000000:Vmj002000000BY
_NP0000000000002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP4000000BY_NP0001J9gMJ9gL200000X98
P@030000SDn0SDn000<000001?FbO@000000000000:IGXX00`000:1RQj1RQ`04000000>NHHL0003o
b7/00`000003hij60000Y6B600@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800003
ZKgX00@00028E8b8E8b8E8`3000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP300000ZVmj0L000000jVmj00000000007000000>Y_NP00000000010000004ZKgX00000000
ZKgX0`0000:Y_NP4000000>Y_NP00000000010000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000
002Y_NP000000jVmj0050000HSN70000ZKgX000000>9Dh/00`0005@LK0000004R56810000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
00000jVmj0060000SE^ASE^ASE^A0000ZKgX0P0000ASF[8200000X]BQP8000001K5[P@0000000000
0<9iO`0<000000?QUW`0002dKX800P000003/ff100000000008000001:Vmj00000000:Vmj0H00000
0jVmj00000000004000000D003h0002DF8D0002Y_NP00P000009ZKgX0000Qdj5Qdj50000ZKgX0000
05KA000000:<DhL01@000:Vmj:Vmj:Vmj0000004R5270`0000F;EH/2000000>Y_NP0000000001P00
0005ZKgX000000000000ZKgX00H000000jVmj00000000004000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000004ZKgX000000000000U_ooo`00]ooo
o`<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP0
1@000:Vmj00000000:Vmj003000000BY_NP0001J9gMJ9gL2000000J2B840002=Ch2=Ch00002eLXH2
000000Ce/Wd0000000000002VEj:00<0002PHXNPHXL010000003WV670000olQk00<000000n>NQP00
0:ATQP05000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000000jVmj0060000R5B<R5B<
R5B<0000ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0H000000jVmj00000000009000000FY_NP000000000002Y_NP01P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000000
00>Y_NP00`00068gQ`000002ZKgX00H00029Dh/00000001D76`00003R56800<0002EF8H000000`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000ZVm
j0030000SE^ASE^A00<000000jVmj00006=J/P03HeZb0P0000:;DXH2000000FaJh40000000000032
NGl030000003hIIl0000]6j2008000000k=]P@0000000009000000>Y_NP00000000010000003ZKgX
00000000008000000iAHQ@000:Vmj002000000BY_NP00027CXF7CXD3000000D0E]40002<DhN<DhL0
00000jVmj0040000R527R527R5270`0000J;EH/3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0P00
09Koool00;Coool4000000BY_NP00000002Y_NP2000000FY_NP000000000002Y_NP00P0000:Y_NP0
1@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj08000001:Vmj00005XWMeXWM`800000
1X98P@0008e?P8e?P0000;EbQP8000001?FbO@0009YPR`0000:IGXX010000:1RQ`000=fKS0<00000
19iQQ`00000009QIP`8000000n>NQP0000000002000000GQe5/000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj0000:Vmj:Vmj0000002R5B<0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3
000000BY_NP00000002Y_NP9000000>Y_NP00000000010000003ZKgX0000000000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000YYn/`8000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP0000000000002ZKgX00<0001R=hL000000ZVm
j0060000RE>;00000000E1a/00000hQAR0040000UER60000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1P000003ZKgX0000000000800002ZKgX1P000003ZKgX0000000000@00000
0jVmj0000000000600000jVmj0030000SE^A000000D00003HeZb0P0000:;DXH00`0000008P000003
000000?2NGl0000000001`000006;@ad00000000hIIl0000]6j20P000003/ff10000000000<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001jVmj0000000000009AHQ@000:Vmj003
000000>Y_NP00027CXD00`00000505KA0000S5>7S5>7000000>Y_NP0100008Q@QhQ@QhQ@Q`<00005
ReF;1@0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP6000000>Y_NP00000
000010000004ZKgX0000000000000ZVmj0L000000jVmj00000000004000000>Y_NP000000000UOoo
o`00O?ooo`<00003oooo00<0003oooooool0;Oooo`@000001:Vmj00000000:Vmj08000000jVmj000
00000002ZKgX0P0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<000001jVmj00000000:Vmj0000:Vm
j0000002FRMg0P000006PTR10000SDn0SDn00000]G:60P000004mK9m0000VV2;00000YUNRP040000
X6:70000gI^<0P0000:NHHL2000000>HFH<0000000001P000005W5n8000000000000ZKgX00800000
1JVmj000000000000:Vmj00300000ZVmj0030000R5B<R5B<00@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H00002ZKgX00D0002Y_NP00000002Y_NP02@00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000iYn/`040000Re>8000000000ZVm
j0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000>Y_NP01P00068gQ`000:Vmj00008UCR`800002E1a/00D00028DHR8DHP0002E
F8H00P000003ZKgX0000000000@000000jVmj00000000007000000NY_NP000000000002Y_NP0002Y
_NP01P000003ZKgX0000000000@000000jVmj00000000004000000BY_NP00000002Y_NP200000ZVm
j0060000SE^A0000ZKgX0000ZKgX0P0000=SF[8200000X]BQP030000000R000000<000000l9iO`00
00000007000000H]37@00000003QUW`0002dKX82000000BcKH400000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP6000000bDF8D000000000002Y_NP0002Y_NP00027CXD0002Y
_NP0000205KA00<0002<DhL000000jVmj0040000R527R527R5270`0000F;EH/2000000>Y_NP00000
00000P0000:Y_NP6000000>Y_NP0000000001`000003ZKgX0000000000@000000jVmj00000000006
000000FY_NP000000000002Y_NP01P000003ZKgX0000000000@0002Doooo001loooo00<0003ooooo
ool00_ooo`030000oooo000002_oool4000000FY_NP000000000002Y_NP00P000003ZKgX00000000
00:Y_NP2000000BY_NP0000000000002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003
000000JY_NP000000000002Y_NP00002FRMg0P000006PTR10000SDn0SDn00000]G:60P000006mK9m
000000000000VEj:00000Z1RQ`040000gI^<000000000YiQQ`8000000iQIP`0000000006000000>L
GhP0002?EXP00P000004ZKgX00000000ZKgX0`0000:Y_NP2000000JY_NP00028E8b8E8`0002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP900000jVmj0X000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX00000000QTf4000000:JO[<200000X]CR0@00002
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP600000ZVmj0060000HSN70000ZKgX0000RE>;0P00009D76`01@0008QAR8QAR000
09EHQP06000000>Y_NP00000000010000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
000000>Y_NP00000000010000003ZKgX0000HeZb009SF[8200000X]BQPH000000l9iO`000000000<
000000BdKX800000002cKH43000000FY_NP000000000002Y_NP00P000003ZKgX0000000000@00000
0jVmj00000000003000000>DF8D0000000000`000003ZKgX0000Qdj500<0000205KA00<0002<DhL0
00000jVmj0040000R527R527R5270P000003ZKgX0000ReF;00>;EH/3000000>Y_NP0002Y_NP01P00
0003ZKgX0000000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000
00000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0P0009Coool007goool01`000?ooooooooooo`000?ooo`00000Yoooo10000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000006ZKgX00000000ZKgX0000ZKgX0P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX
0000000000000ZVmj0@000001:Vmj00000000:Vmj0<000001JVmj00000000:Vmj0000002FRMg0P00
0004PTR10000SDn0SDn00P000003lZeo0000mK9m00<0000019UNRP000:1RQj1RQ`@00002WV670P00
0003V5V30000000000L00002SeJ80`000004ZKgX00000000ZKgX10000005ZKgX0000ZKgX0000R5B<
00<000001JVmj000000000000:Vmj002000000>Y_NP0000000001`000004ZKgX00000000ZKgX1@00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`0000B6CH@2000018]CR0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002
ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000003ZKgX0000000000:Y_NP0
1000068gQ`000:Vmj0D0000015@LK00008QAR00000:EF8H3000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000000jVmj0000000000200000ZVmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002
ZKgX100000=SF[8200000X]BQPH000000l9iO`0000000009000000CcW3P00000002dKX82000000>c
KH40000000000P000003ZKgX0000000000L000000jVmj00000000006000000VDF8D0002Y_NP0002Y
_NP0002Y_NP00027CXD00P000005ZKgX000005KA0000S5>700800002ZKgX00@00028D8N8D8N8D8L2
000000>Y_NP0002;EH/00h]ER`030000ZKgX000000<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX1P000003ZKgX0000000009?oool007goool01`000?oo
ooooooooo`000?ooo`00000Voooo10000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000BY_NP0000000000002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<000001:Vmj0000:Vmj000009J9gL300000he?P08000000o:]O`000?FbO@03
000000BIGXX0002PHXNPHXL4000000FNHHL0003ob7/0002HFH<00`000009Y6B6000000000000W5n8
0000SeJ80000e/Y;00<000000jVmj00000000002ZKgX00T0002Y_NP00000002Y_NP00028E8`0002Y
_NP00P000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vmj0<000000jVmj00000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000FY_NP00000002Y_NP000001HI=Q0030000Re>8Re>800:;DhP00`0008a@P`000002000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP4000000>Y_NP0000000001@000003ZKgX0000000000L000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0T0000015@LK00008QAR00000:EF8H01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<00003HeZb0P0000:;DXH6000000?2NGl00000000010000003ZKgX
00000000008000001?>L>00000000;A^PP8000000k=]P@0000000006000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>DF8D0000000000`000003ZKgX0000Qdj500@000000`1Fd@00
08aCQ`0200000ZVmj0040000R527R527R5270P000003ZKgX0000ReF;00>;EH/200000ZVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000000jVmj000
0000000200000ZVmj0H000000jVmj00000000007000000>Y_NP000000000100009;oool007coool0
0`000?ooo`000002oooo00<0003oool000009?ooo`@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY
_NP00000002Y_NP4000000BY_NP0001J9gMJ9gL300000he?P0<00002mK9m0`000004VEj:0000X6:7
X6:70`0000:NHHL01@000?o8N`0000000?BaP002000000NTI8H000000000002LGhP0002?EXP00P00
0004000T0000000000000ZVmj0@000000jVmj00000000004000000BY_NP00000002Y_NP5000000FY
_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0030000QTf4QTf4
00>6CH@00`0008]CR8]CR002Re>800<0002<D8<000000`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1P000003ZKgX0000000000T000001JVmj000000000000:Vmj006000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0002Y_NP01P000007ZKgX00000000E1a/0000
R568000000:EF8H2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000001:Vmj000
0000000000:Y_NP7000000>Y_NP0000000000f=J/P040000Re:6Re:6Re:61P000003`WUo00000000
00T000001?>L>00000000;A^PP8000001;=]P@0000000:Vmj08000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000007ZKgX000000000000U5R50000ZKgX00<000000jVmj000
08M>Q@04000000<0E]40002<DhL00P0000:Y_NP0100008Q@QhQ@QhQ@Q`8000000jVmj00008]ER`03
ReF;00D0002Y_NP00000002Y_NP01P000003ZKgX0000000000@000000jVmj00000000007000000NY
_NP000000000002Y_NP0002Y_NP01P000003ZKgX0000000000@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj080002Boooo001moooo00<0003oooooool00_ooo`030000oooooooo023oool4
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj00200000ZVmj0050000ZKgX00000000ZKgX008000000jVmj00000000002ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP3000000>Y_NP0001J9gL00UXWM`800003SDn00`000003mK9m
0000000000<00003X6:70`0000:NHHL2000000JHFH<00000003SWXH0002TI8H3000000>LGhP0002?
EXP00`000003VEj:00000000008000000jVmj00000000002000000>Y_NP0000000002P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800003ZKgX00<00026CHB6CH@00hI=Q0030000
Re>8Re>800:;DhP00`0008a@P`000004000000BY_NP00000002Y_NP9000000>Y_NP0000000001000
0003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000020000004E1a/0000R568
00000YEHQP<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000BY_NP00000002Y_NP6000000>Y_NP0000000001`000003ZKgX0000000000H000001JVmj000
000000000:Vmj00600000f=J/P030000Re:6Re:600H000000l9iO`0000000009000000CcW3P00000
002dKX82000000FcKH4000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000BY_NP00000002DF8D2000000>Y_NP00000000010000006ZKgX00000000
05KA0000S5>70P0000>Y_NP00`0008Q@QhQ@Q`02000000>Y_NP0002;EH/00X]ER`T000000jVmj000
00000004000000>Y_NP00000000010000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
0000TOooo`00Xoooo`@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0P0000:Y_NP2000000BY_NP00000002Y_NP2
000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0@000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj08000000jVmj00005XWM`02FRMg0P0000>=Ch03000000?e/Wd00000
00000`0000:PHXL010000=fKS000000000:NHHL2000000JHFH<00000003SWXH0002TI8H200000YaO
R0030000SeJ80000008000000iUNRP000000000300000ZVmj0T000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP0
00000jVmj0030000QTf4QTf400>6CH@00`0008]CR8]CR002Re>800D0002<D8<00000002Y_NP02@00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP9000000BY
_NP00000003/RbH300000iEHQP@000001:Vmj00000000:Vmj0H000000jVmj0000000000200000ZVm
j0T000000jVmj00000000004000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0800003HeZb00@0002;DXJ;DXJ;DXH5000000?2
NGl00000000010000003ZKgX00000000008000001?>L>00000000;A^PP8000000k=]P@0000000002
000000BY_NP00000002Y_NP6000000BY_NP0000000000002ZKgX0`000005U5R5000000000000ZKgX
00P000000`1Fd@0008aCQ`0200000jVmj0040000R527R52700000ZVmj0040000ReF;ReF;ReF;0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP6000000>Y
_NP0000000001P00097oool00:3oool4000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000
008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX00000000ZKgX0000
ZKgX000000=J9gL200000Xe?P0050000]G:600000000mK9m00D00002X6:700@0003MVh`000000002
WV670P000004V5V300000000hij610000003W5n80000SeJ800<000000iUNRP000:=TR003000000>Y
_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj0000000000000>Y_NP00`0008I=Q8I=Q002QTf40P0000>;DhP00`0008a@
Pha@P`06000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000003ZKgX0000k8/V00<00003
UER600<0002Y_NP0000020000007ZKgX000000000000ZKgX0000ZKgX00H000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000
ZKgX0`000005ZKgX00000000ZKgX000000=SF[80100008]BQX]BQX]BQPD000000l9iO`0000000009
00000_>L>0050000]6j200000000/ff100/000000jVmj00000000006000000BY_NP00000002DF8D:
000000RY_NP000000000002<DhL000199H800002ZKgX00@00028D8N8D8L00002ZKgX00@0002;EH^;
EH^;EH/4000000>Y_NP0000000000X]ER`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0H00002ZKgX00D0002Y_NP00000002Y_NP01P000003ZKgX0000000000L000000jVmj00000000004
000000>Y_NP0000000000ZVmj0030000oooooooo08koool009goool5000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP400000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000006ZKgX
000000000000ZKgX00000eXWM`060000SDn0SDn0SDn00000]G:60P000004mK9m00000000mK9m0P00
00:PHXL010000=fKS000000000:NHHL2000000BHFH<00000003SWXH4000000>LGhP0002?EXP00`00
0003VEj:0000XfB800H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP600000jVmj0030000
QTf4QTf400:6CH@200000h]CR0030000S523S52300<000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y
_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00:Y_NP7000000>Y_NP0000000000P000004k8/V0000000000000iEHQPD000001:Vmj00000000:Vm
j0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0<00000
1:Vmj0000000000000=SF[80100008]BQX]BQX]BQPD000000l9iO`0000000004000000>Y_NP00000
00000P0000;cW3P01@000;A^PP0000000;=]P@05000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0030000ZKgX000000<000000iAHQ@000:Vmj002000000FY_NP000000000002Y_NP00P00
0007ZKgX00000000S5>70000BBF2000000:Y_NP00`0008Q@QhQ@Q`02000000>Y_NP0002;EH/00X]E
R`D00004ReF;1P000003ZKgX0000000000L00003ZKgX2P000003ZKgX0000000000@000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX100008ooool009_oool4000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000AJ9gL01P0008e?P8e?P8e?P0000;Eb
QP8000001OFbO@0000000?FbO@000003X6:710000005WV670000olQk0000V5V300<000001jATQP00
0>7DF`0009aOR00008mFR00200000YUNRP8000001NBSR`00000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y
_NP0000000000P0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj000
00000:Vmj0T000000jVmj00000000003ZKgX00<00026CHB6CH@00XI=Q0800003Re>800@0002<D8<0
003g/WL3000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj000
0000000000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP6000000>Y_NP0000000000P000003ZKgX0000000000P000000jVmj0000000000200000iEH
QP8000001JVmj000000000000:Vmj002000000>Y_NP0000000000P0000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj0<000001:Vmj00000000:Vmj0H00003HeZb00@0002;DXJ;DXJ;DXH5000000?2NGl00000
000020000005;@ad0000li`h0000]6j2008000001;=]P@0000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000004ZKgX00000000000n0`000003ZKgX0000000000@000000jVmj00000000002
000000B<DhL000199H800002ZKgX00<00028D8N8D8L00P0000:Y_NP00`0008]ERh]ER`02000000>Y
_NP0002;EH/018]ER`<000000jVmj00000000004000000BY_NP00000002Y_NP9000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj080002?oooo002Hoooo1@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00AJ9gL01P0008e?P8e?P8e?P0000;EbQP8000001OFbO@0000000?FbO@000003X6:70`0000:NHHL0
10000?o8N`0009QIP`<000000jATQP0000000002W5n800@0002?EXP000000002VEj:0`000005n/aQ
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP9000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000QTf4QTf400:6CH@2
00000h]CR0060000S5230000mk9g0000ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0T000000jVmj00000000006000000FY_NP000000000002Y_NP00P00
0003ZKgX00000000008000000nb;9P0009EHQP03UER60`000005ZKgX000000000000ZKgX00800002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1P000003ZKgX0000ZKgX00<000000jVmj00000000007000000>Y_NP00000
00000f=J/P040000Re:6Re:6Re:61@000003`WUo0000000000D000000jVmj00000000002000000?c
W3P0002dKX800P000005/ff1000000000000ZKgX00<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000>Y_NP0000000003`000004S5>70000BBF200000ZVmj0030000R527R52700<00000
1:Vmj00008]ERh]ER`8000000jVmj00008]ER`04ReF;10000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP6000000>Y
_NP00000000010000003ZKgX0000ZKgX00<000000jVmj0000000002>oooo002Eoooo10000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0001J9gL00eXWM`060000SDn0SDn0SDn00000
]G:60P000005mK9m00000000mK9m000000>PHXL300000YiQQ`800002V5V30`000003Y6B600000000
00:LGhP300000YUNRP030000XfB8000000H000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000P00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj0000:Vmj:Vmj0000004QTf40P00
00:;DhP00`0008a@Pha@P`04000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000003k8/V
0000UER600>EF8H01@000:Vmj00000000:Vmj00300000ZVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0H000000jVmj0000000000700000ZVmj0@000000jVmj00000000004000000BY
_NP00000002Y_NP3000000>Y_NP0000000000V=J/P040000Re:6Re:6Re:61@000003`WUo00000000
00X000000o>L>0000;A^PP02000000>cKH40000000000P000003ZKgX0000000000T00002ZKgX2@00
0003ZKgX0000000000@000002:Vmj0000000000008aCQ`0004TUPP0000:Y_NP00`0008Q@QhQ@Q`03
000000RY_NP0002;EH/00036R940002Y_NP00004ReF;00<0002`Lhh000000`000004ZKgX00000000
ZKgX1P0000:Y_NP01@000:Vmj00000000:Vmj006000000>Y_NP0000000001`000003ZKgX00000000
00@00002ZKgX10000003ZKgX0000000000@0002=oooo002Coooo1`0000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVm
j0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj08000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000AJ9gL0100008e?P8e?P8e?P08000000o:]O`00
0?FbO@02000000Ke/Wd0002PHXNPHXL0003MVh`200000YiQQ`800002V5V30`000003Y6B600000000
00:LGhP300000YUNRP030000XfB80000008000000nNYT00000000002000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000003ZKgX0000000000800002ZKgX00<00026CHB6CH@00XI=Q0800002Re>800<0
002<D8><D8<01@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00:Y_NP01@000:Vmj00000000:Vmj009000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
00000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000000nb;9P0009EHQP03
UER60P000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0T00000
0jVmj00000000004000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX0000HeZbHeZb000000>;DXH5000000?2NGl00000
000010000004ZKgX00000000ZKgX0P000003li`h0000]6j2008000000k=]P@0000000006000000>Y
_NP0000000000ZVmj0030000ZKgX000000`000000jVmj00000000004000000>Y_NP0000000000`00
0004BBF20000ZKgX00000XQ@Q`<000000jVmj00008]ER`0200000ZVmj0030000ReF;ReF;00:;EH/0
0`000;1cSP000002S5N=200000>Y_NP:000000>Y_NP00000000010000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj080002=oooo002A
oooo0P000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800002
ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00AJ9gL0100008e?P8e?P8e?P0<00002mK9m0P000006mK9m0000X6:7X6:70000gI^<0P0000:NHHL2
000000>HFH<0003d/H000P000007Y6B60000W5n8W5n80000SeJ8000000>IGXX00`000:=TR0000003
000000>QHhL0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP6000000>Y_NP0002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0070000
QTf4QTf4QTf40000SE63000000:;DhP00`0008a@Pha@P`02000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001:Vmj0000000000000:Y_NP:000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000007ZKgX00000000ZKgX0000k8/V000000BEF8H6000000>Y_NP0000000000P00
00:Y_NP9000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002HeZb00@0002;DXJ;
DXJ;DXH5000000?2NGl0000000002P000003li`h0000]6j2008000000k=]P@0000000003000000BY
_NP0000000000002ZKgX10000004ZKgX00000000ZKgX1P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj004000000A99H80002Y_NP00002R5271@000003ReF;0000000000:Y_NP0
0`0008]ERh]ER`02ReF;00<0002`Lhh000000XaGS@8000001:Vmj00000000:Vmj0T000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000000jVmj00000000002
00000ZVmj0H000000jVmj0000000002<oooo002>oooo0`000003ZKgX0000000000>Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800004FRMg00@0002=Ch2=
Ch2=Ch03000000Ke/Wd000000000003e/Wd00002X6:700@0003MVh`000000002WV670P000007V5V3
00000000hij60000Y6B6000000:LGhP00`0008mFR0000003VEj:00<0002SI8P000000`000003XF>7
0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@00
00:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP200000ZVmj0070000QTf4QTf4QTf40000SE63000000:;DhP00`0008a@
Pha@P`03000000FY_NP000000000002Y_NP00P000003ZKgX0000000000d000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002
ZKgX0`000004ZKgX00000000ZKgX0`000006ZKgX000000000000k8/V000019EHQP<000001jVmj000
000000000:Vmj0000:Vmj006000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00002HeZb00@0002;DXJ;DXJ;DXH5000000?2NGl00000
00001@000003ZKgX00000000008000000o>L>0000;A^PP02000000FcKH4000000000002Y_NP00P00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP6000000>Y_NP00000
000010000003ZKgX0000000000D0000014TUPP000:Vmj00000:8D8L00`000:Vmj0000002000000>;
EH/0000000000ZVmj0030000ReF;ReF;00:;EH/00`000;1cSP000002S5N=0`000004ZKgX00000000
ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP9000000NY_NP00000
0000002Y_NP0002Y_NP01P000003ZKgX0000000000@0002;oooo002<oooo0`000004ZKgX00000000
ZKgX10000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000FY_NP00000002Y_NP0000015XWM`050000SDn0SDn00000]G:6008000001_FbO@0000000000
0?FbO@0000:PHXL00`000=fKS0000002WV6700@0003ob7/0002HFH<2000000CSWXH0000000000002
W5n80`0000>IGXX2000000?TXh/0000000000P000003]jLI0000000000<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000
002Y_NP000000ZVmj0090000QTf4QTf4QTf40000SE630000Re>8000000><D8<4000000>Y_NP00000
00001`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj0H000000nb;9P0009EHQP02UER600<0002Y_NP000000P0000:Y_NP4
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0H000000jVmj0000000000700000V=J
/P040000Re:6Re:6Re:61@000003`WUo0000000000H000001jVmj000000000000?>L>0000;A^PP02
000000>cKH40000000000P000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NPB
000000JY_NP000199H80002Y_NP00002R5271@000003ReF;0000000000>Y_NP0100008]ERh]ERh]E
R`800002S5N=200000:Y_NP01@000:Vmj00000000:Vmj006000000>Y_NP0000000001`000004ZKgX
00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP20000Rooo
o`00ROooo`<000001JVmj000000000000:Vmj002000000>Y_NP0000000000P0000:Y_NP2000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001ZVmj00000000:Vmj0000:Vmj08000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00004FRMg00D0002=Ch2=Ch00002e
LXH00P000003mK9m0000000000<00002X6:70`0000:NHHL010000?o8N`0009QIP`8000000n>NQP00
00000003W5n80`0000:IGXX010000:=TR0000>BSR`D000000iiOQ@0000000003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj0000000000200000ZVm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj0000000000000:Y_NP02@0008I=Q8I=Q8I=Q00008eAP`0008]CR0000003S52320000004ZKgX
00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj000
00000:Vmj0T000001JVmj00000000>b;9P000003UER60P000003ZKgX00000000008000000jVmj000
00000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>Y_NP00000000020000003ZKgX0000000000@000001:Vmj000
00000:Vmj0800002HeZb00@0002;DXJ;DXJ;DXH5000000?2NGl0000000001`000006ZKgX00000000
li`h0000]6j20P000003/ff10000000000H000000jVmj0000:Vmj003000000>Y_NP0000000002P00
0003ZKgX0000000000@000000jVmj00000000004000000A99H80002Y_NP00002R5270P000004ZKgX
00000000ReF;0P0000>Y_NP0100008]ERh]ERh]ER`800002S5N=1@0000>Y_NP:000000>Y_NP00000
000010000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj080002:oooo0027oooo0`000004ZKgX00000000
ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj002000000>Y_NP0000000000ZVm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0
002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000eXWM`060000SDn0SDn0SDn00000]G:60P000004mK9m
00000000mK9m0P0000:PHXL300000YiQQ`800002V5V30P000003hij60000000000>LGhP200000iUN
RP030000XfB8000000H000000iiOQ@0000000004000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP00000
002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX00@0002Y_NRY_NP00003
QTf400D0002=DH<0002;DhP000000ha@P`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj0<00000
1:Vmj0000>b;9P0000>EF8H3000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0/000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000006=J/P000002Re:600<0002Y_NP000000`000003`WUo0000000000@000000jVmj00000000003
000000?cW3P0002dKX800P000003/ff10000000000<00002ZKgX10000003ZKgX0000000000@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<0000013b2j000
0000000000:Y_NP0100008Q@Q`000:Vmj0@000000lJ8T@000:Vmj002ZKgX00H0002;EH^;EH/0002`
Lhh00002S5N=0`000003SEV?0000000000H000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0H000000jVmj00000000002000000>Y_NP0000000001@000003ZKgX
0000000000L00029oooo0024oooo0`000005ZKgX000000000000ZKgX008000001:Vmj00000000000
00:Y_NP4000000BY_NP00000002Y_NP200000ZVmj08000001:Vmj00000000:Vmj08000001JVmj000
000000000:Vmj002000000BY_NP0000000000002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000006ZKgX
000000000000ZKgX00000eXWM`060000SDn0SDn0SDn00000]G:60P000004mK9m00000000mK9m0P00
0003X6:70000gI^<00800002WV670P0000:HFH<3000000NTI8H0002LGhRLGhP0002?EXP000000iUN
RP030000XfB80000008000001NNYT0000000000009iOQ@07000000BY_NP00000002Y_NP3000000>Y
_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj002000000BY_NP0000000000002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@0000:Y_NP02@0008I=
Q8I=Q8I=Q00008eAP`0008]CR0000003S5230`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0/000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0003ZKgX00000000008000000nb;9P0009EHQP02UER600D0002Y_NP00000002Y_NP0100000:Y_NP3
000000BY_NP00000002Y_NP6000000>Y_NP0000000001`000003ZKgX0000000000:Y_NP01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000NY_NP00000
002Y_NP0001SF[8000000X]BQPH000000l9iO`000000000:000000?cW3P0002dKX800P000003/ff1
0000000000D000000jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0004ZKgX00000000ZKgX1P000003ZKgX00000000008lP^P0200004TUPP000:Vmj00008Q@Q`000:Vm
j0@000000lJ8T@000:Vmj002ZKgX00H0002;EH^;EH/0002`Lhh00002S5N=0`000003SEV?00000000
00800002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000003ZKgX00000000
00H000001JVmj000000000000:Vmj006000000BY_NP00000002Y_NP20000ROooo`00POooo`@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP2000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP400000eXWM`060000SDn0SDn0SDn00000]G:60P00
0004mK9m00000000mK9m0P000003X6:70000gI^<00800002WV670P0000:HFH<3000000BTI8H0002L
GhRLGhP300000iUNRP030000XfB8000000<000000j5SQ`0000000002000000?TWhH0003JVY001000
0004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@000003ZKgX0000QTf4
00:6CH@0100008eAP`00000000B<D8<4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000000jVmj00000000002
ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003k8/V0000UER600:EF8H2000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00T00000
0jVmj00000000004000000BY_NP00000002Y_NP300000ZVmj0@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0L0000016=J/P0008]BQX]BQPH000000l9iO`00
00000005000000NY_NP000000000000]37@0003cW3P00`000005/ff1000000000000ZKgX00@00000
0jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP0000000002P000003ZKgX00000000
00@000002Cb2j000000000000:Vmj00008Q@Q`000:Vmj004000000?6R940000000000ZVmj0060000
ReF;ReF;0000/7>>00000XaGS@<000001HeIS`00000000000:Vmj002000000>Y_NP0000000001000
0003ZKgX0000000000L000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP0
0000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P0008Soool007ooool3
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000002
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX0000
0000ZKgX008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00003FRMg00H0002=Ch2=Ch2=Ch00002eLXH2000000Ce/Wd00000003e/Wd2000000>PHXL0003M
Vh`00P0000:NHHL200000YQIP`<000001:ATQP0009aOR9aOR0<00002VEj:00<0002SI8RSI8P01000
0003XF>70000000000H000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX
00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX2`000005ZKgX0000QTf4QTf4000000:=DH<2000018a@
P`D000001:Vmj00000000:Vmj0<000000jVmj00000000002RUJ=00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000?/RbH0002EF8H00YEHQP<00002
ZKgX2P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1000
0003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000001:Vmj000
00000000009SF[800`0008]BQP000005000000?2NGl0000000001P000003ZKgX0000000000800000
1O>L>000000000000;=]P@04000000>Y_NP0000000000P0000:Y_NP6000000>Y_NP0000000001`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP00`0003b2j3b2j002000000FY_NP00028
D8L0002Y_NP010000003aXRA0000000000:Y_NP01P0008]ERh]ER`000;1cSP0000:<Ehd4000000>F
GHX0000000001`000003ZKgX0000000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000004ZKgX00000000ZKgX1P000003ZKgX0000000000L00027oooo001loooo1000
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000>Y
_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX10000003ZKgX0000000000<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800003FRMg00@0002=Ch2=
Ch2=Ch02000000?b[Gl0003e/Wd00P000006mK9m00000000X6:70000gI^<0P000004WV670000olQk
00000YQIP`<000001:ATQP0009aOR9aOR0<00002VEj:00<0002SI8RSI8P010000003XF>700000000
00L000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX0000000000@00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000000jVmj0000000000200000ZVmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000003000000>Y_NP0000000000ZVmj0<000001JVmj00008I=Q8I=Q0000002
SE630P0000B<D8<2000000FY_NP000000000002Y_NP00P000004ZKgX00000000000018YFS@800000
1:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
00000iEHQPT000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP9000000BY
_NP00000002Y_NP3000000>Y_NP0000000000V=J/P040000Re:60000ZKgX10000003`WUo00000000
00L000001JVmj000000000000?>L>003000000>cKH40000000000`000003ZKgX0000ZKgX00H00000
0jVmj00000000004000000>Y_NP00000000010000004ZKgX00000000ZKgX0`0000:Y_NP4000000Ll
P^P00000002Y_NP00028D8L000000ZVmj0<000000lJ8T@0000000002ZKgX00d0002;EH^;EH/0002`
Lhh0002<Ehd0002BF8P0002=FHl0002FGHX00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX1P000003ZKgX00000000008000000jVmj00000000008000000>Y
_NP00000000010000004ZKgX00000000ZKgX0P0008Ooool007[oool3000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00200000ZVmj0050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000@000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj000
05XWM`02FRMg00@0002=Ch2=Ch2=Ch02000000?b[Gl0003e/Wd00P000006mK9m00000000X6:70000
gI^<0P000007WV670000olQk0000V5V30000m;60008000001:ATQP0009aOR9aOR0<00002VEj:00@0
002SI8P0003TXh/3000000>QHhL0000000001@000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX100000:Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0D000001:Vmj0000000000000:Y_NP5000000FY_NP00026CHB6CH@0
00000XeAP`800004S5230`000005ZKgX000000000000ZKgX008000000jVmj00008YFS@04RUJ=2@00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T00003UER61@0000:Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP400000ZVmj0T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1ZVmj00006=J/V=J/P0008]BQPH000000l9iO`0000000005000000BY_NP00000002Y_NP2000000Gc
W3P000000000002cKH400`000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0H000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000
00@000001:Vmj00008Q@Q`0000:Y_NP400000U/fRP030000ZKgX000000:;EH/02P000;1cSP0008aG
S@00099HR00008eIS`0009IMRP@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T00000
0jVmj00000000006000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000>Y_NP000000000Q_ooo`00Moooo`@000000jVmj00000000002
ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000>Y_NP0000000000ZVm
j0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`00
00=J9gL0100008e?P8e?P8e?P0<000001OFbO@00000000000?FbO@02000000>PHXL0003MVh`00P00
0003WV670000000000:HFH<2000000GSWXH000000000002LGhP0100000:IGXX01P000:=TR0000>BS
R`000>NYT0<000000iiOQ@0000000004000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVm
j0030000ZKgX000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001JVmj00008I=Q8I=Q0000002SE6300<0002<D8><
D8<00ha@P`@000001:Vmj0000000000000>Y_NP00`0008YFSHYFS@02RUJ=00D00026C8@00000002Y
_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000003ZKgX0000000000800002ZKgX0`000004ZKgX00000000ZKgX2@000004ZKgX
00000000ZKgX0P0000>EF8H01@000:Vmj:Vmj0000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000001000
0003ZKgX0000ZKgX00H000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001jVmj00006=J/P0008]BQP000:Vmj004000000?2NGl0000000002`000005li`h
000000000000/ff100@000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP6000000>Y_NP0000000004P0000>Y_NP00`0008aGS@000002000000AK=XX0002Y_NP00002
ReF;00`0002`Lhh0002<Ehd0002BF8P0002=FHl0002FGHX0002Y_NP6000000>Y_NP0000000001`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP90000QOooo`00MOooo`@000000jVmj00000000002
ZKgX0P000004ZKgX00000000ZKgX0P000005ZKgX000000000000ZKgX008000000jVmj00000000002
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0P0000:Y_NP2000000FY_NP000000000002Y_NP010000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00800003FRMg00D0002=Ch2=Ch00002eLXH00P000005mK9m00000000
0000mK9m008000000j1RQ`0000000002000000>NHHL0000000000YQIP`8000001N>NQP0000000000
09aOR004000000BIGXX0002SI8RSI8P3000000GWZI0000000000002NGhD01`000004ZKgX00000000
ZKgX0`0000:Y_NP6000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000JY_NP000000000002Y_NP00002QTf400@0002=DH>=DH<00005S5230P000004ZKgX00000000
ZKgX0P0000>Y_NP00`0008YFSHYFS@02RUJ=00<00026C8@000000P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vm
j00000000:Vmj009000000BY_NP00000002Y_NP3000000JY_NP000000000003/RbH00002UER61@00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@0000:Y_NP4
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP4000000=SF[80002;DXH01P000003`WUo0000000000H000000jVmj00000000002
000000GcW3P0002dKX80002cKH401@000003ZKgX00000000008000001:Vmj00000000:Vmj0H00000
0jVmj00000000007000000BY_NP00000002Y_NP400000ZVmj0<000001:Vmj0000000000000>Y_NP0
0`0008aGS@000002000000IK=XX0002Y_NP0002;EH/00002/7>>00@0002<Ehd0002BF8P200000YIM
RPD000000jVmj00000000004000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVm
j0@000001:Vmj00000000:Vmj0H000000jVmj00000000007000000BY_NP00000002Y_NP20000QOoo
o`00L_ooo`D000001:Vmj00000000856O`<000001:Vmj000000008YHT@8000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX100000:Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0001J9gL00UXWM`050000SDn0SDn00000]G:600800000
0oFbO@0000000002000000Ce/Wd00000003MVh`3000000>NHHL0000000000YQIP`8000001N>NQP00
0000000009aOR004000000BIGXX0002SI8RSI8P4000000BQHhL00000002NGhD3000000?JVY000000
00000P000004ZKgX00000000ZKgX20000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX
00000000008000001JVmj00000000:Vmj0000002QTf400@0002=DH>=DH<00004S52300<0003g/WL0
000010000003ZKgX0000ZKgX00:Y_NP01@0008YFSHYFSHYFS@000002QTb410000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP:000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP00000003/RbH000000YEHQP030000ZKgX0000
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP:000000=SF[80002;DXH00`000004<@aa00000000`WUo2@000009ZKgX000000000000li`h
0000]6j20000/ff100H00002ZKgX2@000003ZKgX0000000000L000001JVmj000000000000:Vmj002
00000ZVmj0050000ZKgX00000000ZKgX00L00002ZKgX00<0002<Ehd000000P000006FcJ:0000ZKgX
0000ReF;00000[1cSP040000S5N=0000TUR80P0000:FGHX2000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000000jVmj00000000004000000>Y_NP0000000000P000003ZKgX
0000000000P000000jVmj00000000004000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
0000Q?ooo`00Koooo`@000000jVmj0000000000200001856O`<00002RURA00D0000W03d00000002Y
_NP00P0000:Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
00:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX008000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00003FRMg00D0002=Ch2=Ch00002eLXH00P00
0003mK9m0000000000<000000j1RQ`000=fKS003000000>NHHL0000000000YQIP`8000001N>NQP00
0000000009aOR004000000BIGXX0002SI8RSI8P4000000BQHhL00000002NGhD500000XA:PP800000
0jVmj00000000004000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP9000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000ZKgX000000800000
1:Vmj00008I=Q00000>=DH<00`0008a@Pha@P`02S52300@0003g/WL000000004ZKgX0P0000:Y_NP0
1@0008YFSHYFSHYFS@000002QTb41@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX20000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX0000k8/V00000YEHQP8000000jVmj00000000002000000BY_NP00000
002Y_NP9000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000003HeZb
0000Re:600<00002<@aa00<00032NGl000002@000008ZKgX00000000li`h0000]6j20000/ff11000
0003ZKgX0000000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX1P0000:Y_NP00`0008aGSHaGS@0200000U/f
RP80000018]ER`000;1cS[1cSP800002TUR80P0000:FGHX3000000FY_NP000000000002Y_NP00P00
0003ZKgX0000000000L000000jVmj0000000000:000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP90000Poooo`00KOooo`L00002ZKgX0P0000B1AWl200000hYH
T@8000000jVmj00000000002ZKgX0P000004ZKgX00000000ZKgX0P000003ZKgX0000000000800002
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0006ZKgX00000000ZKgX0000ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0@000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00003FRMg00D0002=Ch2=Ch00002eLXH00P000004mK9m00000000mK9m0P000003X6:70000gI^<
0080000019iQQ`000?o8N`0000:HFH<3000000BTI8H00000002LGhP4000000BIGXX0002SI8RSI8P4
000000BQHhL00000002NGhD400000hA:PPD00002UgF[0`0000:Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0030000
ZKgX000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<00002ZKgX10000007ZKgX00000000ZKgX0000QTf4000000>=DH<00`0008a@Pha@P`02S5231000
00BY_NP200000ZVmj0050000RUJ=RUJ=RUJ=000000:6C8@6000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP:000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000004k8/V0000UER6UER60`000003ZKgX0000000000P00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0`00
0004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP0100006=J
/P0008]BQP@000000c4<L@000<9iO`07000000>Y_NP0000000000`000005li`h0000]6j20000/ff1
00D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000BY
_NP00000002Y_NP4000000>Y_NP0000000002P000004ZKgX0000ZKgX00000XaGS@800002FcJ:00@0
002Y_NP000000002/7>>0P0000:BF8P200000YIMRP050000ZKgX00000000ZKgX00T000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP20000Poooo`00J_ooo`<000001:Vmj000
00000:Vmj0800003ZKgX00<00021AWn1AWl00X56O`<00002RURA00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX0P000003ZKgX0000000000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000eXWM`050000SDn0SDn00000]G:6
008000001?FbO@0000000?FbO@8000000j1RQ`000=fKS002000000BNHHL0003ob7/00002V5V30`00
0003Y6B60000000000D000001IUNRP000:=TR0000>BSR`03000000BQHhL00000002NGhD400000hA:
PP<00003UgF[0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP6000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX
0000000000@000001:Vmj00008I=Q00000>=DH<00`0008a@Pha@P`02S5230P000003ZKgX0000ZKgX
00>Y_NP200000ZVmj0040000RUJ=RUJ=00000hI<Q0<000001JVmj000000000000:Vmj002000000>Y
_NP0000000001`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001>b;9P0009EHQYEHQP@00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00T000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<00002ZKgX0`000005HeZb0000Re:60000ZKgX00800000
0c4<L@000<9iO`0<000000H]37@00000002dKX80002cKH46000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP?000000BY_NP00000002Y_NP4000000RY_NP0002Y
_NP0002<Ehd0002>FY000002FcJ:00P0002Y_NP00000002`Lhh0002<Ehd00002TUR800@0002FGHZF
GHZFGHX8000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
00000ZVmj0H000000jVmj00000000007000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVm
j0030000oooooooo083oool006Soool2000000FY_NP000000000002Y_NP00P000003ZKgX0000ZKgX
00:Y_NP00`000856Oh56O`02PDIo0`0000::F942000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP200000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y
_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001JVmj00000000:Vmj0000003FRMg00D0002=Ch2=Ch00002e
LXH00P000004mK9m00000000mK9m0P000003X6:70000gI^<008000000iiQQ`0000000003V5V30`00
0003Y6B60000W5n800H00002XfB800H0003TXh/0003WZI00002QHhL4000000?TWhH0000000000hA:
PP800003UgF[1@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX20000004ZKgX00000000Y9g>0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001OFPD@00
000008I=Q0000003SE6300<0002<D8><D8<00Xa@P`@00004ZKgX00D00021B880002Y_NP000000XYF
S@040000QTb4QTb4QTb410000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@00
0004k8/V0000UER6UER60P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP:000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000008Re:600000000
ZKgX0000<@aa0000`WUo20000003ZKgX0000000000@000000kA^PP000;=]P@07000000BY_NP00000
002Y_NP6000000>Y_NP0000000001`000004ZKgX00000000ZKgX10000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<000001JVmj0000:Vmj00008aGS@0400000U/fRP<000001;1cSP0008aGS@00
00:BF8P0100009IMRYIMRYIMRP8000000jVmj00000000002ReB90P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1P000003ZKgX0000ZKgX00H000000jVmj00000000004000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP300000ZVmj0@00021oooo001Uoooo0`000003ZKgX00000000
00:Y_NP200000ZVmj0800002ZKgX00<00021AWn1AWl00h56O`<000000hYHT@0000000002000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1000
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
0000000000000UXWM`040000SDn0SDn0SDn00P000003lZeo0000mK9m008000001_FbO@0000000:1R
Q`000=fKS08000000iiQQ`0000000003V5V30`000003Y6B60000W5n8008000001?FbO@0000000000
00:SI8P020000>BSR`000>NYT0000:5SQ`0009iOQ@<000001]ZJT00008A:PXA:PP0009iOQP800000
19MeZ`0000000:Vmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000000jVmj00000000004000000>Y_NP0000000000P000004Y9g>00000000/ncg0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX
000000000000mJ1A008000000hI=Q00008eAP`02SE6300<0002<D8><D8<00Xa@P`@00004ZKgX00L0
0021B880002Y_NP0002:EXd0000018I<Q08000001:Vmj00000000:Vmj0D000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003000000BY
_NP00000002Y_NP9000000BY_NP00000002Y_NP2000000C/RbH0002EF8JEF8H3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP?000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000FY
_NP000000000002;DXH010000003<@aa0000`WUo00T000000jVmj00000000003000000>dKX80002c
KH400`000003ZKgX0000000000P000000jVmj00000000004000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP400000ZVmj0<000001:Vmj00000000:Vmj0800002ZKgX0P000005S5N=00000000
ZKgX0000009K=XX200000[1cSP030000S5N=000000:BF8P0100009IMRYIMRYIMRP<00004ReB91P00
0003ZKgX0000000000L00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX2`000004ZKgX000000000000POooo`00Hoooo`<000000jVmj00000000002
ZKgX0P000006ZKgX000000000000ZKgX00000ZVmj0030000PDIoPDIo00>1AWl3000000>:F940002Y
_NP00`000003ZKgX0000000000:8Dh`2000000BY_NP00000002Y_NP3000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX10000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj0000000000200000ZVm
j0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002FRMg00@0002=Ch2=Ch2=Ch02000000?b[Gl0003e/Wd00P000005mK9m00000000
0000gI^<00<000000iiQQ`0000000002V5V300<0003d/H0000000`000004W5n800000000mK9m0`00
00:SI8P4000000BQHhL00000002NGhD400000hA:PP030000WUn6000000D000000jVmj00000000002
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000>Y
_NP0000000000P000003ZKgX00000000008000001;?/m`0000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0L000001OFPD@00000008I=Q0000003
SE6300<0002<D8><D8<00Xa@P`8000000jVmj0000:Vmj003ZKgX00L00021B880002Y_NP0002:EXd0
00000hI<Q0030000Y6B7000000L000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00002
ZKgX10000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0<00000
1jVmj00000000:Vmj0000>b;9P000002UER610000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX2@000003ZKgX0000000000:;EX`300000hYDRP8000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0h000000h]BQP0000000002000000<a37400032NGl01`00
0004ZKgX00000000ZKgX10000003]6j20000/ff100P000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0H000001JVmj000000000000:Vmj00200000ZVmj0050000ZKgX00000000ZKgX00P00002
ZKgX00<0002Y_NP000001000009K=XX200000[1cSP<00002TUR800H0002FGHZFGHX0002Y_NP00005
ReB90`000003ZKgX0000000000@000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP90000P?ooo`00H?oo
o`@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX00<00021AWn1AWl00X56
O`8000000aD0B`0000000002000000BY_NP0000000000003R5><10000004ZKgX00000000ZKgX0`00
00:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP400000ZVmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0002Y_NP00000002Y_NP00`00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000005ZKgX
0000FRMgFRMg000000:=Ch0010000;EbQP000?:]O`@000001OFbO@00000000000=fKS003000000>N
HHL0000000000YQIP`8000001N>NQP000000000009aOR003000000?e/Wd0000000000Z=TR0@00000
1:5SQ`00000009iOQ@@00003Q4Z200D0002NGhH00000002Y_NP010000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0@000000iZhk@0000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP:00000ZVmj0060000mJ1A00000000QTf400000heAP`030000S523S523
00:<D8<400001:Vmj0030000PDR2PDR2008000000hYFS@0008I<Q002QTb400D0002TI8L00000002Y
_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP00000
00000P000003ZKgX00000000008000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000003ZKgX0000000000:EF8H5000000BY_NP00000002Y_NP9
000000BY_NP00000002Y_NP3000018]FS0030000RUB:RUB:00>:E8X3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP4000000JY_NP00000002;DXH0002Y_NP2
000000<a37400032NGl03`000003]6j20000/ff100@00002ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1P000004ZKgX0000000000000ZVmj0X000000jVmj0000000000200000ZVm
j0P00002FcJ:00<0002`Lhj`Lhh00P0000>BF8P01P0009IMRYIMRP000:Vmj00000F;E8T4000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000001@000003ZKgX00000000
00L000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001:Vmj00000000000083oool0
05koool3000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj000
0000000000:Y_NP00`000856Oh56O`02PDIo0P0000045@1;00000000ZKgX0P000003ZKgX0000R5><
00>8Dh`00`000:Vmj0000002000000BY_NP00000002Y_NP400000ZVmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002ZKgX00D0
002Y_NP00000002Y_NP00P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX1000009J9gL01@0008e?P8e?P0000;EbQP02000000Ge
/Wd000000000003e/Wd00`000003gI^<00000000008000001?o8N`0009QIPiQIP`8000001N>NQP00
0000000009aOR003000000?e/Wd0002SI8P00Z=TR0@000001:5SQ`00000009iOQ@@00003Q4Z21@00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX100000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000003ZKgX0000000000:Y_NP0
0`000:Vmj0000002000000CeX540000000000004SE6300<0002<D8><D8<00Xa@P`@00004ZKgX00<0
0021B8:1B880100000>6C8@00`000:ATQ`000002000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP00000000020000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX000000000080000019EHQP0000000:Vmj0@000000jVmj000
00000003000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000001H]FS0030000RUB:RUB:
00>:E8X4000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP6
000000R;DXH00000002Y_NP0000a37400032NGl8000000BY_NP00000002Y_NP3000000>dKX80002c
KH400`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000003ZKgX0000000000X00000
1:Vmj00000000:Vmj0<000000jVmj0000000000200000ZVmj0<000001:Vmj00000000000009K=XX0
0`000;1cS[1cSP0200000i9HR0060000UUf:UUf:0000ZKgX00001H]DR@8000001>O]d@0000000:Vm
j08000000jVmj0000000000=000000>Y_NP00000000010000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX2`000004ZKgX000000000000Ooooo`00Foooo`@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800002ZKgX00<00021AWn1AWl00X56O`800000
11D0B`000000000000>Y_NP0100008QCS8QCS8QCS0<000001JVmj000000000000:Vmj00200000ZVm
j0050000ZKgX00000000ZKgX008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX
0000000000000UXWM`050000SDn0SDn00000]G:6008000000oFbO@0000000002000000Ce/Wd00000
003MVh`4000000Cob7/0002HFH>HFH<2000000?SWXH0000000001@000003mK9m0000XfB800:SI8P4
000000BQHhL00000002NGhD400000hA:PP8000001@00<`00000000000:Vmj004000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX
00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX1@000004ZKgX0000000000000ZVmj0@000001:Vmj00000000?FPD@<00003SE630P0000B<D8<4
00001:Vmj0030000PDR2PDR200@00003QTb400<0002TI8L000000`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000T000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001JVmj0000000000009EHQP03000000>Y_NP00000
000010000005ZKgX000000000000ZKgX008000001:Vmj0000000000000>Y_NP00`0008]FS8]FS002
ReJ<0P0000F:E8X;000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000Re:600@000000c4<L@000<9iO`09000000>Y_NP0000000000`00
0003]6j20000/ff100@000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP0000000000002
ZKgX1`00009K=XX00`000;1cS[1cSP0200000i9HR0060000UUf:UUf:0000ZKgX00001H]DR@040000
ingA0000SEF920000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0D000001:Vmj0000000000007koool0
05Woool3000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP0002Y_NRY_NP000001856O`80000011D0B`000000000000>Y_NP0
1P0008QCS8QCS8QCS0000:Vmj08000001:Vmj0000000000000:Y_NP4000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800002FRMg00D0
002=Ch2=Ch00002eLXH00P000003mK9m00000000008000001?FbO@0000000=fKS0D00003V5V30P00
0003hij60000000000D000002_FbO@000:=TR:=TR0000>BSR`000>NYT0000:5SQ`8000000iiOQ@00
0000000200000hA:PP8000000`00<`000:Vmj002000000>Y_NP0000000000P0000:Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000000jVmj0000?FPD@0300000heAP`800004S5230P000003ZKgX
0000ZKgX00>Y_NP010000858PX58PX58PP<00003QTb400@0002TI8L0002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000000iEHQP00
00000006000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000jVmj0030000ReJ<ReJ<
00:;EX`2000018YDRP030000V5f9000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002ZKgX2`000004<@aa0000`WUo`WUo2@000003ZKgX00000000
008000001;A^PP000;=]PK=]P@X000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@000000jVmj00000000005000000>Y_NP0000000001@000003ZKgX00000000
008000001ZVmj00008aWX`0005/fRP0000:`Lhh200000i9HR0040000UUf:UUf:00000ZVmj0030000
ReB9ReB900:;E8T200000XeER@8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP3000000>Y_NP00000
00000ZVmj0050000ZKgX00000000ZKgX0080001noooo001Foooo10000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX0000000000000ZVmj0040000
PDIoPDIoPDIo0P0000055@1;00000000ZKgX000000>Y_NP00`0008QCS8QCS003000000>Y_NP00000
00000YIcZP<000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001JVmj00000000:Vmj0000002FRMg00D0002=Ch2=Ch00002eLXH00P00
0003mK9m00000000008000001?FbO@0000000=fKS0D00003V5V30`000003Y6B60000000000@00000
2_FbO@000:=TR:=TR0000>BSR`000>NYT0000:5SQ`8000000iiOQ@000000000200000hA:PP800000
1000<`0000000:Vmj0800002QD^200D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX1@00
0005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj000
00000002000000>Y_NP0000000000`000004mJ1A0000000000000heAP`800004S523100000BY_NP0
10000858PX58PX58PP<00003QTb410000005ZKgX000000000000ZKgX008000000jVmj00000000007
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX2@000004ZKgX00000000UER6100000:Y_NP3000000BY_NP00000002Y_NP3000000FY
_NP00000002Y_NP000000jVmj0030000ReJ<ReJ<00:;EX`2000018YDRP040000V5f90000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX3`000004ZKgX00000000ZKgX0`000004<@aa
0000`WUo`WUo1P000003ZKgX0000000000@000000o>L>00000000002/ff110000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX3`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj00200000jVmj0050000S6NS0000FcJ:000000:`Lhh200000i9HR0040000
UUf:UUf:00000ZVmj0030000ReB9ReB900:;E8T0100008eERHeERHeER@<000001:Vmj00000000:Vm
j0/00002ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY
_NP00000002Y_NP20000OOooo`00Doooo`D000001:Vmj00000000:Vmj08000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0040000ZKgXZKgX
00000h56O`<000001JVmj00000000:Vmj0000002ZKgX00<00028Dhb8Dh`0100000>FLjX5000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP0000000000002FRMg00D0002=Ch2=Ch00002eLXH00P000007mK9m00000000mK9m0000
mK9m000000;MVh`500000iQIP`<000000jATQP0000000004000000Ke/Wd0002SI8RSI8P0003TXh/2
00000Z5SQ`030000WUn5WUn500<00003Q4Z200@0002NGhH0000003<3000018E;PP8000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0@000000jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001?FPD@0000000000
00>=DH<2000018a@P`@00004ZKgX00<00021B8:1B8800X58PP800003QTb41@000005ZKgX00000000
0000ZKgX00D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00002ZKgX0`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000001IEHQP000:Vmj000
0:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX0000000000000jVmj0800002ZKgX00<0
002;EXb;EX`00X]FS0800004RUB:00D0002HGHT00000002Y_NP00`000004ZKgX00000000ZKgX2@00
0004ZKgX00000000ZKgX10000003ZKgX0000000000D000000jVmj0000000000200000/9iO`X00000
1:Vmj00000000?>L>0800002/ff11@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@00
0004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0<000000jVmj000
0000000400000jVmj0800002FcJ:00@0002`Lhh000000003TUR800@0002FGHZFGHX00002ZKgX00<0
002;E8V;E8T00X]DR@040000SEF9SEF9SEF92P000003ZKgX0000000000:Y_NP00`000:Vmj0000005
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP;000000>Y_NP000000000200007coool0
057oool5000000BY_NP00000002Y_NP2000000>Y_NP0000000000ZVmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0D000000jVmj0000856O`03PDIo10000006ZKgX000000000000ZKgX
00000XQCS08000000jVmj00009IcZP02UW>Z0P0000:QTlH3000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000UXW
M`050000SDn0SDn00000]G:6008000002?FbO@0000000?FbO@000?FbO@000=fKS08000001?FbO@00
0000000000>HFH<3000000>TI8H00000000010000004mK9m0000XfB8XfB8100000:QHhL00`0009iO
QIiOQ@0300000hA:PP060000WUn600000000ZKgX00001HE;PP<000001:Vmj00000000:Vmj0<00000
0jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP00000
00000P000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj002000000>Y_NP0000000000P000004ZKgX0000000000000_FPD@800003SE630P0000B<D8<4
00001:Vmj0030000PDR2PDR200:1B88200000hI<Q0<000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P0000:Y_NP01@000:Vmj00000000:Vmj003
000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000003ZKgX0000000000800000
0iEHQP0000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000jVmj0800002
ZKgX00D0002;EXb;EXb;EX`000000U`VL`060000RUB:RUB:RUB:0000V5f90`000005ZKgX00000000
0000ZKgX00D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000005
000000BY_NP0000000000002`WUo1`000005ZKgX000000000000ZKgX00@00002/ff11P000004ZKgX
00000000ZKgX2@000003ZKgX0000000000@000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000BY_NP00000002Y_NP;000000NY_NP000000000001K=XX0002`Lhh00P0000>BF8P0100009IM
RYIMRP0000:Y_NP00`0008]DRH]DR@02ReB900@0002=EHV=EHV=EHT4000000BY_NP00000002Y_NP3
00000ZVmj0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vm
j0T000001:Vmj00000000:Vmj080001loooo001>oooo10000003ZKgX00000000008000001:Vmj000
00000:Vmj0800002ZKgX0P000004ZKgX00000000ZKgX0P000005ZKgX000000000000ZKgX00800000
0jVmj00000000002000000>Y_NP00021AWl00h56O`8000000jVmj00000000002ZKgX00<0002Y_NP0
00000XQCS0070000ZKgXZKgXZKgX0000UW>Z000000:QTlH2000000F=FHl000000000002Y_NP01000
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000FY_NP0001J
9gMJ9gL000000Xe?P0050000]G:600000000mK9m008000001OFbO@000?FbO@000=fKS002000000Ce
/Wd0000000000003V5V31P000006mK9m000000000000mK9m00000Z=TR0@000001:5SQ`00000009iO
Q@8000000nBOQP0008A:PP02Q4Z200H0002NGhH00000002Y_NP00005QD^210000004ZKgX00000000
ZKgX1@000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP00000
00000P000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000_FPD@030000SE63SE63
00:=DH<2000018a@P`8000000jVmj0000:Vmj003ZKgX00<00021B8:1B8800X58PP800003QTb42P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY_NP00000002Y_NP9
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>EF8H0000000000`000004ZKgX
00000000ZKgX2@0000:Y_NP200000ZVmj0050000ReJ<ReJ<ReJ<0000009L9W<0200008YDRXYDRXYD
RP0009QMR@000:Vmj08000000jVmj00000000003000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0P0000;2NGl8000000>Y_NP0000000001@0000:cKH42000000>Y_NP00000000020000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP9000000>Y
_NP00000000010000008ZKgX00000000ZKgX0000FcJ:0000/7>>0P0000>BF8P0100009IMRYIMRP00
00:Y_NP00`0008]DRH]DR@02ReB900H0002=EHV=EHV=EHT0002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj080001koooo001<oooo0P00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000ZVmj0040000PDIoPDIo
PDIo10000005ZKgX000000000000ZKgX0080000018QCS0000000000000:Y_NP500000heIS`@00000
0jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX100000:Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000eXW
M`080000SDn00000]G:60000lZeo0000mK9m0P000005mK9m0000mK9m0000gI^<008000001?FbO@00
0000000000:HFH<00`000?BaP0000004000000Ke/Wd000000000003e/Wd00002XfB810000004XF>7
00000000WUn5100000>4BX801P0009iOQP0000000:Vmj00000F5Bh85000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX
0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000000jVmj00000000002000000FY_NP0003eX57eX540000018eAP`800004
S5230P000003ZKgX0000ZKgX00>Y_NP00`000858PX58PP02PDR20P0000>6C8@4000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000000iEHQP000:Vmj00:000000BY_NP00000002Y_NP200000ZVmj0800002ZKgX00D0
002;EXb;EXb;EX`000000U`VL`060000RUB:RUB:RUB:0000V5f920000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX0000000000L00002`WUo1P00
0004ZKgX00000000ZKgX1P0000:cKH47000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP6000000>Y_NP0002Y_NP01P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000007ZKgX000000000000FcJ:0000/7>>00800003TUR800@0002FGHZFGHX00002
ZKgX00<0002;E8V;E8T00X]DR@040000SEF9SEF9SEF90P000005ZKgX000000000000ZKgX00800000
0jVmj00000000002000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX2`000003ZKgX0000000000P0001joooo0019oooo0`000004ZKgX00000000ZKgX10000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000000jVmj00000000002
ZKgX0P000005ZKgX00000000ZKgX000000:Y_NP010000856Oh56Oh56O`8000001:Vmj00000000:Vm
j0D000000hQCS00000000006000018eIS`030000bIRS000000<000000jVmj00000000002000000BY
_NP00000002Y_NP2000000>Y_NP0000000000ZVmj08000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000ZVmj0050000ZKgX00000000ZKgX00<00000
0jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP200000eXWM`080000
SDn00000]G:60000lZeo0000mK9m0P000005mK9m0000mK9m0000gI^<008000001?FbO@000?FbOP00
00:HFH<2000000?SWXH0000000000P000003mK9m0000mK9m00<00002XfB80P000003ijV@0000XF>7
008000000iiOQ@000000000200000hA:PP060000WUn600000000ZKgX00001HE;PPP000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
0jVmj00000000002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000<00002
mJ1A00<0002=DH>=DH<00XeAP`800003S52300D0003g/WL0002Y_NP000001:Vmj0030000PDR2PDR2
00:1B88200000hI<Q0D000001:Vmj00000000:Vmj0<000000jVmj00000000002RU>:0P000004ZKgX
00000000ZKgX10000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX00@000000iEHQP0000000004000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP2000000JY_NP0001G<hT0002Y_NP00003ReJ<00@0001L9W=L
9W<00002RUB:00<0002HGHT000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX3`000007ZKgX000000000000<@aa0000`WUo00L000001:Vmj00000000:Vm
j0D00002/ff10`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP900000ZVm
j0@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0P00000
1;1cSP000=Yd000000:BF8P0100009IMRYIMRP0000:Y_NP00`0008]DRH]DR@02ReB900@0002=EHV=
EHV=EHT3000000>Y_NP0000000003@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@00
0004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0P0007[oool004Ooool3000000BY_NP00000
002Y_NP2000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0800002ZKgX0P000004ZKgX00000000ZKgX0`0000:Y_NP010000856Oh56Oh56
O`<000001:Vmj00000000:Vmj0H000001:Vmj0000000000000:?]?000`0008eISheIS`02SEV?0P00
0003/g^F00000000008000000jVmj00000000002000000BY_NP00000002Y_NP200000ZVmj0800000
1:Vmj00000000:Vmj08000001JVmj000000000000:Vmj002000000>Y_NP0000000000P0000:Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000ZVm
j0@000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000003ZKgX0000FRMg009J9gL0100008e?P0000;EbQP8000002OFbO@00000000000?FbO@00
0?FbO@000=fKS002000000Ce/Wd0003e/Wh00002V5V30P000008hij600000000nKMi0000mK9m0000
mK9m0`000007XfB80000i:>;0000ijV@0000XF>70080000019iOQ@000000000000B4BX801P0009iO
QP0000000:Vmj00000B5Bh800`000:MXQ`000004000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP8000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000JY_NP00000002Y_NP0002Y_NP2
00000_FPD@030000SE63SE6300:=DH<200000ha@P`030000mk9g000000800004ZKgX00<00021B8:1
B8800X58PP800003QTb40P000005ZKgX000000000000ZKgX008000001:Vmj0000000000000B:DhX3
000000>Y_NP0000000002@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1`000004UER600000000ZKgX10000004ZKgX00000000ZKgX0`000005ZKgX00000000
ZKgX000000:Y_NP200000ZVmj0040000ReJ<000000000U`VL`050000RUB:RUB:0000V5f900@00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000JY_NP00000000a37400032NGl@00000[=]P@8000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0`000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX2@000003ZKgX0000000000<00002fW@000@0002BF8RBF8P00002
UUf:00@0002Y_NRY_NP00004ReB900@0002=EHV=EHV=EHT7000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj080001ioooo0014oooo10000004ZKgX
00000000ZKgX0P000003ZKgX0000000000:Y_NP3000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000003ZKgX0000000000:Y_NP0
10000856Oh56Oh56O`@000001:Vmj00000000:Vmj0H000000jVmj00008ndl002SkC`00H0002=FHn=
FHn=FHl00039V:<3000000FUO:L000000000002Y_NP010000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000003ZKgX0000000000:Y_NP01@000:Vmj0000000
0:Vmj003000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX0000000000000eXWM`040000SDn00000]G:60P000009mK9m00000000
0000mK9m0000mK9m0000gI^<008000001?FbO@000000000000:HFH<2000000KSWXH00000003i]gT0
003e/Wd2000000Ke/Wd00000002SI8P0003TXh/200000Z5SQ`030000WUn5WUn500<00004Q4Z21000
0003ZKgX0000QD^200>5Bh800`000:MXQ`000005000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP000000000100000:Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P00
0005ZKgX0000mJ1AmJ1A000000B=DH<200000ha@P`D00004ZKgX00<00021B8:1B8800X58PP800003
QTb40`000005ZKgX000000000000ZKgX008000000jVmj00008YCRP04RU>:00<00027CXD000000`00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP9000000FY_NP000000000002EF8H00`000003ZKgX00000000008000001:Vmj00000000:Vm
j0<000001ZVmj00000000:Vmj0000:Vmj0800002ZKgX00@0002;EX`000000002G2Ic00D0002:E8Z:
E8X0002HGHT01@000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003YZ?C00000000008000001JVmj000034<L@000<9iO`08000000BY_NP00000002Y_NP4
00000[=]P@<000001:Vmj00000000:Vmj0T000000jVmj00000000007000000>Y_NP0000000000P00
0003ZKgX00000000008000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000000jVmj000
0000000200000]Yd00040000TUR8TUR800000YIMRP040000ZKgXZKgX000018]DR@060000SEF9SEF9
SEF90000ZKgX0P000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP00000
000020000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2`000003ZKgX0000000000P0001h
oooo0012oooo0`000005ZKgX000000000000ZKgX008000000jVmj00000000002ZKgX0P000005ZKgX
000000000000ZKgX00@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000001JVmj0000:Vmj:Vmj0000002PDIo1P000004ZKgX00000000ZKgX0`000004ZKgX
0000000000000hndl0040000SEV?SEV?SEV?0P000003/g^F0000YGbW00D00002ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`0000:Y_NP4000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX00000000009J9gL01@0008e?P8e?P0000;EbQP02000000?e
/Wd0000000000P0000;e/Wd4000000Ce/Wd0000000000002V5V30P000004hij600000000nKMi1000
0006mK9m00000000XfB80000i:>;0P0000:QHhL00`0009iOQIiOQ@03000018A:PP@000000jVmj000
08E;PP03QD^20P000003aX>90000000000@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0D00002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj0000000000300000_FP
D@030000SE63SE6300:=DH<200000ha@P`D00004ZKgX00<00021B8:1B8800X58PP800003QTb41000
0004ZKgX0000000000000jVmj0030000RU>:RU>:00::DhX00`0008M>QHM>Q@02000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0<000001:Vmj000000009EHQP@000000jVmj00000000002000000BY_NP00000
002Y_NP7000000NY_NP000000000002Y_NP0002;EX`00`000008G2Ic0000RUB:RUB:0000V5f90000
ZKgX10000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
0jVmj00000000002ZKgX00D0002VXm<00000002ai?P010000003<@aa0000`WUo00T000000jVmj000
0000000400000[=]P@@000000jVmj00000000003000000BY_NP00000002Y_NP6000000FY_NP00000
0000002Y_NP00P000003ZKgX00000000008000000jVmj00000000008000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP700000]Yd00040000TUR8TUR800000YIMRP040000ZKgXZKgX000018]D
R@040000SEF9SEF9SEF90P000004ZKgX00000000ZKgX3`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX2@000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0P0007Soool003ooool4
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`0000:Y_NP00`000856Oh56O`02000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0004ZKgX0000000000000Xndl0090000SEV?SEV?0000bIRS0000/g^F0000YGbW008000000ko9hP00
0:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj000
00000:Vmj08000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX
00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001JVmj00005XWMeXWM`000002SDn000D0002eLXH00000003e/Wd010000003mK9m0000mK9n
00<000001?FbO@000000000000:HFH<3000000>TI8H0003i]gT010000004mK9m00000000XfB81000
00:QHhL00`0009iOQIiOQ@0300000hA:PP030000WUn60000008000000jVmj00008E;PP03QD^21@00
0003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0800002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1@000003ZKgX00000000008000000jVmj0000000000200000_FPD@030000SE63SE63
00:=DH<200000ha@P`8000000jVmj00000000004ZKgX00L00021B8:1B8:1B880003AS8L000000XI<
Q0040000Y6B70000ZKgX0P000003ZKgX0000000000>Y_NP00`0008YCRXYCRP02RU>:00<00027CXF7
CXD00`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0D00000
1JVmj000000000000:Vmj002000000NY_NP000000000002Y_NP0002EF8H01@000003ZKgX00000000
008000000jVmj00000000003000000BY_NP00000002Y_NP4000000>Y_NP0002;EX`00`000006G2Ic
0000RUB:RUB:0000V5f90P000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000004ZKgX0000000000000ZVmj0/000000c4<L@000<9iO`06000000FY
_NP000000000002Y_NP01@0000:cKH47000000FY_NP000000000002Y_NP01P000004ZKgX00000000
ZKgX3`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000004ZKgX0000000000000]Yd
00040000TUR8TUR800000YIMRP050000ZKgXZKgXZKgX000000>;E8T0100008eERHeERHeER@T00000
1:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP9000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P00
07Ooool003coool4000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP010000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000003ZKgX0000PDIo00:1AWl3000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0`000003ZKgX0000000000:?]?001@0008eISheIS`00
0<VHX`02000000BUO:L0002obN:obN83000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002FRMg00D0002=Ch2=Ch00002eLXH00P000008mK9m00000000mK9m0000
mK9m0000mK9n10000003mK9n0000000000:HFH<3000000BTI8H00000003e/Wd3000000Ce/Wd00000
002SI8P400000Z5SQ`030000WUn5WUn500<00003Q4Z200L0002NGhH0000003<0002Y_NP0000018E;
PPH000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000003000000BY_NP00000002Y_NP4000000BY_NP0000000000002mJ1A00<0
002=DH>=DH<00XeAP`800003S5231P0000>Y_NP01`000858PX58PX58PP000=6<Q`000002QTb400D0
002TI8L00000002Y_NP00P000003ZKgX0000ZKgX00:Y_NP00`0008YCRXYCRP02RU>:00<00027CXF7
CXD010000004ZKgX00000000ZKgX10000003ZKgX00000000008000000jVmj00000000003000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>EF8H0002Y_NP010000003ZKgX00000000
00@000001JVmj000000000000:Vmj006000000BY_NP00000002Y_NP2000000IL9W<0002:E8Z:E8X0
002HGHT3000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj00;000000BY_NP00000002Y_NP3000000<a37400032NGl01`000003ZKgX00000000
00H00002/ff11@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX30000003ZKgX00000000
008000000jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000;JM0001000099HR99HR00000:FGHX01@000:Vmj:Vmj:Vm
j0000003ReB900@0002=EHV=EHV=EHT3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1P000003ZKgX
0000000000800002ZKgX2@0007Koool003[oool4000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000007ZKgX00000000ZKgX0000ZKgX0000
00>1AWl400000ZVmj0<000001:Vmj00000000:Vmj0<000002ZVmj000000008ndl00008eIS`000<VH
X`000;=kUP8000000ko9hP0000000004000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<00002FRMg00D0002=Ch2=Ch00002eLXH00P000008mK9m00000000mK9m0000
mK9m0000mK9n10000003mK9n0000V5V300:HFH<6000000Ge/Wd000000000003e/Wd00P000006XfB8
00000000ijV@0000XF>70P0000:NGhD300000hA:PP070000WUn60000000c0000ZKgX000000B5Bh87
00000hI<P`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@000005ZKgX
000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000_FPD@030000SE63SE63
00:=DH<200000ha@P`<000000jVmj00000000003ZKgX00L00021B8:1B8:1B880003AS8L000000XI<
Q0030000Y6B7000000800003ZKgX0P0000:Y_NP00`0008YCRXYCRP02RU>:00<00027CXF7CXD01@00
0004ZKgX00000000ZKgX10000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000UER600/000001:Vmj00000000:Vmj0<00000
0jVmj00000000008000000G]SBP00000002:E8X000000YQMR@050000ZKgX00000000ZKgX00<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0P000003<@aa0000`WUo00/000000jVmj0000000000200000[=]
P@H000000jVmj0000000000:000000BY_NP00000002Y_NP6000000>Y_NP0000000000P000003ZKgX
00000000008000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000JY_NP00000
0000002Y_NP00002fW@000@0002BF8RBF8P00002UUf:00D0002Y_NRY_NRY_NP000000h]DR@040000
SEF9SEF9SEF910000004ZKgX00000000ZKgX3`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX2@000007ZKgX000000000000ZKgX0000ZKgX00H000001:Vmj00000000:Vmj080001foooo000g
oooo10000005ZKgX000000000000ZKgX00800002ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000JY_NP000000000002Y_NP00002PDIo0P000003ZKgX0000ZKgX00800000
1JVmj000000000000:Vmj002000000fY_NP000000000002Y_NP0002?]?00002=FHl00039V:<0002c
NiH01@000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0P00009J9gL01@0008e?P8e?P0000;EbQP02000000Se/Wd00000003e/Wd0003e/Wd0
003e/Wh2000000Ce/Wd0003e/Wh00003V5V31P000005mK9m000000000000mK9m00<000001NBSR`00
0>NYT0000:5SQ`0200000YiOQ@<00003Q4Z200H0002NGhH00000002Y_NP00005QD^21@0000F6C8<3
000000>Y_NP0000000000XUDR`8000000jVmj00000000003000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX0000mJ1AmJ1A000000B=DH<200000ha@P`@00000
0jVmj0000:Vmj002ZKgX00L00021B8:1B8:1B880003AS8L000000XI<Q0030000Y6B7000000800003
ZKgX0P0000:Y_NP00`0008YCRXYCRP02RU>:00<00027CXF7CXD00P000005ZKgX000000000000ZKgX
00/000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D00000
0jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX1P000005kHdX00000000RUB:000000:HGHT2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP9000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0003`WUo0000000000H000001JVmj000000000000:Vmj00300000[=]P@8000000jVmj00000000002
000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0@00002fW@000@0002BF8RBF8P00002UUf:00D0002Y_NRY_NRY_NP000000h]DR@060000SEF9SEF9
SEF90000ZKgX2@000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vm
j0T000001:Vmj00000000:Vmj0<00002ZKgX10000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0P0007Goool003Goool2000000>Y_NP0000000000P000004ZKgX0000000000000ZVmj0800000
1:Vmj00000000:Vmj08000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0003ZKgX00000000008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001:Vmj0000856Oh56O`D000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001jVmj000000000000<VHX`000;=kUP03000000FY_NP000000000002Y
_NP010000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P00
0004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP000000UXW
M`080000SDn00000]G:60000lZeo0000mK9m0P000005mK9m0000mK9m0000mK9n008000001?FbO@00
0?FbOP0000:HFH<00`000?BaP0000004000000Ge/Wd000000000003e/Wd00`000003i:>;00000000
00:QHhL2000000FNGhD00000003TWhH000000hA:PP060000WUn600000000ZKgX00001HE;PPD00005
QTb3100000B9E8/5000000FY_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj000
00000002000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1@0000;eX5400`0008eAPheAP`02SE630P0000><D8<600000jVmj0070000
PDR2PDR2PDR20000dHb7000000:6C8@00`000:ATQ`00000200000jVmj0800002ZKgX00D0002:DhZ:
DhZ:DhX000000hM>Q@<000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX00000000
008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0`000000jVmj00000000002000000>Y
_NP0000000000P000004ZKgX00000000ZKgX30000005kHdX00000000RUB:000000:HGHT3000000BY
_NP00000002Y_NP9000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP00000
00000P000003ZKgX0000000000<000000l9iO`0000000004000000BY_NP00000002Y_NP7000000>c
KH400000000020000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y
_NP0000000003@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2P0000;JM0001000099H
R99HR00000:FGHX01@000:Vmj:Vmj:Vmj0000003ReB900@0002=EHV=EHV=EHT5000000>Y_NP00000
00000XmLT@8000001:Vmj00000000:Vmj0@000000jVmj00000000008000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@0007Coool0
03?oool2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000RY_NP000000000002Y_NP0002Y
_NP00002PDIo0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000>Y
_NP00000000010000003bIRS0000/g^F00@000001:Vmj0000000000000>8Dh/2000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX00000000008000000jVmj00000000003
000000BY_NP00000002Y_NP3000000BY_NP0000000000002FRMg00P0002=Ch00002eLXH0003b[Gl0
003e/Wd2000000Ge/Wd0003e/Wd0003e/Wh00P000004mK9m0000mK9n00000YQIP`8000000n>NQP00
00000002000000We/Wd000000000003e/Wd0002SI8P0003TXh/00P0000:QHhL00`0009iOQIiOQ@04
00000hA:PP060000WUn600000000ZKgX000018E;PP030000YfR7000000<00005QTb30`0000B9E8/0
1@000:Vmj00000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000800000
0jVmj00000000002000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000000jVmj0000000000200000_FPD@030000SE63SE6300:=DH<200000ha@
P`8000001:Vmj0000000000000>Y_NP01`000858PX58PX58PP000=6<Q`000002QTb400<0002TI8L0
00000P0000>Y_NP200000ZVmj0050000RU>:RU>:RU>:000000:7CXD8000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0`000005ZKgX0000kHdX0000G2Ic00800002V5f910000003ZKgX00000000
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00000
0jVmj00000000004000000BY_NP000000032NGl7000000BY_NP00000002Y_NP?000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP<000000>Y_NP0000000000P000003ZKgX0000000000800000
1:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<00002fW@000@0002BF8RBF8P00002UUf:0P00
00:Y_NP01@0008]DRH]DRH]DR@000003SEF90P000004ZKgX00000000000018mLT@/000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000T000000jVmj000
00000008000000BY_NP00000002Y_NP20000M?ooo`00<oooo`<000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP2000000>Y_NP0000000000ZVmj08000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000003ZKgX00000000008000001:Vmj0000856Oh56O`<000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000800002bIRS00D0002cNiH0
0000002Y_NP00`0000F8Dh/3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000
ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@00000
0jVmj00000000004000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800002
FRMg00H0002=Ch00002eLXH0003b[Gl4000000Ge/Wd0003e/Wd0003e/Wh00P000004mK9m0000mK9n
00000YQIP`8000000n>NQP0000000002000000?e/Wd0003e/Wd00`000003XfB80000i:>;00800002
XF>700<0002NGhFNGhD0100000>4BX801P0009iOQP0000000:Vmj00000B5Bh800`000:MXQ`000003
000018I<P`040000Wf670000000018UDR`D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0@000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`0000;eX5401`0008eAPheAPheAP`0003L;K0000003
S5230`000003ZKgX0000000000>Y_NP01`000858PX58PX58PP000=6<Q`000002QTb400D0002TI8L0
002Y_NP000000jVmj0050000P4R30000ZKgX000000>:DhX00`0008M>QHM>Q@05000000FY_NP00000
0000002Y_NP00P000003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP5
000000FY_NP000000000002Y_NP01P000004ZKgX00000000ZKgX100000:Y_NP5000000FY_NP00000
0000002Y_NP00P000007ZKgX000000000000ZKgX0000kHdX00<00002V5f91`000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000003@000003ZKgX00000000
008000000l9iO`000000000?000000>cKH40000000000P000003ZKgX00000000008000001:Vmj000
00000:Vmj0T000001:Vmj00000000:Vmj0H000000jVmj00000000002000000>Y_NP0000000002000
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000005fW@00000TUR8TUR8000000:FGHX2
00000ZVmj0050000ReB9ReB9ReB9000000>=EHT3000000>Y_NP0002?G9400hmLT@050000UEb;0000
0000ZKgX00800002ZKgX00D0002Y_NP00000002Y_NP00`000004ZKgX00000000ZKgX2@000004ZKgX
00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P0007?oool003?oool0
1@000?ooo`0000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj000
00000:Vmj0800002ZKgX0P000004ZKgX00000000ZKgX0P000005ZKgX000000000000ZKgX00800000
0jVmj00000000002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1jVmj000000000000:Vmj0000856O`05000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001jVmj000000000000<VHX`000;=kUP0400000ZVmj0030000R5>;R5>;00:8Dh/5
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX1@000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000JY_NP000000000002Y_NP00002FRMg00@0
002=Ch00002eLXH2000000We/Wd000000000003e/Wd0003e/Wd0003e/Wh00P000004mK9m00000000
00000YQIP`8000002>>NQP0000000?VgN@000?FbO@000?FbO@<000000j=TR0000000000200000Z5S
Q`030000WUn5WUn500@00002Q4Z200<0002NGhJNGhH00P000003ZKgX0000QD^200>5Bh800`000:MX
Q`000003000018I<P`040000Wf670000000018UDR`8000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj00000000004000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00500000_FP
D@070000SE63SE63SE630000=`]/000000><D8<4000000>Y_NP0002Y_NP00ZVmj0070000PDR2PDR2
PDR20000dHb7000000:6C8@00`000:ATQ`00000200000jVmj0050000P4R30000ZKgX000000>:DhX0
0`0008M>QHM>Q@03000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP00000
000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001ZVmj00000000:Vmj0000:Vm
j0H000001:Vmj00000000:Vmj0<000000jVmj00000000005000000C]SBP0000000000002V5f91@00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj000
00000:Vmj0@000000jVmj00000000002000000FY_NP0000000000032NGl020000003ZKgX00000000
00H000000k=]P@0000000003000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000003000000CJM000002BF8RBF8P2000000>FGHX0000000000ZVmj0050000
ReB9ReB9ReB9000000>=EHT01@000:Vmj:Vmj:Vmj0000004SebA00<0002EG8/000000P0000:Y_NP4
000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y
_NP0000000001@000003ZKgX0000000000L0001boooo000coooo00<0003oooooool00P000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002
00000ZVmj08000001:Vmj00000000:Vmj08000000jVmj0000856O`06000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000002:Vmj00000000<VHX`000;=kUP000:Vmj0800002
ZKgX00<00028Dh^8Dh/00XQCR`040000U72VU72VU72V0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX10000003ZKgX00000000
008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0003ZKgX0000000000800002FRMg00@0002=Ch00002eLXH2000000?e/Wd0000000000P000003mK9m
0000mK9n00<000001?FbO@000000000000:HFH<2000000SSWXH00000003i]gT0003e/Wd0003e/Wd3
000000FSI8P00000003e/Wh000000Z5SQ`030000WUn5WUn500@00002Q4Z200<0002NGhH000000P00
0003ZKgX0000QD^200>5Bh800`000:MXQ`000003000018I<P`040000Wf67000000000hUDR`050000
ZKgX00000000ZKgX00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
0jVmj00000000003000000>Y_NP0000000000_FPD@070000SE63SE63SE630000=`]/000000><D8<2
000000BY_NP0000000000002ZKgX00<00021B8:1B8800X58PP030000dHb7000000:6C8@00`000:AT
Q`00000200000jVmj0050000P4R30000ZKgX000000::DhX0100008M>QHM>QHM>Q@@000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000?]SBP0000000000iQMR@030000ZKgX0000
00<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002
000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000<9iO``000000jVmj000
00000002000000>cKH400000000020000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000002000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP5000000FY_NP00000003JM00000000Y9HR08000000iIMRP00
00000002ZKgX00D0002;E8V;E8V;E8T000000heER@050000ZKgXZKgXZKgX000000B?G9400`0009EL
R`000004000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000000jVmj00000000009000000>Y_NP00000000010000004ZKgX00000000
ZKgX0P0007;oool002Koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`8000000jVmj000
00000002ZKgX0`000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001:Vmj0000000000000:Y_NP2
000000BY_NP00000002Y_NP2000000>Y_NP0000000000X56O`8000000jVmj00000000002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000002/g^F0P00
0005ZKgX0000ZKgXZKgX000000>8Dh/0100009A`YYA`YYA`YP@000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001:Vmj00000000000009J9gL0100008e?P0000;EbQP8000000oFbO@0000000002000000?e
/Wd0003e/Wh00`000004mK9m0000000000000YQIP`<000000jATQP000?VgN@04000000Ce/Wd00000
002SI8P2000000Ge/Wh0002QHhNQHhL000000YiOQ@@00002Q4Z200<0002NGhH000000P000003ZKgX
0000QD^200>5Bh800`000:MXQ`000003000018I<P`8000000lR4R@0008UDR`02REB;0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX20000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001JVmj00000000:Vmj0000002
mJ1A00L0002=DH>=DH>=DH<0000g2f`000000ha@P`<000000jVmj00000000002ZKgX00<00021B8:1
B8800X58PP030000dHb7000000:6C8@00`000:ATQ`00000200000jVmj0030000P4R3000000:Y_NP0
0`0008YCRP000003Qdj51@000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj000
00000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP:000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX2@000003kHdX0000000000>HGHT2000000>Y
_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX0000000000@000000l9iO`0000000008000000>Y_NP00000000010000003/ff1
0000000000@000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP<
000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0T000001JVmj000
00000:Vmj0000002fW@000D0002BF8P00000002FGHX00P0000:Y_NP01@0008]DRH]DRH]DR@000003
SEF90P0000>Y_NP0200008mLTHmLTHmLT@0009ELR`000:Vmj0@000000jVmj00000000004000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0T0001aoooo000Uoooo00<0
003oool000002_ooo`030000oooooooo00?oool200000ZVmj08000001JVmj000000000000:Vmj004
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000003ZKgX00000000
00800002PDIo0`000003ZKgX00000000008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP0100000:cNiH3000000BY_NP0002Y_NP00003R5>;00D0002DL:JDL:H0002Y_NP01000
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000003ZKgX00000000009J9gL0100008e?P0000;EbQP800000
0oFbO@0000000002000000?e/Wd0003e/Wh00`000004mK9m0000000000000YQIP`D000000oVgN@00
00000002000000We/Wd000000000003TXh/0003e/Wh0002QHhL00P0000:NGhD400000XA:PP030000
WUn60000008000000jVmj00008E;PP03QD^20P000004aX>90000SUnF000018I<P`8000000lR4R@00
08UDR`02REB;0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00@000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000FY
_NP000000000002Y_NP00`0000;eX5401`0008eAPheAPheAP`0003L;K0000003S5231P0000:Y_NP0
0`000858PX58PP02PDR200<0003AS8L000000XI<Q0030000Y6B7000000800003ZKgX00P00020B8>0
B8<0002Y_NP0002:DhX00003Qdj50P000005ZKgX000000000000ZKgX008000000jVmj00000000003
000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0<000000jVmj000
00000003000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0800002kHdX00@0002HGHVHGHVHGHT3000000>Y
_NP00000000020000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
00/000000l9iO`0000000005000000>Y_NP0000000001`000004/ff100000000ZKgX10000003ZKgX
00000000008000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0@000000jVmj00000000008000000BY_NP00000002Y_NP3000000BY_NP0000000000002fW@000P0
002BF8P00000002FGHX0002Y_NP00002ZKgX00@0002;E8T000000003SEF90P0000>Y_NP0100008mL
THmLT@0000:EG8/;000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP9000000BY_NP00000
002Y_NP4000000>Y_NP00000000020000004ZKgX00000000ZKgX0P00077oool002Ooool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`<000001:Vmj00000000:Vmj0<000000jVmj00000000002
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000>Y_NP0000000000ZVmj0800000
1:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2000000FY_NP00000
00000021AWl00P000004ZKgX00000000ZKgX10000005ZKgX000000000000ZKgX00800002ZKgX0P00
0005ZKgX000000000000/g^F008000001ZVmj000000000000:Vmj00000:8Dh/2000000FDL:H00000
0000002Y_NP010000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0P000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000008ZKgX0000FRMgFRMg0000SDn00000
]G:60P000008mK9m00000000mK9m0000mK9m0000mK9n10000003mK9n0000000000:HFH<6000000Ge
/Wd000000000003e/Wd00`000005i:>;0000mK9n0000XF>700800002WUn5100000:4BX800`0009iO
QP000002000000>Y_NP00025Bh800hE;PP8000001<J3R@0008iOUP0000B6C8<400000XUDR`030000
ZKgX0000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000003ZKgX0000000000;eX5401`0008eAPheAPheAP`0003L;K0000003S5231000
0005ZKgX0000ZKgXZKgX000000B1B8800`000=6<Q`000002QTb400<0002TI8L000000P0000>Y_NP0
20000818Ph18P`000:Vmj00008YCRP0000>7CXD3000000FY_NP000000000002Y_NP01@000004ZKgX
00000000ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj0D000000jVmj00000000004
000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj002000000FY_NP0003]SBS]SBP000000iQMR@P000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP00000
00003`000003ZKgX0000000000<000001K=]P@00000000000:Vmj004000000>Y_NP0000000002000
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX3`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1P0000;JM0001@00099HR000000009IMRP0300000ZVmj0040000ReB9000000000heE
R@030000_E00000000:Y_NP0100008mLTHmLT@0000:EG8/2000000>Y_NP0000000000P000003ZKgX
00000000008000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj080001`oooo000Uoooo0P0000_oool0
0`000?ooooooo`05oooo0`000004ZKgX00000000ZKgX0`000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0800002ZKgX0P000004ZKgX00000000ZKgX0P000003ZKgX
00000000008000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP000000021AWl3
000000BY_NP00000002Y_NP4000000BY_NP0000000000002ZKgX0P000004ZKgX00000000ZKgX0P00
0005/g^F000000000000ZKgX008000001:Vmj00008QCRhQCR`<000001JVmj000000000000:Vmj004
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj003000000AJ9gL0002=Ch000002]G:60P000008mK9m00000000
mK9m0000mK9m0000mK9n10000003mK9n0000000000:HFH<6000000Ge/Wd000000000003e/Wd00`00
0006i:>;000000000000XF>700000iiOQ@@00002Q4Z200<0002NGhH000000P000003ZKgX0000QD^2
00>5Bh84000000>>GiH00026C8<00hI<P`@00002REB;0P0000:7ChH2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001JVmj0000?FPDOFP
D@000003SE6300<0000g2f`000000Xa@P`030000mk9g000000@00002ZKgX00<00021B8:1B8800X58
PP030000dHb7000000:6C8@01@000:ATQ`000:Vmj0000003ZKgX00P00020B8>0B8<0002Y_NP0002:
DhX00003Qdj510000003ZKgX0000000000<000001JVmj000000000000:Vmj002000000>Y_NP00000
00000P000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP4000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000004ZKgX00000000
00000^f=:0040000V5f9V5f9V5f910000003ZKgX00000000008000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@000000jVmj00000000002000000?2NGl00000
00001P000005ZKgX000000000000ZKgX00@000000k=]P@0000000002000000>Y_NP0000000001P00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000H000000jVmj000
00000002000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000003ZKgX0000000000;JM000
0`00099HR99HR002000000>Y_NP0000000000ZVmj0040000ReB9000000000heER@<00002ZKgX00@0
002?G96?G9400002UEb;0`000003ZKgX00000000008000000jVmj00000000008000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP:000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@00
06ooool002Goool00`000?ooooooo`0:oooo00@0003oool000000006oooo0P000004ZKgX00000000
ZKgX0`000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP4000000>1AWl0000000000P000004ZKgX00000000ZKgX10000003ZKgX0000000000800000
1:Vmj00000000:Vmj0@000000k=kUP0000000002000000BY_NP0002Y_NP00002R5>;10000005ZKgX
000000000000ZKgX00@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP8000000BY
_NP00000002Y_NP3000000NY_NP00000001J9gL0002=Ch0000000[EbQP8000002?FbO@0000000?Fb
O@000?FbO@000?FbOP8000000oFbO@000?FbOP02000000>HFH<0003d/H001@000005mK9m00000000
0000mK9m00<000001^BSR`00000000000:5SQ`0000>NGhD400000XA:PP040000WUn6000000000ZVm
j0060000QD^2QD^2QD^20000YfR70`000003SUnF0000QTb300>6C8<400000XUDR`040000Qdn6Qdn6
Qdn60`000003ZKgX0000000000:?GiD2000000>Y_NP0000000000`000004ZKgX00000000ZKgX1000
0003ZKgX00000000008000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000>Y
_NP0000000000P0000;eX5401`0008eAPheAPheAP`0003L;K0000002S52300@0003g/WL0002Y_NP3
00000ZVmj0030000PDR2PDR200:1B8800`000=6<Q`000002QTb400<0002TI8L000000P0000>Y_NP0
1@000818Ph18P`000:Vmj002000018M>Q@8000000jVmj00000000003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP4000000>Y_NP00000000010000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000>Y_NP0000000001P000003ZKgX0000000000@000001:Vmj000
00000:Vmj0<000000jVmj00000000002kHdX00D0002HGHVHGHT0002Y_NP010000003ZKgX00000000
008000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0l00000
1:Vmj00000000:Vmj0<000001JVmj000000000000;=]P@09000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX1@000003ZKgX0000000000@000000jVmj00000000002
000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000005ZKgX0000fW@0fW@0000000:BF8P5
00000ZVmj0040000ReB9000000000heER@8000001;e@00000:Vmj00000:?G9400`0009ELRiELR`0=
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP9000000BY_NP00000002Y_NP4000000>Y
_NP00000000020000004ZKgX00000000ZKgX0P0006ooool002Goool300002_ooo`800009oooo0P00
0004ZKgX00000000ZKgX0`0000:Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000003PDIo0000ZKgX00<000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000005R5>;000000000000ZKgX
008000001JVmj000000000000:Vmj004000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000`000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000^Y_NP0001J9gL0002=Ch00002e
LXH0003b[Gl0003e/Wd00P000005mK9m0000mK9m0000mK9n008000000oFbO@000?FbOP02000000>H
FH<0003d/H001@000005mK9m000000000000mK9m00L000001:5SQ`0009iOQIiOQ@8000001NBOQP00
000008A:PP000002WUn60P0000:Y_NP01P0008E;PXE;PXE;PP000:MXQ`@00004QTb300<0002OHHL0
00000P000003REB;0000Qdn600>7ChH400000hmOU@H000001JVmj000000000000:Vmj002000000>Y
_NP0000000000P000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP300000_FPD@070000SE63SE63SE630000=`]/000000:<D8<4000000>Y
_NP0000000000ZVmj0050000PDR2PDR2PDR2000000;AS8L01P0008I<Q0000:ATQ`000:Vmj0800003
ZKgX00@00020B8>0B8>0B8<3000018M>Q@D000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000003ZKgX0000000000H000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000004000000>Y_NP00000000010000003ZKgX00000000008000001:Vmj000
00000:Vmj0D00002kHdX00<0002HGHVHGHT00P000003ZKgX00000000008000000jVmj00000000002
000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX
00000000010000001:Vmj00000000:Vmj0H000001;=]P@0000000:Vmj08000000jVmj00000000002
000000>Y_NP0000000000P000004ZKgX00000000ZKgX1P000004S5F:00000000ZKgX0P000005ZKgX
000000000000ZKgX008000000jVmj00000000006000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP5000000CJM000002BF8RBF8P3000000JY_NP00000002Y_NP0002;E8T200000heER@800000
1[e@00000:Vmj00008mLT@0000>EG8/01@000:Vmj00000000:Vmj004000000>Y_NP0000000000P00
0003ZKgX0000000000X000001:Vmj00000000:Vmj0<000000jVmj00000000009000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP20000K_ooo`00<Oooo`030000oooooooo00[oool2000000BY
_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y_NP0000000000P000003ZKgX
00000000008000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000>Y_NP00000
00000P000003ZKgX00000000008000001:Vmj00000000:Vmj0D000000jVmj00000000003000000>8
Dh/0000000000P000004ZKgX00000000ZKgX0`0000>IO;42000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX00000000ZKgX10000007FRMg
0000SDn00000]G:60000lZeo00@000001OFbO@000?FbO@000?FbOP02000000?e/Wd0003e/Wh00P00
0004V5V300000000hij610000005mK9m000000000000mK9m00L000001:5SQ`0009iOQIiOQ@@00002
Q4Z200<0002NGhJNGhH00P0000:Y_NP01P0008E;PXE;PXE;PP000:MXQ`@00004QTb300<0002OHHL0
00000P000003REB;0000Qdn600>7ChH3000018mOU@050000ZKgX00000000ZKgX008000001JVmj000
000000000:Vmj002000000>Y_NP0000000000P000003ZKgX0000000000@000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000;eX5401`0008eAPheAPheA
P`0003L;K0000002S5230P000005ZKgX00000000ZKgX000000:Y_NP01@000858PX58PX58PP000002
dHb700@00026C8@0002TI8L2000000>Y_NP0002Y_NP00ZVmj0040000P4R3P4R3P4R30`0000B7CXD3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000000jVmj00000000006000000>Y_NP0000000001000
0003ZKgX00000000008000000jVmj00000000002000000>Y_NP0000000000`000005ZKgX0000kHdX
kHdX000000:HGHT3000000>Y_NP0000000000P000003ZKgX0000000000@000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000<000000jVmj00000000002
000000>Y_NP0000000002@000003ZKgX0000000000H000001K=]P@00000000000:Vmj002000000>Y
_NP0000000000P000003ZKgX0000000000P00004S5F:0`000004ZKgX00000000ZKgX2P000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP0003JM0000002
TUR810000005ZKgX0000ZKgX0000ReB900800003SEF90P0000:mD002000000>?G940002EG8/00YEL
R`8000001:Vmj00000000:Vmj0@000000jVmj00000000008000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vm
j0T0001]oooo000aoooo00<0003oooooool02oooo`8000001:Vmj00000000:Vmj0@000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1:Vmj00000000:Vmj08000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX00000000
00<000000jVmj00000000002ZKgX0P000004ZKgX00000000ZKgX10000003ZKgX0000000000800000
0jVmj00000000003000000BY_NP00000002Y_NP6000000FY_NP000000000002Y_NP00`0000>IO;42
000000B<EHX00000002Y_NP2000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX0P00
0005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001eXWM`0008e?P0000;EbQP00
0?:]O`04000000?e/Wd0003e/Wd010000006mK9m00000000mK9n0000V5V30P000006hij600000000
nKMi0000mK9m10000003mK9m0000i:>;00<00002XF>700<0002NGhFNGhD0100000:4BX800`0009iO
QYiOQP0200000ZVmj0060000QD^2QD^2QD^20000YfR7100000B6C8<00`0009mQQ`000002000000>9
E8/00027ChH00XM?QP040000Wf:8000000000hmOU@H000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX008000001JVmj0000?FPDOFPD@000003SE6300<0000g2f`000000Xa@P`<00000
1:Vmj0000000000000:Y_NP01@000858PX58PX58PP000002dHb700@00026C8@0002TI8L400000jVm
j0040000P4R3P4R3P4R30`0000B7CXD4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000003ZKgX00000000008000001:Vmj00000000:Vmj0<000000jVmj000
00000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y_NP0000000001000
0003ZKgX0000000000800002kHdX00D0002HGHVHGHT0002Y_NP00P000003ZKgX0000000000H00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@000000jVmj000
0000000;000000>Y_NP0000000000`000003/ff100000000008000000jVmj0000000000500000XeH
SP8000001JVmj00000000:Vmj0000005S5F:3@000003ZKgX00000000008000000jVmj00000000002
000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000004fW@00000TUR8TUR80P000007ZKgX
000000000000ZKgX0000ReB900800003SEF90P0000:mD002000000>?G940002EG8/00YELR``00000
0jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000
ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj080001]oooo000aoooo00<0003ooooo
ool03?ooo`8000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj0800002ZKgX0`00
0003ZKgX00000000008000001:Vmj00000000856O`800002ZKgX0P000004ZKgX00000000ZKgX0P00
0003ZKgX00000000008000000jVmj00000000004000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000@000001:Vmj0000000000000>Y_NP300000haERP<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000005FRMg
0000SDn00000]G:6008000000oFbO@0000000002000000?e/Wd0003e/Wh00`000006mK9m00000000
mK9n0000V5V30P000008hij600000000nKMi0000mK9m0000mK9m0P000003mK9m0000i:>;00<00002
XF>700<0002NGhFNGhD0100000:4BX800`0009iOQYiOQP0200000ZVmj0060000QD^2QD^2QD^20000
YfR7100000B6C8<00`0009mQQ`000003000018M?QP040000Wf:8000000000XmOU@@000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000H000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj0000000000000;eX5401`0008eAPheAPheA
P`0003L;K0000002S52310000003ZKgX0000000000:Y_NP01@000858PX58PX58PP000002dHb700@0
0026C8@0002TI8L400000jVmj0040000P4R3P4R3P4R30`0000B7CXD5000000BY_NP00000002Y_NP3
000000BY_NP00000002LP;@2000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX1@000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj00;000000BY
_NP00000002Y_NP4000000C]SBP0002HGHVHGHT9000000>Y_NP0000000000P000003ZKgX00000000
00@000000jVmj00000000006000000FY_NP000000000002Y_NP00P000003ZKgX0000000000d00000
1:Vmj00000000:Vmj0@000000k=]P@0000000005000000>Y_NP0002=F8h018eHSP<00003ZKgX00<0
002<EHZ<EHX00haERP@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
00000008000000BY_NP00000002Y_NP3000000CJM000002BF8RBF8P6000000>Y_NP0002;E8T00P00
00>=EHT00`000:Vmj0000002_E000`0000>EG8/3000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP4000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000T00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj080001/oooo000aoooo00<0003oooooool03Ooo
o`8000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000002ZKgX0P000005ZKgX00000000
0000ZKgX00H000000h56O`0000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP6
000000>Y_NP0000000001P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1P0000B<EHX2
000000BaNiP00000002Y_NP2000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX0P00
0005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000003ZKgX0000000000:>GYD2000000BY_NP00000
002Y_NP3000000>Y_NP0000000000P00000:ZKgX00000000ZKgX0000FRMg0000SDn00000]G:60P00
0003mK9m00000000008000000oFbO@000?FbOP03000000Ke/Wd00000003e/Wh0002HFH<5000000Gi
]gT0003e/Wd0003e/Wd00P000007mK9m0000i:>;0000mK9n0000XF>700800002WUn5100000:4BX80
0`0009iOQP00000200000ZVmj0060000QD^2QD^2QD^20000YfR7100000B6C8<00`0009mQQ`000003
000018M?QP040000Wf:8000000000XmOU@8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP600000_FPD@070000SE63SE63SE630000=`]/000000:<D8<5000000FY_NP0002Y
_NRY_NP000000h58PP090000dHb7dHb70000QTb40000Y6B70000ZKgX00800003ZKgX00<00020B8>0
B8<00X18P`800004Qdj50P000005ZKgX000000000000ZKgX008000001:Vmj0000000000000:LP;@0
1@0008eGR`0000000:Vmj002000000>Y_NP0000000000P000003ZKgX0000000000P000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0`000004kHdX0000V5f9V5f90P000004ZKgX00000000ZKgX10000003ZKgX
0000000000@000000jVmj00000000008000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP;
000000FY_NP000000000002Y_NP00P000005ZKgX0000;@ad0000/ff100D00003ZKgX00<0002=F8j=
F8h00heHSP<00003ZKgX00<0002<EHZ<EHX00haERP030000ZKgX0000008000001:Vmj00000000:Vm
j0<000000jVmj00000000009000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000CJ
M000002BF8RBF8P3000000JY_NP00000002Y_NP0002;E8T200000XeER@@00002_E000P0000BEG8/4
000000BY_NP00000002Y_NP?000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000>Y
_NP0000000000P000003ZKgX00000000008000000jVmj0000000000:00003_ooo`<00003oooo00<0
003oooooool00_ooo`030000oooooooo04ooool0037oool00`000?ooooooo`0>oooo0P000004ZKgX
00000000ZKgX10000005ZKgX000000000000ZKgX00800002ZKgX0P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000D000001JVmj000
000000000:Vmj002000000BY_NP00000002Y_NP2000000FY_NP000000000002Y_NP00P000003ZKgX
00000000008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX
00000000009SX_<00`0008aERXaERP02S5F:0P000005/G^H000000000000ZKgX00H000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000>Y_NP0000000000`000003ZKgX0000000000:DKJ<200000hiNU@@000000jVmj00000000004
000000>Y_NP0000000000P000009ZKgX000000000000FRMg0000SDn00000]G:6008000000oFbO@00
00000002000000?e/Wd0003e/Wh00`000004mK9m0000000000000YQIP`D000000oVgN@0000000002
000000[e/Wd0003e/Wd0003TXh/0003e/Wh0002QHhL00003WUn5100000:4BX800`0009iOQP000002
00000ZVmj0060000QD^2QD^2QD^20000YfR70P000003SUnF0000QTb300>6C8<00`0009mQQ`000003
000018M?QP8000000j=TQ`0008mOU@04000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000000jVmj00000000002mJ1A00L0002=DH>=DH>=DH<0000g2f`000000Xa@P`L00002
ZKgX00D00021B8:1B8:1B88000000]6<Q`040000QTb40000Y6B70P000003ZKgX0000ZKgX00:Y_NP0
0`000818Ph18P`02P4R30P0000>7CXD4000000>Y_NP00000000010000003RU:90000W82d00800002
SEN;0`000004ZKgX00000000ZKgX20000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP2000000C]SBP0002HGHVHGHT3000000BY_NP00000002Y_NPB000000FY_NP000000000002Y
_NP00P000003ZKgX00000000010000001JVmj000000000000:Vmj003000000<]37@0002cKH400P00
0003ZKgX0000000000>Y_NP00`0008eHSXeHSP02SER>00@0002`MI4000000003ZKgX00<0002<EHZ<
EHX00haERP8000001JVmj000000000000:Vmj002000000>Y_NP0000000000`000003ZKgX00000000
008000000jVmj00000000002000000BY_NP00000002Y_NP8000000CJM000002BF8RBF8P4000000FY
_NP000000000002;E8T00P0000:=EHT400000ke@00030000UEb;UEb;00:EG8/00`000:Vmj0000008
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX
00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj080000>oooo00<0003ooooo
ool00_ooo`030000oooo000000;oool00`000?ooo`00001@oooo000aoooo00<0003oooooool03ooo
o`8000001:Vmj00000000:Vmj0@000001:Vmj0000000000000:Y_NP2000000BY_NP00000002Y_NP2
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj00000000000
0:Vmj007000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX0P000005ZKgX00000000
0000ZKgX008000000jVmj00000000002000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001JVmj00006>Rlf>Rl`000004S5F:00<0002aNiP000000XYGSP@000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000>Y_NP00000000010000004ZKgX0000000000000iA]X`800004SUjE00<0002Y_NP000001000
0003ZKgX00000000008000000jVmj00000000002000000RY_NP00000001J9gL0002=Ch00002eLXH2
000000Se/Wd00000003e/Wd0003e/Wd0003e/Wh4000000?e/Wh0000000000YQIP`D000000oVgN@00
00000002000000[e/Wd0003e/Wd0003TXh/0003e/Wh0002QHhL00003WUn5100000:4BX800`0009iO
QP00000200000ZVmj0060000QD^2QD^2QD^20000YfR70P000003SUnF0000QTb300>6C8<00`0009mQ
Q`000003000018M?QP8000001:=TQ`0000000:Vmj0@000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX0000000000@00000
0jVmj00000000003000000BY_NP0003eX5400004SE6300<0000g2f`000000Xa@P`L00002ZKgX00D0
0021B8:1B8:1B88000000]6<Q`040000QTb40000Y6B7100000>Y_NP00`000818Ph18P`02P4R30P00
00>7CXD2000000BY_NP00000002Y_NP2000018YBR@800004SEN;10000003ZKgX0000000000@00000
0jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000FY_NP00000
0000002Y_NP00P000003ZKgX00000000008000000jVmj00000000007000000C]SBP0002HGHVHGHT4
000000BY_NP00000002Y_NP5000000>Y_NP0000000001`000004ZKgX00000000ZKgX0`000003ZKgX
0000000000<000001:Vmj00000000:Vmj0T000000jVmj00000000007000000<]37@0002cKH400`00
0003ZKgX0000ZKgX00:Y_NP00`0008eHSXeHSP02SER>00@0002`MI4000000003ZKgX00<0002<EHZ<
EHX00haERP<000000jVmj0000000000:000000>Y_NP0000000000P000003ZKgX0000000000P00000
1jVmj00000000:Vmj0000=Yd00000002TUR81`000006ZKgX00000000A8OY0000SEF9100000>mD000
0`0009ELRiELR`02UEb;1@000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000003ZKgX
0000000000P000001:Vmj00000000:Vmj0<000000jVmj00000000006000000>Y_NP0000000000P00
0003ZKgX00000000008000001:Vmj00000000:Vmj080000>oooo00L0003oooooooooool0003oool0
00000_ooo`030000oooo0000053oool0033oool00`000?ooooooo`0Aoooo0P000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<00002Hj;c00@0002<EHZ<
EHZ<EHX2000000FaNiP0002:Ehh0002Y_NP010000003ZKgX00000000008000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002
000000>Y_NP0002DKJ<00YA]X`0300002@0;000000>>GYD3000000BY_NP00000002Y_NP2000000>Y
_NP0000000000P000003ZKgX00000000008000000jVmj00005XWM`0200000[EbQP8000002?FbO@00
00000?FbO@000?FbO@000?FbOP@000000oFbOP0000000002V5V31P000007mK9m000000000000mK9m
0000mK9m00<000001?FbOP000:5SQ`0000>NGhD400000XA:PP030000WUn6000000800002ZKgX00@0
0025Bh:5Bh800002YfR70P000003SUnF0000QTb300>6C8<2000000C8Q8T0000000000004Qdn61P00
0003ZKgX00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0@000000jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000800000
0oFPD@0008eAP`03SE6300<0000g2f`000000Xa@P`8000000jVmj0000000000200000ZVmj0070000
PDR2PDR2PDR20000dHb7000000:6C8@00`000:ATQ`00000300000jVmj0030000P4R3P4R300:0B8<2
00000hM>Q@<000001:Vmj0000000000000F:DXT00`0008eGRheGR`02SEN;00<0002@EXL000001@00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP00000
00000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX20000007ZKgX00000000ZKgX0000
kHdX000000:HGHT00`000:Vmj0000002000000>Y_NP0000000000`000003ZKgX0000000000D00000
0jVmj00000000002000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000d000001JVmj0000000000002d<M005000000FY_NP0002Y_NRY_NP0000018eHSP030000
/7FA000000800003ZKgX00<0002<EHZ<EHX00XaERPL000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0P000001:Vmj00000000:Vmj0<000001ZVmj000000000000=Yd000000:BF8P5000000>Y
_NP0002Y_NP00P000003A8OY0000SEF900@00003_E0000<0002EG8^EG8/00YELR`8000001JVmj000
000000000:Vmj002000000>Y_NP0000000003@000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000002000
00goool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool00000D?ooo`00<?ooo`040000
oooo000000004Oooo`8000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj00200000V>Rl`050000S5F:S5F:S5F:000000:aNiP01@0008YGSP0000000:Vmj004
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX10000003ZKgX0000000000800003ZKgX00<0002DKJ<000000PT02`030000SUjESUjE
008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000003000000=J
9gL0000000000[EbQP8000002?FbO@0000000?FbO@000?FbO@000?FbOP@000001_FbOP00000009QI
P`000?BaP0D000001oFbO@00000000000?FbO@000?FbO@05000000>QHhL0002NGhD00YiOQ@@00000
18A:PP0009iOQYiOQP<00002ZKgX00X00025Bh:5Bh80002WJ8L00036PhT0002>GiH00003QTb300@0
002OHHL00038Q8T300000hM?QP030000Wf:8000000D00003Qdn60P000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0H000000jVmj00000000006000000BY_NP00000
002Y_NP3000000?eX540002=DH<00XeAP`040000=`]/=`]/00000Xa@P`<000001:Vmj00000000000
00:Y_NP01`000858PX58PX58PP000=6<Q`000002QTb400@0002TI8L0002Y_NP300000ZVmj0030000
P4R3P4R300:0B8<200000hM>Q@@00002ZKgX00<0002:DXV:DXT00hYBR@030000SEN;SEN;00:=Eh/0
0`00091FQ`000003000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000
ZKgX1@000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj006000000>Y_NP00000
00000P000006ZKgX000000000000kHdX00000YQMR@8000000jVmj00000000003000000>Y_NP00000
000010000003ZKgX00000000008000000jVmj00000000008000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP:000000>Y_NP0000000000P000004ZKgX00000000;@ad1`0000>Y_NP02@0008eH
SXeHSXeHSP000;1eT@000:Vmj0000003ZKgX00<0002<EHZ<EHX00XaERP050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj0X000000jVmj00000000002000000BY_NP00000002Y_NP3000000NY
_NP000000000003JM000002BF8P00P000003ZKgX00000000008000002:Vmj000000004B7j@0008eE
R@000:Vmj0800003_E0000<0002EG8^EG8/00YELR`<000000jVmj00000000007000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX3`00
0004ZKgX00000000ZKgX0P0000coool00`000?ooo`000002oooo00<0003oool000000_ooo`030000
oooo0000053oool0033oool200005?ooo`8000001:Vmj00000000:Vmj0@000000jVmj00000000002
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP8000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX0080000016>Rl`0008aERXaERP8000001K5kV00008YGSP000:Vmj002000000>Y_NP00000
00000P000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0H000001JVmj000000000000:Vmj00300000PT02`030000SUjESUjE00<00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000QJ9gL00000
002eLXH0003b[Gl0003e/Wd2000000Ge/Wd0003e/Wd0003e/Wh00P000003mK9m0000mK9n00800000
0iQIP`000?BaP005000000Oe/Wd000000000003e/Wd0003e/Wd01@000003XF>70000WUn500:NGhD4
000000B4BX80002NGhJNGhH3000000>Y_NP00025Bh800XE;PP070000YfR70000aX>90000SUnF0000
00>6C8<01@0009mQQ`0000000?FbO@0200000hM?QP030000Wf:8000000<00005Qdn60`000003ZKgX
0000000000:<FY04000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj004000000BY_NP00000002Y_NP2000000?eX540002=DH<00XeAP`040000
=`]/=`]/00000Xa@P`@000000jVmj00000000002ZKgX00L00021B8:1B8:1B880003AS8L000000XI<
Q0050000Y6B700000000ZKgX00800002ZKgX00<00020B8>0B8<00X18P`800003Qdj50`0000>Y_NP0
0`0008YBRHYBR@03RU:900<0002=Eh^=Eh/00XeGR`030000T5J7000000@000001:Vmj00000000:Vm
j0@000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000002000000FY_NP00000003]SBP0
00000YQMR@H000000jVmj00000000004000000BY_NP00000002Y_NP8000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NPA000000>Y_NP0000000000P000003ZKgX0000;@ad00<000001:Vmj000
0000000000>Y_NP0100008eHSXeHSXeHSPD00003ZKgX00<0002<EHZ<EHX00XaERP8000001:Vmj000
00000:Vmj0`000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX00000000ZKgX1P00
0003fW@00000TUR800<000001JVmj000000000000:Vmj002000000=4QnT0002=EHT01@0000:mD000
0`0009ELRiELR`02UEb;00<0002Y_NP0000010000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP200003?ooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo00<0003oooooool0Coooo`00<?ooo`030000oooooooo01Coool2000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX20000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX10000005ZKgX00000000
0000ZKgX008000002:Vmj000000000000:Vmj00006>Rl`0000:<EHX01@000;5kV;5kV00008YGSP02
000000BY_NP00000002Y_NP4000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1`0000052@0;0000SUjE
0000ZKgX00<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000001JVmj00000000000
05XWM`02000000>eLXH0003b[Gl010000005mK9m0000mK9m0000mK9n008000000oFbO@000?FbOP02
000000BHFH<00000003SWXH4000000Ge/Wd000000000003e/Wd00P000003mK9o0000000000800000
1:5SQ`0009iOQIiOQ@8000001NBOQP00000008A:PP000002WUn60`000003ZKgX0000QD^200:5Bh80
0`000:MXQ`000002000000>>GiH00026C8<00XI<P`050000Wf6700000000mK9m00800003Qdn600<0
002OHXP000000`0000F7ChH4000018aJT08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000004000000>Y_NP0000000000P000007ZKgX00000000ZKgX0000mJ1A0000
00>=DH<0100003L;K3L;K00000:<D8<700000ZVmj0070000PDR2PDR2PDR20000dHb7000000:6C8@0
0`000:ATQ`000002000000FY_NP0002Y_NRY_NP000000h18P`030000dHb8000000>7CXD300000jVm
j0030000RU:9RU:900>:DXT00`0008eGRheGR`02SEN;00D0002@EXL00000002Y_NP00`000004ZKgX
00000000ZKgX10000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP01@000004ZKgX00000000ZKgX10000003ZKgX00000000008000001:Vmj0000>f=:000
00:HGHT3000000>Y_NP00000000010000005ZKgX000000000000ZKgX00H000000jVmj00000000002
000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX1P000003ZKgX
00000000008000000jVmj00000000003000000<]37@0000000000P000004ZKgX0000000000000ZVm
j0040000SER>SER>SER>1@0000>Y_NP00`0008aERXaERP02S5F:0`000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0H000000jVmj00000000002000000>Y_NP00000000020000006ZKgX00000000
fW@00000TUR82P000003A8OY0000SEF9008000000jVmj00000000002_E0000<0002EG8^EG8/00YEL
R`@000001JVmj000000000000:Vmj002000000>Y_NP0000000003@000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000000jVmj000
000000080000Ioooo`00<?ooo`030000oooooooo01Goool2000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000FY_NP00000
0000002Y_NP00P000003ZKgX00000000008000001F>Rl`0008aERXaERP000002/G^H0P000004ZKgX
00000000ZKgX0P000003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY
_NP00000000900/4000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX0P000003ZKgX
00000000008000002JVmj0000000000008e?P0000;EbQP000?:]O`04000000Ce/Wd00000003e/Wh3
000000Ke/Wd00000003e/Wh0002HFH<2000000?SWXH0000000000P000005mK9m000000000000mK9m
008000000oFbO`0000000002000000BQHhL0002NGhFNGhD5000000B4BX80002NGhJNGhH3000000>Y
_NP00025Bh800XE;PP030000YfR70000008000000hiOUP0008I<P`02QTb300D0002OHHL00000003e
/Wd00P0000>7ChH00`0009mRR000000300001HM?QP<00004S5Z@10000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000002000000JY_NP00000
0000003eX5400003SE6300@0000g2f`g2f`00002S5231@000005ZKgX0000ZKgXZKgX000000>1B880
0`000=6<Q`000002QTb400<0002TI8L00000100000:Y_NP01`000818Ph18Ph18P`000=6<R0000003
Qdj50`0000>Y_NP00`0008YBRHYBR@02RU:90P0000B=Eh/00`00091FQ`000002000000FY_NP00000
0000002Y_NP00P000003ZKgX0000000000H000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0D000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX0000000000<00000
1^f=:00009QMRIQMR@000:Vmj0H000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y
_NP0000000000P000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX01<000000bd<M000
00000003000000>Y_NP0000000000ZVmj0050000SER>SER>0000/7FA00@00003ZKgX00<0002<EHZ<
EHX00XaERPH000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP03@000003ZKgX
00000000008000001JVmj0000=Yd0000099HR004000000>Y_NP0000000000`000003A8OY0000SEF9
00<000001JVmj0000;e@0;e@00000004UEb;0P000004ZKgX00000000ZKgX0`000003ZKgX00000000
00<000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP5000000FY
_NP000000000002Y_NP00P000003ZKgX0000000000d000001:Vmj00000000:Vmj080001Woooo000`
oooo00<0003oooooool05_ooo`8000000jVmj00000000002ZKgX0`000003ZKgX0000000000@00000
1JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj004000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P00
0008ZKgX000000000000Hj;c0000S5F:00000[5kV0050000RUN>00000000ZKgX008000001:Vmj000
00000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1`000003SDn00000]G:6
008000000oFbO@0000000002000000?e/Wd0003e/Wh00`000006mK9m00000000mK9n0000V5V30P00
0006hij600000000nKMi0000mK9m10000003mK9m0000mK9o00D00003WUn51@000004Q4Z20000WUn6
WUn60`000003ZKgX0000QD^200:5Bh800`000:MXQ`000002000000>>GiH00026C8<00XI<P`050000
Wf6700000000mK9m00800003Qdn600<0002OHXP000000`0000B7ChH0100009iQR000000000B<FY00
0`000:Vmj0000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP4000000>Y_NP0000000000P000005ZKgX00000000mJ1A000000>=DH<0100003L;K3L;K000
00:<D8<2000000>Y_NP0000000000P0000:Y_NP01`000858PX58PX58PP000=6<Q`000002QTb400@0
002TI8L0002Y_NP300000ZVmj0070000P4R3P4R3P4R30000dHb8000000>7CXD300000jVmj0030000
RU:9RU:900::DXT2000018eGR`030000T5J7000000<000001JVmj000000000000:Vmj006000000>Y
_NP0000000000P000003ZKgX0000000000@000000jVmj00000000003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP9000000C]SBP0002HGHVHGHT5000000>Y_NP0000000001`000004ZKgX
00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj0<000000jVmj00000000006
000000>Y_NP0000000000P000003ZKgX00000000008000000bd<M0000000000600000ZVmj0050000
SER>SER>0000/7FA00D00002ZKgX00@0002<EHZ<EHZ<EHX5000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP5000000>Y_NP00000000010000003ZKgX0000000000800003U6NL0`000003fW@0
0000TUR8008000001:Vmj00000000:Vmj0@000000dB7j@0008eER@0500000ke@00040000UEb;UEb;
UEb;0`000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj00000000002
000000>Y_NP00000000020000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX10000003ZKgX
00000000008000001:Vmj00000000:Vmj080001Voooo000_oooo00<0003oooooool06?ooo`800002
ZKgX0P000003ZKgX0000000000<000000jVmj00000000002000000FY_NP000000000002Y_NP00P00
00:Y_NP2000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX0000000000800000
0jVmj00000000004000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP4000000FY_NP000000000002Y_NP00P000004Y9c=0000000000000XaERP030000/G^H/G^H
008000001:Vmj000000008UDS08000000jVmj00000000002R5>:0`000003ZKgX0000000000800000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0<000000jVmj00000000002000000BY_NP00000002Y_NP3000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0`000006ZKgX00000000SDn00000]G:60P000003mK9m0000000000800000
0oFbO@000?FbOP03000000Ke/Wd00000003e/Wh0002HFH<5000000?i]gT0003e/Wd010000003mK9m
0000mK9o00D00003WUn51@000004Q4Z20000WUn6WUn60`000003ZKgX0000QD^200:5Bh800`000:MX
Q`000002000000>>GiH00026C8<00XI<P`050000Wf6700000000mK9m00800003Qdn600<0002OHXP0
00000`0000B7ChH0100009iQR000000000><FY03000000FY_NP000000000002Y_NP00P000005ZKgX
000000000000ZKgX00D000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP0003e
X5400003SE6300@0000g2f`g2f`00002S5230`000004ZKgX0000000000000ZVmj0070000PDR2PDR2
PDR20000dHb7000000:6C8@01@000:ATQ`0000000:Vmj00200000ZVmj0070000P4R3P4R3P4R30000
dHb8000000>7CXD2000000FY_NP0002Y_NRY_NP0000018YBR@800003SEN;00<0002@EXN@EXL00P00
0003ZKgX0000000000:CIid4000000>Y_NP0000000000P000003ZKgX0000000000@000000jVmj000
00000004000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00H000000jVmj000
00000002000000?]SBP00000000010000003ZKgX0000000000<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0`000000jVmj000
00000002000000FY_NP000000000000]37@01P000005ZKgX00000000ZKgX000000:=F8h010000;1e
T@000:Vmj0<00002ZKgX00H0002<EHZ<EHZ<EHX0002Y_NP4000000BY_NP00000002Y_NP<000000FY
_NP000000000002Y_NP00P000003ZKgX0000U6NL00>DIi`4000000?JM000002BF8P00`000004ZKgX
00000000ZKgX0`000003A8OY0000SEF900D00003_E0000@0002EG8^EG8^EG8/:000000BY_NP00000
002Y_NP?000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX10000003ZKgX0000000000P0001Uoooo000_oooo00<0003oooooool06Ooo
o`<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000001:Vmj0000000000000:Y_NP2
000000BY_NP00000002Y_NP2000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
00H000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP400000XMAR@8000001:BLc@00000008mNT`800002S5F:00<0002aNiRaNiP00`00
00>9E8`3000018QCRP@000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX0000000000800000
1:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000>Y_NP0000000000`000003SDn0
0000]G:6008000000oFbO@0000000002000000?e/Wd0003e/Wh00`000006mK9m00000000mK9n0000
V5V31@000005nKMi000000000000mK9m008000001OFbO@000?FbO`000?FbOP0300000iiOQ@D00000
0hA:PP0009iOQP04000000>Y_NP00025Bh800XE;PP030000YfR70000008000000hiOUP0008I<P`02
QTb300<0002OHHL000000P000005ZKgX0000Qdn6Qdn6000000:OHXP4000018M?QP040000WV680000
00000haJT0030000ZKgX000000D000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002
000000>Y_NP0000000000P000003ZKgX0000000000<000000oFPD@0008eAP`02SE6300L0000g2f`g
2f`0002<D8<0003g/WL00`000003ZKgX0000000000:Y_NP02@000858PX58PX58PP000=6<Q`0008I<
Q0000002Y6B70`000005ZKgX0000ZKgXZKgX000000>0B8<00`000=6<R0000003Qdj5100000:Y_NP0
0`0008YBRHYBR@02RU:90P0000>=Eh/00`00091FQi1FQ`0300000i=WW@<000001:Vmj00000000:Vm
j0H000000jVmj00000000006000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000>Y
_NP0000000000P000003ZKgX0000000000<00002V5f91P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj006000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`000003ZKgX
0000000000<000000jVmj00000000004000000BY_NP00000002Y_NP4000000BY_NP00000000]37@7
000000BY_NP0002Y_NP00002SER>00<0002`MI400000100000:Y_NP0100008aERXaERXaERP800000
0jVmj00000000008000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP300000jVmj0030000
U6NLU6NL00:DIi`4000000?JM000002BF8P030000003SEF90000000000@00002_E0000@0002EG8^E
G8^EG8/4000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX1000
0003ZKgX00000000008000000jVmj00000000006000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000d000001:Vmj00000000:Vmj080001Uoooo000_oooo00<0003oooooool06oooo`800000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP500000ZVmj0<000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000FY_NP00000002Y_NP0
000018MAR@<00003SejC0P000004S5F:0000/G^H/G^H0`0000>9E8`00`000;=kU`000004R5>:00<0
002Y_NP000000`000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@0000:eLXH2000000?e
/Wd0000000000P000003mK9m0000mK9n00@000001OFbOP000?FbOP0009QIP`05000000Gi]gT00000
0000003e/Wd00P000005mK9m000000000000mK9n00<00003WUn51P0000:NGhH4000000FY_NP00025
Bh:5Bh8000000ZMXQ`800002SUnF00H00026C8>6C8>6C8<0002OHHL3000000RY_NP00027ChJ7ChH0
002OHXP0002SI8L3000018M?QP8000001:Y[R@0008aJT8aJT0D000000jVmj00000000002000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000NY_NP00000
002Y_NP0003eX54000000heAP`090000=`]/=`]/0000S5230000mk9g0000ZKgX00@00002ZKgX00@0
0021B8:1B8800002dHb700<00026C8@000000ZATQ`030000ZKgX000000800002ZKgX00L00020B8>0
B8>0B8<0003AS8P000000hM>Q@@00002ZKgX00<0002:DXV:DXT00XYBR@800003SEN;00<0002@EXN@
EXL00P0000BCIid4000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX00000000
008000001:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP00000002Y_NP6000000BY
_NP00000002HGHT5000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000>Y_NP00000
00000P000003ZKgX00000000008000000jVmj00000000006000000>Y_NP00000000020000003ZKgX
0000000000L000000bd<M00000000002000000>Y_NP0000000000P000006ZKgX0000SER>SER>0000
/7FA0P000003ZKgX0000000000:Y_NP0100008aERXaERXaERPL000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0P00004ZKgX00H0002DIibDIibDIi`0002Y_NP5000000>BF8P0000000000P00
0004ZKgX00000000ZKgX10000003SEF900000000008000001JVmj0000;e@0;e@00000003UEb;1@00
0004ZKgX00000000ZKgX1@0000:AHID2000000BY_NP00000002Y_NP4000000>Y_NP0000000002000
0004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX10000003ZKgX0000000000P0001Toooo000_
oooo00<0003oooooool07?ooo`8000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP200000ZVmj08000001JVmj000000000000:Vmj004000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP300000jVmj0070000Qe69Qe69Qe690000UkS^000000B?GY<2000000B<EHX0002a
NiRaNiP300000hUDS0<00004R5>:0P000003ZKgX00000000008000000jVmj00000000002000000>Y
_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000
ZKgX10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0@00002]G:60P000008mK9m00000000mK9m0000mK9m0000mK9n10000005mK9n
0000mK9n0000V5V300D000000oVgN@0000000002000000?e/Wd0003e/Wd00`000004mK9n00000000
00000iiOQ@H00002WUn610000005ZKgX0000QD^2QD^2000000:WJ8L200000XiOUP040000QTb3QTb3
00000YmQQ`<000002:Vmj00008M?QXM?QP0009mRR0000:=TQ`<00004Qdn60P000006ZV^90000S5Z@
S5Z@0000ZKgX10000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP8000000?eX540002=DH<00XeAP`050000=`]/=`]/0000S52300H00000
1JVmj0000:Vmj:Vmj0000002PDR200H0003AS8OAS8L00026C8@00002Y6B71@0000:Y_NP01`000818
Ph18Ph18P`000=6<R0000003Qdj5100000:Y_NP00`0008YBRHYBR@02RU:90P0000>=Eh/00`00091F
Qi1FQ`0200000i=WW@8000001ImUS@00000000000:Vmj002000000>Y_NP0000000000`000003ZKgX
00000000008000000jVmj00000000002000000BY_NP00000002Y_NP5000000FY_NP000000000002Y
_NP01P000003ZKgX00000000008000000iQMR@000:Vmj004000000BY_NP00000002Y_NP3000000>Y
_NP0000000000`000004ZKgX00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vm
j0`000000jVmj00000000002000000>Y_NP0000]37@02@000004ZKgX0000SER>00000[1eT@<00000
1JVmj0000:Vmj:Vmj0000003S5F:0`000003ZKgX00000000008000001:Vmj00000000:Vmj0<00000
0jVmj00000000006000000>Y_NP0000000001:Vmj0030000U6NL000000L000000i9HR0000:Vmj003
000000>Y_NP00000000010000003SEF90000ZKgX00@00002_E0000H0002EG8^EG8^EG8/0002Y_NP:
0000195QU@`000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0X000000jVmj000000000020000Hoooo`00;ooo
o`040000oooo000000007?ooo`8000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@00000
0jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P00
0004ZKgX00000000ZKgX0P0000>Y_NP01`0008MARHMARHMAR@0009NhkP000003SejC00<0002Y_NP0
00000P0000:aNiP00`000240;`000002REB<00@0002cNiL000000004R5>:0`000003ZKgX00000000
008000000jVmj00000000008000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP4000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<00002]G:60P000008mK9m00000000mK9m0000mK9m0000mK9n1000
0003mK9n0000mK9n008000000oBaP00000000003000000Oe/Wd000000000003e/Wd0003e/Wd00`00
0004mK9n0000000000000iiOQ@H00002WUn610000005ZKgX0000QD^2QD^2000000:WJ8L200000XiO
UP040000QTb3QTb300000YmQQ`<000002:Vmj00008M?QXM?QP0009mRR0000:=TQ`<00004Qdn60P00
0003ZV^90000S5Z@00<00002R5270`000003ZKgX0000000000@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00<000000oFPD@0008eAP`02
SE6300D0000g2f`g2f`0002<D8<010000004ZKgX0000000000000ZVmj0040000PDR2PDR200000]6<
Q`030000QTb4000000:TI8L2000000>Y_NP0000000000ZVmj0070000P4R3P4R3P4R30000dHb80000
00>7CXD400000ZVmj0030000RU:9RU:900::DXT200000heGR`030000T5J7T5J700<000001I=WW@00
09UTTP0009mUS@04000000>Y_NP0000000000`000004ZKgX00000000ZKgX10000003ZKgX00000000
008000000jVmj00000000003000000BY_NP00000002Y_NP6000000>Y_NP0000000001@000004V5f9
00000000ZKgX10000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj000
00000008000000>Y_NP0000000000P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX1000
0003ZKgX0000000000X000001XeHSP000;1eTK1eT@000:Vmj0@000000jVmj00008aERP02S5F:1000
0003ZKgX00000000008000000jVmj00000000006000000>Y_NP00000000010000003ZKgX00000000
00>Y_NP00`0009AWW0000002000000>Y_NP0000000000P000004TUR800000000ZKgX20000005A8OY
000000000000ZKgX00<00002_E0000@0002EG8^EG8^EG8/6000000FY_NP00000002Y_NP00000195Q
U@050000T5V;00000000ZKgX008000001JVmj000000000000:Vmj002000000>Y_NP0000000000P00
0003ZKgX0000000000@000001JVmj000000000000:Vmj002000000>Y_NP0000000002P000003ZKgX
00000000008000001:Vmj0000000000006?oool002ooool200007oooo`8000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0@000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0P000005ZKgX00000000ZKgX000000>Y_NP01`0008MARHMARHMA
R@0009NhkP000003SejC00<0002Y_NP000001@0000068@0_0000REB<REB<0000/g^G0P0000>8DhX2
000000BY_NP00000002Y_NP6000000FY_NP000000000002Y_NP010000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX10000003ZKgX0000000000@000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP01@0000:eLXH2000000Se/Wd00000003e/Wd0
003e/Wd0003e/Wh4000000?e/Wh0003e/Wh00P000003m;600000000000<000001oFbO@0000000000
0?FbO@000?FbO@04000000?e/Wh0000000000iiOQ@H00002WUn610000005ZKgX0000QD^2QD^20000
00:WJ8L200000XiOUP070000QTb3QTb30000Wf670000b8B9008000002:Vmj00008M?QXM?QP0009mR
R0000:=TQ`<00004Qdn610000003S5Z@0000R52700>8D8L4000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj009000000?eX540002=DH<00XeA
P`030000=`]/000000:<D8<5000000>Y_NP0000000000ZVmj0040000PDR2PDR200000]6<Q`030000
QTb4000000:TI8L500000ZVmj0070000P4R3P4R3P4R30000dHb8000000:7CXD01@000:9SQ`000:Vm
j0000002ZKgX00L0002:DXV:DXV:DXT0002@EXL000000XeGR`050000T5J7T5J70000n;=f00<00002
VFBB00<0002OIHd000001P000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00`000001JVmj0000000000009QMR@03000000>Y
_NP00000000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vm
j0@000000jVmj00000000002000000>Y_NP0000000002P000004ZKgX00000000ZKgX2P000003ZKgX
0000000000<0000018eHSP000;1eTK1eT@@000001JVmj0000:Vmj:Vmj0000002S5F:1@000003ZKgX
0000000000P000001:Vmj00000000:Vmj0<000000jVmj00000000004000000>Y_NP0000000001000
0005ZKgX000000000000TUR800H000000jVmj00000000002000000=4QnT0000000000P000003ZKgX
0000000000:mD000100009ELRiELRiELR`800003UFZN0P0000>Y_NP00`00095QUI5QU@02TF6E00<0
002@FH/000000P000004ZKgX00000000ZKgX3`000004ZKgX00000000ZKgX2@000004ZKgX00000000
ZKgX3`0006;oool002ooool00`000?ooooooo`0Ooooo0P000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX10000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX0000000000000jVmj0030000Qe69Qe69008000001YNhkP0008mNThmN
T`000:Vmj0H000028@0_00<00029E8b9E8`00P00000350180000R5>:00:8DhX3000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P000003ZKgX00000000008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP010000003]G:60000lZeo00@000001OFbO@00
0?FbO@000?FbOP02000000Ge/Wd0003e/Wh0003e/Wh00`000003hij600000000008000001oFbO@00
000000000?FbO@000?FbO@04000000?e/Wh0000000000iiOQ@H00002WUn610000009ZKgX0000QD^2
QD^20000YfR70000aX>9000000:>GiH01`0008I<PhI<P`0009mQQ`000<R4R@02000000^Y_NP00027
ChJ7ChH0002OHXP0002SI8L0002Y_NP000000hM?QP030000WV68000000<00005R5271@0000:>GI<2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P00
0003mJ1A0000SE6300:=DH<00`0003L;K0000002S5230P000006ZKgX000000000000ZKgX00000ZVm
j0040000PDR2PDR200000]6<Q`030000QTb4000000:TI8L00`000:Vmj000000200000ZVmj0070000
P4R3P4R3P4R30000dHb8000000:7CXD00`000:9SQ`00000200000ZVmj0050000RU:9RU:9RU:90000
00:@EXL00`0008eGR`000002T5J71@0000:II982000000>CFHP0000000000P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX20000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX0`00
0003ZKgX0000kHdX00T000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj002000000>Y_NP0000000000P000003ZKgX0000000000@000000jVmj00000000004
000000FY_NP000000000002Y_NP01@000003ZKgX0000000000D000001JVmj000000000000:Vmj002
00000[1eT@8000001:Vmj0000000000000:Y_NP01@0008aERXaERP000:Vmj005000000>Y_NP00000
00000P000003ZKgX00000000008000001:Vmj00000000:Vmj0D000000jVmj00000000004000000>Y
_NP0000000000P000004ZKgX00000000TUR81`000004ZKgX00000000ZKgX2@000003_E000000UEb;
00:EG8/0100009EZWYEZWYEZWP<00004ZKgX00H0002AHIFAHIFAHID0002@FH/:000000BY_NP00000
002Y_NP4000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0@000000jVmj000000000020000HOooo`00;_ooo`030000oooooooo027oool2
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP00000000010000005ZKgX
000000000000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00@000000jVmj00000000003000000BY_NP0000000000002ZKgX00<0
0027DHV7DHT00P000003UkS^0000SejC00<000000jVmj0000000000300000R40;`070000REB<0000
/g^G00005018000000>8DhX01@000:Vmj00000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX00@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000>Y
_NP0000000001@000003]G:60000lZeo00@000001?FbO@0000000?FbOP<000000oFbO@0000000002
mK9n0`000003hij60000mK9m008000001OFbO@00000000000?FbO@02000000Ge/Wl000000000003e
/Wh00P0000:NGhD2000000?TWhH0000000000P0000:NGhH2000000A@8GL0002Y_NP00002QD^200D0
002WJ8L00036PhT000000XiOUP070000QTb3QTb30000Wf670000b8B9008000001:Vmj00008M?QP00
00:OHXP01@000:=TQ`000:Vmj0000003Qdn600<0002NHHP000000`0000F8D8L300000hiMT`050000
lMBc00000000ZKgX008000001JVmj000000000000:Vmj005000000BY_NP00000002Y_NP3000000BY
_NP0003eX5400003SE6300<0000g2f`000000Xa@P`<000000jVmj0000000000200000ZVmj0040000
PDR2PDR200000]6<Q`030000QTb4000000:TI8L2000000>Y_NP0000000000ZVmj0070000P4R3P4R3
P4R30000dHb8000000:7CXD00`000:9SQ`000003000000>Y_NP0002:DXT00XYBR@060000T5J7T5J7
0000SEN;00000Y1FQ`80000028E@R`0009UTTYUTTP0009mUS@0009=IR0D000001:Vmj00000000:Vm
j0<000000jVmj00000000004000000>Y_NP0000000000P000003ZKgX0000000000H000001JVmj000
000000000:Vmj002000000>Y_NP0000000000P000003kHdX0000000000<000000jVmj00000000002
000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX20000004ZKgX00000000ZKgX1P000003ZKgX0000000000<000000jVmj00000000009
000000>Y_NP0000000000`000003/7FA00000000008000000jVmj00000000002ZKgX00<0002<EHZ<
EHX01@000004ZKgX00000000ZKgX10000003ZKgX0000000000/000000jVmj0000000000;000000FB
F8P000000000002Y_NP02P000004ZKgX00000000ZKgX0P000005_E000000UEb;UEb;000000BEJYh4
00000jVmj0040000TF6ETF6E00000Y1IR`@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002
000000>Y_NP0000000000P000004ZKgX000000000000HOooo`00;_ooo`030000oooooooo02;oool2
000000BY_NP00000002Y_NP2000000>Y_NP0000000000ZVmj0D000000jVmj00000000002000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP01P000005ZKgX000000000000ZKgX00800002ZKgX00<00027DHV7
DHT010000003SejC0000ZKgX00L000002B40;`0008UDS8UDS0000;=kU`0001@0B0000002R5>:0`00
0004ZKgX00000000ZKgX0P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj004
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP8000000BY_NP00000002Y_NP6000000>eLXH0003b[Gl01@000003mK9m0000mK9n
00<000000oFbO@0000000002mK9n0`000003hij60000mK9m008000001OFbO@00000000000?FbO@02
000000Ge/Wl000000000003e/Wh00P0000:NGhD3000000AF9WP0000000000002WUn60P000004D25g
0000ZKgX00000XE;PP050000YfR70000aX>9000000:>GiH01`0008I<PhI<P`0009mQQ`000<R4R@03
00000XM?QP030000Wf:8Wf:800<000000jVmj00008M?QP02Qdn600<0002NHHP000000`0000B8D8L0
100009eQR@00000000>>GI<5000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00800000
0jVmj00000000002000000?eX540002=DH<00XeAP`030000=`]/000000:<D8<4000000BY_NP00000
00000002ZKgX00@00021B8:1B8800002dHb700<00026C8@000000ZATQ`<000001JVmj0000:Vmj:Vm
j0000003P4R300<0003AS8P000000XM>Q@040000XV>70000ZKgX0P000003ZKgX0000RU:900::DXT0
1P00091FQi1FQ`0008eGR`0000:@EXL2000000R5D8/0002II9:II980002OIHd0002CFHP2000000FY
_NP000000000002Y_NP00P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP00000
000020000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003kHdX0000000000@00000
0jVmj00000000002000000>Y_NP0000000001P000005ZKgX000000000000ZKgX008000000jVmj000
00000008000000>Y_NP0000000000P000003ZKgX0000000000X000001:Vmj00000000:Vmj1000000
0k1eT@000:Vmj003000000FY_NP0002Y_NRY_NP000000XaERP8000001JVmj000000000000:Vmj002
000000>Y_NP0000000001P000004ZKgX00000000ZKgX2@000004ZKgX00000000ZKgX1P000003TUR8
0000000000H000000jVmj00000000004000000NY_NP00000002Y_NP0002mD00000000YELR`060000
UFZNUFZNUFZN0000ZKgX0P000005001^0000ZKgXZKgX000000:AHID01@00091IRi1IR`000:Vmj003
000000BY_NP00000002Y_NP:000000>Y_NP0000000000P000003ZKgX0000000000X000001:Vmj000
00000:Vmj0l0001Poooo000^oooo00<0003oooooool08oooo`8000001:Vmj00000000:Vmj0800002
ZKgX0P000004ZKgX00000000ZKgX0P000003ZKgX00000000008000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000003
000000>Y_NP0000000000P000006ZKgX000000000000ZKgX00000ZVmj0040000Qe690000ZKgX1P00
0004ZKgX00000000ZKgX0`0000068@0_0000REB<0000/g^G00000Q@0B0050000R5>:R5>:0000ZKgX
00D000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000>Y
_NP00000000010000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0`000003ZKgX00000000008000001:Vmj00000000:Vmj0D000001;EbQP0000000?FbO@@00000
0oFbO@000?FbOP03000000?e/Wd0000000000_FbOPH000000oVgN@000?FbO@04000000?e/Wd0003e
/Wl01P0000:NGhD3000000=F9WP0000000000iiOQP800000150QM`000:Vmj00000:5Bh800`000:MX
Q`00000200000XiOUP050000QTb3QTb30000Wf67008000000oFbO@0000000002Qdn600<0002OHXRO
HXP00`000003ZKgX0000Qdn600:7ChH00`0009iQR0000003000018Q@Q`040000WF69000000000XiM
T`030000lMBc000000H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0006ZKgX000000000000mJ1A00000heAP`030000=`]/000000:<D8<2000000>Y_NP0000000000`00
00:Y_NP010000858PX58PP0000;AS8L00`0008I<Q0000002Y6B700<0002Y_NP000000P0000:Y_NP0
1`000818Ph18Ph18P`000=6<R0000002Qdj500<0002RHhL000000`000003ZKgX0000RU:900::DXT0
1P00091FQi1FQ`0008eGR`0000:@EXL2000000R5D8/0002II9:II980002OIHd0002CFHP3000000FY
_NP000000000002Y_NP01@000004ZKgX00000000ZKgX2P000003ZKgX00000000008000001:Vmj000
00000:Vmj0<000000jVmj00000000003000000C]SBP00000002Y_NP4000000>Y_NP0000000002000
0004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0@000000jVmj000
00000002000000>Y_NP0000000001P000005ZKgX000000000000ZKgX008000000jVmj00000000008
000000BY_NP0000000000002/7FA0P000003ZKgX0000000000<000001:Vmj00008aERXaERP<00000
0jVmj00000000008000000>Y_NP0000000000P000004ZKgX00000000ZKgX1@000005ZKgX00000000
0000ZKgX008000000jVmj00000000002000000?JM000000000000`000003ZKgX0000000000800000
0jVmj0000000000800000[e@00050000UEb;00000000UFZN00D000001@00KP000:Vmj:Vmj0000002
TF6E00<0002@FH^@FH/00P000003ZKgX0000000000L000001:Vmj00000000:Vmj0@000000jVmj000
00000008000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX1000
0004ZKgX000000000000H?ooo`00;_ooo`030000oooooooo02Coool2000000BY_NP00000002Y_NP3
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2
000000>Y_NP0000000000P000003ZKgX0000000000800002ZKgX00D00027DHT00000002Y_NP01P00
0004ZKgX00000000ZKgX10000004REB<0000/g^G00000Q@0B0030000R5>:000000@00002RUJ>0P00
0003ZKgX0000000000:9E8`2000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX
00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000P000003ZKgX000000000080000015XWM`000;EbQ[EbQP8000000oFbO@00
00000002000000?e/Wd0003e/Wh00`000006mK9m00000000mK9n0000V5V31@000003nKMi0000mK9m
00@000000oFbO@000?FbO`0600000YiOQ@<000000eHVN00000000003WUn60P000004D25g0000ZKgX
00000XE;PP030000YfR70000008000001HiOUP0008I<PhI<P`000002Wf670P000003mK9m00000000
00:7ChH00`0009mRR9mRR003000000>Y_NP00027ChH00XM?QP030000WV68000000<00004R52700@0
002MHHT000000002SUfC1@000003ZKgX0000000000H000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj08000000oFPD@0008eAP`02SE6300<0000g2f`000000Xa@P`D000000jVmj00000000002
ZKgX00@00021B8:1B8800002dHb700@00026C8@0002TI8L600000ZVmj0070000P4R3P4R3P4R30000
dHb8000000:7CXD00`000:9SQ`000003000000>Y_NP0002:DXT00XYBR@030000T5J7T5J700800003
T5J70P00000:QE2;0000VFBBVFBB0000WfF=0000TeV80000ZKgX0P0000:<Eh`4000000FY_NP00000
0000002Y_NP020000003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP5
000000BY_NP00000003]SBP3000000>Y_NP00000000020000003ZKgX00000000008000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000003ZKgX00000000
00P000001:Vmj00000000:Vmj0<000000jVmj00000000006000000>Y_NP0000000000P000003ZKgX
0000000000:`MI46000000BY_NP0002Y_NP00002S5F:00<0002Y_NP0000010000004ZKgX00000000
ZKgX10000003ZKgX0000000000/000001JVmj000000000000:Vmj005000000>Y_NP0000000001@00
0003ZKgX00000000008000000jVmj00000000003000000BY_NP0000000000002_E0000<0002EG8/0
000010000003ZKgX00000000008006h01@000:Vmj000095QU@000003T5V;1P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000002000000BY
_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000003ZKgX0000000000H0001Ooooo000^
oooo00<0003oooooool09Oooo`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000002000000JY
_NP000000000002Y_NP00002Qe690`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0004REB<0000/g^G00000Q@0B0030000R5>:000000800004RUJ>0`0000B9E8`3000000BY_NP00000
002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00H000001:Vmj00005XWM`00
00:eLXH2000000?e/Wd0000000000P000003mK9m0000mK9n00<000001_FbO@0000000?FbOP0009QI
P`D000001?VgN@0000000?FbO@<000000oFbO@000?FbO`0600000YiOQ@<000000eHVN00000000003
WUn60P000006D25g0000ZKgX0000QD^200000ZMXQ`<000001HiOUP0008I<PhI<P`000002Wf670P00
0003mK9m0000000000:7ChH00`0009mRR9mRR003000000>Y_NP00027ChH00XM?QP030000WV680000
00<00004R5270P000005YVN90000SUfC0000lMBc008000001:Vmj00000000:Vmj0<000000jVmj000
00000002000000BY_NP00000002Y_NP3000000NY_NP00000002Y_NP0003eX54000000heAP`030000
=`]/000000:<D8<9000000FY_NP00021B8:1B88000000]6<Q`040000QTb40000Y6B70`000003ZKgX
0000000000:Y_NP01`000818Ph18Ph18P`000=6<R0000002Qdj500<0002RHhL000000`000003ZKgX
0000RU:900::DXT00`00091FQi1FQ`0200000i1FQ`80000018E@R`0009UTTP0000:OIHd0100009=I
R000000000B<Eh`2000000BY_NP00000002Y_NP6000000BY_NP00000002Y_NP2000000>Y_NP00000
00000P000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP6000000>Y
_NP0000000000`000003ZKgX00000000008000000jVmj00000000002000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@000003ZKgX0000000000L000001:Vmj000
00000:Vmj0D000000jVmj00002d<M004000000>Y_NP000000000100000:`MI42000000>Y_NP00000
00000`000004ZKgX0000S5F:S5F:10000005ZKgX000000000000ZKgX008000000jVmj00000000006
000000>Y_NP0000000001`000003ZKgX0000000000<000000jVmj00000000004000000>Y_NP00000
00000P000003ZKgX0000000000P000000jVmj00000000002_E0000<0002EG8/000001@000003ZKgX
00000000008006h2000000>AHID0002@FH/00Y1IR`<000001JVmj000000000000:Vmj002000000>Y
_NP0000000001`000004ZKgX00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vm
j0`000000jVmj0000000001Noooo000^oooo00<0003oool000009_ooo`8000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj006
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y
_NP0000000000P0000:7DHT4000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>c
NiL0000000000Q@0B0040000R5>:0000000018YFSP030000a92O000000B9E8`00`000:Vmj0000002
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP00P00
0005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY_NP0000000000002
T6:I200000:eLXH2000000Se/Wd00000003e/Wd0003e/Wd0003e/Wh4000000Ge/Wh0003e/Wh0002H
FH<01@000005nKMi000000000000mK9m008000001OFbO@00000000000?FbOP0400000YiOQ@<00000
0eHVN00000000002WUn60`000006D25g0000ZKgX0000QD^200000ZMXQ`<000001HiOUP0008I<PhI<
P`000002Wf670P000003mK9m0000000000:7ChH00`0009mRR9mRR003000000>Y_NP00027ChH00XM?
QP030000WV68000000<00004R5270P000003YVN90000SUfC00D000001:Vmj00000000:Vmj0<00000
0jVmj00000000002000000BY_NP00000002Y_NP3000000JY_NP000000000003eX5400002SE6300@0
000g2f`g2f`00002S5231P000005ZKgX00000000ZKgX000000:1B8801`000=6<Qm6<Q`0008I<Q000
0:ATQ`04000000FY_NP0002Y_NRY_NP000000h18P`030000dHb8000000:7CXD00`000:9SQ`000003
00000ZVmj0030000RU:9000000>@EXL200000i1FQ`80000018E@R`0009UTTP0000:OIHd00`0009=I
R0000005S5N<0`000003ZKgX0000000000@000000jVmj00000000003000000BY_NP00000002Y_NP4
000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj000
00000:Vmj0@000000jVmj00000000004000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX00D000001:Vmj00000000:Vmj0l000001JVmj0000000000002d<M00;00000[1eT@<00000
0jVmj00000000002000000BY_NP0002<EHZ<EHX2000000BY_NP00000002Y_NP3000000>Y_NP00000
0000100000>>FHh4000000>Y_NP00000000020000004ZKgX00000000ZKgX3`000003ZKgX00000000
00L000000ke@000009ELR`03000000JY_NP000000000002Y_NP00003001^0`0000>@FH/00`000:Vm
j000000;000000BY_NP00000002Y_NP3000000>Y_NP0000000002@000004ZKgX00000000ZKgX2@00
0004ZKgX00000000ZKgX200005koool002goool00`000?ooo`00000Xoooo0P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX10000003ZKgX0000000000<00000
0jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP4000000FY_NP0000000000027DHT01P000004ZKgX00000000ZKgX0`000003ZKgX00000000
00<000000k=kU`000000000250180P000003ZKgX0000RUJ>00>:EXh3000018UDS08000001JVmj000
000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y_NP0000000000P000005ZKgX00000000
0000ZKgX008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`0000B@HYT0
0`000:Vmj000000500000[EbQP8000002?FbO@0000000?FbO@000?FbO@000?FbOP@000000oFbOP00
0?FbOP02000000?d/H00000000000P000005nKMi000000000000mK9m008000001OFbO@0000000000
0?FbOP0400000YiOQ@<000000eHVN00000000002WUn60`000006D25g0000ZKgX0000QD^200000ZMX
Q`<000001HiOUP0008I<PhI<P`000002Wf671@0000:7ChH0100009mRR0000:=TQ`8000002:Vmj000
08M?QXM?QP0009iQR0000:Y[R@<00004R5270P000006YVN900000000lMBc0000ZKgX0`000003ZKgX
0000000000@000000jVmj00000000002000000BY_NP00000002Y_NP6000000GeX540002=DH>=DH<0
00000SL;K0030000S523S523008000000jVmj00000000002000000BY_NP0002Y_NP00002PDR200T0
003AS8OAS8L00026C8@0002TI8L0002Y_NP0100000:Y_NP010000818Ph18P`0000;AS8P00`0008M>
QHM>Q@02000000VY_NP00000003eWdl0002Y_NP0002:DXT000000i1FQ`800003T5J70P000004QE2;
0000VFBB00000YmUS@030000TeV8000000B<Eh`00`0008YBR0000005000000>Y_NP0000000000`00
0005ZKgX000000000000ZKgX008000000jVmj00000000008000000>Y_NP0000000000P000003ZKgX
0000000000H000001JVmj000000000000:Vmj002000000>Y_NP0000000001P000003ZKgX00000000
00@000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj002000000>Y_NP0000000001P00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000H000001ZVmj000000000000:Vmj00000:`MI48
000000BY_NP0002<EHZ<EHX3000000BY_NP00000002Y_NP5000000>Y_NP0002>FHh018iISP`00000
1JVmj000000000000:Vmj002000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj000
00000008000000RY_NP00000002mD000002EG8/0002Y_NP2000000>Y_NP0000000000P0000<006h2
0000191IR`P000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj000
00000003000000BY_NP00000002Y_NP20000GOooo`00;Oooo`80000Zoooo0P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P000005ZKgX000000000000ZKgX
00@000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@00000
1:Vmj000000008MAR@8000000jVmj00000000002000000BY_NP00000002Y_NP3000000BY_NP00000
00000002/g^G0`000005501800000000ZKgX000000>:EXh010000<B@W`00000000>9E8`01@000:Vm
j00000000:Vmj003000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000001:Vmj0000000000000:Y_NP01000091R
VI1RVI1RV@<000000jVmj0000000000300000[EbQP8000002?FbO@0000000?FbO@000?FbO@000?Fb
OP@000000oFbOP000?FbOP02000000?d/H00000000000`000007mK9m000000000000mK9m0000mK9m
00<000001?FbOP000000000000>NGhD3000000=F9WP0000000000YiOQP<000001U0QM`000:Vmj000
08E;PP0000:WJ8L3000000F>GiH00026C8>6C8<000000YmQQ`D000001XM?QP0009mRR9mRR0000:=T
Q`8000002:Vmj00008M?QXM?QP0009iQR0000:Y[R@<00003R52700<0002MHHT000001P000003ZKgX
0000000000<000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX0000000000<00000
1JVmj00000000?FPD@000002SE6300@0000g2f`g2f`00002S5230`000003ZKgX0000000000<00000
1JVmj0000858PX58PP000002dHb700@00026C8@0002TI8L2000000BY_NP0000000000002ZKgX00@0
0020B8>0B8<00002dHb800<00027CXF7CXD00`000008ZKgX0000mIm?0000ZKgX0000RU:900000i1F
Q`800003T5J70P000006QE2;0000VFBB0000WfF=00000Y=IR0030000S5N<S5N<00:<Eh`6000000>Y
_NP0000000000`000004ZKgX00000000ZKgX0`000003ZKgX0000000000H000000jVmj00000000002
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj000
0000000400000i=WW0@000000jVmj00000000008000000BY_NP00000002Y_NP3000000>Y_NP00000
00002@000003ZKgX0000000000X000001:Vmj00000000:Vmj0@00002/7FA10000006ZKgX00000000
0000ZKgX00000XaERPL000000hiHS@0000000003ZKgX00<0002>FHj>FHh00hiISPD000000jVmj000
00000005000000>Y_NP0000000002P000003ZKgX0000000000P000000jVmj00000000002000000FY
_NP0002mD000002EG8/02@0000@006h00`00091IRi1IR`02T5V;10000003ZKgX0000000000800000
1:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@000000jVmj00000000003000000>Y_NP00000
00000P000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj0000000001L
oooo000]oooo00<0003oooooool0:_ooo`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP6000000F7DHT00000
0000002Y_NP010000004ZKgX00000000ZKgX0`000003ZKgX0000000000:cNiL00`000:Vmj0000003
000000>Y_NP0002:EXh00XYFSP040000a92O000000000hUDS08000001:Vmj00000000:Vmj0<00000
0jVmj00000000003000000BY_NP00000002Y_NP4000000FY_NP000000000002Y_NP01P000004ZKgX
00000000ZKgX0P0000:Y_NP00`00091RVI1RV@02000000BY_NP00000002Y_NP4000000>eLXH0003b
[Gl010000003mK9m0000mK9m00H000000oFbOP000?FbOP03000000?SWXH0003e/Wd00P000007mK9m
000000000000mK9m0000mK9m00@000000oFbOP0000000003WUn50`000003ERIh0000000000:NGhH3
000000I@8GL0002Y_NP00025Bh800002YfR70P000003GBak0000000000:6C8<00`0009mQQimQQ`05
000000J7ChH0002OHXROHXP0002SI8L2000000RY_NP00027ChJ7ChH0002NHHP0002ZJhT300000hQ@
Q`030000WF690000008000000o7D/`000:Vmj002000000B8D8H00000002Y_NP2000000>Y_NP00000
00000P000003ZKgX0000000000<000000jVmj00000000002000000BY_NP0003eX5400002SE6300@0
000g2f`g2f`00002S52310000003ZKgX00000000008000001JVmj0000858PX58PP000002dHb70P00
00:TI8L3000000>Y_NP0000000000ZVmj0040000P4R3P4R300000]6<R0030000Qdj5Qdj500D00000
1_FOC`000:Vmj00008YBR@0000>@EXL200000i1FQ`8000000hE@R`0000000002WfF=00D0002CFHRC
FHP0002<Eh`010000003RU:80000000000D000001JVmj000000000000:Vmj002000000>Y_NP00000
00000`000005ZKgX000000000000ZKgX008000000jVmj00000000002000000>Y_NP0000000002000
0004ZKgX00000000ZKgX1@000003ZKgX0000TfNL00>CIi`00`0009I^XiI^X`07000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP5000000>Y_NP0000000003@000003ZKgX0000000000@00000
1:Vmj00000000:Vmj0@000000k1eT@0000000003000000>Y_NP0000000000P0000:<EHX4000018iH
S@800003ZKgX00<0002>FHj>FHh00hiISPH000000jVmj00000000008000000BY_NP00000002Y_NP3
000000>Y_NP0000000000`000004ZKgX00000000ZKgX10000003ZKgX0000000000<000000ke@0000
09ELR`02000000BY_NP00000002Y_NP300001000KP030000T5V;T5V;00:@FH/5000000>Y_NP00000
000020000004ZKgX00000000ZKgX30000003ZKgX00000000008000000jVmj00000000008000000BY
_NP00000002Y_NP80000G?ooo`00;Oooo`030000oooooooo02_oool2000000>Y_NP0000000001000
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX
00000000008000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0H000001JVmj000000000000:Vmj004000000BY_NP00000002Y_NP5000000FcNiL000000000002Y
_NP00`000009ZKgX0000RUJ>RUJ>0000a92O0000A`eQ000000>9E8`3000000BY_NP00000002Y_NP5
000000FY_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj00000000003000000>Y
_NP0000000000P000004ZKgX00000000ZKgX0P0000:Y_NP00`00091RV@000002000000BY_NP00000
002Y_NP3000000>eLXH0003b[Gl010000004mK9m00000000mK9n0`000003mK9m0000000000;e/Wh3
000000?SWXH0003e/Wd00P000007mK9m000000000000mK9m0000mK9m00@000000oFbOP0000000003
WUn50`000003ERIh0000000000:NGhH3000000I@8GL0002Y_NP00025Bh800002YfR70P000003GBak
0000000000:6C8<0100009mQQ`000<R4R@@000001hM?QP0009mRR9mRR0000:=TQ`000002ZKgX00L0
0027ChJ7ChH0002NHHP0002ZJhT00`0000>8D8L00`0009eQR@00000500000hQ@QP<000000jVmj000
00000002WH:f1@000005ZKgX000000000000ZKgX00D000001OFPD@0008eAPheAP`000002=`]/00<0
002<D8><D8<00P000004ZKgX00000000ZKgX0`000004ZKgX0000PDR200000m6<Q`800002Y6B700H0
002Y_NP00000002Y_NP00002ZKgX00@00020B8>0B8<00002dHb800<00027CXF7CXD01@000006mIm?
0000ZKgX0000RU:900000i1FQ`030000T5J7T5J700:@EXL2000000>5D8/0000000000YmUS@030000
TeV8000000800003S5N<00<0002:DXP0000010000003ZKgX0000000000@000000jVmj00000000003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP8000000>Y_NP00000000010000003ZKgX
0000000000<00003ZKgX00<0002CIibCIi`00Y=WW0030000UVjS000000<000000jVmj00000000002
000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX2P000003ZKgX
00000000008000000jVmj0000000000;000000>`MI40002Y_NP010000009ZKgX00000000ZKgX0000
S5F:0000ZKgX000000F>F8d200000jVmj0030000SUV>SUV>00>>FHh2000000>Y_NP0000000000P00
0003ZKgX0000000000P000000jVmj00000000006000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000L000000ke@000009ELR`03000000BY_NP00000002Y_NP200001000KP030000T5V;T5V;
00:@FH/00`000:Vmj0000007000000BY_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000T000001:Vmj00000000:Vmj0<000000jVmj00000000003
000000BY_NP00000002Y_NP20000Foooo`00;Oooo`030000oooooooo02coool4000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`00
0003ZKgX00000000008000000jVmj00000000004000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP6000000FY_NP000000000002Y_NP010000004ZKgX00000000ZKgX10000003/g^G0000ZKgX
008000001JVmj00000000:Vmj0000002RUJ>00D00034T9l000173F4000000XUDS0D000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0H000001JVmj00000000000
0:Vmj004000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000>Y_NP0000000000`00
0003]G:60000lZeo00D000000oFbO@000?FbOP03000000?e/Wd0000000000_FbOP<000000n>NQP00
0?FbO@02000000Ge/Wd000000000003e/Wd00P000005mK9o000000000000mK9n00800002WUn50P00
0004i9n60000ERIh00000iiOQP<000000e0QM`0000000002QD^200H0002WJ8L00036PhT0001M;7/2
00000XI<P`040000Wf670000b8B910000007Qdn60000Wf:8Wf:80000XfB7000000:Y_NP02P0008M?
QXM?QP0009iQR0000:Y[R@000:Vmj00000>8D8L00`0009eQR@000004000018Q@QP@00003WH:f1000
0003ZKgX0000000000@000000jVmj00000000002000000GeX540002=DH>=DH<000000SL;K0040000
S5230000mk9g0P000004ZKgX00000000ZKgX0P000004ZKgX0000PDR200000m6<Q`800002Y6B70P00
0004ZKgX0000000000000ZVmj0040000P4R3P4R300000]6<R0030000Qdj5Qdj500D000001_FOC`00
0:Vmj00008YBR@0000>@EXL00`00091FQi1FQ`02T5J70P000004QE2;00000000WfF=0`000003TeV8
0000S5N<00:<Eh`00`0008YBR8YBR008000000>Y_NP00000000010000005ZKgX000000000000ZKgX
008000001JVmj000000000000:Vmj006000000>Y_NP0000000002`000003ZKgX0000000000>Y_NP0
200009=WW9=WW9=WW00009I^X`0009QTT`@000000jVmj00000000002000000BY_NP00000002Y_NP5
000000FY_NP000000000002Y_NP00P0000:GL:@4000000>Y_NP0000000000P000003ZKgX00000000
00P000001:Vmj00000000:Vmj0<000001;1eT@0000000:Vmj0H000001ZVmj00008aERP000:Vmj000
00F>F8d00`000:Vmj0000003ZKgX00H0002>FHj>FHj>FHh0002]LY0=000000>Y_NP0000000002000
0004ZKgX00000000ZKgX2P000003ZKgX0000000000@000000iELR`000000000800000`00KP030000
T5V;T5V;00:@FH/6000000>Y_NP0000000000P000003ZKgX0000000000H000001JVmj00000000000
0:Vmj002000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000002000000BY
_NP00000002Y_NP5000000FY_NP000000000002Y_NP00P000003ZKgX0000000005[oool002goool0
0`000?ooooooo`0^oooo0`000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P000005ZKgX000000000000ZKgX00@00000
0jVmj00000000004000000>cNiL0000000000`000006ZKgX000000000000RUJ>00000/B@W`030000
A`eQ000000:9E8`00`000:Vmj0000003000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj00000000002000000BY_NP00000
002Y_NP5000000FY_NP000000000002Y_NP010000004]G:600000000mK9m10000003mK9m0000mK9n
00<000000oFbO@0000000002mK9n1P000003nKMi0000mK9m00<000001?FbO@0000000?FbO`<00000
0oFbOP0000000002WUn50`00009F9WP0100009iOQYiOQYiOQP<000000e0QM`0000000002QD^200H0
002WJ8L00036PhT0001M;7/2000000J6C8<0002OHHNOHHL00038Q8T4000000N7ChH0002OHXROHXP0
002SI8L000000ZVmj00:0000Qdn6Qdn60000WV680000ZV^90000ZKgX00000hQ@Q`030000WF690000
00@00004R5260`0000:MP[H3000000>Y_NP0000000000`000003ZKgX00000000008000001ZVmj000
000000000?FPD@0000:=DH<01`0003L;K3L;K00008a@P`000?NbM`03000000VY_NP00000002Y_NP0
002Y_NP00021B88000000m6<Q`800002Y6B71P0000:Y_NP010000818Ph18P`0000;AS8P00`0008M>
QHM>Q@07000000BY_NP0002:DXT00003T5J700<0002@EXN@EXL00Y1FQ`8000001hE@R`0000000000
09mUS@0009=IR00200000haGS0030000RU:8RU:800@000000jVmj00000000002000000FY_NP00000
0000002Y_NP00P000005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y_NP00000
00000P000003ZKgX0000000000P000000jVmj00000000002WH6d00T0002Y_NRY_NRY_NP0002CIi`0
002FKZ<000000YQTT`D000000jVmj00000000008000000BY_NP00000002Y_NP300000iM`Y0<00000
1:Vmj00000000:Vmj0@000000jVmj00000000008000000BY_NP00000002Y_NP2000000>`MI400000
000010000009ZKgX00000000ZKgX0000S5F:0000ZKgX000000F>F8d00`000:Vmj0000003ZKgX00H0
002>FHj>FHj>FHh0002]LY02000000>Y_NP00000000010000003ZKgX0000000000H000000jVmj000
00000004000000>Y_NP0000000000`000004ZKgX00000000ZKgX1P000005ZKgX000000000000UEb;
00@000001:Vmj00000000:Vmj0800003001^00<0002@FH^@FH/00Y1IR`8000000jVmj00000000002
00000hiHS@P000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@000000jVmj00000000008
000000BY_NP00000002Y_NP80000F_ooo`00;?ooo`030000oooooooo033oool3000000>Y_NP00000
00000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@00
0003ZKgX00000000008000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX0000000000@00000
1JVmj000000000000:Vmj002000000>:EXh00034T9l00P000004A`eQ0000REB<REB<0P000003ZKgX
0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000<000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0<000000jVmj00000000002]G:60P000003mK9m00000000008000000oFbO@00
0?FbOP03000000?e/Wd0000000000_FbOPH000000oVgN@000?FbO@03000000Ce/Wd00000003e/Wl3
000000?e/Wh0000000000YiOQ@<00002ERIh00@0002NGhJNGhJNGhH3000000E@8GL000000025Bh80
00000ZMXQ`040000aX>90000GBak0P000006QTb30000Wf67Wf670000b8B910000009Qdn60000Wf:8
Wf:80000XfB70000ZKgX000000:7ChH00`0009iQR9iQR003000000>Y_NP00028D8L00XQ@Q`030000
WF69000000@00004R5261P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX10000005ZKgX
00000000mJ1A000000:=DH<01@0003L;K3L;K00008a@P`02000000FY_NP000000000002Y_NP00`00
0004ZKgX0000PDR200000m6<Q`800002Y6B70`000003ZKgX0000000000:Y_NP010000818Ph18P`00
00;AS8P01P0008M>Q@000:9SQ`000:Vmj0@000001:Vmj00008YBR@0000>@EXL00`00091FQi1FQ`02
T5J7100000>OIHd0100009=IR000000000><Eh`00`0008YBR8YBR00500000Y1PU@L000001:Vmj000
00000:Vmj0<000000jVmj00000000003000000BY_NP00000002Y_NP:000000>Y_NP0000000000P00
00>MPK@01@00095MT00000000:Vmj003000000>FKZ<0002HI9<00P000003ZKgX0000000000P00000
0jVmj00000000002000000FY_NP00000002Y_NP000000iM`Y0030000SUV>SUV>008000001:Vmj000
00000:Vmj0l000000jVmj00000000003000000BY_NP00000002Y_NP3000000RY_NP0002Y_NP0002<
EHX0002Y_NP00004SUR=100000>Y_NP0100008iISXiISXiISP8000001:Vmj00000000:Vmj0<00000
0jVmj00000000004000000>Y_NP0000000000P000003ZKgX0000000000H000001JVmj00000000000
0:Vmj00<000000>EG8/0000000000`000005ZKgX00000000ZKgX000000<006h00`00091IRi1IR`02
T5V;0`000003ZKgX0000SUR=00B>F8d4000000>Y_NP0000000000P000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0<000000jVmj0000000000;000000>Y_NP00000000020000004ZKgX00000000
ZKgX0P0005Woool002coool00`000?ooooooo`0aoooo0`000003ZKgX00000000008000000jVmj000
00000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1@000003ZKgX00000000008000001JVmj000000000000:Vmj002000000>Y_NP00000
0000100000;4T9l2000000=73F400029E8`010000004Whg000000000Re>90`0000::EH`2000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4000000>Y_NP00000
000010000005ZKgX000000000000ZKgX008000000jVmj0000000000300000[EbQP8000000oFbO@00
00000002000000?e/Wd0003e/Wh00`000003mK9m0000000000;e/Wh6000000?i]gT0003e/Wd01000
0003mK9m0000mK9o00<000000oFbOP0000000002WUn50`00009F9WP0100009iOQYiOQYiOQP<00000
1E0QM`00000008E;PP000002YfR700@00036PhT0001M;7/2000000J6C8<0002OHHNOHHL00038Q8T5
00000imRR0050000XfB70000ZKgX000000:7ChH00`0009iQR9iQR003000000FY_NP00028D8N8D8L0
00000YeQR@D00003R52600<0002OHXT000001@000003ZKgX0000000000<000001:Vmj00000000:Vm
j0H000001OFPD@0008eAPheAP`000002=`]/00<0002<D8<000000P000003ZKgX0000000000@00000
1:Vmj0000858PP0000?AS8L200000ZATQ`H00002ZKgX00@00020B8>0B8<00002dHb800@00027CXD0
002RHhL2000000BY_NP00000003eWdl30000191FQ`030000T5J7T5J700@000000hE@R`0009mUS@02
WfF=00@0002CFHP000000003S5N<00<0002:DXR:DXP00`0000B@H9D3000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y
_NP0000000000P0000:Y_NP00`0009f1]9f1]00200000Y5MT0030000RE>:000000@00002V6BC2@00
0003ZKgX00000000008000000jVmj0000000000200000jVmj0040000Ug2TUg2T00000hiISP<00000
0jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000@000001JVmj00000000000
0:Vmj002000000>Y_NP00000000010000005S5F:0000ZKgXZKgX000000>>F8d500000ZVmj0040000
SUV>SUV>SUV>0`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000002
000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001ZVmj000
00000:Vmj0000;e@008000000jVmj0000000000600001000KP050000T5V;T5V;T5V;000000>Y_NP0
0`0008iHSHiHS@03SUR=1@000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000>Y
_NP0000000000`000003ZKgX0000000000@000000jVmj00000000006000000BY_NP00000002Y_NP3
000000>Y_NP0000000000`0005Soool002coool010000?ooooooooooo`80000_oooo0`000003ZKgX
0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX
00000000ZKgX0P000003ZKgX00000000008000000jVmj00000000002000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX10000005ZKgX
000000000000ZKgX008000000jVmj00000000003000000W4T9l00000000000173F400029E8`0000l
05400`0000>;DhT00`0008YES8YES002RUF<0`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX0P000004ZKgX00000000ZKgX1P000003ZKgX0000000000H000001:Vmj00000000:Vmj0@00002
]G:60P000003mK9m00000000008000000oFbO@000?FbOP04000000Ce/Wh0003e/Wke/Wh6000000Ci
]gT00000003e/Wd3000000?e/Wd0000000000`000003mK9n0000000000:NGhD300000UHVN0040000
WUn6WUn6WUn60`000005D25g00000000QD^2000000:WJ8L200000Ud/N`8000001XI<P`0009mQQimQ
Q`000<R4R@D00003Wf:81@0000:7ChH00`0009iQR9iQR003000000FY_NP00028D8N8D8L000000YeQ
R@D00003R52600<0002OHXT000000P000003ZKgX0000000000<000001JVmj000000000000:Vmj002
000000>Y_NP0000000000`000005mJ1A0000SE63SE630000008g2f`00`0008a@P`000003000000BY
_NP00000002Y_NP2000000BY_NP00021B8800003dHb70P0000:TI8L2000000BY_NP0000000000002
ZKgX00@00020B8>0B8<00002dHb800@00027CXD0002RHhL3000000>Y_NP0003eWdl00`0000B@EXL3
00000Y1FQ`@00003WfF=00@0002CFHP000000003S5N<00<0002:DXR:DXP00P0000B@H9D00`0008mH
R`000002000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<00000
0jVmj00000000003000000>Y_NP0000000001@0000:Y_NP200000i5MT0800002RE>:0`0000>HI9<3
000000FY_NP000000000002Y_NP00P000003ZKgX00000000008000000jVmj0000000000200000jVm
j0030000Ug2T000000>>FHh6000000>Y_NP0000000003@000003ZKgX0000000000@000000jVmj000
00000003000000BY_NP0000000000003ZKgX00@0002>F8f>F8f>F8d500000ZVmj0040000SUV>SUV>
SUV>2P000004ZKgX00000000ZKgX10000003ZKgX0000000000P000001:Vmj00000000:Vmj0D00000
1JVmj000000000000:Vmj003000000>mD000000000001@000004ZKgX0000000000001000KP050000
T5V;T5V;T5V;000000>Y_NP00`0008iHSHiHS@03SUR=2P000003ZKgX0000000000X000001:Vmj000
00000:Vmj0X000000jVmj00000000002000000BY_NP00000002Y_NP5000000>Y_NP000000000F?oo
o`00;?ooo`040000oooo00000000<_ooo`D000000jVmj00000000002000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000002
000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002
000000BY_NP00000002Y_NP200000YE_Y@L000000jVmj0000000000400000/B@W`030000ZKgX0000
00H00004Re>90P0000>:EH`00`000:Vmj0000002000000>Y_NP00000000010000004ZKgX00000000
ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000800000
1:Vmj00000000:Vmj0<00002]G:60P000008mK9m00000000mK9m0000mK9m0000mK9n10000006mK9n
0000mK9nmK9n0000m;6010000005nKMi000000000000mK9m008000001oFbO@00000000000?FbOP00
0?FbOP0200000YiOQ@<00002ERIh00<0002NGhJNGhH010000005D25g00000000QD^2000000:WJ8L2
00000Ud/N`80000018I<P`0009mQQimQQ`8000000oFbO@000000000200000imRR0D00002Qdn600<0
002NHHRNHHP00`000008ZKgX0000R527R5270000WF690000YVN9100000>8D8H00`0009mRR@000006
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY_NP0003eX5400002SE6300D0
000g2f`g2f`0002<D8<00P000003ZKgX0000000000<000001ZVmj0000:Vmj0000858PP0000?AS8L2
00000ZATQ`<000000jVmj00000000002ZKgX00@00020B8>0B8<00002dHb800H00027CXD0002RHhL0
002Y_NP3000000GeWdl000000000002@EXL0100000B@EXL400000YmUS@080000TeV8TeV80000ZKgX
0000S5N<00000XYBR0030000XVF:000000B@H9D00`0008mHR`000003000000>Y_NP0000000000`00
0003ZKgX00000000008000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj005000000Af
Yo40000000000004TEf@0P0000B9DhX01P0009QTTiQTTiQTT`000:Vmj08000001JVmj00000000000
0:Vmj002000000>Y_NP0000000000P0000:Y_NP01@0008UES@0000000:Vmj00200000hiISP030000
Vf6<0000008000001:Vmj00000000:Vmj0<000000jVmj00000000004000000>Y_NP0000000000P00
0003ZKgX0000000000H000000jVmj0000000000400000jVmj0040000SUR=SUR=SUR=1@0000:Y_NP0
100008iISXiISXiISP@000001:Vmj00000000:Vmj0<000000jVmj00000000006000000>Y_NP00000
00000P000003ZKgX0000000000P000001:Vmj00000000:Vmj0X000000jVmj00000000003000000>Y
_NP0000006h00`00KP050000T5V;T5V;T5V;000000>Y_NP00`0008iHSHiHS@03SUR=00<0002Y_NP0
00000`000003ZKgX0000000000P000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0@00000
0jVmj00000000008000000BY_NP00000002Y_NP20000Eoooo`00;?ooo`80000eoooo0P000004ZKgX
00000000ZKgX10000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002000000BY
_NP00000002Y_NP2000000>Y_NP00000000010000003ZKgX00000000008000001JVmj00000000000
0:Vmj002000000FY_NP000000000002Y_NP00P000003ZKgX0000000000>EKjD00`0008eFR@000002
00000XaJT@@000001:Vmj0000000000000;4T9l00`000:Vmj0000004000000>7/_40002;DhT00h]C
R@800003RUF<0P000003ZKgX0000000000<000000jVmj00000000002000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000003ZKgX
0000000000<00002]G:60P000008mK9m00000000mK9m0000mK9m0000mK9n10000006mK9n0000mK9n
mK9n0000m;6020000004mK9m00000000mK9m0`000003mK9n0000mK9n00800002WUn50`00009F9WP0
0`0009iOQYiOQP04000000E@8GL000000025Bh8000000ZMXQ`800002GBak0P000004QTb30000Wf67
Wf670P000003mK9m0000J3Io00800002Wf:800<0002SI8L000000`0000:7ChH0100009iQR0000:Y[
R@8000002:Vmj00008Q@QhQ@Q`0009eQR@000:IWR@@00003R52600<0002OHXT000001`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000@000001OFPD@0008eAPheAP`000002=`]/00<0002<D8<0
00000`000003ZKgX0000000000<000001:Vmj0000858PP0000?AS8L200000ZATQ`060000ZKgX0000
0000ZKgX00000ZVmj0040000P4R3P4R300000]6<R0040000Qdj50000XV>70P000004ZKgX00000000
mIm?100000>@EXL00`00091FQi1FQ`02T5J70P000005Nd1l0000WfF=WfF=000000:CFHP01@000:Vm
j00008aGS0000002RU:800<0002RIHX000000i1PU@030000SeR;SeR;00H000000jVmj00000000002
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj000
0000000200000gJWl@030000TEf@TEf@00:AGI02000018UCRP030000V6BCV6BC00<000001:Vmj000
00000:Vmj0P00004ZKgX00@00029EHf9EHf9EHd2000018iISP030000Vf6<000000<000001:Vmj000
00000:Vmj0X000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX00000000ZKgX1P00
00:Y_NP0100008iHSHiHSHiHS@H000000jVmj00008iISP02SUV>1@000004ZKgX00000000ZKgX1@00
0005ZKgX000000000000ZKgX008000000jVmj00000000006000000BY_NP00000002Y_NP3000000>Y
_NP0000000000`000003ZKgX0000000000T0000015JBk@000000000000<006h01@00091IRi1IRi1I
R`000004ZKgX00<0002>F8f>F8d00XiHS@8000000jVmj00000000008000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj0000000000;000000>Y_NP00000
0000200005Koool002coool00`000?ooooooo`0eoooo0P000004ZKgX00000000ZKgX10000005ZKgX
000000000000ZKgX00H000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj000
00000:Vmj0@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00`0000>EKjD0
100008eFRHeFR@0000B<FY45000000FY_NP000000034T9l000000ZVmj0@00002Qk;a00<0002;DhV;
DhT00X]CR@800002RUF<1P000005ZKgX000000000000ZKgX00@000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000004000000>Y_NP00000
00000[EbQPD000001?FbO@0000000?FbOPD000001?FbOP000?FbO_FbOP8000000n>NQP000?FbO@02
000000Oe/Wd000000000003e/Wd0003e/Wd00`000003mK9n0000000000800002WUn50`00009F9WP0
0`0009iOQYiOQP04000000E@8GL000000025Bh8000000ZMXQ`800002GBak0P000004QTb30000Wf67
Wf670P000003mK9m0000J3Io00800002Wf:800<0002SI8L000000`0000:7ChH0100009iQR0000:Y[
R@8000002:Vmj00008Q@QhQ@Q`0009eQR@000:IWR@8000000hmOU@0008Q@QP02R5260P000005bXN;
000000000000ZKgX00@000001:Vmj00000000:Vmj0D000001ZVmj000000000000?FPD@0000:=DH<0
1@0003L;K3L;K00008a@P`05000000>Y_NP0000000000P000004ZKgX0000PDR200000m6<Q`800002
Y6B70P000004ZKgX0000000000000ZVmj0040000P4R3P4R300000]6<R0040000Qdj50000XV>72@00
00B@EXL00`00091FQi1FQ`02T5J7100000:OIHd0200009=IR9=IR0000:Vmj00008aGS00000::DXP0
0`000:9URP000003T62E00<0002?F8^?F8/010000004ZKgX00000000ZKgX10000003ZKgX00000000
00P000001:Vmj00000000:Vmj0D000000jVmj00000000002MZOa00<0002AGI2AGI000Y5MT0800004
RE>:00<0002HI9>HI9<010000003ZKgX0000000000<000001JVmj00000000:Vmj0000004ZKgX00@0
0029EHf9EHf9EHd2000018iISP040000Vf6<0000ZKgX2@000003ZKgX0000000000D000000jVmj000
00000008000000BY_NP00000002Y_NP500000ZVmj0060000SUR=SUR=SUR=0000ZKgX10000003ZKgX
0000SUV>00:>FHh6000000>Y_NP0000000000`000004ZKgX00000000ZKgX2P000003ZKgX00000000
008000000jVmj00000000006000000FY_NP000000000002Y_NP020000003ZKgX00000000009FT^d0
1@000000KP00KP00KP000004T5V;00D0002Y_NRY_NRY_NP0000018iHS@H000001:Vmj00000000:Vm
j0@000000jVmj00000000004000000FY_NP000000000002Y_NP00P000003ZKgX0000000000<00000
0jVmj00000000004000000>Y_NP0000000001P000004ZKgX00000000ZKgX0P0005Koool002_oool0
0`000?ooooooo`0goooo0P000004ZKgX00000000ZKgX10000003ZKgX0000000000<000000jVmj000
00000002000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4
000000FY_NP000000000002Y_NP01P0000>Y_NP00`0009E_Y@000002SEJ90P0000><FY43000000RY
_NP000000000002Y_NP00034T9l00002ZKgX00<0002=G98000000hNbl@070000Re>9Re>9Re>90000
?@MP000000::EH`4000000>Y_NP00000000010000003ZKgX00000000008000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000000jVmj00000000004000000>e
LXH0003b[Gl010000004mK9m00000000mK9n0`000003mK9m0000000000?e/Wh2000000?SWXH0003e
/Wd00P000007mK9m000000000000mK9m0000mK9m00@000001?FbOP000000000000:NGhD300000UHV
N0030000WUn6WUn600<00002D25g0P000004QD^20000YfR7YfR70P00009M;7/2000000B6C8<0002O
HHNOHHL300000VPfO`800002Wf:800<0002SI8L000000`0000:7ChH0100009iQR0000:Y[R@800000
2:Vmj00008Q@QhQ@Q`0009eQR@000:IWR@8000000hmOU@0008Q@QP02R5260`000004001500000000
00000hUAQ`8000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj08000001OFPD@0008eAPheA
P`000002=`]/00<0002<D8<000001@000008ZKgX000000000000ZKgX0000PDR200000m6<Q`800002
Y6B70`000003ZKgX0000000000:Y_NP010000818Ph18P`0000;AS8P0100008M>Q@000:9SQ`D00000
1?FOC`000000000000B@EXL00`00091FQi1FQ`02T5J7100000:OIHd0200009=IR9=IR0000:Vmj000
08aGS00000::DXP01P000:9URP000000091PU@0000>?F8/5000000BY_NP00000002Y_NP4000000>Y
_NP0000000000`000003ZKgX00000000008000001:Vmj00000000:Vmj08000001JVmj00000000:Vm
j0000002MZOa00L0002AGI2AGI2AGI00001R;GP0000018UCRP030000V6BCV6BC00L000001:Vmj000
0000000000>Y_NP00`000:Vmj:Vmj002ZKgX00@00029EHf9EHf9EHd2000018iISP030000Vf6<0000
00@000001:Vmj00000000:Vmj0<000000jVmj00000000006000000>Y_NP0000000000P000003ZKgX
0000000000X00002ZKgX00@0002>F8f>F8f>F8d600000ZVmj0060000SUV>0000[G:@0000ZKgX1P00
0005ZKgX000000000000ZKgX00P000000jVmj00000000002000000>Y_NP00000000020000004ZKgX
00000000ZKgX2@000005ZKgX00000000ZKgX0000009FT^d01@000000KP00KP00KP000004T5V;00D0
002Y_NRY_NRY_NP0000018iHS@<000001JVmj000000000000:Vmj00;000000>Y_NP0000000002P00
0004ZKgX00000000ZKgX2P000003ZKgX00000000008000001:Vmj00000000:Vmj080001Eoooo000[
oooo00<0003oooooool0>?ooo`8000001:Vmj00000000:Vmj0H000001JVmj000000000000:Vmj004
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP4000000>Y
_NP0000000000`000003ZKgX0000000000800002ZKgX0P0000>=EXT200000haJT@@000001JVmj000
000000000:Vmj00200000ZVmj0030000SEbB000000>7/_401`0008]CRH]CRH]CR@0003d7H0000002
RUF<00<0002Y_NP0000010000003ZKgX00000000008000000jVmj00000000002000000>Y_NP00000
00000`000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1@00
0003]G:60000lZeo00@000001?FbO@0000000?FbOP<000000oFbO@0000000003mK9n0P000003hij6
0000mK9m008000001OFbO@00000000000?FbO@02000000Ge/Wl000000000003e/Wh00`0000:NGhD3
00000UHVN0030000WUn6WUn600<00002D25g0P000004QD^20000YfR7YfR70P00009M;7/300000imQ
Q`<00002J3Io00H0002OHXROHXROHXP0002SI8L4000000J7ChH0002NHHRNHHP0002ZJhT2000000BY
_NP00028D8L00002WF6900H0002VIhT00000002?GiD00003R5260`00000300150000RE6700B9DHL3
000000>Y_NP0000000000`000007ZKgX00000000ZKgX0000mJ1A000000:=DH<01@0003L;K3L;K000
08a@P`02000000>Y_NP0000000000P000007ZKgX00000000ZKgX0000PDR2000000?AS8L200000ZAT
Q`H00002ZKgX00@00020B8>0B8<00002dHb800<00027CXD000001P000004mIm?000000000000191F
Q`030000T5J7T5J700:@EXL400000YmUS@080000TeV8TeV80000ZKgX0000S5N<00000XYBR0060000
XVF:00000000T62E00000hmHR`H000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y
_NP0000000000P000003ZKgX0000000000L00002MZOa00L0002AGI2AGI2AGI00001R;GP0000018UC
RP050000V6BCV6BC0000ZKgX00<000001:Vmj00000000:Vmj0800003ZKgX0P0000>Y_NP01`0008UE
SHUESHUES@0006HcO@000003SUV>00<0002KHH`000001@000004ZKgX00000000ZKgX2@000004ZKgX
00000000ZKgX20000003ZKgX0000000000D00002ZKgX00@0002>F8f>F8f>F8d2000000ZY_NP00000
000005L0002Y_NP0002>FHh0002]LY06000000BY_NP00000002Y_NP5000000>Y_NP0000000001000
0003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000P000003ZKgX00000000
00<000000jVmj00000000004000000>Y_NP0000000000P000003EY;]0000001^008006h00`00091I
Ri1IR`02T5V;00D0002Y_NRY_NRY_NP0000018iHS@050000ZKgX00000000ZKgX00D000000jVmj000
00000002000000>Y_NP00000000020000004ZKgX00000000ZKgX0`000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0@000000jVmj000000000080000E?ooo`006?ooo`D00002oooo00<0003ooooo
ool02Oooo`030000oooooooo03Woool2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3
000000>Y_NP0000000000P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1P000005ZKgX000000000000ZKgX00H00004SEJ90P0000:<FY43000000BY_NP00000
002Y_NP6000000BY_NP0000000000003Qk;a00P0002;DhV;DhV;DhT0000m1f00002:EH`3000000BY
_NP00000002Y_NP2000000>Y_NP0000000000P000003ZKgX0000000000P000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<00002]G:600<0003b[Gl000001000
0003mK9m0000mK9n00<000000oFbO@0000000002mK9n1@000004mK9m00000000mK9m0`000004mK9m
00000000mK9o0`000005mK9n000000000000WUn5008000001NBOQP0005HVN5HVN0000002WUn60`00
009@8GL300000jMXQ`800002GBak0`0000>OHHL300000VPfO`060000Wf:8Wf:8Wf:80000XfB71000
0006Qdn60000WV68WV680000ZV^90`0000:8D8L01@0009eQRIeQR@000:IWR@02000000>?GiD00028
D8H00XQ@QPD00005RE672P000006ZKgX000000000000mJ1A00000XeAP`050000=`]/=`]/0000S523
00<000000jVmj00000000002000000JY_NP0002Y_NP00021B8800003dHb70P0000:TI8L01P000:Vm
j00000000:Vmj00000:Y_NP010000818Ph18P`0000;AS8P3000000>RHhL0000000000`0000;eWdl0
0`00091FQi1FQ`03T5J700<0002@EXN@EXL00Y1FQ`@00002WfF=00<0002CFHRCFHP0100000>:DXP0
0`000:9URP00000200000hmHR`050000WV>;00000000ZKgX00<000000jVmj00000000003000000BY
_NP00000002Y_NP4000000>Y_NP00000000010000005ZKgX000000000000ZKgX00800002MZOa00L0
002AGI2AGI2AGI00001R;GP000001HUCRPP000001JVmj00000000:Vmj0000003ZKgX0P0000>Y_NP0
1`0008UESHUESHUES@0006HcO@000003SUV>00D0002KHH`00000002Y_NP010000003ZKgX00000000
00H000001JVmj000000000000:Vmj006000000>Y_NP00000000010000003ZKgX0000000000<00000
0jVmj00008iHS@02SUR=0`000009ZKgX000000000000ZKgX0000SUV>0000[G:@008000000jVmj000
00000002000000BY_NP00000002>FHh2000000BY_NP00000002Y_NP3000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX10000003ZKgX0000000000@000000jVmj00000000004000000>Y_NP00000
00000`000004ZKgX0000000000000`00KP030000T5V;T5V;00:@FH/01@000:Vmj:Vmj:Vmj0000004
SUR=20000004ZKgX00000000ZKgX2P000003ZKgX00000000008000001:Vmj00000000:Vmj0D00000
1JVmj000000000000:Vmj00=000000BY_NP000000000001Doooo000Joooo00L0003oooooooooool0
003oool000002_ooo`030000oooooooo03[oool2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP3000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<00000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj000000000025GKS00<0002=EXV=
EXT00XeFR@800002S5ZA10000004ZKgX00000000ZKgX2P0000:7/_40100008]CRH]CRH]CR@800002
RUF<00D0002Y_NP00000002Y_NP00P000004ZKgX00000000ZKgX1P000005ZKgX000000000000ZKgX
00@000001:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP00000002Y_NP200000[Eb
QP8000000oFbO@0000000002000000?e/Wd0003e/Wh00`000003mK9m0000000000;e/Wh6000000?i
]gT0003e/Wd00`000004mK9m00000000mK9o0`000005mK9n0000mK=o0000WUn500<00003ERIh00<0
002NGhJNGhH00`00009@8GL300000ZMXQ`030000aX>90000009M;7/300000YmQQ`040000b8B90000
00000VPfO`060000Wf:8Wf:8Wf:80000XfB710000006Qdn60000WV68WV680000ZV^90`0000:8D8L0
0`0009eQRIeQR@04000000>?GiD00028D8H00XQ@QPD00005RE671P000003ZKgX0000000000800000
1JVmj00000000?FPD@000002SE6300D0000g2f`g2f`0002<D8<010000003ZKgX0000000000<00000
1:Vmj0000858PP0000?AS8L200000ZATQ`H00002ZKgX00<00020B8>0B8<010000005Qdj50000XV>7
0000ZKgX00<00002mIm?00<0002@EXN@EXL00i1FQ`030000T5J7T5J700:@EXL400000YmUS@030000
TeV8TeV800@00003RU:800<0002RIHX000000P0000>?F8/00`0009iSR`000002000000>Y_NP00000
00000`000005ZKgX000000000000ZKgX008000000jVmj00000000006000000>Y_NP0000000001000
0005ZKgX00000000MZOa000000>AGI000`00068]N0000005RE>:10000003ZKgX0000000000800000
0jVmj0000000000200000ZVmj0800003ZKgX00L00029EHf9EHf9EHd0001V<gd000000XiISP030000
Vf6<Vf6<00<000000jVmj00000000004000000>Y_NP00000000010000003ZKgX0000000000<00000
0jVmj00000000004000000>Y_NP0000000001`000003ZKgX0000SUR=00:>F8d00`000:Vmj0000004
000000FY_NP0002>FHh0002]LY000`000003ZKgX0000000000800003SUV>0`000004ZKgX00000000
ZKgX2@000003ZKgX0000000000T000000jVmj0000000000:000000BY_NP00000002Y_NP200000`00
KP030000T5V;T5V;00:@FH/01@000:Vmj:Vmj:Vmj0000004SUR=0P000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0@000000jVmj00000000008000000BY_NP00000
002Y_NP5000000>Y_NP00000000010000003ZKgX0000000000H0001Coooo000Joooo00L0003ooooo
ooooool0003oool000002_ooo`030000oooooooo03_oool2000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP3000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00P000006ZKgX000000000000ZKgX00000QEf
h`080000SEJ9SEJ9SEJ90000000]0000S5ZA0P000005ZKgX000000000000ZKgX008000001:Vmj000
00000:Vmj0H00002Qk;a00H0002;DhV;DhT0000m1f000002RUF<0P000004ZKgX00000000TFFK0P00
0003ZKgX0000000000:=G9<2000000BY_NP00000002Y_NP3000000>Y_NP0000000000P000003ZKgX
0000000000H000001JVmj000000000000:Vmj00400000[EbQP8000000oFbO@0000000002000000?e
/Wd0003e/Wh00`000003mK9m0000000000;e/Wh6000000?i]gT0003e/Wd00`000004mK9m00000000
mK9o0`000005mK9n0000mK=o0000WUn500<00003ERIh00<0002NGhJNGhH00`00009@8GL300000ZMX
Q`030000aX>90000009M;7/300000YmQQ`040000b8B9000000000VPfO`060000Wf:8Wf:8Wf:80000
XfB710000006Qdn60000WV68WV680000ZV^90`0000:8D8L00`0009eQRIeQR@04000000>?GiD00028
D8H00XQ@QPD00005RE671`000003ZKgX00000000008000002jVmj0000?FPD@0008eAP`000:Vmj000
03L;K00008a@P`02000000BY_NP00000002Y_NP2000000JY_NP0002Y_NP00021B8800003dHb700@0
002TI8NTI8NTI8L2000000FY_NP000000000002Y_NP0100000?AS8P0100008M>Q@000:9SQ`D00002
mIm?00<0002@EXN@EXL00i1FQ`030000T5J7T5J700:@EXL400000YmUS@030000TeV8TeV800@00003
RU:800@0002RIHX000000004SeR;00@0002NHh/0002Y_NP5000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000003ZKgX0000000000@000000jVmj00000000004000000EfYo40002AGI2AGI00
00000V8]N0030000RE>:RE>:00>9DhX5000000>Y_NP0000000001P0000:Y_NP200000jVmj0070000
REF=REF=REF=0000IS=m000000:>FHh00`0009]QS9]QS008000000>Y_NP0000000002P000004ZKgX
00000000ZKgX0`000003ZKgX0000000000@000000jVmj00000000002000000BY_NP0002>F8f>F8d5
000000RY_NP00000002Y_NP0002>FHh0002]LY0400000ZVmj0030000SUV>SUV>00:>FHh=000000>Y
_NP0000000000`000003ZKgX00000000008000000jVmj0000000000;000000FY_NP000000000002Y
_NP01@00008006h00`00091IRi1IR`02T5V;00D0002Y_NRY_NRY_NP0000018iHS@<000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj00;000000>Y_NP0000000002P000004ZKgX00000000
ZKgX2P000003ZKgX000000000080001Boooo000Joooo00L0003oooooooooool0003oool000002_oo
o`040000oooooooo0000>oooo`8000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D00000
0jVmj00000000002000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj00700000QEfh`080000SEJ9SEJ9SEJ90000000]0000S5ZA0`000005ZKgX
000000000000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000002Qk;a00L0002;DhV;
DhT0000m1f00002:EH`0100000:AII/01000095JR`00000000>=G9<4000000BY_NP00000002Y_NP3
000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj003
00000[EbQP8000000oFbO@0000000002000000?e/Wd0003e/Wh00`000003mK9m0000000000;e/Wh6
000000?i]gT0003e/Wd010000003mK9m0000000000<000001OFbOP000?FcO`0009iOQ@0300000UHV
N0040000WUn6WUn6WUn60`00009@8GL300000ZMXQ`030000aX>90000009M;7/300000YmQQ`040000
b8B9000000000VPfO`080000Wf:8Wf:8Wf:80000XfB70000HS5n0P000006Qdn60000WV68WV680000
ZV^90`0000:8D8L00`0009eQRIeQR@04000000J?GiD00028D8J8D8H0002OHXT400001HUAQ`<00000
0jVmj00000000002000000>Y_NP0000000000`000003mJ1A0000SE6300<000000cL;K00008a@P`03
000000>Y_NP00000000010000004ZKgX0000PDR200000m6<Q`040000Y6B7Y6B7Y6B7200000:0B8<0
20000=6<R=6<R=6<R00008M>Q@000:9SQ`8000000jVmj00000000002mIm?00<0002@EXN@EXL00Y1F
Q`800004T5J710000003WfF=0000TeV800:CFHP400000hYBR0040000XVF:0000000018mHR`030000
WV>;000000<000001JVmj000000000000:Vmj002000000>Y_NP0000000000`000003ZKgX00000000
00@000000jVmj00000000006000000BY_NP0001fYo400002TEf@00D0001R;GQR;GQR;GP0000018UC
RPH000000jVmj00000000003000000>Y_NP0000000000ZVmj0800002ZKgX00L00029EHf9EHf9EHd0
001V<gd000000XiISP030000Vf6<000000@000000jVmj00000000004000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y_NP0000000000P000004ZKgX
0000000000000ZVmj0030000SUR=0000008000001JVmj000000000000000E`02000000>>FHh0002]
LY000P0000BY_NP00`0008iISXiISP02SUV>10000003ZKgX0000000000@000000jVmj00000000003
000000BY_NP00000002Y_NP:000000>Y_NP0000000001@000003ZKgX0000000000<000000jVmj000
00000003001^00D0002@FH^@FH^@FH/000000jVmj0030000SUR=SUR=00:>F8d:000000BY_NP00000
002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000P000001:Vmj00000000:Vmj0T00000
1:Vmj00000000:Vmj0@000001:Vmj0000000000005;oool001[oool01`000?ooooooooooo`000?oo
o`00000:oooo0`0003goool2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP4000000FY_NP000000000002Y_NP01P000004ZKgX00000000ZKgX1@000003ZKgX
00000000008000025GKS00H0002=EXV=EXV=EXT0000002d3000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP2000000FY_NP00000002Y_NP000000XNbl@0:0000Re>9Re>90000?@MP0000RUF<
0000ZKgX00000i5UV`030000TEZ;000000B=G9<00`000:Vmj0000002000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002
00000[EbQP8000000oFbO@0000000002000000?e/Wd0003e/Wh010000006mK9n0000mK9nmK9n0000
m;6010000004nKMi00000000mK9m0`000003mK9m0000000000<000001OFbOP000?FcO`0009iOQ@03
00000UHVN0040000WUn6WUn6WUn60`00009@8GL300000ZMXQ`030000aX>90000009M;7/300000YmQ
Q`040000b8B9000000000VPfO`080000Wf:8Wf:8Wf:80000XfB70000HS5n0P000006Qdn60000WV68
WV680000ZV^90`0000:8D8L00`0009eQRIeQR@04000000J?GiD00028D8J8D8H0002OHXT4000018UA
Q`030000YfV:0000008000000jVmj00000000004000000JY_NP00000003eX540002=DH<3000000<g
2f`0002<D8<01P000005ZKgX000000000000ZKgX00800004dHb700@0002TI8NTI8NTI8L800000X18
P`080000dHb8dHb8dHb80000Qdj50000XV>71@0000;eWdl00`00091FQi1FQ`02T5J70P0000>@EXL0
1@000?RcMP00000007]0O00200000i=IR0<00004RU:800@0002RIHX000000004SeR;00D0002NHh/0
0000002Y_NP01P000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj00000000004
000000>Y_NP0000000000P000006ZKgX0000MZOa0000TEf@00000f8]N0030000RE>:RE>:00:9DhX2
000000>Y_NP0000000000P000003UfnS0000VfRF00<0000019I/X0000:Vmj:Vmj0800002ZKgX00<0
0029EHf9EHd00P000008IS=m0000SUV>SUV>0000Vf6<0000ZKgX1P000003ZKgX0000000000H00000
1:Vmj00000000:Vmj0<000000jVmj00000000003000000BY_NP00000002Y_NP8000000>Y_NP0002>
F8d0100000:Y_NP01`000000E`00000008iISP000:ebT00200001:Vmj0030000SUV>SUV>00:>FHh7
000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX0000000000P000001JVmj00000000:Vmj0000003001^00D0002@FH^@
FH^@FH/000000jVmj0030000SUR=SUR=00:>F8d4000000>Y_NP00000000010000003ZKgX00000000
00<000001:Vmj00000000:Vmj0X000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0`000003ZKgX0000000000H000000jVmj0000000001Aoooo000Ioooo0P0000Coool0
0`000?ooooooo`08oooo0P00043oool2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP4000000>Y_NP0000000000`000003ZKgX00000000008000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0<000025GKS00H0002=EXV=EXV=EXT0000002d4000000>Y
_NP00000000010000004ZKgX00000000ZKgX0P000004ZKgX0000000000000XNbl@030000Re>90000
00@00002ZKgX00D0002AII^AII/0002AFX/00P0000>=G9<3000000FY_NP000000000002Y_NP00P00
0004ZKgX00000000ZKgX0P000003ZKgX00000000008000001JVmj000000000000:Vmj002000000>Y
_NP0000000000`0000:eLXH2000000Se/Wd00000003e/Wd0003e/Wd0003e/Wh4000000Ke/Wh0003e
/Wke/Wh0003d/H04000000Ci]gT00000003e/Wd3000000_e/Wd000000000003e/Wh0003e/Wh0003e
/gl0002NGhD00`00009F9WP01@0009iOQYiOQP000<9nR00200000U0QM`<00002YfR70`00009M;7/3
00000YmQQ`040000b8B9000000000VPfO`080000Wf:8Wf:8Wf:80000XfB70000HS5n0P000006Qdn6
0000WV68WV680000ZV^90`0000:8D8L00`0009eQRIeQR@04000000J?GiD00028D8J8D8H0002OHXT4
000018UAQ`030000YfV:000000<000001JVmj000000000000:Vmj004000000?eX540002=DH<00`00
0003=`]/0000S52300@000001:Vmj00000000:Vmj08000000jVmj00000000004dHb700<0002TI8NT
I8L01@000004ZKgX0000000000000X18P`040000dHb8dHb8dHb80P0000:RHhL3000000FY_NP0003e
WdoeWdl00000191FQ`800003T5J70`000004mJ1@0000000000000i=IR0@00003RU:800@0002RIHX0
00000004SeR;00<0002NHh/0000010000003ZKgX0000000000@000001JVmj000000000000:Vmj002
000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000003000000AfYo40002A
GI000003HReh00<00029DhZ9DhX00XUCRP<000001JVmj00009M_XiM_X`000002VfRF00<0002FK:2F
K:000YI/X0040000ZKgX000000000ZVmj0030000REF=REF=008000001VHcO@0008iISXiISP0009]Q
S08000001JVmj000000000000:Vmj006000000>Y_NP0000000000P000003ZKgX0000000000H00000
1JVmj000000000000:Vmj008000000FY_NP0002Y_NP0002>F8d0100000>Y_NP3000000>>FHh0002]
LY000`0000>Y_NP00`0008iISXiISP02SUV>0`000003ZKgX0000000000T000000jVmj00000000007
000000BY_NP00000002Y_NP:000000>Y_NP0000000000P000004ZKgX0000000000000`00KP050000
T5V;T5V;T5V;000000>Y_NP00`0008iHSHiHS@02SUR=1`000003ZKgX0000000000@000001JVmj000
000000000:Vmj005000000BY_NP00000002Y_NP4000000>Y_NP00000000020000004ZKgX00000000
ZKgX1@000005ZKgX000000000000ZKgX00@0001Aoooo000Zoooo00<0003oooooool0@?ooo`800000
1:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0H000001JVmj000
000000000:Vmj004000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000DEM^<0002=
EXV=EXT000000P00;@L000000jVmj00000000002000000>Y_NP0000000000`000005ZKgX00000000
Qk;a000000:;DhT500000ZVmj0030000TFFK000000:AFX/200000heLT`050000ZKgX00000000ZKgX
00<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000001JVmj000000000000:Vmj007
00000[EbQPD000001?FbO@0000000?FbOPD000001?FbOP000?FbO_FbOP8000000n>NQP0000000005
000000Ce/Wd00000003e/Wd3000000Oe/Wh0003e/Wh0003e/gl0002NGhD00`00009F9WP01@0009iO
QYiOQP000<9nR00200000U0QM`<00002YfR70`00009M;7/300000YmQQ`040000b8B9000000000VPf
O`080000Wf:8Wf:8Wf:80000XfB70000HS5n0`0000>NHHP5000000J8D8L0002MHHVMHHT0002VIhT4
00000hQ@QP030000Wf:9000000<00004RE6700D0002WJHX00000002Y_NP00P000003ZKgX00000000
00<000001JVmj0000?FPD@0008eAP`03000000@g2f`00000003g/WL4000000JY_NP00000002Y_NP0
002Y_NP200001=6<Q`@000000jVmj0000000000500000X18P`040000dHb8dHb8dHb80P0000:RHhL5
00000_FOC`030000T5J7T5J700:@EXL200000i1FQ`<000001?FPD0000000000000>CFHP400000hYB
R0040000XVF:0000000018mHR`040000WV>;0000ZKgX10000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y_NP0000000001`000004MZOa
0000000000000f8]N0030000RE>:RE>:00:9DhX01`000:Vmj:Vmj:Vmj00009M_X`000002VfRF0P00
00>FK:02000000>Y_NP0000000000ZVmj0030000REF=REF=008000001VHcO@0008iISXiISP0009]Q
S0<000000jVmj0000000000300000XiJSP<000000jVmj00000000008000000BY_NP00000002Y_NP5
000000FY_NP000000000002Y_NP00`000003ZKgX0000SUR=00@00003ZKgX00D0000005L00000002]
LY00100000>Y_NP0100008iISXiISXiISPT000000jVmj00000000008000000BY_NP00000002Y_NP3
000000>Y_NP0000000001P000003ZKgX00000000008000000jVmj0000000000500000`00KP040000
T5V;T5V;T5V;0P0000>Y_NP0100008iHSHiHSHiHS@`000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj00=000000>Y_NP00000000020000004ZKgX00000000ZKgX1@000003ZKgX00000000
053oool002[oool00`000?ooooooo`11oooo0P000003ZKgX0000000000@000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0<000000jVmj00000000002000000>Y
_NP0000000000`000004ZKgX00000000ZKgX0P0000055GKS0000SEJ9SEJ90000008002d3000000>Y
_NP0000000000P000003ZKgX0000000000@000001JVmj000000000000:Vmj00300000X]CR@H00000
0jVmj00000000003TEZ;0P0000:=G9<3000000BY_NP00000002Y_NP3000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX10000003ZKgX0000000000<000000jVmj00000000002000000>eLXH0003b
[Gl010000004mK9m00000000mK9n1P0000?e/Wh2000000?SWXH0003e/Wd01@000004mK9m00000000
mK9m0`000007mK9n000000000000mK=o0000WUn500<00002ERIh00<0002NGhJNGhH01000009@8GL3
00000ZMXQ`<00002GBak0P0000>OHHL2000000Ge/Wd0001X=WmX=Wl000000YmRR0050000XfB70000
0000HS5n00<00002WV6800<0002ZJhT000000`000006R5270000WF69WF690000YVN9100000>8D8H0
0`0009mRR@000003000018UAQ`8000001<N5R`0000000:Vmj080000018iKT@0000000:Vmj0<00000
0oFPD@0008eAP`03000000@g2f`00000003g/WL5000000FY_NP000000000002Y_NP00P0000;AS8L3
00000ZATQ`8000001JVmj000000000000:Vmj00200000X18P`040000dHb8dHb8dHb80P0000:RHhL0
0`000:Vmj000000200000_FOC`030000T5J7T5J700:@EXL200000i1FQ`<000001?FPD00000000000
00>CFHP2000000?CShT0002:DXP00XYBR08000000hIDS`0008mHR`03SeR;00D0002NHh/00000002Y
_NP0100000:MP;<2000000>Y_NP00000000010000003ZKgX0000000000<000001:Vmj00000000:Vm
j0D000000jVmj0000000000400000f8]N0030000RE>:RE>:00:9DhX01`000:Vmj:Vmj:Vmj00009M_
X`000002VfRF00@0003ehWd0002FK:07000000BY_NP00029EHf9EHd2000000AV<gd0002>FHh00002
Vf6<00D0002Y_NP00000002?G9400P0000B>FXh:000000>Y_NP0000000000P000003ZKgX00000000
00<000001:Vmj00000000:Vmj0<000002:Vmj00000000:Vmj00008iHS@000:Vmj0800003ZKgX00D0
000005L00000002]LY00100000>Y_NP0100008iISXiISXiISP8000001:Vmj00000000:Vmj0@00000
0jVmj00000000003000000>Y_NP0000000000P000004ZKgX00000000ZKgX1@000005ZKgX00000000
0000ZKgX00/000000jVmj00000000003001^00@0002@FH^@FH^@FH/200000jVmj0040000SUR=SUR=
SUR=0`000003ZKgX00000000008000000jVmj00000000008000000BY_NP00000002Y_NP5000000>Y
_NP00000000010000003ZKgX0000000000H000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vm
j080001?oooo000Zoooo00<0003oooooool0@_ooo`@000000jVmj00000000002000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX008000001:Vmj00001Efh`0000:=EXT01@000000;@0000000:Vmj002
000000>Y_NP0000000000P000005ZKgX000000000000ZKgX00H000001:Vmj000000008]CR@800000
1JVmj00000000000000GU`0300000i5JR`8000000heLT`0000000003000000>Y_NP0000000001P00
0005ZKgX000000000000ZKgX008000000jVmj00000000003000000>Y_NP0000000000P000007ZKgX
000000000000]G:60000lZeo00@000001?FbO@0000000?FbOP<000000oFbO@0000000003mK9n0P00
0003hij60000mK9m008000001oFbO@00000000000?FbO@000?FbO@04000000Ke/Wh00000003e/gl0
002NGhD300000UHVN0030000WUn6WUn600@00002D25g0P0000>WJ8L300000Ud/N`800003Wf670P00
0005mK9m0000J3IoJ3Io000000:OHXP01@000:=TQ`000000068aOP0300000YiQR0030000ZV^90000
00<000001XQ@Q`0009eQRIeQR@000:IWR@@00003R52600<0002OHXT000000`0000B9DHL2000000C7
QH/0000000000003SU^A0`00000:ZKgX00000000mJ1A0000SE630000ZKgX0000=`]/10000003ZKgX
00000000008000001:Vmj00000000:Vmj0@00002dHb700<0002TI8NTI8L02@0000:0B8<010000=6<
R=6<R=6<R0800002XV>70P000003ZKgX0000000000;eWdl00`00091FQi1FQ`02T5J70P0000>@EXL3
000000CeX500000000000003TeV80P000003dhn90000RU:800::DXP2000000>6E8l0002?F8/00hmH
R`8000001JVmj00000000:Vmj0000002WH2c0P000003V6RH00000000008000000jVmj00000000004
000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX0P000003ZKgX0000000000<00003
HReh00<00029DhZ9DhX00XUCRP<000000jVmj00000000003VfRF00@0003ehWd0002FK:02000000>Y
_NP0000000000P0000:Y_NP00`0008UES@000003000000B>FHh0002KHHbKHH`200000hmLT@030000
SUZ>SUZ>00>>FXh6000000>Y_NP0000000000P000003ZKgX0000000000P000001:Vmj00000000:Vm
j0L000000hiHS@000000000300000ZVmj0070000001G00000000[G:@0000k:^800800003ZKgX00@0
002>FHj>FHj>FHh3000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000
00P000001:Vmj00000000:Vmj0X000000jVmj0000000000500000P00KP040000T5V;T5V;T5V;0P00
00>Y_NP01P0008iHSHiHSHiHS@000:Vmj08000000jVmj00000000008000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0X000000jVmj00000000002000000>Y_NP00000
00000`000004ZKgX00000000ZKgX200004ooool002[oool00`000?ooooooo`14oooo0`000003ZKgX
00000000008000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000005ZKgX000000000000ZKgX00<000000aEfh`0008eFR@03000000BY
_NP00000002Y_NP2000000>Y_NP0000000000P000003ZKgX0000000000<000000jVmj00000000004
000000F;DhT000000000002Y_NP00P0000805iL02P00095JRi5JRi5JR`0003P4H00008eLT`000:Vm
j0H000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P000004ZKgX00000000
ZKgX0P000003ZKgX00000000008000001ZVmj00000000;EbQP000?:]O`D000000oFbO@000?FbOP03
000000?e/Wd0000000000oFbOP@000001?FbO@0000000?FbO@<000001?FbO@0000000?FbO`<00000
1_FbOP0000000?FcO`0009iOQ@<00002ERIh00<0002NGhJNGhH01000009@8GL200000jMXQ`<00002
GBak0P0000>OHHL2000000Ge/Wd0001X=WmX=Wl000000YmRR0040000XfB7000000000V8aOP800002
WV6800<0002ZJhT000000`000006R5270000WF69WF690000YVN90P000003SenE0000R52600:8D8H0
0`0009mRR@000003000018UAQ`<000000jVmj00008iKT@02SU^A00<0002?EXP000000P000005U6VN
0000mJ1A0000SE6300<000000cL;K00000000003000000>Y_NP0000000001`0000CAS8L00`000:AT
QjATQ`03000000>Y_NP0000000000`0000:0B8<010000=6<R=6<R=6<R0800002XV>71@0000;eWdl0
0`00091FQi1FQ`02T5J70P0000>@EXL3000000CeX500000000000003TeV80P000003dhn90000RU:8
00::DXP2000000>6E8l0002?F8/00hmHR`<00003ZKgX0`0000>HJ9P9000000BY_NP00000002Y_NP3
000000>Y_NP0000000000`000004ZKgX00000000ZKgX100000=R;GP00`0008UCRXUCRP02RE>:00<0
0029EHf9EHd00P0000>KJ9H00`000?GROOGRO@07000000JY_NP0002Y_NRY_NP00029EHd4000000F>
FHh0002KHHbKHH`0000018mLT@030000SUZ>SUZ>00>>FXh7000000>Y_NP00000000020000003ZKgX
00000000008000000jVmj00000000003000000FY_NP000000000002>F8d01@0000:Y_NP01@000000
E`00E`000:ebT002000000>Y_NP0000000000jVmj0030000SUV>SUV>00@000000jVmj00000000003
000000BY_NP00000002Y_NP8000000>Y_NP00000000010000003ZKgX0000000000<000001:Vmj000
00000:Vmj0/00002001^00@0002@FH^@FH^@FH/200000jVmj0040000SUR=SUR=SUR=0P000003ZKgX
0000000000H000000jVmj00000000002000000>Y_NP00000000010000005ZKgX000000000000ZKgX
00D000001:Vmj00000000:Vmj0@000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX
0000000000<000001:Vmj00000000:Vmj080001>oooo000Zoooo00<0003oooooool0AOooo`<00000
0jVmj00000000004000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX00800000
1:Vmj00000000:Vmj08000000jVmj00000000002000000FY_NP000000000002Y_NP00P0000055GKS
0000SEJ90000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000004000000FY_NP00000
0000002Y_NP01@000003Re>900000000008000001JVmj000000GU`0GU`000003TEZ;00<0000h1600
00001@000003ZKgX00000000008000001JVmj000000000000:Vmj002000000FY_NP000000000002Y
_NP00P000004ZKgX00000000ZKgX0P000003ZKgX0000000000@000000kEbQP000?:]O`05000000?e
/Wd0003e/Wh00`000003mK9m0000000000?e/Wh4000000Ce/Wd00000003e/Wd3000000Ce/Wd00000
003e/Wl3000000Ge/Wh000000000002NGhD00P000005i9n60000ERIhERIh000000:NGhH400000U0Q
M`800003YfR70`00009M;7/200000imQQ`8000001OFbO@0006PfOfPfO`000002Wf:800@0002SI8L0
00000002HS5n0P0000:NHHP00`000:Y[R@000003000000J8D8L0002MHHVMHHT0002VIhT2000000>?
GiD00028D8H00XQ@QP030000Wf:9000000<00004RE670`000003ZKgX0000SU^A00:>Fi40100008mF
R000000000:DJIh200000XeAP`<000000cL;K0000000000:000000>Y_NP0000000001=6<Q`050000
Y6B7Y6B70000ZKgX008000000jVmj0000000000200000X18P`040000dHb8dHb8dHb80P0000:RHhL3
000000FY_NP0003eWdoeWdl00000191FQ`800003T5J70`000004mJ1@0000000000000i=IR0800000
0m>?R@0008YBR002RU:80P0000:6E8l0100008mHRhmHRhmHR`L00004V6RH00<0002LII0000000`00
0003ZKgX00000000008000000jVmj00000000006000000FY_NP000000000002Y_NP01@000005ZKgX
0000HRehHReh000000>9DhX00`0008UESHUES@02REF=00D0002KJ9JKJ9JKJ9H000000_GRO@800000
1:Vmj00000000:Vmj0<00002ZKgX00<00029EHd000000P000003IS=m0000000000:KHH`0100008mL
THmLTHmLT@800004SUZ>00<0002PIhh0000030000003ZKgX00000000008000000jVmj00000000004
000000FY_NP000000000002Y_NP00P000004SUR=00000000ZKgX0P0000>Y_NP010000000E`000:eb
T0D00003ZKgX00D0002>FHj>FHh0002Y_NP01@000005ZKgX000000000000ZKgX00H000000jVmj000
00000004000000>Y_NP00000000010000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vm
j0@00002001^00@0002@FH^@FH^@FH/200000jVmj0040000SUR=SUR=SUR=1@000005ZKgX00000000
0000ZKgX00/000000jVmj00000000006000000FY_NP000000000002Y_NP020000003ZKgX00000000
008000000jVmj00000000004000000FY_NP000000000002Y_NP01@0004goool002Woool00`000?oo
ooooo`17oooo1@000003ZKgX00000000008000001JVmj000000000000:Vmj002000000FY_NP00000
0000002Y_NP00P000004ZKgX00000000ZKgX0P000003ZKgX00000000008000000jVmj00000000004
00000XeFR@8000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vm
j0<000000jVmj00000000002000000>;DhT0002Y_NP0100000805iL01P00095JRi5JRi5JR`0003P4
H0@000000jVmj00000000002XHo20`000005ZKgX000000000000ZKgX00H000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0D000001;EbQP0000000?FbO@@000000oFbO@000?FbOP03000000?e
/Wd0000000000oFbOPD000000oVgN@000?FbO@03000000Ce/Wd00000003e/Wl3000000Ge/Wh0003e
/gl0002NGhD01000009F9WP00`0009iOQYiOQP02000000COL0T0001@8GM@8GL200000jMXQ`800003
GBak0P0000>OHHL300000fPfO`050000Wf:8Wf:80000XfB700800002HS5n0P0000:NHHP00`000:Y[
R@000003000000J8D8L0002MHHVMHHT0002VIhT2000000>?GiD00028D8H00XQ@QP030000Wf:90000
00<00004RE670`000003ZKgX0000SU^A00:>Fi40100008mFR000000000:DJIh200000XeAP`<00000
0cL;K0000000000;000000>1B880003AS8L00m6<Q`030000Y6B7Y6B7008000001:Vmj00000000:Vm
j0<00002P4R300@0003AS8SAS8SAS8P200000Z9SQ`D00002mIm?00<0002@EXN@EXL00Y1FQ`800003
T5J70`000003mJ1@0000000000BCFHP2000000?CShT0002:DXP00XYBR0800002QUB?00D0002?F8^?
F8/0002NHh/00P0000=bYO400`0009QXV9QXV002V6RH0P000003[G:@00000000008000000jVmj000
00000008000000BY_NP00000002Y_NP5000000>Y_NP0000000000P00009R;GP01@0008UCRXUCRXUC
RP000004REF=00H0002KJ9JKJ9JKJ9H0003ehWd7000000>Y_NP0000000000ZVmj0050000REF=0000
0000jXLO00<00002Vf6<00@0002?G96?G96?G942000018iJSP040000X6N>0000ZKgX1@000005ZKgX
000000000000ZKgX008000000jVmj00000000006000000>Y_NP0000000001P000006SUR=00000000
0000ZKgX00000jVmj0040000001G0000[G:@1@0000>Y_NP00`0008iISXiISP05000000BY_NP00000
002Y_NP5000000>Y_NP0000000003@000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX
008000001:Vmj00000000000008006h01`00091IRi1IRi1IR`000:Vmj0000002ZKgX00@0002>F8f>
F8f>F8d3000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000P00000
1:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj00;000000>Y_NP0000000001P000003ZKgX
0000000004goool002Woool00`000?ooooooo`18oooo0P000004ZKgX00000000ZKgX10000005ZKgX
000000000000ZKgX00H000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0H000001:Vmj000
0000000000:=EXT3000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP:00000ZRagP<000000`0GU`00095JR`02TEZ;10000003ZKgX0000000000:QSl82000000B<
Eh`0000000000002S5R>10000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0<00002]G:60P000003mK9m00000000008000000oFbO@000?FbOP03000000?e/Wd00000
00000_FbOP030000mKF4000000<000000oVgN@000?FbO@03000000Ce/Wd00000003e/Wl3000000Ge
/Wh0003e/gl0002NGhD01000009F9WP00`0009iOQYiOQP02000000COL0T0001@8GM@8GL200000ZMX
Q`030000aX>9000000=M;7/200000YmQQ`040000b8B9000000000fPfO`050000Wf:8Wf:80000XfB7
00800002HS5n0P0000:NHHP00`000:Y[R@00000400000ieQR@060000YVN900000000SenE00000hQ@
QP8000001<Z7R`000000000000B9DHL3000000FY_NP0002>Fi6>Fi4000000XmFR0<000000iAYWP00
00000002SE630`000003=`]/0000000000L000001ZVmj000000000000858PP0000CAS8L00`000:AT
QjATQ`03000000BY_NP00000002Y_NP200000X18P`040000dHb8dHb8dHb80P0000:RHhL500000_FO
C`030000T5J7T5J700:@EXL200000i1FQ`<00002mJ1@00<0002CFHRCFHP00Y=IR08000000m>?R@00
08YBR002RU:80P0000:6E8l01@0008mHRhmHR`0009iSR`0300000W:Ul@080000V6RHV6RHV6RH0000
W6F@0000[G:@2`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000001000
009R;GP01@0008UCRXUCRXUCRP000004REF=00@0002KJ9JKJ9H00002mN9m10000005ZKgX00000000
0000ZKgX008000000jVmj00000000002000000CZQal0000000000002Vf6<00@0002?G96?G96?G942
000018iJSP030000X6N>000000@000001:Vmj00000000:Vmj0<000000jVmj00000000004000000>Y
_NP00000000020000004ZKgX00000000ZKgX100000>Y_NP010000000E`000:ebT0D00003ZKgX00<0
002>FHj>FHh01P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0T00002001^00@0
002@FH^@FH^@FH/300000ZVmj0040000SUR=SUR=SUR=2P000004ZKgX00000000ZKgX1@000003ZKgX
00000000008000000jVmj00000000008000000BY_NP00000002Y_NP5000000>Y_NP0000000000P00
0003ZKgX0000000000P000001:Vmj00000000:Vmj080001<oooo000Yoooo00@0003oool000000018
oooo0P000004ZKgX00000000ZKgX10000003ZKgX0000000000<000000jVmj00000000002000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP2000000>=EXT00000
00000`000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0800000
0jVmj00000000003000000RX/Mh000000000002CJZ0000005iL00002TEZ;0`000004ZKgX00000000
ZKgX0`0000><Eh`00`0008aHSXaHSP02S5R>00<0002Y_NP000000P000003ZKgX0000000000800000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0800002]G:60P000003mK9m0000000000800000
0oFbO@000?FbOP04000000Ke/Wh0003e/Wke/Wh0003e]H@4000000Ci]gT00000003e/Wd3000000?e
/Wd0000000000`000005mK9n0000mK=o0000WUn500@00002ERIh00<0002NGhJNGhH00P000004gg09
0000D25gD25g0P0000:WJ8L00`000<J3R@000003GBak0P0000:OHHL010000<R4R@00000000=X=Wl0
1@0009mRR9mRR0000:=TQ`0200000V8aOP060000WV68WV68WV680000ZV^91@0000>MHHT01P000:IW
R@00000008mOU@0000:8D8H0100009mRR@000<Z7R`<00004RE670`000005ZKgX0000SU^ASU^A0000
00:?EXP600000XeAP`P000001:Vmj00000000:Vmj08000001JVmj00000000858PP000004dHb700<0
002TI8NTI8L010000003ZKgX0000000000800002P4R300@0003AS8SAS8SAS8P2000000BRHhL00000
00000002SefC00@0003eWdoeWdl00004T5J70P0000>@EXL300000_FPD0030000TeV8TeV800:CFHP2
000000?CShT0002:DXP00XYBR0800002QUB?00D0002?F8^?F8/0002NHh/00`00009bYO402P0009QX
V9QXV9QXV00009aUT0000:ebT0000:Vmj0D000000jVmj00000000002000000>Y_NP0000000002000
0004ZKgX00000000ZKgX0P00009R;GP01@0008UCRXUCRXUCRP000004REF=00T0002KJ9JKJ9H0003e
hWd0002AFX`0002Y_NP020000006ZKgX00000000Q:g`0000jXLO0P0000>KHH`0100008mLTHmLTHmL
T@800004SUZ>00<0002PIhh000001@000004ZKgX00000000ZKgX1@000003ZKgX0000000000P00000
0jVmj00000000005000000>Y_NP0000000000P0000:Y_NP010000000E`000:ebT0H00002ZKgX00<0
002>FHj>FHh00P000003ZKgX0000000000@000001JVmj000000000000:Vmj008000000>Y_NP00000
00000P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0P00008006h01000091IRi1IRi1IR`<00002ZKgX00@0002>F8f>F8f>F8d4000000BY
_NP00000002Y_NP3000000>Y_NP0000000000`000004ZKgX00000000ZKgX20000003ZKgX00000000
00@000000jVmj00000000003000000BY_NP00000002Y_NP:000000>Y_NP0000000000P000003ZKgX
0000000000<0001;oooo000Yoooo0P0004_oool2000000BY_NP00000002Y_NP6000000FY_NP00000
0000002Y_NP010000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000003ZKgX00000000
008000000heFR@000:Vmj006000000FY_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX
008000000jVmj00000000002ZKgX100000:;Ehd01@0009=ZX000000GU`000002TEZ;100000:Y_NP2
000018aGS0800003S5R>1`000003ZKgX00000000008000000jVmj00000000003000000FY_NP00000
002Y_NP000000[EbQP8000001?FbO@0000000?FbO@8000000oFbOP0000000003000000Ce/Wh0003e
/Wke/Wh6000000Ci]gT00000003e/Wd3000000?e/Wd0000000000`000005mK9n0000mK=o0000WUn5
00@00002ERIh00<0002NGhJNGhH00P000004gg090000D25gD25g0P0000:WJ8L00`000<J3R@000003
GBak0P0000:OHHL010000<R4R@00000000=X=Wl01@0009mRR9mRR0000:=TQ`0200000V8aOP060000
WV68WV68WV680000ZV^91@0000>MHHT01P000:IWR@00000008mOU@0000:8D8H00`0009mRR@000002
000000>Y_NP00029DHL00hUAQ`<000001:Vmj00008iKT@0000:?EXP00`000:5URP00000400000XeA
P``000000jVmj00000000002000000>1B880003AS8L00]6<Q`800002Y6B71@000004ZKgX00000000
00000X18P`040000dHb8dHb8dHb80P000004XV>70000ZKgX00000XmMT`040000mIm?mIm?0000191F
Q`800003T5J70`0000;eX5000`0009=IR9=IR002TeV80P000003dhn90000RU:800::DXP200000XID
S`050000SeR;SeR;0000WV>;00800000189@S00007:Ul@0000:HJ9P00`0009aUT9aUT004000000BY
_NP00000002Y_NP2000000>Y_NP00000000020000003ZKgX00000000008000001JVmj00000000:Vm
j0000002HReh00@00029DhZ9DhZ9DhX2000018UES@040000VfRF000000000Y5JS0P000000jVmj000
0:Vmj002000000F4[O00003ZQaoZQal000000i]QS0040000SebASebA00000VD_N@060000SUZ>SUZ>
SUZ>0000X6N>0P000003ZKgX00000000008000000jVmj00000000003000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000003ZKgX0000000000T00002ZKgX00@0000005L0002]LY02000000BY
_NP0000000000002ZKgX00<0002>FHj>FHh01`000003ZKgX0000000000H000001JVmj00000000000
0:Vmj002000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000004000000FY
_NP000000000002Y_NP00P000003ZKgX00000000008006h00`00091IRi1IR`0300000ZVmj0040000
SUR=SUR=SUR=1@000004ZKgX00000000ZKgX1@0000:AGI42000000>Y_NP00000000010000003ZKgX
0000000000@000000jVmj00000000004000000FY_NP000000000002Y_NP01@000004ZKgX00000000
ZKgX10000003ZKgX0000000000<000001:Vmj0000000000004_oool002Woool00`000?ooooooo`1;
oooo0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000800000
0jVmj00000000003000000BY_NP00000002Y_NP3000000FY_NP000000000002=EXT010000003ZKgX
00000000008000001JVmj000000000000:Vmj006000000BY_NP00000002Y_NP4000000>U_>X0002;
Ehd00h]GS@800000100GU`00095JRi5JR`H000000hZcl@0008aGS003S5N<0P0000><F8h3000000>Y
_NP0000000000P000003ZKgX0000000000<000000jVmj00000000002000000BY_NP0000000000002
]G:61@000004mK9m00000000mK9n1@000004mK9n0000mK9nmK9n1P000004nKMi00000000mK9m0`00
0003mK9m0000000000<000001OFbOP000?FcO`0009iOQ@0400000UHVN0070000WUn60000`Wj80000
gg090000009@8GL200000ZMXQ`030000aX>9000000=M;7/01P0009mQQimQQimQQ`000<R4R@800003
J3Io00D0002OHXROHXP0002SI8L00P00009R<Gh01P0009iQR9iQR9iQR0000:Y[R@8000000fTgP@00
00000003WF6900H0002VIhT00000002?GiD00002R52600<0002OHXT000000P000003ZKgX0000RE67
00:9DHL020000:MYRP0000000:Vmj00008iKT@0000:?EXP00`000:5URP000008000000>Y_NP00000
000010000005ZKgX000000000000ZKgX00<000000h58PP000=6<Q`02dHb70P0000:TI8L00`000:Vm
j000000600000X18P`040000dHb8dHb8dHb80P000004XV>70000ZKgX00000XmMT`040000mIm?mIm?
0000191FQ`800003T5J70`0000;eX5000`0009=IR9=IR002TeV80P000007dhn90000RU:8RU:80000
XVF:000000:6E8l01@0008mHRhmHR`0009iSR`0200000X9@S0050000LZGa0000V6RH000000:LII08
000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000008000000jVmj000
00000002000000=R;GP00029DhX00XUCRP800004REF=0P000005mN9m0000TEZ<0000ZKgX00<00000
0jVmj00000000003000000>Y_NP0000000000P0000;ZQal01@0009]QS9]QS9]QS0000002SebA00@0
001U;gUU;gT00003SUZ>00<0002PIhh000000P000003ZKgX0000000000@000001JVmj00000000000
0:Vmj005000000BY_NP00000002Y_NP4000000>Y_NP0000000000`000003ZKgX0000000000800002
ZKgX0`000005[G:@000000000000ZKgX00800002ZKgX00<0002>FHj>FHh00`000003ZKgX00000000
00P000001:Vmj00000000:Vmj0T000001:Vmj00000000:Vmj0P000000jVmj0000000000900000P00
KP030000T5V;T5V;00<00002ZKgX00H0002>F8f>F8f>F8d0002Y_NP:0000195MT@D000000jVmj000
0000000=000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP020000003ZKgX00000000
008000001:Vmj0000000000004[oool002Woool00`000?ooooooo`1<oooo0P000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP00P000004SEJ900000000ZKgX0P000003ZKgX0000000000800000
0jVmj00000000003000000>Y_NP0000000000P000009ZKgX00000000ZKgX0000YKcZ0000YKcZ0000
00B;Ehd2000000H05iL0002AFX^AFX/0002Y_NP300000XZcl@030000S5N<S5N<00:<Eh`200000haH
SP050000ZKgX00000000ZKgX00H000001JVmj000000000000:Vmj004000000>Y_NP0000000000[Eb
QPD000001?FbO@0000000?FbOPD000001?FbOP000?FbO_FbOPT000001OFbO@00000000000?FbO@03
000000Oe/Wh000000000003e/gl0002NGhD01000009F9WP0100009iOQP000<9nR0<00002D25g00L0
002WJ8NWJ8NWJ8L00036PhT000000ed/N`060000Wf67Wf67Wf670000b8B90P0000=X=Wl01@0009mR
R9mRR0000:=TQ`0200000V8aOP060000WV68WV68WV680000ZV^90P000003JCN10000000000>MHHT4
000000J?GiD00028D8J8D8H0002OHXT3000000>Y_NP00029DHL00XUAQ`080000YfV:00000000ZKgX
0000SU^A00000XmFR0030000XFF:000000@00002SE631`000003ZKgX0000000000@000001JVmj000
00000858PP000003dHb70P0000:TI8L900000X18P`040000dHb8dHb8dHb80P000004XV>70000ZKgX
00000XmMT`040000mIm?mIm?0000191FQ`800003T5J70`0000;eX5000`0009=IR9=IR002TeV80P00
0007dhn90000RU:8RU:80000XVF:000000:6E8l01@0008mHRhmHR`0009iSR`0200000X9@S0040000
LZGa000000000iaUT0D000001JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y
_NP0000000000P000003ZKgX0000000000<000001JVmj0000000068]N0000003RE>:0P0000B9EHd3
00000Y5JS0H000000jVmj00000000006000000B4[O00003ZQal00003Vf6<0P000005SebA0000IBmi
IBmi000000:>FXh00`000:1WSZ1WSP08000000>Y_NP0000000001P000005ZKgX000000000000ZKgX
008000000jVmj00000000003000000>Y_NP0000000000P000004ZKgX0000000000000ZVmj0<00000
0jebT0000000000400000ZVmj0030000SUV>000000X000000jVmj00000000002000000>Y_NP00000
00001P000005ZKgX000000000000ZKgX00H000000jVmj00000000008000000FY_NP00000002Y_NP0
00000P00KP030000T5V;T5V;00@00002ZKgX00<0002>F8d00000200000:Y_NP00`00095MTI5MT@03
TEfA0`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000008000000BY
_NP00000002Y_NP5000000FY_NP000000000002Y_NP02`0004Woool002Soool00`000?ooooooo`1>
oooo0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX1@000003ZKgX0000000000800000
1JVmj000000000000:Vmj006000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP6000000FY
_NP000000000002Y_NP010000004ZKgX0000000000000jFljP030000ReN=ReN=00:;Ehd2000000<0
5iL0002AFX/00`000003ZKgX0000000000::/o401`0008aGS8aGS8aGS0000=6JW@000002S5R>0`00
0004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000kEbQP00
0?:]O`04000000Ce/Wd00000003e/Wh600000oFbOP@000000oFbO@0000000003000000Ce/Wd00000
003e/Wd3000000Oe/Wh000000000003e/gl0002NGhD01000009F9WP0100009iOQP000<9nR0<00002
D25g00@0002WJ8NWJ8NWJ8L300000ed/N`060000Wf67Wf67Wf670000b8B90P0000=X=Wl01P0009mR
R9mRR0000:=TQ`0000=R<Gh01P0009iQR9iQR9iQR0000:Y[R@8000000fTgP@0000000002WF6900<0
002VIhT000000P000006SenE0000R526R5260000Wf:90`000003ZKgX0000RE6700:9DHL00`000:MY
RP00000400000hmFR0L00002SE632P000003ZKgX0000000000@000000h58PP000=6<Q`02dHb70P00
00:TI8L4000000>Y_NP0000000000P0000:0B8<010000=6<R=6<R=6<R08000001:9SQ`000:Vmj000
00:?GI<010000?FOCoFOC`0000B@EXL200000i1FQ`<00002mJ1@00<0002CFHRCFHP00Y=IR0800000
1m>?R@0008YBR8YBR0000:9URP000002QUB?00D0002?F8^?F8/0002NHh/00P0000>2D8`300000YaU
T0050000[G:@00000000ZKgX00H000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y
_NP0000000000P000004ZKgX0000HReh00000XUCRP030000ZKgX000000B9EHd300000Y5JS0800000
0jVmj00000000002000000>Y_NP0000000001`000003jXLO0000Vf6<00:KHH`2000000F?G940001U
;gUU;gT000000XiJSP030000X6N>000000@000000jVmj00000000008000000BY_NP00000002Y_NP3
000000>Y_NP0000000000`000004ZKgX00000000ZKgX1`0000:Y_NP3000000>]LY00000000000P00
0008ZKgX00000000ZKgX0000SUV>0000ZKgX1@000003ZKgX00000000008000000jVmj0000000000;
000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj00000000002000000BY_NP00000
00000002001^00<0002@FH^@FH/0100000:Y_NP00`0008iHS@000004000000>Y_NP0000000000jVm
j0030000TEfATEfA00>AGI4:000000BY_NP00000002Y_NP:000000>Y_NP00000000020000004ZKgX
00000000ZKgX1@000003ZKgX00000000008000001:Vmj0000000000004Woool002Soool00`000?oo
ooooo`1?oooo0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0P000004ZKgX00000000
ZKgX10000003ZKgX0000000000<000000jVmj00000000005000000BY_NP00000002Y_NP2000000FY
_NP000000000002Y_NP01P000003ZKgX0000000000H00002YKcZ00@0002;Ehf;Ehf;Ehd3000000<0
5iL0002AFX/01P0000::/o401`0008aGS8aGS8aGS0000=6JW@000002S5R>10000004ZKgX00000000
ZKgX0`000004ZKgX00000000ZKgX1@000007ZKgX000000000000]G:60000lZeo00D000000oFbO@00
0?FbOP03000000?e/Wd0000000000oFbOP@000001?FbO@0000000?FbO@8000001?FbO@0000000?Fb
O@@000001_FbOP0000000?FcO`0009iOQ@@00002ERIh00@0002NGhH00032OXP300000U0QM`040000
YfR7YfR7YfR70`0000=M;7/01P0009mQQimQQimQQ`000<R4R@800003J3Io00<0002OHXP000000Z=T
Q`050000HS5nHS5nHS5n000000:NHHP00`000:Y[RJY[R@02000000=Y=h40002MHHT00YeQR@030000
YVN90000008000001XmOU@0008Q@QXQ@QP0009mRR@<000000jVmj00008UAQ`02RE6700<0002WJHX0
000010000003SeJ800000000008000000nBOQ`0008]DR@0200000XeAP`/000000jVmj00000000004
00001=6<Q`800002Y6B70P000004ZKgX00000000ZKgX0`000003P4R30000dHb800?AS8P2000000NR
HhL0002Y_NRY_NP0002?GI<000000_FOC`030000T5J7T5J700:@EXL200000i1FQ`<00002mJ1@00<0
002CFHRCFHP00Y=IR08000001m>?R@0008YBR8YBR0000:9URP000002QUB?00D0002?F8^?F8/0002N
Hh/00P0000>2D8`200000iaUT0030000[G:@000000@000000jVmj00000000004000000FY_NP00000
0000002Y_NP01@000004ZKgX00000000ZKgX1@000007HReh0000RE>:RE>:0000ZKgX000000B9EHd2
00000i5JS0<000000jVmj00000000003000000>Y_NP0000000000P000005ZKgX00000000jXLO0000
00>KHH`400000VD_N@070000SUZ>SUZ>0000X6N>0000ZKgX00X000000jVmj00000000002000000>Y
_NP0000000001P000005ZKgX000000000000ZKgX00P000000jVmj0000:Vmj003000000B]LY000000
002Y_NP2000000FY_NP0002Y_NP0002>FHh01@000004ZKgX00000000ZKgX2P000003ZKgX00000000
00P000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000`000005ZKgX
0000001^001^000000:@FH/010000:Vmj000000000:Y_NP00`0008iHS@000002000000FY_NP00000
002Y_NP000000jVmj0030000TEfATEfA00:AGI400`000;QmU0000002000000BY_NP00000002Y_NP<
000000>Y_NP0000000001P000003ZKgX0000000000X000001:Vmj00000000:Vmj0D000000jVmj000
00000018oooo000Xoooo00<0003oooooool0D?ooo`8000000jVmj00000000004000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP6000000FY_NP000000000002Y_NP01`000004ZKgX00000000
ZKgX0P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000005ZKgX
0000YKcZYKcZ000000>;Ehd3000000<05iL0002AFX/010000005ZKgX0000R[?aR[?a000000><Eh`0
10000=6JW@0008aHSP8000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP00P00
0004ZKgX00000000ZKgX0P000006ZKgX00000000]G:60000lZeo1@000003mK9m0000mK9n00<00000
0oFbO@0000000002mK9n00<0003e]H@000000P000004mK9m00000000mK9m0`000004mK9m00000000
mK9o0`000006mK9n00000000mK=o0000WUn51000009F9WP00`0009iOQP00000400000U0QM`040000
YfR7YfR7YfR70`0000=M;7/01P0009mQQimQQimQQ`000<R4R@800003J3Io00<0002OHXP000000Z=T
Q`050000HS5nHS5nHS5n000000:NHHP010000:Y[RJY[R@00009Y=h401P0009eQRIeQRIeQR@000:IW
R@<000001XmOU@0008Q@QXQ@QP0009mRR@<000000jVmj00008UAQ`02RE6700<0002WJHX000001@00
00:?EXP2000000?TWhL0002;E8T00P000005SE63000000000000T62E00@000000jVmj00000000002
000000>Y_NP0000000000`0000CAS8L200000ZATQ`<000001:Vmj00000000:Vmj08000000h18P`00
0=6<R003dHb800@0002RHhNRHhL00002ZKgX00<0002?GI<000000_FOC`030000T5J7T5J700:@EXL2
00000i1FQ`<00002mJ1@00<0002CFHRCFHP00Y=IR08000001m>?R@0008YBR8YBR0000:9URP000002
QUB?00D0002?F8^?F8/0002NHh/00P0000B2D8`01P0009aUT9aUT9aUT0000:ebT0X000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000>Y_NP0000000000P000007HReh0000RE>:
RE>:0000ZKgX000000B9EHd200000i5JS0030000ZKgX000000@000001:Vmj00000000:Vmj0H00000
0nZ77`0009]QS002Vf6<1000009U;gT01@0008iJSXiJSP000:1WSP02000000>Y_NP0000000000`00
0003ZKgX00000000008000000jVmj00000000008000000BY_NP00000002Y_NP5000000FY_NP00000
0000002Y_NP00`000004ZKgX00000000001G10000007ZKgX000000000000ZKgX0000SUV>00800000
1JVmj000000000000:Vmj008000000>Y_NP0000000003@000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000000jVmj0000000000300000P00KP030000T5V;T5V;00@00002ZKgX00<0002>F8d0
00000`0000>Y_NP200000jVmj0060000TEfATEfATEfA0000^7fD10000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0X000000jVmj00000000008000000BY_NP00000002Y_NP9000000BY_NP00000
002Y_NP20000Aoooo`00:?ooo`030000oooooooo057oool4000000>Y_NP0000000000P000004ZKgX
00000000ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003ZKgX00000000
008000000jVmj00000000003000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP6000000>Y
_NP0000000000P0000:U_>X01@0008]GSH]GS@0005dQJP0300000Y5JR`030000ZKgX000000@00000
1HZcl@0008aGS8aGS0000002dIZM00<0002<F8h000000P000005ZKgX000000000000ZKgX00800000
1JVmj000000000000:Vmj005000000>Y_NP0000000000P000004]G:600000000mK9m10000003mK9m
0000mK9n00<000000oFbO@0000000002mK9n00<0003e]H@000000P000004mK9m00000000mK9m0`00
0004mK9m00000000mK9o0`000004mK9n00000000mK=o0`000003i9n600000000009F9WP00`0009iO
QP00000400000U0QM`040000YfR7YfR7YfR70`0000=M;7/0100009mQQimQQimQQ`8000000oFbO@00
06PfO`02J3Io00<0002OHXP000000Z=TQ`050000HS5nHS5nHS5n000000:NHHP010000:Y[RJY[R@00
009Y=h401P0009eQRIeQRIeQR@000:IWR@<000001XmOU@0008Q@QXQ@QP0009mRR@<000000jVmj000
08UAQ`02RE6700<0002WJHX000000`0000B?EXP2000000?TWhL0002;E8T00P000005SE630000WF:;
0000T62E00D000000jVmj00000000003000000BY_NP0000000000004dHb70P0000:TI8L4000000>Y
_NP0000000000P000003P4R30000dHb800?AS8P00`000:9SQj9SQ`02000000BY_NP0002?GI<00002
mIm?00<0002@EXN@EXL00Y1FQ`800003T5J70`0000;eX5000`0009=IR9=IR002TeV80P000007dhn9
0000RU:8RU:80000XVF:000000:6E8l01@0008mHRhmHR`0009iSR`020000189@S0060000W6F@W6F@
W6F@0000[G:@0P000005ZKgX000000000000ZKgX00@000000jVmj00000000003000000BY_NP00000
002Y_NP3000000>Y_NP00000000010000007HReh0000RE>:RE>:0000ZKgX000000B9EHd200000i5J
S0@000001JVmj000000000000:Vmj002000000>Y_NP0000000000`000003jXLO0000Vf6<00:KHH`5
000000IU;gT0002>FXj>FXh0002PIhh6000000BY_NP00000002Y_NP:000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0H000000jVmj00008iHS@02000000?/ZhP00000
000010000003ZKgX0000SUV>00<000000jVmj00000000003000000FY_NP000000000002Y_NP01P00
0003ZKgX0000000000@000000jVmj00000000004000000FY_NP000000000002Y_NP01@000004ZKgX
00000000ZKgX1@000004001^0000T5V;T5V;1@000003ZKgX0000SUR=00<00005ZKgX00D0002Y_NRY
_NRY_NP000000i5MT@030000^7fD000000X000000jVmj00000000003000000BY_NP00000002Y_NP:
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0P00017oooo000X
oooo00<0003oooooool0Doooo`<000000jVmj00000000002000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000020000004ZKgX00000000
ZKgX0P000004ZKgX00000000ZKgX0`000004ZKgX00000000ZKgX0`000003YKcZ0000ReN=00:;Ehd0
0`0005dQJP000002000000FAFX/000000000002Y_NP010000005R[?a0000S5N<S5N<000000;AVYd0
0`0008aHSP00000300000Y9VW08000000jVmj00000000002SUfC10000005ZKgX000000000000ZKgX
00<000001;EbQP0000000?FbO@@000000oFbO@000?FbOP03000000?e/Wd0000000000_FbOP800000
1oFeQ000000000000?VgN@000?FbO@03000000Ce/Wd00000003e/Wl3000000Ce/Wh0003e/goe/gl4
000000JY_NP0001F9WQF9WP0002NGhH2000000?OL0T0000000000U0QM`040000YfR7YfR7YfR70`00
00=M;7/0100009mQQimQQimQQ`8000000oFbO@0006PfO`02J3Io00@0002OHXP0002SI8L200000f8a
OP050000WV68WV680000ZV^900800002JCN100H0002MHHVMHHVMHHT0002VIhT200000XmOU@050000
R526R5260000Wf:900<000001:Vmj00008UAQhUAQ`<000001<N5R`0008==Q`0000B?EXP2000000?T
WhL0002;E8T00P000005SE630000WF:;0000T62E00H000001:Vmj00000000:Vmj08000000jVmj000
00000004dHb70P0000:TI8L5000000JY_NP0000000000020B8<00004dHb800<0002RHhNRHhL00P00
0004ZKgX0000000000000_FOC`030000T5J7T5J700:@EXL200000i1FQ`<00002mJ1@00T0002CFHRC
FHRCFHP00023CHH0003CShT000000XYBR0030000XVF:000000:6E8l01@0008mHRhmHR`0009iSR`02
0000189@S0060000W6F@W6F@W6F@0000[G:@1`000003ZKgX0000000000P000001:Vmj00000000:Vm
j0D000000jVmj0000000000300000XUCRP030000ZKgX000000>9EHd00`000<AA00000003TEZ<0P00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000<000001:Vmj0000>Z77`0000>KHH`5000000IU
;gT0002>FXj>FXh0002PIhh3000000FY_NP000000000002Y_NP00P000003ZKgX0000000000<00000
0jVmj00000000002000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj00000000002
ZKgX0`000003k:^80000000000<000001ZVmj000000008iISP000:Vmj0D000001:Vmj00000000:Vm
j0D000000jVmj0000000000=000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP01`00
0004001^0000T5V;T5V;1@000005ZKgX0000SUR=0000ZKgX00<00003ZKgX00D0002Y_NRY_NRY_NP0
00000i5MT@T000000jVmj00000000004000000FY_NP000000000002Y_NP01@000004ZKgX00000000
ZKgX10000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0P0004Koool002Soool010000?ooo`00000005?oool3000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0<000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj004000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000004ZKgX00000000
ZKgX100000:;Ehd00`0005dQJUdQJP03000000>AFX/0002Y_NP00P000008ZKgX000000000000R[?a
0000S5N<00000m6JW@8000000jVmj000099VW002TVJL00@0002CG8d000000003SUfC0`000004ZKgX
00000000ZKgX0`000004ZKgX00000000]G:60P000003mK9m00000000008000000oFbO@000?FbOP04
000000Ce/Wh0003e/Wke/Wh2000000Oe]H@000000000003i]gT0003e/Wd00`000003mK9m00000000
00@000001?FbOP000?FcOoFcO`H00002ERIh00D0002NGhH00000003OL0T00P00009@8GL010000:MX
QjMXQjMXQ`<00003GBak00@0002OHHNOHHNOHHL2000000?e/Wd0001X=Wl00VPfO`040000Wf:80000
XfB70P0000=R<Gh01@0009iQR9iQR0000:Y[R@0200000VTgP@060000WF69WF69WF690000YVN90P00
00:?GiD00`0008Q@QP000002Wf:90`000005ZKgX000000000000RE67008000001<N5R`0008==Q`00
00B?EXP2000000?TWhL0002;E8T00P000005SE630000WF:;0000T62E008000000oNbM`000:Vmj005
000000>Y_NP0000000000P0000CAS8L200000ZATQ`030000ZKgX000000H000000h18P`000=6<R003
dHb800<0002RHhNRHhL01P0000;eWdl00`00091FQi1FQ`02T5J70P0000>@EXL300000_FPD0090000
TeV8TeV8TeV80000Pdf60000dhn9000000::DXP00`000:9URP000002QUB?00<0002?F8/000000YiS
R`800004PU2<00@0002LII2LII000002[G:@0`000003ZKgX0000000000P000000jVmj00000000002
000000>Y_NP0000000000`000004ZKgX00000000ZKgX100000:9DhX00`000:Vmj0000003REF=00<0
0034D@0000000i5JS0<000000jVmj0000000000;000000?ZQal0002KHH`00Y]QS0<000001:Vmj000
06D_N@0000:>FXh010000:1WSP000:Vmj08000001JVmj000000000000:Vmj005000000BY_NP00000
002Y_NP:000000>Y_NP00000000010000005ZKgX000000000000ZKgX008000001jVmj00000000000
0>b[R0000:Vmj006000000F>FHh000000000002Y_NP010000003ZKgX0000000000<000000jVmj000
00000002TF2D10000003ZKgX00000000008000000jVmj00000000002000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX1@000003ZKgX00000000008000001000KP00091IRi1IR`8000001ZVmj000
00000:Vmj00008iHS@L000000jVmj00000000002ZKgX00@0002AGI6AGI6AGI45000000>Y_NP00000
00001P000003ZKgX0000000000H000001JVmj000000000000:Vmj008000000>Y_NP0000000000P00
0003ZKgX0000000000@000001JVmj000000000000:Vmj0050000AOooo`00:?ooo`80001Foooo0`00
0003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY_NP000000000002Y_NP01@00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000FY
_NP000000000002Y_NP00P000004ZKgX0000000000000X]GS@040000GB5Z0000SeN:0P000004TEZ;
00000000ZKgX1P0000:<Eh`010000=6JWM6JWM6JW@8000001JVmj000099VW99VW0000002Teb=00<0
002>GI>>GI<00XiMT`@000000jVmj00000000006000000BeLXH00000003e/Wd5000000?e/Wh00000
00000`000004mK9n0000mK9nmK9n0P000005mKF4000000000000nKMi008000001OFbO@0000000000
0?FbO@05000000Ce/Wh0003e/goe/gl6000000AF9WP0002NGhJNGhH2000000?OL0T0000000000U0Q
M`040000YfR7YfR7YfR70`0000=M;7/01@0009mQQimQQ`000<R4R@0300000fPfO`040000Wf:80000
XfB70P0000=R<Gh01@0009iQR9iQR0000:Y[R@0200000VTgP@060000WF69WF69WF690000YVN90P00
00:?GiD00`0008Q@QP000002Wf:91@0000>9DHL2000000C7QH/00023CHL00004SeJ80P000003i9n7
0000ReB9008000000heAP`0009eRR`04000000?g/WL0000000000P000005ZKgX000000000000ZKgX
00<00003dHb700<0001W<GT000000ZATQ`8000001JVmj000000000000:Vmj002000000>0B8<0003A
S8P00m6<R0030000XV>7XV>700@000001JE`UP000?FOCoFOC`000004T5J70P0000>@EXL300000_FP
D0090000TeV8TeV8TeV80000Pdf60000dhn9000000::DXP00`000:9URP000002QUB?00<0002?F8/0
00000YiSR`800004PU2<00L0002LII2LII00002]LY00002SIh`00`000003ZKgX0000000000<00000
0jVmj00000000002000000>Y_NP0000000000`000003ZKgX00000000008000001:Vmj00000000:Vm
j0<00002RE>:00<0002Y_NP000000hUES@030000a540000000>AFX`:000000BY_NP00000002Y_NP3
000000CZQal0002KHHbKHH`8000000B>FXh0002PIhjPIhh2000000>Y_NP0000000001P000005ZKgX
000000000000ZKgX00P000000jVmj00000000006000000>Y_NP00000000010000003ZKgX0000ZKgX
00H000000jVmj00000000003000000>>FHh0000000000P000003ZKgX0000000000P00004TF2D0P00
0004ZKgX00000000ZKgX10000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP00000
00000`000004ZKgX00000000ZKgX0`000004001^0000T5V;T5V;0`000007ZKgX0000ZKgX0000SUR=
0000ZKgX00@000001:Vmj0000000000000:Y_NP01000095MTI5MTI5MT@<000000jVmj00000000004
000000>Y_NP00000000020000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX00/00000
0jVmj00000000006000000>Y_NP000000000AOooo`009oooo`030000oooooooo05Ooool5000000>Y
_NP0000000000P000005ZKgX000000000000ZKgX00P000001JVmj000000000000:Vmj002000000>Y
_NP0000000000`000003ZKgX00000000008000001JVmj000000000000:Vmj006000000BY_NP00000
002Y_NP2000000F;Ehd00000001M8FX000000XmGRP030000TEZ;000000@000001:Vmj00000000000
00:<Eh`010000=6JWM6JWM6JW@8000001:Vmj000099VW00000:CG8d200000hiMT`8000000jVmj000
00000003000000>Y_NP0000000000`000003]G:60000000000<000001?FbO@0000000?FbOPD00000
1?FbOP000?FbO_FbOP8000001OFeQ000000000000?VgN@02000000Ge/Wd000000000003e/Wd01@00
0004mK9n0000mK=omK=o10000004ZKgX0000ERIh00000YiOQP8000000mm`2@0000000002D25g00D0
002WJ8NWJ8L00036PhT00P0000=M;7/01@0009mQQimQQ`000<R4R@0300000fPfO`040000Wf:80000
XfB70P0000=R<Gh01@0009iQR9iQR0000:Y[R@0200000VTgP@060000WF69WF69WF690000YVN90P00
00:?GiD0100008Q@QP0009mRR@@000000jVmj00008UAQ`02RE670P000004ahF;0000Pdf7000018mF
R08000000nBOQ`0008]DR@02000000>=DH<0000000001`000004ZKgX00000000ZKgX0`000003ZKgX
0000000000?AS8L00`0006LaN@000002Y6B72@000003P4R30000dHb800?AS8P00`000:9SQj9SQ`02
000000CCH@00002UL9H00002mIm?00<0002@EXN@EXL00Y1FQ`800003T5J710000003mJ1@0000TeV8
00:CFHP01@0008==QP000=>?R@000002RU:800P0002RIHX000000026E8l0002?F8/00002WV>;00<0
002Y_NP000000h9@S0090000W6F@W6F@0000[G:@0000XfN<0000ZKgX008000001:Vmj00000000:Vm
j08000000jVmj00000000008000000>Y_NP0000000000P000003ZKgX0000000000<00002RE>:0`00
00>9EHd00`000<AA00000003TEZ<0P000005ZKgX000000000000ZKgX00@000000jVmj00000000005
00000Y]QS0<000000jVmj00000000002000000B>FXh0002PIhjPIhh9000000BY_NP00000002TUlP5
000000FY_NP000000000002Y_NP01P000003ZKgX0000000000@000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX0000000000@000000jVmj0000000000:00000ZVmj0030000TF2DTF2D
00:AH9@4000000>Y_NP0000000001P000003ZKgX00000000008000000jVmj00000000008000000>Y
_NP0000000000`00008006h00`00091IR`000004000000>Y_NP0002>F8d00P000003ZKgX00000000
00@0000012HPT`000:Vmj00000>AGI46000000>Y_NP00000000020000003ZKgX0000000000800000
0jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000
00P000001:Vmj00000000:Vmj0800014oooo000Woooo00<0003oooooool0F?ooo`8000001:Vmj000
00000:Vmj0@000000jVmj00000000003000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000002000000>Y_NP0000000000`00
0003ZKgX00000000008000000jVmj00000000002000000F;Ehd00000001M8FX000000XmGRP<00000
0jVmj00000000002000000FY_NP00000002<Eh`000001=6JW@060000ZKgXZKgX0000TVJL00000Y=L
S@800003SUfC1@000005ZKgX000000000000ZKgX00@000000kEbQP0000000003000000Ce/Wd00000
003e/Wh5000000Ce/Wh0003e/Wke/Wh2000000Ge]H@000000000003i]gT00P000005mK9m00000000
0000mK9m00L00002mK=o1P000004ERIh0000WUn6WUn60P000003gg0900000000009@8GL01@000:MX
QjMXQ`000<J3R@0200000ed/N`050000Wf67Wf670000b8B900<00003J3Io00@0002OHXP0002SI8L2
00000f8aOP050000WV68WV680000ZV^900800002JCN100H0002MHHVMHHVMHHT0002VIhT200000XmO
U@@000001YmRR@00000000000:Vmj00000>9DHL2000000C7QH/00023CHL00004SeJ810000004ReB9
00000000SE632P000003ZKgX0000000000H00003dHb700<0001W<GT000000ZATQ`<00002Ug2T1000
0003P4R30000dHb800?AS8P00`000:9SQj9SQ`04000000FUL9H0003eWdoeWdl00000191FQ`800003
T5J710000003mJ1@0000TeV800:CFHP01@0008==QP000=>?R@000002RU:800P0002RIHX000000026
E8l0002?F8/00002WV>;00<0002Y_NP000000h9@S0050000W6F@W6F@0000[G:@00@000000jVmj000
00000003000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000<00000
1:Vmj0000000068]N0D00002REF=0P000003a5400000TEZ<00:AFX`7000000>Y_NP0000000002000
0003jXLO0000Vf6<00P0000018iJSP000:1WSZ1WSPD000000jVmj00000000002000000>TUlP00000
00000`000004ZKgX00000000ZKgX1@000003ZKgX0000000000@000000jVmj00000000007000000>Y
_NP0002>F8d01@000003ZKgX0000000000P00003T5fA0P0000>Y_NP00`00095PU95PU002TF2D1`00
0005ZKgX000000000000ZKgX008000000jVmj00000000008000000>Y_NP00000000010000003ZKgX
00000000008006h00`00091IR`000002000000FY_NP000000000002>F8d02`000006ZKgX0000TEfA
TEfA0000^7fD0`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000003
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj000
00000002000000>Y_NP000000000200004?oool002Ooool00`000?ooooooo`1Ioooo0P000004ZKgX
00000000ZKgX1P000005ZKgX000000000000ZKgX00<000000jVmj00000000004000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP6000000FY_NP000000000002Y_NP010000003ZKgX00000000
00@0000015dQJP0008mGRXmGRP@000000jVmj00000000004000000><Eh`0003AVYd00m6JW@D00003
Teb=0P0000:>GI<4000000>Y_NP00000000010000003ZKgX00000000008000000o:]O`0000000002
000000Ce/Wd00000003e/Wh600000_FbOP030000mKF4000000L000001OFbO@00000000000?FbO@03
000000Ce/Wh0000000000002mK=o1P000007ERIh0000WUn60000`Wj80000gg0900800002D25g00D0
002WJ8NWJ8L00036PhT00P0000=M;7/01@0009mQQimQQ`000<R4R@0300000fPfO`040000Wf:80000
XfB70P0000=R<Gh01@0009iQR9iQR0000:Y[R@0200000VTgP@060000WF69WF69WF690000YVN91@00
0004R5260000Wf:9Wf:90`000003ZKgX0000RE6700:9DHL300000X==Q`060000SeJ8SeJ8SeJ80000
XFF:0`000004ReB900000000SE633@000003ZKgX0000000000<00003dHb700<0001W<GT000000ZAT
Q`040000Ug2TUg2TUg2T0P000005ZKgX00000000P4R3000000CAS8P00`000:9SQj9SQ`04000000FU
L9H0003eWdoeWdl00000191FQ`800003T5J710000003mJ1@0000TeV800:CFHP01@0008==QP000=>?
R@000002RU:800P0002RIHX000000026E8l0002?F8/00002WV>;00<0002Y_NP000000h9@S0050000
W6F@W6F@0000[G:@00/000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP00000
00000P000003ZKgX0000HReh008000000jVmj00000000002REF=0P000003a5400000TEZ<00:AFX`3
000000>Y_NP00000000020000007ZKgX000000000000jXLO0000Vf6<00@000001:Vmj000000006D_
N@800002X6N>00<0002Y_NP000000`000003ZKgX0000000000<000000jVmj00000000002000000BY
_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000>Y_NP00000000010000003ZKgX00000000
008000000jVmj00008iHS@03000000BY_NP00000002Y_NP5000000>Y_NP0002@GI40191MT@<00002
ZKgX00<0002AH9BAH9@00Y5PU0D000001:Vmj00000000:Vmj0`000000jVmj00000000006000000>Y
_NP0000000000P00008006h00`00091IR`000003000000>Y_NP0002Y_NP01P000003ZKgX00000000
00<00002ZKgX00@0002AGI40002hOI@:000000>Y_NP0000000001P000003ZKgX0000000000800000
0jVmj00000000004000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX2P000004ZKgX
000000000000@oooo`009oooo`030000oooooooo05[oool2000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000003ZKgX0000000000<000000jVmj00000000002000000BY_NP00000002Y_NP2
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y_NP00000000020000004GB5Z
0000SeN:SeN:0P000004ZKgX00000000ZKgX1@000003S5N<0000dIZM00;AVYd200000P0EU@030000
Teb=Teb=00:CG8d2000000B>GI<00000002Y_NP5000000>Y_NP0000000001P000003lZeo00000000
00<000000oFbO@000?FbOP0600000_FbOP030000mKF40000008000000oFbO@0000000002000000Ge
/Wd000000000003e/Wd00`000004mK9n0000000000000_FcO`H000001eHVN00009iOQP000<9nR000
0=m`2@0200000U0QM`050000YfR7YfR70000aX>900800003GBak00D0002OHHNOHHL00038Q8T00`00
00=X=Wl0100009mRR0000:=TQ`800003HS5n00D0002NHHRNHHP0002ZJhT00P00009Y=h40100009eQ
RIeQRIeQR@@00002SenE00L00028D8H0002OHXT0003:Qh/000000ZVmj0050000RE67RE670000YfV:
00800002Pdf700H0002?EXR?EXR?EXP0002QIHX3000000B;E8T00000002=DH<9000000>Y_NP00000
00000P000003ZKgX0000000000800003dHb700<0001W<GT000000ZATQ`050000Ug2TUg2T0000ZKgX
00@000000h18P`000=6<R003dHb800<0002RHhNRHhL010000005YG2F0000mIm?mIm?000000>@EXL0
0`0003hDL`000003T5J70P000004ZKgX0000mJ1@00000i=IR0050000Pdf60000dhn9000000::DXP0
20000:9URP00000008IDS`0008mHR`0000:NHh/00`000:Vmj0000003PU2<00D0002LII2LII00002]
LY001`000003ZKgX0000000000@000001JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2
000000>Y_NP0000000000P000003ZKgX0000000000@00002REF=0P000003a5400000TEZ<00:AFX`0
1@000:Vmj00000000:Vmj005000000>Y_NP0000000000P000007ZKgX00000000jXLO0000Vf6<0000
00:JMj/3000000C^SRX0000000000002X6N>0P000003ZKgX0000000000<000000jVmj00000000002
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj000
00000008000000>>F8d0000000000P000003ZKgX0000000000@00002ZKgX00<0002@GI6@GI400Y1M
T@0400000007000000000jVmj0040000TF2DTF2DTF2D1P000003ZKgX0000000000H000000jVmj000
00000008000000>Y_NP0000000001`000005001^0000T5V;0000ZKgX00@000000jVmj00000000002
000000>Y_NP000000000100000079R2C0000ZKgX0000TEfA0000^7fD00@000001:Vmj00000000:Vm
j0D000001JVmj000000000000:Vmj00;000000>Y_NP0000000001P000005ZKgX000000000000ZKgX
00P000000jVmj000000000060000@_ooo`009oooo`030000oooooooo05_oool2000000BY_NP00000
002Y_NP5000000>Y_NP00000000010000005ZKgX000000000000ZKgX00@000000jVmj00000000003
000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000>Y_NP0000000001`0000:?EhX3
000000BY_NP00000002Y_NP500001=6JW@80000201FE00P0002CG8fCG8fCG8d0000c05h0002>GI<3
000000BY_NP00000002Y_NP2000000VY_NP000000000002Y_NP0002eLXH0003b[Gl01@000003mK9m
0000mK9n00<000000oFbO@0000000002mK9n0P000004mKF400000000mK9m0P000004mK9m00000000
mK9m0`000005mK9o000000000000mK9n00800002mK=o10000009ZKgX0000ERIh0000WUn60000`Wj8
0000gg0900800002D25g00D0002WJ8NWJ8L00036PhT00P0000=M;7/01@0009mQQimQQ`000<R4R@03
00000VPfO`030000Wf:8000000:SI8L200000f8aOP030000WV68000000:ZJhT200000VTgP@030000
WF690000008000003:IWR@000000000008mOU@0008Q@QP0009mRR@000<Z7R`0000:Y_NP01@0008UA
QhUAQ`000:MYRP0200000X==Q`060000SeJ8SeJ8SeJ80000XFF:0`000004ReB900000000SE631`00
0004ZKgX00000000ZKgX200000?AS8L00`0006LaN@000002Y6B70P000004Ug2T00000000ZKgX0`00
0003P4R30000dHb800?AS8P00`000:9SQj9SQ`04000000FUL9H0003eWdoeWdl000000i1FQ`030000
?QAc000000>@EXL4000000?eX500002CFHP00Y=IR0800002dhn900D0002:DXR:DXP0002RIHX01000
0007SeR;0000WV>;WV>;0000ZKgX000000B2D8`200000ZebT0<000000jVmj00000000002000000FY
_NP000000000002Y_NP01P000003ZKgX0000000000<000001:Vmj00000000:Vmj0/000001HUES@00
00000<AA00000003TEZ<0P000003ZKgX0000000000<000001:Vmj00000000:Vmj0@000002In5^000
0>Z77`0009]QS00009YgZ`00095LS`02000000C^SRX0000000000002X6N>0`000004ZKgX00000000
ZKgX0P000003ZKgX0000000000800003VG>W0`000003ZKgX00000000008000000jVmj00000000003
000000BY_NP00000002Y_NP5000000FY_NP000000000002>F8d01P000003ZKgX0000000000800002
ZKgX00<0002@GI6@GI400Y1MT@<000001LIG00000:Vmj:Vmj0000002TF2D00<0002FGhh000004@00
0004ZKgX00000000ZKgX2P000006ZKgX00000000001^0000T5V;1P000003ZKgX0000000000D00000
0jVmj00000000003000000FY_NP0002AGI40002hOI@01@000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000000jVmj00000000002000000>Y_NP00000000020000004ZKgX00000000ZKgX1@00
0003ZKgX0000000000P000000jVmj000000000020000@Oooo`009oooo`030000oooooooo05coool2
000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP3000000>Y
_NP00000000010000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj005000000BY
_NP00000002Y_NP3000000>Y_NP0000000000P000003SeN:0000000000<000001:Vmj00000000:Vm
j0@00003dIZM0`0000805ID01P0009=LSI=LSI=LS@0003<0GP<000000jVmj00000000003000000BY
_NP00000002Y_NP4000000>eLXH0003b[Gl01@000003mK9m0000mK9n00<000000oFbO@0000000002
mK9n0P000004mKF400000000mK9m0P000005mK9m000000000000mK9m008000001OFbO`0000000000
0?FbOP0200000_FcO`H000001eHVN00009iOQP000<9nR0000=m`2@0200000U0QM`030000YfR7YfR7
008000000j9TR00005d/N`02GBak00D0002OHHNOHHL00038Q8T00`00009X=Wl00`0009mRR0000002
XfB70P0000=R<Gh00`0009iQR0000002ZV^90P000006JCN1000000000000WF6900000ZIWR@<00000
1HmOU@0008Q@QP0009mRR@0300000ZVmj0050000RE67RE670000YfV:00800002Pdf700H0002?EXR?
EXR?EXP0002QIHX3000000B;E8T00000002=DH<2000000?e/Wd0002Y_NP00`000004ZKgX00000000
ZKgX1`0000?AS8L00`0006LaN@000002Y6B72@000003P4R30000dHb800?AS8P00`000:9SQj9SQ`06
00000_FOC`070000T5J7T5J7T5J70000?QAc000000:@EXL00`000?RcMP000002000000?eX500002C
FHP00Y=IR0800002dhn900D0002:DXR:DXP0002RIHX00`000003QUB?0000000000:NHh/00`000:Vm
j0000004PU2<0P0000:]LY04000000>Y_NP00000000020000003ZKgX0000000000@000001JVmj000
000000000:Vmj005000000>Y_NP000000000200000;4D@000`00095JS95JS005000000FY_NP00000
0000002Y_NP00P000003UV^O0000WhFh00:OQKP010000>Z77`0009]QS0800002TEb?0P000003kXhZ
0000000000>PIhh00`000:Vmj0000004000000FY_NP00000002Y_NP0000019UcY`030000SeZ>0000
008000000jVmj00000000008000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P000004SUR=
00000000ZKgX10000004ZKgX0000000000000ZVmj0030000T5fAT5fA00:@GI4500000ZVmj0050000
TF2DTF2D0000UUn>00P000000jVmj00000000004000000FY_NP000000000002Y_NP00P000003ZKgX
0000000000<000000jVmj00000000002000000NY_NP0000006h0002@FH/0002Y_NP010000003ZKgX
0000000000<000001:Vmj00000000:Vmj0@000001jVmj000095MT@000;QmU0000:Vmj005000000>Y
_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP00000000020000003ZKgX0000000000<000001:Vmj00000000:Vmj0P00011oooo000V
oooo00<0003oooooool0G_ooo`8000000jVmj00000000003000000BY_NP00000002Y_NP3000000BY
_NP00000002Y_NP5000000>Y_NP0000000000P000005ZKgX000000000000ZKgX00P000001JVmj000
000000000:Vmj002000000FY_NP000000000002Y_NP00`000004SeN:00000000ZKgX0`000004ZKgX
00000000ZKgX0`0000?AVYd300000P0EU@060000Teb=Teb=Teb=0000<`1N1P000005ZKgX00000000
0000ZKgX008000001JFOd000000000000;EbQP02000000?e/Wd0000000000P000003mK9m0000mK9n
00<000000oFbO@0000000002mK9n0P000007mKF4000000000000nKMi0000mK9m00<000001?FbO@00
00000?FbO`<000000oFbOP0000000002mK=o0P00000;i9n60000SEZ?0000ERIh0000WUn60000`Wj8
0000gg0900800002D25g00<0002WJ8NWJ8L00P000003XVB80000GBak009M;7/01@0009mQQimQQ`00
0<R4R@0300000VPfO`030000Wf:8000000:SI8L200000f8aOP030000WV68000000:ZJhT3000000IY
=h40002MHHVMHHT0002VIhT4000000F?GiD00028D8H0002OHXT00`0000:Y_NP01@0008UAQhUAQ`00
0:MYRP0200000X==Q`060000SeJ8SeJ8SeJ80000XFF:0`000004ReB900000000SE630P000003mK9m
0000000000@000000jVmj00000000003000000BY_NP0000000000003dHb700@0001W<GT0002TI8L3
000000FY_NP000000000002Y_NP00P000003P4R30000dHb800;AS8P200000Z9SQ`030000ZKgX0000
00<00002mIm?00L0002@EXN@EXN@EXL0000n57<000000Y1FQ`D000000oFPD00009=IR002TeV80P00
00;CShT01@0008YBR8YBR0000:9URP03000000>6E8l0000000000YiSR`<00004PU2<0P0000:]LY02
000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000005ZKgX000000000000ZKgX00P00000
0jVmj00000000004000000>Y_NP000000000100000;4D@000`00095JS95JS003000000>Y_NP00000
0000100000BFJil4000000CZQal0002KHH`00003TEb?1@0000>PIhh4000000BY_NP0000000000003
ZKgX00D0002ILjNILjNILjL000000XmJSPX000000jVmj00000000004000000FY_NP000000000002Y
_NP010000005SUR=000000000000ZKgX00L00003ZKgX00@0002@GI6@GI6@GI44000000C6E`00002Y
_NP00002TF2D00<0002FGhh000000`000003ZKgX0000000001<000001:Vmj00000000:Vmj0D00000
0`00KP00091IR`02000000>Y_NP00000000020000003ZKgX0000000000<000001RHPT`000000095M
T@000;QmU0<000000jVmj00000000002000000>Y_NP00000000020000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0X000000jVmj00000000004000000FY_NP000000000002Y_NP01@000004ZKgX
00000000ZKgX0P00043oool002Koool010000?ooo`00000005koool4000000FY_NP000000000002Y
_NP00P000005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000000jVmj00000000002
000000>Y_NP0000000000`000005ZKgX000000000000ZKgX008000001JVmj000000000000:Vmj002
000000>Y_NP00000000010000005SeN:000000000000ZKgX00<000000jVmj0000000000200000m6J
W@030000ZKgX000000800000100EU@0009=LSI=LS@D00002SUfC0`0000:OR;`2000000>UWm000000
00000XeISP050000]G:600000000mK9m00D00002mK9n0`000003mK9m0000000000;e/Wh2000000Oe
]H@000000000003i]gT0003e/Wd00`000003mK9m0000000000@000000oFbOP000?FcO`02mK=o1000
0005SEZ?0000ERIh0000WUn600<000000mm`2@0000000002D25g00<0002WJ8NWJ8L00P000003XVB8
0000GBak009M;7/01@0009mQQimQQ`000<R4R@04000000AX=Wl0002OHXP00002XfB70P00009R<Gh0
0`0009iQR9iQR00500000VTgP@050000WF69WF690000YVN900@000001HmOU@0008Q@QP0009mRR@03
00000ZVmj0050000RE67RE670000YfV:00800002Pdf700H0002?EXR?EXR?EXP0002QIHX3000000B;
E8T00000002=DH<2000000?e/Wd0000000001`000005ZKgX000000000000ZKgX00800003dHb700@0
001W<GT0002TI8L4000000>Y_NP0000000000`000003P4R30000dHb800;AS8P200000Z9SQ`800000
1:Vmj0000000000000;eWdl01`00091FQi1FQi1FQ`0003hDL`000002T5J70`000004ZKgX0000mJ1@
00000i=IR0800002dhn900D0002:DXR:DXP0002RIHX00`000003QUB?0000000000:NHh/30000189@
S0800002[G:@0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0@00002UfjR10000005ZKgX
000000000000ZKgX008000000jVmj0000000000;000000C4D@00002AFXbAFX`600000ZVmj0030000
UV^OUV^O00>FJil0200008aHSXaHSP000>Z77`0009]QS00000>AG8l01@000:Vmj0000>j>:P000003
X6N>0P000003ZKgX0000000000@00003ZKgX00<0002ILjL000000hmJSPH000000jVmj00000000006
000000>Y_NP00000000020000003SUR=0000000000T00003ZKgX00@0002@GI6@GI6@GI44000000C6
E`00002Y_NP00002TF2D00D0002FGhh00000002Y_NP01P000003ZKgX0000000000P000001:Vmj000
00000:Vmj0T000001JVmj0000000KP00091IR`09000000>Y_NP00000000010000004ZKgX00000000
9R2C0P000005TEfA000000000000ZKgX008000000jVmj00000000008000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX00P000000jVmj00000000006000000>Y_NP0000000001P000005ZKgX
000000000000ZKgX00@00010oooo000Voooo0P0006;oool3000000FY_NP000000000002Y_NP01P00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P000005ZKgX000000000000ZKgX00<00000
0jVmj00000000004000000BY_NP00000002Y_NP2000000>Y_NP0000000001@000003ZKgX00000000
00<000001:Vmj0000=6JWM6JW@<000001JVmj0000000000EU@000002Teb=0`0000>>GI<200000in8
_0040000SER<0000000018eISP050000]G:600000000mK9m00D000000oFbOP0000000003000000Ce
/Wh0003e/Wke/Wh6000000?i]gT0003e/Wd00`000003mK9m0000000000@000000oFbOP000?FcO`02
mK=o10000005SEZ?0000ERIh0000WUn600<000000mm`2@0000000002D25g00<0002WJ8NWJ8L00P00
0005XVB80000GBakGBak000000>OHHL2000000Se/Wd000000000001X=Wl0002OHXP00002XfB70P00
009R<Gh400000ZY[R@800002JCN100D0002MHHVMHHT0002VIhT010000003SenE0000000000:OHXT3
00000ZVmj0050000RE67RE670000YfV:00800002Pdf700H0002?EXR?EXR?EXP0002QIHX3000000B;
E8T00000002=DH<2000000Ge/Wd000000000002Y_NP00`000004ZKgX00000000ZKgX100000?AS8L2
000000=W<GT0002TI8L02P000003P4R30000dHb800;AS8P200000Z9SQ`D000001:E`UP000?FOC`00
00>@EXL00`0003hDL`000002T5J71@000003mJ1@0000TeV800:CFHP200000]>?R@050000RU:8RU:8
0000XVF:008000001JeXP@000000000009iSR`040000189@S08000000jebT0000:=WS005000000FY
_NP000000000002Y_NP00P000003ZKgX0000UfjR00:GKZ800`0009MSTP000007000000>Y_NP00000
00001P000005ZKgX000000000000ZKgX008000001<AA0000095JS95JS08000000jVmj00000000003
ZKgX00<0002FJinFJil00YI[W`800003S5R>0P000004Vf6<0000TEb?TEb?10000003kXhZ0000X6N>
00:PIhh500000Y1MT@@000000jVmj00000000004SeZ>10000003ZKgX0000000000@000000jVmj000
00000008000000FY_NP000000000002>F8d010000005ZKgX000000000000ZKgX00800003ZKgX00<0
002@GI6@GI401@0000;6E`02000000BAH9@0002FGhjFGhh5000000>Y_NP00000000020000003ZKgX
00000000008000000jVmj00000000003000000BY_NP00000002Y_NP4000000<006h0002@FH/03P00
0003ZKgX0000000000<000000bHPT`00095MT@0=00000YAUV0L000000jVmj00000000006000000>Y
_NP00000000020000003ZKgX0000000000P000001:Vmj00000000:Vmj0D000000jVmj0000000000o
oooo000Voooo00<0003oooooool0H_ooo`<000000jVmj00000000003000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX0`000003ZKgX0000000000@000000jVmj000
00000003000000>Y_NP0000000000P000004ZKgX00000000ZKgX1@000003ZKgX0000000000@00000
0hmNU@000000000200000]6JW@030000ZKgX000000<00000100EU@0009=LSI=LS@800004SUfC00<0
00182e`000000P0000:=F8`00`0008eISXeISP02SEV>0P000004]G:600000000mK9m0P000004mK9m
00000000mK9n1@000005mK9n0000mK9n0000mKF400D000001?VgN@0000000?FbO@<000000oFbO@00
00000003000000?e/Wh0003e/gl00_FcO`@000001HeJS`0005HVN00009iOQP03000000?OL0T00000
00000U0QM`030000YfR7YfR7008000001J9TR00005d/Ned/N`000003Wf670P000008mK9m0000ZKgX
0000J3Io0000Wf:800000Z=TQ`D00002WV6800<0002ZJhVZJhT00P00009Y=h401@0009eQRIeQR@00
0:IWR@04000000>?GiD0000000000YmRR@<00002ZKgX00D00029DHN9DHL0002WJHX00P0000:3CHL0
1P0008mFR8mFR8mFR0000:5URP<0000018]DR@00000008eAP`8000000oFbO@0000000002000000FY
_NP000000000002Y_NP01P0000?AS8L2000000EW<GT0002TI8L0002Y_NP01@000005ZKgX00000000
P4R3000000?AS8P200000Z9SQ`D000001:E`UP000?FOC`0000>@EXL00`0003hDL`000002T5J70P00
0005ZKgX00000000mJ1@000000>CFHP200000]>?R@050000RU:8RU:80000XVF:008000000jeXP@00
00000002WV>;00@0002Y_NP000000004PU2<0P000003[G:@0000XfN<00<000001:Vmj00000000:Vm
j0<00003ZKgX00@0002GKZ:GKZ800002Uf>B10000003ZKgX0000000000P000001:Vmj00000000:Vm
j0D000001LAA0000095JS0000:Vmj002000000>Y_NP0000000000jVmj0030000UV^OUV^O00<00003
S5R>0P000004Vf6<0000TEb?TEb?10000003kXhZ0000X6N>00:PIhh00`000:Vmj0000004T5fA0P00
00:Y_NP200001HmJSPL000000jVmj00000000008000000>Y_NP0000000000P000007ZKgX00000000
0000k:^80000ZKgX008000000jVmj0000000000400000ZVmj0030000T5fAT5fA00D00002aUL00P00
0004TF2D0000UUn>UUn>0`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj000
00000003000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj0000000091IR`D00000
0jVmj00000000002000000>Y_NP0000000001`0000049R2C00000000^7fD0`000004ZKgX00000000
ZKgX0`0000BDIIP3000000>Y_NP00000000020000003ZKgX0000000000<000001:Vmj00000000:Vm
j0X000000jVch00000000008000000>Y_NP0000000000`0003koool002Koool00`000?ooooooo`1S
oooo1@000005ZKgX000000000000ZKgX00@000000jVmj00000000003000000BY_NP00000002Y_NP5
000000>Y_NP00000000010000005ZKgX000000000000ZKgX00@000000jVmj00000000006000000BY
_NP0000000000002SejE00<0002GGhd0000020000008ZKgX000001FE0000Teb=0000ZKgX00000hiM
T`@00003SER<0P0000B=FHh2000000>eLXH0000000000`000004mK9m00000000mK9n1@000005mK9n
0000mK9n0000mKF400D000001?VgN@0000000?FbO@<000000oFbO@0000000003000000Ce/Wh0003e
/goe/gl5000000F=FXl0001F9WP0002NGhH010000005OTJ20000D25gD25g000000:WJ8L2000000FR
I8P0001M;7]M;7/000000imQQ`8000002OFbO@000000000006PfO`0009mRR0000:=TQ`0300000V8a
OP040000WV68WV6800000ZY[R@050000JCN1JCN1JCN1000000:MHHT01`000:IWR@00000006@cO`00
08mOU@0200000YmRR@<00002ZKgX00D00029DHN9DHL0002WJHX00P0000:3CHL01P0008mFR8mFR8mF
R0000:5URP<0000018]DR@00000008eAP`8000000oFbO@0000000009000000BY_NP0000000000003
dHb70P000003Ic5i0000Y6B700D000000jVmj0000000000300001=6<R0800002XV>71@000004YG2F
0000mIm?00000i1FQ`030000?QAc000000:@EXL3000000BY_NP0003eX5000003TeV80P0000;CShT0
1@0008YBR8YBR0000:9URP02000000>]J840000000000YiSR`@00004PU2<00D0002]LY2]LY00002S
Ih`010000003ZKgX0000000000800004ZKgX00<0002GKZ8000000YMSTP030000X6N?000000D00000
1JVmj000000000000:Vmj004000000>Y_NP0000000000`000005ZKgX0000a5400000TEZ<00800000
1JVmj00000000000001;b@02000000FY_NP0002FJil0002IIYD00P0000><F8h2000000JKHH`0002A
G8nAG8l0002Y_NP2000000?^SRX0002PIhh00Z1WSP030000ZKgX000000B@GI4200000jVmj0030000
SeZ>SeZ>00>?FXh2000000BY_NP00000002Y_NP2000000>Y_NP0000000000`000003ZKgX00000000
008000000jVmj00000000005000000C/ZhP00000002Y_NP5000000>Y_NP0000000000ZVmj0030000
T5fAT5fA00D00003aUL00`0000:FGhh4000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@00
0003ZKgX00000000008000000jVmj00000000009000000<006h0000000000P000004ZKgX00000000
ZKgX1@000003ZKgX00000000008000001:Vmj000000002HPT`8000000kQmU00000000002000000FY
_NP00000002Y_NP0000019AUV0H000000jVmj00000000002000000>Y_NP00000000020000003ZKgX
0000000000<000001:Vmj00000000:Vmj0X000000jVmj00000000004000000>Y_NP000000000?_oo
o`009_ooo`030000oooooooo06Coool2000000BY_NP00000002Y_NP3000000>Y_NP0000000001000
0005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP01P000004ZKgX00000000SeN:0`000003ZKgX0000SejE00:?GYD0
0`0009MOS@000002SUfC0P000003f[6^0000000000<000001P0EU@0009=LS@000:Vmj00000>>GI<0
100007n^lWn^lP0000>=F8`2000018eISP<000000o:]O`0000000002000000Ce/Wd00000003e/Wh6
00000_FbOP8000000oFeQ00000000002000000Ci]gT00000003e/Wd3000000?e/Wd0000000001@00
00;e/gl5000000F=FXl0001F9WP0002NGhH01000000;OTJ20000D25gD25g0000YfR70000aX>90000
XVB80000009M;7/01@0009mQQimQQ`000<R4R@05000000=X=Wl0000000001P000006HS5n0000WV68
WV680000ZV^90P0000=Y=h401@0009eQRIeQR@000:IWR@02000000=T<gl0002?GiD00P0000:OHXT3
00000ZVmj0050000RE67RE670000YfV:00800002Pdf700@0002?EXR?EXR?EXP2000000CTWhL00000
002;E8T2000000J=DH<00000003e/Wd0002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000
00?AS8L2000000=W<GT0002TI8L00P000005ZKgX000000000000ZKgX00@00004dHb80P0000:RHhL7
000000?eWdl0002@EXL00Y1FQ`030000?QAc000000:@EXL5000000?eX500002CFHP00Y=IR0800002
dhn900<0002:DXP000000Z9URP8000000jeXP@0000000002WV>;0P000003ZKgX0000PU2<00>2D8`0
1@000:ebT:ebT0000:=WS007000000BY_NP0000000000002ZKgX00<0002GKZ8000000YMSTP030000
X6N?000000<000000jVmj00000000004000000>Y_NP0000000002@000003a5400000TEZ<00D00000
1:Vmj000001;b@1;b@<00002VFJE0P0000><F8h2000000BKHH`0002AG8nAG8l2000000BY_NP0003^
SRX00002X6N>00@0002Y_NRY_NP00003T5fA00<0002WKi8000000jVmj0030000SeZ>SeZ>00:?FXh0
0`0009eTS@000004000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP5000000>Y_NP00000
00000`000003k:^80000000000L000001JVmj0000:Vmj:Vmj0000002T5fA0P000004ZKgX00000000
00000/IG00<00002UUn>2`000003ZKgX0000000000H000000jVmj00000000008000000>Y_NP00000
00000P000003001^0000000000<000000jVmj00000000003000000BY_NP00000002Y_NP7000000@V
89<0002hOI@00002TUnC0P0000>Y_NP00`0009AUV9AUV002U6FH10000004ZKgX00000000ZKgX2P00
0003ZKgX0000000000@000001JVmj000000000000:Vmj008000000>Y_NP0000000001P000003ZKgX
0000000000<0000moooo000Uoooo00<0003oooooool0I_ooo`8000001:Vmj00000000:Vmj0D00000
0jVmj00000000002000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX0`000004ZKgX
00000000ZKgX1@000003ZKgX0000000000H00003ZKgX00@0002?GYF?GYD00002Uen=00<0002>GI>>
GI<01000000:ZKgX00000000000001FE0000Teb=0000ZKgX00000XiMT`050000OjkbOjkbOjkb0000
00>=F8`200000heISP@000000o:]O`0000000003000000?e/Wd0003e/Wh01P0000;e/Wh2000000?e
]H@0000000001@000005mK9m000000000000mK9m00<000001?FbOP000000000000;e/gl5000000>=
FXl0001F9WP00P000006`Wj8000000000000OTJ200000U0QM`070000YfR70000aX>90000XVB80000
009M;7/01@0009mQQimQQ`000<R4R@07000000>OHXP0002SI8L010000006HS5n0000WV68WV680000
ZV^90P0000=Y=h401@0009eQRIeQR@000:IWR@02000000=T<gl0002?GiD00P0000:OHXT300000ZVm
j0030000RE67RE67008000001LN5R`0008==Qh==Q`000003SeJ80P000004i9n700000000ReB91@00
0003mK9m0000000000<000001:Vmj00000000:Vmj0H00003dHb70P000003Ic5i0000Y6B700L00000
1:Vmj0000000000000CAS8P200000Z9SQ`030000ZKgX000000@000000oFOC`00091FQ`02T5J700<0
000n57<000000Y1FQ`D000000oFPD00009=IR002TeV80P0000;CShT00`0008YBR0000002XVF:0P00
00:]J8400`0009iSRiiSR`0900000ZebT0030000XfN<0000008000000jVmj0000:Vmj002ZKgX00<0
002:EXf:EXd0100000>GHi800`000:1WS`000006000000>Y_NP00000000020000003ZKgX00000000
008000000lAA0000095JS003000000BY_NP000000000000304_900@0002IIYFIIYFIIYD200000haH
SP80000019]QS000095LSi5LS`@000001Nj>:P000:1WSZ1WSP000002ZKgX00H0002@GI6@GI6@GI40
002WKi8200000jVmj0080000SeZ>SeZ>SeZ>0000WFB=0000ZKgX10000003ZKgX0000000000<00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000000nb[R00000000003000000>Y_NP00000
000010000004ZKgX0000T5fAT5fA1P0000?6E`00100009IOSYIOSYIOSPL000000jVmj00000000004
000000FY_NP000000000002Y_NP020000003ZKgX0000000000H000000`00KP000000000:000000>Y
_NP0000000001`0000049R2C0000^7fD00000Y9OT`030000ZKgXZKgX00:Y_NP01P0009AUV9AUV9AU
V00009=MSP@000000jVmj00000000006000000>Y_NP0000000001P000003ZKgX0000000000H00000
1JVmj000000000000:Vmj006000000>Y_NP000000000200003coool002Goool00`000?ooooooo`1W
oooo0P000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX2P000005ZKgX000000000000ZKgX
00H000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj0000000000000>Y_NP0
1@0008mNUHmNU@0009MOS@0200000XiMT`030000f[6^0000008000001:Vmj0000000000000:CG8d0
0`000:Vmj0000002SUfC00D0001o[_9o[_9o[_8000000heHS0800003SEV>10000003lZeo00000000
00<000000oFbO@000?FbOP0600000_FbOP8000001?FeQ00000000?FbO@@000001OFbO@0000000000
0?FbO@03000000Ce/Wh0000000000002mK=o1@000003SEZ?0000ERIh008000002<9nR00000000000
07i6PP00050QM`0000:WJ8L01@000<J3R@000:9TR0000002GBak00D0002OHHNOHHL00038Q8T01@00
0005J3Io0000Wf:80000XfB700@000001V8aOP0009iQR9iQR0000:Y[R@800003JCN100D0002MHHVM
HHT0002VIhT00P000003I3=o0000SenE00800002Wf:90`0000:Y_NP00`0008UAQhUAQ`02000000G7
QH/00023CHN3CHL000000XmFR0040000XFF:0000i9n70P000003ReB90000000000<000001?FbO@00
00000:Vmj0<000001:Vmj00000000:Vmj0D00003dHb70P000003Ic5i0000Y6B700<000000jVmj000
0000000500001=6<R0800002XV>710000005ZKgX00000000mIm?000000>@EXL00`0003hDL`000002
T5J70P000005ZKgX00000000mJ1@000000>CFHP200000]>?R@030000RU:8000000:RIHX200000ZeX
P@050000WV>;WV>;0000ZKgX00L00002[G:@00@0002SIh`0002Y_NP300000jVmj0030000RUJ=RUJ=
00::EXd00`0009MSTYMSTP02Uf>B00<0002PIhl0000010000004ZKgX00000000ZKgX1@000003ZKgX
00000000008000001jVmj000000000000<AA0000095JS004000000BY_NP000000000000204_900H0
002IIYFIIYD0001V<G/00003S5R>0P000004Vf6<0000TEb?TEb?1P0000:PIhh010000:Vmj:Vmj000
00>@GI4010000:M_TP00000000>Y_NP01P0008mJSXmJSXmJSP0009eTS@8000000jVmj00000000003
000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj000
00000002000000RY_NP000000000002Y_NP0002Y_NP00002T5fA0`000003ZKgX0000000000?6E`00
100009IOSYIOSYIOSP<000000jVmj0000000000200000Y1LT08000000jVmj00000000006000000FY
_NP000000000002Y_NP01P000005ZKgX000000000000001^00H000000jVmj00000000006000000BY
_NP0000000000002ZKgX00D0000V89<0002hOI@000000Y9OT`800003ZKgX00P0002DIIRDIIRDIIP0
002CGHh0002Y_NP5000000FY_NP000000000002Y_NP01P000003ZKgX0000000000P000001:Vmj000
00000:Vmj0D000000jVmj00000000008000000BY_NP000000000000loooo000Uoooo00<0003ooooo
ool0J?ooo`8000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0D000000jVmj00000000002
000000>Y_NP0000000000`000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0D000001jVmj0000:Vmj:Vmj00008mNU@000002Uen=0P0000:>GI<3000000>Y_NP00000
00000`000006Teb=00000000ZKgX0000SUfC0P0000=o[_801P0008eHS8eHS00004hGJP0000>=FHh4
000000?b[Gl0000000000`000003mK9m0000mK9n00<000000oFbO@0000000002mK9n0P000004mKF4
00000000mK9m1@000005mK9m000000000000mK9o008000001?FbOP000000000000;e/gl5000000>=
FXl0001F9WP00P000008`Wj8000000000000OTJ20000D25g00000ZMXQ`050000aX>90000XVB80000
009M;7/00`0009mQQimQQ`05000000NY_NP0001X=Wl0002OHXP0002SI8L010000006HS5n0000WV68
WV680000ZV^90P0000=Y=h401@0009eQRIeQR@000:IWR@02000000=T<gl0002?GiD00P0000:OHXT3
000000VY_NP00029DHN9DHL0002WJHX00037QH/000000X==Q`070000SeJ8SeJ80000XFF:0000i9n7
008000000h]DR@0000000004000000>Y_NP00000000010000003ZKgX0000000000<000000jVmj000
0=6<Q`02dHb70P000003Ic5i0000Y6B700@000000jVmj0000000000400001=6<R0800002XV>70P00
0007ZKgX00000000ZKgX0000mIm?000000>@EXL00`0003hDL`000002T5J70`000004ZKgX0000mJ1@
00000i=IR0800002dhn900<0002:DXP000000Z9URP800002[FR100<0002NHh^NHh/02@0000:]LY00
0`000:=WS000000400000jVmj0030000RUJ=RUJ=00::EXd01P0009MSTYMSTYMSTP000:1WS`L00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0L000000lAA0000095JS00800000P1;b@060000
VFJEVFJE0000IS5k00000haHSP8000001Y]QS000095LSi5LS`000:Vmj0@00002X6N>00@0002Y_NRY
_NP00003T5fA00@0002WKi8000000003ZKgX00H0002?FXj?FXj?FXh0002MI8d4000000>Y_NP00000
00000P000003ZKgX0000000000P000000jVmj00000000006000000>Y_NP0000000002@000004T5fA
00000000ZKgX0P000003ZKgX0000aUL000;6E`00100009IOSYIOSYIOSP@000000jVmj000091LT003
T5b@30000003ZKgX0000000000<000000jVmj00000000005000000@006h00000002Y_NP:000000BY
_NP00000002Y_NP200000jVmj08000000kQmU000099OT`0400000jVmj0030000U6FH000000:CGHh5
000000BY_NP00000002Y_NP5000000>Y_NP00000000020000003ZKgX0000000000P000000jVmj000
00000003000000BY_NP00000002Y_NP5000000>Y_NP000000000>oooo`009Oooo`030000oooooooo
06Woool2000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P00
0005ZKgX000000000000ZKgX00@000000jVmj00000000003000000BY_NP00000002Y_NP600000ZVm
j0030000SejE000000:GGhd2000000>>GI<0003J/Jh01@000004ZKgX00000000Teb=10000004SUfC
0000ZKgX00000Wn^lP060000SER<SER<0000CQMZ00000XeISPD000000o:]O`0000000003000000?e
/Wd0003e/Wh00`000003mK9m0000000000;e/Wh5000000Ce/Wd00000003e/Wd2000000Ge/Wd00000
0000003e/Wl00`000003mK9n0000000000;e/gl5000000>=FXl0001F9WP00P000008`Wj800000000
0000OTJ20000D25g00000ZMXQ`050000aX>90000XVB80000009M;7/4000000?8Q8T0000000000`00
0003J3Io0000000000:SI8L4000000AR<Gh0002NHHP00002ZV^90P0000=Y=h401@0009eQRIeQR@00
0:IWR@02000000=T<gl0002?GiD00P0000:OHXT500000XUAQ`050000YfV:0000ahF;000000:3CHL0
1`0008mFR8mFR0000:5URP000>BOQ`02000000>;E8T0000000001`0000>@GY<4000000>Y_NP00000
00000P0000?AS8L2000000=W<GT0002TI8L02`0000CAS8P200000Z9SQ`<000001ZVmj00000000000
0?FOC`0000>@EXL00`0003hDL`000002T5J71@000003mJ1@0000TeV800:CFHP200000]>?R@030000
RU:8000000:RIHX3000000B]J840002NHh^NHh/4000000>Y_NP0000000000P0000:]LY001@000:=W
S00000000:Vmj00300000ZVmj0030000RUJ=RUJ=00::EXd01P0009MSTYMSTYMSTP000:1WS`<00000
0jVmj00000000002000000>Y_NP0000000000`000004ZKgX00000000ZKgX1P000005a5400000TEZ<
0000ZKgX00H0000204_900@0002IIYFIIYD00002IS5k00<0002<F8j<F8h00P000004Vf6<0000TEb?
TEb?0P000004ZKgX0000000000000Z1WSP040000ZKgXZKgX00000i1MT@@00003ZKgX00H0002?FXj?
FXj?FXh0002MI8d2000000BY_NP00000002Y_NP:000000>Y_NP00000000010000005ZKgX00000000
0000ZKgX00P000000jVmj00000000002000000F@GI4000000000002Y_NP00`0000?6E`00100009IO
SYIOSYIOSP800003ZKgX00<0002@G92@G9000Y1LT0D000000jVmj00000000008000000BY_NP00000
002Y_NP300000iEWVP8000000i1IR`000000000:000000>Y_NP0000000000P0000>Y_NP2000000>h
OI@0002BGi<00`000007001k0000ZKgXZKgX0000U6FH000000:CGHh00`000:Vmj0000009000000>Y
_NP0000000000`000004ZKgX00000000ZKgX2P000003ZKgX0000000000@000001JVmj00000000000
0:Vmj005000000BY_NP00000002Y_NP20000>_ooo`009Oooo`030000oooooooo00<0001Woooo1000
0005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000001JVmj000000000000:Vmj002
000000FY_NP000000000002Y_NP01@000003ZKgX00000000008000001:Vmj00000000:Vmj0800000
1JVmj000000000000:Vmj00200000iMOS@8000000hiMT`0000000003000000>Y_NP0000000000P00
0003Teb=0000ZKgX00H00002Ojkb00H0002=F8b=F8`0001>5fX00002SEV>1P000003mK9m00000000
00<000000oFbOP0000000002000000Ke/Wd00000003e/Wh0003e]H@5000000?i]gT0003e/Wd00`00
0004mK9m00000000mK9o0`000003mK9n0000000000;e/gl7000000AF9WP000000032OXP3000000An
AX80001@8GL00002YfR700@00036PhT0002RI8P400000YmQQ`030000b8B9000000@000000fPfO`00
00000002XfB710000004HS5n0000WV6800000ZY[R@800003JCN100<0002MHHT000000ZIWR@800000
1F@cO`00000008Q@QP000002Wf:91@0000:9DHL01@000:MYRP000<N5R`000002Pdf700L0002?EXR?
EXP0002QIHX0003TWhL00P000003ReB90000000000D00005T5jC0P000003ZKgX0000000000@00003
dHb70P000005Ic5i0000Y6B70000ZKgX00D000001:Vmj0000000000000?AS8P00`0006PcN`000002
XV>71`000003mIm?0000T5J700:@EXL00`0003hDL`000002T5J70P000005ZKgX00000000mJ1@0000
00>CFHP200000]>?R@030000RU:8000000:RIHX01@000:Vmj0000:eXP@000002WV>;1@000004ZKgX
0000000000000ZebT0030000XfN<0000008000000jVmj00000000002ZKgX00<0002:EXf:EXd00XYF
S@060000Uf>BUf>BUf>B0000X6N?10000003ZKgX0000000000<000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX00000000008000001I5JS000000000000:Vmj005000000D0BlT0002I
IYFIIYD000000VHaN`0:0000S5R>S5R>S5R>0000Vf6<0000TEb?0000ZKgX0P000006ZKgX0000kXhZ
0000X6N>00000ZVmj0050000T5fAT5fA0000YfnB008000001JVmj0000:Vmj:Vmj0000003SeZ>00<0
002MI8d000000P000003ZKgX0000000000H000000jVmj00000000006000000>Y_NP0000000001P00
0005ZKgX000000000000ZKgX00D000000jVmj00000000004000000>Y_NP00036E`000/IG00040000
UUn>UUn>UUn>0P0000>Y_NP00`00091LT91LT002T5b@1P000003ZKgX0000000000<000000jVmj000
00000002000000FY_NP00000002Y_NP000000iEWVP<000001I1IR`00000000000:Vmj004000000>Y
_NP0000000000`000004ZKgX0000000000000ZVmj08000000kQmU000099OT`03000000@007/0002Y
_NRY_NP200000i=MSPP000000jVmj00000000004000000FY_NP000000000002Y_NP020000003ZKgX
0000000000H000000jVmj00000000006000000FY_NP000000000002Y_NP0100003[oool002Goool3
0000Joooo`@000001JVmj000000000000:Vmj005000000BY_NP00000002Y_NP3000000BY_NP00000
002Y_NP5000000FY_NP000000000002Y_NP010000003ZKgX0000000000<000000jVmj0000<iE0003
00000YMOS@070000:@1K00000000f[6^0000ZKgX00D000000jVmj00000000002000000>Y_NP00000
00000`00009o[_801`0008eHS8eHS00004hGJP0008eISP02000000>=FHl0000000000P000003mK9m
0000000000<000000oFbOP0000000003000000Ge/Wh0003e/Wh0003e]H@01@000003nKMi0000mK9m
00<000000oFbO@0000000004000000?e/Wh0003e/gl00_FcO`L0000015HVN00000000<9nR0<00000
17i6PP00050QM`0000:WJ8L500000Ud/N`050000Wf67Wf670000b8B900P00002XfB710000004HS5n
0000WV6800000ZY[R@<00002JCN100<0002MHHT000000ZIWR@8000001F@cO`00000008Q@QP000002
Wf:90P000003G2in0000000000:9DHL01@000:MYRP000<N5R`000002Pdf700L0002?EXR?EXP0002Q
IHX0003TWhL00P000003ReB90000000000D00004T5jC1P000004ZKgX0000000000000]6<Q`<00000
0fLaN@000:ATQ`05000000BY_NP00000002Y_NP200000m6<R0060000J3=k0000XV>70000ZKgX0`00
0005ZKgX00000000mIm?000000>@EXL00`0003hDL`000002T5J70`000004ZKgX0000mJ1@00000i=I
R0800002dhn900<0002:DXP000000Z9URP<000001ZeXP@0009iSRiiSR`000:Vmj0L000001:ebT000
0:=WS:=WS0@000000jVmj0000:Vmj002ZKgX00D0002:EXf:EXf:EXd000000iMSTP030000X6N?0000
00X000000jVmj00000000008000000NY_NP000000000002AFX`0002Y_NP00P000003ZKgX00000000
008000001@1;b@0009UVUIUVU@000002IS5k00P0002<F8j<F8j<F8h0002KHH`0002AG8l2000000RY
_NP000000000003^SRX0002PIhh00002ZKgX00D0002@GI6@GI40002WKi80100000:Y_NP01P0008mJ
SXmJSXmJSP0009eTS@H000001JVmj000000000000:Vmj006000000>Y_NP00000000020000004ZKgX
00000000ZKgX1@000003ZKgX0000000000P000001JVmj0000<IG0<IG00000003UUn>0P0000>Y_NP0
0`00091LT91LT002T5b@0P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP00000
00000P0000>Y_NP0100009EWVYEWVYEWVP<000000i1IR`000:Vmj002000000>Y_NP0000000000`00
0003ZKgX00000000008000000jVmj00000000002ZKgX00<0000V89<000000Y9OT`@000000`00N`00
0:Vmj00200000i=MSP@000000jVmj00000000006000000>Y_NP0000000001P000005ZKgX00000000
0000ZKgX00H000000jVmj00000000008000000BY_NP00000002Y_NP5000000>Y_NP000000000>Ooo
o`009?ooo`030000oooooooo06goool:000000FY_NP000000000002Y_NP00P000005ZKgX00000000
0000ZKgX008000001:Vmj00000000:Vmj08000001JVmj000000000000:Vmj006000000>Y_NP00000
00000P000003cUD00000000000>GGhd01@0002T0F`0000000=Za[P04000000>Y_NP0000000002`00
009o[_801`0008eHS000000004hGJP0008eISP02000000>=FHl0000000000P000003mK9m00000000
00<000000oFbOP0000000003000000?e/Wh0003e/Wh00P000003mKF400000000008000000oVgN@00
0?FbO@03000000?e/Wd00000000010000003mK9n0000mK=o00;e/gl3000000>3C8H0000000000P00
0003WUn60000`Wj800<000001Gi6PP00050QM`000:MXQ`0300000Z9TR0040000GBakGBak00000YmQ
Q`030000b8B9000000L00002XfB710000004HS5n0000WV6800000ZY[R@<00002JCN100<0002MHHT0
00000ZIWR@80000016@cO`000000000000:OHXT010000<Z7R`0005`^OP800002RE6700D0002WJHX0
0037QH/000000X==Q`070000SeJ8SeJ80000XFF:0000i9n7008000000h]DR@00000000050000191N
T`8000000jVmj00000000002000000>Y_NP0000000000]6<Q`060000ZKgX0000Ic5i0000Y6B70P00
0005ZKgX000000000000ZKgX00@00003dHb800@0001X<g/0002RHhL6000000BY_NP0003eWdl00003
T5J700D0000n57<n57<0002@EXL01@000003mJ1@0000TeV800:CFHP200000]>?R@030000RU:80000
00:RIHX3000000B]J840002NHh^NHh/2000000>Y_NP00000000010000004[G:@0000XfN<XfN<1P00
00>Y_NP01@0008YFSHYFSHYFS@000002Uf>B00<0002PIhnPIhl01`000003ZKgX0000000000800000
0jVmj00000000003000000>Y_NP0000000001@000004TEZ<00000000ZKgX1@000003ZKgX000004_9
00<00002IS5k00P0002<F8j<F8j<F8h0002KHH`0002AG8l300000Y1MT@040000kXhZ0000X6N>0P00
00:Y_NP01P00091MT@000:M_TP000:Vmj0800002ZKgX00H0002?FXj?FXj?FXh0002MI8d4000000BY
_NP00000002Y_NP5000000>Y_NP00000000020000003ZKgX00000000008000000jVmj00000000003
000000BY_NP00000002Y_NP5000000>Y_NP0000000000ZVmj0040000aUL0aUL000000iIOSP800004
ZKgX00@0002@G92@G92@G906000000BY_NP00000002Y_NP700001:Vmj0030000UFNJUFNJ00@00000
191IR`0000000:Vmj0D000000jVmj0000000000800000ZVmj0800002TUnC00@0002Y_NP000000002
001k0P0000BCGHh2000000>Y_NP00000000010000003ZKgX0000000000P000001:Vmj00000000:Vm
j0D000000jVmj00000000008000000>Y_NP00000000020000003ZKgX0000000000<0000hoooo000T
oooo00<0003oooooool0K_ooo`D000000jVmj00000000002000000FY_NP000000000002Y_NP01P00
0004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1@000003ZKgX00000000008000001:Vmj000
0000000000;>E@00200009MOSIMOSIMOS@0002T0F`000=Za[P<000001:Vmj00000000:Vmj0D00000
1JVmj000000000000:Vmj00200000Wn^lP070000SER<00000000CQMZ0000SEV>008000000heIS`00
00000005000000Ce/Wd00000003e/Wh5000000?e/Wh0003e/Wh00P000003mKF40000000000800000
1?VgN@0000000?FbO@<000000oFbO@0000000003000000?e/Wh0003e/gl00_FcO`<000000h=<QP00
00000002000000BNGhH000000026CXH2000000=nAX80000000000P000004YfR700000000XVB80P00
009M;7/01@0009mQQimQQ`000<R4R@02000000>Y_NP0000000000`0000:SI8L4000000AR<Gh0002N
HHP00002ZV^90`00009Y=h400`0009eQR@000002YVN90P000004I3=o0000000000000YmRR@040000
bXN;0000G2in0P0000:9DHL010000:MYRP00000000>3CHL01@0008mFR8mFR0000:5URP02000000>Y
_NP0002;E8T01`0000>@GY<01@000:Vmj00000000:Vmj00600000]6<Q`<000000fLaN@000:ATQ`07
000000BY_NP0000000000003dHb800@0001X<g/0002RHhL2000000>Y_NP0000000000`000003mIm?
0000T5J700:@EXL01@0003hDLchDL`00091FQ`05000000?eX500002CFHP00Y=IR0800002dhn900<0
002:DXP000000Z9URP<000001:eXP@0009iSRiiSR`<000001:Vmj00000000:Vmj08000001:ebT000
0:=WS:=WS0L00002ZKgX00D0002:EXf:EXf:EXd000000YMSTP030000X6N?X6N?00D000001:Vmj000
00000:Vmj0D000000jVmj00000000002000000FY_NP000000000002Y_NP00P000003TEZ<00000000
00<000000jVmj00000000002000000@0BlT0000000000002IS5k00@0002<F8j<F8j<F8h200000Y5L
S`800003T5fA00@0003^SRX0002PIhh200000ZVmj0040000T5fA0000YfnB100000:Y_NP01P0008mJ
SXmJSXmJSP0009eTS@D000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP00000
00000P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000001P000005ZKgX
0000ZKgXZKgX000000?6E`000`0009IOSYIOSP0200001:Vmj0040000T5b@T5b@T5b@0`000005ZKgX
000000000000ZKgX00P000000jVmj0000:Vmj003ZKgX00<0002EIiX000000`000003T5V;00000000
00<000000jVmj00000000003000000>Y_NP0000000001@0000:Y_NP2000000JBGi<000000000002Y
_NP00003001k00<0002CGHjCGHh00Y=MSPD000000jVmj00000000008000000>Y_NP0000000002000
0003ZKgX0000000000<000001:Vmj00000000:Vmj0X000000jVmj000000000070000>?ooo`009?oo
o`030000oooooooo06ooool2000000BY_NP00000002Y_NP4000000>Y_NP0000000000`000003ZKgX
00000000008000000jVmj00000000003000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP4
000000JY_NP000000000003>E@000003Uen=0`000003f[6^00000000008000001:Vmj00000000:Vm
j0D000002:Vmj000000000000:Vmj00007n^lP0000:=F8`00`000:Vmj0000002000000FY_NP0002=
FHl0002eLXH01@000004mK9m00000000mK9n1P0000;e/Wh2000000?e]H@0000000000P000004nKMi
00000000mK9m0`000003mK9m0000000000D00003mK=o0`000003Pdb60000XVF;0080000019iOQP00
000008I>QP@00000150QM`000:MXQjMXQ`8000000j9TR00000000002GBak00D0002OHHNOHHL00038
Q8T00`000003ZKgX0000000000800002XfB710000004HS5n0000WV6800000ZY[R@<00002JCN100<0
002MHHT000000ZIWR@80000016@cO`000000000000:OHXT010000<Z7R`0005`^OP800002RE6700@0
002WJHX000000003Pdf700D0002?EXR?EXP0002QIHX00P000003ZKgX0000ReB900L00003T5jC0P00
0004ZKgX00000000ZKgX0P000003ZKgX0000000000;AS8L3000000=W<GT0002TI8L00`000003ZKgX
0000000000D00003dHb800@0001X<g/0002RHhL5000000FY_NP00000003eWdl000000i1FQ`050000
?QAc?QAc0000T5J7008000001JVmj00000000?FPD0000003TeV80P0000;CShT00`0008YBR0000002
XVF:0`000006[FR10000WV>;WV>;0000ZKgX1`000004[G:@0000XfN<XfN<0`000004ZKgX00000000
00000ZVmj0050000RUJ=RUJ=RUJ=000000:GHi800`000:1WSj1WS`06000000BY_NP00000002AHID2
000000BY_NP00000002Y_NP:000000FAFX`000000000002Y_NP01P00000404_90000000000000VHa
N`040000S5R>S5R>S5R>0P0000:AG8l200000i1MT@<000000j1WSP0000000002ZKgX0P0000:WKi82
000000FY_NP00000002Y_NP000000hmJSP040000WFB=0000ZKgX1@0000>@G902000000>Y_NP00000
00000`000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX00000000008000000jVmj0000<IG0002aUL000<0002FGhjFGhh00P00
00BY_NP01000091LT91LT91LT0X000001JVmj000000000000:Vmj00400000jVmj0H000001I1IR`00
000000000:Vmj005000000BY_NP00000002Y_NP600000ZVmj08000000i9OT`000000000300000`00
N`030000Tef>Tef>00:CGHh3000000BY_NP00000002Y_NP5000000>Y_NP00000000020000003ZKgX
0000000000@000001JVmj000000000000:Vmj008000000>Y_NP00000000020000004ZKgX00000000
0000=oooo`004Oooo`D00002oooo00<0003oooooool02Oooo`030000oooooooo073oool2000000BY
_NP00000002Y_NP6000000FY_NP000000000002Y_NP01@000003ZKgX00000000008000001:Vmj000
00000:Vmj08000001:Vmj00000000:Vmj0D000001:Vmj0000<iE000000:GGhd5000000>Y_NP00000
00000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0H000000heHS00000000004000000>Y
_NP0002=FHl00P000003lZeo0000000000<000000oFbO@000?FbOP0600000_FbOPX000001OFbO@00
000000000?FbO@0700000oFcO`<000000h=<QP000:9UR`02000000>NGhH0000000000`000004OTJ2
0000D25g00000ZMXQ`8000000j9TR00000000002GBak00<0002OHHNOHHL00P000003mK9m00000000
00D00002XfB710000004HS5n0000WV6800000ZY[R@<00002JCN100@0002MHHT0002VIhT3000000AT
<gl0000000000002Wf:90`000003G2in0000000000:9DHL010000:MYRP00000000>3CHL01@0008mF
R8mFR0000:5URP04000000>;E8T00000000010000003ZKgX0000T5jC00@000001:Vmj00000000:Vm
j08000001:Vmj0000=6<Qm6<Q`<000000fLaN@000:ATQ`04000000FY_NP000000000002Y_NP00P00
00?AS8P0100006PcN`000:9SQ`<000001jVmj00000000:Vmj0000?FOC`000003T5J700D0000n57<n
57<0002@EXL00`000004ZKgX0000mJ1@00000i=IR0800003dhn90P0000:RIHX3000000B]J840002N
Hh^NHh/3000000>Y_NP0000000001@0000:SIh`01@000:Vmj00000000:Vmj00200000ZVmj0030000
RUJ=RUJ=00::EXd00`0009MSTP000002X6N?0P000003ZKgX0000000000800003TF6E0`000004ZKgX
00000000ZKgX1@000005ZKgX000000000000TEZ<00H000000jVmj0000000000500000VHaN`040000
S5R>S5R>S5R>0P0000:AG8l200000i1MT@<000001J1WSP00000000000:Vmj00200000ZM_TPD00000
0jVmj00008mJSP02SeZ>00<0002MI8d00000100000F@G909000000>Y_NP0000000000`000004ZKgX
00000000ZKgX1@000003ZKgX00000000008000000jVmj00000000006000000>Y_NP00036E`000/IG
00030000UUn>UUn>00800004ZKgX00D0002@G92@G900002eNY401`000003ZKgX0000000000H00000
1JVmj000000000000:Vmj00<000000>Y_NP0000000000P000003ZKgX0000000000<000001JVmj000
000000000:Vmj002000000>BGi<0002Y_NP00`0000<007/00`0009=MSY=MSP02Tef>2P000003ZKgX
0000000000H000000jVmj00000000006000000>Y_NP0000000001P000003ZKgX0000000001<0000f
oooo000Coooo00L0003oooooooooool0003oool000002_ooo`030000oooooooo077oool2000000BY
_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP010000003ZKgX
0000000000<000001:Vmj00000000:Vmj08000001ZVmj000000000000<iE000000:GGhd2000000FY
_NP000000000002Y_NP02P000004ZKgX00000000ZKgX0P000004ZKgX00000000SER<1P000003ZKgX
0000SEV?008000000o:]O`0000000003000000?e/Wd0003e/Wh01P0000;e/Wh:000000Ge/Wd00000
0000003e/Wd01`0000?e/gl01P000?FeQ00008=<QP000:9UR`D0000038I>QP00000007i6PP00050Q
M`000:MXQ`000<J3R@000:9TR0800002GBak00H0002OHHL00038Q8T0003e/Wd700000Z=TQ`080000
ZKgX00000000HS5n0000WV6800000ZY[R@<00002JCN100@0002MHHT0002VIhT200000V@cO`<00002
Wf:90`000003G2in0000000000:9DHL010000:MYRP00000000>3CHL01@0008mFR8mFR0000:5URP04
000000>;E8T00000000010000003ZKgX0000T5jC00D000000jVmj0000000000400000]6<Q`<00000
0fLaN@000:ATQ`05000000>Y_NP0000000000`0000?AS8P0100006PcN`000:9SQ`@000001ZVmj000
000000000?FOC`0000>@EXL01@0003hDLchDL`00091FQ`05000000?eX500002CFHP00Y=IR0800003
dhn90P0000:RIHX3000000B]J840002NHh^NHh/4000000>Y_NP000000000100000:SIh`2000000FY
_NP00000002Y_NP000000ZVmj0030000RUJ=RUJ=00::EXd200000j1WS`<00002ZKgX00H0002AHIFA
HIFAHID0002LII03000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P000004TEZ<00000000
ZKgX30000003IS5k0000S5R>00:<F8h200000Y5LS`800003T5fA0`000005X6N>000000000000ZKgX
00800002YfnB00<0002Y_NP000000P0000:Y_NP00`0008mJSP000002WFB=0P0000:Y_NP00`00091L
T91LT003T5b@1@000003ZKgX0000000000P000000jVmj00000000003000000BY_NP00000002Y_NP:
000000FY_NP0002Y_NRY_NP000000/IG00030000UUn>UUn>00<00003ZKgX00D0002@G92@G900002e
NY400`000003ZKgX0000000000/000000jVmj00000000003000000>Y_NP0000000000`000003ZKgX
00000000008000000jVmj00000000008000000BY_NP00000002Y_NP2000000BBGi<00000002Y_NP2
00000`00N`030000Tef>Tef>00:CGHh4000000>Y_NP0000000001P000005ZKgX000000000000ZKgX
00H000000jVmj00000000008000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000003ZKgX
00000000008000001:Vmj0000000000003Koool001?oool00`000?ooooooo`03oooo00<0003ooooo
ool02?ooo`030000oooooooo07;oool2000000>Y_NP00000000010000004ZKgX00000000ZKgX0P00
0004ZKgX00000000ZKgX0`000003ZKgX0000000000@000001JVmj000000000000:Vmj005000000FY
_NP00000003>E@0000000YMOS@<000001JVmj000000000000:Vmj005000000>Y_NP0000000000P00
0004ZKgX00000000ZKgX10000003SER<0000000000<00002ZKgX00D0002=FHl00000003b[Gl01@00
0003mK9m0000mK9n00H000000oFbOP000?FeQ004000000?e/Wd0000000000P000003mK9m00000000
008000001?FbO`0000000?FbOP<00003mK=o00@0003e]H@00023C8H5000000?2OXP00026CXH00P00
009nAX82000000FWJ8L00036PhT0002RI8P00P00009M;7/01P0009mQQ`000<R4R@000?FbO@L00002
XfB710000004HS5n0000WV6800000ZY[R@<00002JCN100@0002MHHT0002VIhT200000f@cO`800002
Wf:90`000003G2in0000000000:9DHL010000:MYRP00000000>3CHL01@0008mFR8mFR0000:5URP04
000000>;E8T00000000010000005ZKgX0000T5jC0000ZKgX00D000000jVmj0000000000200000]6<
Q`<000001FLaN@000:ATQ`000:Vmj005000000BY_NP0000000000003dHb800@0001X<g/0002RHhL8
000000?eWdl0002@EXL00Y1FQ`050000?QAc?QAc0000T5J7008000001JVmj00000000?FPD0000003
TeV80P0000?CShT2000000NRIHX00000002Y_NP0002]J84000000YiSR`030000TEnC000000P00002
XfN<0`000003ZKgX00000000008000000jVmj00008YFS@03RUJ=0P0000>PIhl200000jVmj0060000
TF6ETF6ETF6E0000W6F@2P000003ZKgX00000000008000001I5JS000000000000:Vmj003000000>Y
_NP0000000001@000003IS5k0000S5R>00:<F8h200000Y5LS`800003T5fA0`000004X6N>00000000
hg`?0`0000:WKi8500000ZVmj0030000SeZ>000000:MI8d01@000:Vmj:Vmj:Vmj0000005T5b@1P00
0003ZKgX0000000000<000000jVmj00000000004000000FY_NP000000000002Y_NP020000003ZKgX
0000000000<00002ZKgX00@00036E`36E`000002UUn>0`0000>Y_NP01@00091LT91LT0000;EjT@0:
000000>Y_NP0000000000P000003ZKgX0000000000`000000jVmj00000000008000000>Y_NP00000
000010000005ZKgX0000TUnC0000ZKgX00D00002001k00<0002CGHjCGHh00i=MSPH00002UFNJ0P00
0004ZKgX00000000ZKgX1@000003ZKgX0000000000P000000jVmj00000000003000000>Y_NP00000
00000P000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj0000000000eoooo000C
oooo00@0003oooooooooool200002oooo`030000oooooooo07?oool4000000>Y_NP0000000000P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP00000
00000`000008ZKgX000000000000ZKgX0000cUD000000YMOS@030000ZKgX000000L000001JVmj000
000000000:Vmj004000000>Y_NP00000000010000003SER<0000ZKgX00@000000jVmj00008eIS`02
000000?b[Gl0000000000`000003mK9m0000mK9n00<000001?FbO@0000000?FbOP8000001OFeQ000
000000000?FbO@04000000?e/Wd0000000000P000004mK9o00000000mK9n0`0000?e/gl00`000?Fe
Q0000006000000?2OXP00026CXH00P00009nAX82000000FWJ8L00036PhT0002RI8P00P00009M;7/0
100009mQQ`000<R4R@<000000jVmj00000000003000000>SI8L0000000000`000004HS5n0000WV68
00000ZY[R@<00002JCN100@0002MHHT0002VIhT200000f@cO`800002Wf:90`000003G2in00000000
00:9DHL010000:MYRP00000000>3CHL01@0008mFR8mFR0000:5URP04000000>;E8T0000000001000
0003ZKgX0000000000@000001JVmj000000000000:Vmj00300000]6<Q`<000000fLaN@000:ATQ`02
000000BY_NP00000002Y_NP2000000>Y_NP0000000000m6<R0060000J3=k0000XV>70000ZKgX0`00
0005ZKgX00000000mIm?000000>@EXL01@0003hDLchDL`00091FQ`03000000BY_NP0003eX5000003
TeV80P0000?CShT2000000>RIHX0000000000P000006[FR10000WV>;WV>;0000TEnC2@0000:SIh`5
000000FY_NP00000002Y_NP0000018YFS@800003X6N?0`0000:Y_NP01P00095QUI5QUI5QU@0009aU
T0H000000jVmj00000000004000000FY_NP0002AFX`0002Y_NP020000003ZKgX0000000000800000
0fHaN`0008aHSP03S5R>00D0002AG8l0002EJ9`000000i1MT@<000000j1WSP00095MT00400000ZM_
TPH000001:Vmj00008mJSP0000:MI8d01@000:Vmj:Vmj:Vmj0000005T5b@0P000003ZKgX00000000
00<000000jVmj00000000006000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00H00000
1:Vmj0000:Vmj00000;6E`000`0009IOSYIOSP0300000jVmj0050000T5b@T5b@0000]GZA00H00000
0jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000@000000jVmj0000000000:
000000>Y_NP0000000002P000003TUnC00000000008000000jVmj00000000003001k00<0002CGHjC
GHh00Y=MSP8000000jVmj00009EWVP03UFNJ0`000003ZKgX0000000000<000000jVmj00000000003
000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000P000000jVmj000
00000003000000>Y_NP0000000000`0003Coool001?oool01@000?ooooooooooo`00000;oooo00<0
003oooooool0M_ooo`<000000jVmj00000000008000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP5000000>Y_NP0000000000P000003ZKgX00000000008000000liE000009MOS@05000000FY
_NP000000000002Y_NP00P000005ZKgX000000000000ZKgX014000000jVmj00008eIS`03000000?e
/Wd0000000000`000003mK9n00000000008000001?FbO@0000000?FbOP8000001OFeQ00000000000
0?FbO@02000000Ce/Wd00000003e/Wd3000000Ge/Wl000000000003e/Wh00P0000;e/gl4000000>3
C8H0000000000`000003`Wj80000QTj600800002OTJ20P000005YfR70000aX>90000XVB800800002
GBak00@0002OHHL00038Q8T5000000?WUVl0000000000Z=TQ`D000001F8aOP0009iQR0000:Y[R@04
00000VTgP@040000WF690000YVN90P0000=T<gl200000YmRR@<000001E`^OP00000008UAQ`000002
YfV:0P0000>3CHL00`0008mFR0000002XFF:2@000003mK9m0000000000@000000jVmj00000000004
000000>Y_NP0000000000]6<Q`060000ZKgX0000Ic5i0000Y6B71P000003ZKgX0000000000800002
dHb80P000003J3=k0000XV>700P000000oFOC`00091FQ`02T5J700D0000n57<n57<0002@EXL01@00
0003mJ1@0000TeV800:CFHP200000m>?R@8000000j9URP0000000002000000B]J840002NHh^NHh/2
000000BPJI400000002Y_NP500000Z=WS0H000001:Vmj0000:Vmj00000B:EXd200000Z1WS`040000
VF2<000000000ZVmj0040000TF6ETF6E00000YaUT0/000001JVmj00000000000095JS004000000FY
_NP000000000002Y_NP01P000003IS5k0000S5R>00><F8h01@00095LS`0009EXW0000002T5fA00L0
002@Fhl00000002PIhh0002AGI000`0000>WKi80100009em/0000:Vmj08000001:Vmj00008mJSP00
00:MI8d200000jVmj0060000T5b@T5b@T5b@0000ZFnA1@000004ZKgX00000000ZKgX0`000003ZKgX
0000000000P000001:Vmj00000000:Vmj0D000000jVmj00000000003000000FY_NP00036E`36E`00
00000YIOSP@00002ZKgX00<0002@G92@G9001P000004ZKgX00000000ZKgX1@000003ZKgX00000000
00H000000jVmj00000000006000000FY_NP000000000002Y_NP020000003ZKgX0000000000<00000
199OT`0000000:Vmj0@00003001k00<0002CGHjCGHh00Y=MSP040000ZKgXZKgX00000iEWVP030000
_8ZQ000000<000000jVmj00000000008000000>Y_NP0000000000`000004ZKgX00000000ZKgX2P00
0003ZKgX0000000000X000000jVmj0000000000doooo000Boooo0P0000?oool300002Oooo`040000
oooo00000000M_ooo`<000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX00000000
00<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0@000001jVmj000000000000<iE0000
09MOS@03000000BY_NP00000002Y_NP3000000BY_NP00000002Y_NP5000000FY_NP000000000002Y
_NP01P000007ZKgX000000000000ZKgX0000SEV?00<000000oFbO@0000000003000000?e/Wh00000
00000P000004mK9m00000000mK9n0P000003mKF400000000008000000oVgN@000?FbO@02000000?e
/Wd0000000001@000003mK9n0000000000D00002Pdb61@000003`Wj80000QTj6008000002Gi6PP00
000000000:MXQ`000<J3R@000:9TR00200000Ud/N`040000Wf670000b8B90`000005ZKgX0000iiI_
iiI_000000:SI8L5000000=R<Gh0000000000ZY[R@@000001VTgP@0009eQRIeQR@000:IWR@800003
I3=o0P0000:OHXT3000000EL;Wh000000029DHL000000ZMYRP800003Pdf700<0002?EXP000000Z5U
RPT000001OFbO@00000000000:Vmj005000000>Y_NP00000000010000003dHb70000000000800000
0fLaN@000:ATQ`02000000>Y_NP0000000000P000003ZKgX0000000000?AS8P2000000=X<g/0002R
HhL010000006ZKgX000000000000mIm?00000i1FQ`050000?QAc?QAc0000T5J700D000000oFPD000
09=IR002TeV80P0000?CShT2000000NRIHX0002?G92?G900002]J84000000YiSR`8000001J1YT@00
000000000:Vmj00300000j=WS08000000jVmj00000000003000000>Y_NP0002:EXd00hYFS@0;0000
X6N?X6N?X6N?0000VF2<0000KdVD0000ZKgX000000:AHID0100009aUT0000<^>T`8000001JVmj000
000000000:Vmj00:000000>Y_NP0000000001P000006ZKgX000000000000IS5k000018aHSP050000
TEb?0000UFRL000000:@GI402P00091KS`0000000:1WSP00095MT0000>=l3`0000:WKi801@0009em
/00000000:Vmj002000000BY_NP0002?FXh00002WFB=0P0000>Y_NP01P00091LT91LT91LT0000:U_
T@8000001JVmj000000000000:Vmj008000000FY_NP000000000002Y_NP010000003ZKgX00000000
00<000001:Vmj00000000:Vmj0@000001JVmj0000<IG0<IG00000002UUn>100000:Y_NP00`00091L
T91LT007000000>Y_NP0000000000`000004ZKgX00000000ZKgX0`000003ZKgX0000000000P00000
0jVmj00000000006000000FY_NP000000000002Y_NP030000003ZKgX0000000000<007/00`0009=M
SY=MSP02Tef>00@0002Y_NRY_NP00003UFNJ3@000003ZKgX0000000000@000001JVmj00000000000
0:Vmj00G000000BY_NP00000002Y_NP20000<oooo`008oooo`80001ioooo1@000005ZKgX00000000
0000ZKgX00H000001JVmj000000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y_NP00000
00001@000003cUD00000Uen=00@000000jVmj00000000004000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP:000000>Y_NP0000000001P000003mK9m0000000000<000000oFbOP0000000003
000000?e/Wh0003e/Wh00P000003mKF400000000008000000oVgN@000?FbO@03000000?e/Wd00000
00001P0000?e/gl300000X=<QPD000000l9nR00008I>QP02000000UnAX8000000000002WJ8L00036
PhT0002RI8P00P00009M;7/0100009mQQ`000<R4R@D00002iiI_00<0002SI8NSI8L01@000003HS5n
0000000000:ZJhT4000000AY=h40002MHHT00002YVN90P0000=T<gl200000YmRR@<000002E`^OP00
000008UAQ`000:MYRP000<N5R`000003Pdf700<0002?EXP000000Z5URPT000000oFbO@000:Vmj005
000000BY_NP00000002Y_NP:000000=W<GT0002TI8L00`000003ZKgX0000000000@00003dHb80P00
0003J3=k0000XV>7008000001:Vmj00000000:Vmj08000001OFOC`00091FQi1FQ`000003?QAc00D0
002@EXL00000002Y_NP00P000007mJ1@0000TeV8TeV80000Pdf6000000?CShT2000000NRIHX0002?
G92?G900002]J84000000YiSR`8000000j1YT@0000000002000000>Y_NP0000000000j=WS0<00000
0jVmj00000000002000000>Y_NP0002:EXd00hYFS@090000X6N?X6N?X6N?0000VF2<0000KdVD0000
00:Y_NP01P00095QU@0009aUT0000<^>T`T000000jVmj0000000000<000000BY_NP00000002Y_NP4
000018aHSP050000TEb?0000UFRL000000:@GI402P00091KS`0000000:1WSP00095MT0000>=l3`00
00:WKi84000000NY_NP00000002Y_NP0002?FXh000000YeTS@800003ZKgX00H0002@G92@G92@G900
002YKi49000000FY_NP000000000002Y_NP01P000003ZKgX0000000000<000000jVmj00000000002
000000>Y_NP00000000010000005ZKgX0000aUL0aUL0000000:FGhh400000ZVmj0030000T5b@T5b@
00<000000jVmj00000000008000000>Y_NP0000000002P000003ZKgX0000000000P000001:Vmj000
00000:Vmj0D000000jVmj00000000008000000>Y_NP0000007/00P00N`030000Tef>Tef>00:CGHh0
10000:Vmj:Vmj00000:EIiX01@000;b:X@000000095LS`05000000>Y_NP0000000001P000003ZKgX
0000000000H000000jVmj00000000003000000>Y_NP00000000020000003ZKgX0000000000800000
0jVmj000000000030000<_ooo`008oooo`030000oooooooo07Woool2000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vmj0<00000
2:Vmj00000000<iE000009MOS@000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX0P000003ZKgX0000000000l000001OFbO@00000000000?FbOP05000000?e
/Wh0003e/Wh00`000007mK9n000000000000nKMi0000mK9m00<000000oFbO@0000000004000000?e
/Wh0003e/gl00_FcO`<00002Pdb61@000003`Wj80000QTj6008000002Gi6PP00000000000:MXQ`00
0<J3R@000:9TR00200000Ud/N`040000Wf670000b8B91@0000;WUVl00`000:=TQj=TQ`05000000=R
<Gh0000000000ZY[R@@0000016TgP@0009eQR@0000:VIhT200000f@cO`040000Wf:9Wf:9Wf:90`00
0009G2in00000000RE670000YfV:0000ahF;000000>3CHL01P0008mFR0000:5URP000>BOQ`P00000
0oFbO@0000000006000000>Y_NP0000000000`000003ZKgX0000000000@000000fLaN@000:ATQ`04
000000>Y_NP0000000000`0000?AS8P2000000=X<g/0002RHhL00`000007ZKgX00000000ZKgX0000
mIm?000000:@EXL01P0003hDLchDLchDL`00091FQ`D000001oFPD00009=IR9=IR00008==QP000003
dhn90P000007XVF:0000Seb@Seb@0000[FR1000000:NHh/00`000:1YT@00000700000j=WS0050000
ZKgX00000000ZKgX008000000jVmj00000000004RUJ=00H0002PIhnPIhnPIhl0002IH8`2000000M_
BI@0002Y_NP0002AHID0002LII000P000004Y6Z>00000000ZKgX0`000003ZKgX0000000000H00000
1JVmj000000000000:Vmj004000000>Y_NP000000000100000B<F8h300000YEXW0030000T5fA0000
00:@Fhl010000:1WSP00095MT0<00002YfnB1P000005lYLj00000000SeZ>000000:MI8d200000jVm
j0060000T5b@T5b@T5b@0000ZFnA1`000003ZKgX0000000000H000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX0000000000<000000jVmj00000000003000000BY_NP00036E`000002
UUn>1@0000:Y_NP00`00091LT0000009000000>Y_NP00000000010000003ZKgX0000000000<00000
0jVmj00000000008000000>Y_NP0000000000P000003ZKgX0000000000<000000jVmj00000000006
000000>Y_NP0000000000`0000<007/00`0009=MSY=MSP02Tef>00P0002Y_NRY_NRY_NP0002EIiX0
002lRZ42000000FAG8l000000000002Y_NP01P000003ZKgX0000000000P000000jVmj00000000003
000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj000
0000000003;oool002?oool00`000?ooooooo`1joooo0P000004ZKgX00000000ZKgX0P000004ZKgX
00000000ZKgX2P000005ZKgX000000000000ZKgX00T000000iMOS@0000000003000000FY_NP00000
0000002Y_NP01@000003ZKgX00000000008000001:Vmj00000000:Vmj08000001:Vmj00000000:Vm
j0h000001?FbO@0000000?FbOPH00002mK9n1`000004nKMi00000000mK9m0P000003mK9m00000000
00@000000oFbOP000?FcO`02mK=o00H0003e]H@00023C8H0002RIH/4000000C2OXP00026CXH00002
OTJ20`000003YfR70000000000:RI8P200000Ud/N`040000Wf670000b8B91@0000;WUVl00`000:=T
Qj=TQ`02000000BY_NP00000001R<Gh200000ZY[R@@0000016TgP@0009eQR@0000:VIhT200000f@c
O`040000Wf:9Wf:9Wf:90`000009G2in00000000RE670000YfV:0000ahF;000000>3CHL01P0008mF
R0000:5URP000>BOQ`P000000oFbO@0000000002000000>Y_NP00000000010000005ZKgX00000000
0000ZKgX008000000jVmj00000000003000000>Y_NP0000000001`0000?AS8P2000000=X<g/0002R
HhL010000006ZKgX000000000000mIm?00000Y1FQ`060000?QAc?QAc?QAc0000T5J71`0000:CFHP0
0`0008==QP000003dhn90P000007XVF:0000Seb@Seb@0000[FR1000000:NHh/00`000:1YT@000003
000000BY_NP0000000000003XfN<0P000003ZKgX0000000000D00004RUJ=00H0002PIhnPIhnPIhl0
002IH8`2000000=_BI@0002Y_NP00P0000:LII02000000>TJXh0000000001`000003ZKgX00000000
00P000000jVmj00000000003000000>Y_NP0000000000P0000F<F8h200000YEXW0030000T5fA0000
00:@Fhl200000Y5MT0<00002YfnB0`000004ZKgX00000000lYLj0P000007SeZ>0000WFB=WFB=0000
ZKgX000000:Y_NP01P00091LT91LT91LT0000:U_T@<000000jVmj00000000008000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX0000000000800000
1:Vmj0000<IG000000:FGhh2000000>Y_NP0000000000ZVmj0030000T5b@000000D000000jVmj000
00000006000000>Y_NP0000000001P000003ZKgX0000000000P000000jVmj00000000003000000>Y
_NP0000000003P000003ZKgX00000000008007/00`0009=MSY=MSP02Tef>0P0000:Y_NP00`0009EW
VP000003000000>AG8l00000000010000003ZKgX0000000000<000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000001P00
0003ZKgX0000000000H0000aoooo000Soooo00<0003oooooool0Noooo`8000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000`000005ZKgX
000000000000ZKgX008000001IMOS@00000000000:Vmj002000000>Y_NP0000000000`000005ZKgX
000000000000ZKgX00@000000jVmj00000000006000000BY_NP00000002Y_NP5000000?b[Gl00000
00000P000004mK9m00000000mK9n1P000003mK9n0000mKF400H000001?VgN@0000000?FbO@<00000
0oFbO@000000000500000oFcO`060000mKF40000Pdb60000XVF;10000004`Wj80000QTj600000Wi6
PP<000000jMXQ`0000000002XVB80P00009M;7/0100009mQQ`000<R4R@D00002iiI_00<0002SI8NS
I8L00P000004ZKgX00000000HS5n0P0000:ZJhT4000000AY=h40002MHHT00002YVN90P0000=T<gl0
100009mRRImRRImRR@800002G2in0P000006RE670000YfV:0000ahF;00000h==Q`060000SeJ80000
XFF:0000i9n720000003mK9m0000ZKgX00D000000jVmj0000000000?000000>Y_NP0000000000`00
0003ZKgX0000000000?AS8P2000000=X<g/0002RHhL020000005mIm?0000T5J7T5J7000000<n57<2
000000?h/gH0002Y_NP0100000:CFHP00`0008==QP000003dhn90P000003XVF:0000Seb@00:?G902
00000YiSR`030000X6VA000000L00003XfN<10000003ZKgX0000000000<00003RUJ=0P0000>PIhl0
100009UPS0000000009_BI@300000YaUT08000001JAZSP00000000000:Vmj003000000BY_NP00000
002Y_NP5000000>Y_NP00000000020000004ZKgX0000000000001HaHSP800002UFRL0P0000>@Fhl2
000000>AGI00000000000P0000:WKi86000000GbUcX00000002?FXh000000YeTS@<00002ZKgX00H0
002@G92@G92@G900002YKi4:000000>Y_NP0000000000P000003ZKgX0000000000<000000jVmj000
00000003000000BY_NP00000002Y_NP8000000BY_NP00036E`000002UUn>1@0000:Y_NP00`00091L
T0000003000000>Y_NP00000000010000003ZKgX0000000000<000000jVmj00000000002000000>Y
_NP0000000000`000004ZKgX00000000ZKgX1@000003ZKgX0000000000P000000jVmj00000000004
000000>Y_NP0000000000`00008007/00`0009=MSY=MSP02Tef>0P0000:Y_NP2000000>lRZ400000
00000Y5LS`@000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP0000000000P00
0003ZKgX0000000000X000001JVmj000000000000:Vmj00:0000<Oooo`008_ooo`030000oooooooo
07goool2000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX1P00
0005ZKgX000000000000ZKgX00D000000iMOS@0000000002000000BY_NP00000002Y_NP2000000BY
_NP00000002Y_NP3000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj00000000002
000000?b[Gl0000000000`000003mK9m0000mK9n00H000001?FbOP0000000?FeQ0`000000oFbO@00
0000000500000oFcO`060000mKF40000Pdb60000XVF;1@0000:6CXH00`0007i6PWi6PP03000000>W
J8L0000000000Z9TR0800002GBak00@0002OHHL00038Q8T2000000>Y_NP0000000000^NFK`030000
XfB7XfB7008000001:Vmj0000000068aOP800002ZV^910000004JCN10000WF6900000ZIWR@800003
I3=o00@0002OHXVOHXVOHXT200000U`^OP8000001XUAQ`000:MYRP000<N5R`0000:3CHL02@0008mF
R8mFR0000:5URP000>BOQ`0006dlQ006000000?e/Wd0000000000`000004ZKgX00000000ZKgX0`00
0003ZKgX0000000000h000001JVmj00000000:Vmj0000003dHb80P000005J3=k0000XV>70000ZKgX
00H000001OFOC`00091FQi1FQ`000003?QAc2@0000:CFHP00`0008==QP000003dhn900@0002RIHZR
IHX00003Seb@0P0000:NHh/00`000:1YT@000004000000>Y_NP0000000000Z=WS0H000001ZVmj000
000000000:Vmj00000::EXd200000j1WS`040000VF2<000000000Vm9U0<00002W6F@0P000003Y6Z>
0000000000H000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP0000000001000
0003IS5k0000S5R>00><F8h200000YEXW0800003T5^?0P000007TEf@000000000000hg`?0000YfnB
00H000001O:G>P00000008mJSP000002WFB=0`0000:Y_NP01P00091LT91LT91LT0000:U_T@H00000
0jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj00000000006
000000BY_NP0000000000002aUL000<0002FGhh00000100000:Y_NP00`00091LT0000006000000>Y
_NP0000000000`0000:AG903000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj000
00000006000000>Y_NP0000000001P000003ZKgX0000000000<000001JVmj0000000N`00N`000004
Tef>0`000004ZKgX00000000_8ZQ0P0000:AG8l;000000>Y_NP0000000000`000004ZKgX00000000
ZKgX3P000003ZKgX0000000000H000000jVmj00000000003000000>Y_NP000000000<?ooo`008_oo
o`030000oooooooo07koool4000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX0`00
0004ZKgX00000000ZKgX0`000003ZKgX00000000008000000iMOS@0000000003000000BY_NP00000
002NQKP2000000BY_NP00000002DJj05000000FY_NP000000000002Y_NP01P000005ZKgX00000000
0000ZKgX00<000000o:]O`0000000003000000?e/Wd0003e/Wh01P000004mK9n00000000mKF42000
0005mK9m000000000000mK9m00L00002mK=o0P000005mKF40000Pdb60000XVF;00<000000l9nR000
08I>QP0200000Wi6PP<000001:MXQ`0000000:9TR0<00002GBak00@0002OHHL00038Q8T3000000FY
_NP0003WUVoWUVl000000Z=TQ`8000001:Vmj0000000068aOP800002ZV^90`000005h:<L00000000
WF69000000:VIhT200000f@cO`040000Wf:9Wf:9Wf:90P00009L;Wh2000000J9DHL0002WJHX00037
QH/00002Pdf700/0002?EXR?EXP0002QIHX0003TWhL0001]?8@0002MHX/010000004mK9m00000000
YjGD0`000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX00X000001:Vmj00000000000
00?AS8P2000000=X<g/0002RHhL00`000003ZKgX00000000008000001OFOC`00091FQi1FQ`000003
?QAc1@000004ZKgX0000000000000Y=IR0800004dhn900@0002RIHZRIHX00003Seb@0P0000:NHh/0
0`000:1YT@000002000000>Y_NP0000000000P0000:SIh`2000000>Y_NP0000000001`000004RUJ=
0000000000000j1WS`040000VF2<000000000fm9U0040000W6F@W6F@W6F@0P000003Y6Z>00000000
008000000jVmj00000000008000000>Y_NP0000000000`000004ZKgX00000000ZKgX1`0000B<F8h0
100007Y>T@0009EXW0800003T5^?0P000003TEf@0000000000<000000jM_TP0000000003000000JY
_NP0003bUcX0002?FXh00002WFB=10000003ZKgX0000T5b@00:@G90010000:U_T@000:Vmj0800000
1:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX00000000
00@000001JVmj000000000000:Vmj00500000/IG00030000UUn>0000008000001ZVmj00000000:Vm
j000091LT0D000001:Vmj00000000:Vmj0800004TEb@1@000003ZKgX00000000008000000jVmj000
0000000:000000FY_NP000000000002Y_NP01P000003ZKgX0000000000<000000jVmj00000000003
00000P00N`030000Tef>Tef>00:CGHh500000[b:X@040000TEb?TEb?TEb?1`000003ZKgX00000000
01D000000jVmj00000000008000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P0000koool2
00001?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo000Roooo00<0003oooooool0Oooo
o`@000000jVmj00000000003000000FY_NP000000000002Y_NP01P000003ZKgX0000000000H00000
1JVmj000000000000:Vmj004000000BNQKP00000002CHI@200000YA[X0050000V6BB00000000ZKgX
008000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX0000000000@000000o:]O`00
0000000400000_FbOP030000mK9n000000<000001?FbOP0000000?FeQ0<000000oFbO@0000000002
000000?e/Wd0000000000P000004mK9o00000000mK9n0`0000;e/gl300000X=<QP030000XVF;0000
008000000l9nR00008I>QP02000000=nAX80002YJhX00`000003aX>90000XVB800<00002GBak00@0
002OHHL00038Q8T500000^NFK`030000XfB7XfB7008000001:Vmj0000000068aOP800002ZV^90`00
0005h:<L00000000WF69000000:VIhT200000f@cO`060000Wf:9Wf:90000bXN;00000U`^OP800000
1XUAQ`000:MYRP000<N5R`0000:3CHL02`0008mFR8mFR0000:5URP000>BOQ`0006dlQ00009eRR`04
000000Ce/Wd0000000000002SUV>0P000003ZKgX0000000000<000000jVmj0000000000:000000>Y
_NP0000000000P000003ZKgX0000000000?AS8P2000000EX<g/0002RHhL0002Y_NP00P000006ZKgX
000000000000mIm?00000Y1FQ`040000?QAc?QAc?QAc0`000003ZKgX0000000000<00002TeV80P00
00CCShT010000:9URZ9URP0000>?G902000000BNHh/0002PJI6PJI44000000BY_NP0000000000002
XfN<0`000003ZKgX0000000000<000001:Vmj000000008YFS@<00003X6N?00@0002IH8`000000003
KdVD00@0002LII2LII2LII02000000>TJXh0000000002@000003ZKgX0000000000P000000jVmj000
00000003000000BY_NP0000000000004S5R>00@0001jCY40002EJ9`200000i1KS`8000000i5MT000
00000003000000>WKi80002Y_NP00`000003ZKgX0000lYLj00800003WFB=10000003ZKgX0000T5b@
00:@G9000`000:U_T@000004000000BY_NP00000002AGY42000000BY_NP00000002Y_NP5000000>Y
_NP0000000001P000003ZKgX0000000000H000000jVmj00000000002aUL000<0002FGhh000001@00
0003ZKgX0000T5b@00800002TEjB0P000004ZKgX0000000000001I5LT0<000001:Vmj00000000:Vm
j0h000000jVmj00000000006000000>Y_NP00000000020000003ZKgX0000000000800003001k00@0
002CGHjCGHjCGHh5000000>lRZ40000000000i5LS`<000000jVmj0000000000<000000BY_NP00000
002Y_NP5000000>Y_NP00000000020000003ZKgX0000000000P000000jVmj0000000000200004?oo
o`060000oooooooo0000oooo00000_ooo`030000oooo000001Coool002;oool00`000?ooooooo`20
oooo2P000003ZKgX0000000000<000000jVmj00000000004000000FY_NP000000000002Y_NP01P00
00:Y_NP300000i=QU0040000U6^PU6^P00000YQTTP<000001:Vmj00000000:Vmj08000001:Vmj000
00000:Vmj0X000000o:]O`0000000004000000?e/Wh0000000000P000004mK9m00000000mK9n0`00
0004mK9n00000000mK9m10000003mK9m00000000008000001?FbO`0000000?FbOP<00002mK=o0`00
00:3C8H2000000K`[hD000000032OXP00026CXH2000000=nAX80002YJhX00`000003aX>90000XVB8
00<000001ed/N`0009mQQ`000<R4R@000?FbO@0400000^NFK`030000XfB7XfB7008000001:Vmj000
0000068aOP800002ZV^90`000005h:<L00000000WF69000000:VIhT200000f@cO`060000Wf:9Wf:9
0000bXN;00000U`^OP8000001XUAQ`000:MYRP000<N5R`0000:3CHL02`0008mFR8mFR0000:5URP00
0>BOQ`0006dlQ00009eRR`06000018iISPT000000jVmj00000000003000000>Y_NP0000000001000
0003ZKgX0000000000@00003dHb80P000003J3=k0000XV>7008000001:Vmj00000000:Vmj0800000
1OFOC`00091FQi1FQ`000003?QAc1P000003ZKgX0000000000:CFHP200001=>?R@040000XVF:XVF:
00000hmLT08000000iiSR`000:1YT@0900000Z=WS0030000ZKgX000000@000000jVmj00000000002
000000F:EXd000000020Ah8000000Z1WS`040000VF2<000000000fm9U0090000W6F@W6F@0000bhjC
0000Y6Z>0000ZKgX00D000000jVmj00000000008000000>Y_NP00000000020000003ZKgX00000000
00B<F8h600000i1KS`8000000i5MT00000000003000000>WKi80000000001@000003lYLj00000000
00>MI8d010000:Vmj000000000:Y_NP01000091LT0000:U_T@800003TV2D0P0000>AGY43000000>Y
_NP0000000000`000004ZKgX00000000ZKgX0`000003ZKgX0000000000P000002JVmj00000000000
0:Vmj0000<IG000009IOSP06000000>Y_NP0002@G9000P0000:AGY8300000ZVmj0030000TEb@TEb@
00>AG904000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00X000001:Vmj00000000:Vm
j0D000000jVmj00000000003000000>Y_NP0000000000`00N`040000Tef>Tef>Tef>1@000003_8ZQ
0000000000>AG8l00`000:Vmj000000;000000>Y_NP0000000000P000003ZKgX0000000000<00000
0jVmj00000000003000000BY_NP00000002Y_NP:000000>Y_NP0000000001`0000koool01`000?oo
ooooooooo`000?ooo`000002oooo00<0003oool000005?ooo`008_ooo`040000oooo00000000P?oo
o`D000000jVmj00000000004000000FY_NP000000000002Y_NP00`000003ZKgX0000000000@00000
0jVmj00000000006000019=QU080000019A[X00009QTTYQTTPD000000jVmj00000000003000000BY
_NP00000002Y_NP5000000>Y_NP0000000000P000003mK9m0000000000<000000oFbOP0000000002
000000?e/Wd00000000010000009mK9n000000000000nKMi0000mK9m0000mK9m00P000000oFbOP00
00000002mK=o0`0000:3C8H5000000?2OXP00026CXH00P000003OTJ20000ZF^:00<000000lJ3R@00
0:9TR005000000FOHHL00038Q8T0003e/Wd0100000;WUVl00`000:=TQj=TQ`05000000=R<Gh00000
00000ZY[R@<000001^2S7000000009eQR@000:IWR@<00003I3=o00H0002OHXVOHXT0003:Qh/00002
G2in0P000006RE670000YfV:0000ahF;00000X==Q`0;0000SeJ8SeJ80000XFF:0000i9n70000KCb4
0000WF:;00D00005SUV>1@000003ZKgX00000000014000001:Vmj0000000000000;AS8P3000000=X
<g/0002RHhL00`000003ZKgX00000000008000001OFOC`00091FQi1FQ`000003?QAc2@0000:CFHP2
00001=>?R@030000XVF:XVF:00800002Seb@0P000003WV>;0000X6VA00@000000jVmj00000000002
00000Z=WS0P000000jVmj00000000004000000J0Ah80002PIhnPIhl0002IH8`200000fm9U0070000
W6F@W6F@0000bhjC0000Y6Z>00D000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX0000000000@00004S5R>1P0000B@Fhl01000095MT0000:Vmj0<00000
0jM_TP0000000005000000?bUcX0000000000ieTS@8000002JVmj00000000:Vmj000091LT0000:U_
T@000004TV2D00<0002AGY6AGY400Y5NT@X000000jVmj0000000000:000000>Y_NP0000000001`00
0003aUL00000UUn>00@000001JVmj00000000000091LT00200000Y5NTP800003ZKgX00<0002AG92A
G9000i5LT0L000001JVmj000000000000:Vmj00<000000>Y_NP0000000000P000003ZKgX00000000
00<000000jVmj00000000003000000BY_NP00000002Y_NP200000P00N`040000Tef>Tef>Tef>0`00
0003ZKgX0000000000800003TEb?10000003ZKgX0000000000<000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX0000000000P000000jVmj0000000000E00003_ooo`060000oooooooo
0000oooo00000_ooo`030000oooo000001Coool002;oool20000Poooo`8000001:Vmj00000000:Vm
j0<000001:Vmj00000000:Vmj0<000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX
0000000000800002Mj_c00<0002CHIBCHI@00Y=QU08000001IA[X00009QTTYQTTP000003T5nE1000
0005ZKgX000000000000ZKgX008000001:Vmj00000000:Vmj08000001JVmj000000000000?FbO@05
000000?e/Wh0000000000`000003mK9n0000mK9n00<000001oFbOP00000000000?VgN@000?FbO@02
000000?e/Wd0000000001@000003mK9n0000000000;e/gl00`000?FeQ0000002Pdb61@000003`Wj8
0000QTj6008000000gi6PP000:U[RP03000000?6PhT0002RI8P01@000003Wf670000b8B900H00002
iiI_00<0002SI8NSI8L01@000003HS5n0000ZV^900:ZJhT3000000KPXa`00000002MHHT0002VIhT3
00000f@cO`060000Wf:9Wf:90000bXN;00000U`^OP8000000hUAQ`000:MYRP0200000h==Q`0;0000
SeJ8SeJ80000XFF:0000i9n70000KCb40000WF:;00D00004SUV>00<0002TJhl0000010000003ZKgX
0000000000<000000jVmj00000000004000000FY_NP000000000002Y_NP01@0000;AS8P01P000:Vm
j00006PcN`000:9SQ`P000001OFOC`00091FQi1FQ`000003?QAc0`0000:CI9P400000Y=IR0800004
dhn900<0002RIHZRIHX00P0000:?G902000000>NHh/0002PJI402@0000:SIh`4000000>Y_NP00000
00001`000005mZ9D00000000X6N?000000:IH8`300000Vm9U0070000W6F@W6F@0000bhjC0000Y6Z>
00H000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP0000000000P000003ZKgX
0000000000<00003S5R>1`0000B@Fhl00`00095MT0000004000000BWKi800000002Y_NP400000_:G
>P040000WFB=WFB=WFB=1@000006ZKgX0000T5b@0000ZFnA00000i9PU0800004TEjA1P000003ZKgX
0000000000@000000jVmj00000000003000000>Y_NP00000000020000006ZKgX00000000aUL00000
UUn>10000003ZKgX00000000008000001;EjT@00095NTY5NTP800003ZKgX00<0002AG92AG9000i5L
T0D000000jVmj00000000006000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj000
00000003000000>Y_NP00000000020000003ZKgX0000000000800002001k00@0002CGHjCGHjCGHh3
000000>Y_NP0000000000P0000>AG8l2000000BY_NP00000002CHI@2000000BY_NP00000002Y_NP5
000000>Y_NP00000000020000003ZKgX0000000000@000000jVmj00000000003000000>Y_NP00000
000020000004ZKgX0000000000003?ooo`030000oooo000000;oool00`000?ooo`000002oooo00<0
003oool000005?ooo`008Oooo`030000oooooooo08Coool2000000>Y_NP00000000010000004ZKgX
00000000ZKgX1@000005ZKgX000000000000ZKgX00D000000jVmj00000000002Mj_c00H0002CHIBC
HIBCHI@0002FGX`200000iQTTP050000T5nET5nE0000ZKgX00@000001JVmj000000000000:Vmj005
000000>Y_NP00000000010000003mK9m00000000008000000oFbOP0000000003000000Ce/Wh00000
003e]H@2000000Oe/Wh000000000003i]gT0003e/Wd00`000003mK9m0000000000@000000oFbOP00
0?FcO`02mK=o00H0003e]H@00023C8H0002RIH/4000000?2OXP00026CXH00P000003OTJ20000ZF^:
00<000000lJ3R@000:9TR005000000>OHHL00038Q8T00`000003ZKgX0000000000;WUVl00`000:=T
Q`00000700000jY[R@<000001^2S7000000009eQR@000:IWR@<00003I3=o00<0002OHXVOHXT00`00
009L;Wh300000ZMYRP800003Pdf700<0002?EXP000000Z5URP800002KCb400D0002MHX/00000002W
JX/00P0000B>FHh00`000:A[S`00000;000000>Y_NP000000000100000:@GY84000000>Y_NP00000
00000]6<R0<000000fPcN`000:9SQ`02000000RY_NP000000000002Y_NP0003eWdl00002T5J700@0
000n57<n57<n57<3000000>CI9P0000000000`0000:CFHP200001=>?R@030000XVF:XVF:00800002
Seb@0P000003WV>;0000X6VA00D000001:Vmj0000000000000:SIh`5000000>Y_NP0000000001P00
0005mZ9D00000000X6N?000000:IH8`00`000:Vmj0000002KdVD00D0002LII2LII00003;SY<01000
0003ZKgX0000000000P000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0D000001JVmj000
0000000008aHSP090000191KS`@000001:Vmj00000000:M_TPL00002lYLj00H0002MI8fMI8fMI8d0
002Y_NP3000000JY_NP0002@G900002YKi400003TV2D0P0000>AGY40100009eUS`000:Vmj0P00000
0jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP00000000010000005aUL00000UUn>
0000ZKgX008000000jVmj00000000002000000FeNY40002AGY80002cNI@00P0000>Y_NP00`00095L
T95LT002TEb@00<0002Y_NP000003`000004ZKgX00000000ZKgX1@000003ZKgX0000000000P00000
0jVmj00000000004000000FY_NP0000007/007/000000i=MSP<00002ZKgX00<0002Y_NP000000i5L
S`<00003Tf6D0`000003ZKgX0000000000<000000jVmj00000000006000000>Y_NP0000000001P00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000003000000>Y_NP00000
00003?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool04oooo`008Ooo
o`030000oooooooo08Goool4000000>Y_NP0000000000P000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000=gZo<0002CHI@00Y=QU0030000UUj<0000
00>HI9801000091OUI1OUI1OU@8000000jVmj00000000008000000FY_NP000000000002Y_NP01`00
0003mK9m0000000000L000001?FbOP0000000?FeQ0D000001?VgN@0000000?FbO@8000000oFbO@00
00000004000000?e/Wh0003e/gl00_FcO`060000mKF40000Pdb60000XVF;10000003`Wj80000QTj6
008000000gi6PP000:U[RP03000000?6PhT0002RI8P01@000003Wf670000b8B900@000001ZVmj000
0>NFKnNFK`000:=TQ`P00003ZV^90`000004h:<L0000000000000ZIWR@<00003I3=o00<0002OHXVO
HXT00`00009L;Wh300000ZMYRP800003Pdf700<0002?EXP000000Z5URP800002KCb400D0002MHX/0
0000002WJX/00P0000B>FHh00`000:A[S`000007000000>Y_NP0000000000P000003ZKgX00000000
00800003T5jB0P000003ZKgX0000000000800002dHb80`000003J3=k0000XV>700P000001OFOC`00
091FQi1FQ`000003?QAc0`000003TfBH0000000000<00002TeV80P0000CCShT00`000:9URZ9URP02
00000XmLT08000000iiSR`000:1YT@03000000>Y_NP0000000000`0000:SIh`00`000:Vmj0000009
000000>Y_NP0003fXU@00P000004X6N?0000VF2<VF2<0`00009_BI@00`0009aUT9aUT002000000>T
JXh00000000010000005ZKgX000000000000ZKgX00@000000jVmj00000000003000000BY_NP00000
002Y_NP2000000BY_NP00000002Y_NP:000000=^>Gl0002@Fhl00i1KS`l00002lYLj00@0002MI8fM
I8fMI8d5000000JY_NP0002@G900002YKi400003TV2D0P0000>AGY401@0009eUS`0000000:Vmj003
000000>Y_NP00000000020000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000lIG0000
09IOSP06000000S^T2T00000002eNY40002AGY80002cNI@200000jVmj0030000TEb@TEb@00:AG908
000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP00000
00001P000003ZKgX0000000000H000001:Vmj00000000000008007/0100009=MSY=MSY=MSP@00003
ZKgX00@0002AG8nAG8nAG8l2000019=QU0`000001JVmj000000000000:Vmj006000000>Y_NP00000
00000`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0P0002_oool0027oool00`000?ooooooo`27oooo0`000003ZKgX0000000000P00000
1:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0<000001:Vmj00007N[l`0000:CHI@0100009IN
S9INS00000>HI9801@00091OUI1OU@000:Vmj002000000>Y_NP0000000000`000003ZKgX00000000
008000000jVmj0000000000;000000?e/Wh00000000010000004mK9n00000000mKF41@000004nKMi
00000000mK9m0P000003mK9m0000000000H00002mK=o0P000005mKF40000Pdb60000XVF;00@00000
0l9nR00008I>QP02000000=nAX80002YJhX00`000003aX>90000XVB800D000000imQQ`000<R4R@03
00000ZVmj0050000iiI_iiI_0000XfB700<000000nb9<`000>RZ:@0200000ZY[R@050000m;1n0000
0000h:<L00<00002YVN90`0000=T<gl00`0009mRRImRR@0300000U`^OP<00002YfV:0P0000>3CHL0
0`0008mFR0000002XFF:0P00009]?8@01@0009eRR`0000000:MZR`02000018iISPP000001:Vmj000
00000:Vmj0@000001:Vmj0000000000000:@GY86000000BY_NP0003AS8SAS8P3000000=X<g/0002R
HhL00`000003ZKgX00000000008000001OFOC`00091FQi1FQ`000003?QAc10000003ZKgX00000000
00800002TeV80P0000CCShT00`000:9URZ9URP0200000XmLT08000000iiSR`000:1YT@06000000>Y
_NP0000000000Z=WS08000000jVmj00000000003000000>Y_NP0000000000`000005mZ9D00000000
X6N?000000:IH8`300000Vm9U0030000W6F@W6F@008000000jAZSP0000000002000000>Y_NP00000
000010000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX
0000000000<000000jVmj00000000004000000=^>Gl0002@Fhl0191KS`@000000jVmj00000000003
000000BY_NP0000000000002lYLj00@0002MI8fMI8fMI8d2000000=jZO00000000000P000004T5b@
0000ZFnA00000i9PU0800003TEjA00<0002MIHl0000030000003ZKgX0000000000<000000jVmj000
00000002000000>Y_NP0000000000`000005ZKgX0000aUL00000UUn>00H000002>j@:@0000000;Ej
T@00095NTP000;=iU0800003ZKgX00<0002AG92AG9000Y5LT0@000000jVmj00000000003000000>Y
_NP0000000000P000003ZKgX0000000000X000001JVmj000000000000:Vmj006000000>Y_NP00000
00000`000005ZKgX0000001k001k000000>CGHh400000jVmj0040000TEb?TEb?TEb?0P0000BCHI@:
000000>Y_NP0000000001P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP00000
00000`000003ZKgX0000000000P000000jVmj000000000020000:oooo`008Oooo`030000oooooooo
08Soool3000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000003000000BY
_NP00000002Y_NP4000000EgZo<0002CHIBCHI@000000YINS0050000V6BBV6BBV6BB000000:@GiD2
000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000003ZKgX0000000000L000000oFbO@00
0?FbOP06000000Ce/Wh00000003e]H@5000000Ci]gT00000003e/Wd3000000?e/Wd0000000001@00
00;e/gl300000X=<QP030000XVF;000000<000000l9nR00008I>QP0300000ZU[RP<000001LJ3R@00
0:9TR0000:iaS@03000000>OHHL00038Q8T00`0000:Y_NP01@000>NFKnNFK`000:=TQ`03000000?/
RC<0003XZRT00P0000:ZJhT2000000>HH8h0003PXa`00`0000:VIhT300000f@cO`030000Wf:9Wf:9
00<00002G2in0`0000:WJHX200000h==Q`030000SeJ8000000:QIHX200000VdlQ0050000WF:;0000
0000YfZ;00800003SUV>00<0002TJhl000001`000003ZKgX0000000000800003ZKgX0`0000:@GY82
000000>Y_NP0000000000`0000;AS8P3000000EX<g/0002RHhL0002Y_NP00P000006ZKgX00000000
0000mIm?00000Y1FQ`800002?QAc1@000004ZKgX0000000000000Y=IR0800004dhn900<0002RIHZR
IHX00P000005Seb@000000000000WV>;008000000j=YS`000:Vmj00600000Z=WS0H000001:Vmj000
00000:Vmj08000000jVmj00000000002000000BPIhl0002IH8bIH8`4000000A_BI@0002LII2LII02
000000>TJXh0000000001@000003ZKgX0000000000P000000jVmj00000000003000000>Y_NP00000
000020000003ZKgX0000000000<000000fhiO`00091KS`04T5^?2`000003ZKgX0000000000;bUcX0
100009eTSIeTSIeTS@800002NZW`0`000004T5b@0000ZFnA00000Y9PU0040000JcMnJcMn00000Y5N
T@030000WFF?0000008000000jVmj00000000003000000>Y_NP00000000020000003ZKgX00000000
00/0000019IOSP0000000:Vmj0<000001^j@:@0000000;EjT@00095NTP@00003ZKgX00<0002AG92A
G9000Y5LT08000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0X000001JVmj00000000000
0:Vmj008000000>Y_NP0000000000`000003ZKgX0000000000<00002001k00@0002CGHjCGHjCGHh4
00000jVmj0040000TEb?TEb?TEb?0P0000>CHI@00`000:Q`T`000004000000>Y_NP0000000002000
0003ZKgX0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000008000000>Y_NP00000
000010000003ZKgX0000000002[oool0027oool00`000?ooooooo`29oooo1@000005ZKgX00000000
0000ZKgX00X000000jVmj00000000006000000BCHI@0002FGXbFGX`200000YQTTP8000000i1OU@00
00000004000000FY_NP000000000002Y_NP00P000004ZKgX00000000ZKgX1@000003lZeo00000000
00<000000oFbO@000?FbOP06000000?e/Wh0000000002@000005mK9m000000000000mK9m00L00002
mK=o0`0000:3C8H00`000:9UR`000003000000?2OXP00026CXH00`0000:YJhX400000Z9TR0030000
[W6=0000008000000imQQ`000<R4R@04000000JY_NP0003WUVoWUVl0002SI8L3000000?/RC<0003X
ZRT00P0000:ZJhT2000000>HH8h0003PXa`00`0000:VIhT300000f@cO`030000Wf:9Wf:900<00003
G2in0P000004YfV:0000ahF;00000h==Q`030000SeJ8000000:QIHX200000VdlQ0050000WF:;0000
0000YfZ;00800003SUV>00<0002TJhl000000`000003ZKgX0000000000@000000jVmj0000:Vmj002
ZKgX0`0000:@GY83000000>Y_NP0000000000P0000;AS8P3000000=X<g/0002RHhL00P000003ZKgX
0000000000<000001?FOC`00091FQi1FQ`800002?QAc1P000003ZKgX0000000000:CFHP200001=>?
R@030000XVF:XVF:008000001HmLT0000000000009iSR`02000000BSJHl00000002Y_NP3000000BY
_NP0002SIhbSIh`7000000>Y_NP0000000000`000006ZKgX000000000000X6N?00000YUPS0060000
ZKgX00000000KdVD00000YaUT08000000jAZSP000:Vmj003000000>Y_NP0000000001P000003ZKgX
0000000000<000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000@00000
0jVmj0000000000200001I1KS`<000001JVmj000000000000:Vmj007000000?bUcX0002MI8d00YeT
S@<0000027ZYl00000000000091LT0000:U_T@0000:BH9@0100006/gOV/gOP0000:AGY40100009eU
S`000:Vmj0D000001:Vmj00000000:Vmj0D000000jVmj00000000008000000>Y_NP0000000001000
0003UUn>0000000000L000000kEjT@00095NTP0500000ZVmj0040000TEb@TEb@TEb@10000003ZKgX
0000000000<000000jVmj00000000006000000>Y_NP00000000030000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0D000000`00N`0009=MSP02Tef>100000BY_NP00`00095LSi5LS`0200000i=Q
U0030000Z72C000000:BGi49000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj000
00000003000000>Y_NP0000000001P000003ZKgX0000000000H000000jVmj000000000030000:Ooo
o`008Oooo`030000oooooooo08[oool2000000BY_NP00000002Y_NP5000000FY_NP000000000002Y
_NP01P000003ZKgX0000000000<0000019=QU00009INS9INS0800002V6BB0P000004T5nE00000000
ZKgX10000005ZKgX000000000000ZKgX00P000000jVmj0000?:]O`06000000Ce/Wh00000003e/Wh4
000000Ge/Wh000000000003e/Wh01`000005mK9m000000000000mK9m00L00002mK=o0`0000:3C8H0
0`000:9UR`00000200000/9nR0030000QTj6000000800002ZF^:100000:RI8P00`000:iaS@000002
000000>OHHL00038Q8T010000004ZKgX0000iiI_00000Z=TQ`<000000nb9<`000>RZ:@0200000ZY[
R@8000000iQPSP000>2S700300000ZIWR@<00003I3=o00<0002OHXVOHXT00`0000=L;Wh2000000BW
JHX00037QH/00003Pdf700<0002?EXP000000Z5URP800002KCb400D0002MHX/00000002WJX/00P00
00>>FHh00`000:A[S`000006000000>Y_NP000000000100000:Y_NP3000000B@GY800000002Y_NP2
000000BY_NP0000000000002dHb80`000003J3=k0000XV>700D000001JVmj00000000?FOC`000002
T5J70P00008n57<900000Y=IR0800004dhn900<0002RIHZRIHX00`000003dK:j0000[FR100<00000
0j=YS`0000000007000000FSIh`000000000002Y_NP01@000003ZKgX0000000000<000001OJRE000
0:1WS`0009UPS003000000BY_NP0001_BI@00002W6F@0P000003Y6Z>0000000000H000001JVmj000
000000000:Vmj002000000BY_NP00000002Y_NP2000000>Y_NP0000000000`000003ZKgX00000000
008000001JVmj000000000000:Vmj00600001I1KS`030000ZKgX000000`000000o:G>P0009eTS@02
WFB=0`000008NZW`0000l98a0000T5b@0000ZFnA00000Y9PU0040000JcMnJcMn00000Y5NT@030000
WFF?000000L000000jVmj00000000003000000BY_NP00000002Y_NP5000000>Y_NP0000000001`00
0003aUL000000000008000002JVmj000000000000>j@:@000;EjT@00095NTP0500000ZVmj0040000
TEb@TEb@TEb@1P000003ZKgX0000000000P000000jVmj0000000000:000000>Y_NP0000000002000
0003ZKgX0000000000<000001JVmj0000000N`00N`000002Tef>0P000003ZKgX0000ZKgX00>Y_NP0
1P00095LSi5LS`000:Vmj00000:CHI@00`000:Q`T`000002TUnA1@000003ZKgX0000000000<00000
0jVmj00000000002000000>Y_NP0000000002P000003ZKgX0000000000P000000jVmj00000000003
000000BY_NP000000000000Yoooo000Poooo00<0003oooooool0S?ooo`8000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000000`0000>FGX`2
000000>HI980002Y_NP00P000004ZKgX00000000ZKgX10000003ZKgX0000000000L000001JVmj000
000000000?:]O`06000000Ge/Wh000000000003e/Wh00`000005mK9n000000000000mK9n00800000
0oFbO@0000000002000000?e/Wd0000000000P000004mK9o00000000mK9n0`0000;e/gl300000X=<
QP030000XVF;0000008000001<9nR00008I>QXI>QP<00002ZF^:100000:RI8P00`000:iaS@000002
000000>OHHL00038Q8T010000004ZKgX0000iiI_00000Z=TQ`<000000nb9<`000>RZ:@0200000ZY[
R@8000000iQPSP000>2S700300000ZIWR@<00003I3=o00<0002OHXVOHXT00`0000=L;Wh2000000BW
JHX00037QH/00003Pdf700<0002?EXP000000Z5URP800002KCb400D0002MHX/00000002WJX/00P00
00>>FHh00`000:A[S`000004000000BY_NP00000002Y_NP3000000BY_NP0002Y_NRY_NP3000000F@
GY8000000000002Y_NP01@0000;AS8P020000:Vmj00006PcN`000:9SQ`000:Vmj0H000001?FOC`00
091FQi1FQ`800002?QAc1P000003ZKgX0000000000:CFHP200001=>?R@030000XVF:XVF:00<00000
0m6b^P000:eXP@03000000>SJHl0000000001`000003XfN<0000000000P000000jVmj00000000002
000000OfXU@0002PIhl0002IH8`0002Y_NP00`000007KdVD0000W6F@0000bhjC0000Y6Z>00@00000
0jVmj00000000006000000>Y_NP0000000000`000004ZKgX00000000ZKgX0P000004ZKgX00000000
ZKgX2P000004ZKgX0000000000001I1KS`@000000jVmj00000000003000000>Y_NP0000000000P00
0003lYLj0000WFB=00:MI8d00`000:Vmj0000002000000?`TS40000000000ZU_T@040000TV2DTV2D
00000V/gOP050000TEjATEjA0000WFF?00@000000jVmj00000000003000000>Y_NP0000000000P00
0003ZKgX0000000000<000000jVmj00000000006000000BY_NP000000036E`08000000G^T2T0002e
NY40002AGY801@0000:Y_NP01000095LT95LT95LT08000000jVmj00000000008000000>Y_NP00000
000010000003ZKgX0000000000<000000jVmj00000000008000000>Y_NP0000000002@00008007/0
0`0009=MSY=MSP0500000jVmj0040000TEb?TEb?TEb?0P0000:CHI@00`000:Q`T`000002TUnA0`00
0003ZKgX0000000000<000001:Vmj00000000:Vmj0h000000jVmj00000000003000000BY_NP00000
002Y_NP5000000>Y_NP0000000001P0002Soool0023oool00`000?ooooooo`2=oooo0P000003ZKgX
0000000000<000001:Vmj00000000:Vmj08000001:Vmj00000000:Vmj0T00003UUj<0P000003V6BB
0000000000<000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>Y_NP0000000001000
0003lZeo0000000000@000000oFbOP0000000002000000Ge/Wd000000000003e]H@00P000004mK9n
00000000mK9m10000003mK9m00000000008000001?FbO`0000000?FbOP<00002mK=o00<0003e]H@0
00000X=<QP030000XVF;0000008000001<9nR00008I>QXI>QP<00002ZF^:10000004XVB800000000
[W6=0`000003Wf670000b8B900<000001HI@R00000000>NFK`000002XfB70`000003k8Tc0000j:XY
00800002ZV^90P000003V62>0000h:<L00<00002YVN90`0000=T<gl00`0009mRRImRR@0300000e`^
OP8000000jMYRP000<N5R`0200000X==Q`030000SeJ8000000:QIHX200000VdlQ0050000WF:;0000
0000YfZ;00800003SUV>00<0002TJhl000001@000003ZKgX0000000000H000001JVmj00000000000
091NTP09000000?AS8P0000000000P000003J3=k00000000008000000jVmj00000000003000000Ce
Wdl0002@EXN@EXL200000ShDL`<000000jVmj0000000000300000Y=IR0800004dhn900<0002RIHZR
IHX00P0000;A/[X00`000:eXP@000002000000FSJHl000000000002Y_NP01@000003XfN<00000000
00@000000jVmj00000000006000000GfXU@0002PIhl0002IH8`01P000006KdVD00000000bhjC0000
Y6Z>0P000003ZKgX0000000000@000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX
0000000000<000001:Vmj00000000:Vmj0D000000jVmj000000000050000191KS`<000000jVmj000
00000003000000BY_NP00000002Y_NP3000000?bUcX0002MI8d00YeTS@80000019IYW00000000?2B
<@800002ZFnA00@0002BH9@000000002JcMn00D0002AGY6AGY40002MIHl02`000003ZKgX00000000
00<000000jVmj00000000004000000FY_NP000000000002Y_NP010000003aUL00000000000H00000
1Nj@:@000;EjT@00095NTP0500000ZVmj0040000TEb@TEb@TEb@0`000003ZKgX0000000000<00000
0jVmj0000000000<000000BY_NP00000002Y_NP5000000>Y_NP00000000020000003ZKgX00000000
00800002001k00<0002CGHjCGHh00`000003ZKgX0000ZKgX00:Y_NP01000095LSi5LSi5LS`800002
Tf6D00<0002XL9<000000Y9OT@X000000jVmj0000000000:000000>Y_NP0000000000`000003ZKgX
00000000008000000jVmj00000000003000000>Y_NP0000000001P000003ZKgX0000000002Ooool0
023oool010000?ooo`00000008goool4000000FY_NP000000000002Y_NP01@000004ZKgX00000000
ZKgX1@000003j7lZ0000UUj<00>FGX`2000000>HI9800000000010000003ZKgX0000000000H00000
0jVmj00000000009000000?e/Wd0000000000`000003mK9n0000000000<000001oFbOP0000000000
0?FeQ0000?FbOP03000000Gi]gT000000000003e/Wd020000003mK9n0000000000;e/gl020000?Fe
Q00008=<QP000:9UR`000?2_Q@8000001<9nR00008I>QXI>QP<00002ZF^:0P000003aX>90000XVB8
008000000jiaS@000000000200000/R4R@<000001HI@R00000000>NFK`000002XfB70`000003k8Tc
0000j:XY00800002ZV^90P000003V62>0000h:<L00<00002YVN90`0000=T<gl00`0009mRRImRR@03
00000e`^OP8000000jMYRP000<N5R`0200000X==Q`070000SeJ80000XFF:0000i9n70000009]?8@0
1@0009eRR`0000000:MZR`0200000XiISP030000Y6^?Y6^?008000000jVmj00000000008000000>Y
_NP0002Y_NP01P000005ZKgX000000000000ZKgX008000000m6<R00000000002000000AX<g/00000
002Y_NP2000000NY_NP00000002Y_NP0003eWdl000000Y1FQ`800002?QAc2@0000:CFHP200001=>?
R@030000XVF:XVF:00800002dK:j00<0002]J84000000P000003XfV?00000000008000000jVmj000
00000002000000>SIh`0000000000P000004ZKgX00000000ZKgX1@000007ZKgX0000mZ9D0000X6N?
0000VF2<00H000001Vm9U00000000<^>T`000:AZSPD000000jVmj00000000008000000>Y_NP00000
00000`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000001`0000B@Fhl:
000000>Y_NP0000000000`000003lYLj0000WFB=00:MI8d01@0009IYW9IYW00007ZYl00300000ZU_
T@090000TV2D0000k8XT0000JcMn0000TEjA000000:MIHl00`000:Vmj0000004000000>Y_NP00000
00000`000003ZKgX00000000008000001JVmj000000000000:Vmj008000000>Y_NP0000000000`00
0003ZKgX00000000008000000nj@:@000;EjT@02000000>cNI@0000000000`000003ZKgX0000TEb@
00:AG9000`000:Vmj0000004000000>Y_NP00000000010000003ZKgX0000000000<000000jVmj000
00000002000000>Y_NP0000000000`000003ZKgX0000000000H000000jVmj0000000000600000P00
N`050000Tef>Tef>0000ZKgX00<00003ZKgX00@0002AG8nAG8nAG8l200000Y=QU0030000Z72C0000
00:BGi400`0009ARU@000003000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj000
00000002000000>Y_NP0000000000`000003ZKgX0000000000@000001JVmj000000000000:Vmj004
00009oooo`008?ooo`80002@oooo2P000005ZKgX000000000000ZKgX00D000001:Vmj0000>Qo:P00
00>FGX`00`0004hJK`000004000000>Y_NP0000000001`000004ZKgX00000000ZKgX1@000003ZKgX
0000000000<000000oFbO@0000000002000000?e/Wh0000000000`000005mK9n000000000000mKF4
00D000001OVgN@000?FbO@000?FbO@08000000Ce/Wh00000003e/gl2000000Oe]H@00023C8H0002R
IH/0003`[hD00P000004`Wj80000QTj6QTj60`0000:YJhX2000000?6PhT0002RI8P00P000003[W6=
00000000008000000lR4R@000?FbO@02000000F6D8P00000003WUVl000000Z=TQ`<000000nb9<`00
0>RZ:@0200000ZY[R@8000000iQPSP000>2S700300000ZIWR@<00003I3=o00<0002OHXVOHXT00`00
00=L;Wh2000000>WJHX00037QH/00P0000:3CHL01`0008mFR0000:5URP000>BOQ`000002KCb400<0
002MHX/000000P000005mK9m0000SUV>SUV>000000:TJhl3000000>Y_NP0000000000`000003ZKgX
0000000000P000000jVmj0000000000;000000EX<g/000000000002Y_NP01P000004mIm?0000T5J7
T5J70P00008n57<4000000>Y_NP0000000000P0000:CFHP200000m>?R@800002XVF:00<0002Y_NP0
00000]6b^P<00002XfV?2@000003XfN<0000ZKgX00<000000jVmj00000000003000000FY_NP00000
0000003fXU@00`000003VF2<0000000000@000001Vm9U00000000<^>T`000:AZSP<000000jVmj000
00000006000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj00000000008000000BY
_NP0000000000002T5^?0`000005ZKgX000000000000ZKgX00D00002TEf@0P000003lYLj0000WFB=
00:MI8d00`0009IYW9IYW003000000C`TS40002YKi6YKi43000000K/RR@0001[=gh0002AGY400002
WFF?1@000004ZKgX00000000ZKgX0P000004ZKgX00000000ZKgX3P000003ZKgX0000000000H00000
0jVmj00000000003000000BeNY400000002cNI@500000ZVmj0030000TEb@TEb@00X000000jVmj000
00000008000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj0000000000800000P00
N`030000Tef>Tef>00<000000jVmj0000:Vmj002ZKgX00@0002AG8nAG8nAG8l2000000FCHI@0002X
L9>XL9<000000Y9OT@030000U6:E000000h000000jVmj00000000003000000BY_NP00000002Y_NP5
000000>Y_NP0000000001P000003ZKgX0000000000H000000jVmj0000000000Voooo000Poooo00<0
003oooooool0T?ooo`D000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX00000000
008000000nQo:P0009INS002UUj<00<0001>6Vl000002`000005ZKgX000000000000ZKgX00D00000
1:Vmj00000000:Vmj0D000001OFbO@00000000000?FbOP06000000?e/Wh0000000001P000003nKMi
0000mK9m008000000oFbO@0000000005000000Ce/Wh0003e/goe/gl300000X=<QP040000XVF;0000
l:n50P000004`Wj80000QTj6QTj60P0000>YJhX2000000?6PhT0002RI8P00P000003[W6=00000000
008000000lR4R@000?FbO@0200000XI@R0030000iiI_000000:SI8L3000000C/RC<0003XZRT00003
ZV^90P000004V62>0000h:<Lh:<L0P0000:VIhT300000f@cO`040000Wf:90000bXN;0P0000=L;Wh2
000000>WJHX00037QH/00P0000:3CHL01`0008mFR0000:5URP000>BOQ`000002KCb400<0002MHX/0
00000P000005mK9m0000SUV>SUV>000000:TJhl:000000FY_NP000000000002Y_NP020000005ZKgX
000000000000ZKgX00H000000fPcN`0000000003000000>Y_NP0000000000P000004mIm?0000T5J7
T5J70P00008n57<8000000?eX500002CFHP00P0000?CShT200000Z9URP030000ZKgX000000;A/[X3
00000Z=YS`030000ZKgX000000H000000j=WS0000000000:000000BY_NP00000003fXU@200000YUP
S0030000ZKgX000000<000001Vm9U00000000<^>T`000:AZSPH000001JVmj000000000000:Vmj008
000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP00000
00001@0000:@Fhl00`000:Vmj00000080000195MT0800002lYLj00L0002MI8fMI8d0002FJI`0002Y
_NP00P000004l98a0000ZFnAZFnA1@000004JcMn0000TEjA00000YeUS`030000ZKgX000000<00000
0jVmj00000000003000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00X000000jVmj000
00000006000000>AGY80002cNI@00`000005ZKgX0000ZKgXZKgX000000:AG908000000>Y_NP00000
00001P000003ZKgX0000000000<000000jVmj00000000008000000>Y_NP0000000002P000005ZKgX
00000000001k000000:CGHh4000000FY_NP0002Y_NRY_NP000000i5LS`8000001I=QU0000:Q`TjQ`
T`000002TUnA00<0002DHYD000002P000003ZKgX0000000000P000000jVmj00000000003000000>Y
_NP00000000010000003ZKgX0000000000P000000jVmj0000000000300009Oooo`008?ooo`030000
oooooooo097oool2000000BY_NP00000002Y_NP:000000JY_NP000000000003XObX00003UUj<00D0
001>6Vl00000002Y_NP02P000003ZKgX0000000000<000001JVmj000000000000:Vmj008000000Ce
/Wd00000003e/Wh6000000?e/Wh0000000001P000004nKMi00000000mK9m0P000003mK9m00000000
00@000001?FbOP000?FcOoFcO`<00002Pdb600@0002RIH/0003`[hD2000000C2OXP00026CXJ6CXH2
00000jU[RP8000000lJ3R@000:9TR002000000>^LHd0000000000P000003b8B90000mK9m00800002
QU2800<0003WUVl000000Z=TQ`<000001>b9<`000>RZ:@0000>ZJhT2000000BHH8h0003PXacPXa`2
00000ZIWR@<00003I3=o00@0002OHXT0003:Qh/200000e`^OP050000YfV:YfV:0000ahF;00800002
Pdf70P0000:QIHX00`000>BOQ`000002KCb400<0002MHX/000000P000006mK9m0000SUV>SUV>0000
Y6^?1`000003ZKgX00000000008000000jVmj00000000007000000>Y_NP0000000002P000003J3=k
0000000000@000001ZVmj000000000000?FOC`0000:@EXL3000000<n57<0000000000`000006ZKgX
00000000mJ1@0000TeV80P0000?CShT200000Z9URP@000001=6b^P000000000000:SJHl5000000FY
_NP000000000002SIh`010000005ZKgX000000000000ZKgX00H000000oJRE00000000002VF2<1P00
0004KdVD0000000000000ZAZSP8000000jVmj00000000008000000FY_NP000000000002Y_NP00P00
0004UFRK00000000ZKgX0P000003ZKgX0000000000<000000jVmj00000000002000000FY_NP00000
0000002Y_NP00P000003T5^?0000000000<000001:Vmj0000000000000:Y_NP00`00095MT95MT002
TEf@0P0000;bUcX01@0009eTS@00000009IYW004000000C`TS40002YKi6YKi42000000>Y_NP0003/
RR@00P000004TEjA0000WFF?WFF?0P000003ZKgX0000000000<000000jVmj00000000008000000>Y
_NP0000000002P000003ZKgX0000000000<000000jVmj00000000004000000FAGY80002cNI@0002Y
_NP00`0000:Y_NP00`00095LT95LT004000000>Y_NP00000000020000003ZKgX0000000000<00000
1:Vmj00000000:Vmj0D000000jVmj0000000000<000000NY_NP00000002Y_NP0000007/000000Y=M
SPH00002ZKgX00@0002AG8nAG8nAG8l2000000FCHI@0002XL9>XL9<000000Y9OT@8000000i]UT@00
00000004000000>Y_NP00000000020000003ZKgX0000000000X000000jVmj00000000008000000>Y
_NP0000000000`000004ZKgX0000000000009Oooo`008?ooo`030000oooooooo09;oool2000000BY
_NP00000002Y_NP5000000>Y_NP0000000000P000005ZKgX00000000j7lZ000000>FGX`;000000>Y
_NP00000000010000005ZKgX000000000000ZKgX00D000000jVmj00000000004000000?e/Wd0003e
/Wh01P000003mK9n0000000000H000001?VgN@0000000?FbO@8000000oFbO@000000000600000_Fc
O`<00002Pdb600@0002RIH/0003`[hD2000000C2OXP00026CXJ6CXH200000jU[RP8000000lJ3R@00
0:9TR002000000>^LHd0000000000P000005b8B900000000ZKgX000000:6D8P00`000>NFK`000002
XfB700L0002<EHX0003/RC<0003XZRT000000jY[R@@00002h:<L00<0002VIhVVIhT0100000=T<gl0
100009mRR@000<Z7R`800003G2in00D0002WJHZWJHX00037QH/00P0000:3CHL200000Z5URP030000
i9n70000009]?8@00`0009eRR`000002000000Ce/Wd0002>FHh00002Y6^?1@000004ZKgX00000000
ZKgX1@000003ZKgX0000000000P000001JVmj000000000000:Vmj008000000>Y_NP0000000001@00
0004mIm?0000T5J7T5J70`000003?QAc0000000000H000000oFPD00009=IR00200000m>?R@800002
XVF:10000005dK:j000000000000XfV?008000000jVmj00000000002000000BY_NP00000002SIh`2
000000>Y_NP0000000001P000004ZKgX0000000000000_JRE0030000VF2<VF2<00X00002Y6Z>0`00
0003ZKgX0000000000<000000jVmj0000000000600000YEXV`@000001:Vmj00000000:Vmj0800000
1:Vmj00000000:Vmj0X000001I1KS`00000000000:Vmj00400000jVmj0030000TEf@TEf@00>AGI00
1@000?:G>_:G>P0009eTS@07000000C`TS40002YKi6YKi44000000G/RR@00000002AGY4000000YeU
S`@000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj000
00000008000000>Y_NP0000000000`000003TEjB0000/gVD00D00002ZKgX00<0002AG92AG9002`00
0003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX00000000
00H000001JVmj000000000000:Vmj004000000JY_NP000000000000007/00002Tef>10000005ZKgX
0000ZKgXZKgX000000>AG8l2000000FCHI@0002XL9>XL9<000000Y9OT@8000000i]UT@0000000002
000000>Y_NP0000000001P000003ZKgX0000000000`000000jVmj00000000006000000>Y_NP00000
00000`000003ZKgX0000000000H0000Toooo000Ooooo00<0003oooooool0U?ooo`8000000jVmj000
00000003000000BY_NP00000002Y_NP6000000?XObX0002FGX`00YINS0D000001JVmj00000000000
0:Vmj006000000BY_NP00000002IMJT5000000FY_NP000000000002Y_NP01P0000;e/Wh6000000?e
/Wh0000000001P000004nKMi00000000mK9m0`000003mK9m0000000000D00002mK=o0`0000:3C8H0
10000:9UR`000?2_Q@8000001<9nR00008I>QXI>QP800002ZF^:0`000004aX>90000XVB800000Zia
S@@000001<R4R@000000000000>6D8P00`000>NFK`000002XfB700L0002<EHX0003/RC<0003XZRT0
00000jY[R@@00002h:<L00<0002VIhVVIhT0100000=T<gl0100009mRR@000<Z7R`800003G2in00D0
002WJHZWJHX00037QH/00`000003Pdf70000000000:QIHX00`000>BOQ`000002KCb400T0002MHX/0
002WJX/0003e/Wd0002>FHh000000ZA[S`H000000jVmj00000000003000000BY_NP00000002Y_NP5
000000>Y_NP0000000000P000003ZKgX0000000000<00002YZ?B2`000003ZKgX0000000000:@EXL3
000000<n57<0000000001P000003mJ1@0000TeV800800003dhn90P0000:RIHX8000000FSJHl00000
0000002Y_NP01P000003XfN<0000000000<000001JVmj000000000000:Vmj00500000_JRE0030000
VF2<VF2<008000000jVmj0000000000500000ZAZSP030000ZKgX000000@000001:Vmj00000000:Vm
j0<00002ZKgX00@0002EJ9^EJ9^EJ9/5000000>Y_NP0000000000`000003ZKgX0000000000H00000
1JVmj00000000000091KS`0800000jVmj0030000TEf@TEf@00>AGI02000000?bUcX0002MI8d00`00
0003ZKgX0000000000<00002ZFnA10000005k8XT00000000TEjA000000:MIHl2000000BY_NP00000
002Y_NP500000Y5NT@T000001JVmj000000000000:Vmj002000000>Y_NP0000000002@000007ZKgX
000000000000TEjB0000/gVD008000001ZVmj000000000000:Vmj00000:AG9000`000:Vmj0000004
000000>Y_NP00000000020000003ZKgX0000000000X000001JVmj000000000000:Vmj006000000>Y
_NP0000000000`000004ZKgX0000001k00000Y=MSP@000000jVmj0000:Vmj002ZKgX00<0002AG8nA
G8l00P000005Tf6D0000Z72CZ72C000000:BGi42000000>KII40000000002@000003ZKgX00000000
00X000000jVmj00000000008000000>Y_NP0000000000`000003ZKgX0000000000H000000jVmj000
0000000Soooo000Ooooo00<0003oooooool0UOooo`@000001JVmj000000000000:Vmj008000000CX
ObX0002FGXbFGX`3000000FY_NP000000000002Y_NP01@000003ZKgX0000000000800002VGFY00D0
002=EHT00000002Y_NP030000003mK9n0000mK=o00H000001?FeQ00000000?FbOPL000001OFbO@00
000000000?FbO@0700000_FcO`030000mKF4000000:3C8H010000:9UR`000?2_Q@8000001<9nR000
08I>QXI>QP800002ZF^:0`000004aX>90000XVB800000ZiaS@@000001<R4R@000000000000>6D8P0
10000>NFK`000:=TQ`@000001>b9<`000>RZ:@0000>ZJhT400000^2S70030000YVN9YVN900@00003
I3=o00@0002OHXT0003:Qh/200000e`^OP050000YfV:YfV:0000ahF;00<000000h==Q`0000000002
XFF:00<0003TWhL000000VdlQ0090000WF:;0000YfZ;0000mK9m0000SUV>000000:TJhl9000000FY
_NP000000000002Y_NP020000003ZKgX0000000000<00002ZKgX10000003U6>G0000000000800000
1JVmj000000000000:Vmj004000000>@EXL0000000000P000003?QAc0000000000H000000oFPD000
09=IR00200000m>?R@800002XVF:20000003XfV?0000000000P000001J=WS000000000000:Vmj008
000000>Y_NP0000000000_JRE0030000VF2<VF2<00<000000jVmj00000000002000000C;SY<0002T
JXjTJXh8000000>Y_NP0000000000P0000>Y_NP00`0009EXViEXV`02000000>Y_NP0000000000`00
0003ZKgX0000000000P000000jVmj00000000006000000FY_NP000000000002Y_NP00P0000>Y_NP0
0`00095MT95MT002TEf@0P000003lYLj0000WFB=00T00002ZFnA100000;/RR@300000YeUS`<00000
0jVmj000000000030000195NT@D000000jVmj00000000006000000>Y_NP0000000000`000004ZKgX
00000000ZKgX0P000003ZKgX0000000000<000000i5NTP000;=iU006000000BY_NP0002AG92AG905
000000BY_NP00000002Y_NP5000000>Y_NP00000000030000003ZKgX0000000000H000000jVmj000
00000003000000>Y_NP0000000000`00008007/00`0009=MSY=MSP03000000>Y_NP0002Y_NP00ZVm
j0050000TEb?TEb?0000ZKgX00800002Z72C00<0002BGi6BGi400P000003VfFA0000ZKgX00D00000
0jVmj0000000000:000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj00000000004
000000>Y_NP0000000001P0002?oool001ooool00`000?ooooooo`2Goooo0`000003ZKgX00000000
00<000001jVmj000000000000:Vmj0000>Qo:P04000000>Y_NP0000000001P000004ZKgX00000000
00000ZVmj0040000VGFYVGFY00000XeER@T000000jVmj00000000003000000Ce/Wh00000003e/Wh6
000000?e]H@0003e/Wh01`000003mK9m00000000008000000oFbO`0000000004000000Ge/gl00000
003e]H@000000X=<QP040000XVF;0000l:n50P000004`Wj80000QTj6QTj60P0000:YJhX400000Z9T
R0030000[W6=[W6=00@000001<R4R@000000000000>6D8P010000>NFK`000:=TQ`@000001>b9<`00
0>RZ:@0000>ZJhT400000^2S70030000YVN9YVN900@00003I3=o00<0002OHXT000000`0000=L;Wh0
1@000:MYRZMYRP000<N5R`03000000>3CHL0000000000Z5URP030000i9n70000009]?8@02@0009eR
R`000:MZR`000?FbO@0008iISP000002Y6^?1@000003ZKgX0000000000P000001JVmj00000000000
0:Vmj00500000ZVmj0@00003U6>G1@000003ZKgX0000000000D000000i1FQ`000:Vmj002000000<n
57<0000000000`000006ZKgX00000000mJ1@0000TeV80P0000?CShT200000Z9URPP000000j=YS`00
00000004000000FY_NP000000000002SIh`01P000005ZKgX000000000000ZKgX00@00002mZ9D00<0
002IH8bIH8`020000004bhjC0000Y6Z>Y6Z>100000>FJId700000ZVmj0030000UFRKUFRK00T00000
0jVmj00000000003000000>Y_NP00000000020000003ZKgX0000000000H00003ZKgX00<0002AGI2A
GI000Y5MT08000000o:G>P0009eTS@04000000>Y_NP0000000000P0000:YKi4400000^b:90<00002
WFF?1P000003ZKgX0000TEjA00BAGY43000000>Y_NP00000000010000003ZKgX0000000000<00000
0jVmj00000000008000000>Y_NP0000000000P000003TEjB0000000000H000001ZVmj000095LT95L
T0000:Vmj0@000000jVmj00000000003000000>Y_NP0000000001P000005ZKgX000000000000ZKgX
00X000000jVmj00000000003000000>Y_NP0000000001@00008007/00`0009=MSY=MSP04000000FY
_NP0002Y_NRY_NP000000Y5LS`<00003Z72C00<0002BGi6BGi400P000005VfFA000000000000ZKgX
00h000001:Vmj00000000:Vmj0D000000jVmj00000000003000000>Y_NP0000000001P000003ZKgX
0000000000<000001:Vmj00000000:Vmj080000Roooo000Ooooo00<0003oooooool0V?ooo`D00000
1JVmj000000000000:Vmj00600000YINS0P000001JVmj00000000:Vmj0000003ZKgX00<0002IMJT0
00000heER@D000000jVmj00000000002000000>Y_NP0000000000P000005mK9n000000000000mK9n
00D000000oFeQ0000?FbOP02000000?e/Wd0000000000P000003mK9m00000000008000000oFbO`00
00000004000000Ge/gl00000003e]H@000000X=<QP030000XVF;000000<000001<9nR00008I>QXI>
QP800002ZF^:100000:RI8P00`000:iaSJiaS@04000000C8Q8T0000000000003QU2800@0003WUVl0
002SI8L4000000C/RC<0003XZRT00003ZV^9100000;PXa`00`000:IWRJIWR@0400000V@cO`030000
Wf:9Wf:900@00003G2in00<0002WJHZWJHX01@000003Pdf70000000000:QIHX00`000>BOQ`000002
KCb400@0002MHX/0002WJX/3000000B>FHh0002TJhnTJhl3000000BY_NP00000002Y_NP5000000>Y
_NP00000000020000003ZKgX0000000000800002W[W/0P0000:DHiL8000000>Y_NP0000000000`00
0006T5J700000000ZKgX0000?QAc0`000008ZKgX00000000ZKgX0000mJ1@0000TeV80P0000?CShT2
00000Z9URP<000000jVmj00000000002000000>SJHl0000000000P000004ZKgX00000000ZKgX0P00
0004XfN<00000000ZKgX2P000005ZKgX0000mZ9DmZ9D000000:IH8`3000000>Y_NP0000000000P00
0004bhjC0000Y6Z>Y6Z>0P0000BFJId5000000BY_NP0000000000002ZKgX1`000003ZKgX00000000
00<000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000X00003ZKgX00<0
002AGI2AGI000Y5MT08000000o:G>P0009eTS@02000000>Y_NP0000000000`000003l98a0000ZFnA
00@00002k8XT0P0000>MIHl010000:NTd`00000000>Y_NP00`00095NTI5NT@03TEjA1P000003ZKgX
0000000000P000000jVmj00000000003000000>Y_NP0000000001`000004/gVD00000000ZKgX1000
0004ZKgX0000TEb@TEb@0P000003ZKgX0000000000<000000jVmj00000000008000000>Y_NP00000
00002P000003ZKgX0000000000<000000jVmj00000000008000000BY_NP0000007/00002Tef>1000
0005ZKgX0000ZKgXZKgX000000:AG8l300000jQ`T`030000TUnATUnA008000000i]UT@000:Vmj002
000000>CHI<0000000001`000003ZKgX00000000008000000jVmj00000000003000000>Y_NP00000
00000`000003ZKgX0000000000@000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX
0000000000<0000Qoooo000Ooooo00@0003oool00000002Hoooo0P000004ZKgX00000000ZKgX1@00
0004ZKgX0000j7lZ00000YINS0@000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX
0000000000>=EHT3000000FY_NP000000000002Y_NP020000003mK9n00000000008000000oFbO@00
00000007000000?e/Wd0000000000P000003mK9m0000000000D000001OFbOP00000000000?FcO`04
000000B3C8H0002RIH^RIH/4000000G2OXP00026CXJ6CXH000000jU[RP@00002XVB800<0002^LHf^
LHd010000004b8B90000000000000hI@R0040000iiI_0000XfB710000004k8Tc0000j:XY00000ZY[
R@8000000iQPSP0000000002h:<L00<0002VIhVVIhT01000009T<gl00`0009mRRImRR@0400000e`^
OP030000YfV:YfV:00D000000h==Q`0000000002XFF:00<0003TWhL000000VdlQ0040000WF:;0000
YfZ;100000>TJhl4000000BY_NP00000002Y_NP2000000BY_NP00000002Y_NP5000000>Y_NP00000
00001@0000>N^N`0100009ASUiASUiASU`H000001:Vmj00000000:Vmj0@000000i1FQ`0000000002
000000<n57<0000000000P000007ZKgX000000000000mJ1@0000TeV800800003dhn90P0000:RIHX8
000000>SJHl0000000000`000006ZKgX00000000TV2D0000XfN<0`000003ZKgX0000000000<00000
0jVmj0000000000300000_JRE0030000VF2<VF2<00@000001ZVmj000000000000<^>T`0000:TJXh2
000019IYW@030000ZKgX000000L000000jVmj00000000003000000>Y_NP0000000000`000004ZKgX
00000000ZKgX1@000003ZKgX0000000000P000001ZVmj000000000000:Vmj00000>Y_NP00`00095M
T95MT002TEf@0P000003lYLj0000WFB=00D000001ZVmj00000000?2B<@000:U_T@D000000nb:9000
00000003WFF?100000>Y_NP00`00095NTI5NT@03TEjA10000003ZKgX0000000000H000000jVmj000
00000003000000>Y_NP0000000002`000003/gVD0000000000L00002TEb@10000003ZKgX00000000
008000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj000
00000002000000>Y_NP0000000000`000003ZKgX0000000000<000001000N`0009=MSY=MSP<00000
0jVmj00000000002ZKgX00H0002AG8nAG8l0001UAYP00002Z72C00D0002BGi6BGi6BGi4000000Y]U
T@800003Tf6C1@000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000002P00
0003ZKgX0000000000<000000jVmj00000000002000000>Y_NP0000000000`000004ZKgX00000000
00008Oooo`007oooo`80002Koooo0P000003ZKgX0000000000<000001ZVmj000000000000>Qo:P00
00:FGX`00`000:Vmj0000002000000>Y_NP0000000001P000003;8CZ0000000000B=EHT4000000FY
_NP000000000002Y_NP01@000003ZKgX0000000000D000000oFbOP0000000007000000Gi]gT00000
0000003e/Wd020000004mK9n00000000mK=o10000004Pdb60000XVF;XVF;1@0000>6CXH010000:U[
RZU[RZU[RP@00002XVB800<0002^LHd0000010000004b8B90000000000000hI@R0040000iiI_0000
XfB710000004k8Tc0000j:XY00000ZY[R@8000000iQPSP0000000002h:<L00<0002VIhVVIhT01000
009T<gl00`0009mRRImRR@0400000e`^OP030000YfV:YfV:00D000000h==Q`0000000002XFF:0`00
009]?8@0100009eRR`000:MZR`@00003Y6^?1@000003ZKgX0000000000<000001:Vmj00000000:Vm
j08000001:Vmj00000000:Vmj0<000001:Vmj0000000000000:N^N`00`0009ASUiASU`08000000BY
_NP00000002Y_NP3000000>@EXL0002Y_NP00P000003?QAc0000000000H000000oFPD00009=IR002
00000m>?R@800002XVF:20000003XfV?0000ZKgX00@00003TV2D00@0002SIh`0002Y_NP5000000BY
_NP00000002Y_NP400000_JRE0030000VF2<VF2<00P000001<^>T`000:AZSZAZSP800003UVVM0`00
0003ZKgX0000000000<000000jVmj0000000000<000000BY_NP00000002Y_NP2000000BY_NP00000
002Y_NP5000000>Y_NP0000000001P000005ZKgX0000ZKgXZKgX000000BAGI02000000?bUcX0002M
I8d020000003l98a0000ZFnA00D00002k8XT00T0002MIHnMIHnMIHl0002IKYl0002Y_NP000000ZVm
j0030000TEjATEjA00:AGY4<000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000003ZKgX
0000000000@000000k=iU0000000000700000Y5LT08000001:Vmj00000000:Vmj0D000000jVmj000
0000000B000000BY_NP00000002Y_NP5000000>Y_NP0000000001`000006001k0000Tef>Tef>0000
ZKgX100000:Y_NP01P00095LSi5LS`0006E6V00000:XL9<01@00099OTI9OTI9OT@000002VfFA00<0
002CHI>CHI<00Y=QT`<000001:Vmj00000000:Vmj0D000000jVmj0000000000<000000>Y_NP00000
00000`000004ZKgX00000000ZKgX1@000003ZKgX0000000000H0000Poooo000Noooo00<0003ooooo
ool0W?ooo`P000000jVmj0000000000200000YINS08000001JVmj000000000000:Vmj005000000FY
_NP0000/Q>X/Q>X0000018eER@8000001:Vmj00000000:Vmj0D000001:Vmj0000000000000><EX`5
000000?e/Wh0000000001P000005nKMi0000mK9m0000mK9m00P000001?FbOP0000000?FcO`@00000
1H=<QP000:9UR`000?2_Q@0400000hI>QP040000ZF^:ZF^:ZF^:0P000003aX>90000XVB800800000
0jiaS@000000000200000/R4R@<00003QU2800@0003WUVl0002SI8L4000000C/RC<0003XZRT00002
ZV^90`000005Z6f>0000h:<Lh:<L000000:VIhT400000V@cO`030000Wf:9Wf:900@00003G2in00@0
002WJHX00037QH/3000000CQSFd0000000000002XFF:0`00009]?8@0100009eRR`000:MZR`@00003
Y6^?1`000003ZKgX00000000008000000jVmj00000000006000000>Y_NP000000000100000:N^N`0
0`0009ASUiASU`09000000>Y_NP0000000000`000004T5J700000000ZKgX0`000003n;=f0000ZKgX
00@000000oFPD00009=IR00200000m>?R@800002XVF:20000003XfV?0000000000:Y_NP01000099P
U99PU99PU08000001J=WS000000000000:Vmj004000000>Y_NP000000000100000;fXU@00`0009UP
S9UPS003000000>Y_NP0000000000P000008bhjC0000Y6Z>Y6Z>0000ZKgX0000UVVM0P000003ZKgX
0000000000<000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj004000000>Y_NP00000
00000`000003ZKgX0000000000<000001:Vmj00000000:Vmj0<000000jVmj0000000000300000ZVm
j0030000TEf@TEf@00>AGI0010000?:G>P0009eTS@X000000jU_T@000:Vmj00300000^b:90040000
WFF?WFF?WFF?1@0000>Y_NP01000095NTI5NTI5NT@@000001JVmj000000000000:Vmj005000000>Y
_NP0000000000P000003ZKgX0000000000<000000jVmj00000000006000000FcNI@000000000002Y
_NP010000003ZKgX0000TEb@00<000000jVmj00000000003000000>Y_NP0000000001P000005ZKgX
000000000000ZKgX00X000000jVmj00000000003000000>Y_NP0000000001P000005ZKgX00000000
001k000000:CGHh2000000BY_NP0000000000002ZKgX00H0002AG8nAG8l0001UAYP00002Z72C00D0
002BGi6BGi6BGi4000000Y]UT@030000Tf6CTf6C00:CHI<4000000>Y_NP0000000000`000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX0000000000<00000
0jVmj0000000000800008?ooo`007_ooo`030000oooooooo09Woool3000000Goool000000000002Y
_NP010000007ZKgX000000000000UUj<0000ZKgX008000000jVmj00000000003000000>Y_NP00000
00000P00008/Q>X00`0008eERHeER@02SEF90`000003ZKgX0000000000<000001:Vmj00000000000
00F<EX`5000000?e/Wh0000000001P000003nKMi0000mK9m008000000oFbO@0000000005000000Ce
/Wh0003e/goe/gl4000000F3C8H0002RIH/0003`[hD0100000>6CXH010000:U[RZU[RZU[RP800000
0lJ3R@000:9TR002000000>^LHd0000000000P0000;8Q8T300000hI@R0040000iiI_0000XfB71000
0004k8Tc0000j:XY00000ZY[R@<000001JQ]SP000>2S7>2S70000002YVN90`000004ZKgX0000I3=o
00000YmRR@@00003G2in00@0002WJHX00037QH/3000000CQSFd0000000000002XFF:0`00009]?8@0
100009eRR`000:MZR`@00002Y6^?00<0002QIXd000000P000005ZKgX000000000000ZKgX00D00000
0jVmj00000000002000000>Y_NP0000000000`000007ZKgX000000000000W[W/0000U6>G00800000
1JVmj000000000000:Vmj005000000FY_NP000000000002@EXL03@000003mJ1@0000000000800002
dhn900<0001_>Wl000000Z9URPL00002XfV?00D0002Y_NRY_NRY_NP000000i9PU08000000j=WS000
00000002000000>Y_NP0000000000`000003ZKgX0000000000800002mZ9D00D0002IH8bIH8`0002Y
_NP01P000006bhjC0000Y6Z>Y6Z>0000ZKgX2`000003ZKgX0000000000<000000jVmj00000000004
000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj0000000000900000ZVmj0030000
TEf@TEf@00>AGI0010000?:G>P0009eTS@H000001JVmj000000000000:U_T@0500000^b:90040000
WFF?WFF?WFF?0`000003ZKgX0000ZKgX00:Y_NP01000095NTI5NTI5NT@8000000jVmj0000000000:
000000>Y_NP0000000000`000003ZKgX0000000000X000000k=iU00000000006000000>Y_NP0002A
G9001@000003ZKgX0000000000@000001JVmj000000000000:Vmj00<000000>Y_NP0000000002P00
0005ZKgX000000000000ZKgX00@000001000N`0009=MSY=MSP@000001JVmj00000000:Vmj0000002
TEb?00<0001UAYP000000ZQ`T`050000TUnATUnATUnA000000:KII400`0009=QTi=QT`02Tf6C1P00
0003ZKgX0000000000X000000jVmj00000000008000000>Y_NP0000000000`000003ZKgX00000000
00X000000jVmj0000000000Ooooo000Noooo00<0003oooooool0Uoooo`800005oooo0`000003ZKgX
0000000000D0000019INS00000000:Vmj0D000001:Vmj00000000:Vmj0<00002;8CZ00<0002=EHV=
EHT00XeER@030000TV>H000000L00002ZKgX00<0002<EXb<EX`00haFS0H000000oFeQ00000000005
000000Ki]gT00000003e/Wd0003e/Wd900000_FcO`@000001H=<QP000:9UR`000?2_Q@0400000hI>
QP040000ZF^:ZF^:ZF^:0P000003aX>90000XVB8008000000jiaS@000000000200000/R4R@<00003
QU2800@0003WUVl0002SI8L4000000C/RC<0003XZRT00002ZV^90`000005Z6f>0000h:<Lh:<L0000
00:VIhT5000000AT<gl0002OHXVOHXT2000000>PIXd0001L;Wh00U`^OP040000YfV:0000ahF;0`00
0004hHe]0000000000000Z5URP<00002KCb400@0002MHX/0002WJX/300000jA[S`030000XFJ=0000
00T000001JVmj000000000000:Vmj005000000>Y_NP0000000001@000003W[W/0000U6>G00T00000
1JVmj000000000000:Vmj002000000B@EXL00000002Y_NP?00000]>?R@030000KcYo000000:RIHX0
0`000:Vmj000000400000Z=YS`050000ZKgXZKgXZKgX000000>BH9@2000000>SIh`0000000002@00
0003ZKgX00000000008000001?JRE00009UPS9UPS0@000000jVmj0000000000200000jAZSPT00000
0jVmj0000000000:000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj0000000000:
000000>Y_NP0000000000ZVmj0030000TEf@TEf@00>AGI0010000?:G>P0009eTS@8000000jVmj000
0000000;00000^b:90040000WFF?WFF?WFF?1@0000>Y_NP01000095NTI5NTI5NT@/000000jVmj000
00000003000000>Y_NP0000000000P000003ZKgX0000000000<000000jVmj00000000003000000>c
NI@00000000010000007ZKgX0000ZKgX0000TEb@0000ZKgX00@000001JVmj000000000000:Vmj008
000000>Y_NP0000000000`000003ZKgX0000000000P000001JVmj000000000000:Vmj008000000BY
_NP0000007/00002Tef>1`0000:Y_NP00`00095LS`000002IDJH00<0002XL9<000000Y9OT@800002
VfFA0P0000>CHI<200000Y=OTPd000000jVmj00000000006000000>Y_NP0000000000`000003ZKgX
0000000000`000000jVmj0000000000300007_ooo`007_ooo`030000oooooooo09Coool300002?oo
o`D000000jVmj00000000002000000>FGX`0000000001`000006ZKgX000000000000S5F;00000Rb4
jP030000SEF9SEF900:=EHT6000000BY_NP0000000000002ZKgX00<0002<EXb<EX`00XaFS0030000
hjVG000000D000000oFeQ00000000004000000Ci]gT00000003e/Wd2000000?e/Wd0000000001P00
0004mK=o00000000mKF40P000005Pdb60000XVF;0000l:n500@00003QTj600@0002YJhZYJhZYJhX2
000000?6PhT0002RI8P00P000003[W6=00000000008000000lR4R@000?FbO@0200000hI@R0040000
iiI_0000XfB710000004k8Tc0000j:XY00000ZY[R@<000001JQ]SP000>2S7>2S70000002YVN91@00
0004I3=o0000Wf:9Wf:90P000003X6J=0000G2in009L;Wh010000:MYRP000<N5R`<000001>6=K@00
0000000000:QIHX300000VdlQ0040000WF:;0000YfZ;0`0000>TJhl00`000:5VS@000007000000>Y
_NP0000000002P000003ZKgX0000000000<000000jVmj00000000008000000>Y_NP0000000001P00
0005T5J7000000000000ZKgX00D000000jVmj0000000000600000]>?R@030000KcYo000000:RIHX7
00000Z=YS`800002ZKgX00@0002BH9BBH9BBH9@2000000>SIh`0002Y_NP01@000003ZKgX00000000
00H000001?JRE00009UPS9UPS08000000jVmj0000000000400000jAZSPD000000jVmj00000000002
000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00P00002U6JJ10000003ZKgX00000000
00P000001JVmj000000000000:Vmj005000000>Y_NP0002AGI00195MT0<000000ieTS@000000000;
000000>Y_NP0000000000^b:90040000WFF?WFF?WFF?1P0000:Y_NP01000095NTI5NTI5NT@D00000
1JVmj000000000000:Vmj005000000BY_NP00000002Y_NP5000000>Y_NP0000000001`000003/gVD
00000000008000001:Vmj00000000:Vmj0800000195LT00000000:Vmj0h000000jVmj00000000003
000000BY_NP00000002Y_NP5000000>Y_NP00000000030000003ZKgX0000000000<00002Tef>1`00
00:Y_NP01`00095LS`00000006E6V0000:Q`T`02000000>BGi40000000000Y]UT@800002Tf6C00<0
002fO9@000000Y=OTPT000000jVmj00000000008000000>Y_NP0000000000`000003ZKgX00000000
00X000000jVmj0000000000700007_ooo`007_ooo`030000oooooooo097oool300003?ooo`800000
1:Vmj00000000:Vmj0<000000iINS0000:Vmj003000000>Y_NP0000000000P0000:Y_NP00`0008aE
R`000002;8CZ00@0002=EHV=EHV=EHT4000000>?GY<000000000100000:Y_NP00`0008aFS8aFS002
S5J<2P000003mK9n00000000008000001?VgN@0000000?FbO@<000000oFbO@0000000005000000Ce
/gl00000003e]H@2000000F3C8H0002RIH/0003`[hD00P000003`Wj80000QTj600:6CXH010000:U[
RZU[RZU[RP8000001<J3R@000:9TR00000:^LHd4000000?8Q8T0003e/Wd00P0000>6D8P010000>NF
K`000:=TQ`@000001>b9<`000>RZ:@0000:ZJhT3000000FXKHh0003PXacPXa`000000ZIWR@D00000
16@cO`0009mRRImRR@8000000j1VS@0005`^OP02G2in00@0002WJHX00037QH/3000000?QSFd00000
00000j5URP<00002KCb400@0002MHX/0002WJX/300000jA[S`030000XFJ=000000<000000jVmj000
0000000X000000>@EXL00000000020000003ZKgX0000000000@00003dhn900<0001_>Wl000000Z9U
RP@000000jVmj00000000002XfV?0P0000:Y_NP00`00099PU99PU003000000>SIh`0000000000`00
0004ZKgX00000000ZKgX1@000004ZKgX0000mZ9D00000YUPS0D000001:Vmj0000000000000>TJXh3
000000BY_NP00000002Y_NP5000000>Y_NP00000000020000004ZKgX0000000000000iAVVP<00000
1:Vmj00000000:Vmj0D000000jVmj0000000000;000000>Y_NP0002AGI00195MT0<000000ieTS@00
00000003000000>Y_NP0000000002@000003k8XT0000WFF?00:MIHl4000000FY_NP0002Y_NRY_NP0
00000i5NTA0000000jVmj00000000003000000BY_NP00000002Y_NP5000000BY_NP00000002cNI@5
000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP00000
00000P000003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000`000004ZKgX
0000000000000Y=MSPD000001ZVmj0000:Vmj:Vmj000095LS`8000000fE6V0000:Q`T`02000000>B
Gi40002KII400Y]UT@800002Tf6C00<0002fO9@000000Y=OTPD000000jVmj00000000008000000>Y
_NP0000000000`000003ZKgX0000000000X000000jVmj00000000008000000BY_NP000000000000M
oooo000Noooo00<0003oooooool0S_ooo`<0000@oooo0P000003ZKgX0000000000800002UUj<0P00
0003ZKgX0000000000<000001jVmj0000:Vmj:Vmj00008aER`000002;8CZ00@0002=EHV=EHV=EHT2
00000hmNT`<000000jVmj00000000002ZKgX00<0002<EXb<EX`00XaFS0<000000jVmj0000:EYS004
000000?e/Wh0000000001@000005mK9m000000000000mK9m00L000000oFcO`0000000003000000F3
C8H0002RIH/0003`[hD00P000003`Wj80000QTj600:6CXH010000:U[RZU[RZU[RP8000001<J3R@00
0:9TR00000:^LHd4000000G8Q8T00000002Y_NP000000hI@R0040000iiI_0000XfB710000004k8Tc
0000j:XY00000ZY[R@<000001JQ]SP000>2S7>2S70000002YVN91@000004I3=o0000Wf:9Wf:90P00
0003X6J=0000G2in009L;Wh010000:MYRP000<N5R`<000000n6=K@0000000003XFF:0`00009]?8@0
100009eRR`000:MZR`<00003Y6^?1`000003ZKgX0000000000<000001JVmj000000000000:Vmj008
000000>Y_NP0000000003P000003ZKgX0000000000<000000i1FQ`000000000:000000>Y_NP00000
00000P0000?CShT00`0006ljO`000002XVF:0P000003ZKgX0000000000800002XfV?0`000004ZKgX
0000TV2DTV2D1P000005ZKgX000000000000ZKgX00D000001ZVmj000000000000?JRE00000:IH8`0
0`000:Vmj0000004000000?5Ngh0002TJXh00ZAZSP@000000jVmj00000000003000000BY_NP00000
002Y_NP5000000>Y_NP0000000000P000003ZKgX0000U6JJ00>DIYX4000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX00800002ZKgX00<0002AGI2AGI000Y5M
T0<000001IeTS@00000000000:Vmj008000000>Y_NP0000000000P000003k8XT0000WFF?00:MIHl6
00000ZVmj0040000TEjATEjATEjA20000005U6>F000000000000ZKgX00D000000jVmj00000000002
000000>Y_NP0000000000`000003ZKgX00000000008000000k=iU0000:Vmj005000000>Y_NP00000
00002P000003ZKgX0000000000P000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX
0000000000<000000jVmj00000000002000000NY_NP0000007/0002CGHh0002Y_NP01@0000:Y_NP0
1`00095LS`00000006E6V0000:Q`T`02000000>BGi40002KII400Y]UT@800002Tf6C00<0002fO9@0
00000Y=OTP<000000jVmj00000000006000000>Y_NP0000000000`000003ZKgX0000000000`00000
0jVmj00000000006000000>Y_NP0000000000`000003ZKgX0000000001coool001goool00`000?oo
ooooo`2<oooo0`0001Coool4000000FY_NP0002FGX`0002Y_NP01@000004ZKgX0000000000000ZVm
j0050000S5F;0000;8CZ000000B=EHT200000XmNT`030000ZKgX0000008000001JVmj0000:Vmj:Vm
j0000004S5J<1@000003YFV<0000000000<000000oFcP@0000000004000000?e/Wd0000000000P00
0003mK9o0000000000@000000oFcO`000000000400000Z9UR`060000l:n500000000`Wj800000hI>
QP040000ZF^:ZF^:ZF^:0P000004aX>90000XVB800000ZiaS@050000V5j;00000000b8B900800000
0jVmj00008I@R002QU2800@0003WUVl0002SI8L4000000C/RC<0003XZRT00002ZV^90P0000:XKHh0
10000>2S7>2S700000:VIhT5000000QT<gl0002OHXT0003:Qh/0002PIXd00003G2in00@0002WJHX0
0037QH/300000^6=K@050000XFF:XFF:0000i9n700800002KCb40P0000:WJX/300000jA[S`<00000
0jVmj00000000008000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00P000000jVmj000
00000003000000>Y_NP0000000000P000003ZKgX00000000008000000i1FQ`0000000008000000>Y
_NP000000000100000?CShT00`0006ljO`000002XVF:0`000004ZKgX0000000000000Z=YS`<00002
ZKgX00<0002BH9@0000040000005ZKgX00000000mZ9D000000:IH8`2000000>Y_NP0000000000P00
0003aG]n0000Y6Z>00:TJXh;000000>Y_NP0000000000`000003ZKgX0000000000800003ZKgX00@0
002DIYZDIYZDIYX2000000>SKY@0000000000P000003ZKgX00000000008000000jVmj00000000003
000000>Y_NP0000000001P0000:Y_NP01P00095MT95MT95MT0000006S`8000000ieTS@000000000?
000000?/RR@0002MIHl00YeUS`030000ZKgX000000<00002ZKgX00@0002AGY6AGY6AGY4600000iAS
UPX000000jVmj0000000000<000000FcNI@000000000002Y_NP02P000005ZKgX000000000000ZKgX
00P000000jVmj00000000003000000>Y_NP00000000030000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000000`00N`0009=MSP08000000FY_NP0002AG8l0002Y_NP00P000005Z72C00000000
TUnA000000>KII4200000Y=QT`030000]WbD000000:CGi8:000000>Y_NP0000000000`000003ZKgX
0000000000X000000jVmj00000000008000000>Y_NP0000000000`000003ZKgX000000000080000L
oooo000Moooo00@0003oooooooooool20000Q_ooo`<0000Hoooo1@000003UUj<0000000000800000
1JVmj000000000000:Vmj00200000ZVmj0050000S5F;0000;8CZ000000B=EHT0100008mNThmNThmN
T`8000000jVmj0000000000200000ZVmj0040000S5J<S5J<S5J<1P000003YFV<0000YFV<00D00000
0oFbO@0000000002000000?e/Wd0000000000`000003mK=o0000000000<000000oFcO`0000000004
00000Z9UR`060000l:n500000000`Wj800000hI>QP040000ZF^:ZF^:ZF^:0P000004aX>90000XVB8
00000ZiaS@050000V5j;00000000b8B9008000000jVmj00008I@R002QU2800@0003WUVl0002SI8L4
000000C/RC<0003XZRT00002ZV^90P0000:XKHh010000>2S7>2S700000:VIhT5000000QT<gl0002O
HXT0003:Qh/0002PIXd00003G2in00@0002WJHX00037QH/300000^6=K@050000XFF:XFF:0000i9n7
00800002KCb40P0000:WJX/300000jA[S`X000000jVmj00000000003000000>Y_NP0000000000P00
0003ZKgX0000000000<000001JVmj000000000000:Vmj008000000>Y_NP0000000000`000004ZKgX
00000000T5J71`000005ZKgX000000000000ZKgX00D00003dhn900@0001_>Wl0002RIHX800000Z=Y
S`050000ZKgX00000000ZKgX008000000jVmj00000000006000000FY_NP000000000002Y_NP01P00
0004mZ9D0000VF2<VF2<1`000003aG]n0000Y6Z>00:TJXh3000000FY_NP000000000002Y_NP01@00
0003ZKgX0000000000L00002ZKgX00@0002DIYZDIYZDIYX2000000>SKY@0000000000`000003ZKgX
0000000000<000000jVmj0000000000;000000>Y_NP0002AGI000Y5MT005000000J?00000000WFB=
00H00003Tf:F100000:CHiH200000^b:90030000WFF?WFF?00<000001ZVmj000000000000:Vmj000
00>AGY4200000ZVmj0050000U6>FU6>FU6>F000000:CHYD4000000>Y_NP00000000030000003ZKgX
0000000000<000001:Vmj00000000:Vmj1@000000jVmj00000000003000000>Y_NP0000000001P00
0005ZKgX000000000000ZKgX00X000000jVmj00000000003000000FY_NP0000007/0002CGHh02000
0003ZKgX0000TEb?00<000001VE6V00000000000099OT@0000>KII4200000Y=QT`030000]WbD0000
00:CGi86000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj00000000008000000>Y
_NP0000000000`000003ZKgX0000000000@000000jVmj0000000000Koooo000Moooo00@0003oool0
00000025oooo0`0001coool4000000>FGX`0000000000`000003ZKgX0000000000<00002ZKgX00D0
002<EH/0000/Q>X0000018eER@030000SejCSejC00D000000jVmj00000000002ZKgX00P0002<EXb<
EXb<EX`0003SZIL0002PRkd200000jEYS0D000000oFbO@0000000002000000?e/Wd0000000001@00
0005mK9n000000000000mK=o00H00002XVF;00H0003`[hD000000032OXP00003QTj600@0002YJhZY
JhZYJhX300000Z9TR0050000[W6=[W6=0000V5j;008000001LR4R@0000000:Vmj0000002QU280P00
0003iiI_00000000008000001ZVmj0000>b9<`000>RZ:@0000:ZJhT200000ZQ]SP050000h:<Lh:<L
0000YVN900H000001f@cO`0009mRR@000<Z7R`000:1VS@0200000U`^OP040000YfV:0000ahF;0`00
00;QSFd01@000:5URZ5URP000>BOQ`02000000A]?8@0002MHX/00002YfZ;0`0000>TJhl4000000FY
_NP000000000002Y_NP01@000004ZKgX00000000ZKgX1@000003ZKgX00000000008000000jVmj000
00000003000000>Y_NP0000000001`000003ZKgX00000000008000001I1FQ`00000000000:Vmj008
000000>Y_NP0000000000P0000?CShT0100006ljO`000:9URP<000000jVmj0000000000200000Z=Y
S`@000001JVmj000000000000:Vmj005000000>Y_NP0000000001P000006ZKgX000000000000mZ9D
00000YUPS08000000jVmj00000000002000000C5Ngh0002TJXjTJXh2000000>Y_NP0000000002P00
0003ZKgX0000000000<00002ZKgX00@0002Y_NRY_NP00002U6JJ00@0002kRZ<0002SKY@<000000>Y
_NP0000000000`000005ZKgX000000000000ZKgX008000000jVmj000095MT002TEf@00@000001Xl0
003bUcX3000000>Y_NP0002CHYH019=RUP800004Tf>F0P0000;/RR@01@0009eUSieUS`000:Vmj002
000000FY_NP00000002Y_NP000000i5NT@800002ZKgX00D0002DHiJDHiJDHiH000000Y=RU@800000
1:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj00:000000>Y_NP0000000000`000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP00000000020000003ZKgX0000000000X00000
0jVmj00000000003000000>Y_NP0000000000`000003001k0000Tef>00@000001jVmj00000000000
0:Vmj000095LS`03000000IUAYP000000000002BGi400003VfFA0P0000:CHI<00`000;IlU0000002
TenB0P000003ZKgX0000000000<000000jVmj00000000008000000FY_NP000000000002Y_NP02000
0003ZKgX0000000000<000000jVmj00000000006000000>Y_NP0000000000`0001[oool001goool2
0000Q?ooo`<0000Poooo0`000003UUj<0000ZKgX00T00002ZKgX00D0002<EH/0000/Q>X0000018eE
R@030000SejCSejC00<00003ZKgX0P0000:Y_NP01P0008aFS8aFS8aFS0000>>YU`<00004YFV<00<0
002NH8L000000`000005nKMi000000000000mK9m00P000001?FbOP0000000?FcO`H00002XVF;00H0
003`[hD000000032OXP00003QTj600@0002YJhZYJhZYJhX300000Z9TR0050000[W6=[W6=0000V5j;
008000001LR4R@0000000:Vmj0000002QU280P000003iiI_0000000000@000001>b9<`000>RZ:@00
00:ZJhT200000ZQ]SP050000h:<Lh:<L0000YVN900H000001f@cO`0009mRR@000<Z7R`000:1VS@02
00000U`^OP040000YfV:0000ahF;0`0000;QSFd01@000:5URZ5URP000>BOQ`02000000A]?8@0002M
HX/00002YfZ;0`0000>TJhl5000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00D00000
1:Vmj00000000:Vmj0D000000jVmj00000000008000000FY_NP000000000002Y_NP00`000003T5J7
0000ZKgX008000001JVmj000000000000:Vmj00800000m>?R@060000KcYo0000XVF:0000ZKgX1P00
0003XfV?0000ZKgX01@000000jVmj00000000003000000CfXU@0002IH8bIH8`3000000JY_NP00000
00000035Ngh00002Y6Z>2`000003ZKgX0000000000H00003ZKgX0P0000:Y_NP01`0009AVVP000000
0:=^U0000;1fT`07000000>Y_NP0000000000`000003ZKgX0000000000P000000jVmj000095MT002
TEf@00@000001Xl0003bUcX200000ZVmj0030000Tf:FTf:F00:CHYH300000i=SUP<00002k8XT00<0
002MIHl000000P000003ZKgX0000000000800002ZKgX00D0002AGY40002JHhl000000ZVmj0050000
U6>FU6>FU6>F000000:CHYD3000000>Y_NP0000000000`000003ZKgX00000000010000000jVmj000
0000000:000000>Y_NP00000000020000003ZKgX0000000000<000000jVmj0000000000:000000>Y
_NP0000000000`000003ZKgX0000000000T0000019=MSP0000000:Vmj0D000000jVmj000095LS`07
000000>BGi40002KII400Y]UT@800002Tf6C00<0002fO9@000000Y=OTPH000001:Vmj00000000:Vm
j0D000000jVmj0000000000<000000>Y_NP0000000000`000003ZKgX0000000000@000000jVmj000
00000003000000BY_NP000000000000Joooo000Moooo00<0003oooooool0POooo`80000Toooo0P00
0003UUj<0000000000H000000jVmj00000000002ZKgX00D0002<EH/0000/Q>X000000heER@800002
SejC0`0000>Y_NP01@0008eHS@000:Vmj0000003S5J<1@0000BUJH`00`0009iPQ`000005000000?e
/Wd0003e/Wd020000003mK9n00000000008000000oFeQ0000000000200000Z9UR`060000l:n50000
0000`Wj800000hI>QP040000ZF^:ZF^:ZF^:0`0000:RI8P01@000:iaSJiaS@0009QNR`02000000G8
Q8T00000002Y_NP000000XI@R0<000000j=TQ`0000000003000000C/RC<0003XZRT00002ZV^90P00
00:XKHh01@000>2S7>2S70000:IWR@06000000MT<gl0002OHXT0003:Qh/0002PIXd00P00009L;Wh0
10000:MYRP000<N5R`<00002hHe]00D0002QIHZQIHX0003TWhL00P000007KCb40000WF:;0000YfZ;
0000mK9m00800002Y6^?00<0002QIXd000001@000003ZKgX0000000000P000001JVmj00000000000
0:Vmj005000000BY_NP00000002KNJ`A000000B@EXL00000002Y_NP8000000>Y_NP0000000000`00
00?CShT0100006ljO`000:9URPP000000j=YS`000000000:000000>Y_NP0000000000`000003ZKgX
0000000000L000001?JRE00009UPS9UPS0D000001:Vmj0000000000000:TJXh5000000FY_NP00000
0000002Y_NP020000003ZKgX0000000000:Y_NP0100007I>U@000:Vmj08000001K^:X`000:=^U000
0;1fT`05000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000006ZKgX000000000000ZKgX
00000Y5MT08000000`06S`000?:G>P0200000ZVmj0030000Tf:FTf:F00:CHYH300000i=SUP<00002
k8XT00<0002MIHl000001000000:ZKgX0000lI@d0000ZKgX0000TEjA0000VV>?00000ZVmj0060000
U6>FU6>FU6>F0000Tf:E1P000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP00000
00000P000003ZKgX0000000000<000001JVmj000000000000:Vmj008000000>Y_NP0000000000`00
0003ZKgX00000000018000001:Vmj00000000:Vmj0D000000jVmj00000000002000000>CGHh00000
00001P000003ZKgX0000TEb?00H000001:Vmj0000000000000:KII401`000:Vmj00009=QT`000;Il
U0000002TenB0P000003ZKgX00000000008000000jVmj00000000003000000>Y_NP0000000002P00
0003ZKgX0000000000X000000jVmj00000000003000000>Y_NP0000000001P0001Woool001goool0
0`000?ooooooo`1noooo0`0002Ooool01@0009INS00000000:Vmj003000000>Y_NP0000000000P00
0007ZKgX0000S5F;S5F;0000;8CZ000000>=EHT2000000F?GY<00000002Y_NP000000jVmj0050000
SER=0000ZKgX000000><EX`3000000>Y_NP0002UJH`00jEYS0030000WV27000000D000000oFbO@00
0?FbO@0:000000Ce/gl00000003e]H@4000000>RIH/0003`[hD01@0000>6CXH010000:U[RZU[RZU[
RP<00002XVB800D0002^LHd00000002HGX/00P000005b8B900000000ZKgX000000:6D8P3000000>S
I8L0000000000`000004k8Tc0000j:XY00000ZY[R@8000000jQ]SP0000000002h:<L00<0002VIhT0
00001@000007I3=o0000Wf:90000bXN;0000X6J=00800002G2in00@0002WJHX00037QH/300000^6=
K@050000XFF:XFF:0000i9n7008000001fdlQ00009eRR`000:MZR`000?FbO@0200000ZA[S`030000
XFJ=000000<000001:Vmj000000009QbY@D000000jVmj0000000000<00000Y]i[0050000TUj@0000
0000ZKgX00P000000jVmj00000000002000000F@EXL000000000002Y_NP01@000003ZKgX00000000
00D00003dhn900@0001_>Wl0002RIHX4000000FY_NP000000000002SJHl020000003ZKgX00000000
00P000000jVmj00000000003000000FY_NP00000003fXU@000000YUPS0<000001:Vmj00000000:Vm
j0800002Y6Z>00<0002Y_NP000002@000005ZKgX000000000000ZKgX00@00002ZKgX00<0001fCYD0
00000`000005^hZS0000XfjD0000/7JC00`000000jVmj00000000003000000>Y_NP0000000001@00
00:AGI02000000<01Xl0003bUcX00P0000>Y_NP0100009=RUY=RUY=RUP<00003Tf>F10000003k8XT
0000WFF?00H000002JVmj00000000:Vmj000095NT@0009YSS`000002ZKgX00@0002DHiJDHiH00002
Tf:E3@000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vmj0D000000jVmj0000000000<
000000>Y_NP0000000000`000003ZKgX0000000000H000001JVmj000000000000:Vmj00:000000>Y
_NP0000000000`000003ZKgX0000000000@000000i=MSP0000000003000000FY_NP000000000002Y
_NP02`0000:KII401`000:Vmj00009=QT`000;IlU0000002TenB0`000003ZKgX0000000000<00000
0jVmj0000000000:000000>Y_NP00000000030000003ZKgX0000000000<000001:Vmj00000000:Vm
j0D000000oooo`000?ooo`0Hoooo000Loooo00<0003oooooool0O?ooo`<0000Zoooo1@000003ZKgX
0000000000<000001:Vmj0000:Vmj00000:<EH/00`0002b4jP000003SEF90P000003SejC00000000
00800003ZKgX00D0002=F8d0002Y_NP000000XaFS0H00004YFV<00@0002NH8L0000^0685000000?e
/Wd0003e/Wd02@000003mK=o0000000000D000000j9UR`000?2_Q@0500000hI>QP040000ZF^:ZF^:
ZF^:0`0000:RI8P01P000:iaS@00000009QNR`0000;8Q8T2000000BY_NP00026D8R6D8P3000000>S
I8L0000000000`000009k8Tc0000j:XY0000ZV^90000m;1n0000Z6f>00800002h:<L00<0002VIhT0
00001@000003I3=o0000Wf:900<000000j1VS@0000000002G2in00@0002WJHX00037QH/300000^6=
K@050000XFF:XFF:0000i9n7008000001fdlQ00009eRR`000:MZR`000?FbO@0200000ZA[S`030000
XFJ=000000@00002V7:U10000004ZKgX00000000ZKgX1@000004ZKgX0000000000000ZVmj0040000
VgV/VgV/00000Y9NT0T000001:Vmj00000000:Vmj0<000000i1FQ`000000000:000000>Y_NP00000
00000P0000;CShT2000000E_>Wl0002RIHX0002OQ;H00`000004ZKgX00000000XfV?0P000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP00000000010000004mZ9D0000VF2<VF2<1000
0003ZKgX0000000000800002Y6Z>0P000003ZKgX0000000000<000000jVmj0000000000;000000BY
_NP0001fCYEfCYD200000[^:X`040000XfjD0000/7JC10000005ZKgX000000000000ZKgX00D00000
0jVmj0000000000900000Y5MT08000000`06S`000000000200000jVmj0040000Tf:FTf:FTf:F0`00
00>CHiH4000000?/RR@0002MIHl00P000003ZKgX0000000000@000001JVmj000095NT@0009YSS`02
000000FY_NP0002DHiJDHiH000000Y=RU@<000000jVmj00000000003000000>Y_NP0000000004P00
0003ZKgX0000000000H000001JVmj000000000000:Vmj005000000>Y_NP00000000020000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP00000000020000003Tef>0000ZKgX00D00000
0jVmj0000:Vmj00;00000Y]UT@070000ZKgX0000Tf6C0000]WbD000000:CGi85000000>VW<`00000
000030000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP0000000000P000003ZKgX
0000000000<00003oooo00<0003oooooool05oooo`002_ooo`<00003oooo00<0003oooooool02Ooo
o`030000oooooooo07Woool30000;Oooo`8000000oooo`0000000003000000>Y_NP0000000000P00
0007ZKgX0000S5F;S5F;0000;8CZ000000>=EHT2000000>?GY<0000000000P0000>Y_NP01@0008eH
S@000:Vmj0000002S5J<00<0003SZIL000000`0000BUJH`0100009iPQ`0002h0HPD000001?FbO@00
00000?FbO@P000000oFcO`0000000005000000>RIH/0003`[hD01@0000>6CXH010000:U[RZU[RZU[
RP<000001:9TR00000000:iaS@80000019QNR`000<R4RLR4R@8000001:Vmj00008I@R8I@R0<00000
0j=TQ`0000000003000000G/RC<0003XZRT0002ZJhT00`000005Z6f>00000000h:<L000000:VIhT6
000000=T<gl0002OHXT00`000003X6J=00000000009L;Wh01@000:MYRP00000008A@RP0200000^6=
K@070000XFF:XFF:0000i9n70000n:e7008000001IeRR`000:MZR`000?FbO@0200000ZA[S`030000
XFJ=000000<00002V7:U0P000005ZKgX000000000000ZKgX00D000001:Vmj00000000:Vmj0<00002
ZKgX0P0000>BGY0:000000>Y_NP0000000000`000003T5J70000000000P00003ZKgX100000;CShT2
000000=_>Wl0002RIHX020000005XfV?000000000000ZKgX00D000001JVmj000000000000:Vmj005
000000BY_NP00000002Y_NP5000000CfXU@0002IH8bIH8`900000ZAZSPH000001:Vmj00000000:Vm
j0D000001JVmj000000000000:Vmj00200000ZVmj0060000MTjE00000000^hZS00000Z=^U0@00000
0jVmj0000000000:000000>Y_NP0000000000`000003ZKgX0000000000800002TEf@0P00000300J?
0000000000<00002ZKgX00D0002CHYJCHYH0002QJY<00P0000:CHiH5000000?/RR@0002MIHl01@00
00:Y_NP2000000FY_NP0002AGY40002JHhl00P0000:Y_NP00`0009ASUP000002Tf:E1`000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP00000000020000003ZKgX0000000000X00000
0jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj0000000000<
000000>CGHh0000000000`000005ZKgX000000000000ZKgX00@000000jVmj0000000000400000Y]U
T@070000ZKgX0000Tf6C0000]WbD000000:CGi83000000>VW<`0000000002P000003ZKgX00000000
00<000000jVmj0000000000:000000>Y_NP0000000000P000003ZKgX0000000000<00007oooo00<0
003oooooool05oooo`002_ooo`030000oooooooo00;oool00`000?ooo`00000:oooo00<0003ooooo
ool0M_ooo`<0000`oooo0P0000;oool2000000BY_NP00000002Y_NP3000000NY_NP0002<EH^<EH/0
000/Q>X000000heER@P00002ZKgX00D0002=F8d0002Y_NP000000XaFS0030000hjVG000000<00004
YFV<00@0002NH8L0000^0685000000Ge/Wd000000000003e/Wd01`000003mK=o0000000000D00000
0j9UR`000?2_Q@0500000hI>QP030000ZF^:ZF^:00@000001:9TR0000:iaSJiaS@80000019QNR`00
0<R4RLR4R@8000001:Vmj00008I@R8I@R0<000000j=TQ`0000000002ZKgX00H0003/RC<0003XZRT0
002ZJhT3000000FXKHh00000003PXa`000000ZIWR@<000001_BWJ`00000006@cO`0009mRR@<00000
2Z1VS@00000005`^OP000:MYRP000<N5R`0008A@RP800002hHe]00L0002QIHZQIHX0003TWhL0003h
[DL00P000005WF:;0000YfZ;0000mK9m00800002Y6^?00<0002QIXd0000010000003V7:U00000000
00/000001:Vmj0000000000000:;H9/300000i9NT0030000ZW2B000000@000000jVmj00000000003
000000FY_NP000000000002@EXL030000003ZKgX0000000000800002dhn90P000003KcYo0000XVF:
00D000001:Vmj00000000:=YS`D000000jVmj0000000000<000000>Y_NP0000000000`000004ZKgX
0000mZ9D00000YUPS0<000000jVmj0000000000300000ZAZSP8000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX0000000000L000001jVmj00007I>UGI>U@000;^:X`000002XfjD3@00
0003ZKgX0000000000<000000jVmj00000000002000000VY_NP000000000002AGI00002Y_NP00000
1Xl01@0000:Y_NP00`0009=RUY=RUP02000000Aa@8D0002CHiJCHiH5000000?/RR@0002MIHl01@00
00:Y_NP01`000?6D=0000000095NT@0009YSS`03000000NY_NP0002DHiH0002CHYD0002HHY000P00
0003ZKgX0000000000X000000jVmj00000000008000000>Y_NP0000000000`000003ZKgX00000000
00X000000jVmj00000000003000000>Y_NP00000000030000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj002000000<007/0000000001@000004ZKgX00000000
ZKgX0P000003ZKgX0000000000H00002VfFA00L0002Y_NP0002CHI<0002fO9@000000Y=OTPH00002
VFjP10000003ZKgX0000000000<000000jVmj00000000008000000FY_NP000000000002Y_NP02000
00coool00`000?ooooooo`0Foooo000;oooo00L0003oooooooooool0003oool000002_ooo`030000
oooooooo07?oool30000<oooo`800003oooo0P000003ZKgX0000000000<000001jVmj00008aERhaE
R`0002b4jP000003SEF90`000003ZKgX0000000000800002ZKgX00D0002=F8d0002Y_NP000000XaF
S0<000000jVmj00000000004YFV<00@0002NH8L0000^0682000000BNIHl00000003e/Wd3000000?e
/Wd0000000001@000003mK=o0000000000@00002XVF;00<0003`[hD00000100000:6CXH200000ZU[
RP@000001:9TR0000:iaSJiaS@8000001IQNR`000<R4R@000?FbO@0200000hI@R0<000000j=TQ`00
00000002ZKgX00H0003/RC<0003XZRT0002ZJhT3000000FXKHh00000003PXa`000000ZIWR@<00000
1_BWJ`00000006@cO`0009mRR@800002X6J=0P000007G2in0000YfV:0000ahF;0000Q52:00800002
hHe]00L0002QIHZQIHX0003TWhL0003h[DL00P000005WF:;0000YfZ;0000mK9m00800002Y6^?00<0
002QIXd000002P000005ZKgX000000000000ZKgX00@00002ZKgX00<0002;H9^;H9/00X]PV`060000
TUj@TUj@TUj@0000ZW2B20000005ZKgX000000000000ZKgX00800000191FQ`0000000:Vmj0@00002
TV2D00<0002=F8f=F8d01@0000;CShT2000000=_>Wl0002RIHX00P000007ZKgX000000000000ZKgX
0000XfV?00<000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj00;000000KfXU@0002I
H8bIH8`0002Y_NP700000ZAZSP<000000jVmj00000000003000000>Y_NP0000000002`000004ZKgX
0000MTjEMTjE0`000003XfjD0000/7JC00H000001JVmj000000000000:Vmj005000000BY_NP00000
002Y_NP5000000>Y_NP0000000002P000004ZKgX0000Tf:FTf:F0P000006LD250000Tf>FTf>F0000
ZKgX0`000003k8XT0000WFF?00<000001ZVmj00000000:Vmj0000?6D=08000000i5NT@0009YSS`03
000000>Y_NP0000000000Y=RU@030000V6:@0000008000000jVmj00000000003000000FY_NP00000
0000002Y_NP020000003ZKgX0000000000<000000jVmj0000000000<000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX00D000000jVmj00000000002000000>Y
_NP0000000000`000003ZKgX0000000000X000000jVmj00000000004000000>Y_NP0000000002@00
00:KII4400000[IlU0030000TenBTenB00@00003VFjP0`000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000000jVmj0000000000<00003_ooo`030000oooooooo01Koool000_oool01`000?oo
ooooooooo`000?ooo`00000:oooo00<0003oooooool0L?ooo`<0000foooo0P0000Coool7000000NY
_NP0002<EH^<EH/0000/Q>X000000XeER@030000ZKgX000000@000001ZVmj0000:Vmj:Vmj00008eH
S@800002S5J<1`0000BUJH`0100009iPQ`0002h0HP80000019iUS`0000000?FbO@@000000oFbO`00
00000004000000?e/gl000000000100000:RIH/00`000?2_Q@00000400000XI>QP800002ZF^:0P00
0004aX>90000XVB800000ZiaS@8000001IQNR`000<R4R@000?FbO@0200000hI@R0<000001j=TQ`00
000000000:Vmj0000>b9<`0200000ZY[R@<000001JQ]SP0000000>2S70000002YVN90`000006m:M[
00000000I3=o0000Wf:90P0000:PIXd2000000ML;Wh0002WJHX00037QH/00024D8X00P0000;QSFd0
1`000:5URZ5URP000>BOQ`000?R]A`02000000FMHX/0002WJX/0003e/Wd00P0000:TJhl00`000:5V
S@000008000000BY_NP00000002Y_NP5000000FY_NP0002Y_NRY_NP0000018]PV`060000TUj@TUj@
TUj@0000ZW2B1P000003ZKgX0000000000H00000191FQ`000000000000:Y_NP01@00099PU99PU99P
U0000003SER=100000;CShT2000000=_>Wl0002RIHX03@000003ZKgX0000000000<000001:Vmj000
00000:Vmj0D000001JVmj000000000000:Vmj004000000CfXU@0002IH8bIH8`900000ZAZSPX00000
0jVmj00000000003000000FY_NP000000000002Y_NP0100000=fCYD01@000:=^U:=^U0000;1fT`02
000000>Y_NP00000000030000003ZKgX0000000000<000000jVmj0000000000<000000VY_NP0002C
HYH0002QJY<0001a@8D0002CHiH01P000003k8XT0000WFF?00H000000jVmj0000?6D=002000000>A
GY40002JHhl00`000003ZKgX0000000000:CHYD00`0009QRT0000004000000>Y_NP0000000003000
0003ZKgX0000000000<000001:Vmj00000000:Vmj0D000001JVmj000000000000:Vmj005000000>Y
_NP0000000000P000003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000`00
0003ZKgX00000000010000000jVmj0000000000>00000Y]UT@@000000kIlU00009=OTP02TenB00<0
002Y_NP0000019U^X0X000000jVmj00000000003000000>Y_NP0000000002P0001;oool00`000?oo
ooooo`0Foooo000:oooo00<0003oool000000_ooo`030000oooo000000[oool00`000?ooooooo`1]
oooo0`0003Woool00`000?ooooooo`04oooo0`000005ZKgX00000000ZKgX000000:<EH/00`0002b4
jP000002SEF91@000004ZKgX0000000000000ZVmj0040000SER=000000000XaFS0L00004YFV<0`00
0004;P1R00000000WVF?20000003mK=o0000000000D000000oFeQ0000000000200000Z9UR`030000
l:n5000000@00002QTj60P0000:YJhX2000000C6PhT0002RI8P00002[W6=0P000003V5j;0000b8B9
008000001ZVmj00008I@R8I@R0000:9VS08000001:=TQ`00000008ACS`8000000nb9<`0000000002
ZV^90`000005Z6f>00000000h:<L000000:VIhT3000000KdYf/00000001T<gl0002OHXT200000Z1V
S@8000001e`^OP000:MYRP000<N5R`0008A@RP0200000^6=K@030000XFF:XFF:00<000001_R]A`00
000009eRR`000:MZR`8000001Y5IR`000:A[SjA[S`000:5VS@X000000jVmj00000000003000000>Y
_NP0000000000P0000:Y_NP01@0008]PVh]PVh]PV`000003TUj@00<0002ZL98000003P000003T5J7
0000000000>Y_NP01@00099PU99PU99PU0000003SER=100000;CShT2000000=_>Wl0002RIHX01@00
0003ZKgX0000000000L000000jVmj00000000008000000>Y_NP00000000020000004mZ9D0000VF2<
VF2<10000003ZKgX0000000000800002Y6Z>1P000003ZKgX0000000000<000000jVmj0000000000:
00000gI>U@050000XfjDXfjD0000/7JC00<000000jVmj00000000003000000FY_NP000000000002Y
_NP02P000003ZKgX0000000000<000000jVmj00000000004000000KFI`000000002CHYH0002QJY<3
000000BCHiH00000002Y_NP3000000?/RR@0002MIHl020000006lI@d00000000TEjA0000VV>?1P00
00:CHYD00`0009QRT0000002000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00D00000
0jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj00000000003
000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj0000000000<000000>Y_NP00000
00000`000004ZKgX00000000ZKgX1@000005TEb?000000000000ZKgX00D00003VfFA0`000003]WbD
0000TenB00:CGi8010000:Vmj:Vmj00000:IKZ000`0009IRTP000004000000>Y_NP0000000000`00
0003ZKgX0000000000X0000Foooo00<0003oooooool05_ooo`002oooo`030000oooooooo00;oool0
0`000?ooooooo`09oooo00@0003oool00000001Zoooo0P0003coool00`000?ooooooo`05oooo1@00
0007ZKgX0000S5F;S5F;0000;8CZ000000:=EHT6000000>Y_NP0000000000ZVmj0040000SER=0000
00000XaFS0050000hjVG00000000ZKgX00800004YFV<0`000003;P1R0000000000/000000oFbOP00
00000003000000?e]H@0000000000P0000:RIH/00`000?2_Q@00000400000XI>QP800002ZF^:0P00
0004aX>90000XVB800000ZiaS@8000000iQNR`000<R4R@02000000JY_NP00026D8R6D8P0002RIX`2
000000BSI8L000000024Dhl2000000?/RC<0000000000ZY[R@<000001JQ]SP0000000>2S70000002
YVN90`000006m:M[00000000I3=o0000Wf:90P00000;X6J=0000XFF<0000G2in0000YfV:0000ahF;
0000Q52:00800002hHe]00<0002QIHZQIHX00`000006n:e700000000WF:;0000YfZ;0P0000:AFH/0
10000:A[S`000:5VS@8000001JEZSP00000000000:Vmj005000000>Y_NP0000000001@000004R`d0
0000ZKgX00000h]PV`040000TUj@TUj@TUj@0P000003[76@0000000000H000000jVmj00000000003
000000>@EXL0000000000jVmj0050000TV2DTV2DTV2D000000>=F8d400000]>?R@8000000fljO`00
0:9URP03000000>Y_NP0000000001P000005ZKgX000000000000ZKgX00D000000jVmj0000000000:
000000JY_NP0003fXUCfXU@0002IH8`5000000JY_NP000000035Ngh0002TJXh4000000>Y_NP00000
00000`000004ZKgX00000000ZKgX1@000003ZKgX0000000000<00003MTjE00D0002SKYBSKY@0002`
MY<01`000003ZKgX0000000000X000000jVmj00000000009000000<01Xl0000000000P000003eVL0
0000ZKgX008000001:5ZT`0000000750Q@@000000jVmj00000000002000000>MIHl0000000000P00
0004ZKgX0000000000000_6D=0040000TEjA0000VV>?1P000004Tf:E0000V6:@V6:@2P000003ZKgX
0000000000X000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000<00000
0jVmj0000000000<000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000005ZKgX00000000
0000ZKgX00X000000jVmj00000000005000000>AG8l0000000001P000004c6800000VfFAVfFA0`00
0003]WbD0000TenB00:CGi8010000:Vmj:Vmj00000:IKZ000`0009IRTP000006000000>Y_NP00000
0000300001Soool00`000?ooooooo`0Foooo000Koooo0`0006Woool30000?_ooo`030000oooooooo
00Koool2000000FY_NP0002Y_NP0002<EH/00P000004;8CZ0000SEF9SEF90P000003ZKgX00000000
00@000001:Vmj00008eHSHeHS@800002S5J<00<0003SZIL000000P000003ZKgX0000YFV<00:UJH`0
1`0009iPQ`00000002h0HP0009iUS`04000000>Y_NP0000000001@000003mK9n0000000000L00002
XVF;00<0003`[hD0000010000004QTj60000Y6R=00000ZU[RP8000001<J3R@000:9TR00000:^LHd2
000000>HGX/00038Q8T00P000006ZKgX0000QU28QU280000XVJ<0P000003XfB70000000000:4Dhl0
10000>b9<`00000000:ZJhT3000000FXKHh00000003PXa`000000ZIWR@<000001_BWJ`00000006@c
O`0009mRR@8000002j1VS@000:5US00005`^OP000:MYRP000<N5R`0008A@RP0200000^6=K@030000
XFF:XFF:00<000001?R]A`000000000000:WJX/200000Y5IR`800002XFJ=0P000003YFZ>00000000
00@000001JVmj000000000000:Vmj00600000X/=00800003Rf2K00@0002BGY2BGY2BGY02000000>/
LI00000000001`000003ZKgX0000000000<000000jVmj00000000002ZKgX00D0002BH9BBH9BBH9@0
00000heHS@@00002dhn90P000003KcYo0000XVF:00X000000jVmj00000000006000000FOOZl00000
0000002Y_NP01@000005ZKgX000000000000ZKgX00<00002mZ9D00@0002IH8`0002Y_NP6000000?5
Ngh0002TJXh02`000003ZKgX0000000000<000001:Vmj00000000:Vmj0@00003MTjE00D0002SKYBS
KY@0002`MY<00`000003ZKgX0000000000X000000jVmj0000000000=000000<01Xl0000000000`00
0005eVL0000000000000XFZC00T0000019ai[000000009eUS`T000000o6D=00000000003VV>?0P00
0005g78000000000Tf:E000000:HHY06000000>Y_NP0000000000`000003ZKgX0000000000X00000
0jVmj0000000000<000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000005ZKgX00000000
0000ZKgX00D000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000001000000
0jVmj00000000003000000>AG8l00000000010000004ZKgX0000c68000000Y]UT@<000000kIlU000
09=OTP02TenB0P000004ZKgX0000VFjP00000YIRTPD000000jVmj0000000000:00007?ooo`030000
oooooooo01Koool001_oool00`000?ooooooo`1Voooo0`0004_oool3000000>Y_NP0002<EH/00`00
00>=EHT5000000JY_NP000000000002Y_NP00002SER=0P000003S5J<00000000008000001:Vmj000
0000000000>UJH`00`0009iPQ`000003000000>NIHl0000000000`000003ZKgX0000000000@00000
0oFbOP000000000700000Z9UR`030000l:n5000000@0000018I>QP000:AXS@0000:YJhX4000000BR
I8P0002^LHf^LHd2000000>HGX/00038Q8T00P000006ZKgX0000QU28QU280000XVJ<0P000003XfB7
0000000000:4Dhl010000>b9<`00000000:ZJhT4000000BSIh`0003PXa`00002YVN90`000006m:M[
00000000I3=o0000Wf:90P00000;X6J=0000XFF<0000G2in0000YfV:0000ahF;0000Q52:00800002
hHe]00<0002QIHZQIHX00`000004n:e70000000000000ZMZR`800002TEV;0P0000:QIXd2000000>U
JXh0000000000P000003ZKgX0000000000H000001:Vmj0000000000000>;3@001@0008]PVh]PVh]P
V`000002TUj@00@0002ZL980002/LI05000000>Y_NP0000000000`000003ZKgX0000000000@00002
ZKgX00D0002BH9BBH9BBH9@000000heHS@@00002dhn90P000003KcYo0000XVF:008000001JVmj000
000000000:Vmj005000000>Y_NP0000000000P0000:OOZl6000000>Y_NP0000000000P000003ZKgX
0000000000<000001JVmj0000?JRE00009UPS005000000NY_NP000000035Ngh0002TJXh000000YEW
V`@000000jVmj00000000008000000>Y_NP0000000000`000005ZKgX0000MTjEMTjE000000:SKY@0
0`000;1fT`000003000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00P000000jVmj000
00000003000000BY_NP0000000001Xl5000000?FI`00000000000Z5ZT`030000ZKgX000000@00003
W7V/00<0003/RR@000000`000003ZKgX0000000000<000000o6D=00000000003VV>?0P000003g780
0000HRA/00800002V6:@0P000003ZKgX0000000000<000000jVmj00000000002000000>Y_NP00000
00000`000005ZKgX000000000000ZKgX00P000001JVmj000000000000:Vmj00:000000>Y_NP00000
00000`000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX
0000000000<000000jVmj0000000000<000000JY_NP000000000003<HP000002VfFA00D0001D>iL0
002fO9@000000i=OTP03000004[9000000<00002UV:B3P00023oool00`000?ooooooo`0Foooo000K
oooo00<0003oooooool0Hoooo`<0001?oooo10000004S5F;0000000000000heER@<000001:Vmj000
00000:Vmj0@000001HeHS@000000000008aFS006000000>Y_NP0002UJH`00ZEYS0030000WV270000
00<0000019iUS`0000000:Vmj0<000000jVmj00000000005000000?e/gl0000000000P000008lj]e
00000000XVF;0000l:n500008`1U0`0000:6CXH00`000:AXS@000002ZF^:10000004XVB80000[W6=
[W6=0P000003V5j;0000b8B9008000001ZVmj00008I@R8I@R0000:9VS0D00002Q5>?00@0003/RC<0
00000002ZV^910000004XfN<0000h:<L00000ZIWR@040000R5:90000m:M[0P00000>I3=o00000000
bXN;0000X6J=0000XFF<0000G2in0000YfV:0000ahF;0P000005UUn=0000hHe]hHe]000000:QIHX3
000000Ch[DL0000000000002YfZ;0P0000:AFH/2000000FQIXd000000000002UJXh02`000003ZKgX
0000000000<00003R`d000D0002;H9^;H9^;H9/000000Y9NT0030000ZW2B000000@000000jVmj000
00000003000000>Y_NP0000000001P0000:Y_NP01@00099PU99PU99PU0000003SER=100000;CShT2
000000=_>Wl0002RIHX03@0000:R^nX01@0009mn[`0000000:Vmj003000000>Y_NP0000000001P00
0003ZKgX0000000000<000000oJRE00009UPS00:000000BTJXh0002EIi^EIi/7000000FY_NP00000
0000002Y_NP01@000003ZKgX0000000000<00002MTjE00D0002SKYBSKY@0002`MY<01P000003ZKgX
0000000000800002V6nR10000005ZKgX000000000000ZKgX00D000001ZVmj00000000:Vmj0000006
S`<000001JVmj0000=IW0=IW00000002XFZC10000003ZKgX0000W7V/00:LNJ`2000000C/RR@00000
002Y_NP7000000?aU3@0000000000iYSS`800002g7800`0000:HHY06000000BY_NP00000002Y_NP5
000000>Y_NP00000000030000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP00000
000040000003ZKgX0000000000`000000jVmj0000000000F000000BY_NP0003<HP000002VfFA00D0
001D>iL0002fO9@000000i=OTP05000004[904[904[9000000>FHY8<00008_ooo`030000oooooooo
01Koool001_oool00`000?ooooooo`1Poooo0`0005?oool3000000B<EH/0000000000002SEF900<0
002Y_NP000000P000003ZKgX0000000000@000001HeHS@000000000008aFS003000000>Y_NP00000
00000P0000>UJH`00`0009iPQ`000003000000>NIHl0000000000`0000:Y_NP00`0009AWV`000004
000000?e/gl0000000000P000008lj]e00000000XVF;0000l:n500008`1U0`0000:6CXH010000:AX
S@000:U[RP@00002XVB800<0002^LHf^LHd00P000003V5j;0000b8B9008000001ZVmj00008I@R8I@
R0000:9VS0D00002Q5>?00@0003/RC<000000002ZV^910000005XfN<0000h:<L0000YVN900800000
0hQBR@000?BWJ`02000000iT<gl00000003:Qh/0002PIXd0002QIH`0001L;Wh0002WJHX00037QH/2
000000FFGhd0003QSFgQSFd000000Z5URP<000001?R]A`000000000000:WJX/200000Y5IR`800000
0j5VS@0000000002000000?<S8h00000000010000003ZKgX0000000000L00003R`d000D0002;H9^;
H9^;H9/000000Y9NT0030000ZW2B000000L000001JVmj000000000000:Vmj006000000CUNaP0002Y
_NP00003TV2D00@0002=F8f=F8f=F8d400000]>?R@8000000fljO`000:9URP0=00000Z:kjPD00000
0jVmj00000000003000000FY_NP000000000002Y_NP01`000003mZ9D0000VF2<00@000001:Vmj000
09IXW9IXW08000001JAZSP0009EWV`0009QST@04000000>Y_NP0000000002P000003ZKgX00000000
00<0000017I>U@000:=^U00000:`MY<4000000FY_NP00000002Y_NP000000iQ_XP030000TEf@TEf@
00d000000jVmj0000000000700000]IW00030000XFZCXFZC00<00003ZKgX00<0002LNJ`000000P00
0003k8XT0000000000P00002lI@d00P0002JHhnJHhnJHhl0002Y_NP0003LLP0200000iQRT0L00000
0jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj0000000000:
000000>Y_NP0000000004P000003ZKgX0000000000H000001JVmj000000000000:Vmj005000000>Y
_NP0000000002P000003ZKgX0000000000<000000jVmj00000000002ZKgX00<0003<HP0000000Y]U
T@040000E3^G0000]WbD0P000003TenB0000000000<0B/T0100009IRTYIRTYIRTP@000001:Vmj000
0000000002Ooool00`000?ooooooo`0Eoooo000Koooo00<0003oooooool0GOooo`<0001Goooo0P00
0004S5F;0000000000000XeER@8000000jVmj00000000003000000FY_NP000000000002=F8d00`00
0003S5J<00000000008000001:Vmj0000000000000>UJH`00`0009iPQ`000003000000BNIHl00000
002Y_NP3000000BY_NP0002DIi^DIi/4000000?e/gl0000000000P000008lj]e0000XVF;XVF;0000
l:n500008`1U0`000006QTj60000Y6R=Y6R=0000ZF^:100000:RI8P020000:iaS@000?33B`0009QN
R`000<R4R@8000001ZVmj00008I@R8I@R0000:9VS0D00002Q5>?00@0003/RC<000000002ZV^91000
0005XfN<0000h:<L0000YVN9008000000hQBR@000?BWJ`02000000iT<gl00000003:Qh/0002PIXd0
002QIH`0001L;Wh0002WJHX00037QH/2000000FFGhd0003QSFgQSFd000000Z5URP<000001?R]A`00
0000000000:WJX/200000Y5IR`8000000j5VS@0000000002000000?<S8h0000000001@0000:?Fhl4
000000>Y_NP0000000000h/=00800002Rf2K00D0002BGY2BGY00002ZL9804`000004iG/H0000ZKgX
00000i9PU0040000SER=SER=SER=100000;CShT2000000=_>Wl0002RIHX00`000003ZKgX00000000
00X000000jVmj00000000003000000>Y_NP0000000003@000003mZ9D0000VF2<00800003ZKgX00<0
002FJ9bFJ9`00P000005Y6Z>0000UFNK0000V6>A00H000000jVmj0000000000:000000RY_NP00000
0000001fCYD0002SKY@00002/7JC1@0000>Y_NP01@0009Q_XYQ_XYQ_XP000002TEf@1@000005ZKgX
000000000000ZKgX00D000000jVmj0000000000500000]IW00030000XFZCXFZC00D000000jVmj000
00000003000000?/RR@0000000000`000003ZKgX0000000000800002lI@d00@0002JHhnJHhnJHhl3
00000]ab00040000V6:@V6:@V6:@0`000003ZKgX0000000000<00003Wh6b2P000003ZKgX00000000
00P000000jVmj00000000003000000FY_NP000000000002Y_NP020000003ZKgX0000000000<00000
1JVmj000000000000:Vmj005000000>Y_NP0000000000P000003ZKgX0000000000X000000jVmj000
00000003000000FY_NP000000000002Y_NP020000007ZKgX00000000ZKgX0000c680000000:KII43
000000BfO9@00000002CGi8200000`1:b@040000UV:BUV:BUV:B1@0002[oool00`000?ooooooo`0E
oooo000Koooo00<0003oooooool0F_ooo`<0001Joooo0P000004S5F;0000000000000XeER@@00000
0jVmj00000000002000000ZY_NP00000002=F8d0002bNI@0002<EX`0003SZIL600000jEYS0030000
WV27000000<000001IiUS`00000000000:Vmj003000000>Y_NP0002DIi/01@000006m;J600000000
0000lj]e00000Z9UR`040000l:n500008`1U0`000006QTj60000Y6R=Y6R=0000ZF^:100000:RI8P0
10000:iaS@000?33B`<000001LR4R@0000000:Vmj0000002QU2800<0002RIX`00000100000:4Dhl0
10000>b9<`00000000:ZJhT4000000FSIh`0003PXa`0002VIhT00P000003R5:90000m:M[00800000
3V@cO`0000000<Z7R`000:1VS@000:5US00005`^OP000:MYRP000<N5R`80000029IOS@000>6=KN6=
K@000:5URP000>BOQ`8000001?R]A`000000000000:WJX/200000Y5IR`8000000j5VS@0000000002
000000K<S8h000000000002Y_NP00004Se^?1@000003ZKgX0000R`d000:;3@0200000X]PV`050000
TUj@TUj@0000ZW2B00D000001:Vmj0000000000000>AGY87000000CUNaP0002Y_NP00003TV2D00@0
002=F8f=F8f=F8d4000000OCShT000000000001_>Wl0002RIHX010000003ZKgX0000000000<00000
1JVmj000000000000:Vmj005000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP01000
0003mZ9D0000VF2<00800003ZKgX00<0002FJ9bFJ9`00P000003Y6Z>0000000000:HHi47000000>Y
_NP0000000000`000005ZKgX000000000000ZKgX00D00002MTjE0P0000:`MY<500001:Vmj0030000
V6nR000000>AGI03000000>Y_NP0000000002P000003ZKgX0000000000<000001:Vmj0000=IW0000
00:QJY<4000000BY_NP00000002Y_NP6000000>BGI00000000001@0000;aU3@0100009YSSiYSSiYS
S`<00002g78000@0002HHY2HHY2HHY0700000in1/PH000001JVmj000000000000:Vmj008000000>Y
_NP0000000000`000003ZKgX0000000000`000000jVmj00000000003000000>Y_NP0000000002P00
0003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP00000000030000003ZKgX00000000
00H00002VfFA0P000005E3^G000000000000TenB0080000304[900@0002FHY:FHY:FHY840000:ooo
o`030000oooooooo01Goool001[oool00`000?ooooooo`1Ioooo0P0005goool600000XeER@800000
0jVmj0000000000800000[9iU0<000001N>YU`00000000000:Vmj00200000jEYS0030000WV270000
00/000000jVmj00000000002U5j?10000005mKF400000000lj]e000000:RIH/010000?2_Q@0002<0
I@<0000018I>QP000:AXS@0000:YJhX4000000JRI8P0002^LHf^LHd0003``d/3000000G8Q8T00000
002Y_NP000000XI@R0030000XVJ<000000@00002Q5>?00@0003/RC<000000002ZV^910000005XfN<
0000h:<L0000YVN9008000000hQBR@000?BWJ`02000000iT<gl00000003:Qh/0002PIXd0002QIH`0
001L;Wh0002WJHX00037QH/2000000RFGhd0003QSFgQSFd0002QIHX0003TWhL2000000Ch[DL00000
00000002YfZ;0P0000:AFH/2000000>QIXd0000000000P000003c8b>0000ZKgX00:Y_NP00`0008mK
ShmKS`02Se^?1`0000>;3@0200000X]PV`050000TUj@TUj@0000ZW2B00L00004TEjB200000;UNaP2
00000i9PU0040000SER=SER=SER=10000007dhn9000000000000KcYo0000XVF:00H000000jVmj000
0000000<000000>Y_NP0000000000`000004ZKgX00000000ZKgX1@000005ZKgX0000mZ9D0000VF2<
00<00003ZKgX00D0002FJ9`00000002TJXh00P0000:HHi43000000>Y_NP0000000000`000003ZKgX
0000000000`000000gI>U@0000000002/7JC1`0000:Y_NP20000195MT0D000000jVmj0000000000@
000000?FI`00002QJY<01P000003ZKgX0000000000H00000199MT0000000000000:KMZP200000_6D
=0040000VV>?VV>?VV>?0`0000;LLP00100009QRT9QRT9QRT0@00003ZKgX100000:CHI<>000000>Y
_NP0000000000`000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP0000000002P00
0003ZKgX0000000000<000000jVmj0000000000<000000>Y_NP0000000002P000003ZKgX00000000
00<000000jVmj0000000000400000Y]UT@8000001E@kU`000000000009=OTP0300000`1:b@030000
UV:BUV:B00<000000ieVT@000?ooo`0Yoooo00<0003oooooool05Oooo`006_ooo`030000oooooooo
05Koool30000Goooo`@0000012b4jP0008eERHeER@D000001JVmj000000000000:Vmj00300000[9i
U0X00003YFV<00<0002NH8L0000020000003ZKgX0000XR4000<00002U5j?1`000008lj]e0000XVF;
XVF;0000l:n500008`1U0`000004QTj60000Y6R=00000ZU[RP@000001Z9TR0000:iaSJiaS@000?33
B`<000001lR4R@0000000:Vmj00008I@R0000002XVJ<1@0000:4Dhl03`000>b9<`0000000:Y[R@00
0?B`OP000:Q]SP000:=WS0000>2S70000:IWR@02000000>8DXT0003dYf/00P00000>I3=o00000000
bXN;0000X6J=0000XFF<0000G2in0000YfV:0000ahF;0P00000:UUn=0000hHe]hHe]0000XFF:0000
i9n70000YF^>100000:WJX/200000Y5IR`8000000j5VS@000000000400000jVmj0030000Se^?Se^?
00:?Fhl5000000>Y_NP0002;3@000X/=00800002Rf2K00<0002BGY0000000ZY`TPD000000jVmj000
095NTP03TEjB2@000003iG/H0000000000>BH9@0100008eHSHeHSHeHS@@000000m>?R@0000000002
000000=_>Wl0000000000`000003ZKgX0000000000H000001JVmj000000000000:Vmj00:000000>Y
_NP0000000000`000007ZKgX000000000000mZ9D0000VF2<00@00002ZKgX00H0002FJ9`00000002T
JXh00002V6>A00<0002YL94000001@000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX
00<000000gI>U@0000000002/7JC0P0000:Y_NP00`0009=QU9=QU0040000195MT0H000000jVmj000
00000003000000FY_NP000000000002Y_NP01`000003eVL00000XFZC008000000jVmj00000000003
00000ZVmj0030000TUf@0000008000000i9MT00009]fZ002VgJX0`0000;aU3@0100009YSSiYSSiYS
S`<00002g78000@0002HHY2HHY2HHY09000019=QT`H000001JVmj000000000000:Vmj005000000>Y
_NP0000000002P000003ZKgX0000000000<000000jVmj0000000000<000000>Y_NP0000000000`00
0004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX00D000000jVmj0000000000@000000NY
_NP000000000003<HP00002KII401P000004TenB0000000000000`1:b@080000UV:BUV:B0000[7:A
0000WFJA0000:_ooo`030000oooooooo01Goool001[oool00`000?ooooooo`1Coooo0`0006;oool4
000000</Q>X0002=EHT00`000005ZKgX000000000000ZKgX00H000000k9iU0000000000900000jEY
S0d00002XR4000@0002DGXnDGXnDGXl7000000KcZgD0002RIH^RIH/0003`[hD600000ZAXS@030000
ZF^:ZF^:00@000001Z9TR0000:iaSJiaS@000?33B`<000001lR4R@0000000:Vmj00008I@R0000002
XVJ<1@0000:4Dhl03`000>b9<`0000000:Y[R@000?B`OP000:Q]SP000:=WS0000>2S70000:IWR@02
000000>8DXT0003dYf/00P000003I3=o00000000008000002J1VS@000:5US00005`^OP000:MYRP00
0<N5R`02000000ZFGhd0003QSFgQSFd0002QIHX0003TWhL0002UJhh400000ZMZR`800002TEV;0P00
0003XFJ=0000000000@00003ZKgX00H0002?Fhn?Fhn?Fhl0002XKi4600000h/=00800002Rf2K00<0
002BGY0000000ZY`TPD000000jVmj000095NTP03TEjB00<0002OIi00000010000003ZKgX0000iG/H
00800003TV2D00@0002=F8f=F8f=F8d4000000?CShT0002Y_NP00P000004KcYo00000000ZKgX0`00
0003ZKgX0000000000<000000jVmj00000000006000000FY_NP000000000002Y_NP01@000003ZKgX
0000000000D000000oJRE00009UPS002000000JY_NP00000002Y_NP0002FJ9`2000000JTJXh0002H
Hi6HHi40002YL947000000>Y_NP0000000000`000004ZKgX00000000ZKgX1P000007MTjE00000000
/7JC0000VF6>000000:Y_NP00`0009=QU9=QU002Tf6D00<0002AGI2AGI000i5MT08000000jVmj000
00000003000000>Y_NP0000000003@000003eVL00000XFZC00L00003ZKgX00<0002BGI0000000P00
0004TUf@00000000VgJX0P000005ZKgX00000000lI@d000000>JHhl300000]ab00040000V6:@V6:@
V6:@0`0000FAGi<00`0009=QTi=QT`02Tf6C10000003ZKgX0000000000X000000jVmj00000000003
000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX
00D000000jVmj00000000002000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj000
00000003000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX0P000003c6800000VfFA
00H0000019=OTP000000000000<0B/T01@0009IRTYIRTP000:abT@030000:_ooo`030000oooooooo
01Goool001[oool010000?ooo`00000004ooool30000IOooo`@000001Bb4jP0008eER@000:Vmj002
000000>Y_NP0000000000`000005ZKgX000000000000/WVD00D000001ZVmj000000000000:Vmj000
00>UJH`5000000>NIHl0000000000P000003ZKgX0000000000:R8@00100009ANSiANSiANS`800000
0l>?W`0000000002000000KcZgD0002RIH^RIH/0003`[hD600000ZAXS@030000ZF^:ZF^:00@00000
1Z9TR0000:iaSJiaS@000?33B`@000001oFbO@000:Vmj00008I@R0000:9VS00600000XACS`@00000
2jY[R@00000000000:Q]SP000:=WS0000>2S70000:IWR@02000000>8DXT0003dYf/00P000003I3=o
00000000008000002J1VS@000:5US00005`^OP000:MYRP000<N5R`02000000ZFGhd0003QSFgQSFd0
002QIHX0003TWhL0002UJhh400000ZMZR`800002TEV;00<0002QIXfQIXd01P0000>Y_NP01P0008mK
ShmKShmKS`000:Q_T@<000001:Vmj0000000000000:;3@002P0008MBR`0008]PV`00099NT0000:Y`
TP000:aaT0@000000jVmj000095NTP03TEjB00<0002OIi0000001P0000;UNaP01@00099PU99PU99P
U0000003SER=10000003dhn900000000008000000fljO`000000000A000000>Y_NP0000000002P00
0003ZKgX0000000000@000000oJRE00009UPS004000000@007X00000002FJ9`2000000JTJXh0002H
Hi6HHi40002YL943000000>Y_NP0000000000`000003ZKgX00000000008000000jVmj00000000003
000000>Y_NP0000000000P0000:`MY<00`0009UQSP000002ZKgX00<0002CHIBCHI@00Y=QU0030000
TEf@TEf@00>AGI06000000BY_NP00000002Y_NP5000000>Y_NP0000000001P000003eVL00000XFZC
00L00003ZKgX00<0002BGI0000000P000003TUf@0000000000H000000o6D=00009YSS`02VV>?0`00
00;LLP00100009QRT9QRT9QRT0<00005TEnC00<0002CHI>CHI<00Y=QTa<000000jVmj0000000000<
000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP00000
00002P000003ZKgX00000000018000000jVmj00000000002000000?<HP00002KII401P000004TenB
0000000000000`1:b@050000UV:BUV:B0000[7:A00<0000Zoooo00<0003oooooool05Oooo`006_oo
o`80001>oooo0`0006Soool01`0008aER`00000002b4jP0008eER@02000000>Y_NP0000000000`00
0003ZKgX0000000000800002/WVD0`000004hjVG00000000ZKgX100000>UJH`5000000BNIHl00000
002Y_NP2000000F>FXh0002R8@2R8@0000000YANS`<00002`hnO0`000006lj]e0000XVF;XVF;0000
l:n51P0000:TJ8d00`000:U[RZU[RP04000000JRI8P0002^LHf^LHd0003``d/4000000Oe/Wd0002Y
_NP00026D8P0002RIX`01P0000:4Dhl4000000>ZJhT0000000000P0000:SIh`010000>2S70000:IW
R@8000000hQBR@000?BWJ`02000000AT<gl0000000000002X6J=00@0002QIH`0001L;Wh200000/N5
R`80000039IOS@000>6=KN6=K@000:5URP000>BOQ`000:E[SP000?R]A`800002YfZ;0P0000:AFH/0
0`000:5VSJ5VS@0700000ZVmj0040000Se^?Se^?Se^?0P000005/7F@000000000000ZKgX00800002
R`d000X00027DX/0002;H9/0002BGY00002ZL980002/LI04000000>Y_NP0002AGY800Y5NTP800000
0imWT0000000000500000^Ek60050000TV2DTV2DTV2D000000>=F8d6000000BY_NP00000001_>Wl5
000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00D000000jVmj0000000000:000000>Y
_NP0000000000P000003mZ9D0000VF2<00@00002001j10000006Y6Z>0000V6>AV6>A0000ZG2A1P00
0005ZKgX000000000000ZKgX00D000000jVmj00000000003000000?fXU<0000000000[1fT`040000
VF6>000000000ZVmj0050000Tf6DTf6DTf6D000000BAGI08000000>Y_NP0000000000`000003ZKgX
0000000000X000000j5ZT`0000000003000000>Y_NP0002Y_NP00ZVmj0030000TUf@000000800000
199MT00000000:Vmj0D000000o6D=00009YSS`02VV>?0`0000;LLP00100009QRT9QRT9QRT0<00005
TEnC00H0002CHI>CHI>CHI<0002MIY4<000000FY_NP000000000002Y_NP020000005ZKgX00000000
0000ZKgX00D000000jVmj0000000000@000000>Y_NP00000000030000003ZKgX0000000000<00000
0jVmj0000000000@000000>Y_NP0000000000P000004VfFA0000oooooooo0`000005TenB00000000
EcRA00000080B/T01@0009IRTYIRTP000:abT@030000:oooo`030000oooooooo01Coool001[oool0
0`000?ooooooo`1:oooo0`0006_oool4000000</Q>X0002=EHT010000003ZKgX0000000000800000
1:Vmj0000000000000:bNI@3000000?SZIL0000000000`000003ZKgX0000YFV<00:UJH`2000000B?
FXd00000002NIHl300000hiJSP040000XR40XR4000000YANS`<00003`hnO0P000006lj]e0000XVF;
XVF;0000l:n51P0000:TJ8d010000:U[RP0009mRR@<000001Z9TR0000:iaSJiaS@000?33B`H00000
1JVmj00008I@R0000:9VS00600000XACS`@000000jY[R@000000000200000Z=WS0040000h:<L0000
YVN90P000003R5:90000m:M[008000001V@cO`00000000000:1VS@0000:QIH`01`0005`^OP000000
0<N5R`0008A@RP0300000^6=K@080000XFF:0000i9n70000YF^>0000n:e70P0000:WJX/200000Y5I
R`030000XFJ=XFJ=008000000jEZSP000000000200000ZVmj0040000Se^?Se^?Se^?0P000003/7F@
0000000000@00002R`d000X00027DX/0002;H9/0002BGY00002ZL980002/LI04000000>Y_NP0002A
GY800Y5NTP8000000imWT0000000000500000^Ek60050000TV2DTV2DTV2D000000>=F8d9000000E_
>Wl000000000002Y_NP03P000005ZKgX000000000000ZKgX00D000001JVmj000000000000:Vmj006
000000?fXU@0002IH8`01000008007X01P00099RUP0000000:AZSP0000:HHi400`000:U`T@000003
000000>Y_NP0000000002P000003ZKgX00000000008000000oJRD`0000000002/7JC00@0002IHHh0
00000002ZKgX00<0002CHIBCHI@00Y=QU0040000TEf@TEf@TEf@10000003ZKgX0000000000<00000
0jVmj0000000000:000000NY_NP000000000002QJY<0002Y_NP01@0000>Y_NP00`00099MT0000002
000000>BGI000000000010000005ZKgX0000lI@dlI@d000000:JHhl4000000?LLP00002HHY000YQR
T08000000jVmj000095OT`02TEnC0P0000>CHI<01@0009eVT@0000000:Vmj005000000>Y_NP00000
000030000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP0000000000`000005ZKgX
000000000000ZKgX00P000001JVmj000000000000:Vmj005000000>Y_NP0000000002P000003ZKgX
0000000000<000000jVmj00000000006000000BKII40003oooooool2000000JY_NP000000000001G
>940000204[900D0002FHY:FHY80002/LY400`0002_oool00`000?ooooooo`0Doooo000Ioooo00<0
003oooooool0B?ooo`<0001^oooo0P000007oooo0000;8CZ0000SEF90000oooo00<000000jVmj000
0000000500000[9iU0L000001:Vmj0000000000000>UJH`2000000B?FXd00000002NIHl2000018iJ
SP8000001:8Q000009ANSiANS`<00002`hnO0`000004lj]e0000XVF;XVF;0P0000038`1U00000000
00800003Y6R=00@0002YJhX0002OHXT3000000JRI8P0002^LHf^LHd0003``d/6000000FY_NP00026
D8P0002RIX`01P0000:4Dhl4000000>ZJhT0000000000P0000:SIh`010000>2S70000:IWR@800000
0hQBR@000?BWJ`02000000IT<gl000000000002PIXd00002XFF<00L0001L;Wh000000037QH/00024
D8X00`0000;QSFd02@000:5URP000>BOQ`000:E[SP000?R]A`000002YfZ;00<0003e/Wd000000Y5I
R`030000XFJ=XFJ=008000000jEZSP000000000200000ZVmj0040000Se^?Se^?Se^?0P000003/7F@
0000000000@00002R`d000X00027DX/0002;H9/0002BGY00002ZL980002/LI04000000>Y_NP0002A
GY800Y5NTP<000000jI]T0000000000400000^Ek60050000TV2DTV2DTV2D000000>=F8d9000000=_
>Wl0000000000`000003ZKgX0000000000P000000jVmj0000000000:000000>Y_NP0000000000`00
0007ZKgX000000000000mZ9D0000VF2<00D000000`00NP00099RUP02000000JTJXh0002HHi6HHi40
002YL946000000>Y_NP0000000002P000003ZKgX0000000000<00002/7JC00@0002IHHh000000002
ZKgX00<0002CHIBCHI@00Y=QU0040000TEf@TEf@TEf@2`000003ZKgX0000000000<000000jVmj000
00000006000000GFI`0000000000002Y_NP01@0000:Y_NP00`00099MT99MT002000000BBGI000000
002Y_NP500000_6D=0030000VV>?VV>?008000001JVmj0000=ab0=ab00000002V6:@0P000003ZKgX
0000TEnC00:AGi<00`0007=2QP000002Tf6C00<0002MIY4000001@000003ZKgX0000000000X00000
0jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000<000000jVmj0000000000<
000000>Y_NP00000000050000003ZKgX0000000000X00002oooo0P000004VfFA0000oooooooo1P00
0005EcRA000004[904[9000000:FHY800`000:abT@0000020000:oooo`030000oooooooo01Coool0
01Woool00`000?ooooooo`15oooo0`00077oool2000000Koool0000/Q>X0002=EHT00002oooo1@00
0003ZKgX00000000008000000k9iU0000000000:00000jEYS0H000000jVmj00008iJSP02SUZ>0`00
0004XR400000U5j?U5j?1P000009R4b00000lj]e0000XVF;0000l:n500008`1U00@00003Y6R=00@0
002YJhX0002OHXT3000000BRI8P0002^LHf^LHd8000000FY_NP00026D8P0002RIX`01P0000:4Dhl4
000000>ZJhT0000000000P0000:SIh`010000>2S70000:IWR@8000000hQBR@000?BWJ`02000000IT
<gl000000000002PIXd00002XFF<00L0001L;Wh000000037QH/00024D8X00`00000;hHe]0000XFF:
XFF:0000i9n70000YF^>0000n:e7000000:WJX/00`000?FbO@000002TEV;00<0002QIXfQIXd00P00
0003YFZ>0000000000800002ZKgX00@0002?Fhn?Fhn?Fhl2000000>`MI00000000000P000008ZKgX
0000R`d0R`d00000Qe:;0000Rf2K0P0000:ZL9800`000:aaT0000003000000>Y_NP0002AGY800Y5N
TP<000001JI]T000000000000:Vmj00200000^Ek60050000TV2DTV2DTV2D000000>=F8d6000000BQ
R[/00000001_>Wl2000000FY_NP000000000002Y_NP01@000003ZKgX0000000000X000000jVmj000
00000003000000>Y_NP0000000001@000003mZ9D0000VF2<00D000000`00NP00099RUP02000000BT
JXh0002HHi6HHi49000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00L00002/7JC00L0
002IHHh0002Y_NP0002Y_NP0000019=QU0040000TEf@TEf@TEf@3@000003ZKgX0000000000X00000
0mIW000000000005000000FY_NP0002Y_NRY_NP000000Y9MT0H000000jVmj0000000000200000_6D
=0030000VV>?VV>?00@00002g78000<0002HHY2HHY000P000003ZKgX0000TEnC00:AGi<00`0007=2
QP000002Tf6C00D0002MIY400000002Y_NP030000003ZKgX0000000000<000000jVmj0000000000<
000000>Y_NP0000000000`000003ZKgX0000000000X000000jVmj00000000003000000>Y_NP00000
00002P000005ZKgX000000000000ZKgX00D000000jVmj0000000000300001oooo`8000000i]UT@00
0?ooo`02oooo1@000005EcRA000004[904[9000000:FHY800`000:abT@0000020000:oooo`030000
oooooooo01Coool001Woool00`000?ooooooo`13oooo0P0007Coool2000000Goool00000002=EHT0
00001?ooo`8000000jVmj00000000004000000>bNI@0000000000`000003ZKgX0000000000@00003
YFV<1P000003ZKgX0000SUZ>00:>FXh3000000BR8@00002DGXnDGXl6000000N8C800003cZgD0002R
IH/0003`[hD00P000004LSn40000000000000jAXS@040000ZF^:0000Wf:90`000004XVB80000[W6=
[W6=20000005ZKgX0000QU280000XVJ<008000001:=TQ`000000000000:4Dhl4000000>ZJhT00000
00000P0000:SIh`010000>2S70000:IWR@8000000hQBR@0000000002000000IT<gl000000000002P
IXd00002XFF<00L0001L;Wh000000037QH/00024D8X00`00000;hHe]0000XFF:XFF:0000i9n70000
YF^>0000n:e7000000:WJX/00`000?FbO@000002TEV;00<0002QIXfQIXd00P000003YFZ>00000000
00800002ZKgX00D0002?Fhn?Fhl0002XKi400P000003ZFj?0000000000<00002R`d000<00027DX^7
DX/00`0000:ZL9800`000:aaT0000002000000>5DXd0000000000Y5NTP8000000imWT0000:I]T006
00000^Ek60050000TV2DTV2DTV2D000000>=F8d2000000?>SHd00000000010000003KcYo00000000
00/000000jVmj00000000003000000FY_NP000000000002Y_NP00P000004UVRK00000000ZKgX0P00
0003ZKgX0000000000@000000oJRE00009UPS005000000L007X0002BHYJBHYH0002TJXh000000YQS
T@D000000jVmj00000000003000000>Y_NP0000000003@0000:`MY<00`0009UQSP000002000000>Y
_NP0002CHI@00i=QU0040000TEf@TEf@TEf@1`000005ZKgX000000000000ZKgX00`000000jVmj000
0=IW0003000000>Y_NP0000000000`0000>Y_NP00`00099MT0000007000000>Y_NP0000000000_6D
=0030000VV>?VV>?00@00002g78000<0002HHY2HHY000P000003ZKgX0000TEnC00:AGi<00`0007=2
QP000002Tf6C00<0002MIY4000000P000003ZKgX0000000000<000001JVmj000000000000:Vmj005
000000BY_NP00000002Y_NP5000000FY_NP000000000002Y_NP01@000003ZKgX0000000000X00000
0jVmj00000000003000000>Y_NP00000000030000003ZKgX0000000000`0000:oooo0P000003VfFA
0000oooo00;oool4000000>Y_NP0000000000`1:b@040000UV:B0000[7:A0`0002_oool00`000?oo
ooooo`0Doooo000Ioooo00<0003oooooool0@?ooo`<0001foooo0P000005oooo00000000SEF90000
00Goool4000000FY_NP000000000002bNI@00`000003hjVG00000000008000001:Vmj00000000000
00:UJH`00`0009iPQ`000004000000>Y_NP0002>FXh00XiJSP060000ZKgX0000XR400000U5j?1@00
0009ZKgX0000R4b00000lj]e0000XVF;0000l:n500800000178oQ0000000000000>TJ8d010000:U[
RP0009mRR@<000001:9TR0000:iaSJiaS@P000001JVmj00008I@R0000:9VS002000000BSI8L00000
00000002Q5>?10000003ZV^90000000000800002XfN<00@0003PXa`0002VIhT2000000>8DXT00000
00000P000006I3=o000000000000X6J=00000Z5US0070000G2in00000000ahF;0000Q52:00<00000
2n6=K@000:5URZ5URP000>BOQ`000:E[SP000?R]A`000002YfZ;00<0003e/Wd000000Y5IR`030000
XFJ=XFJ=008000000jEZSP000000000200000ZVmj0050000Se^?Se^?0000Z6nA008000000jU^S`00
0000000300000X/=00030000Qe:;Qe:;00<00002ZW2B00<0002/LI0000000P000005QE:=0000ZKgX
0000TEjB008000000imWT0000:I]T003000000>Y_NP0000000000^Ek60050000TV2DTV2DTV2D0000
00>=F8d2000000G>SHd000000000002Y_NP00P000004KcYo00000000ZKgX30000003ZKgX00000000
00H00002UVRK00D0002FHI000000002Y_NP01@000006ZKgX00000000mZ9D0000VF2<1`0000:BHYH0
0`000:AZSP000002V6>A0`000003ZKgX0000000000<000001:Vmj00000000:Vmj0D000001JVmj000
000000000:Vmj00400000[1fT`030000VF6>0000008000000jVmj00009=QU003Tf6D00@0002AGI2A
GI2AGI03000000>Y_NP00000000030000003ZKgX0000000000l00003ZKgX00<0002BGI0000001@00
0003ZKgX0000000000800002lI@d00<0002JHhnJHhl0100000;LLP000`0009QRT9QRT002000000>Y
_NP0002AGi<00Y5OT`030000Ld:6000000:CHI<00`0009eVT@000004000000>Y_NP0000000003000
0003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000`000005ZKgX00000000
0000ZKgX00D000001:Vmj00000000:Vmj0T000000jVmj00000000003000000>Y_NP0000000002000
00goool300001?ooo`<000001:Vmj00005LhT@000080B/T0100009IRTP000:abT@<0000[oooo00<0
003oooooool05?ooo`006Oooo`030000oooooooo03goool30000NOooo`030000oooooooo00800000
0heER@000?ooo`05oooo10000004ZKgX00000000/WVD0`000004hjVG00000000ZKgX1@0000:UJH`0
0`0009iPQ`000004000000>Y_NP0002>FXh00XiJSP<000000j8Q000009ANS`03000000^Y_NP00000
00000028C800003cZgD0002RIH/0003`[hD00P000004LSn40000LSn400000jAXS@040000ZF^:0000
Wf:90`000005XVB80000[W6=0000l<=;00P0000018I@R0000:9VS:9VS0@000001O2DBP0008ACS`00
0>b9<`03000000>ZJhT0000000000P0000:SIh`010000>2S70000:IWR@8000000hQBR@0000000002
000000IT<gl000000000002PIXd00002XFF<00L0001L;Wh000000037QH/00024D8X00`000004hHe]
0000XFF:XFF:0`000004YF^>0000n:e700000ZMZR`030000mK9m000000:AFH/00`000:5VSJ5VS@02
000000>UJXh0000000000P0000:Y_NP01@0008mKShmKS`000:Q_T@02000000>YKXl0000000000`00
00:;3@000`0008MBRhMBR`0300000ZY`TPD000001HEBS@000:Vmj000095NTP02000000>OIi00002V
KI001P0000;UNaP01@00099PU99PU99PU0000003SER=0P000003cXf=0000000000@000001FljO`00
000000000:Vmj005000000FY_NP000000000002Y_NP01P0000:Y_NP01P0009IXViIXViIXV`0009IQ
T0@000000jVmj00000000004000000?fXU@0002IH8`01`0000:BHYH00`000:AZSP000002V6>A2P00
0003ZKgX0000000000<000000jVmj00000000006000000KfXU<0002`MY>`MY<0002IHHh5000019=Q
U0040000TEf@TEf@TEf@10000003ZKgX0000000000<000001JVmj000000000000:Vmj00B000000>Y
_NP0000000000jVmj0030000TUf@000000X00002lI@d00<0002JHhnJHhl0100000;LLP000`0009QR
T9QRT002000000>Y_NP0002AGi<00Y5OT`030000Ld:6000000:CHI<00`0009eVT@000002000000>Y
_NP0000000001P000005ZKgX000000000000ZKgX00D000000jVmj00000000003000000>Y_NP00000
00002P000003ZKgX0000000000`000000jVmj0000000000;000000>Y_NP0000000002000017oool3
00001Oooo`@0000025LhT@00001:b@1:b@0009IRTP000:abT@<0000[oooo00<0003oooooool05?oo
o`006Oooo`030000oooooooo03[oool30000O?ooo`030000oooooooo008000000heER@000?ooo`06
oooo1P000005/WVD000000000000hjVG00P00002YFV<00<0002NH8L0000010000005ZKgX0000SUZ>
SUZ>000000:?Fhl010000:8Q000009ANS`@00002ZKgX00@00028C80000000002XVF;00P0003`[hD0
0000001b?h@0001b?h@00003Y6R=00@0002YJhX0002OHXT3000000FRI8P0002^LHd0003``d/02000
0004QU280000XVJ<XVJ<10000005l9A:0000Q5>?0000k8Tc00<000000jY[R@000000000200000Z=W
S0080000h:<L0000YVN90000R5:90000WF><0`000007I3=o0000bXN;0000X6J=0000XFF<00800000
1U`^OP0000000<N5R`0008A@RP<000001>6=K@000:5URZ5URP8000001JE[SP0000000?R]A`000002
YfZ;0P0000>AFH/00`000:5VSJ5VS@02000000>UJXh0000000000P0000:Y_NP01@0008mKShmKS`00
0:Q_T@02000000JYKXl000000000002Y_NP00002R`d000<00027DX^7DX/00`0000:ZL985000000F5
DXd0002Y_NP0002AGY800P000003WfN@0000YVf@00H00002iG/H0P0000:BH9@0100008eHSHeHSHeH
S@8000000lj=S@0000000002000000>Y_NP0001_>Wl02P000003ZKgX0000000000<000000jVmj000
00000003ZKgX00@0002FJ9^FJ9/00002UV6@1`000007ZKgX000000000000mZ9D0000VF2<00<00000
1ZVmj00000000000NP00099RUP<00002V6>A0P000005ZKgX000000000000ZKgX00D000000jVmj000
00000003000000>Y_NP00000000010000006mZ9C00000000/7JC0000VF6>1@0000BCHI@01000095M
T95MT95MT08000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000L00000
0jVmj0000000000200000jVmj0030000TUf@000000@000001JVmj000000000000:Vmj002000000Ca
U3@0002JHhnJHhl400000]ab00030000V6:@V6:@008000000jVmj000095OT`02TEnC00<0001c@XH0
00000Y=QT`030000WFJA000000T000000jVmj00000000005000000>Y_NP0000000000`000003ZKgX
0000000000`000000jVmj0000000000:000000>Y_NP0000000000`000003ZKgX0000000000<00000
1JVmj000000000000:Vmj00900005?ooo`<00005oooo10000008EcRA000004[904[90000UV:B0000
[7:A0`0002_oool00`000?ooooooo`0Doooo000Ioooo00<0003oooooool0=oooo`<0001ooooo00<0
003oooooool00P000003SEF90000oooo00Ooool2000000BY_NP00000002bNI@5000000FY_NP00000
0000002Y_NP00P0000:UJH`7000000JY_NP0002>FXj>FXh0002?Fhl2000000>R8@00002DGXl01000
00:Y_NP0100008Q<P000000000:RIH/020000?2_Q@000000078oQ000078oQ00000>TJ8d010000:U[
RP0009mRR@<000001J9TR0000:iaS@000?33B`08000000B6D8P0002RIXbRIX`4000000G`U4X00024
Dhl0003/RC<00`000003ZV^90000000000800002XfN<00<0003PXa`000000P000003R5:90000WF><
00<000001f@cO`000<Z7R`000:1VS@000:5US002000000]L;Wh000000037QH/00024D8X0002dN900
003QSFd000000Z5URP8000001JE[SP0000000?R]A`000002YfZ;0P0000>AFH/00`000:5VSJ5VS@02
000000RUJXh000000000001nC8/0002Y_NP00002Se^?00<0002XKi4000000`0000>Y_NP0100008/=
08/=000000:7DX/300000ZY`TPD00002QE:=0`000003biBL0000WfN@00P00002iG/H0P0000:BH9@0
100008eHSHeHSHeHS@T000000fljO`0000000004000000>Y_NP0000000000`000003ZKgX00000000
00D00002ZKgX00@0002FJ9^FJ9/00002UV6@1@000003ZKgX0000000000<000000oJRE00009UPS004
000000FY_NP000000000002BHYH00`000003V6>A0000ZG2A00P000000jVmj00000000003000000FY
_NP000000000002Y_NP01@000006mZ9C00000000/7JC0000VF6>1@0000BCHI@01000095MT95MT95M
T0@000000jVmj00000000003000000>Y_NP0000000002P000003ZKgX0000000000/00002ZKgX00<0
002BGI2BGI000P000003ZKgX0000000000H000001?6D=00009YSSiYSS`D000001=ab000009QRT9QR
T08000000jVmj000095OT`02TEnC00D0001c@XH0002CHI<000000YeVT@H000000jVmj00000000003
000000FY_NP000000000002Y_NP01@000004ZKgX00000000ZKgX1@000005ZKgX000000000000ZKgX
00D000000jVmj0000000000:000000>Y_NP0000000000`000003ZKgX0000000000`0000Goooo0`00
00Goool2000000CJL`00001G>940000204[900@0002FHY80002/LY430000;?ooo`030000oooooooo
01?oool001Soool00`000?ooooooo`020000<oooo`<00025oooo0P000003SEF90000oooo00SooolA
00000ZEYS0L000001ZVmj00008iJSXiJSP0008mKS`8000000j8Q000009ANS`0400000ZVmj0040000
R4b0000000000Z9UR`080000l:n500000000LSn40000LSn400000jAXS@800002Wf:9100000:^LHd0
0`000?33B`000002000000?8Q8T0000000000P000004QU280000XVJ<XVJ<10000005l9A:0000Q5>?
0000k8Tc00<000001:Y[R@000000000000>SIh`00`000>2S70000002000000>8DXT0002MHh`01@00
0005bXN;0000X6J=0000XFF<008000002e`^OP0000000<N5R`0008A@RP000;AhT0000>6=K@000002
XFF:0P000005YF^>00000000n:e7000000:WJX/200000Y5IR`8000001J5VS@00000000000:EZSP03
000000AnC8/0002Y_NP00002Se^?00<0002XKi4000000`0000>Y_NP0100008/=08/=000000>7DX/0
1@000:Y`TZY`TP000:aaT00400000XEBS@<000000l^DW00009mWT005000000>Y_NP0000000000^Ek
60800002TV2D00@0002=F8f=F8f=F8d9000000=_>Wl0000000000P000003ZKgX0000000000<00000
0jVmj0000000000400000ZVmj0800002ZKgX0P0000>FHI0=000000>IH8`0000000001P000007TV:F
000000000000V6>A0000ZG2A00H000000jVmj00000000003000000>Y_NP0000000001@000005ZKgX
000000000000mZ9C008000000k1fT`0009UQSP0600000i=QU0040000TEf@TEf@TEf@2`0000:OPK<4
000000FY_NP000000000002Y_NP020000005ZKgX000000000000ZKgX00800002ZKgX00<0002BGI2B
GI0010000003ZKgX0000000000@000001?6D=00009YSSiYSS`8000001JVmj00000000=ab00000002
V6:@0P0000:Y_NP02000095OT`00000007=2QP0009=QT`0000:MIY48000000>Y_NP0000000003000
0003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000`000005ZKgX00000000
0000ZKgX00D000000jVmj0000000000:00001?ooo`030000oooooooo01Goool200001Oooo`800000
1mYc000005LhTELhT@00001:b@000002UV:B0`000003WFJA0000oooo02[oool00`000?ooooooo`0C
oooo000Hoooo0`0003;oool30000R?ooo`<0000<oooo2@000006ZKgX000000000000ZKgX00000ZEY
S08000000o6IEP0000000002000000JY_NP0002>FXj>FXh0002?Fhl2000000>R8@00002DGXl01000
00:Y_NP0100008Q<P000000000:RIH/020000?2_Q@000000078oQ000078oQ00000>TJ8d200000YmR
R@@00002[W6=00<0003``d/000000P000003b8B9000000000080000018I@R0000:9VS:9VS0@00000
1O2DBP0008ACS`000>b9<`03000000BZJhT0000000000002XfN<0P000007h:<L000000000000R5:9
0000WF><00D000001LZ7R`000:1VS@000:5US002000000AL;Wh000000037QH/3000000BdN900003Q
SFd00002XFF:0P000005YF^>00000000n:e7000000:WJX/200000Y5IR`8000001J5VS@0000000000
0:EZSP03000000UnC8/0002Y_NP0002?Fhl0002XKi40002`MI000`0000>Y_NP0100008/=08/=0000
00>7DX/01@000:Y`TZY`TP000:aaT00400000XEBS@@00002WfN@200000;UNaP200000Y9PU0040000
SER=SER=SER=2@000003KcYo0000000000D000000jVmj0000000000600000jVmj0040000UAX00000
ZKgX0P0000>FHI08000000>Y_NP0000000000P000003VF2<00000000008000001JVmj00000000000
099RUP03000000>HHi40002YL9400P000003ZKgX0000000000<000000jVmj00000000007000000BY
_NP00000002Y_NP2000000SfXU<00000002`MY<0002IHHh0002Y_NP400000i=QU0040000TEf@TEf@
TEf@1`000003ZKgX0000Wh6c00:OPK<00`0009MUUP00000=000000>Y_NP0000000001P0000:Y_NP0
0`00099MT99MT005000000>Y_NP0000000000`000004lI@d0000VV>?VV>?1@000004g7800000V6:@
V6:@0`000003ZKgX0000TEnC0080000017=2QP0009=QT`0000:MIY42000000FY_NP000000000002Y
_NP020000005ZKgX000000000000ZKgX00D000000jVmj0000000000@000000>Y_NP0000000005000
00Woool00`000?ooooooo`0Doooo0P0000Koool00`000=Yc00000002EcRA00<00000B/T000000YIR
TP<000000ieVT@000?ooo`0Zoooo00<0003oooooool04oooo`006?ooo`030000oooooooo033oool2
0000Roooo`<0000=oooo1@000005ZKgX000000000000ZKgX00@00002YFV<0P000003lIUF00000000
008000001:Vmj00008iJSP0000:?Fhl3000000>DGXl0000000000`0000:Y_NP0100008Q<P0000000
00:RIH/020000?2_Q@000000078oQ000078oQ00000>TJ8d2000000>OHXT0000000000`0000:^LHd0
0`000?33B`000002000000?8Q8T0000000000P000004QU280000XVJ<XVJ<10000005l9A:0000Q5>?
0000k8Tc00<000001:Y[R@000000000000:SIh`2000000OPXa`0000000000028DXT0002MHh`01@00
0005bXN;0000X6J=0000XFF<008000002e`^OP0000000<N5R`0008]DRP000;AhT0000>6=K@000002
XFF:0P000005YF^>00000000n:e7000000:WJX/200000Y5IR`8000000j5VS@0000000002000000c<
S8h00000001nC8/0002Y_NP0002?Fhl0002XKi40002`MI0400000ZVmj0040000R`d0R`d000000hMB
R`050000ZW2BZW2B0000[76@00@00002QE:=100000:OIi0800000^Ek60800002TV2D00@0002=F8f=
F8f=F8d9000000E_>Wl000000000002Y_NP01@000005ZKgX000000000000ZKgX00800003ZKgX00<0
002E6P2E6P000P0000>FHI05000000>Y_NP0000000001P000003VF2<0000000000H000001i9RUP00
0000000009QST@000:U`T@09000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00@00002
mZ9C00@0002`MY<0002IHHh600000i=QU0040000TEf@TEf@TEf@1@0000BY_NP300000YMUUPH00000
1JVmj000000000000:Vmj005000000>Y_NP000000000100000:Y_NP00`00099MT99MT007000000JY
_NP000000000003aU3@00002VV>?0P000005ZKgX00000000g780000000:HHY03000000FY_NP0002A
Gi<0003]SBP00P000004Tf6C0000WFJAWFJA3@000003ZKgX0000000000X000000jVmj00000000003
000000>Y_NP0000000001`000003ZKgX0000000000X000000jVmj00000000003000000BY_NP00000
0000000;oooo00<0003oooooool05?ooo`800006oooo00<0003JL`0000000ULhT@03000004[90000
00:FHY83000000>MIY40003oool0:_ooo`030000oooooooo01?oool001Soool00`000?ooooooo`0]
oooo0`0008goool300003Oooo`<000000jVmj0000000000800000ZEYS08000000o6IEP0000000002
000000NY_NP0002>FXh0002?Fhl0002@G9400P000003U5j?0000000000<00002ZKgX00@00028C800
00000002XVF;100000=b?h@010000:AXSJAXSJAXS@8000000imRR@000000000300000ZiaS@040000
l<=;0000ZKgX0P000007mK9m000000000000QU280000XVJ<00D000001O2DBP0008ACS`000>b9<`04
000000?d/7h0000000000Z=WS08000001n2S70000000000008QBR@0009eSS005000000?:Qh/00000
00000Z5US08000001e`^OP0000000<N5R`0008]DRP000002]7R@0P000005XFF:0000i9n70000YF^>
008000001?R]A`000:MZRjMZR`800002TEV;0P000003XFJ=00000000008000003<b<SP00000007i<
R`000:Vmj00008mKS`000:Q_T@000;1eT0@00002ZKgX00@0002;3@2;3@000003Qe:;00D0002ZL9:Z
L980002/LI00100000>5DXd00`000<^DW0000002WfN@1P000004ZKgX00000000iG/H0P0000:BH9@0
100008eHSHeHSHeHS@L000000jVmj00006ljO`07000000BY_NP00000002Y_NP500000jVmj0800002
UAX000@0002FHI2FHI2FHI03000000>Y_NP00000000020000005VF2<000000000000ZKgX00@00000
1i9RUP000000000009QST@000:U`T@0;000000>Y_NP0000000002P0000;fXU<200000YUQSPH00003
Tf6D00@0002AGI2AGI2AGI0:00000iMUUP030000XF^C0000008000000jVmj0000000000:000000>Y
_NP0000000000`0000:Y_NP01000099MT99MT99MT0@000000jVmj00000000003000000CaU3@0002J
HhnJHhl3000000BLNJ/0003LLP000002V6:@0`000005ZKgX0000TEnC0000kHdX0080000019=QT`00
09eVTIeVT@D000001JVmj000000000000:Vmj005000000>Y_NP0000000002P000003ZKgX00000000
00<000001JVmj000000000000:Vmj005000000>Y_NP0000000002P000003ZKgX000000000080000?
oooo00<0003oooooool04oooo`800006oooo00H0003JL`000000001G>940000204[900<0002FHY80
00000P000003WFJA0000oooo02[oool00`000?ooooooo`0Coooo000Hoooo00<0003oooooool0:_oo
o`<0002@oooo0`0000goool5000000>Y_NP0000000001P0000:UJH`2000000?aVEH0000000000`00
00:>FXh0100008mKS`00091LT@80000019ANS`0000000:Vmj0800002ZKgX100000:RIH/400000g8o
Q0040000Y6R=Y6R=Y6R=0P000003Wf:90000000000<00002[W6=00<0003``d/000001`000003QU28
0000XVJ<00D000001O2DBP0008ACS`000>b9<`04000000?d/7h0000000000Z=WS08000001n2S7000
0000000008QBR@0009eSS005000000?:Qh/0000000000Z5US08000001e`^OP0000000<N5R`0008]D
RP000002]7R@0P000005XFF:0000i9n70000YF^>008000001?R]A`000:MZRjMZR`800002TEV;0P00
0006XFJ=00000000YFZ>0000c8b>0P000009OTb;0000ZKgX0000Se^?0000Z6nA0000/7F@00@00002
ZKgX00@0002;3@2;3@000003Qe:;00D0002ZL9:ZL980002/LI00100000>5DXd00`000<^DW0000002
WfN@2@000003iG/H0000000000:BH9@0100008eHSHeHSHeHS@T000000fljO`0000000006000000>Y
_NP0000000000`000003ZKgX0000000000:Y_NP200000YDJ00040000UV6@UV6@UV6@1P000005ZKgX
000000000000ZKgX00<000000iUPS0000:Vmj002000000FY_NP000000000002BHYH00`000003V6>A
0000ZG2A00D000001JVmj000000000000:Vmj008000000>Y_NP0000000000`0000;fXU<200000YUQ
SP@000000jVmj00009=QU002Tf6D00@0002AGI2AGI2AGI0200000ZVmj0030000TEnCTEnC00:AGi<0
1P0009MUUYMUUYMUUP000:5[T`D000000jVmj0000000000:000000BY_NP0000000000002ZKgX00@0
002BGI2BGI2BGI0600000ZVmj08000001O6D=00009YSSiYSS`000003W7V[00<0003LLP0000000YQR
T0<000001JVmj000095OT`000>f=:002000000BCHI<0002MIY6MIY43000000>Y_NP0000000005000
0003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000`000005ZKgX00000000
0000ZKgX0080000Doooo00<0003oooooool04_ooo`800006oooo00@0003JL`3JL`000002EcRA00@0
0000B/T0002FHY83000000>MIY40003oool0:_ooo`030000oooooooo01?oool001Soool00`000?oo
ooooo`0Woooo0`0009?oool300003Oooo`8000001Oooo`00000000000:Vmj005000000BY_NP0002U
JHbUJH`2000000?aVEH0000000000`0000:>FXh0100008mKS`00091LT@80000029ANS`0000000:Vm
j00008iIS@000:Vmj0@000000j9UR`000?2_Q@0300000g8oQ0040000Y6R=Y6R=Y6R=0P000003Wf:9
0000000000<00002[W6=00<0003``d/000001`000003QU280000XVJ<00D000001O2DBP0008ACS`00
0>b9<`05000000BkO8l0002SIhbSIh`3000000JVIhT000000028DXT0002MHh`800000Z5US0800000
1e`^OP0000000<N5R`0008]DRP000002]7R@0P000005XFF:0000i9n70000YF^>008000001?R]A`00
0:MZRjMZR`800002TEV;0P000006XFJ=00000000YFZ>0000c8b>0P000009OTb;0000ZKgX0000Se^?
0000Z6nA0000/7F@00<0000018ICS@000:Vmj00000:;3@001@0008MBRhMBRhMBR`000002ZW2B00<0
002/LI0000000`0000>5DXd01P000<^DW00009mWT0000:I]T0@000001JVmj000000000000>Ek6002
00000Y9PU0050000SER=SER=0000Z6f?00d000000jVmj00000000003000000>Y_NP0000000000P00
0004VG6T0000ZKgXZKgX0P0000:E6P00100009IQT9IQT9IQT0h0000019UPS00000000:Vmj0D00000
2I9RUP000000000009QST@000:U`T@000:Vmj00>000000>Y_NP0000000000`000004ZKgX0000mZ9C
mZ9C0P0000:IHHh6000019=QU0050000TEf@0000XFV@000000:Y_NP00`00095OTi5OT`02TEnC00H0
002GIIJGIIJGIIH0002QJi<6000000>Y_NP0000000000`000005ZKgX000000000000ZKgX00H00000
0jVmj000099MT002TUf@1@0000>Y_NP200000_6D=0050000VV>?00000000W7V[008000001=ab0000
09QRT9QRT0D000001I5OT`000>f=:00007=2QP0200000YeVT@D000000jVmj0000000000:000000FY
_NP000000000002Y_NP01@000003ZKgX00000000010000000jVmj0000000000600005_ooo`030000
oooooooo01?oool00`000?ooooooo`05oooo00<0003JL`0000000ULhT@04000004[90000UV:B0`00
0003WFJA0000oooo02[oool00`000?ooooooo`0Coooo000Goooo00<0003oooooool09Oooo`<0002F
oooo0`0000goool200000_ooo`D000000jVmj0000000000200000ZEYS08000000o6IEP0009iUS`03
000000J>FXh0002?Fhn?Fhl0002@G942000000RDGXl00000002Y_NP0002>FHd0002Y_NP4000000>R
IH/0003`[hD00`0000=b?h@010000:AXSJAXSJAXS@80000019mRR@00000005@QL`800002[W6=00<0
003``d/00000200000:RIX`5000000G`U4X00024Dhl0003/RC<01@000004^gb?0000XfN<XfN<0`00
0004YVN90000000000000YeSS0P00002XFF<0P000007G2in0000ahF;ahF;0000ReB:000000:dN902
000000FQIHX0003TWhL0002UJhh00P000004n:e70000YfZ;YfZ;0P0000:AFH/2000000JQIXd00000
002UJXh0003<S8h200000Wi<R`8000001HmKS`000:Q_T@000;1eT003000000B6Dhd0002Y_NP00002
R`d000D00027DX^7DX^7DX/000000ZY`TP030000[76@000000<00003QE:=00H0003;U9`0002OIi00
002VKI05000000BY_NP00000003UNaP200000Y9PU0050000SER=SER=0000Z6f?00<000001JVmj000
000000000:Vmj008000000BY_NP0000000000002Tf:E00@0002ILJBILJ@00002ZKgX0P0000:E6P00
100009IQT9IQT9IQT0T000000jVmj00000000002000000>IH8`0000000000P000003ZKgX00000000
008000001Y9RUP00000009QST@000:U`T@P000001JVmj000000000000:Vmj005000000>Y_NP00000
00000`0000;fXU<200000YUQSPL00003Tf6D00D0002AGI00002QJI0000000ZVmj0030000TEnCTEnC
00:AGi<01P0009MUUYMUUYMUUP000:5[T`P000000jVmj0000000000<000000>Y_NP0002BGI000Y9M
T0<000000jVmj0000:Vmj002ZKgX00H0002BGi40003aU3@0002JHhl6000000GLLP00002HHY00002Y
_NP00`000004TEnC0000kHdXkHdX0`0000:MIY4@000000>Y_NP0000000002P000003ZKgX00000000
00<000000jVmj00000000007000000>Y_NP000000000100001_oool00`000?ooooooo`0Boooo00<0
003oooooool01Oooo`030000fW<00000009G>9401000001:b@0009IRTP<000000ieVT@000?ooo`0[
oooo00<0003oooooool04_ooo`005oooo`030000oooooooo02;oool30000VOooo`80000>oooo0P00
00?oool2000000>Y_NP000000000100000:UJH`2000000CaVEH00000002=F8`2000000B>FXh0002?
Fhl00002T5bA100000:Y_NP0100008iIS@000:Vmj0@000000j9UR`000?2_Q@0300000g8oQ0040000
Y6R=Y6R=Y6R=0P000004Wf:900000000E25c0P0000:^LHd00`000?33B`000004000000B@G9000000
00000002XVJ<1@000005l9A:000000000000k8Tc00D000001;]lS`000:=WS:=WS0<000001:IWR@00
0000000000:MHh`800000Z5US08000001e`^OP000<N5RlN5R`0008]DRP000002]7R@0P000005XFF:
0000i9n70000YF^>008000001?R]A`000:MZRjMZR`800002TEV;0P000006XFJ=00000000YFZ>0000
c8b>0P00009nC8/2000000F?Fhl0002XKi40002`MI000`000004QU>=0000ZKgX00000X/=00050000
Qe:;Qe:;Qe:;000000:ZL9800`000:aaT000000300000hEBS@800002WfN@00<0002VKI0000000P00
0003ZKgX00000000008000000nEk600000000002TV2D00D0002=F8f=F8d0002XKHl03P000004ZKgX
00000000000019=RU@040000VG6T000000000ZVmj0800002UAX000@0002FHI2FHI2FHI07000000>Y
_NP00000000010000003VF2<0000000000L000001Y9RUP00000009QST@000:U`T@8000001JVmj000
000000000:Vmj00B000000?fXU<0000000000YUQSP030000ZKgX0000008000000jVmj00009=QU002
Tf6D00D0002AGI00002QJI0000000ZVmj0030000TEnCTEnC00:AGi<0100009MUUYMUUP0000:QJi<2
000000FY_NP000000000002Y_NP020000005ZKgX000000000000ZKgX00<000000jVmj000099MT002
TUf@00<0002Y_NP000000P0000>Y_NP01P00099OT@000?6D=00009YSS`8000001jVmj00000000000
0=ab000009QRT005000000BAGi<00000003]SBP200000ieVT@8000000jVmj00000000003000000FY
_NP000000000002Y_NP01@000003ZKgX0000000000X000000jVmj00000000003000000FY_NP00000
0000002Y_NP01@00027oool00`000?ooooooo`0Aoooo00<0003oooooool01Oooo`030000fW<00000
009G>9401000001:b@0009IRTP<000000ieVT@000?ooo`0[oooo00<0003oooooool04_ooo`005ooo
o`030000oooooooo01ooool30000W?ooo`80000>oooo0P0000Coool4000000>Y_NP0000000000P00
0004YFV<00000000lIUF0P000007SER<00000000SUZ>0000Se^?000000:@G94400000ZVmj0040000
SUV=0000ZKgX10000003XVF;0000l:n500<00003LSn400@0002TJ8fTJ8fTJ8d2000000ROHXT00000
0000002RI8P0002^LHd00002l<=;1@000004T5b@0000000000000Z9VS0D000001O2DBP0000000000
0>b9<`05000000BkO8l0002SIhbSIh`3000000BVIhT0000000000002WF><200000:QIH`0100009iU
SP00000000;7QH/00`0008]DRP000002]7R@0P000005XFF:0000i9n70000YF^>008000001?R]A`00
0:MZRjMZR`800002TEV;0P000004XFJ=00000000YFZ>0P000004ZKgX0000OTb;OTb;0`0000:XKi40
0`000;1eT0000002000000B6Dhd0002Y_NP00002R`d000D00027DX^7DX^7DX/000000ZY`TP030000
[76@000000<00004QE:=00D0002OIi2OIi00002VKI001@000004ZKgX00000000iG/H0P0000:BH9@0
1@0008eHSHeHS@000:Q]S`06000000>Y_NP0000000001P0000:Y_NP00`0009=RUI=RU@02Tf:E0P00
0004VVRF0000ZKgXZKgX0P0000:E6P00100009IQT9IQT9IQT0<000000jVmj00000000003000000>Y
_NP0000000000P000003VF2<0000000000X000000iQST@000:U`T@08000000>Y_NP0000000002P00
0004ZKgX0000000000000_JRD`030000VF6>VF6>00L00003Tf6D00D0002AGI00002QJI0000000ZVm
j0030000TEnCTEnC00:AGi<01@0009MUUYMUUP000:5[T`0>000000>Y_NP0000000001`000003ZKgX
0000TUf@00:BGI0600000ZVmj0060000TUnA0000lI@d0000VV>?1P000003g7800000V6:@00P00000
0nf=:00000000003WFJA1P000003ZKgX0000000000X000000jVmj00000000003000000FY_NP00000
0000002Y_NP01@000003ZKgX0000000000H0000Uoooo00<0003oooooool06?ooo`040000fW<00000
00000ULhT@8000001YIRTP000:abT@0009eVT@0002coool00`000?ooooooo`0Boooo000Goooo00<0
003oooooool07?ooo`<0002Ooooo0P0000koool200001Oooo`P000001:EYS00000000?6IEP800000
1heHS000000008iJSP0008mKS`000002T5bA100000:Y_NP0100008iIS@000:Vmj08000001O>[M@00
0:9UR`000?2_Q@0300000g8oQ0040000Y6R=Y6R=Y6R=0P000008Wf:9000000000000XVB80000[W6=
00000_33B`T00002XVJ<1@000005l9A:000000000000k8Tc00L00002XfN<0`000004YVN900000000
00000YeSS0P00002XFF<00H0002NIHh000000037QH/00002ReB:00<0002dN90000000P000005XFF:
0000i9n70000YF^>008000001?R]A`000:MZRjMZR`800002TEV;0P000004XFJ=00000000YFZ>0P00
0004ZKgX0000OTb;OTb;0`0000:XKi400`000;1eT000000200000XICS@800002R`d000D00027DX^7
DX^7DX/000000ZY`TP030000[76@000000<00004QE:=00D0002OIi2OIi00002VKI0020000003iG/H
0000000000:BH9@01@0008eHSHeHS@000:Q]S`04000000>Y_NP0000000001`0000>Y_NP00`0009=R
UI=RU@02Tf:E00@0002JJ9JJJ9H00002ZKgX0P0000:E6P00100009IQT9IQT9IQT0H000001JVmj000
000000000:Vmj003000000>IH8`0002Y_NP01@000003ZKgX00000000008000000iQST@000:U`T@05
000000FY_NP000000000002Y_NP01@000005ZKgX000000000000ZKgX00D00002mZ9C00<0002IHHjI
HHh010000003ZKgX0000000000>CHI@01@00095MT0000:5YT0000003ZKgX00D0002AGi>AGi>AGi<0
00000YMUUP030000XF^C000000D000001JVmj000000000000:Vmj005000000>Y_NP0000000001@00
0003ZKgX0000TUf@00:BGI0600000jVmj08000000o6D=00009YSS`02000000NY_NP000000000003L
LP00002HHY001P000003ZKgX0000kHdX00800003WFJA0P000003ZKgX0000000000<000000jVmj000
0000000:000000>Y_NP0000000001`000003ZKgX0000000000<000000jVmj0000000000200009ooo
o`030000oooooooo01Woool300000ULhT@8000000iIRTP000:abT@030000;?ooo`030000oooooooo
01;oool001Ooool010000?ooo`00000001Woool20000X_ooo`80000>oooo00<0003oooooool01Ooo
o`D000000jVmj0000:EYS003000000>NIHl0002=F8`00`0000:?Fhl00`00091LTI1LT@0400000ZVm
j0040000SUV=0000ZKgX0P000005lj]e0000XVF;0000l:n500<00003LSn400@0002TJ8fTJ8fTJ8d2
000000ROHXT000000000002RI8P0002^LHd00002l<=;2@0000:RIX`3000000?e/Wd0003`U4X00`00
0003k8Tc0000000000D00002XfN<0`000004YVN90000000000000YeSS0P00002XFF<00H0002NIHh0
00000037QH/00002ReB:00<0002dN90000000P000005XFF:0000i9n70000YF^>008000001?R]A`00
0:MZRjMZR`800002TEV;0P000004XFJ=00000000YFZ>0P000004ZKgX0000OTb;OTb;0`0000:XKi40
0`000;1eT000000200000XICS@800002R`d000L00027DX^7DX^7DX/0002ZL98000000ZaaT0@00004
QE:=00D0002OIi2OIi00002VKI0020000006iG/H0000Kd280000TV2D00000XeHS@030000Z6f?0000
00X000001:Vmj0000000000000:Y_NP00`0009=RUI=RU@02Tf:E00H0002JJ9JJJ9JJJ9H0002Y_NP2
00000YDJ00040000UV6@UV6@UV6@10000003ZKgX0000000000L000001IUPS000000000000:Vmj007
000000BBHYH00000002YL943000000>Y_NP0000000002P000003ZKgX0000000000H00002mZ9C00<0
002IHHjIHHh00P000003ZKgX0000000000<00002Tf6D00@0002AGI00002QJI0200000ZVmj0050000
TEnCTEnCTEnC000000:GIIH00`000:5[T`000003000000>Y_NP0000000002P000003ZKgX00000000
00@00002ZKgX00<0002BGI00000010000003ZKgX0000ZKgX00:Y_NP2000000?aU3@0002JHhl00`00
0006ZKgX00000000g7800000V6:@200000;]SBP0100009eVTIeVTIeVT@T000000jVmj00000000007
000000>Y_NP000000000400002coool00`000?ooooooo`0Hoooo0`00009G>942000000>FHY80002/
LY400`0002coool00`000?ooooooo`0Boooo000Goooo0P0001Soool30000Y?ooo`80000>oooo00<0
003oooooool01_ooo`8000000jVmj00000000005000000>NIHl0002=F8`00`000006Se^?00000000
T5bA0000ZKgX0`0000:Y_NP02`0008iIS@00000008iJSP000?>[M@000:9UR`000?2_Q@0300000g8o
Q0040000Y6R=Y6R=Y6R=0P00000;Wf:9000000000000XVB80000[W6=0000l<=;0000ZKgX00P00002
XVJ<10000003l9A:0000Ld:6008000000nb9<`000000000500000Z=WS0<000001:IWR@0000000000
00:MHh`800000Z5US0060000WVF>00000000ahF;00000X]DRP030000]7R@0000008000001J5URP00
0>BOQ`000:E[SP02000000Ch[DL0002WJX^WJX/200000Y5IR`8000001:5VS@0000000:EZSP800000
1:Vmj00007i<Rgi<R`<000001JQ_T@000;1eT0000:U^S`0200000XICS@800002R`d000L00027DX^7
DX^7DX/0002ZL98000000ZaaT08000000jVmj00008EBS@03QE:=00D0002OIi2OIi00002VKI002000
0006iG/H0000Kd280000TV2D00000XeHS@030000Z6f?0000008000001JVmj000000000000:Vmj005
000000FY_NP0002Y_NRY_NP000000i=RU@800003VVRF00L0002Y_NP0001Y?h/0002E6P0000000iIQ
T0H000000jVmj00000000005000000>IH8`0002Y_NP02@000004TV:F0000ZG2AZG2A1@000003ZKgX
0000000000X000000jVmj0000000000400000_JRD`030000VF6>VF6>00@000001:Vmj00000000000
00:CHI@01000095MT0000:5YT0800002ZKgX00<0002AGi>AGi<00Y5OT`040000UfFF0000XF^C1P00
0003ZKgX0000000000X000002jVmj000000000000:Vmj0000:Vmj000099MT0000:Vmj00500000jVm
j08000000o6D=00009YSS`06000000?LLP00002HHY001P000005ZKgX0000kHdXkHdX000000>MIY4;
000000FY_NP000000000002Y_NP01@000003ZKgX0000000000X0000aoooo00<0003oooooool05ooo
o`<00002EcRA00D00000B/T00000002/LY400`0002coool00`000?ooooooo`0Boooo000Foooo00<0
003oooooool05Oooo`<0002Woooo0P0000koool00`000?ooooooo`07oooo2@000003WVF?0000SER<
00<0000018mKS`000000091LT@@00002ZKgX00<0002>FHf>FHd00P000007SUZ>0000lj]e0000XVF;
0000l:n500<00003LSn400<0002TJ8fTJ8d00ZAXS@030000Wf:9000000<00002[W6=00@0003``d/0
002Y_NP800000Z9VS0@000000o2DBP0007=2QP02000000?/RC<0000000001@0000:SIh`3000000BV
IhT0000000000002WF><200000:QIH`01P0009iUSP0000000<N5R`0000:;E8X00`000;AhT0000002
000000FQIHX0003TWhL0002UJhh00P000004n:e70000YfZ;YfZ;0P000005TEV;000000000000XFJ=
008000001JEZSP0000000:Vmj0000002OTb;0`000005Z6nA0000/7F@0000ZFj?00800003QU>=00@0
002;3@2;3@000003Qe:;00T0002ZL980002/LI00002TJXh0002Y_NP0000018EBS@050000WfN@WfN@
0000YVf@00P000001^Ek600006m0R000099PU00000:=F8d00`000:Q]S`000009000000RY_NP00000
0000002Y_NP0002Y_NP00003Tf:E0P0000>JJ9H01`000:Vmj00006ToR`0009DJ00000003UV6@1`00
0003ZKgX0000000000@000000iUPS00000000002000000FY_NP000000000002Y_NP00P000004TV:F
0000ZG2AZG2A1P000003ZKgX0000000000<000001JVmj000000000000:Vmj005000000>Y_NP00000
00000_JRD`030000VF6>VF6>00D000000jVmj00000000002Tf6D00@0002AGI00002QJI0200000ZVm
j0030000TEnCTEnC00:AGi<200000Z5[T`L000000jVmj00000000003000000FY_NP000000000002Y
_NP01`000003ZKgX0000TUf@00L00003ZKgX0P000003lI@d0000VV>?00<000001ZVmj00000000=ab
000009QRT0P00002kHdX00@0002MIY6MIY6MIY49000000>Y_NP0000000002P000003ZKgX00000000
00<000001:Vmj0000000000003Coool00`000?ooooooo`0Foooo00<0003JL`0000000ULhT@050000
04[900000000[7:A008000000ieVT@000?ooo`0Zoooo00<0003oooooool04_ooo`005_ooo`030000
oooooooo01;oool30000Z_ooo`030000oooooooo01Soool6000000FY_NP0002NIHl0002=F8`00`00
0004Se^?00000000T5bA100000:Y_NP00`0008iISHiIS@02000000F>FXh0003cZgD0002RIH/01@00
00=b?h@00`000:AXSJAXS@02Y6R=00<0002OHXT000000`0000:^LHd010000?33B`000:Vmj0P00002
XVJ<10000003l9A:0000Ld:6008000000nb9<`000000000500000Z=WS0D0000018QBR@0009eSS9eS
S0@000001<Z7R`000000000000:QIH`01P0009iUSP0000000<N5R`0000:;E8X00`000;AhT0000002
000000FQIHX0003TWhL0002UJhh00P000004n:e70000YfZ;YfZ;0P000005TEV;000000000000XFJ=
008000001JEZSP0000000:Vmj0000002OTb;0`000005Z6nA0000/7F@0000ZFj?00800003QU>=0P00
0003R`d00000Qe:;00:7DX/02@000:Y`TP000:aaT0000:AZSP000:Vmj0000003QE:=0P0000:OIi00
0`000:I]T0000007000000KUNaP0001_@8P0002BH9@00002SER=00<0002XKHl00000300000:Y_NP0
10000:Vmj:Vmj00000:CHYD200000iYXUP070000ZKgX0000JCn;0000UAX0000000:FHI0:000000>Y
_NP0000000000`000003ZKgX0000000000X00002ZG2A20000003ZKgX0000000000h00002mZ9C00<0
002IHHjIHHh02@000005Tf6D0000TEf@0000XFV@00<000000jVmj000095OT`03TEnC0P0000:QJi<9
000000>Y_NP0000000001`000003ZKgX0000000000<000000jVmj000099MT00800000ZVmj0800000
0o6D=00009YSS`05000000BY_NP00000002HHY0800000^f=:0060000WFJAWFJAWFJA0000ZKgX0`00
0003ZKgX0000000000<000000jVmj0000000000:000000>Y_NP0000000000P0003Ooool00`000?oo
ooooo`0Foooo00@0003JL`0000000002EcRA0`000005[7:A00000000WFJA000002_oool00`000?oo
ooooo`0Boooo000Foooo00<0003oooooool03oooo`<0002]oooo00<0003oooooool06Oooo`D00000
1:Vmj000000008eHS0@000000hmKS`0000000006000000BY_NP0002>FHf>FHd2000000F>FXh0003c
ZgD0002RIH/0100000Ab?h@00`000:AXSJAXS@02Y6R=00<0002OHXT000000`0000:^LHd010000?33
B`000:Vmj0P00002XVJ<10000003l9A:0000Ld:6008000000nb9<`000000000500000Z=WS0H00003
WF><10000004bXN;0000000000000Z5US0060000WVF>00000000ahF;00000X]DRP030000]7R@0000
008000000j5URP000>BOQ`02000000WdXEl0003h[DL0002WJX/0003e/Wd0002AFH/00`000004XFJ=
00000000YFZ>0P000003ZKgX0000OTb;009nC8/01`000:Q_TJQ_T@000;1eT0000:U^S`0200000hIC
S@8000000h/=000008MBR`03Qe:;0P000006[76@0000Y6Z>0000ZKgX00000hEBS@800002WfN@00<0
002VKI00000010000009ZKgX00000000iG/H0000Kd280000TV2D000000:=F8d00`000:Q]S`000003
000000>Y_NP0000000000`000004ZKgX0000000000000ZVmj0070000ZKgX0000Tf:E0000n^ZS0000
00:JJ9H2000000JY_NP0001Y?h/0002E6P000002UV6@10000005ZKgX000000000000ZKgX00h00000
0jVmj00000000003000000FYL94000000000002Y_NP00`000003ZKgX0000000000H000000jVmj000
00000003000000BY_NP0000000000002mZ9C00D0002IHHjIHHh0002Y_NP00`000009ZKgX00000000
0000Tf6D0000TEf@0000XFV@00<000000jVmj000095OT`03TEnC0P0000:QJi<3000000FY_NP00000
0000002Y_NP020000005ZKgX000000000000ZKgX00@000000jVmj000099MT004000000BY_NP00000
00000002ZKgX00D0002BGi400000002JHhl020000005V6:@000000000000ZKgX00D000000nf=:000
09eVT@02WFJA30000003ZKgX0000000000<000001JVmj000000000000:Vmj0020000??ooo`030000
oooooooo01Koool300000ULhT@<000001JabT@00000009eVT@00000/oooo00<0003oooooool04Ooo
o`005_ooo`030000oooooooo00coool30000/?ooo`030000oooooooo01[oool4000000BY_NP00000
002=F8`9000000JY_NP000000000002Y_NP00002SUV=0P000006SUZ>00000000XVF;0000l:n50`00
00Ab?h@00`000:AXSJAXS@02Y6R=1P0000:^LHd010000?33B`000:Vmj08000000oFbO@0000000002
00000Z9VS0030000m;>30000008000000o2DBP0007=2QP02000000?/RC<0000000001@000003XfN<
0000SEJ;00D00003WF><10000003bXN;0000000000:QIH`00`0009iUSYiUSP02000000?7QH/0002;
E8X00X]DRP@000003Z5URP0000000:E[SP000?BQG`000?R]A`000:MZR`000?FbO@00095IR`<00000
1:5VS@0000000:EZSP8000000jVmj00007i<R`02OTb;00L0002XKi6XKi40002`MI00002YKXl00P00
00>6Dhd2000000>;3@000027DX/00hMBR`8000001ZaaT0000:AZSP000:Vmj00000>5DXd200000YmW
T0030000YVf@000000D000001ZVmj0000>Ek600006m0R00000:BH9@0100008eHS@000:Q]Sa400000
1ZVmj00009=RU@000?[ZX`0000:JJ9H200000ZVmj080000019DJ000009IQT9IQT0D000000jVmj000
00000003000000>Y_NP0000000001`000003ZKgX0000000000<000000iePQ`000:U`T@04000000>Y
_NP0000000001`000003ZKgX0000000000<000000jVmj0000000000300000_JRD`030000VF6>VF6>
00T000001I=QU000095MT0000:5YT003000000>Y_NP0002AGi<00i5OT`800002XF^C3P000003ZKgX
0000000000D000001ZVmj00000000:Vmj000099MT0P00002ZKgX00D0002BGi400000002JHhl02000
0003V6:@0000000000<000001ZVmj000000000000>f=:00000>MIY400`000:Vmj000000;000000>Y
_NP0000000001P0003ooool00`000?ooooooo`0Eoooo0`00009G>943000000F/LY400000002MIY40
0000;?ooo`030000oooooooo017oool001Koool00`000?ooooooo`09oooo0`000=7oool3000000BY
_NP00000002=F8`=000000BY_NP0002>FHf>FHd2000000V>FXh00000002RIH/0003`[hD0002Y_NP0
00000g8oQ0800004Y6R=1P0000:^LHd010000?33B`000:Vmj0L00002XVJ<00<0003d/h<000000P00
0003l9A:0000Ld:600<000000haDR00000000004000000>SIh`0002=EX/01@0000:MHh`5000000?:
Qh/0000000000Z5US0030000WVF>WVF>008000000lN5R`0008]DRP02ReB:1000000>XFF:00000000
YF^>0000m:5O0000n:e70000YfZ;0000mK9m0000TEV;0`000004XFJ=00000000YFZ>0P000003ZKgX
0000OTb;009nC8/01`000:Q_TJQ_T@000;1eT0000:U^S`0200000hICS@8000000h/=000008MBR`03
Qe:;0P000006[76@0000Y6Z>0000ZKgX00000hEBS@80000019mWT0000:I]T:I]T0P000001>Ek6000
06m0R00000:BH9@0100008eHS@000:Q]Sa4000000jVmj00000000003n^ZS00H0002JJ9H0002MIi40
002Y_NP2000000BE6P00002FHI2FHI0A000000>Y_NP0000000000`000007ZKgX000000000000WF27
0000ZG2A00H000001JVmj000000000000:Vmj005000000>Y_NP0000000000`000004ZKgX00000000
00000_JRD`030000VF6>VF6>00@000000jVmj00000000002000000FCHI@0002AGI00002QJI000`00
0003ZKgX0000TEnC00>AGi<010000:5[Tj5[Tj5[T`H000001JVmj000000000000:Vmj005000000FY
_NP000000000002Y_NP010000003ZKgX0000TUf@00P00002ZKgX00D0002BGi400000002JHhl00P00
0003ZKgX0000000000<000001IQRT000000000000:Vmj005000000?]SBP0002MIY400YeVT@800000
0jVmj00000000003000000FY_NP000000000002Y_NP01P0004?oool00`000?ooooooo`0Eoooo0`00
009G>943000000F/LY400000002MIY400000;?ooo`030000oooooooo017oool001Koool00`000?oo
ooooo`07oooo0P000=Coool3000000BY_NP00000002=F8`:000000FY_NP00000002Y_NP000000XiI
S@8000001XiJSP0000000:9UR`000?2_Q@<00003LSn40P0000BTJ8d2000000BY_NP0000000000002
[W6=00@0003``d/0002Y_NP700000Z9VS0030000m;>30000008000000o2DBP0007=2QP03000000B<
E8P00000003d/7h3000000>SIh`0002=EX/01@0000:MHh`2000000BAFH/00000003:Qh/200000Z5U
S0030000WVF>WVF>008000000lN5R`0008]DRP02ReB:1000000>XFF:00000000YF^>0000m:5O0000
n:e70000YfZ;0000mK9m0000TEV;1@0000:UJXh400000gi<R`070000Z6nAZ6nA0000/7F@0000ZFj?
00800003QU>=0P000003R`d00000Qe:;00>7DX/2000000J/LI00002TJXh0002Y_NP00003QE:=0P00
0004WfN@0000YVf@YVf@1P000006ZKgX000000000000Kd2800000Y9PU0040000SER=0000Z6f?1`00
0003ZKgX0000000000<000000jVmj0000000000400000o[ZX`060000VVRF0000WFNA0000ZKgX0P00
0004UAX00000UV6@UV6@1`000005ZKgX000000000000ZKgX00P000001JVmj000000000000:Vmj002
000000>MH8L0002YL94010000003ZKgX00000000010000000jVmj00000000002mZ9C00<0002IHHjI
HHh00P000003ZKgX0000000000H000000i5MT0000:5YT0050000195OT`040000XF^CXF^CXF^C1000
0003ZKgX00000000018000000jVmj000099MT005000000>Y_NP0000000000ZVmj0050000TUnA0000
0000VV>?00P000000iQRT0000000000700000^f=:0030000WFJAWFJA00@000000jVmj00000000007
0000BOooo`030000oooooooo01Coool2000000AQ?I00001G>95G>942000000F/LY400000002MIY40
0000;?ooo`030000oooooooo017oool001Goool00`000?ooooooo`05oooo0`000=Koool3000000BY
_NP00000002=F8`;000000BY_NP0002Y_NP00002SUV=0P000006SUZ>00000000XVF;0000l:n50`00
009b?h@00`0009QRT0000004Y6R=1P0000:^LHd010000?33B`000:Vmj0L00002XVJ<00<0003d/h<0
000010000005Ld:6000000000000S5B8008000001oB`OP00000000000:=WS00008eFR`0500000YeS
S0800000195IR`0000000<Z7R`800002XFF<00<0002NIHjNIHh00P000003ahF;0000ReB:00:;E8X4
000000ZQIHX00000002UJhh0003dXEl0003h[DL0002WJX/200000Y5IR`D00002YFZ>100000=nC8/0
1`000:Q_TJQ_T@000;1eT0000:U^S`0200000hICS@8000000h/=000008MBR`03Qe:;0P000006[76@
0000Y6Z>0000ZKgX00000hEBS@80000019mWT0000:I]T:I]T0<000000jVmj00000000004000000Q_
@8P0002BH9BBH9@0002=F8d0002XKHl>000000>Y_NP0000000000`0000?jjZ<200000YeWT@060000
ZKgX00000000UAX000000YIQT18000000jVmj00000000006000000>MH8L0002YL94030000003ZKgX
0000000000/00002mZ9C00<0002IHHjIHHh010000003ZKgX0000000000@000000i5MT0000:5YT005
0000195OT`040000XF^CXF^CXF^C1P000003ZKgX00000000018000000i9MT0000:Vmj00600000ZVm
j0040000TUnA0000lI@d1P000004ZKgX00000000V6:@1P000003ZKgX0000000000;]SBP00`0009eV
TIeVT@02000000>Y_NP0000000001P0004goool00`000?ooooooo`0Coooo0P000004HCf@0000EcRA
EcRA0P000005[7:A00000000WFJA000002coool00`000?ooooooo`0Aoooo000Eoooo00@0003ooooo
ooooool40000fOooo`<000001:Vmj000000008eHS0d000001:Vmj00008iISHiIS@D000000j9UR`00
0?2_Q@03000000Eb?h@0002HHY2HHY0000000jAXS@030000Wf:9000000@00002[W6=00@0003``d/0
002Y_NP3000000CfaiX0000000000002XVJ<00<0003d/h<0000010000005Ld:6000000000000S5B8
00@000001@00?0000:=WS00008eFR`0500000YeSS0800000195IR`0000000<Z7R`800002XFF<00<0
002NIHjNIHh00P000003ahF;0000ReB:00:;E8X4000000ZQIHX00000002UJhh0003dXEl0003h[DL0
002WJX/200000Y5IR`D00002YFZ>100000=nC8/01`000:Q_TJQ_T@000;1eT0000:U^S`0200000hIC
S@8000000h/=000008MBR`03Qe:;0P000006[76@0000Y6Z>0000ZKgX00000XEBS@050000UUn>0000
WfN@000000:VKI05000000>Y_NP0000000000P000008Kd280000TV2DTV2D0000SER=0000Z6f?0`00
0003ZKgX0000000000X000000jVmj00000000004n^ZS0P0000:MIi4010000:Vmj00006ToR`800002
UV6@00<0002fO9<000001`000003ZKgX0000000000L000001JVmj000000000000:Vmj002000000>M
H8L0002YL9402@000005ZKgX000000000000ZKgX00D000001JVmj000000000000:Vmj00200000_JR
D`050000VF6>VF6>0000ZKgX00P0000019=QU0000:5YT:5YT0@000001:Vmj000095OTi5OT`800003
XF^C1`000003ZKgX0000000000<000000jVmj00000000007000000FY_NP000000000002BGI002@00
0005ZKgX0000TUnA0000lI@d00@000001JVmj000000000000=ab000:00000^f=:0030000WFJAWFJA
00T0001@oooo00<0003oooooool04oooo`<00002EcRA0P000005[7:A00000000WFJA000002coool0
0`000?ooooooo`0Aoooo000Eoooo00<0003oool000000P000=coool3000000>Y_NP0000000000P00
0003ZKgX0000000000<000002:Vmj000000000000:Vmj0000:Vmj00000:>FHd5000000RRIH/0003`
[hD0002Y_NP0001b?h@00002V6:@00H0002TJ8fTJ8fTJ8d0002OHXT5000000>^LHd0003``d/00P00
0005ZKgX000000000000m/NJ00<00002XVJ<00<0003d/h<0000010000005Ld:6000000000000S5B8
00@000001@00?0000:=WS00008eFR`0500000YeSS0800000195IR`0000000<Z7R`800002XFF<00@0
002NIHjNIHh00002ahF;00@0002;E8Z;E8Z;E8X5000000WTWhL0002UJhh0003dXEl0003h[DL0002W
JX/00P0000:AFH/500000ZEZSP@00003OTb;00L0002XKi6XKi40002`MI00002YKXl00P0000>6Dhd2
000000>;3@000027DX/00hMBR`080000[76@[76@0000Y6Z>0000ZKgX00000XEBS@050000UUn>0000
WfN@000000:VKI03000000>Y_NP00000000010000008Kd280000TV2DTV2D0000SER=0000Z6f?1000
0003ZKgX0000000000<000001JVmj000000000000:Vmj00500000o[ZX`800002WFNA00@0002Y_NP0
001Y?h/200000YIQT0030000]WbC000000D000000jVmj0000000000:000000>Y_NP0000000001@00
0003ZG2A0000000000D000000jVmj0000000000@00000_JRD`030000VF6>VF6>00T000000jUYR000
00000002XFV@1P0000:AGi<200000j5[T`l000001JVmj000000000000:Vmj007000000>BGI000000
00001`0000:Y_NP2000000?aU3@00000000010000003ZKgX0000000000<000001JVmj00000000000
0:Vmj003000000K]SBP0002MIY6MIY40002Y_NP30000E?ooo`030000oooooooo01?oool300000ULh
T@8000001JabT@00000009eVT@00000/oooo00<0003oooooool04Oooo`005Oooo`80003Ooooo0`00
0003ZKgX0000SER<00D000001JVmj000000000000:Vmj004000000FY_NP0002>FHd0002bN9<01000
0003XVF;0000l:n500@00003V6:@00H0002TJ8fTJ8fTJ8d0002OHXT5000000>^LHd0003``d/00P00
0005ZKgX000000000000m/NJ00<00002XVJ<00<0003d/h<0000010000005Ld:6000000000000S5B8
00@000000`00?0000:=WS00700000YeSS08000001Y5IR`0000000000095IR`0000:QIH`0100009iU
SYiUSP0000;7QH/01P0008]DRX]DRX]DRP0009mTS0<000002NBOQ`000:E[SP000?BQG`000?R]A`00
0:MZR`0200000Y5IR`D000000jEZSP000<b<SP0300000gi<R`030000Z6nA000000:`MI02000000>Y
_NP00026Dhd00XICS@8000000h/=000008MBR`03Qe:;00<0002/LI2/LI001@0000:5DXd01P0009IO
SP0009mWT0000:I]T0L000001ZVmj0000000000006m0R00000:BH9@0100008eHS@000:Q]S`/00000
0jVmj0000000000700000_[ZX`800002WFNA00X0002Y_NP0001Y?h/0002E6P00002FHI00002fO9<E
000000>Y_NP0000000000`000005ZG2A000000000000ZKgX00D000000jVmj0000000000:000000BY
_NP0000000000002mZ9C00D0002IHHjIHHh0002Y_NP01@000003ZKgX0000ZFV800800002XFV@1P00
0004TEnC0000R56800000Z5[T`050000Xf^A00000000ZKgX00D000001JVmj000000000000:Vmj00=
000000>BGI00000000001`0000:Y_NP2000000?aU3@0000000004P000004kHdX0000WFJAWFJA0P00
05Soool00`000?ooooooo`0Boooo0`0000=G>9401P000:abT@00000009eVT@0002goool00`000?oo
ooooo`0@oooo000Foooo00<0003oooooool0gOooo`<000000jVmj00008eHS003000000>Y_NP00000
00001P000007ZKgX0000ZKgX0000SUV=0000/WRC00@000000j9UR`000?2_Q@0400000iQRT0060000
Y6R=Y6R=Y6R=0000Wf:91@000003[W6=0000l<=;008000001JVmj000091LT0000?K7VP0300000Z9V
S0030000m;>3000000@000001G=2QP000000000008aDR004000000<003`0002SIh`01P0000>MHh`2
000000JAFH/000000000002AFH/00002XFF<00@0002NIHjNIHh00002ahF;00H0002;E8Z;E8Z;E8X0
002OI8`3000000WTWhL0002UJhh0003dXEl0003h[DL0002WJX/00P0000:AFH/5000000>UJXh0003<
S8h00`0000=nC8/00`000:Q_T@000002/7F@0P000003ZKgX0000QU>=00:6Dhd2000000>;3@000027
DX/00hMBR`030000[76@[76@00D00002QE:=00H0002FGhh0002OIi00002VKI0;000000Q_@8P0002B
H9BBH9@0002=F8d0002XKHl=000000FY_NP000000000002Y_NP01P0000>MIi43000000MY?h/0002E
6P00002FHI00002fO9<02@000003ZKgX0000000000<000001JVmj000000000000:Vmj007000000>Y
L9400000000020000003ZKgX0000000000<000001JVmj000000000000:Vmj006000000CfXU<0002I
HHjIHHh9000000>YJHP0000000000Z5YT0P000001XQAR0000:5[Tj5[T`000:=[T@@000000jVmj000
00000007000000>Y_NP0000000002@000003TUf@00000000008000000jVmj0000000000200000ZVm
j08000001?6D=00000000:Vmj0<000000jVmj00000000006000000>Y_NP0000000000P000005kHdX
0000WFJAWFJA000005[oool00`000?ooooooo`0Aoooo0P000006HCf@0000EcRAEcRA0000[7:A0P00
0003WFJA0000oooo02coool00`000?ooooooo`0@oooo000Goooo0P000=goool3000000FY_NP0002=
F8`0003oool010000005ZKgX000000000000ZKgX00<000001jVmj00008iIS@000;9hT`000;Z1UP02
000000>RIH/0000000000`0000BHHY001P000:AXSJAXSJAXS@0009mRR@D000001JiaS@000?33B`00
091LT002000000>@G900000000000`0000:RIX`00`000?BcP`000004000000Ec@XH000000000002<
E8P010000003000l0000XfN<00H00003WF><0P000003TEV;0000000000<00002XFF<00@0002NIHjN
IHh00002ahF;00H0002;E8Z;E8Z;E8X0002OI8`3000000WTWhL0002UJhh0003dXEl0003h[DL0002W
JX/00P0000:AFH/5000000>UJXh0003<S8h00`0000=nC8/00`000:Q_T@000002/7F@0P000003ZKgX
0000QU>=00:6Dhd2000000>;3@000027DX/00hMBR`030000[76@[76@00D00002QE:=00H0002FGhh0
002OIi00002VKI0:000000WUNaP0001_@8P0002BH9@0002=F8d0002XKHl01`000005ZKgX00000000
0000ZKgX00T00002VU=h00@0002MIi6MIi6MIi43000000=Y?h/0002E6P0010000003TEb?00000000
00d000000jVmj00000000008000000>YL940000000002P000003ZKgX0000000000L000000jVmj000
00000002000000CfXU<0002IHHjIHHh9000000>YJHP0000000000Z5YT0X00002XF^C00D0002SJi40
0000002Y_NP020000005ZKgX000000000000ZKgX00D000000jVmj00000000002000000>BGI000000
00001`0000:Y_NP00`00099OT@000003000000>Y_NP0000000001`000003ZKgX0000000000@00000
1Nf=:00009eVTIeVT@00001Koooo00<0003oooooool04Oooo`030000HCf@0000009G>9401P000:ab
T@00000009eVT@0002goool00`000?ooooooo`0@oooo0003oooo0`0000?oool00`000?ooooooo`0=
oooo00<0003oooooool0f_ooo`<000001:Vmj00008eHS00000;oool9000000VY_NP0002Y_NP0002>
FHd0002bN9<0002jPIH00P000003XVF;0000000000<00004V6:@00H0002TJ8fTJ8fTJ8d0002OHXT5
000000F^LHd0003``d/0002@G9000`000004m/NJ0000000000000j9VS0040000m;>30000mK9m0`00
0005Ld:6000000000000S5B800D00002XfN<1P0000>MHh`2000000>AFH/0000000000`0000:QIH`0
100009iUSYiUSP0000;7QH/01P0008]DRX]DRX]DRP0009mTS0<000002NBOQ`000:E[SP000?BQG`00
0?R]A`000:MZR`02000000>AFH/00000000010000003YFZ>0000c8b>00<00003OTb;00<0002XKi40
00000[1eT08000000jVmj00008ICS@02QU>=0P000003R`d00000Qe:;00>7DX/00`000:aaT:aaT005
000000R5DXd0002FGhjFGhh0002OIi00002VKI04000000>Y_NP0000000000`000009iG/H0000Kd28
0000TV2D0000SER=0000Z6f?00P000000jVmj0000000000:00000YYCN0030000WFNAWFNA00@00000
0fToR`0009DJ0004000000>AG8l0000000005@000004ZKgX00000000ZG2A1P000005ZKgX00000000
0000ZKgX00h000001ZVmj0000?JRDoJRD`0009UQSP@000000jVmj0000000000200000ZUYR0030000
XFV@XFV@00T000001HQAR0000:5[T`000:=[T@09000000>Y_NP0000000001@000003ZKgX00000000
00H000000i9MT00000000004000000NY_NP000000000002Y_NP0002BGi401P000003ZKgX00000000
00L00004oooo00<0003]SBP000000YeVT@030000oooooooo05Woool00`000?ooooooo`0Aoooo00<0
001Q?I0000000ULhT@060000[7:A00000000WFJA0000;Oooo`030000oooooooo013oool000?oool0
0`000?ooooooo`02oooo00<0003oool000003oooo`030000oooooooo0=Woool3000000BY_NP0002=
F8`00003oooo2P000007ZKgX0000SUV=0000/WRC0000^X6F008000000j9UR`0000000003000019QR
T0060000Y6R=Y6R=Y6R=0000Wf:9100000:^LHd00`000?33B`000004000000CfaiX0000000000003
XVJ<00D0003d/h<00000001AVO800P000005Ld:6000000000000S5B800D00002XfN<1P0000>MHh`2
000000>AFH/0000000000`0000:QIH`0100009iUSYiUSP0000;7QH/01P0008]DRX]DRX]DRP0009mT
S0<000002NBOQ`000:E[SP000?BQG`000?R]A`000:MZR`02000000>AFH/00000000010000003YFZ>
0000c8b>00<00003OTb;00<0002XKi4000000[1eT08000000jVmj00008ICS@02QU>=0P000003R`d0
0000Qe:;00>7DX/00`000:aaT:aaT005000000R5DXd0002FGhjFGhh0002OIi00002VKI0500000YAT
U`<000001NEk600006m0R000099PU00200000ZQ]Sa0000000jVmj0000000000200000YYCN0030000
WFNAWFNA00@000000fToR`0009DJ0004000000>AG8l0000000003`000005ZKgX000000000000ZKgX
00@000000jU`T@0000000005000000>Y_NP0000000003@000004ZKgX0000000000000_JRD`030000
VF6>000000P00002ZFV800<0002QJI2QJI002@000007R5680000XF^C0000Xf^A0000ZKgX00<00000
0jVmj00000000003000000FY_NP000000000002Y_NP02P000003TUf@0000000000D000001ZVmj000
00000:Vmj000099OT@@000000jVmj0000000000600001oooo`030000kHdX000000:MIY400`000?oo
ooooo`1Joooo00<0003oooooool04?ooo`030000HCf@0000009G>94010000:abT@00000000:MIY40
0`000?ooooooo`0Zoooo00<0003oooooool04?ooo`001?ooo`030000oooooooo00?oool00`000?oo
ooooo`0>oooo00<0003oooooool0f?ooo`<000000jVmj00000000005oooo10000003ZKgX00000000
008000000jVmj00000000002/WRC00<0002jPIH000000P000003l:n50000ZKgX00800003V6:@0P00
00>TJ8d00`0009mRR@00000300000ZiaS@030000l<=;000000P00003XVJ<10000004DIWb00000000
Ld:60`000003S5B80000000000<00002XfN<1P0000>MHh`2000000>AFH/0000000000`0000:QIH`0
1P0009iUSYiUSP000<N5R`0000B;E8X00`0009mTS0000002000000WTWhL0002UJhh0003dXEl0003h
[DL0002WJX/00P000005TEV;000000000000XFJ=008000000jEZSP000<b<SP0300000gi<R`030000
Z6nA000000:`MI02000000>Y_NP00026Dhd00XICS@8000000h/=000008MBR`03Qe:;00@0002/LI00
002TJXh4000000R5DXd0002FGhjFGhh0002OIi00002VKI0300000iATU`090000WVVC00000000iG/H
0000Kd280000TV2D00800002Z6f?10000003ZKgX0000000000<000001JVmj000000000000:Vmj006
00000YYCN0050000WFNAWFNA0000a4`0008000000fToR`0009DJ0008000000?DUi<0000000001`00
0003ZKgX0000000000L000001:Vmj00000000:U`T@l000001JVmj000000000000:Vmj005000000JY
_NP0003fXU?fXU<0002IHHh7000000FY_NP0002YJHRYJHP000000Z5YT0<000000jVmj00000000003
000000F8DHP0002QJi<0002SJi409@000003ZKgX0000TUnA00H000000jVmj0000000000300002?oo
o`030000kHdX000000:MIY400`000?ooooooo`1Koooo00<0003oooooool03oooo`030000HCf@0000
009G>94010000:abT@00000000:MIY400`000?ooooooo`0Zoooo00<0003oooooool04?ooo`001?oo
o`040000oooooooooooo0P0001;oool20000f?ooo`<000000jVmj00000000006oooo10000005ZKgX
000000000000ZKgX00800002/WRC00<0002jPIH000000P000003l:n50000000000800003V6:@0P00
00>TJ8d600000ZiaS@030000l<=;000000P00003XVJ<1`000005Ld:6000000000000S5B800D00002
XfN<1P0000>MHh`2000000JAFH/000000000002VKI000002XFF<00H0002NIHjNIHh00037QH/00004
ReB:00<0002OI8`000000P000009i9n70000YF^>0000m:5O0000n:e70000YfZ;008000001I5IR`00
000000000:5VS@02000000>UJXh0003<S8h00`0000=nC8/02@000:Q_T@000;1eT0000:U^S`000:Vm
j0000003QU>=0P000003R`d00000Qe:;00>7DX/010000:aaT0000:AZSP@0000018EBS@0009IOSYIO
SP800002YVf@0`0000>DI9L02@0009iYT`0000000>Ek600006m0R000099PU00200000ZQ]SaH00000
1YYCN00009eWTIeWT@000<A<00800002JCn;2@000005e9NC000000000000ZKgX00`000000jVmj000
00000003000000FYL94000000000002Y_NP01@000005ZKgX000000000000ZKgX00d00002mZ9C00<0
002IHHh0000010000004ZKgX0000000000000ZUYR0030000XFV@XFV@00D000002jVmj00000000000
08QAR0000:5[T`000:=[T@000:Vmj00B000000FY_NP000000000002Y_NP01@000005ZKgX00000000
0000ZKgX008000000jVmj000099OT@0700000_ooo`<00009oooo0P0000:MIY400`000?ooooooo`1K
oooo00<0003oooooool03oooo`8000001F4mT00005LhT@000:abT@0200000YeVT@030000oooooooo
02[oool00`000?ooooooo`0@oooo0003oooo00<0003oool000000_ooo`030000oooooooo01?oool0
0`000?ooooooo`3Eoooo0`000003ZKgX0000000000Ooool5000000>Y_NP0002Y_NP00P000004/WRC
00000000^X6F0`000003l:n50000000000800003V6:@0P0000>TJ8d600000ZiaS@8000000i1LT000
0000000600000Z9VS0030000m;>3000000D000001G=2QP000000000008aDR00500000Z=WS0H00003
WF><0P000006TEV;000000000000YVf@00000Z5US0060000WVF>WVF>0000ahF;000018]DRP030000
WfB<0000008000002NBOQ`000:E[SP000?BQG`000?R]A`000:MZR`02000000FAFH/000000000002Q
IXd00P000003YFZ>0000000000<00003OTb;00H0002XKi40002`MI00002YKXl300000hICS@800000
0h/=000008MBR`03Qe:;00@0002/LI00002TJXh4000000B5DXd0002FGhjFGhh200000ZI]T0<00002
U6BG00<0002NJI>NJI<00P000005iG/H0000Kd280000TV2D00800002Z6f?3@000005ZKgX00000000
0000ZKgX00@000001IYCN00009eWTIeWT@000002a4`000<0001Y?h]Y?h/00`000003]WbC00000000
00P000000jVmj00000000003000000FY_NP000000000002Y_NP01`000003ZG2A0000000000<00000
0jVmj00000000007000000>Y_NP0000000002@0000;fXU<0100009UQSP000:Vmj0D000001JVmj000
00000:UYR0000002XFV@0`000003ZKgX00000000008000001_JQDP0000000:5[T`000:=[T@800000
0jVmj00000000003000000>Y_NP0000000001`000003ZKgX00000000010000000jVmj000099OT@02
000000>JHhl0003oool01Oooo`800009oooo00D0003]SBP0002MIY400000G_ooo`030000oooooooo
00ooool00`00064mT0000002EcRA00<0002/LY4000000YeVT@030000oooooooo02[oool00`000?oo
ooooo`0@oooo0004oooo00@0003oooooooooool300005?ooo`030000oooooooo0=Coool010000?oo
o`000:Vmj0800008oooo0P000005ZKgX000000000000ZKgX008000001;9hT`0000000;Z1UP<00000
0o2_Q@000000000200000iQRT0800003Y6R=0P000004ZKgX0000000000000ZiaS@<000001JI^TP00
000000000:Vmj00300000Z9VS0030000m;>3000000D00002Ld:60P000006S5B8000000000000000l
00000Z=WS0H00003WF><0P000006TEV;000000000000YVf@00000Z5US0060000WVF>WVF>0000ahF;
000018]DRP030000WfB<0000008000002NBOQ`000:E[SP000?BQG`000?R]A`000:MZR`02000000JA
FH/000000000002QIXd00002YFZ>1@0000=nC8/01P000:Q_T@000;1eT0000:U^S`<00003QU>=0P00
0003R`d00000Qe:;00>7DX/010000:aaT0000:AZSP@0000018EBS@0009IOSYIOSP800002YVf@0`00
00:DI9L00`0009iYT`000002000000GUNaP0001_@8P0002BH9@00P0000:XKHl7000000FY_NP00000
0000002Y_NP02P000005VU=h0000WFNAWFNA000000;4C0000`0006ToRfToR`03000000>fO9<00000
00002P000003ZKgX0000000000L000000jVmj00000000003000000FYL94000000000002Y_NP02000
0005ZKgX000000000000ZKgX00D000000jVmj0000000000200000_JRD`030000VF6>000000T00000
1:UYR0000:5YT:5YT0/000000j5[T`000:=[T@0:000000FY_NP000000000002Y_NP01@000005ZKgX
000000000000ZKgX00h000001I9OT@00000009YSS`000006oooo0P0000Woool01@000>f=:00009eV
T@00001Ooooo00<0003oooooool03_ooo`030000HCf@0000009G>9400`000:abT@000002WFJA00<0
003oooooool0:oooo`030000oooooooo00ooool0023oool00`000?ooooooo`3Coooo00@0003oool0
002Y_NP200002Oooo`H000000hiIS@000;9hT`02000000FjPIH000000000003`[hD0100000>HHY02
00000jAXS@H00002[W6=0`000003YVjB0000000000D00002XVJ<00<0003d/h<000001@00009c@XH2
000000N<E8P000000000000003`0002SIh`00P000003Y6V=0000000000800002WF><00@0003n`G@0
002AFH/3000000FVKI00002QIHbQIH`000000YiUSP030000ahF;000000B;E8X00`0009mTS0000002
000000WTWhL0002UJhh0003dXEl0003h[DL0002WJX/00P000006TEV;000000000000XFJ=00000ZEZ
SPD00003OTb;00H0002XKi40002`MI00002YKXl300000hICS@8000000h/=000008MBR`02Qe:;0P00
0003[76@0000Y6Z>00D00003UUn>0P0000:VKI0300000YATU`030000WVVC0000008000001NEk6000
06m0R000099PU00200000ZQ]SaH000001IYCN00009eWTIeWT@000002a4`000<0001Y?h]Y?h/00`00
0003]WbC0000000000P000000jVmj0000000000J000000>Y_NP0000000003P0000;fXU<00`0009UQ
SP000002000000>Y_NP00000000010000004ZFV80000XFV@XFV@0P000005ZKgX000000000000ZKgX
00@000000j5[T`000:=[T@04000000FY_NP000000000002Y_NP030000003ZKgX0000000000l00000
1I9OT@00000009YSS`000006oooo0P0000Woool01@000>f=:00009eVT@00001Poooo00<0003ooooo
ool03Oooo`030000HCf@0000009G>9401P000:abT@00000009eVT@0002goool00`000?ooooooo`0?
oooo000Qoooo00<0003oooooool0d_ooo`060000oooo00000000SER<00002oooo`@000000hiIS@00
0;9hT`06000000?`[hD0002Y_NP00P0000>HHY0200000jAXS@H00002[W6=0`000003YVjB00000000
00D00002XVJ<00@0003d/h<0002JII8400000W=2QP8000001haDR0000?B`OP000000?0000:=WS002
000000>TJHd0000000000P0000:MHh`010000?k1M000095IR`<000000jI]T0000:5US00200000YiU
SP030000ahF;000000>;E8X2000000FOI8`000000000003TWhL00`000005m:5O0000n:e70000YfZ;
008000001Y5IR`00000000000:5VS@0000:UJXh500000gi<R`800002/7F@00<0002YKXl000000P00
00>6Dhd2000000>;3@000027DX/00XMBR`8000000jaaT0000:AZSP0500000iIOSP800002YVf@0`00
0004U6BG0000WVVCWVVC0`000005iG/H0000Kd280000TV2D00800002Z6f?3P000003ZKgX00000000
00<000001:Vmj00009YCN00000:MIi400`000<A<0<A<0006000000>fO9<0000000001@000003ZKgX
0000000001D000001JVmj000000000000:Vmj005000000>Y_NP0000000000`000003ZKgX00000000
00H00002mZ9C00<0002IHHh000000`000003ZKgX0000000000<000001:UYR0000:5YT:5YT0/00000
0j5[T`000:=[T@0M000000BY_NP0000000000004oooo00<0002Y_NP000000P000003VV>?0000oooo
00Goool200002Oooo`050000kHdX0000WFJA0000063oool00`000?ooooooo`0=oooo00<0001Q?I00
00000ULhT@060000[7:A00000000WFJA0000;Oooo`030000oooooooo00ooool002;oool20000d_oo
o`060000oooooooo0000SER<00003?ooo`@00002/WRC10000003XVF;0000l:n500@00003V6:@0P00
00>TJ8d6000000>^LHd0003``d/00P000004YVjB00000000ZKgX100000:RIX`010000?BcP`0009YU
TP@00002Ld:60P000007S5B80000m;1n0000000l0000XfN<008000000jAYS@000000000200000YeS
S0040000o/5d0000TEV;0`000003YVf@0000XFF<008000001IiUSP0000000<N5R`000003ReB:0P00
0005WfB<000000000000i9n700<000001OBQG`000?R]A`000:MZR`02000000JAFH/000000000002Q
IXd00002YFZ>1@0000=nC8/200000[1eT0030000ZFj?000000800003QU>=0P000003R`d00000Qe:;
00:7DX/2000000>/LI00002TJXh01@0000>FGhh200000ZI]T0<0000019ATU`0009iYTiiYT`D00000
0fm0R000099PU002000000>XKHl0003>SHd00`000003ZKgX0000000000<000000jVmj00000000009
000000FJDgP0002MIi6MIi4000000/A<00030000UFJIUFJI00<000000kIlT`000000000=000000FB
GY0000000000002Y_NP01@000003ZKgX0000000001@000000jVmj0000000000500000_JRD`030000
VF6>000000D000001jVmj000000000000:UYR0000:5YT003000000>Y_NP0000000001P000003XF^C
0000Xf^A00L000001JVmj000000000000:Vmj005000000>Y_NP0000000001`000003ZKgX00000000
00Ooool00`000:Vmj000000400001_ooo`800009oooo00D0003]SBP0002MIY400000HOooo`030000
oooooooo00goool01P00064mT00005LhT@000:abT@8000000ieVT@000?ooo`0/oooo00<0003ooooo
ool03oooo`009?ooo`030000oooooooo0<ooool00`000?ooooooo`0200003_ooo`<00002/WRC1000
0003XVF;0000000000@00003V6:@0P0000>TJ8d2000000VY_NP000000000002^LHd0003``d/0002V
KY80200000:RIX`010000?BcP`0009YUTP@00002Ld:610000005m;1n0000000l0000XfN<00800000
0jAYS@000000000200000YeSS0040000o/5d0000TEV;0`000003YVf@0000XFF<008000001IiUSP00
00000<N5R`000003ReB:0P000003WfB<00000000008000002:E[SP0000000?BQG`000?R]A`000:MZ
R`8000000i5IR`000000000300000ZEZSPD00003OTb;0P0000:`MI000`000:U^S`00000200000hIC
S@8000000h/=000008MBR`02Qe:;0P000003[76@0000Y6Z>008000000oFWJ@0000000003UUn>0P00
00:VKI03000000BDI9L0002NJI>NJI<5000000=_@8P0002BH9@00P000003Z6f?0000cXf=00D00000
0jVmj00000000007000000>Y_NP0000000000`000005VU=h0000WFNAWFNA000000;4C0000`0009EV
VIEVV@03000000>fO9<0000000001`000004V6bN0000TUj@TUj@0P000003TUj@0000000002000000
1ZVmj000000000000:Vmj00000;fXU<00`0009UQSP000003000000>Y_NP0000000000`000003ZFV8
0000XFV@00`000000j5[T`000:=[T@05000000>Y_NP0000000002`000005ZKgX000000000000ZKgX
00@00009oooo00<0002Y_NP00000100000Koool200002_ooo`8000000ieVT@000?ooo`1Qoooo00<0
003oooooool03?ooo`060000HCf@0000EcRA0000[7:A0P000003WFJA0000oooo02coool00`000?oo
ooooo`0?oooo000Uoooo00<0003oooooool0dOooo`80000?oooo0P0000:bN9<4000000>RIH/00000
0000100000>HHY000`000:U/S@000002Y6R=1P000005[W6=0000l<=;0000YVjB00P00002XVJ<00@0
003d/h<0002JII8400000W=2QPH000000`00?0000:=WS002000000>TJHd0000000000P0000:MHh`0
10000?k1M000095IR`<000000jI]T0000:5US002000000FNIHh000000037QH/000000h]DRP800000
0imTS00000000002000000JUJhh00000003dXEl0003h[DL2000000?e/Wd0002AFH/01@0000:UJXh5
00000gi<R`800002/7F@00<0002YKXl000000P0000>6Dhd2000000>;3@000027DX/00XMBR`800000
0jaaT0000:AZSP02000000?eYfT0000000000iIOSP800002YVf@100000>NJI<00`000:=ZT0000002
000000=_@8P0002BH9@00P000003Z6f?0000cXf=00<000000jVmj00000000006000000FY_NP00000
0000002Y_NP010000005VU=h0000WFNAWFNA000000;4C0000`0009EVVIEVV@03000000>fO9<00000
00001@0000>HK9h00`00099NT99NT002000000>BGY000000000040000005ZKgX000000000000ZKgX
00D000001JVmj000000000000:Vmj00700000_JRD`040000VF6>0000ZKgX20000003ZFV80000XFV@
00X000001oJQDP000:5[T`000:=[T@000:Vmj005000000>Y_NP0000000000`000005ZKgX00000000
0000ZKgX00H0000>oooo1P0000Koool200002_ooo`8000000ieVT@000?ooo`1Qoooo00<0003ooooo
ool03?ooo`060000HCf@0000EcRA0000[7:A0P000003WFJA0000oooo02coool00`000?ooooooo`0?
oooo000Voooo00<0003oooooool0d?ooo`80000?oooo0P0000:bN9<4000000FRIH/000000000002Y
_NP00P0000>HHY000`000:U/S@000002Y6R=0`000008ZKgX00000000[W6=0000l<=;0000YVjB2000
00:RIX`010000?BcP`0009YUTP@00002Ld:61P000003000l0000XfN<008000000jAYS@0000000002
00000YeSS0040000o/5d0000TEV;0`000003YVf@0000XFF<008000001IiUSP0000000<N5R`000003
ReB:0P000003WfB<00000000008000001ZE[SP0000000?BQG`000?R]A`8000000oFbO@00095IR`05
00000ZEZSP<000000oBYKP0007i<R`02OTb;0P0000:`MI000`000:U^S`00000200000hICS@800000
0h/=000008MBR`02Qe:;0P000003[76@0000Y6Z>008000000oFWJ@0000000003UUn>0P0000:VKI04
00000YiYT`8000001j=ZT0000000000006m0R000099PU002000000>XKHl0003>SHd01P000005ZKgX
000000000000ZKgX00`00002WFNA00<00034C034C0000P000005UFJI000000000000]WbC00L00003
V6bN00<0002BGY2BGY000P000003TUj@0000000000@000000jVmj00000000007000000>Y_NP00000
00005@0000;fXU<00`0009UQSP000009000000>YJHP0002QJI001P000005ZKgX000000000000mZ5B
00800002Xf^A500001;oool600001oooo`030000oooooooo00Soool2000000>MIY40003oool0H_oo
o`030000oooooooo00coool2000000=G>940002/LY400P000003WFJA0000oooo02coool00`000?oo
ooooo`0?oooo000Woooo0P000=3oool200003oooo`8000000k9hT`0000000003000000>RIH/00000
0000100000>HHY000`000:U/S@000002Y6R=1P000005[W6=0000l<=;0000YVjB00@000001:Vmj000
0000000000:RIX`01P000?BcP`0009YUTP000:=/T`800002Ld:61P000003000l0000XfN<00800000
0jAYS@000000000200000YeSS0040000o/5d0000TEV;0P0000:VKI001@000:5US000000009iUSP02
000000?7QH/0002;E8X00X]DRP8000000imTS00000000002000000JUJhh00000003dXEl0003h[DL2
000000?e/Wd0000000001@0000:UJXh3000000?dZFh0001nC8/00Wi<R`800002/7F@00<0002YKXl0
00000P0000>6Dhd2000000>;3@000027DX/00XMBR`8000000jaaT0000:AZSP02000000?eYfT0002F
Ghh00iIOSP800002YVf@00<0001VAiP000000iiYT`8000001:=ZT00000000000009_@8P3000000>X
KHl0003>SHd00P000003ZKgX0000000000L000000jVmj00000000003000000>Y_NP0000000000P00
0003WFNA0000000000;4C002000000FEIYT000000000002fO9<01`0000>HK9h01P00099NT99NT99N
T000099NT0P000000jVmj00000000007000000>Y_NP00000000040000007ZKgX000000000000mZ9C
0000VF6>00<000001JVmj000000000000:Vmj002000000>YJHP0002QJI002P000003mZ5B00000000
00:SJi43000000>Y_NP0000000002P0001Koool600001oooo`030000oooooooo00Soool2000000>M
IY40003oool0Hoooo`030000oooooooo00_oool2000000=G>940002/LY400P000003WFJA0000oooo
02goool00`000?ooooooo`0>oooo000Yoooo00<0003oooooool0cOooo`80000?oooo00<0002bN9>b
N9<01P000004l:n500000000ZKgX0P0000>HHY000`000:U/S@000002Y6R=1@0000:^LHd200000ZI^
TPP00002XVJ<00@0003d/h<0002JII8400000W=2QPH000000`00?0000:=WS002000000>TJHd00000
00000P0000:MHh`010000?k1M000095IR`8000001:I]T0000:5US:5US08000001IiUSP0000000<N5
R`000002ReB:00@0002fNi40002OI8`2000000?TWhL0002UJhh00P000003m:5O0000n:e700800000
0oFbO@000000000500000ZEZSP<000000oBYKP0007i<R`02OTb;0P0000:`MI000`000:U^S`000002
00000hICS@@00003Qe:;0P000003[76@0000Y6Z>008000000oFWJ@0009IOSP03UUn>0P0000:VKI00
0`0006I7V0000003WVVC0P000004XfZ@0000000000000Vm0R0<000000jQ]S`000<j=S@0?000000FY
_NP000000000002Y_NP00`000003WFNA0000000000;4C00200000YEVV@8000000kIlT`0000000006
00000YQ/WP060000TUj@TUj@TUj@0000TUj@1P000003ZKgX0000000000X000000jVmj00000000003
000000>Y_NP0000000001`000003ZKgX0000000000<000000oJRD`0009UQSP0:000000>YJHP0002Q
JI000P000003ZKgX0000000000D000000oJQDP0000000002Xf^A10000003ZKgX0000000000L0000H
oooo1P0000Ooool00`000?ooooooo`08oooo0P000003WFJA0000oooo06Coool00`000?ooooooo`0:
oooo00@0001Q?I00001G>943000000>MIY40003oool0;Oooo`030000oooooooo00koool002[oool0
0`000?ooooooo`3<oooo0P0000ooool00`000;9hTk9hT`06000000K`[hD000000000002Y_NP00003
V6:@00<0002YK8d000000ZAXS@8000000jVmj00000000002[W6=0P0000:VKY8800000Z9VS0800000
0iYUTP000000000300000W=2QPD00002000l00D0002SIh`00000002TJHd0100000:MHh`010000?k1
M000095IR`8000001:I]T0000:5US:5US08000001IiUSP0000000<N5R`000002ReB:00@0002fNi40
002OI8`2000000?TWhL0002UJhh00P000003m:5O0000n:e700<000000i5IR`000000000400000ZEZ
SP<000000oBYKP0007i<R`02OTb;0P0000:`MI001@000:U^S`000?BVJ@000003QU>=100000>7DX/2
000000>/LI00002TJXh00P000003mJMY0000UUn>00>FGhh200000ZI]T0030000ITNH000000>NJI<2
000000BSJY00000000000002Kd280`000003Z6f?0000cXf=00<000000jVmj00000000007000000>Y
_NP0000000001`000003WFNA0000000000;4C00200000YEVV@8000000kIlT`0000000002000000CD
Ui<0000000000002V6bN00H0002BGY2BGY2BGY00002BGY0K000000FY_NP000000000002Y_NP01@00
0007ZKgX000000000000mZ9C0000VF6>00X000000jUYR0000:5YT00=00000Z=[T@X0000Loooo1P00
00Ooool00`000?ooooooo`08oooo0P000003WFJA0000oooo06Coool00`000?ooooooo`0:oooo00@0
001Q?I00001G>94300000YeVT@030000oooooooo02_oool00`000?ooooooo`0>oooo000[oooo00<0
003oooooool0boooo`030000oooooooo00koool01@000;9hTk9hT`000?ooo`04000000?`[hD00000
00000`0000>HHY000`000:U/S@000002Y6R=1@0000:^LHd2000000>VKY80000000000`000004ZKgX
0000000000000Z9VS08000000iYUTP000000000300000W=2QPD00002000l00D0002SIh`00000002T
JHd0100000:MHh`010000?k1M000095IR`8000001:I]T0000:5US:5US08000001IiUSP0000000<N5
R`000002ReB:00@0002fNi40002OI8`2000000?TWhL0002UJhh00P000003m:5O0000n:e700<00000
0i5IR`0000000004000000>UJXh0003<S8h00P000003m:U^0000OTb;009nC8/200000[1eT0050000
ZFj?0000m:IY000000>6Dhd400000XMBR`060000Yff@0000[76@0000Y6Z>0P000003mJMY0000UUn>
00>FGhh01`000:I]T:I]T:I]T00006I7V0000003WVVC0P000004XfZ@0000000000000Vm0R0<00000
0jQ]S`000<j=S@05000000FY_NP000000000002Y_NP01@000005ZKgX000000000000ZKgX00800000
19YCN0000000000000;4C00200000YEVV@8000000kIlT`0000000002000000CDUi<0000000000002
V6bN00H0002BGY2BGY2BGY00002BGY0?000000>Y_NP0000000000`000005ZKgX000000000000ZKgX
00`000001ZVmj00000000?JRD`0009UQSP/000000jUYR00000000004000000RY_NP000000000002Y
_NP0003fXE800002Xf^A1P00023oool3000000?oool0000000004_ooo`8000000ieVT@000?ooo`1U
oooo00<0003oooooool02_ooo`80000015LhT@000000000000:MIY400`000?ooooooo`0[oooo00<0
003oooooool03_ooo`00;?ooo`80003;oooo00<0003oooooool03_ooo`040000/WRC/WRC00000_oo
o`<000000o2_Q@000000000300000iQRT0040000ZFb=0000Y6R=1P0000:^LHd2000000BVKY800000
00000003ZKgX0`0000:RIX`2000000>JII80000000000`00009c@XH3000000NkO8l0000003`003`0
002SIh`000000ZAYS@@00002WF><00@0003n`G@0002AFH/2000000BVKI00002QIHbQIH`2000000FN
IHh000000037QH/000000X]DRP040000]W^A0000WfB<0P000003i9n70000YF^>008000000oBQG`00
0?R]A`03000000>AFH/00000000010000003YFZ>0000c8b>008000000oBYKP0007i<R`02OTb;0P00
00:`MI001@000:U^S`000?BVJ@000003QU>=100000:7DX/01P000:M]T0000:aaT0000:AZSP800000
0oFWJ@0009IOSP03UUn>00L0002VKI2VKI2VKI00001VAiP000000iiYT`8000001:=ZT00000000000
009_@8P3000000>XKHl0003>SHd00`000003ZKgX0000000000X000000jVmj00000000003000000BJ
DgP0000000000002a4`00P0000:EIYT2000000>fO9<0000000000P000004e9NC0000000000000YQ/
WP040000TUj@TUj@TUj@2`000003ZKgX0000000001D000000jVmj00000000005000000?fXU<0002I
HHh00P000005ZKgX000000000000ZKgX00@000000jUYR00000000002000000>Y_NP0000000001@00
0004mZ5B0000Xf^AXf^A0`0002Coool2000000?oool0000000004oooo`<0001Woooo00<0003ooooo
ool02Oooo`80000015LhT@000000000000:MIY400`000?ooooooo`0[oooo00<0003oooooool03_oo
o`00;_ooo`030000oooooooo0<Soool00`000?ooooooo`0>oooo00@0002bN9>bN9<00002oooo0`00
0004l:n500000000ZKgX0P0000>HHY03000000>TJ8d000000000100000:^LHd2000000>VKY800000
00000P0000:Y_NP3000000FRIX`0003d/h<0002JII80100000=c@XH3000000NkO8l0000003`003`0
002SIh`000000ZAYS@@00002WF><00<0003n`G@000000`000004YVf@0000XFF<XFF<0P000005WVF>
00000000ahF;000000:;E8X010000;IkT@0009mTS08000000nBOQ`000:E[SP02000000?dXEl0003h
[DL00`000003TEV;0000000000@000000jEZSP000<b<SP02000000?dZFh0001nC8/00Wi<R`090000
/7F@/7F@/7F@0000ZFj?0000m:IY000000>6Dhd400000XMBR`040000Yff@000000000ZAZSP800000
0oFWJ@0009IOSP03UUn>00L0002VKI2VKI2VKI00001VAiP000000iiYT`<000000lJ7T@0000000002
Kd280`000005Z6f?0000cXf=0000VFnR01@0000019YCN0000000000000;4C00200000YEVV@<00000
1I5LS`00000000000=BGT`0300000YQ/WP040000TUj@TUj@TUj@80000005ZKgX000000000000ZKgX
00H000000oJRD`0009UQSP0;000000>YJHP00000000010000003ZKgX0000000000<000001OJQDP00
0:=[TJ=[T@00000Voooo0P000003oooo0000000001?oool30000J?ooo`030000oooooooo00Soool2
000000AG>940000000000002WFJA00<0003oooooool0:oooo`030000oooooooo00koool002ooool0
0`000?ooooooo`37oooo00<0003oooooool03_ooo`040000/WRC/WRC00000_ooo`<000000o2_Q@00
0000000300000iQRT0<000001JAXS@00000000000:Vmj00200000ZiaS@8000001JI^TP0000000:Vm
j0000002ZKgX0P0000:RIX`01P000?BcP`0009YUTP000:=/T`800003Ld:60P0000:kO8l01P000000
?000?0000:=WS00000:TJHd010000?FbO@00000000:MHh`00`000?k1M0000003000000BVKI00002Q
IHbQIH`2000000FNIHh000000037QH/000000X]DRP040000]W^A0000WfB<0P000003i9n70000YF^>
008000001?BQG`0000000:MZR`8000000i5IR`0000000004000000>UJXh0003<S8h00P000003m:U^
0000OTb;009nC8/02@000;1eT;1eT;1eT0000:U^S`000?BVJ@000003QU>=100000:7DX/010000:M]
T000000000:TJXh2000000?eYfT0002FGhh00iIOSP070000YVf@YVf@YVf@0000ITNH000000:NJI<0
1@000:M_TP0000000<J7T@0200000Vm0R0<000000jQ]S`000<j=S@02000000>GHi80000000000`00
0005WG^]000000000000ZKgX00D000001JVmj0000000000009YCN004000000?4C000000000000YEV
V@<000000i5LS`000000000500000YQ/WP040000TUj@TUj@TUj@50000003ZKgX0000000000L00000
0jVmj00000000005000000>Y_NP0000000000P000006mZ9C0000VF6>VF6>0000ZKgX1@000004ZKgX
00000000ZFV830000005mZ5B0000Xf^AXf^A000002Koool2000000?oool0000000004oooo`<0001X
oooo00<0003oooooool02Oooo`D00002WFJA00<0003oooooool0:oooo`030000oooooooo00koool0
033oool00`000?ooooooo`3Goooo00<0002bN9<000000oooo`L000000jVmj00009QRT002V6:@0`00
0003Y6R=0000000000@00002[W6=0P000003YVjB0000000000<000000jVmj00000000002XVJ<00@0
003d/h<0002JII8400000g=2QP800002^gb?00H0000003`003`0002SIh`00002Y6V=0P000006m:]c
0000WF><WF><0000o/5d10000004YVf@0000XFF<XFF<1P0000:;E8X01@000;IkTKIkT@0009mTS002
000000?TWhL0002UJhh01@000004YfZ;00000000TEV;1@0000:UJXh01P000<b<SP0000000?BYKP00
00=nC8/010000;1eT;1eT00000:YKXl00`000?BVJ@000003QU>=100000:7DX/010000:M]T0000000
00:TJXh2000000?eYfT0002FGhh00iIOSP030000YVf@YVf@00@00002WVVC00D0002WKi8000000036
Qi400P00009_@8P3000000>XKHl0003>SHd00P000004Uf>B0000000000000Yek[A<000000lA<0000
00000002UFJI0`000003TEb?00000000008000000k9hU00000000002V6bN00@0002BGY2BGY2BGY06
000000>WKi<0000000003@000005ZKgX000000000000ZKgX00D000001JVmj000000000000:Vmj006
000000CfXU<0002IHHjIHHh:000000>YJHP0000000001`0000;oool00`000?JQDP000002Xf^A00<0
003oooooool09?ooo`8000000oooo`000000000Coooo0`0006Woool00`000?ooooooo`08oooo1@00
00:MIY400`000?ooooooo`0[oooo00<0003oooooool03_ooo`00<Oooo`80003Goooo00<0002bN9<0
00000oooo`@000000oooo`000000000200000iQRT0<000001JAXS@00000000000:Vmj002000000F^
LHd0003``d/0002VKY801@000003ZKgX0000000000:RIX`00`000?BcP`000003000000>HKj80001c
@XH00W=2QP800002^gb?00H0000003`003`0002SIh`00002Y6V=0P000004m:]c0000WF><00000_k1
M0@000001ZI]T0000:5US:5US00009iUSP@00002ReB:00D0002fNi6fNi40002OI8`00P000003i9n7
0000YF^>00D000001:MZR`000000095IR`D00002YFZ>00D0003<S8h00000003dZFh00P00009nC8/0
1@000;1eT;1eT0000:U^S`02000000GdYVT0000000000026Dhd0100000:7DX/010000:M]T0000000
00:TJXh2000000?eYfT0002FGhh00iIOSP030000YVf@YVf@00@00002WVVC00D0002WKi8000000036
Qi400P00009_@8P3000000BXKHl0000000000002Uf>B0P0000:MNjdD000000?4C000000000000YEV
V@<000000i5LS`0000000002000000>bN9@0000000000YQ/WP040000TUj@TUj@TUj@1P000003YfnC
0000000000L000001JVmj000000000000:Vmj00<000000>Y_NP0000000001`000004mZ9C0000VF6>
VF6>2P000005ZFV8000000000000ZKgX00<00004oooo00<0003fXE8000000Z=[T@030000oooooooo
02Coool2000000?oool0000000004oooo`<0001Zoooo00<0003oooooool01oooo`D00002WFJA00<0
003oooooool0;?ooo`030000oooooooo00goool003?oool00`000?ooooooo`3Doooo00<0002bN9<0
00000oooo`@00002oooo0`0000>HHY03000000>TJ8d00000000010000005[W6=0000l<=;0000YVjB
00P00002XVJ<00<0003d/h<000000`000003V6nR0000Ld:6009c@XH200000[]lS`030000000l000l
00<00002Y6V=0P000004m:]c0000WF><00000_k1M0060000YVf@00000000YVf@00000Z5US0030000
WVF>000000<00002ReB:00<0002fNi4000000YmTS08000000nBOQ`000:E[SP05000000BWJX/00000
002AFH/500000ZEZSP070000c8b>00000000m:U^0000SER=00<00002/7F@00H0002YKXl00000003d
YVT00002SUV=1@0000:7DX/010000:M]T000000000:TJXh2000000?eYfT0002FGhh00iIOSP030000
YVf@YVf@00@00002WVVC00D0002WKi8000000036Qi400P00009_@8P200000ZQ]S`800002Uf>B1`00
0003ZKgX0000000000<000000jVmj00000000003000000NY_NP000000000002Y_NP00034C0000P00
00:EIYT3000000>AG8l0000000000P000003/WRD0000000000:HK9h01000099NT99NT99NT0H00000
0jM_T`000000000800000YIWV@T000000jVmj0000000000:000000BY_NP0003fXU<00002VF6>1000
0003ZKgX0000000000<000000jUYR0000000000200001oooo`030000mZ5B000000:SJi400`000?oo
ooooo`0Uoooo00@0003oool00000000Coooo0`0006[oool00`000?ooooooo`08oooo00@0001G>940
00000002WFJA00<0003oooooool0;?ooo`030000oooooooo00goool003Coool00`000?ooooooo`3C
oooo00<0002bN9<000000oooo`@00002oooo0`0000:HHY001@000:U/S@0000000:AXS@06000000>^
LHd0000000001@000003TEb@0000000000800002XVJ<00<0003d/h<000001@0000=c@XH200000[]l
S`030000000l000l00<00002Y6V=0`0000:MHh`01@000?k1M?k1M0000:I]T002000000JVKI00002Q
IHbQIH`0002NIHh400000X]DRP030000]W^A000000:OI8`2000000?TWhL0002UJhh01@000004YfZ;
00000000TEV;1@0000:UJXh01P000<b<SP0000000?BYKP0000>=F8d01@000;1eT;1eT0000:U^S`02
000000?dYVT0002>FHd00XiIS@040000/gRB000000000XMBR`040000Yff@000000000ZAZSP800000
0oFWJ@0009IOSP03UUn>00<0002VKI2VKI00100000:NJI<00`000:M_TP00000400000Vm0R0800002
Z6f?0P0000:GHi8I000000?4C000000000000YEVV@@000001JaaT@00000000000;9hU003000000>H
K9h0002BGY000i9NT0D000000jM_T`000000000300000YIVV0030000UVNIUVNI00:FIiT6000000FY
_NP000000000002Y_NP01@000005ZKgX000000000000ZKgX00<000001?JRD`0009UQSYUQSPH00000
1JVmj000000000000:UYR00200002Oooo`030000mZ5B000000:SJi400`000?ooooooo`0Uoooo00@0
003oool00000000Coooo0`0006_oool00`000?ooooooo`07oooo100000:MIY400`000?ooooooo`0/
oooo00<0003oooooool03Oooo`00=Oooo`030000oooooooo0=;oool00`000;9hT`000003oooo1000
00Coool01@0009QRT9QRT0000:U/S@02000000>TJ8d00000000010000003[W6=0000000000<00000
1JVmj000095LT0000=i/300200000Z9VS0050000m;>300000000XfbC00<00003Ld:60P0000:kO8l0
0`000000?000?00300000ZAYS@<00002WF><00D0003n`GCn`G@0002VKI000P000008YVf@0000XFF<
XFF<0000WVF>0000ZKgX0P0000:;E8X00`000;IkT@000002WfB<0P000003i9n70000YF^>00D00000
1:MZR`000000095IR`D00002YFZ>0P000004Z6j@0000m:U^00000heHS@050000/7F@/7F@0000ZFj?
008000000oBVJ@0008iIS@02SUV=00@0002cN98000000002Qe:;00@0002WKI0000000002Y6Z>0P00
0003mJMY0000UUn>00>FGhh00`000:I]T:I]T00400000YiYT`030000YfnB000000@00002Kd280P00
00:XKHl200000YMSTPT000000jVmj0000000000=000000?4C000000000000YEVV@050000TEb?0000
0000[76A00<000001[9hU0000000000009Q/WP0000BBGY05000000BWKi<0000000000004UVJH00H0
002FIiVFIiVFIiT0002Y_NP3000000>Y_NP0000000003`000004ZKgX0000mZ9C00000YUQSP@00000
0jVmj00000000002oooo00@0002YJHP00000000:oooo0P0000:SJi400`000?ooooooo`0Uoooo00@0
003oooooool0000Doooo0P0006coool00`000?ooooooo`06oooo100000:MIY400`000?ooooooo`0/
oooo00<0003oooooool03Oooo`00=_ooo`80003Boooo00<0002bN9<000000oooo`8000000o2_Q@00
0?ooo`03oooo00D0002HHY2HHY00002YK8d00P000003Y6R=0000000000<00002[W6=1@000005ZKgX
0000TEb@0000gV`<00800002XVJ<00D0003d/h<00000002SK9<00`0000=c@XH2000000>kO8l00000
03`00P00?0<00002Y6V=0`0000:MHh`01@000?k1M?k1M0000:I]T002000000>VKI00002QIH`00P00
0003WVF>0000000000800002ReB:00<0002fNi4000000YmTS08000001>BOQ`0000000>Il80@00000
0jMZR`000000000600000ZEZSP@000000oBYKP0008eHS@02SER=00D0002`MI2`MI00002YKXl00P00
0003m:IY0000SUV=00:>FHd01P000;=hTP00000008MBR`0000:WKI0200000ZAZSP8000000oFWJ@00
09IOSP03UUn>00<0002VKI2VKI000`000005ITNH0000WVVC0000YfnB00D00003Kd2800<0002XKHnX
KHl00P0000:GHi8:000000>Y_NP0000000000`000003ZKgX0000000000H000000lA<000000000002
UFJI00D0002AG8l00000002/LI400`000006/WRD000000000000V6bN0000199NT0D000001:M_T`00
0?boO@0000BFIYP0100009IWVIIWVIIWV@800002UFBF0`000003ZKgX0000000000<000000jVmj000
00000009000000CfXU<0002IHHjIHHh500001?ooo`040000ZFV8000000002_ooo`800002Xf^A00<0
003oooooool0:?ooo`030000oooooooo01;oool20000KOooo`030000oooooooo00Goool400000YeV
T@030000oooooooo02coool00`000?ooooooo`0=oooo000hoooo00<0003oooooool0coooo`030000
/WRC000000?oool2000000?`[hD0003oool00oooo`050000V6:@V6:@0000ZFb=008000001ZAXS@00
000000000:Vmj00000:^LHd5000000FY_NP0002AG900003NK0`00P0000:RIX`2000000>JII800000
00000`0000=c@XH2000000>kO8l0000003`00P00?0<00002Y6V=0`0000:MHh`01@000?k1M?k1M000
0:I]T002000000>VKI00002QIH`00P000003WVF>00000000008000001H]DRP000;IkTKIkT@000002
WfB<0P000004i9n700000000iW`P10000003YfZ;0000000000H00002YFZ>10000003m:U^0000SER=
00:=F8d01@000;1eT;1eT0000:U^S`02000000?dYVT0002>FHd00XiIS@060000/gRB00000000Qe:;
00000ZM]T0800002Y6Z>0P000003mJMY0000UUn>00>FGhh00`000:I]T:I]T002000000B7E8h00000
00000002YfnB1@0000=_@8P00`000:Q]SjQ]S`0200000YMSTQ8000001JVmj000000000000:Vmj002
000000O4C000001`@h/0002EIYT0002AG8l00P000003[76A00000000008000000`04R00000000002
V6bN00@0002BGY2BGY2BGY05000000BWKi<0000000000004UVJH00D0002FIiVFIiVFIiT000000iET
UPX000000jVmj00000000008000000GfXU<0002IHHjIHHh000002?ooo`040000ZFV8000000002_oo
o`050000mZ5B0000Xf^A000002[oool00`000?ooooooo`0Boooo0P0006goool00`000?ooooooo`06
oooo0`0000:MIY400`000?ooooooo`0/oooo00<0003oooooool03Oooo`00>Oooo`030000oooooooo
0<koool200001?ooo`8000000o2_Q@000?ooo`04oooo00@0002HHY00002YK8d2000000>TJ8d00000
00000`0000:^LHd5000000>Y_NP0002AG900100000:RIX`2000000>JII80000000000`0000=c@XH2
000000>kO8l0000003`00P00?0<00002Y6V=0`0000:MHh`01@000?k1M?k1M0000:I]T002000000>V
KI00002QIH`00P000003WVF>00000000008000001H]DRP000;IkTKIkT@000002WfB<0P000004i9n7
00000000iW`P10000003YfZ;0000000000H00002YFZ>10000003m:U^0000SER=00:=F8d01@000;1e
T;1eT0000:U^S`02000000?dYVT0002>FHd00XiIS@060000/gRB00000000Qe:;00000ZM]T0800002
Y6Z>0P000003mJMY0000UUn>00>FGhh00`000:I]T:I]T002000000N7E8h000000000002WKi80002S
JY00100000=_@8P00`000:Q]SjQ]S`0200000YMSTPH000000jVmj00000000003000000FY_NP00000
0000002Y_NP020000006a4`00000L4>;0000UFJI00000Y5LS`030000[76A000000<000000`04R000
00000002V6bN00@0002BGY2BGY2BGY09000019IVV0040000UVNIUVNI00000iETUQ4000000jVmj000
0000000200000_JRD`030000VF6>000000Woool300002_ooo`050000mZ5B0000Xf^A000002[oool0
0`000?ooooooo`0Boooo0P0006koool00`000?ooooooo`05oooo10000003WFJA0000oooo02goool0
0`000?ooooooo`0=oooo000joooo00<0003oooooool0cOooo`800004oooo0P000003l:n50000oooo
00Coool01`0009QRT00000000;n0SP000:AXS@0500000ZiaS@8000001ZI^TP000:Vmj:Vmj000095L
T0@00002XVJ<1@000003ZKgX0000000000=c@XH2000000>kO8l0000003`00P00?0<00002Y6V=0`00
00:MHh`01@000?k1M?k1M0000:I]T002000000>VKI00002QIH`00P000003WVF>0000000000800000
1H]DRP000;IkTKIkT@000002WfB<0`000003YF^>0000iW`P00@000000jMZR`000000000600000ZEZ
SP@000000oBYKP0008eHS@02SER=00D0002`MI2`MI00002YKXl00P000003m:IY0000SUV=00:>FHd0
1P000;=hTP00000008MBR`0000:WKI02000000JTJXh000000000003eYfT00004UUn>00<0002VKI2V
KI000P000007QeB>000000000000YfnB0000XfZ@00@00003Kd2800<0002XKHnXKHl00P0000:GHi8=
000000>Y_NP0000000002@000006a4`00000L4>;0000UFJI00000Y5LS`030000[76A000000<00000
0`04R00000000002V6bN00@0002BGY2BGY2BGY0900001IIVV0030000UVNI000000>EI9H7000000>Y
_NP0000000002P0000;oool01@000?JRD`0009UQSP000009oooo0`0000[oool01@000?JQDP000:=[
T@00000Zoooo00<0003oooooool04_ooo`80001_oooo00<0003oooooool01?ooo`@00002WFJA00<0
003oooooool0;?ooo`030000oooooooo00coool003_oool00`000?ooooooo`3<oooo0P0000Coool2
000000?`[hD0003oool01?ooo`070000V6:@00000000_h2>0000Y6R=00D00002[W6=0P000005YVjB
0000ZKgXZKgX000000:AG90300000Z9VS0P00003Ld:600@0002kO8nkO8l00003000l0`0000:TJHd3
00000YeSS0060000o/5do/5d0000YVf@00000ZI]T0050000XFF<00000000WVF>00@000001H]DRP00
0;IkTKIkT@000002WfB<0`000003YF^>0000iW`P00@000000jMZR`000000000600000ZEZSP@00000
0oBYKP0008eHS@02SER=00D0002`MI2`MI00002YKXl00P000003m:IY0000SUV=00:>FHd01P000;=h
TP00000008MBR`0000:WKI02000000JTJXh000000000003eYfT00004UUn>00<0002VKI2VKI000P00
0007QeB>000000000000YfnB0000XfZ@00@00003Kd2800<0002XKHnXKHl00P000004Uf>B00000000
XVZA5`000006a4`00000L4>;0000UFJI00000Y5LS`8000001LB5T000000000000004R00200000YQ/
WP040000TUj@TUj@TUj@2P0000BFIYP300000iETUPT000001JVmj000000000000:Vmj00400001?oo
o`050000mZ9C0000VF6>000000Woool300002_ooo`050000mZ5B0000Xf^A000003ooool20000L?oo
o`030000oooooooo00?oool400000YeVT@030000oooooooo02coool00`000?ooooooo`0<oooo000l
oooo0P000<coool200001?ooo`<00006oooo00L0002HHY000000002oP8h0002TJ8d00`000004ZKgX
0000[W6=[W6=100000:Y_NP00`00095LT95LT003000000>RIX`0003d/h<00P000003XfbC00000000
00800003Ld:600@0002kO8nkO8l00003000l0`0000:TJHd300000YeSS0060000o/5do/5d0000YVf@
00000ZI]T0070000XFF<00000000WVF>0000ZKgX008000001H]DRP000;IkTKIkT@000002WfB<0`00
0003YF^>0000iW`P00@000000jMZR`000000000600000ZEZSP@000000oBYKP0008eHS@02SER=00D0
002`MI2`MI00002YKXl00P000003m:IY0000SUV=00:>FHd01P000;=hTP00000008MBR`0000:WKI02
000000JTJXh000000000003eYfT00003UUn>0P0000:VKI02000000N7E8h000000000002WKi80002S
JY00100000=_@8P00`000:Q]SjQ]S`02000000BGHi800000002RJY43000000FY_NP000000000002Y
_NP01@000003ZKgX0000000000L000001/A<00000713R`0009EVV@0000:AG8l2000000G4QI000000
0000000018P00P0000:HK9h01000099NT99NT99NT0X00004UVJH0`0000>EI9H7000000>Y_NP00000
0000100000Soool01@000?JRD`0009UQSP000009oooo0`0000[oool01@000?JQDP000:=[T@000010
oooo00<0003oooooool0K_ooo`030000oooooooo00Coool300000YeVT@030000oooooooo02coool0
0`000?ooooooo`0<oooo000noooo00<0003oooooool0bOooo`800004oooo0`0000Koool02@0009QR
T00000000;n0SP000:AXS@000:Vmj00300000ZiaS@@00002ZKgX00<0002AG92AG9000`000003XVJ<
0000m;>3008000000j=/T`000000000200000g=2QP040000^gb?^gb?00000`00?0<00002Y6V=0`00
00:MHh`01P000?k1M?k1M0000:I]T00000:VKI001@000:5US000000009iUSP04000000J;E8X0002f
Ni6fNi40002OI8`2000000GTWhL0002UJhh0003VO20010000003YfZ;0000000000H00002YFZ>1000
0003m:U^0000SER=00:=F8d01@000;1eT;1eT0000:U^S`02000000?dYVT0002>FHd00XiIS@060000
/gRB00000000Qe:;00000ZM]T08000001ZAZSP00000000000?FWJ@0000>FGhh200000ZI]T0030000
QeB>QeB>00<000000jM_TP000:=ZT00400000fm0R0030000Z6f?Z6f?0080000019MSTP0000000:9Z
T@l000000jVmj00000000005000000K4C000001`@h/0002EIYT00002TEb?0P000005a8F@00000000
000000B800800002V6bN00@0002BGY2BGY2BGY0:000019IVV0<00002UFBF0P000004aXbF00000000
ZKgX1@0000coool01@000?JRD`0009UQSP000009oooo0`0000[oool01@000?JQDP000:=[T@000010
oooo00<0003oooooool0Koooo`030000oooooooo00?oool300000YeVT@030000oooooooo02coool0
0`000?ooooooo`0<oooo000ooooo00<0003oooooool0b?ooo`800004oooo0`0000Koool01`0009QR
T00000000;n0SP000:AXS@05000000>^LHd0000000000`0000:Y_NP00`00095LT95LT003000000>R
IX`0003d/h<00P000003XfbC0000ZKgX00800003Ld:600@0002kO8nkO8l00003000l0`0000:TJHd3
00000YeSS0060000o/5do/5d0000YVf@00000ZI]T0030000XFF<000000L00003]W^A00T0002OI8`0
0000003TWhL0002UJhh0003VO2001@000003mK9m0000000000D00002YFZ>10000003m:U^0000SER=
00:=F8d01@000;1eT;1eT0000:U^S`02000000?dYVT0002>FHd00XiIS@060000/gRB00000000Qe:;
00000ZM]T0030000Y6Z>Y6Z>00<000000oFWJ@0009IOSP02UUn>0P0000:VKI001@0008MDSXMDSXMD
SP000002YfnB00<0002SJY0000000`0000=_@8P00`000:Q]SjQ]S`02000000BGHi800000002RJY49
000000FY_NP000000000002Y_NP02@000006a4`00000L4>;0000UFJI00000Y5LS`8000001LB5T000
000000000004R00200000YQ/WP040000TUj@TUj@TUj@2P0000BFIYP300000YETUP8000000lJ<UP00
0000000200004?ooo`050000mZ9C0000VF6>000000Woool300002_ooo`050000mZ5B0000Xf^A0000
043oool00`000?ooooooo`1`oooo00<0003oooooool00_ooo`<00002WFJA00<0003oooooool0;?oo
o`030000oooooooo00coool0043oool00`000?ooooooo`37oooo0P0000Coool300001_ooo`070000
V6:@00000000_h2>0000Y6R=00D000000jiaS@000000000300000ZVmj0030000TEb@TEb@00<00000
0j9VS0000?BcP`0700000g=2QP040000^gb?^gb?00000`00?0<00002Y6V=0`0000:MHh`01P000?k1
M?k1M0000:I]T00000:VKI000`000:5US000000700000kIkT@090000WfB<00000000i9n70000YF^>
0000iW`P00D000000oFbO@000000000500000ZEZSP@000000oBYKP0008eHS@02SER=00D0002`MI2`
MI00002YKXl00P000003m:IY0000SUV=00:>FHd01P000;=hTP00000008MBR`0000:WKI0020000:AZ
SZAZSP0009=PTP000?FWJ@0000>FGhh200000ZI]T0050000QeB>QeB>QeB>000000:WKi800`000:=Z
T000000300000fm0R0030000Z6f?Z6f?0080000019MSTP0000000:9ZT@X000000jVmj00000000003
000000>Y_NP0000000001P000004L4>;0000UFJI00000Y5LS`8000001LB5T0000;9hU0000004R002
00000YQ/WP040000TUj@TUj@TUj@10000003YfnC0000000000<00003UVJH1@000004UFBF00000000
aXbF0P0001;oool01@000?JRD`0009UQSP000009oooo0`0000_oool2000000>SJi40003oool0?ooo
o`030000oooooooo073oool00`000?ooooooo`02oooo0`0000:MIY400`000?ooooooo`0/oooo00<0
003oooooool03?ooo`00@Oooo`800037oooo00<0003oooooool00oooo`<00006oooo00T0002HHY00
0000002oP8h0002TJ8d0003oool00`000003[W6=0000000000<00002ZKgX00<0002AG92AG9000`00
0003XVJ<0000m;>300P00002Ld:600@0002kO8nkO8l00003000l0`0000:TJHd300000YeSS0060000
o/5do/5d0000YVf@00000ZI]T0030000XFF<000000L00003]W^A00T0002OI8`00000003TWhL0002U
Jhh0003VO2001P000003TEV;0000000000@00002YFZ>10000003m:U^0000SER=00:=F8d01`000;1e
T;1eT0000:U^S`0009eUS`0200000hiIS@060000/gRB00000000Qe:;00000ZM]T0080000Y6Z>Y6Z>
0000Tf2B0000mJMY00000iIOSP800002YVf@00D00027E8j7E8j7E8h000000ZM_TP030000XfZ@0000
00<00003Kd2800<0002XKHnXKHl00P000004Uf>B00000000XVZA4P000005ZKgX000000000000ZKgX
008000001713R`0009EVV@0000:AG8l2000000C4QI00002bN9@0000200B800@0002HK9jHK9h00002
TUj@00<0002WKY4000000P000007YfnC000000000000ff/00000UVJH008000000i=OT@0000000002
000000JEI9H000000000003UYi40000Boooo00D0003fXU<0002IHHh000002Oooo`<0000;oooo0P00
0003Xf^A0000oooo0;?oool010000?ooooooooooo`<00002WFJA00<0003oooooool0;?ooo`030000
oooooooo00coool004?oool00`000?ooooooo`34oooo00<0003oooooool00oooo`030000l:n50000
00Koool01@0009QRT00000000;n0SP0300000oooo`030000[W6=000000@00002ZKgX00<0002AG92A
G9000`000003XVJ<0000m;>300L000001XUGS`00000000000;]lS`0000@003`300000ZAYS@<00000
0ieSS0000?k1M002o/5d00<0002VKI0000000ZI]T0030000XFF<000000<000001:Vmj00000000000
00>fNi402@0009mTS00000000>BOQ`000:E[SP000>Il8006000000>AFH/00000000010000003YFZ>
0000c8b>00<000000oBYKP0008eHS@02SER=00L0002`MI2`MI00002YKXl0002MIHl00P0000B>FHd4
00000jM]T0080000Y6Z>Y6Z>0000Tf2B0000mJMY00000iIOSP800002YVf@00D00027E8j7E8j7E8h0
00000ZM_TP030000XfZ@000000<00003Kd2800<0002XKHnXKHl00`000003XV^B0000XVZA00800000
1JVmj000000000000:Vmj005000000FY_NP000000000002Y_NP020000004L4>;0000UFJI00000Y5L
S`8000001<B5T0000;9hU000008018P2000000JHK9h0002BGY2BGY00002WKY43000000FWKi<00000
0000003KJ`000P0000:CGi400`000:idTP000003000000BUL9H000000000000Coooo00D0003fXU<0
002IHHh000002Oooo`<0000;oooo0P000003Xf^A0000oooo0;Coool00`000?ooooooo`04000000>M
IY40003oool0;Oooo`030000oooooooo00coool004Coool00`000?ooooooo`33oooo00<0003ooooo
ool00oooo`030000l:n5000000Koool01@0009QRT00000000;n0SP0300000oooo`030000[W6=0000
00@00002ZKgX00<0002AG92AG9000`000007XVJ<0000m;>30000XfbC0000ZKgX00<00003REN?00<0
002kO8l000001000?0<00002Y6V=0`000004WF><0000o/5do/5d0P000006YVf@0000YVf@YVf@0000
XFF<200000>fNi402@0009mTS00000000>BOQ`000:E[SP000>Il8006000000>AFH/0000000000P00
0005Vf>?0000YFZ>0000c8b>00<000000oBYKP0008eHS@02SER=00<0002`MI0000000ZU^S`040000
WFF?0000000018iIS@@00003Yff@00<0002TJXjTJXh00`000003mJMY0000UUn>00:FGhh200000ZI]
T0050000QeB>QeB>QeB>000000:WKi800`000:=ZT000000300000fm0R0030000Z6f?Z6f?00<00000
0j9[TP000:9ZT@0=000000>Y_NP00000000020000005a4`000000000UFJI000000:AG8l2000000C4
QI00002bN9@0000200B80P000006V6bN0000TUj@TUj@0000YfjA0`000006YfnC000000000000ff/0
00000i=OT@030000[WBB000000<000001:E`UP000000000001?oool01@000?JRD`0009UQSP000009
oooo0`0000_oool2000000>SJi40003oool0]Oooo`030000oooooooo00<000000ieVT@000?ooo`0^
oooo00<0003oooooool02oooo`00AOooo`030000oooooooo0<;oool00`000?ooooooo`03oooo00<0
003`[hD000001_ooo`050000V6:@00000000_h2>00<00003oooo00<0002^LHd00000100000:Y_NP0
0`00095LT0000003000000FRIX`000000000002SK9<00P000003ZKgX0000000000>9Ehl00`000;]l
S`000004000l0`000003Y6V=0000iZB:0080000019eSS0000?k1M?k1M0800004YVf@00<0002QIH`0
00001@000003ReB:0000]W^A00:fNi402@0009mTS00000000>BOQ`000:E[SP000>Il800:00000Y]S
S`040000YFZ>0000c8b>0`000003m:U^0000SER=00:=F8d00`000;1eT0000002ZFj?00@0002MIHl0
00000004SUV=100000>WKI000`000:AZSZAZSP03000000?eYfT0002FGhh00YIOSP800002YVf@00D0
0027E8j7E8j7E8h000000ZM_TP030000XfZ@000000<00003Kd2800<0002XKHnXKHl00`000003XV^B
0000XVZA01P000001LA<0000000009EVV@000002TEb?0P000004a8F@0000/WRD00000P04R0800000
1YQ/WP00099NT99NT0000:M^T@<000001ZM_T`00000000000=][000000>CGi400`000:idTP000003
000000BUL9H000000000000Coooo00D0003fXU<0002IHHh000002Oooo`<0000;oooo0P000003Xf^A
0000oooo0;Goool00`000?ooooooo`03000000>MIY40003oool0;_ooo`030000oooooooo00_oool0
04Koool20000aoooo`8000000o2_Q@000?ooo`05oooo00D0002HHY000000002oP8h00`0000?oool0
0`000:iaS@00000400000ZVmj0030000TEb@000000<000001J9VS000000000000:=/T`0500000hUG
S`030000^gb?000000@003`3000000>TJHd0003VY8X00P000004WF><0000o/5do/5d0P0000BVKI00
0`000:5US0000002000000BY_NP0000000000004]W^A00T0002OI8`00000003TWhL0002UJhh0003V
O20020000008Odb90000Vf>?Vf>?0000YFZ>0000c8b>0`000003m:U^0000SER=00:=F8d00`000;1e
T0000002ZFj?00@0002MIHl000000004SUV=100000>WKI000`000:AZSZAZSP03000000?eYfT0002F
Ghh00YIOSP800002YVf@00D00027E8j7E8j7E8h000000ZM_TP030000XfZ@000000<00003Kd2800<0
002XKHnXKHl00`000003XV^B0000XVZA00T000000jVmj00000000003000000>Y_NP0000000001P00
0005a4`000000000UFJI000000:AG8l2000000C4QI00002bN9@0000200B80P000006V6bN0000TUj@
TUj@0000YfjA0`000006YfnC000000000000ff/000000i=OT@030000[WBB000000<000001:E`UP00
0000000001?oool01@000?JRD`0009UQSP000009oooo0`0000_oool2000000>SJi40003oool0]_oo
o`070000oooo0000RU250000WFJA000002ooool00`000?ooooooo`0;oooo0018oooo00<0003ooooo
ool0a?ooo`8000000o2_Q@000?ooo`05oooo00<0002HHY0000000[n0SP<00003oooo00<0002^LHd0
0000100000:Y_NP00`00095LT0000003000000>RIX`0000000001`0000>9Ehl00`000;]lS`000003
000l10000003Y6V=0000iZB:0080000019eSS0000?k1M?k1M0800004YVf@00<0002QIH`000001P00
00BfNi402@0009mTS00000000>BOQ`000:E[SP000>Il800900000i]SS`040000YFZ>0000c8b>0`00
0003m:U^0000SER=00:=F8d00`000;1eT0000002ZFj?00@0002MIHl000000004SUV=100000>WKI00
0`000:AZSZAZSP0500000iIOSP800002YVf@00D00027E8j7E8j7E8h000000ZM_TP030000XfZ@0000
00@00002Kd2800<0002XKHnXKHl00`000003XV^B0000XVZA00D000000jVmj00000000009000000FY
_NP000000000002Y_NP00P000003a4`00000L4>;00800002TEb?10000004/WRD000000B800B80P00
0006V6bN0000TUj@TUj@0000YfjA0`000006YfnC000000000000ff/000000i=OT@030000[WBB0000
00800002YG2F0`0001?oool01@000?JRD`0009UQSP00000:oooo0P0000_oool2000000>SJi40003o
ool0]oooo`80000018Y@Q@0009eVT@0002ooool00`000?ooooooo`0;oooo0019oooo00<0003ooooo
ool0`oooo`<00007oooo00H0002HHY00002oP8h0003oool200000oooo`040000[W6=0000oooo0`00
0004ZKgX0000TEb@TEb@10000003XVJ<0000000000L00003REN?00<0002kO8l000000`00?0@00000
0jAYS@000>JTRP02000000BMHh`0003n`GCn`G@200001:I]T0030000XFF<000000H00004]W^A00T0
002OI8`00000003TWhL0002UJhh0003VO2002@0000>KHhl010000:EZSP000<b<SP<000000oBYKP00
08eHS@02SER=00<0002`MI0000000ZU^S`040000WFF?0000000018iIS@@00003Yff@00<0002TJXjT
JXh01@0000>FGhh200000ZI]T0050000QeB>QeB>QeB>000000:WKi800`000:=ZT000000400000Vm0
R0030000Z6f?Z6f?00<000000j9[TP000:9ZT@0;000000FY_NP000000000002Y_NP020000003a4`0
0000L4>;00800002TEb?10000004/WRD000000B800B80P000006V6bN0000TUj@TUj@0000YfjA0`00
0006YfnC000000000000ff/000000i=OT@030000[WBB000000800002YG2F0`0001?oool01@000?JR
D`0009UQSP00000:oooo0P0000_oool2000000>SJi40003oool0]oooo`80000018Y@Q@0009eVT@00
02ooool00`000?ooooooo`0;oooo001:oooo00<0003oooooool0`_ooo`<00007oooo00L0002HHY00
002oP8h0003oool000001?ooo`030000[W6=000000?oool300000Y5LT0@000000j9VS00000000003
000000BY_NP0000000000003REN?00<0002kO8l000000`00?0<00002Y6V=00H0003VY8X00000002M
Hh`00002o/5d0P0000BVKI000`000:5US000000600001;IkT@090000WfB<00000000i9n70000YF^>
0000iW`P00T00003Vf>?00@0002UJXh0003<S8h3000000?dZFh0002=F8d00XeHS@030000/7F@0000
00:YKXl0100009eUS`00000000B>FHd400000jM]T0030000Y6Z>Y6Z>00D00003UUn>0P0000:VKI00
1@0008MDSXMDSXMDSP000002YfnB00<0002SJY0000001000009_@8P00`000:Q]SjQ]S`03000000>R
Ji80002RJY4030000003ZKgX0000000000T000000lA<00000713R`0200000Y5LS`@000001;9hU000
0004R004R08000001YQ/WP00099NT99NT0000:M^T@<000001ZM_T`00000000000=][000000>CGi40
0`000:idTP00000200000ZE`UP<0000Coooo00D0003fXU<0002IHHh000002_ooo`80000;oooo0P00
0003Xf^A0000oooo0;Soool00`0008Y@Q@000002WFJA00<0003oooooool0;?ooo`030000oooooooo
00_oool004_oool20000`_ooo`<00007oooo00L0002HHY00002oP8h0003oool000001?ooo`030000
[W6=000000Coool200000Y5LT0@000000j9VS0000000000700000hUGS`030000^gb?000000<003`3
00000ZAYS@060000iZB:00000000WF><00000_k1M0800004YVf@0P000003o/9a0000000000@00004
]W^A00D0002OI8`00000003TWhL00`000003iW`P0000000000L00003Vf>?00@0002UJXh0003<S8h3
000000?dZFh0002=F8d00heHS@800002ZFj?00@0002MIHl000000004SUV=100000>WKI000`000:AZ
SZAZSP0500000iIOSP8000000jI]T00000000003QeB>00<0002WKi8000000Z=ZT0D00002Kd2800<0
002XKHnXKHl00P0000:RJi84000000>Y_NP0000000004`000003a4`00000L4>;00800002TEb?1000
0004/WRD0000000000B80P000004V6bN0000TUj@TUj@0P000004_h:A00000000YfnC0`000003ff/0
0000TenA00:CGi400`000:idTP000002000000>UL9H00036S9H00P0001Coool2000000>IHHh0003o
ool02Oooo`80000<oooo0`000;[oool01@0008Y@Q@0009eVT@00000^oooo00<0003oooooool02ooo
o`00COooo`030000oooooooo0;ooool300001oooo`070000V6:@0000_h2>0000oooo000000Coool0
0`000:iaS@000004oooo0P000003TEb@0000000000@000000oBcP`000000000600000XUGS`800000
0k]lS`000000?002000l0`0000:TJHd02P000>JTRP00000009eSS0000?k1M000099NT@0000BVKI02
000000?n`W4000000000100000BfNi401@0009mTS00000000>BOQ`03000000?VO200000000001P00
00BKHhl010000:EZSP000<b<SP<000000oBYKP0008eHS@03SER=0P000004ZFj?0000WFF?WFF?0P00
00B>FHd400000jM]T0030000Y6Z>Y6Z>00D00003UUn>0P000003YVf@0000000000>7E8h00`000:M_
TP000002XfZ@1@00009_@8P00`000:Q]SjQ]S`0200000Z9[TPX000000jVmj00000000003000000>Y
_NP0000000000`000007ZKgX000000000000a4`00000L4>;008000000i5LS`000:aaT@06000000D0
18P00000002HK9h000000Y9NT08000001;n2T@0000000:M_T`<000000m][000009=OT@02TenA00<0
002^M98000000P000003YG2F0000aXbF0080000Doooo0P000003VF6>0000oooo00Woool200003?oo
o`<0002joooo0`000003WFJA0000oooo02koool00`000?ooooooo`0:oooo001>oooo00<0003ooooo
ool0__ooo`<00007oooo0`000004_h2>0000oooo00001?ooo`<00004oooo0P000003TEb@00000000
00@000000oBcP`000000000600000XUGS`D00002000l0`0000:TJHd4000000JMHh`0003n`G@0002B
GY400004YVf@0P000003o/9a0000ZKgX00<00005]W^A00D0002OI8`00000003TWhL00`000003iW`P
0000000000H00004Vf>?00D0002UJXh00000002XKY000P000003m:U^0000SER=00>=F8d2000000BY
KXl0002MIHnMIHl2000018iIS@<00004Yff@00<0002TJXjTJXh01@0000>FGhh2000000>VKI000000
00000hMDSP030000YfnB000000:SJY0500000Vm0R0030000Z6f?Z6f?00800002XV^B1P000003ZKgX
00000000014000000lA<00000713R`02000000>AG8l0002/LI4010000003oooo000000B800800000
19Q/WP00099NT99NT08000001;n2T@0000000:M_T`<000000m][000009=OT@02TenA00<0002^M980
00000P000003YG2F0000aXbF0080000Doooo0P000003VF6>0000oooo00Woool200003?ooo`<0002j
oooo0`000003WFJA0000oooo02koool00`000?ooooooo`0:oooo001?oooo00<0003oooooool0_Ooo
o`<00007oooo0`000004_h2>0000oooo00001?ooo`<00004oooo0P000003TEb@0000000000@00000
0oBcP`000000000600000XUGS`D00002000l0`0000:TJHd4000000JMHh`0003n`G@0002BGY400004
YVf@0P000004o/9a00000000ZKgX0P0000FfNi401@0009mTS00000000>BOQ`03000000?VO2000000
00001P0000BKHhl01@000:EZSP0000000:Q^T002000000?dZFh0002=F8d00heHS@8000001:U^S`00
09eUSieUS`800004SUV=0`0000>WKI0200000ZAZSPD00003UUn>0P000003YVf@0000000000>7E8h0
0`000:M_TP000002XfZ@1@00009_@8P00`000:Q]SjQ]S`0200000Z9[TP`000000jVmj00000000003
000000>Y_NP0000000001@000003a4`00000L4>;008000000i5LS`000:aaT@04000000?oool00000
18P00P000004V6bN0000TUj@TUj@0P000004_h:A0000YfnCYfnC0`000003ff/00000TenA00:CGi40
0`000:idTP000002000000>UL9H00036S9H00P0001Coool2000000>IHHh0003oool02Oooo`80000<
oooo0`000;[oool01@0008Y@Q@0009eVT@00000_oooo00<0003oooooool02_ooo`00D?ooo`80002m
oooo00<0003`[hD000001oooo`<000001;n0SP000?ooo`0000Coool300001?ooo`8000000i5LT000
00000002000000>RIX`0003d/h<00`000003ZKgX0000000000800002REN?1@00008003`300000ZAY
S@@000001YeSS0000?k1M000099NT@0000BVKI02000000?n`W40000000000`0000FfNi400`0009mT
S0000002000000FUJhh000000000001jBH/01`0000BKHhl00`000:EZSP000002000000Cl_7P0003d
ZFh00004SER=0P000004ZFj?0000WFF?WFF?0P0000B>FHd300000jM]T0800002Y6Z>1@0000>FGhh2
000000>VKI00000000000hMDSP060000YfnB0000XfZ@0000aXNA1000009_@8P00`000:Q]SjQ]S`02
00000Z9[TQ<000000jVmj00000000004000000?4C000001`@h/00P000003TEb?0000[76A00@00000
1Oooo`000004R00007U:S@0200000Y9NT08000001;n2T@000:M_TjM_T`<000000m][000009=OT@02
TenA00<0002^M98000000P000003YG2F0000aXbF0080000Doooo0P000003VF6>0000oooo00Woool2
00003?ooo`<0002joooo00<0002:D8D000000P0002ooool00`000?ooooooo`0:oooo001Boooo00<0
003oooooool0^_ooo`030000l:n5000000Ooool3000000BoP8h0003oool00004oooo0`0000Coool2
000000>AG900003oool00P000003XVJ<0000m;>300H000001:Vmj00008UGShUGS`D00002000l0`00
00:TJHd4000000>MHh`0003n`G@00`0000BVKI02000000?n`W40000000000`0000FfNi400`0009mT
S0000002000000FUJhh000000000001jBH/01`0000BKHhl00`000:EZSP000002000000Cl_7P0003d
ZFh00004SER=0P000003ZFj?0000WFF?00<00004SUV=0`0000>WKI0200000ZAZSPD00003UUn>0P00
0003YVf@0000000000>7E8h01P000:M_TP000:=ZT0000<J7T@@00002Kd2800D0002XKHl0003>SHd0
00000Z9[TP<000000jVmj00000000003000000>Y_NP0000000003@000004oooo00000000L4>;0P00
0003TEb?0000[76A00@000001Oooo`000004R00007U:S@0200000Y9NT08000001;n2T@000:M_TjM_
T`<000000m][000009=OT@02TenA00<0002^M98000000P000003YG2F0000aXbF0080000Doooo0P00
0003VF6>0000oooo00Woool200003?ooo`<0002joooo00D0002:D8D0002MIY400000;oooo`030000
oooooooo00[oool005?oool00`000?ooooooo`2ioooo00<0003`[hD000001oooo`<000000kn0SP00
0?ooo`05oooo0`0000Coool2000000JAG900003oooooool0002RIX`2000000FY_NP000000000002Y
_NP00`0000:9Ehl6000000@003`0000000000002Y6V=10000003WF><0000o/5d00<00003YVf@00@0
002QIH`0003n`W43000000=gZo<0002fNi401;IkT@030000WfB<0000008000001JE[SP0000000000
07Y9R`07000019]SS`030000YFZ>0000008000001?blN0000?BYKP0000B=F8d2000000>YKXl0002M
IHl00`0000B>FHd300000jM]T0800002Y6Z>1@0000:FGhh00`0001<0IQ<0IP0300000hMDSP060000
YfnB0000XfZ@0000aXNA1000009_@8P020000:Q]S`000<j=S@000:9[TP000:9ZT@X000001JVmj000
000000000:Vmj00500001Oooo`8000001W13R`000000095LS`000:aaT@@000001Oooo`000004R000
07U:S@0200000Y9NT08000001;n2T@000:M_TjM_T`<000000m][000009=OT@02TenA00<0002^M980
00000P000005YG2F00000000iJNA000001Coool2000000>IHHh0003oool02Oooo`80000<oooo0`00
0;_oool2000000>MIY40003oool0;_ooo`030000oooooooo00[oool005Coool00`000?ooooooo`2h
oooo00<0003`[hD000001oooo`800002_h2>00<0003oooooool01?ooo`800005oooo100000;oool0
0`000:9VS0000002000000>Y_NP000000000100000:9Ehl6000000@003`0000000000002Y6V=1@00
00;n`G@300000jI]T0090000XFF<0000o/9a0000ZKgX0000Mj_c000000FfNi43000000?S_C/0002U
Jhh00`000003NTV;0000000000<000000kMjT00009]SS`03Vf>?00<0002UJXh000000P000004o;ah
0000m:U^000018eHS@8000000jU^S`0009eUS`03000018iIS@<00003Yff@0P0000:TJXh500000YIO
SP0300004`1V4`1V00<00003QeB>00H0002WKi80002SJY000036Qi4400000Vm0R0080000Z6f?0000
cXf=0000XV^B0000XVZA10000005ZKgX000000000000ZKgX00P00008oooo0P000006L4>;00000000
TEb?0000[76A10000005oooo000000B80000NDZ=00800002TUj@0P000004_h:A0000YfnCYfnC0`00
00;KJ`001@0009=OTI=OT@000:idTP03000000FUL9H00000003UYi4000005?ooo`8000000iUQSP00
0?ooo`09oooo0P0000coool30000^oooo`8000000ieVT@000000000^oooo00<0003oooooool02_oo
o`00EOooo`030000oooooooo0;Ooool200002?ooo`800002_h2>00<0003oooooool01?ooo`800005
oooo100000;oool00`000:9VS000000600000ZVmj0030000REN?REN?00H000001000?00000000000
00:TJHd5000000?n`G@0002BGY400P0000>VKI0010000:5US0000?k2L@<000000gN[l`000;IkT@04
]W^A0`000003hkdk0000YF^>00<000000gY9R`0000000003000000>gNY00002KHhl00i]SS`030000
YFZ>0000008000001?blN0000?BYKP0000B=F8d2000000>YKXl0002MIHl00`0000B>FHd300000jM]
T0800002Y6Z>1@0000:FGhh00`0001<0IQ<0IP03000018MDSP8000000j=ZT0000<J7T@0400000Vm0
R0080000Z6f?0000cXf=0000XV^B0000XVZA1@000003ZKgX0000000000L0000:oooo0P000006L4>;
00000000TEb?0000[76A0P000007oooo0000oooo000000B80000NDZ=008000001i9NT0000:M^T@00
0;n2T@000:M_T`0400000]][00050000TenATenA0000[WBB00L0000Eoooo0P000003VF6>0000oooo
00[oool00`000?ooooooo`0:oooo0`000;_oool01P0008Y@Q@0000000?ooo`0002goool00`000?oo
ooooo`0:oooo001Foooo0P000;Ooool200002?ooo`8000000kn0SP000?ooo`06oooo0P0000Goool3
00000oooo`030000XVJ<000000@000001JVmj0000:Vmj:Vmj0000002REN?00<0002kO8l000000`00
0007000l000000000000Y6V=0000iZB:00@000001Ok1M00000000>:[VP000003YVf@00@0002QIH`0
003n`W43000000=gZo<0002fNi401;IkT@<000000n>m>`000:E[SP03000000=jBH/0000000000`00
0003]gZ@0000Vf>?00>KHhl00`000:EZSP000002000000Cl_7P0003dZFh00004SER=0P000003ZFj?
0000WFF?00<00004SUV=0`0000>WKI0200000ZAZSPD00002UUn>00<0000C06HC06H00`0000B7E8h2
000000>SJY000036Qi401000009_@8P020000:Q]S`000<j=S@000:9[TP000:9ZT@/0000>oooo0P00
0006L4>;00000000TEb?0000[76A0P000007oooo0000oooo000000B80000NDZ=008000001i9NT000
0:M^T@000;n2T@000:M_T`0400000]][00050000TenATenA0000[WBB00L0000Eoooo0P000003VF6>
0000oooo00[oool00`000?ooooooo`0:oooo0`000;_oool01P0008Y@Q@0000000?ooo`0002koool0
0`000?ooooooo`09oooo001Hoooo00<0003oooooool0]?ooo`800008oooo0P000003_h2>0000oooo
00Koool200001_ooo`800003oooo00D0002RIX`00000003oool0100000:Y_NP01@0008UGShUGS`00
0;]lS`03000000>NIi80000000000P000003Y6V=0000iZB:00@000000ok1M0000000000200000jI]
T0040000XFF<0000o/9a0`000003Mj_c0000]W^A00BfNi43000000?S_C/0002UJhh00`000008NTV;
000000000000mK9m0000]gZ@000019]SS`030000YFZ>0000008000001?blN0000?BYKP0000B=F8d0
1@000:U^SjU^S`0009eUS`0300000hiIS@@00003Yff@0P0000:TJXh2000000?h^7h0000000000YIO
SP0300004`1V4`1V00<00004QeB>0P000003XfZ@0000aXNA00@00002Kd2800P0002XKHl0003>SHd0
002RJi80002RJY4700004_ooo`800002L4>;00@0002AG8l0002/LI42000000Ooool0003oool00000
18P0001iBXd00P000007TUj@0000YfjA0000_h:A0000YfnC00<0000017E8SP000=][000000:CGi42
000000>aMY8000000000100001Goool2000000>IHHh0003oool02_ooo`030000oooooooo00_oool2
0000^oooo`040000RU25000000000_ooo`030000oooooooo02_oool00`000?ooooooo`09oooo001I
oooo00<0003oooooool0]?ooo`030000oooooooo00Koool2000000>oP8h0003oool01Oooo`<00006
oooo0P0000?oool010000:9VS000000000;oool4000000JY_NP00029Ehn9Ehl0002kO8l8000000>T
JHd0003VY8X010000003o/5d0000000000800003YVf@00@0002QIH`0003n`W43000000=gZo<0002f
Ni401;IkT@<000000n>m>`000:E[SP03000000QjBH/000000000003e/Wd0002gNY000004Vf>?0P00
0007c8b>00000000o;ah0000m:U^000000B=F8d01@000:U^SjU^S`0009eUS`0300000hiIS@@00003
Yff@0P0000:TJXh2000000?h^7h0000000000YIOSP0300004`1V4`1V00<00004QeB>0P000003XfZ@
0000aXNA00<000002oBWJ`0006m0R0000:Q]S`000<j=S@000:9[TP000:9ZT@0400005Oooo`800002
L4>;0`00000:[76A00000000oooo0000oooo000000B80000NDZ=0P000007TUj@0000YfjA0000_h:A
0000YfnC00<0000017E8SP000=][000000:CGi42000000>aMY8000000000100001Goool010000?JR
D`00000000_oool00`000?ooooooo`0;oooo0P000;_oool01@0008Y@Q@0009eVT@000002oooo00<0
003oooooool0:_ooo`030000oooooooo00Woool005[oool00`000?ooooooo`2coooo00<0003ooooo
ool01_ooo`8000000kn0SP000?ooo`05oooo0`0000Koool200000oooo`040000XVJ<000000000ooo
o`<000001:Vmj00008UGShUGS`X000000jAYS@000>JTRP04000000?n`G@0000000000P0000>VKI00
10000:5US0000?k2L@D00005]W^A0`000003hkdk0000YF^>00<000000gY9R`0000000005000019]S
S`8000001lb<SP0000000?blN0000?BYKP000004SER=00D0002YKXnYKXl0002MIHl00`0000>>FHd4
00000jM]T0800002Y6Z>0P000003n;Qn0000000000:FGhh00`0001<0IQ<0IP03000018MDSP800000
0j=ZT0000<J7T@05000000U_@8P0002XKHl0003>SHd0002RJi80002RJY400P0001Ooool200000W13
R`<000000jaaT@0000000004oooo0P00000:NDZ=00000000TUj@0000YfjA0000_h:A0000YfnC0`00
0004MDR>0000ff/000000Y=OT@8000001K5fTP00000000000<J<UP0200005Oooo`040000mZ9C0000
00002oooo`030000oooooooo00_oool20000_?ooo`8000000ieVT@000?ooo`02oooo00<0003ooooo
ool0:Oooo`030000oooooooo00Woool005_oool20000_?ooo`8000000kn0SP000?ooo`05oooo0`00
00Koool00`000?ooooooo`02oooo00@0002RIX`000000004oooo0P000004ZKgX0000REN?REN?0P00
0003ZFf>0000000000<000001JVmj0000:AYS@000>JTRP04000000?n`G@0000000000P0000>VKI00
0`000:5US000000600001KIkT@<000000n>m>`000:E[SP03000000=jBH/0000000001@0000BKHhl2
000000C<S8h00000003l_7P200001HeHS@050000ZFj?ZFj?0000WFF?00<00003SUV=100000:WKI00
0`000000C@000002Y6Z>0P000003n;Qn0000000000:FGhh00`0001<0IQ<0IP03000018MDSP800000
0j=ZT0000<J7T@02000000bY_NP00000001_@8P0002XKHl0003>SHd0002RJi80002RJY4200005ooo
o`800002L4>;0`000003[76A0000000000Coool2000000YiBXd00000002BGY00002WKY40002oPY40
002WKi<3000000AeB8h0003KJ`000002TenA0P000005/GJB000000000000aXbF0080000Eoooo00@0
003fXU<00000000;oooo00<0003oooooool02oooo`80002loooo0P000003WFJA0000oooo00;oool0
0`000?ooooooo`0Yoooo00<0003oooooool02Oooo`00GOooo`030000oooooooo0;Woool2000000>o
P8h0003oool01Oooo`<00006oooo00<0003oooooool00_ooo`8000000oBcP`000?ooo`04oooo00<0
002Y_NP000000XUGS`8000000jU]SP0000000005000000BTJHd00000003l_W`3000000?n`G@0003R
ZiX00P0000>VKI000`000:5US000000600001KIkT@<000000n>m>`000:E[SP03000000=jBH/0002>
F8`00P000003]gZ@0000000000BKHhl2000000C<S8h00000003l_7P200001HeHS@050000ZFj?ZFj?
0000WFF?00<00003SUV=100000:WKI000`000000C@000002Y6Z>0P000003n;Qn0000000000:FGhh0
0`0001<0IQ<0IP03000018MDSP8000000j=ZT0000<J7T@05000000U_@8P0002XKHl0003>SHd0002R
Ji80002RJY400P0001Ooool200000W13R`<000000jaaT@0000000004oooo0P00000:NDZ=00000000
TUj@0000YfjA0000_h:A0000YfnC0`000009MDR>0000ff/00000TenA0000[WBB0000/GJB00<00000
0lJ<UP000000000Foooo0`0001Woool20000_?ooo`8000000ieVT@000?ooo`03oooo00<0003ooooo
ool0:?ooo`030000oooooooo00Woool005koool00`000?ooooooo`2hoooo0P000003_h2>0000oooo
00Goool300001_ooo`030000oooooooo00;oool2000000?d/h<0003oool01Oooo`800002REN?0P00
0003ZFf>0000000000D000001:AYS@0000000?bnO0<000000ok1M0000>:[VP0300000ZI]T0030000
XFF<000000D000000gN[l`000;IkT@03]W^A0`000003hkdk0000YF^>00<000000gY9R`0008iHS002
000000>gNY000000000019]SS`8000000lb<SP000000000300001HeHS@050000ZFj?ZFj?0000WFF?
00<00003SUV=100000:WKI000`000000C@000002Y6Z>0P000003n;Qn0000000000:FGhh00`0001<0
IQ<0IP03000018MDSP8000000j=ZT0000<J7T@05000000U_@8P0002XKHl0003>SHd0002RJi80002R
JY400P0001Ooool200000W13R`<000000jaaT@0000000004oooo0P00000:NDZ=00000000TUj@0000
YfjA0000_h:A0000YfnC0`000009MDR>0000ff/00000TenA0000[WBB0000/GJB00<000000lJ<UP00
0000000Foooo0`0001Woool20000_?ooo`8000000ieVT@000?ooo`04oooo00<0003oooooool09ooo
o`030000oooooooo00Woool005ooool00`000?ooooooo`2goooo0P000003_h2>0000oooo00Goool2
00003?ooo`8000000oBcP`000?ooo`05oooo0P0000:9Ehl4000000>NIi80000000000`000004Y6V=
00000000o;il1P000003VFBB0000000000:VKI02000000?n`W40000000000`000003Mj_c0000]W^A
00:fNi401`0009mTS00000000>>m>`000:E[SP03000000=jBH/0002>F8`00P000003]gZ@00000000
00BKHhl2000000?<S8h0000000000`0000F=F8d01@000:U^SjU^S`0009eUS`0300000hiIS@@00002
Yff@00P0000004d0002TJXh0002UKI40003h^7h200000YIOSP0300004`1V4`1V00<00004QeB>00<0
002SJY2SJY000`0000;oool2000000U_@8P0002XKHl0003>SHd0002RJi80002RJY400P0001Ooool2
00000W13R`<000000jaaT@0000000004oooo0P00009iBXd02000099NT0000:M^T@000;n2T@000:M_
T`<000002GE8SP000=][000009=OT@000:idTP000;5fTP03000000?6S9H0000000005_ooo`<0000I
oooo0P000;coool0100008Y@Q@00000000Koool00`000?ooooooo`0Woooo00<0003oooooool02?oo
o`00H?ooo`80002goooo0P000003_h2>0000oooo00Goool200003?ooo`<00007oooo0P0000:9Ehl4
000000BNIi800000002Y_NP2000000BTJHd00000003l_W`6000000>II980000000000ZI]T0800000
0ok2L@000:Vmj003000000=gZo<0002fNi400[IkT@050000WfB<00000000hkdk00D000000gY9R`00
08iHS002000000>gNY000000000019]SS`8000000lb<SP000000000300001HeHS@050000ZFj?ZFj?
0000WFF?00<00003SUV=100000:WKI0020000000C@000:AZSP000:E]T@000?RhOP800002UUn>00<0
000C06HC06H00`0000B7E8h00`000:=ZT:=ZT00300000_ooo`8000002Fm0R0000:Q]S`000<j=S@00
0:9[TP000:9ZT@0200005oooo`800002L4>;0`000003[76A0000000000Coool200000WU:S@<00000
1JM^T@000;n2T@000:M_T`03000000UeB8h0003KJ`00002CGi40002^M980002aMY800`000003aXbF
0000000001Koool300006Oooo`80002moooo0`0000Koool00`000?ooooooo`0Woooo00<0003ooooo
ool02?ooo`00H_ooo`030000oooooooo0;Coool2000000>oP8h0003oool01Oooo`80000<oooo0`00
00Ooool200000XUGS`@000000iiWTP0000000003000000BTJHd00000003l_W`6000000>II9800000
00000ZI]T08000000ok2L@0000000003000000=gZo<0002fNi400[IkT@050000WfB<00000000hkdk
00D000000gY9R`0000000002000000>gNY000000000019]SS`8000001/b<SP000000000004DLN@00
00F=F8d01@000:U^SjU^S`0009eUS`0300000XiIS@030000/gVC000000800002Yff@00P0000004d0
002TJXh0002UKI40003h^7h200000YIOSP0300004`1V4`1V00<00004QeB>00<0002SJY2SJY000`00
00;oool2000000U_@8P0002XKHl0003>SHd0002RJi80002RJY400P0001Ooool200000W13R`<00000
0jaaT@0000000004oooo0P00009iBXd3000000FWKY40002oPY40002WKi<00`000009MDR>0000ff/0
0000TenA0000[WBB0000/GJB00<000000lJ<UP000000000Foooo0`0001Woool20000_Oooo`<00007
oooo00<0003oooooool09_ooo`030000oooooooo00Soool006?oool00`000?ooooooo`2coooo0P00
0003_h2>0000oooo00Goool200003?ooo`<00007oooo0P0000:9Ehl:000000BTJHd00000003l_W`5
00000YUTTP800002YVf@0P000008o/9a000000000000ZKgX0000Mj_c00000kIkT@050000WfB<0000
0000hkdk00D000000gY9R`0000000002000000>gNY000000000019]SS`8000001/b<SP0000000000
04DLN@0000F=F8d01@000:U^SjU^S`0009eUS`0300000XiIS@030000/gVC000000800002Yff@00P0
000004d0002TJXh0002UKI40003h^7h200000YIOSP0300004`1V4`1V00<00004QeB>00<0002SJY2S
JY000`0000;oool2000000U_@8P0002XKHl0003>SHd0002RJi80002RJY400P0001Soool00`000713
Rg13R`03000000>/LI40000000001?ooo`800002NDZ=0`000005YfjA0000_h:A0000YfnC00<00000
2GE8SP000=][000009=OT@000:idTP000;5fTP03000000?6S9H0000000005_ooo`<0000Joooo00<0
003oooooool0^oooo`<00008oooo00<0003oooooool09Oooo`030000oooooooo00Soool006Coool0
0`000?ooooooo`2boooo0`0000Ooool200003?ooo`<00008oooo00<00029Ehn9Ehl02P000004Y6V=
00000000o;il1@0000:II98200000ZI]T08000000ok2L@0000000003000000=gZo<0002fNi400[Ik
T@030000WfB<0000008000000jE[SP0000000002000000=jBH/0000000000P000003]gZ@00000000
00>KHhl010000:EZSP000<b<SP<000000dDLN@0008eHS@04SER=00D0002YKXnYKXl0002MIHl00`00
00:>FHd00`000;=iT`00000200000ZM]T0080000001=0000Y6Z>0000YFfA0000n;Qn0P0000:FGhh0
0`0001<0IQ<0IP03000018MDSP030000XfZ@XfZ@00<00002oooo0P000009Kd280000Z6f?0000cXf=
0000XV^B0000XVZA0080000Hoooo00<0001`@h]`@h/00`000003[76A0000000000Coool200000WU:
S@<000001JM^T@000;n2T@000:M_T`03000000UeB8h0003KJ`00002CGi40002^M980002aMY801000
0003iJNA0000oooo01Goool300006_ooo`030000oooooooo0;_oool300002?ooo`030000oooooooo
02Goool00`000?ooooooo`08oooo001Uoooo0P000;;oool300001oooo`80000<oooo0`0000Soool0
0`0008UGShUGS`06000000FY_NP000000000002TJHd00P000004o;il00000000o/5d0P0000:II982
00000ZI]T08000000ok2L@0000000003000000=gZo<0002fNi400[IkT@030000WfB<000000800000
0jE[SP0000000002000000IjBH/00000002gNY00002gNY0200000i]SS`040000YFZ>0000c8b>0`00
0003AAai0000SER=00>=F8d200000ZU^S`030000WFF?000000800002SUV=00<0002cNI<000000P00
00:WKI0020000000C@000:AZSP000:E]T@000?RhOP800002UUn>00<0000C06HC06H00`0000B7E8h0
0`000:=ZT:=ZT00300000_ooo`8000002Fm0R0000:Q]S`000<j=S@000:9[TP000:9ZT@0200006?oo
o`030000L4>;L4>;00800002[76A0P0000Coool200000WU:S@<000001JM^T@000;n2T@000:M_T`03
00000WE8SP8000001I=OT@000:idTP000;5fTP04000000?UYi40003oool05Oooo`<0000Joooo00<0
003oooooool0^oooo`<00009oooo00<0003oooooool09?ooo`030000oooooooo00Soool006Ooool0
0`000?ooooooo`2_oooo0`0000Ooool200003?ooo`<00008oooo00D00029Ehn9Ehl0002YKHh01@00
0004ZKgX00000000Y6V=0P000004o;il00000000o/5d0P0000:II98200000ZI]T08000000ok2L@00
0000000500000kIkT@030000WfB<0000008000000jE[SP000:ecT@02000000=jBH/0000000000kMj
T0800003Vf>?00D0002UJXh00000002XKY00100000B=F8d200000ZU^S`030000WFF?000000800002
SUV=00<0002cNI<000000P0000:WKI0020000000C@000:AZSP000:E]T@000?RhOP800002UUn>00<0
000C06HC06H00`0000B7E8h00`000:=ZT:=ZT00300000_ooo`8000002Fm0R0000:Q]S`000<j=S@00
0:9[TP000:9ZT@0200006?ooo`030000L4>;L4>;00800002[76A0P0000Coool200000WU:S@<00000
1JM^T@000;n2T@000:M_T`0300000WE8SP8000001I=OT@000:idTP000;5fTP04000000?UYi40003o
ool05Oooo`<0000Joooo00<0003oooooool0^oooo`<0000:oooo00<0003oooooool08oooo`030000
oooooooo00Soool006Soool00`000?ooooooo`2^oooo0`0000Ooool200003?ooo`<00008oooo00D0
0029Ehn9Ehl0002YKHh02@000003iZB:0000o;il00<000000n5b5P0009UTTP0300000ZI]T0800000
1?k2L@0000000:Vmj0@00003]W^A00<0002OI8`000000P000003YF^>0000[G>A008000000gY9R`00
00000003]gZ@0P0000>KHhl01@000:EZSP0000000:Q^T004000018eHS@800002ZFj?00<0002MIHl0
00000P0000:>FHd00`000;=iT`000002000000ZWKI00000004d004d0002TJXh0002UKI40003h^7h2
00000YIOSP0300004`1V4`1V00<00004QeB>00<0002SJY2SJY000`0000;oool2000000U_@8P0002X
KHl0003>SHd0002RJi80002RJY400P0001Soool00`000713Rg13R`0200000ZaaT@800005oooo00<0
001iBXeiBXd00`000005YfjA0000_h:A0000YfnC00<00002MDR>0P000005TenA0000[WBB0000/GJB
00D0000Goooo0`0001[oool00`000?ooooooo`2loooo0P0000_oool00`000?ooooooo`0Roooo00<0
003oooooool02?ooo`00JOooo`030000oooooooo0:goool00`000;n0SP000007oooo0P0000coool3
00002?ooo`050000REN?REN?0000ZFf>00T000000nJTRP000?bnO003000000?QLQH0002II9800`00
00:VKI06000000BY_NP0000000000003]W^A00<0002OI8`000000P000003YF^>0000[G>A00800000
0gY9R`0000000002]gZ@00<0002fXA0000000i]SS`050000YFZ>00000000Z6j@00@00004SER=0P00
0004ZFj?0000WFF?WFF?0`0000:>FHd00`000;=iT`000002000000JWKI00000004d004d0002TJXh2
00000_RhOP8000000iIOSP0001<0IP024`1V0`0000B7E8h00`000:=ZT:=ZT00300000_ooo`800000
2Fm0R0000:Q]S`000<j=S@000:9[TP000:9ZT@0200006?ooo`050000L4>;L4>;L4>;000000:/LI42
00001Oooo`8000002GU:S@00000000000:M^T@000;n2T@000:M_T`0300000WE8SP8000001I=OT@00
0:idTP000;5fTP0500005oooo`<0003Ioooo0`0000[oool00`000?ooooooo`0Soooo00<0003ooooo
ool01oooo`00J_ooo`030000oooooooo0:coool00`000;n0SP000007oooo0P0000_oool400002Ooo
o`040000REN?0000ZFf>0`0000;oool4000000?VY8X0003l_W`00`000003hG8F0000VFBB00<00002
YVf@2P0000>fNi43000000GS_C/0002UJhh0002]Li400P000003NTV;0000000000:gNY000`000;JQ
40000003Vf>?00<0002UJXh000000P000004o;ah00000000000018eHS@8000001JU^S`0009eUS`00
0?^kN`0200000XiIS@030000/gVC0000008000001ZM]T0000000C@00C@000:AZSP800002n;Qn0P00
0003UUn>00004`1V008C06H300000hMDSP800002XfZ@0`0000;oool010000?BWJ`0006m0R0<00000
1:9[TP000:9ZTJ9ZT@80000Hoooo00D0001`@h]`@h]`@h/000000ZaaT@800005oooo0P000003NDZ=
0000000000:WKY400`000;n2T@00000400000WE8SP8000001I=OT@000:idTP000;5fTP0500005ooo
o`<0003Ioooo0`0000_oool00`000?ooooooo`0Roooo00<0003oooooool01oooo`00Joooo`80002/
oooo00<0002oP8h000001oooo`030000oooooooo00[oool2000000?d/h<0003oool02?ooo`040000
REN?0000ZFf>0`0000?oool400000_bnO0<000000n5b5P0009UTTP0300000ZI]T0X00003]W^A0`00
0005hkdk0000YF^>0000[G>A008000000gY9R`0000000002]gZ@00<0002fXA0000000i]SS`030000
YFZ>0000008000001?blN0000000000000>=F8d020000=JKV0000:U^S`0009eUS`000?^kN`800000
2HiIS@000;=iTk=iT`0009mVS`000:M]T0000002001=00@0002TJXh000000002n;Qn0P000003UUn>
00004`1V008C06H300000hMDSP800002XfZ@0`0000;oool010000?BWJ`0006m0R0<000001:9[TP00
0:9ZTJ9ZT@80000Hoooo00D0001`@h]`@h]`@h/000000ZaaT@800005oooo0P000003NDZ=00000000
00:WKY400`000;n2T@00000400000WE8SP8000001I=OT@000:idTP000;5fTP0500005oooo`<0003I
oooo0`0000coool00`000?ooooooo`0Qoooo00<0003oooooool01oooo`00KOooo`030000oooooooo
0:Woool00`000;n0SP000007oooo00<0003oooooool02_ooo`8000000oBcP`000?ooo`08oooo00@0
0029Ehl0002YKHh200001?ooo`@00002o;il0`000003hG8F0000VFBB00<00002YVf@10000003ZKgX
0000000000<00003]W^A0`000005hkdk0000YF^>0000[G>A008000000gY9R`0000000002]gZ@00<0
002fXA0000000i]SS`030000YFZ>0000008000001?blN0000000000000>=F8d020000=JKV0000:U^
S`0009eUS`000?^kN`8000002HiIS@000;=iTk=iT`0009mVS`000:M]T0000002001=00@0002TJXh0
00000002n;Qn0P000003UUn>00004`1V008C06H300000hMDSP800002XfZ@0P0000?oool010000?BW
J`0006m0R0<000001:9[TP000:9ZTJ9ZT@80000Hoooo00D0001`@h]`@h]`@h/000000ZaaT@800005
oooo0P000003NDZ=0000000000:WKY400`000;n2T@000002000000Coool0001eB8ieB8h2000000FC
Gi40002^M980002aMY801@0001Ooool30000fOooo`<0000=oooo00<0003oooooool08?ooo`030000
oooooooo00Ooool006koool00`000?ooooooo`2Xoooo00<0002oP8h000001oooo`030000oooooooo
00[oool2000000?d/h<0003oool02?ooo`040000REN?0000ZFf>0P0000Coool400000_bnO0<00000
0n5b5P0009UTTP0300000ZI]T0D000000jVmj0000000000200000kIkT@<000001N>m>`000:E[SP00
0:ecT@02000000=jBH/0000000000[MjT0030000]Z4@000000>KHhl00`000:EZSP000002000000Cl
_7P0000000000003SER=00P0003FViP0002YKXl0002MIHl0003k^g/2000000V>FHd0002cNI>cNI<0
002OIXl0002WKI0000000P00C@040000Y6Z>000000000_RhOP8000000iIOSP0001<0IP024`1V0`00
00>7E8h200000Z=ZT0800003oooo00@0003dYf/0001_@8P3000000BRJi80002RJY6RJY4200006?oo
o`050000L4>;L4>;L4>;000000:/LI4200001Oooo`800002NDZ=00D0002WKY6WKY40002oPY400`00
0004oooo0000MDR>MDR>0P000005TenA0000[WBB0000/GJB00D0000Goooo0`000=Woool300003Ooo
o`030000oooooooo023oool00`000?ooooooo`07oooo001_oooo00<0003oooooool0Yoooo`030000
_h2>000000Ooool00`000?ooooooo`0:oooo0`0000[oool0100008UGS`000:U]SP800004oooo1000
0003o;il00000000008000000n5b5P0009UTTP0300000ZI]T0X00003]W^A0`000005hkdk0000YF^>
0000[G>A008000000gY9R`0000000002]gZ@00<0002fXA0000000i]SS`030000YFZ>000000800000
1?blN0000000000000>=F8d020000=JKV0000:U^S`0009eUS`000?^kN`8000002HiIS@000;=iTk=i
T`0009mVS`000:M]T0000002001=00@0002TJXh000000002n;Qn0P000003UUn>00004`1V008C06H3
00000XMDSP030000VF>A000000:SJY0200000oooo`040000m:M[0000Kd280`000004XV^B0000XVZA
XVZA0P0001Soool01@000713Rg13Rg13R`000002[76A0P0000Goool200000WU:S@050000YfjAYfjA
0000_h:A00<000001?ooo`00000007E8SP8000001I=OT@000:idTP000;5fTP0500006?ooo`80003J
oooo0P0000koool00`000?ooooooo`0Ooooo00<0003oooooool01oooo`00L?ooo`80002Woooo00<0
002oP8h000001oooo`030000oooooooo00[oool300002_ooo`030000REN?000000<00004oooo1000
0003o;il00000000008000000n5b5P000000000300000ZI]T0L000000jVmj00000000003]W^A0`00
0005hkdk0000YF^>0000[G>A008000000gY9R`000;MjT002]gZ@00<0002fXA0000000i]SS`800000
1<b<SP0000000?blN0<00003SER=00P0003FViP0002YKXl0002MIHl0003k^g/2000000V>FHd0002c
NI>cNI<0002OIXl0002WKI0000000P00C@040000Y6Z>000000000_RhOP8000000iIOSP0001<0IP02
4`1V0`0000:7E8h00`0009UST@000002XfZ@0P0000?oool010000?BWJ`0006m0R0<000001:9[TP00
0:9ZTJ9ZT@80000Hoooo00D0001`@h]`@h]`@h/000000ZaaT@800005oooo0P00009iBXd01@000:M^
TJM^T@000;n2T@03000000Coool00000001eB8h2000000FCGi40002^M980002aMY801@0001Soool2
0000f_ooo`80000?oooo00<0003oooooool07_ooo`030000oooooooo00Ooool007;oool00`000?oo
ooooo`2Toooo00<0002oP8h000001oooo`030000oooooooo00[oool300002_ooo`030000REN?0000
00<00004oooo10000003o;il0000000000<000000iUTTP000000000200000ZI]T0X00003]W^A0`00
0005hkdk0000YF^>0000[G>A008000000gY9R`000;MjT002]gZ@00<0002fXA0000000i]SS`800000
1<b<SP0000000?blN0<00002SER=00T0003FViSFViP0002YKXl0002MIHl0003k^g/00P000009SUV=
0000/gVC/gVC0000WfJ?0000Yff@0000008004d010000:AZSP00000000;h^7h2000000>FGhh0000C
06H00Q<0IP<00002QeB>00L0002IHi40002SJY000036Qi4000000oooo`040000m:M[0000Kd280`00
0004XV^B0000XVZAXVZA0P0001Woool010000713Rg13R`0000:/LI4200001Oooo`800002NDZ=00D0
002WKY6WKY40002oPY400`000003oooo00000000009eB8h01P0009=OT@000:idTP000;5fTPD0000H
oooo0P000=[oool200003oooo`030000oooooooo01ooool00`000?ooooooo`06oooo001coooo00<0
003oooooool0Xoooo`80000Eoooo0`0000[oool00`0008UGS`00000300001?ooo`@000000obnO000
00000003000000>II980000000000`000003YVf@0000000000P00003]W^A0`000005hkdk0000YF^>
0000[G>A008000000gY9R`000;MjT002]gZ@00<0002fXA0000000i]SS`8000001<b<SP0000000?bl
N0<00002SER=00T0003FViSFViP0002YKXl0002MIHl0003k^g/00P000009SUV=0000/gVC/gVC0000
WfJ?0000Yff@0000008004d010000:AZSP00000000;h^7h2000000>FGhh0000C06H00Q<0IP<00000
2HMDSP0009USTIUST@000:=ZT0000<J7T@000004oooo0P000003Kd280000000000<00002XVZA0P00
01Woool010000713Rg13R`0000:/LI4200001Oooo`800002NDZ=00D0002WKY6WKY40002oPY400`00
0003oooo00000000009eB8h01P0009=OT@000:idTP000;5fTPD0000Hoooo0P000=[oool200004?oo
o`030000oooooooo01koool00`000?ooooooo`06oooo001doooo00<0003oooooool0X_ooo`80000E
oooo0`0000[oool00`0008UGS`00000300001?ooo`@000000obnO00000000003000000>II9800000
00000`000003YVf@0000o/9a00T00002]W^A0`000005hkdk000000000000[G>A00@00003]gZ@00<0
002fXA0000000i]SS`8000000lb<SP000000000400000XeHS@090000eY^HeY^H0000ZFj?0000WFF?
0000nk]k008000001XiIS@000;=iTk=iT`0009mVS`800003001=00@0002TJXh000000002n;Qn0P00
0004UUn>00004`1V4`1V10000009QeB>0000VF>AVF>A0000XfZ@0000aXNA000000Coool2000000=_
@8P0000000000`0000:RJY400`000?ooooooo`0Hoooo00@0001`@h]`@h/00002[76A0P0000Goool2
00000WU:S@050000YfjAYfjA0000_h:A00<000000oooo`0000000002MDR>0`000003[WBB0000/GJB
00D0000Hoooo0P000=[oool200004Oooo`030000oooooooo01goool00`000?ooooooo`06oooo001e
oooo0P000:;oool200005Oooo`<0000:oooo00<00029Ehl000000`0000Coool4000000?l_W`00000
00000`000003VFBB0000000000<000000jI]T0000?k2L@04000000>Y_NP0000000000P0000:fNi43
000000?S_C/0000000000ZecT@@00003]gZ@00<0002fXA0000000i]SS`8000000lb<SP0000000004
00000XeHS@090000eY^HeY^H0000ZFj?0000WFF?0000nk]k00<00003/gVC00@0002OIXl000000003
001=00@0002TJXh000000002n;Qn0P000005UUn>000000000000oooo00<000002HMDSP0009USTIUS
T@000:=ZT0000<J7T@000004oooo0P000003Kd280000000000<00002XVZA00<0003oooooool06?oo
o`040000L4>;L4>;00000ZaaT@800005oooo0P00009iBXd01@000:M^TJM^T@000;n2T@03000000?o
ool0000000000WE8SP<000000jidTP000;5fTP0500006?ooo`80003Joooo0P0001;oool00`000?oo
ooooo`0Loooo00<0003oooooool01_ooo`00Moooo`030000oooooooo09ooool200005Oooo`<0000:
oooo00<00029Ehl000000`0000Coool4000000?l_W`0000000000`000003VFBB0000000000<00000
0jI]T0000000000900000[IkT@<000000n>m>`0000000002[G>A0P000005VFFC0000]gZ@]gZ@0000
00:fXA00100009]SSi]SSi]SS`8000000lb<SP000000000400000XeHS@080000eY^HeY^H0000ZFj?
0000WFF?00000_^kN`800003/gVC00@0002OIXl000000003001=00@0002TJXh000000002n;Qn0P00
0003UUn>0000oooo00;oool3000000V7E8h0002IHi6IHi40002SJY000036Qi4000001?ooo`800000
0fm0R0000000000300000Z9ZT@030000oooooooo01Soool010000713Rg13R`0000:/LI4200001_oo
o`040000NDZ=NDZ=00000ZM^T@030000_h:A0000008000000oooo`0000000002MDR>0`000003[WBB
0000/GJB00D0000Hoooo0P000=_oool00`000?ooooooo`0@oooo00<0003oooooool07?ooo`030000
oooooooo00Koool007Soool00`000?ooooooo`2Noooo0P0001Goool300002_ooo`030000REN?0000
00800005oooo10000003o;il0000000000<000000iUTTP0000000003000000BVKI000000002Y_NP5
000000>Y_NP0000000000[IkT@<000000n>m>`0000000002[G>A0P000005VFFC0000]gZ@]gZ@0000
00:fXA00100009]SSi]SSi]SS`8000000lb<SP0000000004000000>=F8d0003FViP00]JKV0050000
ZFj?0000WFF?000000;k^g/200000k=iT`040000WfJ?000000000`00C@040000Y6Z>000000000_Rh
OP8000000iIOSP000?ooo`03oooo0`0000>IHi401@000:=ZT0000<J7T@000004oooo0P000003Kd28
0000000000<00002XVZA00<0003oooooool06?ooo`040000L4>;L4>;00000ZaaT@800006oooo00@0
001iBXeiBXd00002YfjA00@0002oPY4000000002oooo0P00009eB8h200000ZidTP030000/GJB0000
00@0000Hoooo0P000=_oool00`000?ooooooo`0Aoooo00<0003oooooool06oooo`030000oooooooo
00Koool007Woool00`000?ooooooo`2Moooo0P0001Goool300002_ooo`030000REN?000000800005
oooo0P000003iZB:0000000000/000000jI]T0000000000900000[IkT@<000000n>m>`0000000002
[G>A0P000005VFFC0000]gZ@]gZ@000000:fXA00100009]SSi]SSi]SS`8000000lb<SP0000000004
000000>=F8d0003FViP00]JKV0050000ZFj?0000WFF?000000;k^g/200000k=iT`040000WfJ?0000
00000`00C@040000Y6Z>000000000_RhOP8000000iIOSP000?ooo`03oooo0`0000>IHi401@000:=Z
T0000<J7T@000004oooo0P000003Kd280000000000<00002XVZA00<0003oooooool06?ooo`040000
L4>;L4>;00000ZaaT@800006oooo00@0001iBXeiBXd00002YfjA00@0002oPY4000000002oooo0P00
009eB8h200000ZidTP030000/GJB000000@0000Hoooo0P000=_oool200004oooo`030000oooooooo
01[oool00`000?ooooooo`06oooo001joooo0P0009goool200005Oooo`<0000:oooo00<00029Ehl0
00000P0000Goool3000000?l_W`0000000000P000005oooo000000000000oooo00<000000jI]T000
0000000900000[IkT@<000002N>m>`0000000:ecT@000?ooo`0009UUT`000002]gZ@00@0002fXA2f
XA000003Vf>?0P000003c8b>0000000000@000000heHS@000=JKV002eY^H00D0002YKXl0002MIHl0
00000_^kN`800003/gVC00@0002OIXl000000003001=00@0002TJXh000000002n;Qn0P000003UUn>
0000oooo00?oool300000iUST@050000XfZ@0000aXNA000000Coool2000000=_@8P0000000000`00
00:RJY400`000?ooooooo`0Hoooo00@0001`@h]`@h/00002[76A0P0000Koool0100007U:SGU:S@00
00:WKY4010000;n2T@00000000;oool200000WE8SP800002[WBB00<0002aMY800000100001Soool2
0000foooo`80000Coooo00<0003oooooool06_ooo`030000oooooooo00Koool007coool00`000?oo
ooooo`2Ioooo0`0001Goool00`000?BcP`00000:oooo00<00029Ehl000000P0000Goool3000000Cl
_W`0000000000002oooo0`000005oooo000000000000YVf@00/00002]W^A0`000009hkdk00000000
[G>A0000oooo0000VFFC000000:gNY0010000;JQ4;JQ400000>KHhl2000000?<S8h0000000000P00
0004lZ]h0000SER=00000mJKV0050000ZFj?0000WFF?000000;k^g/200000k=iT`040000WfJ?0000
00000`00C@040000Y6Z>000000000_RhOP8000000iIOSP000?ooo`03oooo0`0000>IHi401@000:=Z
T0000<J7T@000004oooo200000:RJY400`000?ooooooo`0Hoooo00@0001`@h]`@h/00002[76A0P00
00Koool0100007U:SGU:S@0000:WKY4010000;n2T@00000000?oool00`0007E8SWE8SP0200000Zid
TP030000/GJB000000@0000Hoooo0P000=_oool200005?ooo`030000oooooooo01[oool00`000?oo
ooooo`05oooo001moooo00<0003oooooool0V?ooo`<0000Eoooo0P0000_oool00`0008UGS`000002
00001Oooo`<000001?bnO0000?ooo`0000;oool3000000?oool0000000002@000004ZKgX00000000
00000[IkT@<000002N>m>`0000000:ecT@000?ooo`0009UUT`000002]gZ@00@0002fXA2fXA000003
Vf>?0P000003c8b>00000000008000001?:[N00008eHS@0000?FViP01@000:U^S`0009eUS`000002
nk]k0P0000>cNI<0100009mVS`00000000<004d010000:AZSP00000000;h^7h2000000>FGhh0003o
ool00oooo`800004VF>A00D0002SJY000036Qi4000001?ooo`P00002XVZA00<0003oooooool06?oo
o`040000L4>;L4>;00000ZaaT@800006oooo00@0001iBXeiBXd00002YfjA00@0002oPY4000000003
oooo00<0001eB8ieB8h00P0000:^M9800`000;5fTP00000400006?ooo`80003Koooo0P0001Goool0
0`000?ooooooo`0Ioooo00<0003oooooool01Oooo`00O_ooo`030000oooooooo09Ooool300005Ooo
o`80000;oooo00<00029Ehl000000P0000Goool3000000Cl_W`0003oool00002oooo0`000003oooo
0000000000d00002]W^A0`000009hkdk00000000[G>A0000oooo0000VFFC000000:gNY0010000;JQ
4;JQ400000>KHhl3000000FXKY0000000000003bZgP00P0000CFViP01@000:U^S`0009eUS`000002
nk]k0P0000>cNI<00`0009mVS`00000200000P00C@040000Y6Z>000000000_RhOP8000000iIOSP00
0?ooo`03oooo0P0000BIHi401@000:=ZT0000<J7T@000004oooo200000:RJY400`000?ooooooo`0I
oooo00<0001`@h/000000ZaaT@800006oooo00@0001iBXeiBXd00002YfjA00@0002oPY4000000003
oooo00D0001eB8ieB8ieB8h000000ZidTP030000/GJB000000@0000Hoooo0P000=coool00`000?oo
ooooo`0Doooo00<0003oooooool06?ooo`030000oooooooo00Goool007ooool20000Uoooo`<0000E
oooo0P0000_oool00`0008UGS`00000200001Oooo`<000000obnO0000?ooo`03oooo0P0000;oool<
00000_ooo`030000]W^A]W^A00<000002N>m>`0000000:ecT@000?ooo`0009UUT`000002]gZ@00@0
002fXA2fXA000003Vf>?0`000005Z6j@000000000000lZ]h00800004eY^H00D0002YKXl0002MIHl0
00000_^kN`030000/gVC/gVC00:cNI<00`0009mVS`00000200000P00C@040000Y6Z>000000000_Rh
OP<00005oooo0P0000BIHi401@000:=ZT0000<J7T@000004oooo10000004cXf=0000000000000Z9Z
T@030000oooooooo01Woool00`000713R`000002[76A0P0000Koool0100007U:SGU:S@0000:WKY40
10000;n2T@00000000?oool01@0007E8SWE8SWE8SP000002[WBB00<0002aMY800000100001Soool2
0000g?ooo`030000oooooooo01Coool00`000?ooooooo`0Hoooo00<0003oooooool01Oooo`00POoo
o`030000oooooooo09Coool200005_ooo`80000;oooo00<00029Ehl000000P0000Goool3000000?l
_W`0003oool00oooo`800002oooo200000Koool00`000;IkTKIkT@0200000^>m>`8000001ZecT@00
0?ooo`0009UUT`0000:gNY0010000;JQ4;JQ400000>KHhl3000000FXKY0000000000003bZgP00P00
00CFViP01@000:U^S`0009eUS`000002nk]k00<0002cNI>cNI<00[=iT`050000WfJ?0000oooo0000
008004d010000:AZSP00000000;h^7h300001Oooo`800004VF>A00D0002SJY000036Qi4000001?oo
o`@000001<j=S@000000000000:RJY400`000?ooooooo`0Ioooo00<0001`@h/000000ZaaT@800006
oooo00@0001iBXeiBXd00002YfjA00<0002oPY4000001?ooo`050000MDR>MDR>MDR>000000:^M980
0`000;5fTP00000400006Oooo`030000oooooooo0=[oool00`000?ooooooo`0Eoooo00<0003ooooo
ool05oooo`030000oooooooo00Goool008;oool00`000?ooooooo`2Coooo0P0001Koool200002ooo
o`040000REN?000000001_ooo`<000000obnO0000?ooo`03oooo0P0000;oool600002?ooo`030000
]W^A]W^A00800002hkdk0P000006[G>A0000oooo0000VFFC00000[MjT0040000]Z4@]Z4@00000i]S
S`<000001:Q^T00000000?ooo`<00004eY^H00@0002YKXl000000003nk]k00<0002cNI>cNI<00[=i
T`050000WfJ?0000oooo0000008004d010000:AZSP00000000;h^7h300001Oooo`800004VF>A00D0
002SJY000036Qi4000001?ooo`@000000lj=S@0000000002XVZA0P0001_oool00`000713R`000002
[76A0P0000Koool0100007U:SGU:S@0000:WKY400`000;n2T@000004oooo00D0001eB8ieB8ieB8h0
00000ZidTP030000/GJB000000@0000Ioooo00<0003oooooool0loooo`030000oooooooo01Koool0
0`000?ooooooo`05oooo0023oooo00<0003oooooool0T_ooo`80000Foooo0P0000_oool0100008UG
S`00000000Koool400001Oooo`800002oooo1P0000Soool00`000;IkTKIkT@0200000^>m>`800000
1ZecT@000?ooo`0009UUT`0000:gNY000`000;JQ4;JQ400200000Y]SS`<000001:Q^T00000000?oo
o`<00004eY^H00@0002YKXl000000003nk]k00<0002cNI>cNI<00[=iT`050000WfJ?0000oooo0000
008004d01`000:AZSP0000000?RhOP000?ooo`0200001_ooo`030000VF>AVF>A00:IHi401@000:=Z
T0000<J7T@000004oooo10000003cXf=0000000000:RJY4200006oooo`050000L4>;L4>;0000[76A
00800006oooo00@0001iBXeiBXd00002YfjA00<0002oPY4000001?ooo`050000MDR>MDR>MDR>0000
00:^M9800`000;5fTP00000400006Oooo`030000oooooooo0?Coool00`000?ooooooo`0Eoooo00<0
003oooooool01Oooo`00Q?ooo`030000oooooooo097oool200008oooo`040000REN?000000001_oo
o`@00005oooo00@0003oooooooooool600002?ooo`030000]W^A]W^A00800002hkdk0P000006[G>A
0000oooo0000VFFC00000[MjT0030000]Z4@]Z4@00800002Vf>?10000003o;ah0000oooo00800005
eY^H0P000003WFF?0000nk]k00;k^g/00`000;=iTk=iT`02/gVC00D0002OIXl0003oool000000P00
C@8000001JE]T@000?RhOP000?ooo`0200001_ooo`030000VF>AVF>A00:IHi401@000:=ZT0000<J7
T@000004oooo10000003cXf=0000000000:RJY4200006oooo`050000L4>;L4>;0000[76A00800007
oooo00<0001iBXd000000ZM^T@030000_h:A000000Coool01@0007E8SWE8SWE8SP000002[WBB00<0
002aMY800000100001Woool00`000?ooooooo`3doooo00<0003oooooool05_ooo`030000oooooooo
00Coool008Goool20000TOooo`80000Soooo100000Koool400001Oooo`040000oooooooooooo1P00
00Soool00`000;IkTKIkT@0200000^>m>`8000002:ecT@000?ooo`0009UUT`000;MjT00000>fXA02
00000Y]SS`@000000oblN0000?ooo`0200001MJKV080000019eUS`000?^kNo^kN`800004/gVC00D0
002OIXl0003oool000000P00C@8000001JE]T@000?RhOP000?ooo`0200001_ooo`030000VF>AVF>A
00:IHi401@000:=ZT0000<J7T@000004oooo10000003cXf=0000000000:RJY4200006oooo`050000
L4>;L4>;0000[76A00800007oooo00<0001iBXd000000ZM^T@030000_h:A000000Coool01@0007E8
SWE8SWE8SP000002[WBB00<0002aMY800000100001Woool00`000?ooooooo`3eoooo00<0003ooooo
ool05Oooo`030000oooooooo00Coool008Ooool00`000?ooooooo`2>oooo0P0002?oool400001_oo
o`@00005oooo00@0003oooooooooool600002?ooo`8000000kIkT@0000000002hkdk0P000008[G>A
0000oooo0000VFFC0000]gZ@00000kJQ40800002Vf>?00L0003<S8h00000003l_7P0003oool00P00
00GFViP2000000BMIHl0003k^g_k^g/200001;=iT`050000WfJ?0000oooo0000008004d2000000FU
KI40003h^7h0003oool00P0000Koool00`0009USTIUST@02VF>A00D0002SJY000036Qi4000001?oo
o`@000000lj=S@0000000002XVZA0P0001_oool01@000713Rg13R`000:aaT@0200001oooo`030000
NDZ=000000:WKY400`000;n2T@000005oooo00@0001eB8ieB8h00002[WBB00<0002aMY8000001000
01Woool00`000?ooooooo`3foooo00<0003oooooool05?ooo`030000oooooooo00Coool008Soool0
0`000?ooooooo`2=oooo0P0002?oool400001_ooo`@00009oooo0P000004bHZ?0000000000002?oo
o`8000000kIkT@0000000002hkdk0P000008[G>A0000oooo0000VFFC0000]gZ@00000kJQ40<00000
0i]SS`000<b<SP02000000?l_7P0003oool00P0000GFViP2000000BMIHl0003k^g_k^g/200001;=i
T`050000WfJ?0000oooo0000008004d2000000FUKI40003h^7h0003oool00P0000Koool00`0009US
TIUST@02VF>A00D0002SJY000036Qi4000001?ooo`@000000lj=S@0000000002XVZA0P0001_oool0
1@000713Rg13R`000:aaT@0200001oooo`030000NDZ=000000:WKY400`000;n2T@000005oooo00@0
001eB8ieB8h00002[WBB00<0002aMY800000100001Woool00`000?ooooooo`3foooo00<0003ooooo
ool05?ooo`030000oooooooo00Coool008Woool00`000?ooooooo`2<oooo0P0002?oool400001_oo
o`8000000obnO0000?ooo`08oooo0P000004bHZ?0000000000002?ooo`8000000kIkT@0000000002
hkdk0P000008[G>A0000oooo0000VFFC0000]gZ@00000kJQ40<000000i]SS`000<b<SP02000000?l
_7P0003oool00P0000GFViP2000000BMIHl0003k^g_k^g/200001;=iT`800002oooo00<0000004d0
04d00P000005YFfA0000n;Qn0000oooo00800006oooo00<0002IHi6IHi400YUST@050000XfZ@0000
aXNA000000Coool4000000?>SHd0000000000Z9ZT@80000Koooo00D0001`@h]`@h/0002/LI400P00
00Ooool0200007U:SGU:S@000:M^T@000;n2T@0000Goool0100007E8SWE8SP0000:^M9800`000;5f
TP00000400006Oooo`030000oooooooo0?Ooool00`000?ooooooo`0Coooo00<0003oooooool01?oo
o`00R_ooo`80002<oooo0P0002?oool400001_ooo`8000000obnO0000?ooo`08oooo0P000004bHZ?
0000000000002?ooo`8000000kIkT@0000000002hkdk0P000008[G>A0000oooo0000VFFC0000]gZ@
00000kJQ40<000000i]SS`000<b<SP0300000_ooo`<00004eY^H0P000004WFF?0000nk]knk]k0P00
00BcNI<200000_ooo`030000001=001=00<00002n;Qn00@0003oool000000006oooo00<0002IHi6I
Hi400YUST@030000XfZ@000000800004oooo10000003cXf=0000000000:RJY4200006oooo`050000
L4>;L4>;0000[76A00800007oooo00P0001iBXeiBXd0002WKY40002oPY400005oooo00@0001eB8ie
B8h00002[WBB00<0002aMY80000010000?oooolEoooo00<0003oooooool04_ooo`030000oooooooo
00Coool008coool00`000?ooooooo`29oooo0P0002?oool400001_ooo`<0000:oooo00<00039RXo9
RXl00`0000Soool500000^>m>`8000002:ecT@000?ooo`0009UUT`000;MjT00000>fXA05000000C<
S8h0000000000002oooo0`0000CFViP2000000BMIHl0003k^g_k^g/200001;=iT`800002oooo00<0
000004d004d00`0000;h^7h010000?ooo`00000000Koool00`0009USTIUST@02VF>A00@0002SJY00
00000005oooo10000003cXf=0000000000:RJY4200007?ooo`040000L4>;0000[76A0P0000Ooool0
200007U:SGU:S@000:M^T@000;n2T@0000Goool0100007E8SWE8SP0000:^M9800`000;5fTP000004
0000oooooaKoool00`000?ooooooo`0Aoooo00<0003oooooool01?ooo`00SOooo`030000oooooooo
08Soool200008oooo`@00006oooo0`0000[oool00`000<V:SlV:S`0300002?ooo`D00002hkdk0`00
00;oool01@0009UUT`000;MjT0000003]Z4@1@000004c8b>0000000000000_ooo`<00004eY^H0P00
0004WFF?0000nk]knk]k0P0000BcNI<200000_ooo`030000001=001=00<00002n;Qn00@0003oool0
00000006oooo00<0002IHi6IHi400YUST@040000XfZ@000000001Oooo`8000000iMRT@000<j=S@02
00000Z9ZT@80000Loooo00@0001`@h/0002/LI4200001oooo`080000NDZ=NDZ=0000YfjA0000_h:A
00001Oooo`040000MDR>MDR>00000ZidTP030000/GJB000000@0003ooooo5_ooo`030000oooooooo
017oool00`000?ooooooo`04oooo002>oooo00<0003oooooool0Qoooo`80000Soooo100000Koool3
00002_ooo`030000bHZ?bHZ?00<00008oooo1@0000;S_C/300000_ooo`050000VFFC0000]gZ@0000
00>fXA05000000C<S8h0000000000002oooo0`0000CFViP2000000BMIHl0003k^g_k^g/200001;=i
T`800002oooo00<0000004d004d00`0000;h^7h010000?ooo`00000000Koool00`0009USTIUST@02
VF>A00@0002SJY0000000005oooo10000003cXf=0000000000:RJY4200007?ooo`040000L4>;0000
[76A0P0000Ooool0200007U:SGU:S@000:M^T@000;n2T@0000Goool0100007E8SWE8SP0000:^M980
0`000;5fTP0000040000oooooaOoool00`000?ooooooo`0Aoooo00<0003oooooool00oooo`00Sooo
o`800027oooo00<0003oooooool08_ooo`@00006oooo0`0000[oool00`000<V:S`00000300002?oo
o`H000001>>m>`000000000000;oool01@0009UUT`000;MjT0000003]Z4@1@000004c8b>00000000
00000_ooo`<00004eY^H0P000004WFF?0000nk]knk]k0P0000BcNI<200000oooo`030000001=0000
00800002n;Qn00@0003oool000000006oooo00<0002IHi6IHi400YUST@040000XfZ@000000001Ooo
o`@000000lj=S@0000000002XVZA0P0001coool01P000713R`0000000<B5T00000Ooool0200007U:
SGU:S@000:M^T@000;n2T@0000Goool0100007E8SWE8SP0000:^M9800`000;5fTP0000040000oooo
oaSoool00`000?ooooooo`0@oooo00<0003oooooool00oooo`00TOooo`030000oooooooo08Coool0
0`000?ooooooo`0Roooo100000Koool300002_ooo`030000bHZ?000000<00008oooo1@000003bhjB
0000000000800002oooo00D0002III<0002gNY0000000kJQ40D000001<b<SP000000000000;oool3
00001=JKV080000019eUS`000?^kNo^kN`800004/gVC0P0000?oool00`000000C@00000200000_Rh
OP040000oooo000000001_ooo`030000VF>AVF>A00:IHi4010000:=ZT000000000Goool4000000?>
SHd0000000000Z9ZT@80000Loooo00H0001`@h/000000034QI000007oooo00D0001iBXeiBXd0002W
KY400P0000Ooool00`0007E8SP000002[WBB00<0002aMY80000010000?oooolIoooo00<0003ooooo
ool03oooo`030000oooooooo00?oool009;oool00`000?ooooooo`23oooo00<0003oooooool08_oo
o`@00006oooo0`0000[oool00`000<V:S`00000300002?ooo`D000000l^>TP000000000200000_oo
o`050000VFFC0000]gZ@000000>fXA05000000C<S8h0000000000002oooo0`0000CFViP2000000>M
IHl0003k^g/00`0000BcNI<200000oooo`030000001=000000800002n;Qn00@0003oool000000006
oooo00<0002IHi6IHi400YUST@040000XfZ@000000001Oooo`@000000lj=S@0000000002XVZA0P00
01coool01P000713R`0000000<B5T00000Ooool01@0007U:SGU:S@000:M^T@0200001oooo`030000
MDR>000000:^M9800`000;5fTP0000040000oooooaWoool00`000?ooooooo`0?oooo00<0003ooooo
ool00oooo`00Toooo`030000oooooooo08;oool00`000?ooooooo`0Roooo0`0000Ooool300002_oo
o`030000bHZ?000000800009oooo1@000003bhjB0000000000800002oooo00D0002III<0002gNY00
00000kJQ40030000bHbB0000008000001<b<SP000000000000;oool300001=JKV08000000ieUS`00
0?^kN`0300001;=iT`800003oooo00<0000004d000000P0000;h^7h010000?ooo`00000000Koool0
0`0009USTIUST@02VF>A00@0002SJY0000000005oooo10000003cXf=0000000000:RJY4200007?oo
o`060000L4>;00000000a8F@00002?ooo`040000NDZ=0000YfjA0P0000Ooool01`0007E8SWE8SP00
0:idTP000;5fTP050000oooooa[oool00`000?ooooooo`0>oooo00<0003oooooool00oooo`00U?oo
o`800022oooo00<0003oooooool08_ooo`<00007oooo0`0000[oool00`000<V:S`00000200002Ooo
o`D000000l^>TP00070nQ00200000_ooo`040000VFFC000000001;JQ40D000001<b<SP0000000000
00;oool300001=JKV08000000ieUS`000?^kN`0300001;=iT`800003oooo00<0000004d000000P00
00;h^7h010000?ooo`00000000Koool00`0009USTIUST@02VF>A0P000003aXNA0000oooo00Goool3
000000?>SHd0000000000Z9ZT@80000Loooo00H0001`@h/000000034QI000008oooo00@0001iBXd0
002WKY4200001oooo`070000MDR>MDR>0000[WBB0000/GJB00D0003ooooo6oooo`030000oooooooo
00goool00`000?ooooooo`03oooo002Foooo00<0003oooooool0Ooooo`030000oooooooo02;oool3
00001oooo`80000;oooo00<00039RXl000000P0000Woool600000W0nQ0800002oooo00@0002III<0
00000004]Z4@1@000004c8b>0000000000000_ooo`@00002eY^H00H0002YKXl0002MIHl0003k^g/3
00000k=iT`030000WfJ?000000?oool00`000000C@00000200000_RhOP030000oooo000000Ooool0
0`0009USTIUST@02VF>A0P000003aXNA0000oooo00Goool3000000?>SHd0000000000Z9ZT@80000L
oooo00H0001`@h/000000034QI000008oooo00@0001iBXd0002WKY4200001oooo`070000MDR>MDR>
0000[WBB0000/GJB00D0003ooooo6oooo`030000oooooooo00goool00`000?ooooooo`03oooo002G
oooo00<0003oooooool0Xoooo`<00007oooo0P0000_oool00`000<V:S`00000200002Oooo`@00000
1<^>TP00070nQ70nQ0800003oooo0`0000BfXA06000000>XKY00000000000_ooo`040000lZ]h0000
00000]JKV0060000ZFj?0000WFF?0000nk]k0`0000>cNI<00`0009mVS`000003oooo00<0000004d0
00000P0000;h^7h00`000?ooo`000007oooo00<0002IHi6IHi400YUST@8000000lJ7T@000?ooo`05
oooo0`000003cXf=0000000000:RJY4200007?ooo`060000L4>;00000000a8F@00002?ooo`040000
NDZ=0000YfjA0P0000Ooool01`0007E8SWE8SP000:idTP000;5fTP050000oooooacoool00`000?oo
ooooo`0=oooo00<0003oooooool00_ooo`00V?ooo`030000oooooooo0:;oool300001oooo`80000;
oooo00<00039RXl000000P0000Woool4000000C;SY80001`?XA`?X@200000oooo`@00003]Z4@1P00
0003Z6j@0000000000;oool010000?:[N000000000;FViP01P000:U^S`0009eUS`000?^kN`<00003
/gVC00<0002OIXl000000oooo`030000001=000000800002n;Qn00<0003oool000001oooo`030000
VF>AVF>A00:IHi42000000?6Qi40003oool01Oooo`<000000lj=S@0000000002XVZA0P0001coool0
1P000713R`0000000<B5T00000Soool0100007U:S@000:M^T@800007oooo00L0001eB8ieB8h0002^
M980002aMY801@000?oooolMoooo00<0003oooooool03?ooo`030000oooooooo00;oool009Woool2
0000X_ooo`<00007oooo0P0000_oool00`000<V:S`00000200002Oooo`@000001<^>TP00070nQ70n
Q0800003oooo0`000004YVf@0000]Z4@]Z4@0P000005oooo000000000000Z6j@00800002oooo00@0
003bZgP000000002eY^H00H0002YKXl0002MIHl0003k^g/300000k=iT`030000WfJ?000000?oool0
0`000000C@000002000000Gh^7h0003oooooool000001oooo`030000VF>AVF>A00:IHi42000000?6
Qi40003oool01Oooo`<000000lj=S@0000000002XVZA0P0001goool3000000?4QI00003oool01ooo
o`040000NDZ=0000YfjA0P0000Ooool01`0007E8SWE8SP000:idTP000;5fTP050000oooooakoool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`00Voooo`030000oooooooo09ooool300001ooo
o`80000;oooo00<00039RXl000000P0000Soool5000000C;SY80001`?XA`?X@200000oooo`<00000
1:I]T00000000;JQ408000001Oooo`00000000000:Q^T00200000_ooo`040000lZ]h000000000]JK
V0040000ZFj?000000000_^kN`<00003/gVC00<0002OIXl000000oooo`030000001=000000800000
1ORhOP000?ooooooo`000007oooo00<0002IHi6IHi400YUST@8000000lJ7T@000?ooo`05oooo0`00
0003cXf=0000000000:RJY4200007Oooo`<000000lB5T0000?ooo`07oooo00@0001iBXd0002WKY42
00001oooo`8000001GE8SP000:idTP000;5fTP050000oooooakoool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`00W?ooo`030000oooooooo09koool300001oooo`80000;oooo00<00039RXl0
00000P0000Soool5000000C;SY800000001`?X@200000oooo`<000001:I]T00000000;JQ40800000
1Oooo`00000000000:Q^T00200000_ooo`040000lZ]h000000000]JKV0040000ZFj?000000000_^k
N`<00003/gVC00<0002OIXl000000oooo`030000001=0000008000001ORhOP000?ooooooo`000007
oooo00<0002IHi6IHi400YUST@8000000lJ7T@000?ooo`05oooo0`000003cXf=0000000000:RJY42
00007Oooo`<000000lB5T0000?ooo`07oooo00@0001iBXd0002WKY4200002?ooo`040000MDR>0000
00000[5fTPD0003ooooo7oooo`030000oooooooo00[oool00`000?ooooooo`02oooo002Moooo00<0
003oooooool0WOooo`<00007oooo00<0003oooooool02_ooo`030000bHZ?000000800008oooo1@00
0006bhjB000000000000[G>A00000oooo`<000000jI]T0000<>5T@03000000Goool000000000002X
KY000P0000;oool010000?:[N000000000;FViP01@000:U^S`0000000?^kN`02000000?H/BP0002c
NI<00[=iT`030000WfJ?000000?oool00`000000C@000002000000Gh^7h0003oooooool000001ooo
o`800003VF>A0P000003aXNA0000oooo00Goool3000000?>SHd0000000000Z9ZT@80000Moooo0`00
0003a8F@0000oooo00Ooool01P0007U:S@0000000;n2T@0000Soool0100007E8SP00000000:aMY85
0000ooooob3oool00`000?ooooooo`09oooo00<0003oooooool00_ooo`00W_ooo`030000oooooooo
09coool300001oooo`030000oooooooo00[oool00`000<V:S`00000200002?ooo`D000001/^>TP00
000000000:ecT@0000?oool3000000>VKI000033QI400`000003oooo00000000008000001_blN000
0?ooooooo`000?:[N0800002eY^H00D0002YKXl00000003k^g/00P000003f;4X0000/gVC00:cNI<0
0`0009mVS`000003oooo00<0000004d000000P000005n;Qn0000oooooooo000000Ooool200000iUS
T@8000000lJ7T@000?ooo`05oooo0`000003cXf=0000000000:RJY400`000?ooooooo`0Loooo0`00
0003a8F@0000oooo00Ooool01P0007U:S@0000000;n2T@0000Soool0100007E8SP00000000:aMY85
0000ooooob7oool00`000?ooooooo`08oooo00<0003oooooool00_ooo`00Woooo`80002Loooo0`00
00Ooool00`000?ooooooo`0:oooo00<00039RXl000000P0000Soool9000000>]Li40003oool00_oo
o`<000000jI]T0000<>5T@03000000?oool0000000000`0000?oool010000?:[N000000000;FViP0
1@000:U^S`0000000?^kN`02000000?H/BP0002cNI<00[=iT`030000WfJ?000000?oool00`000000
C@000002000000Gh^7h0003oooooool000001oooo`800003VF>A0P000003aXNA0000oooo00Goool3
000000?>SHd0000000000Z9ZT@030000oooooooo01coool3000000?4QI00003oool01oooo`060000
NDZ=00000000_h:A00002?ooo`040000MDR>000000000[5fTPD0003ooooo8Oooo`030000oooooooo
00Soool00`000?ooooooo`02oooo002Qoooo00<0003oooooool0VOooo`<0000Doooo00D00039RXl0
003oool000002?ooo`X00004oooo0`000003YVf@0000`hFA00<000000oooo`000000000300000ooo
o`040000lZ]h000000000]JKV0@000001O^kN`0000000=Ra:0000003/gVC00<0002OIXl000000ooo
o`030000001=0000008000000oRhOP000?ooo`09oooo0P0000>IHi42000000?6Qi40003oool01Ooo
o`<000000lj=S@0000000002XVZA00<0003oooooool07?ooo`<000000lB5T0000?ooo`08oooo0`00
0003_h:A0000oooo00Ooool0100007E8SP00000000:aMY850000ooooob;oool00`000?ooooooo`08
oooo00<0003oooooool00Oooo`00X_ooo`030000oooooooo09Soool300005?ooo`050000bHZ?0000
oooo000000Soool:00001?ooo`<000001jI]T000000000000<V<TP000?ooo`0500000oooo`040000
lZ]h000000000]JKV0@000001O^kN`0000000=Ra:0000003/gVC00<0002OIXl000000oooo`D00000
0oRhOP000?ooo`09oooo0P0000>IHi42000000?6Qi40003oool01Oooo`@000001JadU0000:9ZTJ9Z
T@00000Noooo0`000003a8F@0000oooo00Soool3000000>oPY40003oool01oooo`040000MDR>0000
00000[5fTPD0003ooooo8oooo`030000oooooooo00Ooool00`000?ooooooo`01oooo002Soooo00<0
003oooooool0Uoooo`<0000Doooo0`000003oooo0000oooo00Ooool300000/^>TPD00004oooo1000
0006`hFA00000000bHbB0000oooo1@0000?oool010000?:[N000000000;FViP4000000Gk^g/00000
003H/BP000000k=iT`030000WfJ?000000?oool5000000?h^7h0003oool02Oooo`800003VF>A0P00
0003aXNA0000oooo00Goool4000000F/M9@0002RJY6RJY4000007_ooo`<000000lB5T0000?ooo`08
oooo0`000003_h:A0000oooo00Ooool0100007E8SP00000000:aMY850000ooooob?oool00`000?oo
ooooo`07oooo00<0003oooooool00Oooo`00Y?ooo`80002Goooo0P0001Goool3000000?oool0003o
ool01oooo`<00002bhjB00<0003oool000000P0000Coool4000000K3QI4000000039S980003oool5
00000oooo`060000lZ]h0000Y6fB0000eY^H10000005nk]k00000000f;4X000000>cNI<00`0009mV
S`000003oooo1@000003n;Qn0000oooo00Woool200000iUST@8000000lJ7T@000?ooo`05oooo1000
0005[7BD0000XVZAXVZA000001koool3000000?4QI00003oool02?ooo`<000000kn2T@000?ooo`07
oooo100000:aMY850000ooooobCoool00`000?ooooooo`06oooo00<0003oooooool00Oooo`00Y_oo
o`030000oooooooo09Coool200005Oooo`<000000oooo`000?ooo`07oooo0`0000;;SY800`000?oo
o`00000200001?ooo`@000001/>5T@0000000<V<TP000?ooo`D00003oooo00H0003bZgP0002TKI80
003FViP4000000Ck^g/00000003H/BP200000[=iT`030000WfJ?000000?oool5000000?h^7h0003o
ool02Oooo`800003VF>A0P000003aXNA0000oooo00Goool4000000F/M9@0002RJY6RJY4000007_oo
o`<000000lB5T0000?ooo`08oooo0`000003_h:A0000oooo00Ooool400000[5fTPD0003ooooo9Ooo
o`030000oooooooo00Goool00`000?ooooooo`01oooo002Woooo00<0003oooooool0Toooo`80000E
oooo0`000003oooo0000oooo00Ooool300000/^>TP030000oooo000000800004oooo10000006`hFA
00000000bHbB0000oooo1@0000?oool01P000?:[N0000:A]TP000=JKV0@000001?^kN`0000000=Ra
:0800002/gVC00<0002OIXl000000oooo`D000000oRhOP000?ooo`09oooo0P0000>IHi42000000?6
Qi40003oool01Oooo`@000001JadU0000:9ZTJ9ZT@00000Noooo0`000003a8F@0000oooo00Soool3
000000>oPY40003oool01oooo`@00002/GJB1@000?oooolVoooo00<0003oooooool01?ooo`030000
oooooooo007oool00:Soool00`000?ooooooo`2Boooo0P0001Goool3000000?oool0003oool01ooo
o`<00002bhjB00<0003oool000000P0000Goool3000000K3QI4000000039S980003oool500000ooo
o`060000lZ]h0000Y6fB0000eY^H10000004nk]k00000000f;4X0P0000:cNI<200001?ooo`D00000
0oRhOP000?ooo`09oooo0P0000>IHi42000000?6Qi40003oool01Oooo`@000001JadU0000:9ZTJ9Z
T@00000Noooo0`000003a8F@0000oooo00Soool3000000>oPY40003oool01oooo`@00002/GJB1@00
0?oooolVoooo00<0003oooooool01?ooo`030000oooooooo007oool00:Woool20000T_ooo`80000E
oooo0`000003oooo0000oooo00Ooool3000000C;SY800000003oool300001Oooo`<000001/>5T@00
00000<V<TP000?ooo`D00003oooo00H0003bZgP0002TKI80003FViP5000000>nPI80003H/BP00P00
00:cNI<200001?ooo`<000001:E]T@000?RhOP0000_oool0100009USTIUSTIUST@8000000lJ7T@00
0?ooo`05oooo10000005[7BD0000XVZAXVZA000001koool3000000?4QI00003oool02?ooo`<00000
0kn2T@000?ooo`07oooo100000:aMY850000ooooobOoool00`000?ooooooo`04oooo0@00007oool1
oooo002[oooo00<0003oooooool0Soooo`80000Eoooo0`000003oooo0000oooo00Ooool3000000C;
SY800000003oool300001Oooo`<000001/>5T@0000000<V<TP000?ooo`D00003oooo00H0003bZgP0
002TKI80003FViP5000000>nPI80003H/BP00P0000:cNI<200001?ooo`<000001:E]T@000?RhOP00
00_oool0100009USTIUSTIUST@8000000lJ7T@000?ooo`05oooo10000005[7BD0000XVZAXVZA0000
01koool3000000?4QI00003oool02?ooo`<000000kn2T@000?ooo`07oooo100000:aMY850000oooo
obSoool00`000?ooooooo`03oooo0@00007oool1oooo002/oooo00<0003oooooool0S_ooo`80000E
oooo0`000003oooo0000oooo00Ooool6000000Coool0000000000005oooo0`000003`hFA00000000
008000000oooo`000000000300000oooo`060000lZ]h0000Y6fB0000eY^H1@000005_X6B00000000
oooo000000:cNI<200001?ooo`@00002n;Qn00<0003oooooool02Oooo`040000VF>AVF>AVF>A0P00
0003aXNA0000oooo00Goool4000000F/M9@0002RJY6RJY4000007_ooo`<000000lB5T0000?ooo`08
oooo0`000003_h:A0000oooo00Ooool400000[5fTPD0003ooooo:?ooo`030000oooooooo00?oool1
00000Oooo`7oool00:goool00`000?ooooooo`2=oooo0P0001Goool3000000?oool0003oool01ooo
o`H000001?ooo`000000000000Goool3000000C3QI40000000000003oooo100000?oool01P000?:[
N0000:A]TP000=JKV0D000001Kj1TP0000000?ooo`000002/gVC0P0000Coool400000_RhOP030000
oooooooo00Woool0100009USTIUSTIUST@8000000lJ7T@000?ooo`05oooo10000005[7BD0000XVZA
XVZA000001koool3000000?4QI00003oool02?ooo`<000000kn2T@000?ooo`08oooo0`0000:aMY80
0`000?FbO@0000020000ooooobWoool00`000?ooooooo`02oooo0@00007oool1oooo002^oooo0P00
08goool200005Oooo`800002oooo00<0003oooooool01_ooo`H000001?ooo`000000000000Goool3
000000C3QI40000000000003oooo100000?oool01P000?:[N0000:A]TP000=JKV0D000001Kj1TP00
00000?ooo`000002/gVC0P0000Coool4000000?h^7h0003oool02oooo`040000VF>AVF>AVF>A0P00
0003aXNA0000oooo00Goool2000000B/M9@0002/M9@00002XVZA00<0003oooooool07Oooo`800000
0lB5T0000?ooo`08oooo0`000003_h:A0000oooo00Soool300000[5fTP030000mK9m00000080003o
oooo:_ooo`050000oooooooooooo000000;oool00;3oool00`000?ooooooo`2:oooo0P0001Goool2
00000_ooo`030000oooooooo00Koool6000000Coool0000000000005oooo0`000004`hFA00000000
00000oooo`040000Z6j@000000000oooo`060000lZ]h0000Y6fB0000eY^H1@000005_X6B00000000
oooo000000:cNI<200001?ooo`@000000oRhOP000?ooo`0;oooo00@0002IHi6IHi6IHi42000000?6
Qi40003oool01Oooo`8000001:adU0000:adU00000:RJY400`000?ooooooo`0Moooo0P000003a8F@
0000oooo00Woool2000000>oPY40003oool02?ooo`<00002/GJB00<0003e/Wd000000P000?ooool[
oooo00@0003oooooool00002oooo002aoooo00<0003oooooool0ROooo`80000Eoooo0P0000;oool0
0`000?ooooooo`06oooo1P000004oooo0000000000001Oooo`<000001<>5T@000000000000?oool0
10000:Q^T000000000?oool01P000?:[N0000:A]TP000=JKV0D000001Kj1TP0000000?ooo`000002
/gVC0P0000Coool4000000?h^7h0003oool02oooo`040000VF>AVF>AVF>A0P000003aXNA0000oooo
00Goool2000000B/M9@0002/M9@00002XVZA00<0003oooooool07Oooo`8000000lB5T0000?ooo`09
oooo0P000003_h:A0000oooo00Soool300000[5fTP030000mK9m00000080003ooooo:oooo`040000
oooooooo00000_ooo`00/_ooo`030000oooooooo08Soool200005Oooo`800002oooo00<0003ooooo
ool01_ooo`H00002oooo0P0000Goool3000000C3QI40000000000003oooo00@0002XKY0000000003
oooo00H0003bZgP0002TKI80003FViP5000000FnPI800000003oool000000[=iT`800004oooo1000
0003n;Qn0000oooo00_oool0100009USTIUSTIUST@8000000lJ7T@000?ooo`05oooo0P000004[7BD
0000[7BD00000Z9ZT@030000oooooooo01goool2000000?4QI00003oool02Oooo`8000000kn2T@00
0?ooo`08oooo0`0000:aMY800`000?FbO@0000020000ooooobcoool00`000?ooo`000002oooo002c
oooo00<0003oooooool0Qoooo`80000Eoooo0P0000;oool00`000?ooooooo`06oooo1P0000;oool0
0`000?ooooooo`04oooo0`000004`hFA0000000000000oooo`040000Z6j@000000000oooo`040000
lZ]h0000Y6fB1@000003nk]k0000_X6B008000001?ooo`000;=iTk=iT`800004oooo10000003n;Qn
0000oooo00_oool0100009USTIUSTIUST@8000000lJ7T@000?ooo`05oooo0P000004[7BD0000[7BD
00000Z9ZT@030000oooooooo01goool2000000?4QI00003oool02Oooo`8000000kn2T@000?ooo`08
oooo0`0000:aMY800`000?FbO@0000020000ooooobgoool00`000?ooo`000001oooo002doooo0P00
08Ooool200005Oooo`800002oooo00<0003oooooool01_ooo`H00002oooo00<0003oooooool01?oo
o`<000001<>5T@000000000000?oool010000:Q^T000000000?oool010000?:[N0000:A]TPD00000
0o^kN`000;j1TP0200000_ooo`040000/gVC000000001?ooo`@000000oRhOP000?ooo`0;oooo00@0
002IHi6IHi6IHi42000000?6Qi40003oool01Oooo`8000001:adU0000:adU00000:RJY400`000?oo
ooooo`0Moooo0P000003a8F@0000oooo00Woool2000000>oPY40003oool02?ooo`<00002/GJB00<0
003e/Wd000000P000?ooool^oooo0P00007oool00;Koool00`000?ooooooo`24oooo00<0003ooooo
ool05?ooo`8000000oooo`000?ooo`08oooo1P0000;oool00`000?ooooooo`04oooo0`000004`hFA
0000000000000oooo`030000Z6j@000000Coool010000?:[N0000:A]TPH000001;j1TP000=Ra:000
00;oool010000;=iT`00000000Coool4000000?h^7h0003oool02oooo`040000VF>AVF>AVF>A0P00
0003aXNA0000oooo00Goool2000000B/M9@0002/M9@00002XVZA00<0003oooooool07Oooo`<0000;
oooo0P000003_h:A0000oooo00Soool300000[5fTP040000mK9m00000000ooooobooool200000Ooo
o`00]oooo`030000oooooooo08?oool00`000?ooooooo`0Doooo0P000003oooo0000oooo00Soool2
000000B`MY80000000000002oooo00<0003oooooool01?ooo`<000001<>5T@000<V<TP0000?oool0
0`000:Q^T0000004oooo00@0003bZgP0002TKI86000000BnPI80003H/BP00002oooo00@0002cNI<0
00000004oooo10000003n;Qn0000oooo00_oool01`0009USTIUSTIUST@000<J7T@000007oooo0P00
0004[7BD0000[7BD00000Z9ZT@030000oooooooo01goool300002oooo`8000000kn2T@000?ooo`08
oooo0`0000:aMY8010000?FbO@0000000?ooool_oooo0P00007oool00;Soool00`000?ooooooo`22
oooo00<0003oooooool05?ooo`8000000oooo`000?ooo`08oooo1P0000;oool00`000?ooooooo`04
oooo0P0000;3QI400`000<V<TP000003oooo0`0000Coool010000?:[N0000:A]TPH000001;j1TP00
0=Ra:00000;oool010000;=iT`00000000Coool4000000?h^7h0003oool02oooo`070000VF>AVF>A
VF>A0000aXNA000000Ooool2000000F/M9@0002/M9@0002RJY400P0001ooool300002oooo`800000
0kn2T@000?ooo`08oooo00<0003^XG8000000[5fTP040000mK9m00000000ooooob_oool400000ooo
o`00^Oooo`800022oooo00<0003oooooool05?ooo`8000000oooo`000?ooo`08oooo0`000003ahVB
0000000000;oool00`000?ooooooo`05oooo00H00033QI4000000039S9800003oooo0`0000Coool0
10000?:[N0000:A]TPH000001;j1TP000=Ra:00000;oool010000;=iT`00000000Coool4000000?h
^7h0003oool02oooo`070000VF>AVF>AVF>A0000aXNA000000Soool01P000:adU0000:adU0000:9Z
T@80000Ooooo0`0000_oool2000000>oPY40003oool02?ooo`030000kZ5b000000:aMY82000000?e
/Wh0003oool0ooooobKoool400001oooo`00^oooo`030000oooooooo07ooool00`000?ooooooo`0D
oooo00@0003oooooool00009oooo1@0000?oool00`000?ooooooo`05oooo00H00033QI4000000039
S9800003oooo0`0000Coool010000?:[N0000:A]TPH000001;j1TP000=Ra:00000;oool010000;=i
T`00000000Coool4000000?h^7h0003oool02oooo`070000VF>AVF>AVF>A0000aXNA000000Soool0
1P000:adU0000:adU0000:9ZT@80000Ooooo0`0000_oool2000000>oPY40003oool02?ooo`030000
kZ5b000000:aMY82000000?e/Wh0003oool0ooooob;oool400002oooo`00_?ooo`030000oooooooo
07koool00`000?ooooooo`0Doooo00@0003oooooool00009oooo1@0000?oool00`000?ooooooo`05
oooo00H00033QI4000000039S9800003oooo0`0000Coool010000?:[N0000:A]TPH000001;j1TP00
0=Ra:00000;oool010000;=iT`00000000Coool4000000?h^7h0003oool02oooo`070000VF>AVF>A
VF>A0000aXNA000000Soool01P000:adU0000:adU0000:9ZT@80000Ooooo0`0000_oool2000000>o
PY40003oool02?ooo`030000kZ5b000000:aMY82000000?e/Wh0003oool0oooooakoool400003ooo
o`00_Oooo`030000oooooooo07goool00`000?ooooooo`0Doooo00@0003oooooool00009oooo1@00
00_oool01P000<>5T@0000000<V<TP0000?oool300001?ooo`040000lZ]h0000Y6fB1P000003_X6B
0000000000?oool010000;=iT`00000000Coool2000000BUKI40003h^7h0000<oooo00L0002IHi6I
Hi6IHi400036Qi4000002?ooo`060000[7BD0000[7BD0000XVZA0P0001ooool300002oooo`800000
0kn2T@000?ooo`08oooo00<0003^XG8000000[5fTP8000000oFbOP000?ooo`3ooooo6oooo`<0000C
oooo002noooo0P0009Coool010000?ooooooo`0000Woool500002oooo`060000`hFA00000000bHbB
00000oooo`<00004oooo00@0003bZgP0002TKI86000000>nPI80000000000oooo`040000/gVC0000
00001?ooo`8000001:E]T@000?RhOP0000goool01P0009USTIUST@000<J7T@0000Soool01P000:ad
U:adU:adU0000:9ZT@80000Ooooo0`0000coool00`000;n2T@000009oooo00<0003^XG8000000[5f
TP8000000oFbOP000?ooo`3ooooo5oooo`@0000Foooo0030oooo00<0003oooooool0TOooo`040000
oooooooo00002Oooo`D0000;oooo00H00033QI4000000039S9800003oooo0`0000Coool010000?:[
N0000:A]TPH000000kj1TP0000000003oooo00@0002cNI<000000004oooo0P000004YFfA0000n;Qn
00003Oooo`060000VF>AVF>A0000aXNA00002?ooo`060000[7BD[7BD[7BD0000XVZA0P0001ooool3
00003?ooo`030000_h:A000000[oool200000[5fTP@0003ooooo5?ooo`@0000Joooo0031oooo00<0
003oooooool0T?ooo`040000oooooooo00002Oooo`D0000;oooo00H00033QI4000000039S9800003
oooo0`0000Coool010000?:[N0000:A]TPH000000kj1TP0000000003oooo00@0002cNI<000000004
oooo0P000004YFfA0000n;Qn00003_ooo`050000VF>A0000aXNA000000Soool01P000:adU:adU:ad
U0000:9ZT@80000Ooooo0`0000coool00`000;n2T@00000:oooo0P0000:aMY840000oooooa3oool4
00007_ooo`00`_ooo`030000oooooooo09;oool00`000?ooooooo`07oooo1@0000_oool01P000<>5
T@0000000<V<TP0000?oool300001?ooo`040000lZ]h0000Y6fB1P000003_X6B0000000000Coool3
00001?ooo`8000001:E]T@000?RhOP0000koool01@0009UST@000<J7T@000008oooo00H0002/M9B/
M9B/M9@0002RJY4200007oooo`<0000<oooo00<0002oPY4000002_ooo`800002/GJB10000?ooool<
oooo100002;oool00<?oool20000T_ooo`030000oooooooo00Ooool500002oooo`030000`hFA0000
00800004oooo0`0000Coool010000?:[N0000:A]TPH000000kj1TP0000000004oooo0`0000Coool2
000000BUKI40003h^7h0000>oooo0`000003aXNA0000oooo00Ooool01P000:adU:adU:adU0000:9Z
T@80000Ooooo0`0000coool00`000;n2T@00000:oooo0P0000:aMY840000ooooo`Soool400009_oo
o`00aOooo`030000oooooooo08ooool00`000?ooooooo`07oooo1@0000_oool00`000<>5T@000002
00001?ooo`<00004oooo00@0003bZgP0002TKI86000000>nPI80000000001?ooo`<00004oooo0P00
0003YFfA0000000000ooool3000000?6Qi40003oool01oooo`060000[7BD[7BD[7BD0000XVZA0P00
01ooool300003?ooo`030000_h:A000000[oool200000[5fTP@0003ooooo1Oooo`<0000Zoooo0036
oooo00<0003oooooool0S_ooo`030000oooooooo00Ooool500002oooo`030000`hFA000000800004
oooo0`0000Coool010000?:[N0000:A]TPH000000kj1TP0000000004oooo0`0000Coool2000000>U
KI40000000003oooo`050000V5f:0000aXNA000000Soool01P000:adU:adU:adU0000:9ZT@80000O
oooo0`0000coool00`000;n2T@00000:oooo0P0000:aMY840000ooooo`7oool40000;Oooo`00aooo
o`030000oooooooo08goool00`000?ooooooo`07oooo1@0000_oool00`000<>5T@00000200001?oo
o`<00004oooo00D0003bZgP00000003ATY801@000003_X6B0000000000Coool300001?ooo`800000
0jE]T@000000000?oooo00D0002HGHX00036Qi4000002?ooo`060000[7BD[7BD[7BD0000XVZA0P00
023oool200003?ooo`030000_h:A000000[oool200000[5fTP@0003loooo1000037oool00<Soool2
0000SOooo`030000oooooooo00Ooool500002oooo`030000`hFA000000800004oooo0`0000Coool0
1@000?:[N00000000=6BTP05000000>nPI80000000001?ooo`800005oooo0P000003YFfA00000000
00ooool01@0009QMRP000<J7T@000008oooo00L0002/M9B/M9B/M9@0002RJY4000008Oooo`80000<
oooo00<0002oPY4000002_ooo`800002/GJB10000?Soool40000=Oooo`00b_ooo`030000oooooooo
08[oool00`000?ooooooo`07oooo1@0000_oool00`000<>5T@00000200001?ooo`<00004oooo00D0
003bZgP00000003ATY801@000003_X6B0000000000Coool200001Oooo`8000000jE]T@000000000@
oooo0P000003aXNA0000oooo00Ooool01`000:adU:adU:adU0000:9ZT@00000Qoooo0P0000coool0
0`000;n2T@00000:oooo0P0000:aMY840000m?ooo`@0000ioooo003;oooo00<0003oooooool0ROoo
o`030000oooooooo00Ooool500002oooo`030000`hFA000000800004oooo0`0000Coool00`000?:[
N0000007000000>nPI80000000001?ooo`800005oooo0P000003YFfA00000000013oool2000000?6
Qi40003oool01oooo`030000[7BD[7BD00:/M9@200008Oooo`80000<oooo00<0002oPY4000002_oo
o`040000kZ5b0000/GJB10000?7oool30000?Oooo`00c?ooo`030000oooooooo08Soool00`000?oo
ooooo`07oooo1@0000_oool00`000<>5T@00000200001?ooo`800005oooo00<0003bZgP000001`00
0003_X6B0000000000Coool200001Oooo`<000000oRhOP000?ooo`0?oooo0P000003aXNA0000oooo
00Ooool00`000:adU:adU002[7BD0P00027oool200003?ooo`030000_h:A000000[oool010000>jQ
LP000;5fTP@0003]oooo1000043oool00<goool00`000?ooooooo`27oooo00<0003oooooool01ooo
o`D0000;oooo00D00033QI400039S98000001?ooo`800005oooo00<0003bZgP000001@000005oooo
00000000f;4X000000Coool200001_ooo`8000000oRhOP000?ooo`0?oooo0P000003aXNA0000oooo
00Ooool00`000:adU:adU002[7BD0P00027oool200003?ooo`030000_h:A000000[oool010000>jQ
LP000;5fTP@0003Yoooo100004Coool00<koool20000Qoooo`030000oooooooo00Ooool2000000?7
RI80000000002oooo`050000`hFA0000bHbB000000Coool200001Oooo`030000lZ]h000000D00000
1?ooo`000000000000Goool200001_ooo`8000000oRhOP000?ooo`0?oooo0P000003aXNA0000oooo
00Ooool00`000:adU:adU002[7BD0P00027oool200003?ooo`030000_h:A000000[oool010000>jQ
LP000;5fTP@0003Uoooo100004Soool00=3oool00`000?ooooooo`24oooo00<0003oooooool01ooo
o`@0000<oooo00D00033QI400039S98000001?ooo`800005oooo00<0003bZgP000001@000004oooo
0000000000001Oooo`800006oooo0P000003n;Qn0000oooo00ooool2000000?6Qi40003oool01ooo
o`030000[7BD[7BD00:/M9@200008Oooo`80000<oooo00<0002oPY4000002_ooo`040000kZ5b0000
/GJB10000>7oool40000C?ooo`00dOooo`030000oooooooo08?oool00`000?ooooooo`07oooo1000
00coool01@000<>5T@000<V<TP000004oooo0P0000Goool00`000?:[N0000005000000Coool00000
00000006oooo00<0003oooooool01?ooo`8000000oRhOP000?ooo`0?oooo0P000003aXNA0000oooo
00Ooool00`000:adU:adU002[7BD0P00027oool200003?ooo`030000_h:A000000_oool2000000>a
MY80000000000P000=goool40000D?ooo`00d_ooo`030000oooooooo08;oool00`000?ooooooo`07
oooo100000coool3000000?9S980003oool00oooo`800005oooo00<0003bZgP000001@000004oooo
0000000000001_ooo`030000oooooooo00Coool2000000?h^7h0003oool03oooo`8000000lJ7T@00
0?ooo`08oooo00@0002/M9B/M9B/M9@200008Oooo`80000<oooo00<0002oPY4000002oooo`800000
0k5fTP00000000020000f_ooo`<0001Doooo003Coooo0P0008;oool00`000?ooooooo`07oooo1000
00coool3000000?9S980003oool00oooo`800005oooo00<0003bZgP000001@000004oooo00000000
00001_ooo`030000oooooooo00Coool2000000?h^7h0003oool03oooo`8000000lJ7T@000?ooo`08
oooo00@0002/M9B/M9B/M9@200008Oooo`80000<oooo0`0000_oool2000000>aMY80000000000P00
0=Koool40000Eoooo`00eOooo`030000oooooooo07ooool00`000?ooooooo`07oooo100000coool3
000000?9S980003oool00oooo`800005oooo00<0003bZgP000001@000004oooo0000000000001_oo
o`030000oooooooo00Coool2000000?h^7h0003oool03oooo`8000000lJ7T@000?ooo`08oooo00@0
002/M9B/M9B/M9@200008Oooo`80000<oooo0`0000_oool2000000>aMY80000000000P000=;oool4
0000Foooo`00e_ooo`030000oooooooo07koool00`000?ooooooo`07oooo100000coool3000000?9
S980003oool00oooo`800005oooo00<0003bZgP000001@000004oooo0000000000001_ooo`030000
oooooooo00Coool2000000?h^7h0003oool03oooo`8000000lJ7T@000?ooo`08oooo00@0002/M9B/
M9B/M9@200008Oooo`80000<oooo0`0000_oool2000000>aMY80000000000P000<koool40000Gooo
o`00eoooo`030000oooooooo07goool00`000?ooooooo`07oooo100000coool3000000?9S980003o
ool00oooo`800005oooo0P000003Y6fB0000000000<000001?ooo`000000000000Koool00`000?oo
ooooo`04oooo0P000003n;Qn0000oooo00ooool2000000?6Qi40003oool02?ooo`040000[7BD[7BD
[7BD0P00027oool200003?ooo`<0000;oooo0P000003/GJB000000000080003:oooo100006?oool0
0=Soool20000O?ooo`030000oooooooo00Soool400003?ooo`<000000lV<TP000?ooo`03oooo0P00
00Goool2000000>TKI80000000000`000004oooo0000000000003Oooo`8000000oRhOP000?ooo`0?
oooo0P000003aXNA0000oooo00Soool010000:adU:adU:adU080000Qoooo0P0000goool200002ooo
o`8000000k5fTP00000000020000aoooo`<0001Woooo003Joooo00<0003oooooool0NOooo`030000
oooooooo00Soool400003?ooo`<000000lV<TP000?ooo`03oooo0P0000Goool2000000>TKI800000
00000`000004oooo0000000000003Oooo`<0000Aoooo0P000003aXNA0000oooo00Soool010000:ad
U:adU:adU080000Qoooo0P0000goool200002oooo`8000000k5fTP00000000020000`oooo`@0001Z
oooo003Koooo00<0003oooooool0N?ooo`030000oooooooo00Soool400003?ooo`<000000lV<TP00
0?ooo`03oooo00<0003oooooool01?ooo`8000000jA]TP0000000003000000Coool000000000000=
oooo0`00017oool2000000?6Qi40003oool02?ooo`040000[7BD[7BD[7BD0P00027oool200003Ooo
o`80000;oooo0P000003/GJB000000000080002ooooo100006koool00=coool00`000?ooooooo`1g
oooo00<0003oooooool02?ooo`@0000<oooo100000Goool00`000?ooooooo`05oooo00<0002TKI80
000010000004oooo0000000000003Oooo`<0000Boooo00<00036Qi4000002Oooo`040000[7BD[7BD
[7BD0P00027oool200003Oooo`80000;oooo0P000003/GJB000000000080002koooo100007;oool0
0=goool20000Moooo`030000oooooooo00Soool400003?ooo`@00005oooo00<0003oooooool01Ooo
o`050000Y6fB00000000lK66008000000oooo`000000000>oooo0`0001;oool00`000<J7T@000009
oooo00@0002/M9B/M9B/M9@200008Oooo`80000=oooo0P0000_oool2000000>aMY80000000000P00
0;Ooool40000M_ooo`00goooo`030000oooooooo07Coool00`000?ooooooo`08oooo100000coool4
00001Oooo`030000oooooooo00Goool00`000:A]TP000004000000?oool0000000003_ooo`<0000B
oooo00<00036Qi4000002_ooo`030000[7BD[7BD0080000Qoooo0P0000goool200002oooo`800000
0k5fTP00000000020000/oooo`@0001joooo003Poooo00<0003oooooool0Loooo`030000oooooooo
00Soool400003?ooo`@0000=oooo00<0002TKI80000010000003oooo0000000000koool300004_oo
o`<0000:oooo00<0002/M9B/M9@00P0002;oool00`000?ooooooo`0;oooo0P0000_oool2000000>a
MY80000000000P000;3oool30000O_ooo`00hOooo`030000oooooooo07;oool00`000?ooooooo`08
oooo100000coool400003Oooo`030000Y6fB000000@000000oooo`000000000>oooo0`0001;oool3
00002_ooo`030000[7BD[7BD0080000Roooo00<0003oooooool02oooo`80000;oooo0P000003/GJB
000000000080002/oooo1000087oool00>;oool20000L_ooo`030000oooooooo00Soool400003?oo
o`@0000=oooo0P000003dI:B00000000008000000oooo`000000000>oooo0`0001;oool200002ooo
o`030000[7BD[7BD0080000Roooo00<0003oooooool02oooo`80000;oooo0P000003/GJB00000000
0080002Xoooo100008Goool00>Coool00`000?ooooooo`1_oooo00<0003oooooool02?ooo`@0000<
oooo0P000003bHbB0000oooo00coool2000000?ATY80000000000P000003oooo0000000000koool3
00004_ooo`80000;oooo00<0002/M9B/M9@00P0002;oool00`000?ooooooo`0;oooo0P0000coool0
0`000;5fTP0000030000Y?ooo`@00029oooo003Uoooo00<0003oooooool0K_ooo`030000oooooooo
00Soool400003?ooo`8000000lV<TP000?ooo`0<oooo0P000003dI:B00000000008000000oooo`00
0000000>oooo0`0001;oool200002oooo`030000[7BD[7BD0080000Roooo00<0003oooooool02ooo
o`80000<oooo00<0002aMY8000000`000:3oool40000SOooo`00i_ooo`030000oooooooo06goool0
0`000?ooooooo`08oooo0`0000goool2000000?9S980003oool03?ooo`L000000oooo`000000000>
oooo0`0001;oool200002oooo`030000[7BD[7BD0080000Roooo00<0003oooooool02oooo`80000<
oooo1P0009goool30000TOooo`00ioooo`030000oooooooo06coool00`000?ooooooo`08oooo0`00
00goool2000000?9S980003oool03?ooo`L000000oooo`000000000>oooo0`0001;oool200002ooo
o`030000[7BD[7BD0080000Roooo00<0003oooooool02oooo`80000<oooo1P0009Woool40000U?oo
o`00j?ooo`80001/oooo00<0003oooooool02?ooo`<0000=oooo0P000003bHbB0000oooo00coool6
00000_ooo`80000>oooo0`0001;oool200002oooo`030000[7BD[7BD0080000Roooo00<0003ooooo
ool02oooo`80000<oooo1P0009Goool40000V?ooo`00j_ooo`030000oooooooo06Woool00`000?oo
ooooo`08oooo0`0000goool2000000?9S980003oool03?ooo`H00002oooo00<0003oooooool03Ooo
o`<0000Boooo0P0000_oool00`000:adU:adU00200008_ooo`030000oooooooo00_oool200003?oo
o`H0002Aoooo100009coool00>_oool00`000?ooooooo`1Xoooo00<0003oooooool02?ooo`<0000=
oooo0P000003bHbB0000oooo00coool600000_ooo`030000oooooooo00goool300004_ooo`80000<
oooo00@0002/M9@00000000Roooo00<0003oooooool02oooo`80000<oooo1P0008goool40000X?oo
o`00k?ooo`030000oooooooo06Ooool00`000?ooooooo`08oooo0`0000goool2000000?9S980003o
ool03?ooo`H00002oooo00<0003oooooool03Oooo`<0000Boooo0P0000coool010000:adU0000000
02;oool00`000?ooooooo`0;oooo0P0000coool60000ROooo`@0002Toooo003]oooo0P0006Ooool0
0`000?ooooooo`08oooo0`0000goool2000000?9S980003oool03?ooo`H00002oooo00<0003ooooo
ool03Oooo`030000n;Qn000001;oool200003?ooo`040000[7BD00000000<?ooo`80000<oooo1P00
08Koool30000Z?ooo`00koooo`030000oooooooo06Coool00`000?ooooooo`08oooo0`0000goool2
000000?9S980003oool03?ooo`H00002oooo00<0003oooooool03Oooo`030000n;Qn000001?oool0
0`000?ooooooo`0:oooo00@0002/M9@00000000`oooo0P0000coool60000P_ooo`@0002[oooo003`
oooo00<0003oooooool0Hoooo`030000oooooooo00Soool300003Oooo`8000000lV<TP000?ooo`0<
oooo1P0000;oool00`000?ooooooo`0=oooo0P0001Coool00`000?ooooooo`0:oooo00@0002/M9@0
0000000`oooo0P0000coool60000O_ooo`@0002_oooo003aoooo00<0003oooooool0H_ooo`030000
oooooooo00Soool300003Oooo`8000000lV<TP000?ooo`0<oooo1P0001;oool200005?ooo`030000
oooooooo00[oool010000:adU0000000037oool00`000?ooooooo`0:oooo1P0007[oool40000/ooo
o`00l_ooo`80001Roooo00<0003oooooool02?ooo`<0000=oooo0P000003bHbB0000oooo00coool6
00004_ooo`80000Doooo00<0003oooooool02_ooo`040000[7BD00000000<Oooo`030000oooooooo
00[oool60000M_ooo`@0002goooo003doooo00<0003oooooool0Goooo`030000oooooooo00Soool3
00003Oooo`<0000>oooo1P0001;oool200005?ooo`030000oooooooo00[oool00`000:adU000000b
oooo00<0003oooooool02_ooo`H0001coooo0`000;_oool00?Goool00`000?ooooooo`1Noooo00<0
003oooooool02?ooo`<0000=oooo0`0000koool600004_ooo`80000Doooo00<0003oooooool02_oo
o`030000[7BD000003;oool00`000?ooooooo`0;oooo1@0006ooool40000__ooo`00m_ooo`030000
oooooooo05goool00`000?ooooooo`08oooo0`0000goool300003_ooo`H0000Boooo0P0001Coool0
0`000?ooooooo`0:oooo00<0002/M9@00000<_ooo`030000oooooooo00_oool50000Joooo`@00032
oooo003goooo0P0005goool00`000?ooooooo`08oooo0`0000koool200003_ooo`H0000Boooo0P00
01Coool00`000?ooooooo`0;oooo0P0003;oool00`000?ooooooo`0;oooo1@0006Ooool40000a_oo
o`00nOooo`030000oooooooo05[oool00`000?ooooooo`08oooo0`0000koool200003_ooo`H0000B
oooo0P0002;oool20000<_ooo`030000oooooooo00_oool50000Hoooo`@0003:oooo003joooo00<0
003oooooool0FOooo`030000oooooooo00Soool300003_ooo`80000>oooo1P0001;oool200008_oo
o`80000boooo00<0003oooooool02oooo`D0001Ooooo10000<koool00?_oool00`000?ooooooo`1H
oooo00<0003oooooool02?ooo`<0000>oooo0P0000koool3000000?a/HH0000000004_ooo`80000R
oooo0P0003;oool00`000?ooooooo`0;oooo1@0005coool30000d_ooo`00o?ooo`80001Goooo00<0
003oooooool02Oooo`80000?oooo0P0000koool00`000=6BTP00000300004_ooo`030000oooooooo
027oool20000<_ooo`030000oooooooo00_oool50000F?ooo`@0003Eoooo003noooo00<0003ooooo
ool0E?ooo`030000oooooooo00Woool200003oooo`80000>oooo00<0003ATY8000000`0001;oool0
0`000?ooooooo`0Qoooo0P0003;oool00`000?ooooooo`0;oooo1@0005Coool40000fOooo`00oooo
o`030000oooooooo05?oool00`000?ooooooo`09oooo0P0000ooool200003_ooo`030000dI:B0000
00<0000foooo0P00043oool50000D?ooo`@0003Moooo003ooooo0Oooo`030000oooooooo05;oool0
0`000?ooooooo`09oooo0P0000ooool200003_ooo`030000dI:B000000<0000foooo0P00043oool5
0000C?ooo`@0003Qoooo003ooooo0_ooo`030000oooooooo057oool00`000?ooooooo`09oooo0P00
00ooool200003_ooo`H0000foooo0P00043oool50000BOooo`<0003Uoooo003ooooo0oooo`80001A
oooo00<0003oooooool02Oooo`80000?oooo0P0000koool50000=oooo`800010oooo1@0004Goool4
0000j?ooo`00ooooo`Goool00`000?ooooooo`1>oooo00<0003oooooool02Oooo`80000?oooo0P00
00koool50000>?ooo`030000oooooooo03koool50000@Oooo`@0003/oooo003ooooo1_ooo`030000
oooooooo04goool00`000?ooooooo`09oooo0P0000ooool200003_ooo`D0000hoooo00<0003ooooo
ool0?_ooo`D0000moooo10000?3oool00?ooool7oooo00<0003oooooool0C?ooo`030000oooooooo
00Woool200003oooo`80000>oooo1@0003Soool00`000?ooooooo`0ooooo100003Woool40000m?oo
o`00ooooo`Soool20000C?ooo`030000oooooooo01[oool200003_ooo`D0000hoooo00<0003ooooo
ool0?oooo`@0000eoooo10000?Soool00?ooool:oooo00<0003oooooool0BOooo`030000oooooooo
01[oool200003_ooo`D0000hoooo00<0003oooooool0?oooo`@0000boooo0`000?coool00?ooool;
oooo00<0003oooooool0B?ooo`030000oooooooo01[oool200003_ooo`D0001joooo100002koool4
0000ooooo`00ooooo`coool00`000?ooooooo`17oooo00<0003oooooool06_ooo`80000>oooo1@00
07[oool40000:_ooo`@0003ooooo1?ooo`00ooooo`goool20000Aoooo`030000oooooooo01[oool0
0`000?ooooooo`0=oooo1@0007[oool400009_ooo`@0003ooooo2?ooo`00ooooo`ooool00`000?oo
ooooo`14oooo00<0003oooooool06_ooo`030000oooooooo00goool50000N_ooo`@0000Roooo1000
0?ooool<oooo003ooooo4?ooo`030000oooooooo04?oool00`000?ooooooo`0Joooo00<0003ooooo
ool03Oooo`D0001joooo100001ooool30000oooooa3oool00?oooolAoooo00<0003oooooool0@_oo
o`030000oooooooo01[oool00`000?ooooooo`0=oooo1@0007[oool400006oooo`@0003ooooo4ooo
o`00oooooa;oool20000@_ooo`030000oooooooo01[oool00`000?ooooooo`0=oooo1@0007_oool3
00005oooo`@0003ooooo5oooo`00oooooaCoool00`000?ooooooo`0ooooo00<0003oooooool06_oo
o`030000oooooooo00goool50000O?ooo`80000Coooo10000?oooolKoooo003ooooo5Oooo`030000
oooooooo03koool00`000?ooooooo`0Joooo00<0003oooooool03Oooo`D0001moooo00<0003ooooo
ool03Oooo`@0003ooooo7oooo`00oooooaKoool00`000?ooooooo`0moooo00<0003oooooool06_oo
o`030000oooooooo00goool50000ROooo`@0003ooooo8oooo`00oooooaOoool00`000?ooooooo`0l
oooo00<0003oooooool06_ooo`030000oooooooo00goool50000Q_ooo`<0003ooooo9oooo`00oooo
oaSoool20000??ooo`030000oooooooo01[oool00`000?ooooooo`0=oooo1@0008;oool40000oooo
ob[oool00?oooolJoooo00<0003oooooool0>Oooo`030000oooooooo02[oool50000O_ooo`@0003o
oooo;_ooo`00oooooa_oool00`000?ooooooo`0hoooo00<0003oooooool0:_ooo`8000000o6aQP00
0000001joooo10000?oooolboooo003ooooo7?ooo`030000oooooooo03Ooool00`000?ooooooo`0Z
oooo1@0007Koool40000ooooocKoool00?oooolMoooo0P0003Ooool00`000?ooooooo`0Zoooo1@00
07?oool30000oooooc[oool00?oooolOoooo00<0003oooooool0=?ooo`030000oooooooo02[oool4
0000L?ooo`@0003ooooo?Oooo`00ooooob3oool00`000?ooooooo`0boooo00<0003oooooool0:ooo
o`@0001/oooo10000?oooom1oooo003ooooo8Oooo`030000oooooooo037oool00`000?ooooooo`0[
oooo100006Soool40000ooooodGoool00?oooolRoooo0P00037oool00`000?ooooooo`0[oooo1000
06Coool40000ooooodWoool00?oooolToooo00<0003oooooool0;_ooo`030000oooooooo02_oool4
0000H?ooo`@0003oooooCOooo`00ooooobGoool00`000?ooooooo`0]oooo00<0003oooooool0:ooo
o`@0001Moooo0`000?oooomAoooo003ooooo9_ooo`030000oooooooo02coool00`000?ooooooo`0[
oooo100005Woool40000oooooeCoool00?oooolWoooo0P0002coool00`000?ooooooo`0[oooo1000
05Goool40000oooooeSoool00?oooolYoooo00<0003oooooool0:Oooo`030000oooooooo02_oool4
0000DOooo`@0003oooooG?ooo`00ooooob[oool00`000?ooooooo`0Xoooo00<0003oooooool0:ooo
o`@0001=oooo10000?oooomPoooo003ooooo:oooo`030000oooooooo02Ooool00`000?ooooooo`0]
oooo0P0004[oool30000ooooofCoool00?ooool/oooo0P0002Ooool00`000?ooooooo`0]oooo00<0
003oooooool0AOooo`@0003oooooIoooo`00ooooobkoool00`000?ooooooo`0Toooo00<0003ooooo
ool0LOooo`@0003oooooJoooo`00ooooobooool00`000?ooooooo`0Soooo00<0003oooooool0KOoo
o`@0003oooooKoooo`00oooooc3oool00`000?ooooooo`0Roooo00<0003oooooool0JOooo`@0003o
ooooLoooo`00oooooc7oool00`000?ooooooo`0Qoooo00<0003oooooool0IOooo`@0003oooooMooo
o`00oooooc;oool200008Oooo`030000oooooooo06;oool30000ooooog_oool00?ooooldoooo00<0
003oooooool07_ooo`030000oooooooo05koool40000ooooogkoool00?ooooleoooo00<0003ooooo
ool07Oooo`030000oooooooo05[oool40000oooooh;oool00?oooolfoooo00<0003oooooool07?oo
o`030000oooooooo05Koool40000ooooohKoool00?oooolgoooo0P0001coool00`000?ooooooo`1B
oooo10000?oooon:oooo003ooooo>Oooo`030000oooooooo01Woool00`000?ooooooo`1?oooo0`00
0?oooon>oooo003ooooo>_ooo`030000oooooooo01Soool00`000?ooooooo`1;oooo10000?oooonA
oooo003ooooo>oooo`030000oooooooo01Ooool00`000?ooooooo`17oooo10000?oooonEoooo003o
oooo??ooo`80000Goooo00<0003oooooool0@oooo`@0003oooooVOooo`00ooooockoool00`000?oo
ooooo`0Doooo00<0003oooooool0?oooo`@0003oooooWOooo`00ooooocooool00`000?ooooooo`0C
oooo00<0003oooooool0>oooo`@0003oooooXOooo`00oooood3oool00`000?ooooooo`0Boooo00<0
003oooooool0>?ooo`<0003oooooYOooo`00oooood7oool200004_ooo`030000oooooooo03Coool4
0000ooooojSoool00?oooom3oooo00<0003oooooool03_ooo`030000oooooooo037oool40000oooo
ojcoool00?oooom4oooo00<0003oooooool03Oooo`030000oooooooo02goool40000oooook3oool0
0?oooom5oooo00<0003oooooool03?ooo`030000oooooooo02Woool40000oooookCoool00?oooom6
oooo0P0000coool00`000?ooooooo`0Voooo0`000?oooonhoooo003oooooB?ooo`030000oooooooo
00Woool00`000?ooooooo`0Roooo10000?oooonkoooo003oooooBOooo`030000oooooooo00Soool0
0`000?ooooooo`0Noooo10000?oooonooooo003oooooB_ooo`030000oooooooo00Ooool00`000?oo
ooooo`0Joooo10000?ooooo3oooo003oooooBoooo`030000oooooooo00Koool00`000?ooooooo`0F
oooo10000?ooooo7oooo003oooooC?ooo`800006oooo00<0003oooooool04_ooo`@0003ooooobooo
o`00ooooodkoool00`000?ooooooo`03oooo00<0003oooooool03oooo`<0003ooooocoooo`00oooo
odooool00`000?ooooooo`02oooo00<0003oooooool02oooo`@0003oooood_ooo`00oooooe3oool0
1@000?ooooooooooo`000009oooo10000?oooooFoooo003oooooDOooo`8000000oooo`000?ooo`04
oooo10000?oooooJoooo003oooooDoooo`8000000oooo`00000000020000ooooomkoool00?oooomD
oooo0P000?oooooRoooo0000\
\>"],
  ImageRangeCache->{{{0, 821}, {665.563, 0}} -> {-0.0261222, 0.0451561, 
  0.0011921, 0.0011921}}]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowSize->{996, 646},
WindowMargins->{{2, Automatic}, {Automatic, 2}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 62, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1818, 55, 36, 0, 53, "Section"],
Cell[1857, 57, 96, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1990, 64, 57, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[2072, 68, 31, 0, 47, "Subsection"],
Cell[2106, 70, 1069, 22, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3212, 97, 42, 0, 47, "Subsection"],
Cell[3257, 99, 100, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3394, 106, 42, 0, 47, "Subsection"],
Cell[3439, 108, 444, 8, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3920, 121, 46, 0, 47, "Subsection"],
Cell[3969, 123, 1105, 20, 330, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5123, 149, 37, 0, 53, "Section"],
Cell[5163, 151, 82, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[5270, 156, 330, 9, 30, "Input"],
Cell[5603, 167, 194, 4, 25, "Print"],
Cell[5800, 173, 234, 5, 25, "Print"],
Cell[6037, 180, 143, 3, 25, "Print"],
Cell[6183, 185, 161, 3, 25, "Print"],
Cell[6347, 190, 159, 3, 25, "Print"],
Cell[6509, 195, 197, 4, 25, "Print"],
Cell[6709, 201, 171, 3, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6929, 210, 41, 0, 53, "Section"],
Cell[6973, 212, 593, 16, 124, "Input"]
}, Open  ]],
Cell[7581, 231, 31, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[7637, 235, 41, 0, 53, "Section"],
Cell[7681, 237, 55, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7761, 242, 78, 1, 30, "Input"],
Cell[7842, 245, 3353499, 75199, 675, 2655657, 66579, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[3361356, 75447, 26, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

